define((function(){return function(e){function t(t){for(var n,i,o=t[0],a=t[1],s=0,c=[];s<o.length;s++)i=o[s],Object.prototype.hasOwnProperty.call(r,i)&&r[i]&&c.push(r[i][0]),r[i]=0;for(n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n]);for(l&&l(t);c.length;)c.shift()()}var n={},r={0:0};function i(t){if(n[t])return n[t].exports;var r=n[t]={i:t,l:!1,exports:{}};return e[t].call(r.exports,r,r.exports,i),r.l=!0,r.exports}i.e=function(e){var t=[],n=r[e];if(0!==n)if(n)t.push(n[2]);else{var o=new Promise((function(t,i){n=r[e]=[t,i]}));t.push(n[2]=o);var a,s=document.createElement("script");s.charset="utf-8",s.timeout=120,i.nc&&s.setAttribute("nonce",i.nc),s.src=function(e){return i.p+""+e+".voila.js"}(e);var l=new Error;a=function(t){s.onerror=s.onload=null,clearTimeout(c);var n=r[e];if(0!==n){if(n){var i=t&&("load"===t.type?"missing":t.type),o=t&&t.target&&t.target.src;l.message="Loading chunk "+e+" failed.\n("+i+": "+o+")",l.name="ChunkLoadError",l.type=i,l.request=o,n[1](l)}r[e]=void 0}};var c=setTimeout((function(){a({type:"timeout",target:s})}),12e4);s.onerror=s.onload=a,document.head.appendChild(s)}return Promise.all(t)},i.m=e,i.c=n,i.d=function(e,t,n){i.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:n})},i.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.t=function(e,t){if(1&t&&(e=i(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var n=Object.create(null);if(i.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)i.d(n,r,function(t){return e[t]}.bind(null,r));return n},i.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return i.d(t,"a",t),t},i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.p="",i.oe=function(e){throw console.error(e),e};var o=window.webpackJsonp=window.webpackJsonp||[],a=o.push.bind(o);o.push=t,o=o.slice();for(var s=0;s<o.length;s++)t(o[s]);var l=a;return i(i.s=606)}([function(e,t,n){"use strict";e.exports=n(689)},function(e,t,n){"use strict";n.r(t),n.d(t,"__extends",(function(){return i})),n.d(t,"__assign",(function(){return o})),n.d(t,"__rest",(function(){return a})),n.d(t,"__decorate",(function(){return s})),n.d(t,"__param",(function(){return l})),n.d(t,"__metadata",(function(){return c})),n.d(t,"__awaiter",(function(){return u})),n.d(t,"__generator",(function(){return d})),n.d(t,"__createBinding",(function(){return h})),n.d(t,"__exportStar",(function(){return p})),n.d(t,"__values",(function(){return f})),n.d(t,"__read",(function(){return m})),n.d(t,"__spread",(function(){return g})),n.d(t,"__spreadArrays",(function(){return v})),n.d(t,"__await",(function(){return y})),n.d(t,"__asyncGenerator",(function(){return _})),n.d(t,"__asyncDelegator",(function(){return b})),n.d(t,"__asyncValues",(function(){return M})),n.d(t,"__makeTemplateObject",(function(){return w})),n.d(t,"__importStar",(function(){return A})),n.d(t,"__importDefault",(function(){return C})),n.d(t,"__classPrivateFieldGet",(function(){return x})),n.d(t,"__classPrivateFieldSet",(function(){return E}));
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
var r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)};function i(e,t){function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}var o=function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function a(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n}function s(e,t,n,r){var i,o=arguments.length,a=o<3?t:null===r?r=Object.getOwnPropertyDescriptor(t,n):r;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,n,r);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,n,a):i(t,n))||a);return o>3&&a&&Object.defineProperty(t,n,a),a}function l(e,t){return function(n,r){t(n,r,e)}}function c(e,t){if("object"==typeof Reflect&&"function"==typeof Reflect.metadata)return Reflect.metadata(e,t)}function u(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{l(r.next(e))}catch(e){o(e)}}function s(e){try{l(r.throw(e))}catch(e){o(e)}}function l(e){var t;e.done?i(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,s)}l((r=r.apply(e,t||[])).next())}))}function d(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}function h(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}function p(e,t){for(var n in e)"default"===n||t.hasOwnProperty(n)||(t[n]=e[n])}function f(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")}function m(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a}function g(){for(var e=[],t=0;t<arguments.length;t++)e=e.concat(m(arguments[t]));return e}function v(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}function y(e){return this instanceof y?(this.v=e,this):new y(e)}function _(e,t,n){if(!Symbol.asyncIterator)throw new TypeError("Symbol.asyncIterator is not defined.");var r,i=n.apply(e,t||[]),o=[];return r={},a("next"),a("throw"),a("return"),r[Symbol.asyncIterator]=function(){return this},r;function a(e){i[e]&&(r[e]=function(t){return new Promise((function(n,r){o.push([e,t,n,r])>1||s(e,t)}))})}function s(e,t){try{(n=i[e](t)).value instanceof y?Promise.resolve(n.value.v).then(l,c):u(o[0][2],n)}catch(e){u(o[0][3],e)}var n}function l(e){s("next",e)}function c(e){s("throw",e)}function u(e,t){e(t),o.shift(),o.length&&s(o[0][0],o[0][1])}}function b(e){var t,n;return t={},r("next"),r("throw",(function(e){throw e})),r("return"),t[Symbol.iterator]=function(){return this},t;function r(r,i){t[r]=e[r]?function(t){return(n=!n)?{value:y(e[r](t)),done:"return"===r}:i?i(t):t}:i}}function M(e){if(!Symbol.asyncIterator)throw new TypeError("Symbol.asyncIterator is not defined.");var t,n=e[Symbol.asyncIterator];return n?n.call(e):(e=f(e),t={},r("next"),r("throw"),r("return"),t[Symbol.asyncIterator]=function(){return this},t);function r(n){t[n]=e[n]&&function(t){return new Promise((function(r,i){(function(e,t,n,r){Promise.resolve(r).then((function(t){e({value:t,done:n})}),t)})(r,i,(t=e[n](t)).done,t.value)}))}}}function w(e,t){return Object.defineProperty?Object.defineProperty(e,"raw",{value:t}):e.raw=t,e}function A(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)Object.hasOwnProperty.call(e,n)&&(t[n]=e[n]);return t.default=e,t}function C(e){return e&&e.__esModule?e:{default:e}}function x(e,t){if(!t.has(e))throw new TypeError("attempted to get private field on non-instance");return t.get(e)}function E(e,t,n){if(!t.has(e))throw new TypeError("attempted to set private field on non-instance");return t.set(e,n),n}},function(e,t,n){"use strict";var r;function i(e){return"function"==typeof e.iter?e.iter():new f(e)}function o(e){return new m(e)}function a(e){return new g(e)}function s(e){return new v(e)}function l(e){return new y(e)}function c(e,t){for(var n,r=0,o=i(e);void 0!==(n=o.next());)if(!1===t(n,r++))return}function u(e,t){for(var n,r=0,o=i(e);void 0!==(n=o.next());)if(!t(n,r++))return!1;return!0}function d(e,t){for(var n,r=0,o=i(e);void 0!==(n=o.next());)if(t(n,r++))return!0;return!1}function h(e){for(var t,n=0,r=[],o=i(e);void 0!==(t=o.next());)r[n++]=t;return r}function p(e){for(var t,n=i(e),r={};void 0!==(t=n.next());)r[t[0]]=t[1];return r}n.r(t),n.d(t,"ArrayExt",(function(){return r})),n.d(t,"ArrayIterator",(function(){return f})),n.d(t,"ChainIterator",(function(){return b})),n.d(t,"EmptyIterator",(function(){return w})),n.d(t,"EnumerateIterator",(function(){return C})),n.d(t,"FilterIterator",(function(){return E})),n.d(t,"FnIterator",(function(){return y})),n.d(t,"ItemIterator",(function(){return v})),n.d(t,"KeyIterator",(function(){return m})),n.d(t,"MapIterator",(function(){return D})),n.d(t,"RangeIterator",(function(){return P})),n.d(t,"RepeatIterator",(function(){return H})),n.d(t,"RetroArrayIterator",(function(){return Y})),n.d(t,"StrideIterator",(function(){return G})),n.d(t,"StringExt",(function(){return W})),n.d(t,"TakeIterator",(function(){return K})),n.d(t,"ValueIterator",(function(){return g})),n.d(t,"ZipIterator",(function(){return J})),n.d(t,"chain",(function(){return _})),n.d(t,"each",(function(){return c})),n.d(t,"empty",(function(){return M})),n.d(t,"enumerate",(function(){return A})),n.d(t,"every",(function(){return u})),n.d(t,"filter",(function(){return x})),n.d(t,"find",(function(){return L})),n.d(t,"findIndex",(function(){return S})),n.d(t,"iter",(function(){return i})),n.d(t,"iterFn",(function(){return l})),n.d(t,"iterItems",(function(){return s})),n.d(t,"iterKeys",(function(){return o})),n.d(t,"iterValues",(function(){return a})),n.d(t,"map",(function(){return k})),n.d(t,"max",(function(){return O})),n.d(t,"min",(function(){return T})),n.d(t,"minmax",(function(){return I})),n.d(t,"once",(function(){return B})),n.d(t,"range",(function(){return N})),n.d(t,"reduce",(function(){return z})),n.d(t,"repeat",(function(){return R})),n.d(t,"retro",(function(){return F})),n.d(t,"some",(function(){return d})),n.d(t,"stride",(function(){return U})),n.d(t,"take",(function(){return q})),n.d(t,"toArray",(function(){return h})),n.d(t,"toObject",(function(){return p})),n.d(t,"topologicSort",(function(){return V})),n.d(t,"zip",(function(){return X})),function(e){function t(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i,o=e.length;if(0===o)return-1;n=n<0?Math.max(0,n+o):Math.min(n,o-1),i=(r=r<0?Math.max(0,r+o):Math.min(r,o-1))<n?r+1+(o-n):r-n+1;for(var a=0;a<i;++a){var s=(n+a)%o;if(e[s]===t)return s}return-1}function n(e,t,n,r){void 0===n&&(n=-1),void 0===r&&(r=0);var i,o=e.length;if(0===o)return-1;i=(n=n<0?Math.max(0,n+o):Math.min(n,o-1))<(r=r<0?Math.max(0,r+o):Math.min(r,o-1))?n+1+(o-r):n-r+1;for(var a=0;a<i;++a){var s=(n-a+o)%o;if(e[s]===t)return s}return-1}function r(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i,o=e.length;if(0===o)return-1;n=n<0?Math.max(0,n+o):Math.min(n,o-1),i=(r=r<0?Math.max(0,r+o):Math.min(r,o-1))<n?r+1+(o-n):r-n+1;for(var a=0;a<i;++a){var s=(n+a)%o;if(t(e[s],s))return s}return-1}function i(e,t,n,r){void 0===n&&(n=-1),void 0===r&&(r=0);var i,o=e.length;if(0===o)return-1;i=(n=n<0?Math.max(0,n+o):Math.min(n,o-1))<(r=r<0?Math.max(0,r+o):Math.min(r,o-1))?n+1+(o-r):n-r+1;for(var a=0;a<i;++a){var s=(n-a+o)%o;if(t(e[s],s))return s}return-1}function o(e,t,n){void 0===t&&(t=0),void 0===n&&(n=-1);var r=e.length;if(!(r<=1))for(t=t<0?Math.max(0,t+r):Math.min(t,r-1),n=n<0?Math.max(0,n+r):Math.min(n,r-1);t<n;){var i=e[t],o=e[n];e[t++]=o,e[n--]=i}}function a(e,t){var n=e.length;if(t<0&&(t+=n),!(t<0||t>=n)){for(var r=e[t],i=t+1;i<n;++i)e[i-1]=e[i];return e.length=n-1,r}}e.firstIndexOf=t,e.lastIndexOf=n,e.findFirstIndex=r,e.findLastIndex=i,e.findFirstValue=function(e,t,n,i){void 0===n&&(n=0),void 0===i&&(i=-1);var o=r(e,t,n,i);return-1!==o?e[o]:void 0},e.findLastValue=function(e,t,n,r){void 0===n&&(n=-1),void 0===r&&(r=0);var o=i(e,t,n,r);return-1!==o?e[o]:void 0},e.lowerBound=function(e,t,n,r,i){void 0===r&&(r=0),void 0===i&&(i=-1);var o=e.length;if(0===o)return 0;for(var a=r=r<0?Math.max(0,r+o):Math.min(r,o-1),s=(i=i<0?Math.max(0,i+o):Math.min(i,o-1))-r+1;s>0;){var l=s>>1,c=a+l;n(e[c],t)<0?(a=c+1,s-=l+1):s=l}return a},e.upperBound=function(e,t,n,r,i){void 0===r&&(r=0),void 0===i&&(i=-1);var o=e.length;if(0===o)return 0;for(var a=r=r<0?Math.max(0,r+o):Math.min(r,o-1),s=(i=i<0?Math.max(0,i+o):Math.min(i,o-1))-r+1;s>0;){var l=s>>1,c=a+l;n(e[c],t)>0?s=l:(a=c+1,s-=l+1)}return a},e.shallowEqual=function(e,t,n){if(e===t)return!0;if(e.length!==t.length)return!1;for(var r=0,i=e.length;r<i;++r)if(n?!n(e[r],t[r]):e[r]!==t[r])return!1;return!0},e.slice=function(e,t){void 0===t&&(t={});var n=t.start,r=t.stop,i=t.step;if(void 0===i&&(i=1),0===i)throw new Error("Slice `step` cannot be zero.");var o,a=e.length;void 0===n?n=i<0?a-1:0:n<0?n=Math.max(n+a,i<0?-1:0):n>=a&&(n=i<0?a-1:a),void 0===r?r=i<0?-1:a:r<0?r=Math.max(r+a,i<0?-1:0):r>=a&&(r=i<0?a-1:a),o=i<0&&r>=n||i>0&&n>=r?0:i<0?Math.floor((r-n+1)/i+1):Math.floor((r-n-1)/i+1);for(var s=[],l=0;l<o;++l)s[l]=e[n+l*i];return s},e.move=function(e,t,n){var r=e.length;if(!(r<=1)&&(t=t<0?Math.max(0,t+r):Math.min(t,r-1))!==(n=n<0?Math.max(0,n+r):Math.min(n,r-1))){for(var i=e[t],o=t<n?1:-1,a=t;a!==n;a+=o)e[a]=e[a+o];e[n]=i}},e.reverse=o,e.rotate=function(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i=e.length;if(!(i<=1||(n=n<0?Math.max(0,n+i):Math.min(n,i-1))>=(r=r<0?Math.max(0,r+i):Math.min(r,i-1)))){var a=r-n+1;if(t>0?t%=a:t<0&&(t=(t%a+a)%a),0!==t){var s=n+t;o(e,n,s-1),o(e,s,r),o(e,n,r)}}},e.fill=function(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i=e.length;if(0!==i){var o;n=n<0?Math.max(0,n+i):Math.min(n,i-1),o=(r=r<0?Math.max(0,r+i):Math.min(r,i-1))<n?r+1+(i-n):r-n+1;for(var a=0;a<o;++a)e[(n+a)%i]=t}},e.insert=function(e,t,n){var r=e.length;t=t<0?Math.max(0,t+r):Math.min(t,r);for(var i=r;i>t;--i)e[i]=e[i-1];e[t]=n},e.removeAt=a,e.removeFirstOf=function(e,n,r,i){void 0===r&&(r=0),void 0===i&&(i=-1);var o=t(e,n,r,i);return-1!==o&&a(e,o),o},e.removeLastOf=function(e,t,r,i){void 0===r&&(r=-1),void 0===i&&(i=0);var o=n(e,t,r,i);return-1!==o&&a(e,o),o},e.removeAllOf=function(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i=e.length;if(0===i)return 0;n=n<0?Math.max(0,n+i):Math.min(n,i-1),r=r<0?Math.max(0,r+i):Math.min(r,i-1);for(var o=0,a=0;a<i;++a)n<=r&&a>=n&&a<=r&&e[a]===t||r<n&&(a<=r||a>=n)&&e[a]===t?o++:o>0&&(e[a-o]=e[a]);return o>0&&(e.length=i-o),o},e.removeFirstWhere=function(e,t,n,i){var o;void 0===n&&(n=0),void 0===i&&(i=-1);var s=r(e,t,n,i);return-1!==s&&(o=a(e,s)),{index:s,value:o}},e.removeLastWhere=function(e,t,n,r){var o;void 0===n&&(n=-1),void 0===r&&(r=0);var s=i(e,t,n,r);return-1!==s&&(o=a(e,s)),{index:s,value:o}},e.removeAllWhere=function(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=-1);var i=e.length;if(0===i)return 0;n=n<0?Math.max(0,n+i):Math.min(n,i-1),r=r<0?Math.max(0,r+i):Math.min(r,i-1);for(var o=0,a=0;a<i;++a)n<=r&&a>=n&&a<=r&&t(e[a],a)||r<n&&(a<=r||a>=n)&&t(e[a],a)?o++:o>0&&(e[a-o]=e[a]);return o>0&&(e.length=i-o),o}}(r||(r={}));var f=function(){function e(e){this._index=0,this._source=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index>=this._source.length))return this._source[this._index++]},e}(),m=function(){function e(e,t){void 0===t&&(t=Object.keys(e)),this._index=0,this._source=e,this._keys=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source,this._keys);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index>=this._keys.length)){var e=this._keys[this._index++];return e in this._source?e:this.next()}},e}(),g=function(){function e(e,t){void 0===t&&(t=Object.keys(e)),this._index=0,this._source=e,this._keys=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source,this._keys);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index>=this._keys.length)){var e=this._keys[this._index++];return e in this._source?this._source[e]:this.next()}},e}(),v=function(){function e(e,t){void 0===t&&(t=Object.keys(e)),this._index=0,this._source=e,this._keys=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source,this._keys);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index>=this._keys.length)){var e=this._keys[this._index++];return e in this._source?[e,this._source[e]]:this.next()}},e}(),y=function(){function e(e){this._fn=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){throw new Error("An `FnIterator` cannot be cloned.")},e.prototype.next=function(){return this._fn.call(void 0)},e}();function _(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return new b(i(e.map(i)))}var b=function(){function e(e){this._cloned=!1,this._source=e,this._active=void 0}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source.clone());return t._active=this._active&&this._active.clone(),t._cloned=!0,this._cloned=!0,t},e.prototype.next=function(){if(void 0===this._active){var e=this._source.next();if(void 0===e)return;this._active=this._cloned?e.clone():e}var t=this._active.next();return void 0!==t?t:(this._active=void 0,this.next())},e}();function M(){return new w}var w=function(){function e(){}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e},e.prototype.next=function(){},e}();function A(e,t){return void 0===t&&(t=0),new C(i(e),t)}var C=function(){function e(e,t){this._source=e,this._index=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._source.clone(),this._index)},e.prototype.next=function(){var e=this._source.next();if(void 0!==e)return[this._index++,e]},e}();function x(e,t){return new E(i(e),t)}var E=function(){function e(e,t){this._index=0,this._source=e,this._fn=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source.clone(),this._fn);return t._index=this._index,t},e.prototype.next=function(){for(var e,t=this._fn,n=this._source;void 0!==(e=n.next());)if(t(e,this._index++))return e},e}();function L(e,t){for(var n,r=0,o=i(e);void 0!==(n=o.next());)if(t(n,r++))return n}function S(e,t){for(var n,r=0,o=i(e);void 0!==(n=o.next());)if(t(n,r++))return r-1;return-1}function T(e,t){var n=i(e),r=n.next();if(void 0!==r){for(var o=r;void 0!==(r=n.next());)t(r,o)<0&&(o=r);return o}}function O(e,t){var n=i(e),r=n.next();if(void 0!==r){for(var o=r;void 0!==(r=n.next());)t(r,o)>0&&(o=r);return o}}function I(e,t){var n=i(e),r=n.next();if(void 0!==r){for(var o=r,a=r;void 0!==(r=n.next());)t(r,o)<0?o=r:t(r,a)>0&&(a=r);return[o,a]}}function k(e,t){return new D(i(e),t)}var D=function(){function e(e,t){this._index=0,this._source=e,this._fn=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source.clone(),this._fn);return t._index=this._index,t},e.prototype.next=function(){var e=this._source.next();if(void 0!==e)return this._fn.call(void 0,e,this._index++)},e}();function N(e,t,n){return void 0===t?new P(0,e,1):new P(e,t,void 0===n?1:n)}var j,P=function(){function e(e,t,n){this._index=0,this._start=e,this._stop=t,this._step=n,this._length=j.rangeLength(e,t,n)}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._start,this._stop,this._step);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index>=this._length))return this._start+this._step*this._index++},e}();function z(e,t,n){var r=0,o=i(e),a=o.next();if(void 0===a&&void 0===n)throw new TypeError("Reduce of empty iterable with no initial value.");if(void 0===a)return n;var s,l,c=o.next();if(void 0===c&&void 0===n)return a;if(void 0===c)return t(n,a,r++);for(s=t(void 0===n?a:t(n,a,r++),c,r++);void 0!==(l=o.next());)s=t(s,l,r++);return s}function R(e,t){return new H(e,t)}function B(e){return new H(e,1)}!function(e){e.rangeLength=function(e,t,n){return 0===n?1/0:e>t&&n>0||e<t&&n<0?0:Math.ceil((t-e)/n)}}(j||(j={}));var H=function(){function e(e,t){this._value=e,this._count=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._value,this._count)},e.prototype.next=function(){if(!(this._count<=0))return this._count--,this._value},e}();function F(e){return"function"==typeof e.retro?e.retro():new Y(e)}var Y=function(){function e(e){this._source=e,this._index=e.length-1}return e.prototype.iter=function(){return this},e.prototype.clone=function(){var t=new e(this._source);return t._index=this._index,t},e.prototype.next=function(){if(!(this._index<0||this._index>=this._source.length))return this._source[this._index--]},e}();function V(e){var t=[],n=new Set,r=new Map;return c(e,(function(e){var t=e[0],n=e[1],i=r.get(n);i?i.push(t):r.set(n,[t])})),r.forEach((function(e,t){i(t)})),t;function i(e){if(!n.has(e)){n.add(e);var o=r.get(e);o&&o.forEach(i),t.push(e)}}}function U(e,t){return new G(i(e),t)}var W,G=function(){function e(e,t){this._source=e,this._step=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._source.clone(),this._step)},e.prototype.next=function(){for(var e=this._source.next(),t=this._step-1;t>0;--t)this._source.next();return e},e}();function q(e,t){return new K(i(e),t)}!function(e){function t(e,t,n){void 0===n&&(n=0);for(var r=new Array(t.length),i=0,o=n,a=t.length;i<a;++i,++o){if(-1===(o=e.indexOf(t[i],o)))return null;r[i]=o}return r}e.findIndices=t,e.matchSumOfSquares=function(e,n,r){void 0===r&&(r=0);var i=t(e,n,r);if(!i)return null;for(var o=0,a=0,s=i.length;a<s;++a){var l=i[a]-r;o+=l*l}return{score:o,indices:i}},e.matchSumOfDeltas=function(e,n,r){void 0===r&&(r=0);var i=t(e,n,r);if(!i)return null;for(var o=0,a=r-1,s=0,l=i.length;s<l;++s){var c=i[s];o+=c-a-1,a=c}return{score:o,indices:i}},e.highlight=function(e,t,n){for(var r=[],i=0,o=0,a=t.length;i<a;){for(var s=t[i],l=t[i];++i<a&&t[i]===l+1;)l++;o<s&&r.push(e.slice(o,s)),s<l+1&&r.push(n(e.slice(s,l+1))),o=l+1}return o<e.length&&r.push(e.slice(o)),r},e.cmp=function(e,t){return e<t?-1:e>t?1:0}}(W||(W={}));var K=function(){function e(e,t){this._source=e,this._count=t}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._source.clone(),this._count)},e.prototype.next=function(){if(!(this._count<=0)){var e=this._source.next();if(void 0!==e)return this._count--,e}},e}();function X(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return new J(e.map(i))}var J=function(){function e(e){this._source=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._source.map((function(e){return e.clone()})))},e.prototype.next=function(){for(var e=new Array(this._source.length),t=0,n=this._source.length;t<n;++t){var r=this._source[t].next();if(void 0===r)return;e[t]=r}return e},e}()},function(e,t,n){"use strict";n.r(t),n.d(t,"AccordionLayout",(function(){return j})),n.d(t,"AccordionPanel",(function(){return V})),n.d(t,"BoxEngine",(function(){return y})),n.d(t,"BoxLayout",(function(){return G})),n.d(t,"BoxPanel",(function(){return K})),n.d(t,"BoxSizer",(function(){return _})),n.d(t,"CommandPalette",(function(){return J})),n.d(t,"ContextMenu",(function(){return ee})),n.d(t,"DockLayout",(function(){return ie})),n.d(t,"DockPanel",(function(){return ae})),n.d(t,"FocusTracker",(function(){return ce})),n.d(t,"GridLayout",(function(){return ue})),n.d(t,"Layout",(function(){return x})),n.d(t,"LayoutItem",(function(){return L})),n.d(t,"Menu",(function(){return Z})),n.d(t,"MenuBar",(function(){return he})),n.d(t,"Panel",(function(){return z})),n.d(t,"PanelLayout",(function(){return T})),n.d(t,"ScrollBar",(function(){return fe})),n.d(t,"SingletonLayout",(function(){return ge})),n.d(t,"SplitLayout",(function(){return D})),n.d(t,"SplitPanel",(function(){return F})),n.d(t,"StackedLayout",(function(){return ve})),n.d(t,"StackedPanel",(function(){return ye})),n.d(t,"TabBar",(function(){return ne})),n.d(t,"TabPanel",(function(){return be})),n.d(t,"Title",(function(){return w})),n.d(t,"Widget",(function(){return A}));var r,i=n(2),o=n(21),a=n(8),s=n(43),l=n(4),c=n(27),u=function(){function e(e){var t=this;this._onScrollFrame=function(){if(t._scrollTarget){var e=t._scrollTarget,n=e.element,i=e.edge,o=e.distance,a=r.SCROLL_EDGE_SIZE-o,s=Math.pow(a/r.SCROLL_EDGE_SIZE,2),l=Math.max(1,Math.round(s*r.SCROLL_EDGE_SIZE));switch(i){case"top":n.scrollTop-=l;break;case"left":n.scrollLeft-=l;break;case"right":n.scrollLeft+=l;break;case"bottom":n.scrollTop+=l}requestAnimationFrame(t._onScrollFrame)}},this._disposed=!1,this._dropAction="none",this._override=null,this._currentTarget=null,this._currentElement=null,this._promise=null,this._scrollTarget=null,this._resolve=null,this.document=e.document||document,this.mimeData=e.mimeData,this.dragImage=e.dragImage||null,this.proposedAction=e.proposedAction||"copy",this.supportedActions=e.supportedActions||"all",this.source=e.source||null}return e.prototype.dispose=function(){if(!this._disposed){if(this._disposed=!0,this._currentTarget){var e=r.createMouseEvent("pointerup",-1,-1);r.dispatchDragLeave(this,this._currentTarget,null,e)}this._finalize("none")}},Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),e.prototype.start=function(e,t){var n=this;if(this._disposed)return Promise.resolve("none");if(this._promise)return this._promise;this._addListeners(),this._attachDragImage(e,t),this._promise=new Promise((function(e,t){n._resolve=e}));var i=r.createMouseEvent("pointermove",e,t);return document.dispatchEvent(i),this._promise},e.prototype.handleEvent=function(e){switch(e.type){case"mousemove":this._evtMouseMove(e);break;case"mouseup":this._evtMouseUp(e);break;case"pointermove":this._evtMouseMove(e);break;case"pointerup":this._evtMouseUp(e);break;case"keydown":this._evtKeyDown(e);break;default:e.preventDefault(),e.stopPropagation()}},e.prototype.moveDragImage=function(e,t){if(this.dragImage){var n=this.dragImage.style;n.top=t+"px",n.left=e+"px"}},e.prototype._evtMouseMove=function(e){e.preventDefault(),e.stopPropagation(),this._updateCurrentTarget(e),this._updateDragScroll(e),this.moveDragImage(e.clientX,e.clientY)},e.prototype._evtMouseUp=function(e){if(e.preventDefault(),e.stopPropagation(),0===e.button)if(this._updateCurrentTarget(e),this._currentTarget){if("none"===this._dropAction)return r.dispatchDragLeave(this,this._currentTarget,null,e),void this._finalize("none");var t=r.dispatchDrop(this,this._currentTarget,e);this._finalize(t)}else this._finalize("none")},e.prototype._evtKeyDown=function(e){e.preventDefault(),e.stopPropagation(),27===e.keyCode&&this.dispose()},e.prototype._addListeners=function(){document.addEventListener("mousedown",this,!0),document.addEventListener("mousemove",this,!0),document.addEventListener("mouseup",this,!0),document.addEventListener("mouseenter",this,!0),document.addEventListener("mouseleave",this,!0),document.addEventListener("mouseover",this,!0),document.addEventListener("mouseout",this,!0),document.addEventListener("pointerdown",this,!0),document.addEventListener("pointermove",this,!0),document.addEventListener("pointerup",this,!0),document.addEventListener("pointerenter",this,!0),document.addEventListener("pointerleave",this,!0),document.addEventListener("pointerover",this,!0),document.addEventListener("pointerout",this,!0),document.addEventListener("keydown",this,!0),document.addEventListener("keyup",this,!0),document.addEventListener("keypress",this,!0),document.addEventListener("contextmenu",this,!0)},e.prototype._removeListeners=function(){document.removeEventListener("mousedown",this,!0),document.removeEventListener("mousemove",this,!0),document.removeEventListener("mouseup",this,!0),document.removeEventListener("mouseenter",this,!0),document.removeEventListener("mouseleave",this,!0),document.removeEventListener("mouseover",this,!0),document.removeEventListener("mouseout",this,!0),document.removeEventListener("pointerdown",this,!0),document.removeEventListener("pointermove",this,!0),document.removeEventListener("pointerup",this,!0),document.removeEventListener("pointerenter",this,!0),document.removeEventListener("pointerleave",this,!0),document.removeEventListener("pointerover",this,!0),document.removeEventListener("pointerout",this,!0),document.removeEventListener("keydown",this,!0),document.removeEventListener("keyup",this,!0),document.removeEventListener("keypress",this,!0),document.removeEventListener("contextmenu",this,!0)},e.prototype._updateDragScroll=function(e){var t=r.findScrollTarget(e);(this._scrollTarget||t)&&(this._scrollTarget||setTimeout(this._onScrollFrame,500),this._scrollTarget=t)},e.prototype._updateCurrentTarget=function(e){var t=this._currentTarget,n=this._currentTarget,i=this._currentElement,o=this.document.elementFromPoint(e.clientX,e.clientY);this._currentElement=o,o!==i&&o!==n&&r.dispatchDragExit(this,n,o,e),o!==i&&o!==n&&(n=r.dispatchDragEnter(this,o,n,e)),n!==t&&(this._currentTarget=n,r.dispatchDragLeave(this,t,n,e));var a=r.dispatchDragOver(this,n,e);this._setDropAction(a)},e.prototype._attachDragImage=function(e,t){if(this.dragImage){this.dragImage.classList.add("lm-mod-drag-image"),this.dragImage.classList.add("p-mod-drag-image");var n=this.dragImage.style;n.pointerEvents="none",n.position="fixed",n.top=t+"px",n.left=e+"px",(this.document instanceof Document?this.document.body:this.document.firstElementChild).appendChild(this.dragImage)}},e.prototype._detachDragImage=function(){if(this.dragImage){var e=this.dragImage.parentNode;e&&e.removeChild(this.dragImage)}},e.prototype._setDropAction=function(t){if(t=r.validateAction(t,this.supportedActions),!this._override||this._dropAction!==t)switch(t){case"none":this._dropAction=t,this._override=e.overrideCursor("no-drop",this.document);break;case"copy":this._dropAction=t,this._override=e.overrideCursor("copy",this.document);break;case"link":this._dropAction=t,this._override=e.overrideCursor("alias",this.document);break;case"move":this._dropAction=t,this._override=e.overrideCursor("move",this.document)}},e.prototype._finalize=function(e){var t=this._resolve;this._removeListeners(),this._detachDragImage(),this._override&&(this._override.dispose(),this._override=null),this.mimeData.clear(),this._disposed=!0,this._dropAction="none",this._currentTarget=null,this._currentElement=null,this._scrollTarget=null,this._promise=null,this._resolve=null,t&&t(e)},e}();!function(e){e.overrideCursor=function(e,n){void 0===n&&(n=document);var r=++t,i=n instanceof Document?n.body:n.firstElementChild;return i.style.cursor=e,i.classList.add("lm-mod-override-cursor"),i.classList.add("p-mod-override-cursor"),new c.DisposableDelegate((function(){r===t&&(i.style.cursor="",i.classList.remove("lm-mod-override-cursor"),i.classList.remove("p-mod-override-cursor"))}))};var t=0}(u||(u={})),function(e){e.SCROLL_EDGE_SIZE=20,e.validateAction=function(e,r){return t[e]&n[r]?e:"none"},e.createMouseEvent=function(e,t,n){var r=document.createEvent("MouseEvent");return r.initMouseEvent(e,!0,!0,window,0,0,0,t,n,!1,!1,!1,!1,0,null),r},e.findScrollTarget=function(t){for(var n=t.clientX,r=t.clientY,i=document.elementFromPoint(n,r);i;i=i.parentElement){var o=i.hasAttribute("data-lm-dragscroll");if(o=o||i.hasAttribute("data-p-dragscroll")){var a=0,s=0;i===document.body&&(a=window.pageXOffset,s=window.pageYOffset);var l=i.getBoundingClientRect(),c=l.top+s,u=l.left+a,d=u+l.width,h=c+l.height;if(!(n<u||n>=d||r<c||r>=h)){var p=n-u+1,f=r-c+1,m=d-n,g=h-r,v=Math.min(p,f,m,g);if(!(v>e.SCROLL_EDGE_SIZE)){var y=void 0;switch(v){case g:y="bottom";break;case f:y="top";break;case m:y="right";break;case p:y="left";break;default:throw"unreachable"}var _=i.scrollWidth-i.clientWidth,b=i.scrollHeight-i.clientHeight,M=void 0;switch(y){case"top":M=b>0&&i.scrollTop>0;break;case"left":M=_>0&&i.scrollLeft>0;break;case"right":M=_>0&&i.scrollLeft<_;break;case"bottom":M=b>0&&i.scrollTop<b;break;default:throw"unreachable"}if(M)return{element:i,edge:y,distance:v}}}}}return null},e.dispatchDragEnter=function(e,t,n,i){if(!t)return null;var o=r("lm-dragenter",e,i,n),a=!t.dispatchEvent(o);if(a)return t;if(o=r("p-dragenter",e,i,n),a=!t.dispatchEvent(o))return t;var s=e.document instanceof Document?e.document.body:e.document.firstElementChild;return t===s?n:(o=r("lm-dragenter",e,i,n),s.dispatchEvent(o),o=r("p-dragenter",e,i,n),s.dispatchEvent(o),s)},e.dispatchDragExit=function(e,t,n,i){if(t){var o=r("lm-dragexit",e,i,n);t.dispatchEvent(o),o=r("p-dragexit",e,i,n),t.dispatchEvent(o)}},e.dispatchDragLeave=function(e,t,n,i){if(t){var o=r("lm-dragleave",e,i,n);t.dispatchEvent(o),o=r("p-dragleave",e,i,n),t.dispatchEvent(o)}},e.dispatchDragOver=function(e,t,n){if(!t)return"none";var i=r("lm-dragover",e,n,null),o=!t.dispatchEvent(i);return o?i.dropAction:(i=r("p-dragover",e,n,null),(o=!t.dispatchEvent(i))?i.dropAction:"none")},e.dispatchDrop=function(e,t,n){if(!t)return"none";var i=r("lm-drop",e,n,null),o=!t.dispatchEvent(i);return o?i.dropAction:(i=r("p-drop",e,n,null),(o=!t.dispatchEvent(i))?i.dropAction:"none")};var t={none:0,copy:1,link:2,move:4},n={none:t.none,copy:t.copy,link:t.link,move:t.move,"copy-link":t.copy|t.link,"copy-move":t.copy|t.move,"link-move":t.link|t.move,all:t.copy|t.link|t.move};function r(e,t,n,r){var i=document.createEvent("MouseEvent");return i.initMouseEvent(e,!0,!0,window,0,n.screenX,n.screenY,n.clientX,n.clientY,n.ctrlKey,n.altKey,n.shiftKey,n.metaKey,n.button,r),i.dropAction="none",i.mimeData=t.mimeData,i.proposedAction=t.proposedAction,i.supportedActions=t.supportedActions,i.source=t.source,i}}(r||(r={}));var d=n(6),h=n(65),p=n(24),f=n(100),m=function(e,t){return(m=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)};function g(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}m(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}var v=function(){return(v=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};var y,_=function(){this.sizeHint=0,this.minSize=0,this.maxSize=1/0,this.stretch=1,this.size=0,this.done=!1};!function(e){e.calc=function(e,t){var n=e.length;if(0===n)return t;for(var r=0,i=0,o=0,a=0,s=0,l=0;l<n;++l){var c=(v=e[l]).minSize,u=v.maxSize,d=v.sizeHint;v.done=!1,v.size=Math.max(c,Math.min(d,u)),o+=v.size,r+=c,i+=u,v.stretch>0&&(a+=v.stretch,s++)}if(t===o)return 0;if(t<=r){for(l=0;l<n;++l){(v=e[l]).size=v.minSize}return t-r}if(t>=i){for(l=0;l<n;++l){(v=e[l]).size=v.maxSize}return t-i}var h=n;if(t<o){for(var p=o-t;s>0&&p>.01;){var f=p,m=a;for(l=0;l<n;++l){if(!(v=e[l]).done&&0!==v.stretch){var g=v.stretch*f/m;v.size-g<=v.minSize?(p-=v.size-v.minSize,a-=v.stretch,v.size=v.minSize,v.done=!0,h--,s--):(p-=g,v.size-=g)}}}for(;h>0&&p>.01;)for(g=p/h,l=0;l<n;++l){(v=e[l]).done||(v.size-g<=v.minSize?(p-=v.size-v.minSize,v.size=v.minSize,v.done=!0,h--):(p-=g,v.size-=g))}}else{for(p=t-o;s>0&&p>.01;)for(f=p,m=a,l=0;l<n;++l){if(!(v=e[l]).done&&0!==v.stretch){g=v.stretch*f/m;v.size+g>=v.maxSize?(p-=v.maxSize-v.size,a-=v.stretch,v.size=v.maxSize,v.done=!0,h--,s--):(p-=g,v.size+=g)}}for(;h>0&&p>.01;)for(g=p/h,l=0;l<n;++l){var v;(v=e[l]).done||(v.size+g>=v.maxSize?(p-=v.maxSize-v.size,v.size=v.maxSize,v.done=!0,h--):(p-=g,v.size+=g))}}return 0},e.adjust=function(e,t,n){0!==e.length&&0!==n&&(n>0?function(e,t,n){for(var r=0,i=0;i<=t;++i){var o=e[i];r+=o.maxSize-o.size}for(var a=0,s=(i=t+1,e.length);i<s;++i){o=e[i];a+=o.size-o.minSize}var l=n=Math.min(n,r,a);for(i=t;i>=0&&l>0;--i){o=e[i];(u=o.maxSize-o.size)>=l?(o.sizeHint=o.size+l,l=0):(o.sizeHint=o.size+u,l-=u)}var c=n;for(i=t+1,s=e.length;i<s&&c>0;++i){var u;o=e[i];(u=o.size-o.minSize)>=c?(o.sizeHint=o.size-c,c=0):(o.sizeHint=o.size-u,c-=u)}}(e,t,n):function(e,t,n){for(var r=0,i=t+1,o=e.length;i<o;++i){var a=e[i];r+=a.maxSize-a.size}var s=0;for(i=0;i<=t;++i){a=e[i];s+=a.size-a.minSize}var l=n=Math.min(n,r,s);for(i=t+1,o=e.length;i<o&&l>0;++i){a=e[i];(u=a.maxSize-a.size)>=l?(a.sizeHint=a.size+l,l=0):(a.sizeHint=a.size+u,l-=u)}var c=n;for(i=t;i>=0&&c>0;--i){var u;a=e[i];(u=a.size-a.minSize)>=c?(a.sizeHint=a.size-c,c=0):(a.sizeHint=a.size-u,c-=u)}}(e,t,-n))}}(y||(y={}));var b,M,w=function(){function e(e){this._label="",this._caption="",this._mnemonic=-1,this._iconClass="",this._iconLabel="",this._className="",this._closable=!1,this._changed=new l.Signal(this),this.owner=e.owner,void 0!==e.label&&(this._label=e.label),void 0!==e.mnemonic&&(this._mnemonic=e.mnemonic),void 0!==e.icon?"string"==typeof e.icon?(this._icon=null,this._iconClass=e.icon):this._icon=e.icon:this._icon=null,void 0!==e.iconClass&&(this._iconClass=e.iconClass),void 0!==e.iconLabel&&(this._iconLabel=e.iconLabel),void 0!==e.iconRenderer&&(this._icon=e.iconRenderer),void 0!==e.caption&&(this._caption=e.caption),void 0!==e.className&&(this._className=e.className),void 0!==e.closable&&(this._closable=e.closable),this._dataset=e.dataset||{}}return Object.defineProperty(e.prototype,"changed",{get:function(){return this._changed},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"label",{get:function(){return this._label},set:function(e){this._label!==e&&(this._label=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"mnemonic",{get:function(){return this._mnemonic},set:function(e){this._mnemonic!==e&&(this._mnemonic=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"icon",{get:function(){return null===this._icon?this.iconClass:this._icon},set:function(e){if("string"==typeof e)this._icon=null,this.iconClass=e;else{if(this._icon===e)return;this._icon=e,this._changed.emit(void 0)}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconClass",{get:function(){return this._iconClass},set:function(e){this._iconClass!==e&&(this._iconClass=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconLabel",{get:function(){return this._iconLabel},set:function(e){this._iconLabel!==e&&(this._iconLabel=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconRenderer",{get:function(){return this._icon||void 0},set:function(e){this.icon=e},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"caption",{get:function(){return this._caption},set:function(e){this._caption!==e&&(this._caption=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"className",{get:function(){return this._className},set:function(e){this._className!==e&&(this._className=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"closable",{get:function(){return this._closable},set:function(e){this._closable!==e&&(this._closable=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){return this._dataset},set:function(e){this._dataset!==e&&(this._dataset=e,this._changed.emit(void 0))},enumerable:!0,configurable:!0}),e}(),A=function(){function e(t){void 0===t&&(t={}),this._flags=0,this._layout=null,this._parent=null,this._disposed=new l.Signal(this),this._hiddenMode=e.HiddenMode.Display,this.node=b.createNode(t),this.addClass("lm-Widget"),this.addClass("p-Widget")}return e.prototype.dispose=function(){this.isDisposed||(this.setFlag(e.Flag.IsDisposed),this._disposed.emit(void 0),this.parent?this.parent=null:this.isAttached&&e.detach(this),this._layout&&(this._layout.dispose(),this._layout=null),l.Signal.clearData(this),a.c.clearData(this),s.AttachedProperty.clearData(this))},Object.defineProperty(e.prototype,"disposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this.testFlag(e.Flag.IsDisposed)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isAttached",{get:function(){return this.testFlag(e.Flag.IsAttached)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isHidden",{get:function(){return this.testFlag(e.Flag.IsHidden)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isVisible",{get:function(){return this.testFlag(e.Flag.IsVisible)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"title",{get:function(){return b.titleProperty.get(this)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"id",{get:function(){return this.node.id},set:function(e){this.node.id=e},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){return this.node.dataset},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"hiddenMode",{get:function(){return this._hiddenMode},set:function(t){if(this._hiddenMode!==t){switch(this._hiddenMode=t,t){case e.HiddenMode.Display:this.node.style.willChange="auto";break;case e.HiddenMode.Scale:this.node.style.willChange="transform"}this.isHidden&&(t===e.HiddenMode.Display?(this.addClass("lm-mod-hidden"),this.addClass("p-mod-hidden"),this.node.style.transform=""):(this.node.style.transform="scale(0)",this.removeClass("lm-mod-hidden"),this.removeClass("p-mod-hidden")))}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"parent",{get:function(){return this._parent},set:function(t){if(this._parent!==t){if(t&&this.contains(t))throw new Error("Invalid parent widget.");if(this._parent&&!this._parent.isDisposed){var n=new e.ChildMessage("child-removed",this);a.c.sendMessage(this._parent,n)}if(this._parent=t,this._parent&&!this._parent.isDisposed){n=new e.ChildMessage("child-added",this);a.c.sendMessage(this._parent,n)}this.isDisposed||a.c.sendMessage(this,e.Msg.ParentChanged)}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"layout",{get:function(){return this._layout},set:function(t){if(this._layout!==t){if(this.testFlag(e.Flag.DisallowLayout))throw new Error("Cannot set widget layout.");if(this._layout)throw new Error("Cannot change widget layout.");if(t.parent)throw new Error("Cannot change layout parent.");this._layout=t,t.parent=this}},enumerable:!0,configurable:!0}),e.prototype.children=function(){return this._layout?this._layout.iter():Object(i.empty)()},e.prototype.contains=function(e){for(var t=e;t;t=t._parent)if(t===this)return!0;return!1},e.prototype.hasClass=function(e){return this.node.classList.contains(e)},e.prototype.addClass=function(e){this.node.classList.add(e)},e.prototype.removeClass=function(e){this.node.classList.remove(e)},e.prototype.toggleClass=function(e,t){return!0===t?(this.node.classList.add(e),!0):!1===t?(this.node.classList.remove(e),!1):this.node.classList.toggle(e)},e.prototype.update=function(){a.c.postMessage(this,e.Msg.UpdateRequest)},e.prototype.fit=function(){a.c.postMessage(this,e.Msg.FitRequest)},e.prototype.activate=function(){a.c.postMessage(this,e.Msg.ActivateRequest)},e.prototype.close=function(){a.c.sendMessage(this,e.Msg.CloseRequest)},e.prototype.show=function(){if(this.testFlag(e.Flag.IsHidden)&&(!this.isAttached||this.parent&&!this.parent.isVisible||a.c.sendMessage(this,e.Msg.BeforeShow),this.clearFlag(e.Flag.IsHidden),this.node.removeAttribute("aria-hidden"),this.hiddenMode===e.HiddenMode.Display?(this.removeClass("lm-mod-hidden"),this.removeClass("p-mod-hidden")):this.node.style.transform="",!this.isAttached||this.parent&&!this.parent.isVisible||a.c.sendMessage(this,e.Msg.AfterShow),this.parent)){var t=new e.ChildMessage("child-shown",this);a.c.sendMessage(this.parent,t)}},e.prototype.hide=function(){if(!this.testFlag(e.Flag.IsHidden)&&(!this.isAttached||this.parent&&!this.parent.isVisible||a.c.sendMessage(this,e.Msg.BeforeHide),this.setFlag(e.Flag.IsHidden),this.node.setAttribute("aria-hidden","true"),this.hiddenMode===e.HiddenMode.Display?(this.addClass("lm-mod-hidden"),this.addClass("p-mod-hidden")):this.node.style.transform="scale(0)",!this.isAttached||this.parent&&!this.parent.isVisible||a.c.sendMessage(this,e.Msg.AfterHide),this.parent)){var t=new e.ChildMessage("child-hidden",this);a.c.sendMessage(this.parent,t)}},e.prototype.setHidden=function(e){e?this.hide():this.show()},e.prototype.testFlag=function(e){return 0!=(this._flags&e)},e.prototype.setFlag=function(e){this._flags|=e},e.prototype.clearFlag=function(e){this._flags&=~e},e.prototype.processMessage=function(t){switch(t.type){case"resize":this.notifyLayout(t),this.onResize(t);break;case"update-request":this.notifyLayout(t),this.onUpdateRequest(t);break;case"fit-request":this.notifyLayout(t),this.onFitRequest(t);break;case"before-show":this.notifyLayout(t),this.onBeforeShow(t);break;case"after-show":this.setFlag(e.Flag.IsVisible),this.notifyLayout(t),this.onAfterShow(t);break;case"before-hide":this.notifyLayout(t),this.onBeforeHide(t);break;case"after-hide":this.clearFlag(e.Flag.IsVisible),this.notifyLayout(t),this.onAfterHide(t);break;case"before-attach":this.notifyLayout(t),this.onBeforeAttach(t);break;case"after-attach":this.isHidden||this.parent&&!this.parent.isVisible||this.setFlag(e.Flag.IsVisible),this.setFlag(e.Flag.IsAttached),this.notifyLayout(t),this.onAfterAttach(t);break;case"before-detach":this.notifyLayout(t),this.onBeforeDetach(t);break;case"after-detach":this.clearFlag(e.Flag.IsVisible),this.clearFlag(e.Flag.IsAttached),this.notifyLayout(t),this.onAfterDetach(t);break;case"activate-request":this.notifyLayout(t),this.onActivateRequest(t);break;case"close-request":this.notifyLayout(t),this.onCloseRequest(t);break;case"child-added":this.notifyLayout(t),this.onChildAdded(t);break;case"child-removed":this.notifyLayout(t),this.onChildRemoved(t);break;default:this.notifyLayout(t)}},e.prototype.notifyLayout=function(e){this._layout&&this._layout.processParentMessage(e)},e.prototype.onCloseRequest=function(t){this.parent?this.parent=null:this.isAttached&&e.detach(this)},e.prototype.onResize=function(e){},e.prototype.onUpdateRequest=function(e){},e.prototype.onFitRequest=function(e){},e.prototype.onActivateRequest=function(e){},e.prototype.onBeforeShow=function(e){},e.prototype.onAfterShow=function(e){},e.prototype.onBeforeHide=function(e){},e.prototype.onAfterHide=function(e){},e.prototype.onBeforeAttach=function(e){},e.prototype.onAfterAttach=function(e){},e.prototype.onBeforeDetach=function(e){},e.prototype.onAfterDetach=function(e){},e.prototype.onChildAdded=function(e){},e.prototype.onChildRemoved=function(e){},e}();!function(e){var t,n,r;(t=e.HiddenMode||(e.HiddenMode={}))[t.Display=0]="Display",t[t.Scale=1]="Scale",(n=e.Flag||(e.Flag={}))[n.IsDisposed=1]="IsDisposed",n[n.IsAttached=2]="IsAttached",n[n.IsHidden=4]="IsHidden",n[n.IsVisible=8]="IsVisible",n[n.DisallowLayout=16]="DisallowLayout",(r=e.Msg||(e.Msg={})).BeforeShow=new a.b("before-show"),r.AfterShow=new a.b("after-show"),r.BeforeHide=new a.b("before-hide"),r.AfterHide=new a.b("after-hide"),r.BeforeAttach=new a.b("before-attach"),r.AfterAttach=new a.b("after-attach"),r.BeforeDetach=new a.b("before-detach"),r.AfterDetach=new a.b("after-detach"),r.ParentChanged=new a.b("parent-changed"),r.UpdateRequest=new a.a("update-request"),r.FitRequest=new a.a("fit-request"),r.ActivateRequest=new a.a("activate-request"),r.CloseRequest=new a.a("close-request");var i=function(e){function t(t,n){var r=e.call(this,t)||this;return r.child=n,r}return g(t,e),t}(a.b);e.ChildMessage=i;var o=function(e){function t(t,n){var r=e.call(this,"resize")||this;return r.width=t,r.height=n,r}return g(t,e),t}(a.b);e.ResizeMessage=o,function(e){e.UnknownSize=new e(-1,-1)}(o=e.ResizeMessage||(e.ResizeMessage={})),e.attach=function(t,n,r){if(void 0===r&&(r=null),t.parent)throw new Error("Cannot attach a child widget.");if(t.isAttached||t.node.isConnected)throw new Error("Widget is already attached.");if(!n.isConnected)throw new Error("Host is not attached.");a.c.sendMessage(t,e.Msg.BeforeAttach),n.insertBefore(t.node,r),a.c.sendMessage(t,e.Msg.AfterAttach)},e.detach=function(t){if(t.parent)throw new Error("Cannot detach a child widget.");if(!t.isAttached||!t.node.isConnected)throw new Error("Widget is not attached.");a.c.sendMessage(t,e.Msg.BeforeDetach),t.node.parentNode.removeChild(t.node),a.c.sendMessage(t,e.Msg.AfterDetach)}}(A||(A={})),(M=b||(b={})).titleProperty=new s.AttachedProperty({name:"title",create:function(e){return new w({owner:e})}}),M.createNode=function(e){return e.node||document.createElement(e.tag||"div")};var C,x=function(){function e(e){void 0===e&&(e={}),this._disposed=!1,this._parent=null,this._fitPolicy=e.fitPolicy||"set-min-size"}return e.prototype.dispose=function(){this._parent=null,this._disposed=!0,l.Signal.clearData(this),s.AttachedProperty.clearData(this)},Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"parent",{get:function(){return this._parent},set:function(e){if(this._parent!==e){if(this._parent)throw new Error("Cannot change parent widget.");if(e.layout!==this)throw new Error("Invalid parent widget.");this._parent=e,this.init()}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"fitPolicy",{get:function(){return this._fitPolicy},set:function(e){if(this._fitPolicy!==e&&(this._fitPolicy=e,this._parent)){var t=this._parent.node.style;t.minWidth="",t.minHeight="",t.maxWidth="",t.maxHeight="",this._parent.fit()}},enumerable:!0,configurable:!0}),e.prototype.processParentMessage=function(e){switch(e.type){case"resize":this.onResize(e);break;case"update-request":this.onUpdateRequest(e);break;case"fit-request":this.onFitRequest(e);break;case"before-show":this.onBeforeShow(e);break;case"after-show":this.onAfterShow(e);break;case"before-hide":this.onBeforeHide(e);break;case"after-hide":this.onAfterHide(e);break;case"before-attach":this.onBeforeAttach(e);break;case"after-attach":this.onAfterAttach(e);break;case"before-detach":this.onBeforeDetach(e);break;case"after-detach":this.onAfterDetach(e);break;case"child-removed":this.onChildRemoved(e);break;case"child-shown":this.onChildShown(e);break;case"child-hidden":this.onChildHidden(e)}},e.prototype.init=function(){var e=this;Object(i.each)(this,(function(t){t.parent=e.parent}))},e.prototype.onResize=function(e){Object(i.each)(this,(function(e){a.c.sendMessage(e,A.ResizeMessage.UnknownSize)}))},e.prototype.onUpdateRequest=function(e){Object(i.each)(this,(function(e){a.c.sendMessage(e,A.ResizeMessage.UnknownSize)}))},e.prototype.onBeforeAttach=function(e){Object(i.each)(this,(function(t){a.c.sendMessage(t,e)}))},e.prototype.onAfterAttach=function(e){Object(i.each)(this,(function(t){a.c.sendMessage(t,e)}))},e.prototype.onBeforeDetach=function(e){Object(i.each)(this,(function(t){a.c.sendMessage(t,e)}))},e.prototype.onAfterDetach=function(e){Object(i.each)(this,(function(t){a.c.sendMessage(t,e)}))},e.prototype.onBeforeShow=function(e){Object(i.each)(this,(function(t){t.isHidden||a.c.sendMessage(t,e)}))},e.prototype.onAfterShow=function(e){Object(i.each)(this,(function(t){t.isHidden||a.c.sendMessage(t,e)}))},e.prototype.onBeforeHide=function(e){Object(i.each)(this,(function(t){t.isHidden||a.c.sendMessage(t,e)}))},e.prototype.onAfterHide=function(e){Object(i.each)(this,(function(t){t.isHidden||a.c.sendMessage(t,e)}))},e.prototype.onChildRemoved=function(e){this.removeWidget(e.child)},e.prototype.onFitRequest=function(e){},e.prototype.onChildShown=function(e){},e.prototype.onChildHidden=function(e){},e}();(C=x||(x={})).getHorizontalAlignment=function(e){return E.horizontalAlignmentProperty.get(e)},C.setHorizontalAlignment=function(e,t){E.horizontalAlignmentProperty.set(e,t)},C.getVerticalAlignment=function(e){return E.verticalAlignmentProperty.get(e)},C.setVerticalAlignment=function(e,t){E.verticalAlignmentProperty.set(e,t)};var E,L=function(){function e(e){this._top=NaN,this._left=NaN,this._width=NaN,this._height=NaN,this._minWidth=0,this._minHeight=0,this._maxWidth=1/0,this._maxHeight=1/0,this._disposed=!1,this.widget=e,this.widget.node.style.position="absolute"}return e.prototype.dispose=function(){if(!this._disposed){this._disposed=!0;var e=this.widget.node.style;e.position="",e.top="",e.left="",e.width="",e.height=""}},Object.defineProperty(e.prototype,"minWidth",{get:function(){return this._minWidth},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"minHeight",{get:function(){return this._minHeight},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"maxWidth",{get:function(){return this._maxWidth},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"maxHeight",{get:function(){return this._maxHeight},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isHidden",{get:function(){return this.widget.isHidden},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isVisible",{get:function(){return this.widget.isVisible},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isAttached",{get:function(){return this.widget.isAttached},enumerable:!0,configurable:!0}),e.prototype.fit=function(){var e=o.ElementExt.sizeLimits(this.widget.node);this._minWidth=e.minWidth,this._minHeight=e.minHeight,this._maxWidth=e.maxWidth,this._maxHeight=e.maxHeight},e.prototype.update=function(e,t,n,r){var i=Math.max(this._minWidth,Math.min(n,this._maxWidth)),o=Math.max(this._minHeight,Math.min(r,this._maxHeight));if(i<n)switch(x.getHorizontalAlignment(this.widget)){case"left":break;case"center":e+=(n-i)/2;break;case"right":e+=n-i;break;default:throw"unreachable"}if(o<r)switch(x.getVerticalAlignment(this.widget)){case"top":break;case"center":t+=(r-o)/2;break;case"bottom":t+=r-o;break;default:throw"unreachable"}var s=!1,l=this.widget.node.style;if(this._top!==t&&(this._top=t,l.top=t+"px"),this._left!==e&&(this._left=e,l.left=e+"px"),this._width!==i&&(s=!0,this._width=i,l.width=i+"px"),this._height!==o&&(s=!0,this._height=o,l.height=o+"px"),s){var c=new A.ResizeMessage(i,o);a.c.sendMessage(this.widget,c)}},e}();!function(e){function t(e){e.parent&&e.parent.layout&&e.parent.update()}e.horizontalAlignmentProperty=new s.AttachedProperty({name:"horizontalAlignment",create:function(){return"center"},changed:t}),e.verticalAlignmentProperty=new s.AttachedProperty({name:"verticalAlignment",create:function(){return"top"},changed:t})}(E||(E={}));var S,T=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._widgets=[],t}return g(t,e),t.prototype.dispose=function(){for(;this._widgets.length>0;)this._widgets.pop().dispose();e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"widgets",{get:function(){return this._widgets},enumerable:!0,configurable:!0}),t.prototype.iter=function(){return Object(i.iter)(this._widgets)},t.prototype.addWidget=function(e){this.insertWidget(this._widgets.length,e)},t.prototype.insertWidget=function(e,t){t.parent=this.parent;var n=this._widgets.indexOf(t),r=Math.max(0,Math.min(e,this._widgets.length));if(-1===n)return i.ArrayExt.insert(this._widgets,r,t),void(this.parent&&this.attachWidget(r,t));r===this._widgets.length&&r--,n!==r&&(i.ArrayExt.move(this._widgets,n,r),this.parent&&this.moveWidget(n,r,t))},t.prototype.removeWidget=function(e){this.removeWidgetAt(this._widgets.indexOf(e))},t.prototype.removeWidgetAt=function(e){var t=i.ArrayExt.removeAt(this._widgets,e);t&&this.parent&&this.detachWidget(e,t)},t.prototype.init=function(){var t=this;e.prototype.init.call(this),Object(i.each)(this,(function(e,n){t.attachWidget(n,e)}))},t.prototype.attachWidget=function(e,t){var n=this.parent.node.children[e];this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeAttach),this.parent.node.insertBefore(t.node,n),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterAttach)},t.prototype.moveWidget=function(e,t,n){this.parent.isAttached&&a.c.sendMessage(n,A.Msg.BeforeDetach),this.parent.node.removeChild(n.node),this.parent.isAttached&&a.c.sendMessage(n,A.Msg.AfterDetach);var r=this.parent.node.children[t];this.parent.isAttached&&a.c.sendMessage(n,A.Msg.BeforeAttach),this.parent.node.insertBefore(n.node,r),this.parent.isAttached&&a.c.sendMessage(n,A.Msg.AfterAttach)},t.prototype.detachWidget=function(e,t){this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeDetach),this.parent.node.removeChild(t.node),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterDetach)},t}(x);!function(e){e.clampDimension=function(e){return Math.max(0,Math.floor(e))}}(S||(S={}));var O,I,k=S,D=function(e){function t(t){var n=e.call(this)||this;return n.widgetOffset=0,n._fixed=0,n._spacing=4,n._dirty=!1,n._hasNormedSizes=!1,n._sizers=[],n._items=[],n._handles=[],n._box=null,n._alignment="start",n._orientation="horizontal",n.renderer=t.renderer,void 0!==t.orientation&&(n._orientation=t.orientation),void 0!==t.alignment&&(n._alignment=t.alignment),void 0!==t.spacing&&(n._spacing=S.clampDimension(t.spacing)),n}return g(t,e),t.prototype.dispose=function(){Object(i.each)(this._items,(function(e){e.dispose()})),this._box=null,this._items.length=0,this._sizers.length=0,this._handles.length=0,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"orientation",{get:function(){return this._orientation},set:function(e){this._orientation!==e&&(this._orientation=e,this.parent&&(this.parent.dataset.orientation=e,this.parent.fit()))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"alignment",{get:function(){return this._alignment},set:function(e){this._alignment!==e&&(this._alignment=e,this.parent&&(this.parent.dataset.alignment=e,this.parent.update()))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this._spacing},set:function(e){e=S.clampDimension(e),this._spacing!==e&&(this._spacing=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"handles",{get:function(){return this._handles},enumerable:!0,configurable:!0}),t.prototype.relativeSizes=function(){return I.normalize(this._sizers.map((function(e){return e.size})))},t.prototype.setRelativeSizes=function(e){for(var t=this._sizers.length,n=e.slice(0,t);n.length<t;)n.push(0);for(var r=I.normalize(n),i=0;i<t;++i){var o=this._sizers[i];o.sizeHint=r[i],o.size=r[i]}this._hasNormedSizes=!0,this.parent&&this.parent.update()},t.prototype.moveHandle=function(e,t){var n,r=this._handles[e];if(r&&!r.classList.contains("lm-mod-hidden")&&0!==(n="horizontal"===this._orientation?t-r.offsetLeft:t-r.offsetTop)){for(var i=0,o=this._sizers;i<o.length;i++){var a=o[i];a.size>0&&(a.sizeHint=a.size)}y.adjust(this._sizers,e,n),this.parent&&this.parent.update()}},t.prototype.init=function(){this.parent.dataset.orientation=this.orientation,this.parent.dataset.alignment=this.alignment,e.prototype.init.call(this)},t.prototype.attachWidget=function(e,t){var n=new L(t),r=I.createHandle(this.renderer),o=I.averageSize(this._sizers),s=I.createSizer(o);i.ArrayExt.insert(this._items,e,n),i.ArrayExt.insert(this._sizers,e,s),i.ArrayExt.insert(this._handles,e,r),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeAttach),this.parent.node.appendChild(t.node),this.parent.node.appendChild(r),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterAttach),this.parent.fit()},t.prototype.moveWidget=function(e,t,n){i.ArrayExt.move(this._items,e,t),i.ArrayExt.move(this._sizers,e,t),i.ArrayExt.move(this._handles,e,t),this.parent.fit()},t.prototype.detachWidget=function(e,t){var n=i.ArrayExt.removeAt(this._items,e),r=i.ArrayExt.removeAt(this._handles,e);i.ArrayExt.removeAt(this._sizers,e),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeDetach),this.parent.node.removeChild(t.node),this.parent.node.removeChild(r),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterDetach),n.dispose(),this.parent.fit()},t.prototype.onBeforeShow=function(t){e.prototype.onBeforeShow.call(this,t),this.parent.update()},t.prototype.onBeforeAttach=function(t){e.prototype.onBeforeAttach.call(this,t),this.parent.fit()},t.prototype.onChildShown=function(e){this.parent.fit()},t.prototype.onChildHidden=function(e){this.parent.fit()},t.prototype.onResize=function(e){this.parent.isVisible&&this._update(e.width,e.height)},t.prototype.onUpdateRequest=function(e){this.parent.isVisible&&this._update(-1,-1)},t.prototype.onFitRequest=function(e){this.parent.isAttached&&this._fit()},t.prototype.updateItemPosition=function(e,t,n,r,i,o,a){var s=this._items[e];if(!s.isHidden){var l=this._handles[e].style;t?(n+=this.widgetOffset,s.update(n,r,a,i),n+=a,l.top=r+"px",l.left=n+"px",l.width=this._spacing+"px",l.height=i+"px"):(r+=this.widgetOffset,s.update(n,r,o,a),r+=a,l.top=r+"px",l.left=n+"px",l.width=o+"px",l.height=this._spacing+"px")}},t.prototype._fit=function(){for(var e=0,n=-1,r=0,i=this._items.length;r<i;++r)this._items[r].isHidden?(this._handles[r].classList.add("lm-mod-hidden"),this._handles[r].classList.add("p-mod-hidden")):(this._handles[r].classList.remove("lm-mod-hidden"),this._handles[r].classList.remove("p-mod-hidden"),n=r,e++);-1!==n&&(this._handles[n].classList.add("lm-mod-hidden"),this._handles[n].classList.add("p-mod-hidden")),this._fixed=this._spacing*Math.max(0,e-1)+this.widgetOffset*this._items.length;var s="horizontal"===this._orientation,l=s?this._fixed:0,c=s?0:this._fixed;for(r=0,i=this._items.length;r<i;++r){var u=this._items[r],d=this._sizers[r];d.size>0&&(d.sizeHint=d.size),u.isHidden?(d.minSize=0,d.maxSize=0):(u.fit(),d.stretch=t.getStretch(u.widget),s?(d.minSize=u.minWidth,d.maxSize=u.maxWidth,l+=u.minWidth,c=Math.max(c,u.minHeight)):(d.minSize=u.minHeight,d.maxSize=u.maxHeight,c+=u.minHeight,l=Math.max(l,u.minWidth)))}var h=this._box=o.ElementExt.boxSizing(this.parent.node);l+=h.horizontalSum,c+=h.verticalSum;var p=this.parent.node.style;p.minWidth=l+"px",p.minHeight=c+"px",this._dirty=!0,this.parent.parent&&a.c.sendMessage(this.parent.parent,A.Msg.FitRequest),this._dirty&&a.c.sendMessage(this.parent,A.Msg.UpdateRequest)},t.prototype._update=function(e,t){this._dirty=!1;for(var n=0,r=0,i=this._items.length;r<i;++r)n+=+!this._items[r].isHidden;if(0!==n||0!==this.widgetOffset){e<0&&(e=this.parent.node.offsetWidth),t<0&&(t=this.parent.node.offsetHeight),this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var a=this._box.paddingTop,s=this._box.paddingLeft,l=e-this._box.horizontalSum,c=t-this._box.verticalSum,u=0,d=0,h="horizontal"===this._orientation;if(n>0){var p=void 0;if(p=h?Math.max(0,l-this._fixed):Math.max(0,c-this._fixed),this._hasNormedSizes){for(var f=0,m=this._sizers;f<m.length;f++){m[f].sizeHint*=p}this._hasNormedSizes=!1}var g=y.calc(this._sizers,p);if(g>0)switch(this._alignment){case"start":break;case"center":u=0,d=g/2;break;case"end":u=0,d=g;break;case"justify":u=g/n,d=0;break;default:throw"unreachable"}}for(r=0,i=this._items.length;r<i;++r){var v=this._items[r].isHidden?0:this._sizers[r].size+u;this.updateItemPosition(r,h,h?s+d:s,h?a:a+d,c,l,v);var _=this.widgetOffset+(this._handles[r].classList.contains("lm-mod-hidden")?0:this._spacing);h?s+=v+_:a+=v+_}}},t}(T);(O=D||(D={})).getStretch=function(e){return I.stretchProperty.get(e)},O.setStretch=function(e,t){I.stretchProperty.set(e,t)},function(e){e.stretchProperty=new s.AttachedProperty({name:"stretch",create:function(){return 0},coerce:function(e,t){return Math.max(0,Math.floor(t))},changed:function(e){e.parent&&e.parent.layout instanceof D&&e.parent.fit()}}),e.createSizer=function(e){var t=new _;return t.sizeHint=Math.floor(e),t},e.createHandle=function(e){var t=e.createHandle();return t.style.position="absolute",t},e.averageSize=function(e){return e.reduce((function(e,t){return e+t.size}),0)/e.length||0},e.normalize=function(e){var t=e.length;if(0===t)return[];var n=e.reduce((function(e,t){return e+Math.abs(t)}),0);return 0===n?e.map((function(e){return 1/t})):e.map((function(e){return e/n}))}}(I||(I={}));var N,j=function(e){function t(t){var n=e.call(this,v(v({},t),{orientation:t.orientation||"vertical"}))||this;return n._titles=[],n.titleSpace=t.titleSpace||22,n}return g(t,e),Object.defineProperty(t.prototype,"titleSpace",{get:function(){return this.widgetOffset},set:function(e){e=k.clampDimension(e),this.widgetOffset!==e&&(this.widgetOffset=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"titles",{get:function(){return this._titles},enumerable:!0,configurable:!0}),t.prototype.dispose=function(){this.isDisposed||(this._titles.length=0,e.prototype.dispose.call(this))},t.prototype.updateTitle=function(e,t){var n=this._titles[e],r=n.classList.contains("lm-mod-expanded"),i=N.createTitle(this.renderer,t.title,r);this._titles[e]=i,this.parent.node.replaceChild(i,n)},t.prototype.attachWidget=function(t,n){var r=N.createTitle(this.renderer,n.title);i.ArrayExt.insert(this._titles,t,r),this.parent.node.appendChild(r),n.node.setAttribute("role","region"),n.node.setAttribute("aria-labelledby",r.id),e.prototype.attachWidget.call(this,t,n)},t.prototype.moveWidget=function(t,n,r){i.ArrayExt.move(this._titles,t,n),e.prototype.moveWidget.call(this,t,n,r)},t.prototype.detachWidget=function(t,n){var r=i.ArrayExt.removeAt(this._titles,t);this.parent.node.removeChild(r),e.prototype.detachWidget.call(this,t,n)},t.prototype.updateItemPosition=function(t,n,r,i,o,a,s){var l=this._titles[t].style;l.top=i+"px",l.left=r+"px",l.height=this.widgetOffset+"px",l.width=n?o+"px":a+"px",e.prototype.updateItemPosition.call(this,t,n,r,i,o,a,s)},t}(D);!function(e){e.createTitle=function(e,t,n){void 0===n&&(n=!0);var r=e.createSectionTitle(t);return r.style.position="absolute",r.setAttribute("aria-label",t.label+" Section"),r.setAttribute("aria-expanded",n?"true":"false"),r.setAttribute("aria-controls",t.owner.id),n&&r.classList.add("lm-mod-expanded"),r}}(N||(N={}));var P,z=function(e){function t(t){void 0===t&&(t={});var n=e.call(this)||this;return n.addClass("lm-Panel"),n.addClass("p-Panel"),n.layout=P.createLayout(t),n}return g(t,e),Object.defineProperty(t.prototype,"widgets",{get:function(){return this.layout.widgets},enumerable:!0,configurable:!0}),t.prototype.addWidget=function(e){this.layout.addWidget(e)},t.prototype.insertWidget=function(e,t){this.layout.insertWidget(e,t)},t}(A);!function(e){e.createLayout=function(e){return e.layout||new T}}(P||(P={}));var R,B,H,F=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,{layout:H.createLayout(t)})||this;return n._pressData=null,n.addClass("lm-SplitPanel"),n.addClass("p-SplitPanel"),n}return g(t,e),t.prototype.dispose=function(){this._releaseMouse(),e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"orientation",{get:function(){return this.layout.orientation},set:function(e){this.layout.orientation=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"alignment",{get:function(){return this.layout.alignment},set:function(e){this.layout.alignment=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this.layout.spacing},set:function(e){this.layout.spacing=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"renderer",{get:function(){return this.layout.renderer},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"handles",{get:function(){return this.layout.handles},enumerable:!0,configurable:!0}),t.prototype.relativeSizes=function(){return this.layout.relativeSizes()},t.prototype.setRelativeSizes=function(e){this.layout.setRelativeSizes(e)},t.prototype.handleEvent=function(e){switch(e.type){case"mousedown":this._evtMouseDown(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseup":this._evtMouseUp(e);break;case"pointerdown":this._evtMouseDown(e);break;case"pointermove":this._evtMouseMove(e);break;case"pointerup":this._evtMouseUp(e);break;case"keydown":this._evtKeyDown(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("mousedown",this),this.node.addEventListener("pointerdown",this)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("mousedown",this),this.node.removeEventListener("pointerdown",this),this._releaseMouse()},t.prototype.onChildAdded=function(e){e.child.addClass("lm-SplitPanel-child"),e.child.addClass("p-SplitPanel-child"),this._releaseMouse()},t.prototype.onChildRemoved=function(e){e.child.removeClass("lm-SplitPanel-child"),e.child.removeClass("p-SplitPanel-child"),this._releaseMouse()},t.prototype._evtKeyDown=function(e){this._pressData&&(e.preventDefault(),e.stopPropagation()),27===e.keyCode&&this._releaseMouse()},t.prototype._evtMouseDown=function(e){if(0===e.button){var t=this.layout,n=i.ArrayExt.findFirstIndex(t.handles,(function(t){return t.contains(e.target)}));if(-1!==n){var r;e.preventDefault(),e.stopPropagation(),document.addEventListener("mouseup",this,!0),document.addEventListener("mousemove",this,!0),document.addEventListener("pointerup",this,!0),document.addEventListener("pointermove",this,!0),document.addEventListener("keydown",this,!0),document.addEventListener("contextmenu",this,!0);var o=t.handles[n],a=o.getBoundingClientRect();r="horizontal"===t.orientation?e.clientX-a.left:e.clientY-a.top;var s=window.getComputedStyle(o),l=u.overrideCursor(s.cursor);this._pressData={index:n,delta:r,override:l}}}},t.prototype._evtMouseMove=function(e){var t;e.preventDefault(),e.stopPropagation();var n=this.layout,r=this.node.getBoundingClientRect();t="horizontal"===n.orientation?e.clientX-r.left-this._pressData.delta:e.clientY-r.top-this._pressData.delta,n.moveHandle(this._pressData.index,t)},t.prototype._evtMouseUp=function(e){0===e.button&&(e.preventDefault(),e.stopPropagation(),this._releaseMouse())},t.prototype._releaseMouse=function(){this._pressData&&(this._pressData.override.dispose(),this._pressData=null,document.removeEventListener("mouseup",this,!0),document.removeEventListener("mousemove",this,!0),document.removeEventListener("keydown",this,!0),document.removeEventListener("pointerup",this,!0),document.removeEventListener("pointermove",this,!0),document.removeEventListener("contextmenu",this,!0))},t}(z);R=F||(F={}),B=function(){function e(){}return e.prototype.createHandle=function(){var e=document.createElement("div");return e.className="lm-SplitPanel-handle",e.classList.add("p-SplitPanel-handle"),e},e}(),R.Renderer=B,R.defaultRenderer=new B,R.getStretch=function(e){return D.getStretch(e)},R.setStretch=function(e,t){D.setStretch(e,t)},function(e){e.createLayout=function(e){return e.layout||new D({renderer:e.renderer||F.defaultRenderer,orientation:e.orientation,alignment:e.alignment,spacing:e.spacing})}}(H||(H={}));var Y,V=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,v(v({},t),{layout:Y.createLayout(t)}))||this;return n.addClass("lm-AccordionPanel"),n}return g(t,e),Object.defineProperty(t.prototype,"renderer",{get:function(){return this.layout.renderer},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"titleSpace",{get:function(){return this.layout.titleSpace},set:function(e){this.layout.titleSpace=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"titles",{get:function(){return this.layout.titles},enumerable:!0,configurable:!0}),t.prototype.addWidget=function(t){e.prototype.addWidget.call(this,t),t.title.changed.connect(this._onTitleChanged,this)},t.prototype.insertWidget=function(t,n){e.prototype.insertWidget.call(this,t,n),n.title.changed.connect(this._onTitleChanged,this)},t.prototype.handleEvent=function(t){switch(e.prototype.handleEvent.call(this,t),t.type){case"click":this._evtClick(t);break;case"keydown":this._eventKeyDown(t)}},t.prototype.onBeforeAttach=function(t){this.node.addEventListener("click",this),this.node.addEventListener("keydown",this),e.prototype.onBeforeAttach.call(this,t)},t.prototype.onAfterDetach=function(t){e.prototype.onAfterDetach.call(this,t),this.node.removeEventListener("click",this),this.node.removeEventListener("keydown",this)},t.prototype._onTitleChanged=function(e){var t=i.ArrayExt.findFirstIndex(this.widgets,(function(t){return t.contains(e.owner)}));t>=0&&(this.layout.updateTitle(t,e.owner),this.update())},t.prototype._evtClick=function(e){var t=e.target;if(t){var n=i.ArrayExt.findFirstIndex(this.titles,(function(e){return e.contains(t)}));if(n>=0){e.preventDefault(),e.stopPropagation();var r=this.titles[n],o=this.layout.widgets[n];o.isHidden?(r.classList.add("lm-mod-expanded"),r.setAttribute("aria-expanded","true"),o.show()):(r.classList.remove("lm-mod-expanded"),r.setAttribute("aria-expanded","false"),o.hide())}}},t.prototype._eventKeyDown=function(e){if(!e.defaultPrevented){var t=e.target,n=!1;if(t){var r=i.ArrayExt.findFirstIndex(this.titles,(function(e){return e.contains(t)}));if(r>=0){var o=e.keyCode.toString();if(e.key.match(/Space|Enter/)||o.match(/13|32/))t.click(),n=!0;else if("horizontal"===this.orientation?e.key.match(/ArrowLeft|ArrowRight/)||o.match(/37|39/):e.key.match(/ArrowUp|ArrowDown/)||o.match(/38|40/)){var a=e.key.match(/ArrowLeft|ArrowUp/)||o.match(/37|38/)?-1:1,s=this.titles.length,l=(r+s+a)%s;this.titles[l].focus(),n=!0}else"End"===e.key||"35"===o?(this.titles[this.titles.length-1].focus(),n=!0):"Home"!==e.key&&"36"!==o||(this.titles[0].focus(),n=!0)}n&&e.preventDefault()}}},t}(F);!function(e){var t=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.titleClassName="lm-AccordionPanel-title",t._titleID=0,t._titleKeys=new WeakMap,t}return g(t,e),t.prototype.createCollapseIcon=function(e){return document.createElement("span")},t.prototype.createSectionTitle=function(e){var t=document.createElement("h3");for(var n in t.setAttribute("role","button"),t.setAttribute("tabindex","0"),t.id=this.createTitleKey(e),t.className=this.titleClassName,t.title=e.caption,e.dataset)t.dataset[n]=e.dataset[n];t.appendChild(this.createCollapseIcon(e)).className="lm-AccordionPanel-titleCollapser";var r=t.appendChild(document.createElement("span"));return r.className="lm-AccordionPanel-titleLabel",r.textContent=e.label,t},t.prototype.createTitleKey=function(e){var t=this._titleKeys.get(e);return void 0===t&&(t="title-key-"+this._titleID++,this._titleKeys.set(e,t)),t},t}(F.Renderer);e.Renderer=t,e.defaultRenderer=new t}(V||(V={})),function(e){e.createLayout=function(e){return e.layout||new j({renderer:e.renderer||V.defaultRenderer,orientation:e.orientation,alignment:e.alignment,spacing:e.spacing,titleSpace:e.titleSpace})}}(Y||(Y={}));var U,W,G=function(e){function t(t){void 0===t&&(t={});var n=e.call(this)||this;return n._fixed=0,n._spacing=4,n._dirty=!1,n._sizers=[],n._items=[],n._box=null,n._alignment="start",n._direction="top-to-bottom",void 0!==t.direction&&(n._direction=t.direction),void 0!==t.alignment&&(n._alignment=t.alignment),void 0!==t.spacing&&(n._spacing=k.clampDimension(t.spacing)),n}return g(t,e),t.prototype.dispose=function(){Object(i.each)(this._items,(function(e){e.dispose()})),this._box=null,this._items.length=0,this._sizers.length=0,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"direction",{get:function(){return this._direction},set:function(e){this._direction!==e&&(this._direction=e,this.parent&&(this.parent.dataset.direction=e,this.parent.fit()))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"alignment",{get:function(){return this._alignment},set:function(e){this._alignment!==e&&(this._alignment=e,this.parent&&(this.parent.dataset.alignment=e,this.parent.update()))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this._spacing},set:function(e){e=k.clampDimension(e),this._spacing!==e&&(this._spacing=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),t.prototype.init=function(){this.parent.dataset.direction=this.direction,this.parent.dataset.alignment=this.alignment,e.prototype.init.call(this)},t.prototype.attachWidget=function(e,t){i.ArrayExt.insert(this._items,e,new L(t)),i.ArrayExt.insert(this._sizers,e,new _),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeAttach),this.parent.node.appendChild(t.node),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterAttach),this.parent.fit()},t.prototype.moveWidget=function(e,t,n){i.ArrayExt.move(this._items,e,t),i.ArrayExt.move(this._sizers,e,t),this.parent.update()},t.prototype.detachWidget=function(e,t){var n=i.ArrayExt.removeAt(this._items,e);i.ArrayExt.removeAt(this._sizers,e),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeDetach),this.parent.node.removeChild(t.node),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterDetach),n.dispose(),this.parent.fit()},t.prototype.onBeforeShow=function(t){e.prototype.onBeforeShow.call(this,t),this.parent.update()},t.prototype.onBeforeAttach=function(t){e.prototype.onBeforeAttach.call(this,t),this.parent.fit()},t.prototype.onChildShown=function(e){this.parent.fit()},t.prototype.onChildHidden=function(e){this.parent.fit()},t.prototype.onResize=function(e){this.parent.isVisible&&this._update(e.width,e.height)},t.prototype.onUpdateRequest=function(e){this.parent.isVisible&&this._update(-1,-1)},t.prototype.onFitRequest=function(e){this.parent.isAttached&&this._fit()},t.prototype._fit=function(){for(var e=0,n=0,r=this._items.length;n<r;++n)e+=+!this._items[n].isHidden;this._fixed=this._spacing*Math.max(0,e-1);var i=W.isHorizontal(this._direction),s=i?this._fixed:0,l=i?0:this._fixed;for(n=0,r=this._items.length;n<r;++n){var c=this._items[n],u=this._sizers[n];c.isHidden?(u.minSize=0,u.maxSize=0):(c.fit(),u.sizeHint=t.getSizeBasis(c.widget),u.stretch=t.getStretch(c.widget),i?(u.minSize=c.minWidth,u.maxSize=c.maxWidth,s+=c.minWidth,l=Math.max(l,c.minHeight)):(u.minSize=c.minHeight,u.maxSize=c.maxHeight,l+=c.minHeight,s=Math.max(s,c.minWidth)))}var d=this._box=o.ElementExt.boxSizing(this.parent.node);s+=d.horizontalSum,l+=d.verticalSum;var h=this.parent.node.style;h.minWidth=s+"px",h.minHeight=l+"px",this._dirty=!0,this.parent.parent&&a.c.sendMessage(this.parent.parent,A.Msg.FitRequest),this._dirty&&a.c.sendMessage(this.parent,A.Msg.UpdateRequest)},t.prototype._update=function(e,t){this._dirty=!1;for(var n=0,r=0,i=this._items.length;r<i;++r)n+=+!this._items[r].isHidden;if(0!==n){e<0&&(e=this.parent.node.offsetWidth),t<0&&(t=this.parent.node.offsetHeight),this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var a,s=this._box.paddingTop,l=this._box.paddingLeft,c=e-this._box.horizontalSum,u=t-this._box.verticalSum;switch(this._direction){case"left-to-right":a=y.calc(this._sizers,Math.max(0,c-this._fixed));break;case"top-to-bottom":a=y.calc(this._sizers,Math.max(0,u-this._fixed));break;case"right-to-left":a=y.calc(this._sizers,Math.max(0,c-this._fixed)),l+=c;break;case"bottom-to-top":a=y.calc(this._sizers,Math.max(0,u-this._fixed)),s+=u;break;default:throw"unreachable"}var d=0,h=0;if(a>0)switch(this._alignment){case"start":break;case"center":d=0,h=a/2;break;case"end":d=0,h=a;break;case"justify":d=a/n,h=0;break;default:throw"unreachable"}for(r=0,i=this._items.length;r<i;++r){var p=this._items[r];if(!p.isHidden){var f=this._sizers[r].size;switch(this._direction){case"left-to-right":p.update(l+h,s,f+d,u),l+=f+d+this._spacing;break;case"top-to-bottom":p.update(l,s+h,c,f+d),s+=f+d+this._spacing;break;case"right-to-left":p.update(l-h-f-d,s,f+d,u),l-=f+d+this._spacing;break;case"bottom-to-top":p.update(l,s-h-f-d,c,f+d),s-=f+d+this._spacing;break;default:throw"unreachable"}}}}},t}(T);(U=G||(G={})).getStretch=function(e){return W.stretchProperty.get(e)},U.setStretch=function(e,t){W.stretchProperty.set(e,t)},U.getSizeBasis=function(e){return W.sizeBasisProperty.get(e)},U.setSizeBasis=function(e,t){W.sizeBasisProperty.set(e,t)},function(e){function t(e){e.parent&&e.parent.layout instanceof G&&e.parent.fit()}e.stretchProperty=new s.AttachedProperty({name:"stretch",create:function(){return 0},coerce:function(e,t){return Math.max(0,Math.floor(t))},changed:t}),e.sizeBasisProperty=new s.AttachedProperty({name:"sizeBasis",create:function(){return 0},coerce:function(e,t){return Math.max(0,Math.floor(t))},changed:t}),e.isHorizontal=function(e){return"left-to-right"===e||"right-to-left"===e},e.clampSpacing=function(e){return Math.max(0,Math.floor(e))}}(W||(W={}));var q,K=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,{layout:q.createLayout(t)})||this;return n.addClass("lm-BoxPanel"),n.addClass("p-BoxPanel"),n}return g(t,e),Object.defineProperty(t.prototype,"direction",{get:function(){return this.layout.direction},set:function(e){this.layout.direction=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"alignment",{get:function(){return this.layout.alignment},set:function(e){this.layout.alignment=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this.layout.spacing},set:function(e){this.layout.spacing=e},enumerable:!0,configurable:!0}),t.prototype.onChildAdded=function(e){e.child.addClass("lm-BoxPanel-child"),e.child.addClass("p-BoxPanel-child")},t.prototype.onChildRemoved=function(e){e.child.removeClass("lm-BoxPanel-child"),e.child.removeClass("p-BoxPanel-child")},t}(z);!function(e){e.getStretch=function(e){return G.getStretch(e)},e.setStretch=function(e,t){G.setStretch(e,t)},e.getSizeBasis=function(e){return G.getSizeBasis(e)},e.setSizeBasis=function(e,t){G.setSizeBasis(e,t)}}(K||(K={})),function(e){e.createLayout=function(e){return e.layout||new G(e)}}(q||(q={}));var X,J=function(e){function t(n){var r=e.call(this,{node:X.createNode()})||this;return r._activeIndex=-1,r._items=[],r._results=null,r.addClass("lm-CommandPalette"),r.addClass("p-CommandPalette"),r.setFlag(A.Flag.DisallowLayout),r.commands=n.commands,r.renderer=n.renderer||t.defaultRenderer,r.commands.commandChanged.connect(r._onGenericChange,r),r.commands.keyBindingChanged.connect(r._onGenericChange,r),r}return g(t,e),t.prototype.dispose=function(){this._items.length=0,this._results=null,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"searchNode",{get:function(){return this.node.getElementsByClassName("lm-CommandPalette-search")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"inputNode",{get:function(){return this.node.getElementsByClassName("lm-CommandPalette-input")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"contentNode",{get:function(){return this.node.getElementsByClassName("lm-CommandPalette-content")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"items",{get:function(){return this._items},enumerable:!0,configurable:!0}),t.prototype.addItem=function(e){var t=X.createItem(this.commands,e);return this._items.push(t),this.refresh(),t},t.prototype.addItems=function(e){var t=this,n=e.map((function(e){return X.createItem(t.commands,e)}));return n.forEach((function(e){return t._items.push(e)})),this.refresh(),n},t.prototype.removeItem=function(e){this.removeItemAt(this._items.indexOf(e))},t.prototype.removeItemAt=function(e){i.ArrayExt.removeAt(this._items,e)&&this.refresh()},t.prototype.clearItems=function(){0!==this._items.length&&(this._items.length=0,this.refresh())},t.prototype.refresh=function(){(this._results=null,""!==this.inputNode.value)?this.node.getElementsByClassName("lm-close-icon")[0].style.display="inherit":this.node.getElementsByClassName("lm-close-icon")[0].style.display="none";this.update()},t.prototype.handleEvent=function(e){switch(e.type){case"click":this._evtClick(e);break;case"keydown":this._evtKeyDown(e);break;case"input":this.refresh();break;case"focus":case"blur":this._toggleFocused()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("click",this),this.node.addEventListener("keydown",this),this.node.addEventListener("input",this),this.node.addEventListener("focus",this,!0),this.node.addEventListener("blur",this,!0)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("click",this),this.node.removeEventListener("keydown",this),this.node.removeEventListener("input",this),this.node.removeEventListener("focus",this,!0),this.node.removeEventListener("blur",this,!0)},t.prototype.onActivateRequest=function(e){if(this.isAttached){var t=this.inputNode;t.focus(),t.select()}},t.prototype.onUpdateRequest=function(e){var t=this.inputNode.value,n=this.contentNode,r=this._results;if(r||(r=this._results=X.search(this._items,t),this._activeIndex=t?i.ArrayExt.findFirstIndex(r,X.canActivate):-1),t||0!==r.length)if(t&&0===r.length){var a=this.renderer.renderEmptyMessage({query:t});p.VirtualDOM.render(a,n)}else{for(var s=this.renderer,l=this._activeIndex,c=new Array(r.length),u=0,d=r.length;u<d;++u){var h=r[u];if("header"===h.type){var f=h.indices,m=h.category;c[u]=s.renderHeader({category:m,indices:f})}else{var g=h.item,v=(f=h.indices,u===l);c[u]=s.renderItem({item:g,indices:f,active:v})}}if(p.VirtualDOM.render(c,n),l<0||l>=r.length)n.scrollTop=0;else{var y=n.children[l];o.ElementExt.scrollIntoViewIfNeeded(n,y)}}else p.VirtualDOM.render(null,n)},t.prototype._evtClick=function(e){if(0===e.button){if(e.target.classList.contains("lm-close-icon"))return this.inputNode.value="",void this.refresh();var t=i.ArrayExt.findFirstIndex(this.contentNode.children,(function(t){return t.contains(e.target)}));-1!==t&&(e.preventDefault(),e.stopPropagation(),this._execute(t))}},t.prototype._evtKeyDown=function(e){if(!(e.altKey||e.ctrlKey||e.metaKey||e.shiftKey))switch(e.keyCode){case 13:e.preventDefault(),e.stopPropagation(),this._execute(this._activeIndex);break;case 38:e.preventDefault(),e.stopPropagation(),this._activatePreviousItem();break;case 40:e.preventDefault(),e.stopPropagation(),this._activateNextItem()}},t.prototype._activateNextItem=function(){if(this._results&&0!==this._results.length){var e=this._activeIndex,t=this._results.length,n=e<t-1?e+1:0,r=0===n?t-1:n-1;this._activeIndex=i.ArrayExt.findFirstIndex(this._results,X.canActivate,n,r),this.update()}},t.prototype._activatePreviousItem=function(){if(this._results&&0!==this._results.length){var e=this._activeIndex,t=this._results.length,n=e<=0?t-1:e-1,r=n===t-1?0:n+1;this._activeIndex=i.ArrayExt.findLastIndex(this._results,X.canActivate,n,r),this.update()}},t.prototype._execute=function(e){if(this._results){var t=this._results[e];if(t){if("header"===t.type){var n=this.inputNode;return n.value=t.category.toLowerCase()+" ",n.focus(),void this.refresh()}t.item.isEnabled&&(this.commands.execute(t.item.command,t.item.args),this.inputNode.value="",this.refresh())}}},t.prototype._toggleFocused=function(){var e=document.activeElement===this.inputNode;this.toggleClass("lm-mod-focused",e),this.toggleClass("p-mod-focused",e)},t.prototype._onGenericChange=function(){this.refresh()},t}(A);!function(e){var t=function(){function e(){}return e.prototype.renderHeader=function(e){var t=this.formatHeader(e);return p.h.li({className:"lm-CommandPalette-header p-CommandPalette-header"},t)},e.prototype.renderItem=function(e){var t=this.createItemClass(e),n=this.createItemDataset(e);return e.item.isToggleable?p.h.li({className:t,dataset:n,role:"checkbox","aria-checked":""+e.item.isToggled},this.renderItemIcon(e),this.renderItemContent(e),this.renderItemShortcut(e)):p.h.li({className:t,dataset:n},this.renderItemIcon(e),this.renderItemContent(e),this.renderItemShortcut(e))},e.prototype.renderEmptyMessage=function(e){var t=this.formatEmptyMessage(e);return p.h.li({className:"lm-CommandPalette-emptyMessage p-CommandPalette-emptyMessage"},t)},e.prototype.renderItemIcon=function(e){var t=this.createIconClass(e);return"string"==typeof e.item.icon?p.h.div({className:t},e.item.iconLabel):p.h.div({className:t},e.item.icon,e.item.iconLabel)},e.prototype.renderItemContent=function(e){return p.h.div({className:"lm-CommandPalette-itemContent p-CommandPalette-itemContent"},this.renderItemLabel(e),this.renderItemCaption(e))},e.prototype.renderItemLabel=function(e){var t=this.formatItemLabel(e);return p.h.div({className:"lm-CommandPalette-itemLabel p-CommandPalette-itemLabel"},t)},e.prototype.renderItemCaption=function(e){var t=this.formatItemCaption(e);return p.h.div({className:"lm-CommandPalette-itemCaption p-CommandPalette-itemCaption"},t)},e.prototype.renderItemShortcut=function(e){var t=this.formatItemShortcut(e);return p.h.div({className:"lm-CommandPalette-itemShortcut p-CommandPalette-itemShortcut"},t)},e.prototype.createItemClass=function(e){var t="lm-CommandPalette-item";t+=" p-CommandPalette-item",e.item.isEnabled||(t+=" lm-mod-disabled",t+=" p-mod-disabled"),e.item.isToggled&&(t+=" lm-mod-toggled",t+=" p-mod-toggled"),e.active&&(t+=" lm-mod-active",t+=" p-mod-active");var n=e.item.className;return n&&(t+=" "+n),t},e.prototype.createItemDataset=function(e){return v(v({},e.item.dataset),{command:e.item.command})},e.prototype.createIconClass=function(e){var t="lm-CommandPalette-itemIcon";t+=" p-CommandPalette-itemIcon";var n=e.item.iconClass;return n?t+" "+n:t},e.prototype.formatHeader=function(e){return e.indices&&0!==e.indices.length?i.StringExt.highlight(e.category,e.indices,p.h.mark):e.category},e.prototype.formatEmptyMessage=function(e){return"No commands found that match '"+e.query+"'"},e.prototype.formatItemShortcut=function(e){var t=e.item.keyBinding;return t?t.keys.map(h.CommandRegistry.formatKeystroke).join(", "):null},e.prototype.formatItemLabel=function(e){return e.indices&&0!==e.indices.length?i.StringExt.highlight(e.item.label,e.indices,p.h.mark):e.item.label},e.prototype.formatItemCaption=function(e){return e.item.caption},e}();e.Renderer=t,e.defaultRenderer=new t}(J||(J={})),function(e){function t(e,t){for(var n=e.category.toLowerCase(),r=n+" "+e.label.toLowerCase(),o=1/0,a=null,s=/\b\w/g;;){var l=s.exec(r);if(!l)break;var c=i.StringExt.matchSumOfDeltas(r,t,l.index);if(!c)break;c&&c.score<=o&&(o=c.score,a=c.indices)}if(!a||o===1/0)return null;for(var u=n.length+1,d=i.ArrayExt.lowerBound(a,u,(function(e,t){return e-t})),h=a.slice(0,d),p=a.slice(d),f=0,m=p.length;f<m;++f)p[f]-=u;return 0===h.length?{matchType:0,categoryIndices:null,labelIndices:p,score:o,item:e}:0===p.length?{matchType:1,categoryIndices:h,labelIndices:null,score:o,item:e}:{matchType:2,categoryIndices:h,labelIndices:p,score:o,item:e}}function n(e,t){var n=e.matchType-t.matchType;if(0!==n)return n;var r=e.score-t.score;if(0!==r)return r;var i=0,o=0;switch(e.matchType){case 0:i=e.labelIndices[0],o=t.labelIndices[0];break;case 1:case 2:i=e.categoryIndices[0],o=t.categoryIndices[0]}if(i!==o)return i-o;var a=e.item.category.localeCompare(t.item.category);if(0!==a)return a;var s=e.item.rank,l=t.item.rank;return s!==l?s<l?-1:1:e.item.label.localeCompare(t.item.label)}e.createNode=function(){var e=document.createElement("div"),t=document.createElement("div"),n=document.createElement("div"),r=document.createElement("input"),i=document.createElement("ul"),o=document.createElement("button");return t.className="lm-CommandPalette-search",n.className="lm-CommandPalette-wrapper",r.className="lm-CommandPalette-input",o.className="lm-close-icon",i.className="lm-CommandPalette-content",t.classList.add("p-CommandPalette-search"),n.classList.add("p-CommandPalette-wrapper"),r.classList.add("p-CommandPalette-input"),i.classList.add("p-CommandPalette-content"),r.spellcheck=!1,n.appendChild(r),n.appendChild(o),t.appendChild(n),e.appendChild(t),e.appendChild(i),e},e.createItem=function(e,t){return new r(e,t)},e.search=function(e,r){var o=function(e,n){r=n,n=r.replace(/\s+/g,"").toLowerCase();var r;for(var i=[],o=0,a=e.length;o<a;++o){var s=e[o];if(s.isVisible)if(n){var l=t(s,n);l&&(s.isEnabled||(l.score+=1e3),i.push(l))}else i.push({matchType:3,categoryIndices:null,labelIndices:null,score:0,item:s})}return i}(e,r);return o.sort(n),function(e){var t=new Array(e.length);i.ArrayExt.fill(t,!1);for(var n=[],r=0,o=e.length;r<o;++r)if(!t[r]){var a=e[r],s=a.item,l=a.categoryIndices,c=s.category;n.push({type:"header",category:c,indices:l});for(var u=r;u<o;++u)if(!t[u]){var d=e[u],h=d.item,p=d.labelIndices;h.category===c&&(n.push({type:"item",item:h,indices:p}),t[u]=!0)}}return n}(o)},e.canActivate=function(e){return"item"===e.type&&e.item.isEnabled};var r=function(){function e(e,t){this._commands=e,this.category=t.category.trim().replace(/\s+/g," "),this.command=t.command,this.args=t.args||d.JSONExt.emptyObject,this.rank=void 0!==t.rank?t.rank:1/0}return Object.defineProperty(e.prototype,"label",{get:function(){return this._commands.label(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"icon",{get:function(){return this._commands.icon(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconClass",{get:function(){return this._commands.iconClass(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconLabel",{get:function(){return this._commands.iconLabel(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"caption",{get:function(){return this._commands.caption(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"className",{get:function(){return this._commands.className(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){return this._commands.dataset(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isEnabled",{get:function(){return this._commands.isEnabled(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isToggled",{get:function(){return this._commands.isToggled(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isToggleable",{get:function(){return this._commands.isToggleable(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isVisible",{get:function(){return this._commands.isVisible(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"keyBinding",{get:function(){var e=this.command,t=this.args;return i.ArrayExt.findLastValue(this._commands.keyBindings,(function(n){return n.command===e&&d.JSONExt.deepEqual(n.args,t)}))||null},enumerable:!0,configurable:!0}),e}()}(X||(X={}));var Q,Z=function(e){function t(n){var r=e.call(this,{node:Q.createNode()})||this;return r._childIndex=-1,r._activeIndex=-1,r._openTimerID=0,r._closeTimerID=0,r._items=[],r._childMenu=null,r._parentMenu=null,r._aboutToClose=new l.Signal(r),r._menuRequested=new l.Signal(r),r.addClass("lm-Menu"),r.addClass("p-Menu"),r.setFlag(A.Flag.DisallowLayout),r.commands=n.commands,r.renderer=n.renderer||t.defaultRenderer,r}return g(t,e),t.prototype.dispose=function(){this.close(),this._items.length=0,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"aboutToClose",{get:function(){return this._aboutToClose},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"menuRequested",{get:function(){return this._menuRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"parentMenu",{get:function(){return this._parentMenu},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"childMenu",{get:function(){return this._childMenu},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"rootMenu",{get:function(){for(var e=this;e._parentMenu;)e=e._parentMenu;return e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"leafMenu",{get:function(){for(var e=this;e._childMenu;)e=e._childMenu;return e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"contentNode",{get:function(){return this.node.getElementsByClassName("lm-Menu-content")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"activeItem",{get:function(){return this._items[this._activeIndex]||null},set:function(e){this.activeIndex=e?this._items.indexOf(e):-1},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"activeIndex",{get:function(){return this._activeIndex},set:function(e){(e<0||e>=this._items.length)&&(e=-1),-1===e||Q.canActivate(this._items[e])||(e=-1),this._activeIndex!==e&&(this._activeIndex=e,this._activeIndex>=0&&this.contentNode.childNodes[this._activeIndex]&&this.contentNode.childNodes[this._activeIndex].focus(),this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"items",{get:function(){return this._items},enumerable:!0,configurable:!0}),t.prototype.activateNextItem=function(){var e=this._items.length,t=this._activeIndex,n=t<e-1?t+1:0,r=0===n?e-1:n-1;this.activeIndex=i.ArrayExt.findFirstIndex(this._items,Q.canActivate,n,r)},t.prototype.activatePreviousItem=function(){var e=this._items.length,t=this._activeIndex,n=t<=0?e-1:t-1,r=n===e-1?0:n+1;this.activeIndex=i.ArrayExt.findLastIndex(this._items,Q.canActivate,n,r)},t.prototype.triggerActiveItem=function(){if(this.isAttached){var e=this.activeItem;if(e)if(this._cancelOpenTimer(),this._cancelCloseTimer(),"submenu"!==e.type){this.rootMenu.close();var t=e.command,n=e.args;this.commands.isEnabled(t,n)?this.commands.execute(t,n):console.log("Command '"+t+"' is disabled.")}else this._openChildMenu(!0)}},t.prototype.addItem=function(e){return this.insertItem(this._items.length,e)},t.prototype.insertItem=function(e,t){this.isAttached&&this.close(),this.activeIndex=-1;var n=Math.max(0,Math.min(e,this._items.length)),r=Q.createItem(this,t);return i.ArrayExt.insert(this._items,n,r),this.update(),r},t.prototype.removeItem=function(e){this.removeItemAt(this._items.indexOf(e))},t.prototype.removeItemAt=function(e){this.isAttached&&this.close(),this.activeIndex=-1,i.ArrayExt.removeAt(this._items,e)&&this.update()},t.prototype.clearItems=function(){this.isAttached&&this.close(),this.activeIndex=-1,0!==this._items.length&&(this._items.length=0,this.update())},t.prototype.open=function(e,t,n){if(void 0===n&&(n={}),!this.isAttached){var r=n.forceX||!1,i=n.forceY||!1;Q.openRootMenu(this,e,t,r,i),this.activate()}},t.prototype.handleEvent=function(e){switch(e.type){case"keydown":this._evtKeyDown(e);break;case"mouseup":this._evtMouseUp(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseenter":this._evtMouseEnter(e);break;case"mouseleave":this._evtMouseLeave(e);break;case"mousedown":this._evtMouseDown(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("keydown",this),this.node.addEventListener("mouseup",this),this.node.addEventListener("mousemove",this),this.node.addEventListener("mouseenter",this),this.node.addEventListener("mouseleave",this),this.node.addEventListener("contextmenu",this),document.addEventListener("mousedown",this,!0)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("keydown",this),this.node.removeEventListener("mouseup",this),this.node.removeEventListener("mousemove",this),this.node.removeEventListener("mouseenter",this),this.node.removeEventListener("mouseleave",this),this.node.removeEventListener("contextmenu",this),document.removeEventListener("mousedown",this,!0)},t.prototype.onActivateRequest=function(e){this.isAttached&&this.node.focus()},t.prototype.onUpdateRequest=function(e){for(var t=this,n=this._items,r=this.renderer,i=this._activeIndex,o=Q.computeCollapsed(n),a=new Array(n.length),s=function(e,s){var l=n[e],c=e===i,u=o[e];a[e]=r.renderItem({item:l,active:c,collapsed:u,onfocus:function(){t.activeIndex=e}})},l=0,c=n.length;l<c;++l)s(l);p.VirtualDOM.render(a,this.contentNode)},t.prototype.onCloseRequest=function(t){this._cancelOpenTimer(),this._cancelCloseTimer(),this.activeIndex=-1;var n=this._childMenu;n&&(this._childIndex=-1,this._childMenu=null,n._parentMenu=null,n.close());var r=this._parentMenu;r&&(this._parentMenu=null,r._childIndex=-1,r._childMenu=null,r.activate()),this.isAttached&&this._aboutToClose.emit(void 0),e.prototype.onCloseRequest.call(this,t)},t.prototype._evtKeyDown=function(e){e.preventDefault(),e.stopPropagation();var t=e.keyCode;if(13!==t)if(27!==t)if(37!==t)if(38!==t)if(39!==t)if(40!==t){var n=Object(f.a)().keyForKeydownEvent(e);if(n){var r=this._activeIndex+1,i=Q.findMnemonic(this._items,n,r);-1===i.index||i.multiple?-1!==i.index?this.activeIndex=i.index:-1!==i.auto&&(this.activeIndex=i.auto):(this.activeIndex=i.index,this.triggerActiveItem())}}else this.activateNextItem();else{var o=this.activeItem;o&&"submenu"===o.type?this.triggerActiveItem():this.rootMenu._menuRequested.emit("next")}else this.activatePreviousItem();else this._parentMenu?this.close():this._menuRequested.emit("previous");else this.close();else this.triggerActiveItem()},t.prototype._evtMouseUp=function(e){0===e.button&&(e.preventDefault(),e.stopPropagation(),this.triggerActiveItem())},t.prototype._evtMouseMove=function(e){var t=i.ArrayExt.findFirstIndex(this.contentNode.children,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));if(t!==this._activeIndex){if(this.activeIndex=t,(t=this.activeIndex)===this._childIndex)return this._cancelOpenTimer(),void this._cancelCloseTimer();-1!==this._childIndex&&this._startCloseTimer(),this._cancelOpenTimer();var n=this.activeItem;n&&"submenu"===n.type&&n.submenu&&this._startOpenTimer()}},t.prototype._evtMouseEnter=function(e){for(var t=this._parentMenu;t;t=t._parentMenu)t._cancelOpenTimer(),t._cancelCloseTimer(),t.activeIndex=t._childIndex},t.prototype._evtMouseLeave=function(e){if(this._cancelOpenTimer(),this._childMenu){var t=e.clientX,n=e.clientY;o.ElementExt.hitTest(this._childMenu.node,t,n)?this._cancelCloseTimer():(this.activeIndex=-1,this._startCloseTimer())}else this.activeIndex=-1},t.prototype._evtMouseDown=function(e){this._parentMenu||(Q.hitTestMenus(this,e.clientX,e.clientY)?(e.preventDefault(),e.stopPropagation()):this.close())},t.prototype._openChildMenu=function(e){void 0===e&&(e=!1);var t=this.activeItem;if(t&&"submenu"===t.type&&t.submenu){var n=t.submenu;if(n!==this._childMenu){this._closeChildMenu(),this._childMenu=n,this._childIndex=this._activeIndex,n._parentMenu=this,a.c.sendMessage(this,A.Msg.UpdateRequest);var r=this.contentNode.children[this._activeIndex];Q.openSubmenu(n,r),e&&(n.activeIndex=-1,n.activateNextItem()),n.activate()}}else this._closeChildMenu()},t.prototype._closeChildMenu=function(){this._childMenu&&this._childMenu.close()},t.prototype._startOpenTimer=function(){var e=this;0===this._openTimerID&&(this._openTimerID=window.setTimeout((function(){e._openTimerID=0,e._openChildMenu()}),Q.TIMER_DELAY))},t.prototype._startCloseTimer=function(){var e=this;0===this._closeTimerID&&(this._closeTimerID=window.setTimeout((function(){e._closeTimerID=0,e._closeChildMenu()}),Q.TIMER_DELAY))},t.prototype._cancelOpenTimer=function(){0!==this._openTimerID&&(clearTimeout(this._openTimerID),this._openTimerID=0)},t.prototype._cancelCloseTimer=function(){0!==this._closeTimerID&&(clearTimeout(this._closeTimerID),this._closeTimerID=0)},t}(A);!function(e){var t=function(){function e(){}return e.prototype.renderItem=function(e){var t=this.createItemClass(e),n=this.createItemDataset(e),r=this.createItemARIA(e);return p.h.li(v({className:t,dataset:n,tabindex:"0",onfocus:e.onfocus},r),this.renderIcon(e),this.renderLabel(e),this.renderShortcut(e),this.renderSubmenu(e))},e.prototype.renderIcon=function(e){var t=this.createIconClass(e);return"string"==typeof e.item.icon?p.h.div({className:t},e.item.iconLabel):p.h.div({className:t},e.item.icon,e.item.iconLabel)},e.prototype.renderLabel=function(e){var t=this.formatLabel(e);return p.h.div({className:"lm-Menu-itemLabel p-Menu-itemLabel"},t)},e.prototype.renderShortcut=function(e){var t=this.formatShortcut(e);return p.h.div({className:"lm-Menu-itemShortcut p-Menu-itemShortcut"},t)},e.prototype.renderSubmenu=function(e){return p.h.div({className:"lm-Menu-itemSubmenuIcon p-Menu-itemSubmenuIcon"})},e.prototype.createItemClass=function(e){var t="lm-Menu-item";t+=" p-Menu-item",e.item.isEnabled||(t+=" lm-mod-disabled",t+=" p-mod-disabled"),e.item.isToggled&&(t+=" lm-mod-toggled",t+=" p-mod-toggled"),e.item.isVisible||(t+=" lm-mod-hidden",t+=" p-mod-hidden"),e.active&&(t+=" lm-mod-active",t+=" p-mod-active"),e.collapsed&&(t+=" lm-mod-collapsed",t+=" p-mod-collapsed");var n=e.item.className;return n&&(t+=" "+n),t},e.prototype.createItemDataset=function(e){var t=e.item,n=t.type,r=t.command,i=t.dataset;return v(v({},i),"command"===n?{type:n,command:r}:{type:n})},e.prototype.createIconClass=function(e){var t="lm-Menu-itemIcon";t+=" p-Menu-itemIcon";var n=e.item.iconClass;return n?t+" "+n:t},e.prototype.createItemARIA=function(e){var t={};switch(e.item.type){case"separator":t.role="presentation";break;case"submenu":t["aria-haspopup"]="true",e.item.isEnabled||(t["aria-disabled"]="true");break;default:e.item.isEnabled||(t["aria-disabled"]="true"),t.role="menuitem"}return t},e.prototype.formatLabel=function(e){var t=e.item,n=t.label,r=t.mnemonic;if(r<0||r>=n.length)return n;var i=n.slice(0,r),o=n.slice(r+1),a=n[r];return[i,p.h.span({className:"lm-Menu-itemMnemonic p-Menu-itemMnemonic"},a),o]},e.prototype.formatShortcut=function(e){var t=e.item.keyBinding;return t?t.keys.map(h.CommandRegistry.formatKeystroke).join(", "):null},e}();e.Renderer=t,e.defaultRenderer=new t}(Z||(Z={})),function(e){function t(e){return"separator"!==e.type&&e.isEnabled&&e.isVisible}e.TIMER_DELAY=300,e.SUBMENU_OVERLAP=3,e.createNode=function(){var e=document.createElement("div"),t=document.createElement("ul");return t.className="lm-Menu-content",t.classList.add("p-Menu-content"),e.appendChild(t),t.setAttribute("role","menu"),e.tabIndex=0,e},e.canActivate=t,e.createItem=function(e,t){return new n(e.commands,t)},e.hitTestMenus=function(e,t,n){for(var r=e;r;r=r.childMenu)if(o.ElementExt.hitTest(r.node,t,n))return!0;return!1},e.computeCollapsed=function(e){var t=new Array(e.length);i.ArrayExt.fill(t,!1);for(var n=0,r=e.length;n<r;++n){if((s=e[n]).isVisible){if("separator"!==s.type)break;t[n]=!0}}for(var o=r-1;o>=0;--o){if((s=e[o]).isVisible){if("separator"!==s.type)break;t[o]=!0}}for(var a=!1;++n<o;){var s;(s=e[n]).isVisible&&("separator"!==s.type?a=!1:a?t[n]=!0:a=!0)}return t},e.openRootMenu=function(e,t,n,r,i){a.c.sendMessage(e,A.Msg.UpdateRequest);var o=window.pageXOffset,s=window.pageYOffset,l=document.documentElement.clientWidth,c=document.documentElement.clientHeight,u=c-(i?n:0),d=e.node,h=d.style;h.top="",h.left="",h.width="",h.height="",h.visibility="hidden",h.maxHeight=u+"px",A.attach(e,document.body);var p=d.getBoundingClientRect(),f=p.width,m=p.height;!r&&t+f>o+l&&(t=o+l-f),!i&&n+m>s+c&&(n>s+c?n=s+c-m:n-=m),h.top=Math.max(0,n)+"px",h.left=Math.max(0,t)+"px",h.visibility=""},e.openSubmenu=function(t,n){a.c.sendMessage(t,A.Msg.UpdateRequest);var r=window.pageXOffset,i=window.pageYOffset,s=document.documentElement.clientWidth,l=document.documentElement.clientHeight,c=l,u=t.node,d=u.style;d.top="",d.left="",d.width="",d.height="",d.visibility="hidden",d.maxHeight=c+"px",A.attach(t,document.body);var h=u.getBoundingClientRect(),p=h.width,f=h.height,m=o.ElementExt.boxSizing(t.node),g=n.getBoundingClientRect(),v=g.right-e.SUBMENU_OVERLAP;v+p>r+s&&(v=g.left+e.SUBMENU_OVERLAP-p);var y=g.top-m.borderTop-m.paddingTop;y+f>i+l&&(y=g.bottom+m.borderBottom+m.paddingBottom-f),d.top=Math.max(0,y)+"px",d.left=Math.max(0,v)+"px",d.visibility=""},e.findMnemonic=function(e,n,r){for(var i=-1,o=-1,a=!1,s=n.toUpperCase(),l=0,c=e.length;l<c;++l){var u=(l+r)%c,d=e[u];if(t(d)){var h=d.label;if(0!==h.length){var p=d.mnemonic;p>=0&&p<h.length?h[p].toUpperCase()===s&&(-1===i?i=u:a=!0):-1===o&&h[0].toUpperCase()===s&&(o=u)}}}return{index:i,multiple:a,auto:o}};var n=function(){function e(e,t){this._commands=e,this.type=t.type||"command",this.command=t.command||"",this.args=t.args||d.JSONExt.emptyObject,this.submenu=t.submenu||null}return Object.defineProperty(e.prototype,"label",{get:function(){return"command"===this.type?this._commands.label(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.label:""},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"mnemonic",{get:function(){return"command"===this.type?this._commands.mnemonic(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.mnemonic:-1},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"icon",{get:function(){return"command"===this.type?this._commands.icon(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.icon:this.iconClass},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconClass",{get:function(){return"command"===this.type?this._commands.iconClass(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.iconClass:""},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"iconLabel",{get:function(){return"command"===this.type?this._commands.iconLabel(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.iconLabel:""},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"caption",{get:function(){return"command"===this.type?this._commands.caption(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.caption:""},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"className",{get:function(){return"command"===this.type?this._commands.className(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.className:""},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){return"command"===this.type?this._commands.dataset(this.command,this.args):"submenu"===this.type&&this.submenu?this.submenu.title.dataset:{}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isEnabled",{get:function(){return"command"===this.type?this._commands.isEnabled(this.command,this.args):"submenu"!==this.type||null!==this.submenu},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isToggled",{get:function(){return"command"===this.type&&this._commands.isToggled(this.command,this.args)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isVisible",{get:function(){return"command"===this.type?this._commands.isVisible(this.command,this.args):"submenu"!==this.type||null!==this.submenu},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"keyBinding",{get:function(){if("command"===this.type){var e=this.command,t=this.args;return i.ArrayExt.findLastValue(this._commands.keyBindings,(function(n){return n.command===e&&d.JSONExt.deepEqual(n.args,t)}))||null}return null},enumerable:!0,configurable:!0}),e}()}(Q||(Q={}));var $,ee=function(){function e(e){this._groupByTarget=!0,this._idTick=0,this._items=[],this._sortBySelector=!0;var t=e.groupByTarget,n=e.sortBySelector,r=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n}(e,["groupByTarget","sortBySelector"]);this.menu=new Z(r),this._groupByTarget=!1!==t,this._sortBySelector=!1!==n}return e.prototype.addItem=function(e){var t=this,n=$.createItem(e,this._idTick++);return this._items.push(n),new c.DisposableDelegate((function(){i.ArrayExt.removeFirstOf(t._items,n)}))},e.prototype.open=function(e){var t=this;if(this.menu.clearItems(),0===this._items.length)return!1;var n=$.matchItems(this._items,e,this._groupByTarget,this._sortBySelector);return!(!n||0===n.length)&&(Object(i.each)(n,(function(e){t.menu.addItem(e)})),this.menu.open(e.clientX,e.clientY),!0)},e}();!function(e){function t(e,t){var n=e.rank,r=t.rank;return n!==r?n<r?-1:1:e.id-t.id}function n(e,n){var r=o.Selector.calculateSpecificity(e.selector),i=o.Selector.calculateSpecificity(n.selector);return r!==i?i-r:t(e,n)}e.createItem=function(e,t){var n=function(e){if(-1!==e.indexOf(","))throw new Error("Selector cannot contain commas: "+e);if(!o.Selector.isValid(e))throw new Error("Invalid selector: "+e);return e}(e.selector),r=void 0!==e.rank?e.rank:1/0;return v(v({},e),{selector:n,rank:r,id:t})},e.matchItems=function(e,r,i,a){var s=r.target;if(!s)return null;var l=r.currentTarget;if(!l)return null;if(!(l.contains(s)||(s=document.elementFromPoint(r.clientX,r.clientY))&&l.contains(s)))return null;for(var c=[],u=e.slice();null!==s;){for(var d=[],h=0,p=u.length;h<p;++h){var f=u[h];f&&(o.Selector.matches(s,f.selector)&&(d.push(f),u[h]=null))}if(0!==d.length&&(i&&d.sort(a?n:t),c.push.apply(c,d)),s===l)break;s=s.parentElement}return i||c.sort(a?n:t),c}}($||($={}));var te,ne=function(e){function t(n){void 0===n&&(n={});var r=e.call(this,{node:te.createNode()})||this;return r._currentIndex=-1,r._titles=[],r._titlesEditable=!1,r._previousTitle=null,r._dragData=null,r._addButtonEnabled=!1,r._tabMoved=new l.Signal(r),r._currentChanged=new l.Signal(r),r._addRequested=new l.Signal(r),r._tabCloseRequested=new l.Signal(r),r._tabDetachRequested=new l.Signal(r),r._tabActivateRequested=new l.Signal(r),r.addClass("lm-TabBar"),r.addClass("p-TabBar"),r.contentNode.setAttribute("role","tablist"),r.setFlag(A.Flag.DisallowLayout),r._document=n.document||document,r.tabsMovable=n.tabsMovable||!1,r.titlesEditable=n.titlesEditable||!1,r.allowDeselect=n.allowDeselect||!1,r.addButtonEnabled=n.addButtonEnabled||!1,r.insertBehavior=n.insertBehavior||"select-tab-if-needed",r.name=n.name||"",r.orientation=n.orientation||"horizontal",r.removeBehavior=n.removeBehavior||"select-tab-after",r.renderer=n.renderer||t.defaultRenderer,r}return g(t,e),t.prototype.dispose=function(){this._releaseMouse(),this._titles.length=0,this._previousTitle=null,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"currentChanged",{get:function(){return this._currentChanged},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabMoved",{get:function(){return this._tabMoved},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabActivateRequested",{get:function(){return this._tabActivateRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addRequested",{get:function(){return this._addRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabCloseRequested",{get:function(){return this._tabCloseRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabDetachRequested",{get:function(){return this._tabDetachRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"document",{get:function(){return this._document},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"titlesEditable",{get:function(){return this._titlesEditable},set:function(e){this._titlesEditable=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentTitle",{get:function(){return this._titles[this._currentIndex]||null},set:function(e){this.currentIndex=e?this._titles.indexOf(e):-1},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentIndex",{get:function(){return this._currentIndex},set:function(e){if((e<0||e>=this._titles.length)&&(e=-1),this._currentIndex!==e){var t=this._currentIndex,n=this._titles[t]||null,r=e,i=this._titles[r]||null;this._currentIndex=r,this._previousTitle=n,this.update(),this._currentChanged.emit({previousIndex:t,previousTitle:n,currentIndex:r,currentTitle:i})}},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"name",{get:function(){return this._name},set:function(e){this._name=e,e?this.contentNode.setAttribute("aria-label",e):this.contentNode.removeAttribute("aria-label")},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"orientation",{get:function(){return this._orientation},set:function(e){this._orientation!==e&&(this._releaseMouse(),this._orientation=e,this.dataset.orientation=e,this.contentNode.setAttribute("aria-orientation",e))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addButtonEnabled",{get:function(){return this._addButtonEnabled},set:function(e){this._addButtonEnabled!==e&&(this._addButtonEnabled=e,e?this.addButtonNode.classList.remove("lm-mod-hidden"):this.addButtonNode.classList.add("lm-mod-hidden"))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"titles",{get:function(){return this._titles},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"contentNode",{get:function(){return this.node.getElementsByClassName("lm-TabBar-content")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addButtonNode",{get:function(){return this.node.getElementsByClassName("lm-TabBar-addButton")[0]},enumerable:!0,configurable:!0}),t.prototype.addTab=function(e){return this.insertTab(this._titles.length,e)},t.prototype.insertTab=function(e,t){this._releaseMouse();var n=te.asTitle(t),r=this._titles.indexOf(n),o=Math.max(0,Math.min(e,this._titles.length));return-1===r?(i.ArrayExt.insert(this._titles,o,n),n.changed.connect(this._onTitleChanged,this),this.update(),this._adjustCurrentForInsert(o,n),n):(o===this._titles.length&&o--,r===o||(i.ArrayExt.move(this._titles,r,o),this.update(),this._adjustCurrentForMove(r,o)),n)},t.prototype.removeTab=function(e){this.removeTabAt(this._titles.indexOf(e))},t.prototype.removeTabAt=function(e){this._releaseMouse();var t=i.ArrayExt.removeAt(this._titles,e);t&&(t.changed.disconnect(this._onTitleChanged,this),t===this._previousTitle&&(this._previousTitle=null),this.update(),this._adjustCurrentForRemove(e,t))},t.prototype.clearTabs=function(){if(0!==this._titles.length){this._releaseMouse();for(var e=0,t=this._titles;e<t.length;e++){t[e].changed.disconnect(this._onTitleChanged,this)}var n=this.currentIndex,r=this.currentTitle;this._currentIndex=-1,this._previousTitle=null,this._titles.length=0,this.update(),-1!==n&&this._currentChanged.emit({previousIndex:n,previousTitle:r,currentIndex:-1,currentTitle:null})}},t.prototype.releaseMouse=function(){this._releaseMouse()},t.prototype.handleEvent=function(e){switch(e.type){case"mousedown":this._evtMouseDown(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseup":this._evtMouseUp(e);break;case"pointerdown":this._evtMouseDown(e);break;case"pointermove":this._evtMouseMove(e);break;case"pointerup":this._evtMouseUp(e);break;case"dblclick":this._evtDblClick(e);break;case"keydown":this._evtKeyDown(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("mousedown",this),this.node.addEventListener("pointerdown",this),this.node.addEventListener("dblclick",this)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("mousedown",this),this.node.removeEventListener("pointerdown",this),this.node.removeEventListener("dblclick",this),this._releaseMouse()},t.prototype.onUpdateRequest=function(e){for(var t=this._titles,n=this.renderer,r=this.currentTitle,i=new Array(t.length),o=0,a=t.length;o<a;++o){var s=t[o],l=s===r,c=l?a:a-o-1;i[o]=n.renderTab({title:s,current:l,zIndex:c})}p.VirtualDOM.render(i,this.contentNode)},t.prototype._evtDblClick=function(e){if(this.titlesEditable){var t=this.contentNode.children,n=i.ArrayExt.findFirstIndex(t,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));if(-1!==n){var r=this.titles[n],a=t[n].querySelector(".lm-TabBar-tabLabel");if(a&&a.contains(e.target)){var s=r.label||"",l=a.innerHTML;a.innerHTML="";var c=document.createElement("input");c.classList.add("lm-TabBar-tabInput"),c.value=s,a.appendChild(c);var u=function(){c.removeEventListener("blur",u),a.innerHTML=l};c.addEventListener("dblclick",(function(e){return e.stopPropagation()})),c.addEventListener("blur",u),c.addEventListener("keydown",(function(e){"Enter"===e.key?(""!==c.value&&(r.label=r.caption=c.value),u()):"Escape"===e.key&&u()})),c.select(),c.focus(),a.children.length>0&&a.children[0].focus()}}}},t.prototype._evtKeyDown=function(e){e.preventDefault(),e.stopPropagation(),27===e.keyCode&&this._releaseMouse()},t.prototype._evtMouseDown=function(e){if((0===e.button||1===e.button)&&!this._dragData){var t=this.addButtonEnabled&&this.addButtonNode.contains(e.target),n=this.contentNode.children,r=i.ArrayExt.findFirstIndex(n,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));if((-1!==r||t)&&(e.preventDefault(),e.stopPropagation(),this._dragData={tab:n[r],index:r,pressX:e.clientX,pressY:e.clientY,tabPos:-1,tabSize:-1,tabPressPos:-1,targetIndex:-1,tabLayout:null,contentRect:null,override:null,dragActive:!1,dragAborted:!1,detachRequested:!1},this.document.addEventListener("mouseup",this,!0),this.document.addEventListener("pointerup",this,!0),1!==e.button&&!t)){var a=n[r].querySelector(this.renderer.closeIconSelector);a&&a.contains(e.target)||(this.tabsMovable&&(this.document.addEventListener("mousemove",this,!0),this.document.addEventListener("pointermove",this,!0),this.document.addEventListener("keydown",this,!0),this.document.addEventListener("contextmenu",this,!0)),this.allowDeselect&&this.currentIndex===r?this.currentIndex=-1:this.currentIndex=r,-1!==this.currentIndex&&this._tabActivateRequested.emit({index:this.currentIndex,title:this.currentTitle}))}}},t.prototype._evtMouseMove=function(e){var t=this._dragData;if(t){e.preventDefault(),e.stopPropagation();var n=this.contentNode.children;if(t.dragActive||te.dragExceeded(t,e)){if(!t.dragActive){var r=t.tab.getBoundingClientRect();"horizontal"===this._orientation?(t.tabPos=t.tab.offsetLeft,t.tabSize=r.width,t.tabPressPos=t.pressX-r.left):(t.tabPos=t.tab.offsetTop,t.tabSize=r.height,t.tabPressPos=t.pressY-r.top),t.tabLayout=te.snapTabLayout(n,this._orientation),t.contentRect=this.contentNode.getBoundingClientRect(),t.override=u.overrideCursor("default"),t.tab.classList.add("lm-mod-dragging"),this.addClass("lm-mod-dragging"),t.tab.classList.add("p-mod-dragging"),this.addClass("p-mod-dragging"),t.dragActive=!0}if(!t.detachRequested&&te.detachExceeded(t,e)){t.detachRequested=!0;var i=t.index,o=e.clientX,a=e.clientY,s=n[i],l=this._titles[i];if(this._tabDetachRequested.emit({index:i,title:l,tab:s,clientX:o,clientY:a}),t.dragAborted)return}te.layoutTabs(n,t,e,this._orientation)}}},t.prototype._evtMouseUp=function(e){var t=this;if(0===e.button||1===e.button){var n=this._dragData;if(n){if(e.preventDefault(),e.stopPropagation(),this.document.removeEventListener("mousemove",this,!0),this.document.removeEventListener("mouseup",this,!0),this.document.removeEventListener("pointermove",this,!0),this.document.removeEventListener("pointerup",this,!0),this.document.removeEventListener("keydown",this,!0),this.document.removeEventListener("contextmenu",this,!0),!n.dragActive){if(this._dragData=null,this.addButtonEnabled&&this.addButtonNode.contains(e.target))return void this._addRequested.emit(void 0);var r=this.contentNode.children,s=i.ArrayExt.findFirstIndex(r,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));if(s!==n.index)return;var l=this._titles[s];if(!l.closable)return;if(1===e.button)return void this._tabCloseRequested.emit({index:s,title:l});var c=r[s].querySelector(this.renderer.closeIconSelector);return c&&c.contains(e.target)?void this._tabCloseRequested.emit({index:s,title:l}):void 0}if(0===e.button){te.finalizeTabPosition(n,this._orientation),n.tab.classList.remove("lm-mod-dragging"),n.tab.classList.remove("p-mod-dragging");var u=te.parseTransitionDuration(n.tab);setTimeout((function(){if(!n.dragAborted){t._dragData=null,te.resetTabPositions(t.contentNode.children,t._orientation),n.override.dispose(),t.removeClass("lm-mod-dragging"),t.removeClass("p-mod-dragging");var e=n.index,r=n.targetIndex;-1!==r&&e!==r&&(i.ArrayExt.move(t._titles,e,r),t._adjustCurrentForMove(e,r),t._tabMoved.emit({fromIndex:e,toIndex:r,title:t._titles[r]}),a.c.sendMessage(t,A.Msg.UpdateRequest))}}),u)}}}},t.prototype._releaseMouse=function(){var e=this._dragData;e&&(this._dragData=null,this.document.removeEventListener("mousemove",this,!0),this.document.removeEventListener("mouseup",this,!0),this.document.removeEventListener("pointermove",this,!0),this.document.removeEventListener("pointerup",this,!0),this.document.removeEventListener("keydown",this,!0),this.document.removeEventListener("contextmenu",this,!0),e.dragAborted=!0,e.dragActive&&(te.resetTabPositions(this.contentNode.children,this._orientation),e.override.dispose(),e.tab.classList.remove("lm-mod-dragging"),this.removeClass("lm-mod-dragging"),e.tab.classList.remove("p-mod-dragging"),this.removeClass("p-mod-dragging")))},t.prototype._adjustCurrentForInsert=function(e,t){var n=this.currentTitle,r=this._currentIndex,i=this.insertBehavior;if("select-tab"===i||"select-tab-if-needed"===i&&-1===r)return this._currentIndex=e,this._previousTitle=n,void this._currentChanged.emit({previousIndex:r,previousTitle:n,currentIndex:e,currentTitle:t});r>=e&&this._currentIndex++},t.prototype._adjustCurrentForMove=function(e,t){this._currentIndex===e?this._currentIndex=t:this._currentIndex<e&&this._currentIndex>=t?this._currentIndex++:this._currentIndex>e&&this._currentIndex<=t&&this._currentIndex--},t.prototype._adjustCurrentForRemove=function(e,t){var n=this._currentIndex,r=this.removeBehavior;if(n===e){if(0===this._titles.length)return this._currentIndex=-1,void this._currentChanged.emit({previousIndex:e,previousTitle:t,currentIndex:-1,currentTitle:null});if("select-tab-after"===r)return this._currentIndex=Math.min(e,this._titles.length-1),void this._currentChanged.emit({previousIndex:e,previousTitle:t,currentIndex:this._currentIndex,currentTitle:this.currentTitle});if("select-tab-before"===r)return this._currentIndex=Math.max(0,e-1),void this._currentChanged.emit({previousIndex:e,previousTitle:t,currentIndex:this._currentIndex,currentTitle:this.currentTitle});if("select-previous-tab"===r)return this._previousTitle?(this._currentIndex=this._titles.indexOf(this._previousTitle),this._previousTitle=null):this._currentIndex=Math.min(e,this._titles.length-1),void this._currentChanged.emit({previousIndex:e,previousTitle:t,currentIndex:this._currentIndex,currentTitle:this.currentTitle});this._currentIndex=-1,this._currentChanged.emit({previousIndex:e,previousTitle:t,currentIndex:-1,currentTitle:null})}else n>e&&this._currentIndex--},t.prototype._onTitleChanged=function(e){this.update()},t}(A);!function(e){var t=function(){function e(){this.closeIconSelector=".lm-TabBar-tabCloseIcon",this._tabID=0,this._tabKeys=new WeakMap}return e.prototype.renderTab=function(e){var t=e.title.caption,n=this.createTabKey(e),r=n,i=this.createTabStyle(e),o=this.createTabClass(e),a=this.createTabDataset(e),s=this.createTabARIA(e);return e.title.closable?p.h.li(v({id:r,key:n,className:o,title:t,style:i,dataset:a},s),this.renderIcon(e),this.renderLabel(e),this.renderCloseIcon(e)):p.h.li(v({id:r,key:n,className:o,title:t,style:i,dataset:a},s),this.renderIcon(e),this.renderLabel(e))},e.prototype.renderIcon=function(e){var t=e.title,n=this.createIconClass(e);return"string"==typeof t.icon?p.h.div({className:n},t.iconLabel):p.h.div({className:n},t.icon,t.iconLabel)},e.prototype.renderLabel=function(e){return p.h.div({className:"lm-TabBar-tabLabel p-TabBar-tabLabel"},e.title.label)},e.prototype.renderCloseIcon=function(e){return p.h.div({className:"lm-TabBar-tabCloseIcon p-TabBar-tabCloseIcon"})},e.prototype.createTabKey=function(e){var t=this._tabKeys.get(e.title);return void 0===t&&(t="tab-key-"+this._tabID++,this._tabKeys.set(e.title,t)),t},e.prototype.createTabStyle=function(e){return{zIndex:""+e.zIndex}},e.prototype.createTabClass=function(e){var t="lm-TabBar-tab";return t+=" p-TabBar-tab",e.title.className&&(t+=" "+e.title.className),e.title.closable&&(t+=" lm-mod-closable",t+=" p-mod-closable"),e.current&&(t+=" lm-mod-current",t+=" p-mod-current"),t},e.prototype.createTabDataset=function(e){return e.title.dataset},e.prototype.createTabARIA=function(e){return{role:"tab","aria-selected":e.current.toString()}},e.prototype.createIconClass=function(e){var t="lm-TabBar-tabIcon";t+=" p-TabBar-tabIcon";var n=e.title.iconClass;return n?t+" "+n:t},e}();e.Renderer=t,e.defaultRenderer=new t,e.addButtonSelector=".lm-TabBar-addButton"}(ne||(ne={})),function(e){e.DRAG_THRESHOLD=5,e.DETACH_THRESHOLD=20,e.createNode=function(){var e=document.createElement("div"),t=document.createElement("ul");t.setAttribute("role","tablist"),t.className="lm-TabBar-content",t.classList.add("p-TabBar-content"),e.appendChild(t);var n=document.createElement("div");return n.className="lm-TabBar-addButton lm-mod-hidden",e.appendChild(n),e},e.asTitle=function(e){return e instanceof w?e:new w(e)},e.parseTransitionDuration=function(e){var t=window.getComputedStyle(e);return 1e3*(parseFloat(t.transitionDuration)||0)},e.snapTabLayout=function(e,t){for(var n=new Array(e.length),r=0,i=e.length;r<i;++r){var o=e[r],a=window.getComputedStyle(o);n[r]="horizontal"===t?{pos:o.offsetLeft,size:o.offsetWidth,margin:parseFloat(a.marginLeft)||0}:{pos:o.offsetTop,size:o.offsetHeight,margin:parseFloat(a.marginTop)||0}}return n},e.dragExceeded=function(t,n){var r=Math.abs(n.clientX-t.pressX),i=Math.abs(n.clientY-t.pressY);return r>=e.DRAG_THRESHOLD||i>=e.DRAG_THRESHOLD},e.detachExceeded=function(t,n){var r=t.contentRect;return n.clientX<r.left-e.DETACH_THRESHOLD||n.clientX>=r.right+e.DETACH_THRESHOLD||n.clientY<r.top-e.DETACH_THRESHOLD||n.clientY>=r.bottom+e.DETACH_THRESHOLD},e.layoutTabs=function(e,t,n,r){var i,o,a,s;"horizontal"===r?(i=t.pressX,o=n.clientX-t.contentRect.left,a=n.clientX,s=t.contentRect.width):(i=t.pressY,o=n.clientY-t.contentRect.top,a=n.clientY,s=t.contentRect.height);for(var l=t.index,c=o-t.tabPressPos,u=c+t.tabSize,d=0,h=e.length;d<h;++d){var p=void 0,f=t.tabLayout[d],m=f.pos+(f.size>>1);if(d<t.index&&c<m)p=t.tabSize+t.tabLayout[d+1].margin+"px",l=Math.min(l,d);else if(d>t.index&&u>m)p=-t.tabSize-f.margin+"px",l=Math.max(l,d);else if(d===t.index){var g=a-i,v=s-(t.tabPos+t.tabSize);p=Math.max(-t.tabPos,Math.min(g,v))+"px"}else p="";"horizontal"===r?e[d].style.left=p:e[d].style.top=p}t.targetIndex=l},e.finalizeTabPosition=function(e,t){var n,r;if(n="horizontal"===t?e.contentRect.width:e.contentRect.height,e.targetIndex===e.index)r=0;else if(e.targetIndex>e.index){r=(i=e.tabLayout[e.targetIndex]).pos+i.size-e.tabSize-e.tabPos}else{var i;r=(i=e.tabLayout[e.targetIndex]).pos-e.tabPos}var o=n-(e.tabPos+e.tabSize),a=Math.max(-e.tabPos,Math.min(r,o));"horizontal"===t?e.tab.style.left=a+"px":e.tab.style.top=a+"px"},e.resetTabPositions=function(e,t){Object(i.each)(e,(function(e){"horizontal"===t?e.style.left="":e.style.top=""}))}}(te||(te={}));var re,ie=function(e){function t(t){var n=e.call(this)||this;return n._spacing=4,n._dirty=!1,n._root=null,n._box=null,n._items=new Map,n.renderer=t.renderer,void 0!==t.spacing&&(n._spacing=k.clampDimension(t.spacing)),n._document=t.document||document,n._hiddenMode=void 0!==t.hiddenMode?t.hiddenMode:A.HiddenMode.Display,n}return g(t,e),t.prototype.dispose=function(){var t=this.iter();this._items.forEach((function(e){e.dispose()})),this._box=null,this._root=null,this._items.clear(),Object(i.each)(t,(function(e){e.dispose()})),e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"hiddenMode",{get:function(){return this._hiddenMode},set:function(e){var t=this;this._hiddenMode!==e&&(this._hiddenMode=e,Object(i.each)(this.tabBars(),(function(e){e.titles.length>1&&e.titles.forEach((function(e){e.owner.hiddenMode=t._hiddenMode}))})))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this._spacing},set:function(e){e=k.clampDimension(e),this._spacing!==e&&(this._spacing=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"isEmpty",{get:function(){return null===this._root},enumerable:!0,configurable:!0}),t.prototype.iter=function(){return this._root?this._root.iterAllWidgets():Object(i.empty)()},t.prototype.widgets=function(){return this._root?this._root.iterUserWidgets():Object(i.empty)()},t.prototype.selectedWidgets=function(){return this._root?this._root.iterSelectedWidgets():Object(i.empty)()},t.prototype.tabBars=function(){return this._root?this._root.iterTabBars():Object(i.empty)()},t.prototype.handles=function(){return this._root?this._root.iterHandles():Object(i.empty)()},t.prototype.moveHandle=function(e,t,n){var r=e.classList.contains("lm-mod-hidden");if(r=r||e.classList.contains("p-mod-hidden"),this._root&&!r){var i,o=this._root.findSplitNode(e);if(o)0!==(i="horizontal"===o.node.orientation?t-e.offsetLeft:n-e.offsetTop)&&(o.node.holdSizes(),y.adjust(o.node.sizers,o.index,i),this.parent&&this.parent.update())}},t.prototype.saveLayout=function(){return this._root?(this._root.holdAllSizes(),{main:this._root.createConfig()}):{main:null}},t.prototype.restoreLayout=function(e){var t,n=this,r=new Set;t=e.main?re.normalizeAreaConfig(e.main,r):null;var o=this.widgets(),a=this.tabBars(),s=this.handles();this._root=null,Object(i.each)(o,(function(e){r.has(e)||(e.parent=null)})),Object(i.each)(a,(function(e){e.dispose()})),Object(i.each)(s,(function(e){e.parentNode&&e.parentNode.removeChild(e)})),r.forEach((function(e){e.parent=n.parent})),this._root=t?re.realizeAreaConfig(t,{createTabBar:function(){return n._createTabBar()},createHandle:function(){return n._createHandle()}},this._document):null,this.parent&&(r.forEach((function(e){n.attachWidget(e)})),this.parent.fit())},t.prototype.addWidget=function(e,t){void 0===t&&(t={});var n=t.ref||null,r=t.mode||"tab-after",i=null;if(this._root&&n&&(i=this._root.findTabNode(n)),n&&!i)throw new Error("Reference widget is not in the layout.");switch(e.parent=this.parent,r){case"tab-after":this._insertTab(e,n,i,!0);break;case"tab-before":this._insertTab(e,n,i,!1);break;case"split-top":this._insertSplit(e,n,i,"vertical",!1);break;case"split-left":this._insertSplit(e,n,i,"horizontal",!1);break;case"split-right":this._insertSplit(e,n,i,"horizontal",!0);break;case"split-bottom":this._insertSplit(e,n,i,"vertical",!0)}this.parent&&(this.attachWidget(e),this.parent.fit())},t.prototype.removeWidget=function(e){this._removeWidget(e),this.parent&&(this.detachWidget(e),this.parent.fit())},t.prototype.hitTestTabAreas=function(e,t){if(!this._root||!this.parent||!this.parent.isVisible)return null;this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var n=this.parent.node.getBoundingClientRect(),r=e-n.left-this._box.borderLeft,i=t-n.top-this._box.borderTop,a=this._root.hitTestTabNodes(r,i);if(!a)return null;var s=a.tabBar,l=a.top,c=a.left,u=a.width,d=a.height,h=this._box.borderLeft+this._box.borderRight,p=this._box.borderTop+this._box.borderBottom;return{tabBar:s,x:r,y:i,top:l,left:c,right:n.width-h-(c+u),bottom:n.height-p-(l+d),width:u,height:d}},t.prototype.init=function(){var t=this;e.prototype.init.call(this),Object(i.each)(this,(function(e){t.attachWidget(e)})),Object(i.each)(this.handles(),(function(e){t.parent.node.appendChild(e)})),this.parent.fit()},t.prototype.attachWidget=function(e){this.parent.node!==e.node.parentNode&&(this._items.set(e,new L(e)),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeAttach),this.parent.node.appendChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterAttach))},t.prototype.detachWidget=function(e){if(this.parent.node===e.node.parentNode){this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeDetach),this.parent.node.removeChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterDetach);var t=this._items.get(e);t&&(this._items.delete(e),t.dispose())}},t.prototype.onBeforeShow=function(t){e.prototype.onBeforeShow.call(this,t),this.parent.update()},t.prototype.onBeforeAttach=function(t){e.prototype.onBeforeAttach.call(this,t),this.parent.fit()},t.prototype.onChildShown=function(e){this.parent.fit()},t.prototype.onChildHidden=function(e){this.parent.fit()},t.prototype.onResize=function(e){this.parent.isVisible&&this._update(e.width,e.height)},t.prototype.onUpdateRequest=function(e){this.parent.isVisible&&this._update(-1,-1)},t.prototype.onFitRequest=function(e){this.parent.isAttached&&this._fit()},t.prototype._removeWidget=function(e){if(this._root){var t=this._root.findTabNode(e);if(t)if(re.removeAria(e),t.tabBar.titles.length>1)t.tabBar.removeTab(e.title),this._hiddenMode===A.HiddenMode.Scale&&1==t.tabBar.titles.length&&(t.tabBar.titles[0].owner.hiddenMode=A.HiddenMode.Display);else if(t.tabBar.dispose(),this._root!==t){this._root.holdAllSizes();var n=t.parent;t.parent=null;var r=i.ArrayExt.removeFirstOf(n.children,t),o=i.ArrayExt.removeAt(n.handles,r);if(i.ArrayExt.removeAt(n.sizers,r),o.parentNode&&o.parentNode.removeChild(o),n.children.length>1)n.syncHandles();else{var a=n.parent;n.parent=null;var s=n.children[0],l=n.handles[0];if(n.children.length=0,n.handles.length=0,n.sizers.length=0,l.parentNode&&l.parentNode.removeChild(l),this._root===n)return s.parent=null,void(this._root=s);var c=a,u=c.children.indexOf(n);if(s instanceof re.TabLayoutNode)return s.parent=c,void(c.children[u]=s);var d=i.ArrayExt.removeAt(c.handles,u);i.ArrayExt.removeAt(c.children,u),i.ArrayExt.removeAt(c.sizers,u),d.parentNode&&d.parentNode.removeChild(d);for(var h=0,p=s.children.length;h<p;++h){var f=s.children[h],m=s.handles[h],g=s.sizers[h];i.ArrayExt.insert(c.children,u+h,f),i.ArrayExt.insert(c.handles,u+h,m),i.ArrayExt.insert(c.sizers,u+h,g),f.parent=c}s.children.length=0,s.handles.length=0,s.sizers.length=0,s.parent=null,c.syncHandles()}}else this._root=null}},t.prototype._insertTab=function(e,t,n,r){if(e!==t){if(!this._root){var i=new re.TabLayoutNode(this._createTabBar());return i.tabBar.addTab(e.title),this._root=i,void re.addAria(e,i.tabBar)}var o;if(n||(n=this._root.findFirstTabNode()),-1===n.tabBar.titles.indexOf(e.title)&&(this._removeWidget(e),e.hide()),o=t?n.tabBar.titles.indexOf(t.title):n.tabBar.currentIndex,this._hiddenMode===A.HiddenMode.Scale&&n.tabBar.titles.length>0){if(1==n.tabBar.titles.length)n.tabBar.titles[0].owner.hiddenMode=A.HiddenMode.Scale;e.hiddenMode=A.HiddenMode.Scale}else e.hiddenMode=A.HiddenMode.Display;n.tabBar.insertTab(o+(r?1:0),e.title),re.addAria(e,n.tabBar)}},t.prototype._insertSplit=function(e,t,n,r,o){if(e!==t||!n||1!==n.tabBar.titles.length){this._removeWidget(e);var a=new re.TabLayoutNode(this._createTabBar());if(a.tabBar.addTab(e.title),re.addAria(e,a.tabBar),this._root){if(!n||!n.parent){var s=this._splitRoot(r),l=o?s.children.length:0;s.normalizeSizes();var c=re.createSizer(n?1:re.GOLDEN_RATIO);return i.ArrayExt.insert(s.children,l,a),i.ArrayExt.insert(s.sizers,l,c),i.ArrayExt.insert(s.handles,l,this._createHandle()),a.parent=s,s.normalizeSizes(),void s.syncHandles()}var u=n.parent;if(u.orientation===r){var d=u.children.indexOf(n);u.normalizeSizes();var h=u.sizers[d].sizeHint/=2,p=d+(o?1:0);return i.ArrayExt.insert(u.children,p,a),i.ArrayExt.insert(u.sizers,p,re.createSizer(h)),i.ArrayExt.insert(u.handles,p,this._createHandle()),a.parent=u,void u.syncHandles()}var f=i.ArrayExt.removeFirstOf(u.children,n),m=new re.SplitLayoutNode(r);m.normalized=!0,m.children.push(n),m.sizers.push(re.createSizer(.5)),m.handles.push(this._createHandle()),n.parent=m;var g=o?1:0;i.ArrayExt.insert(m.children,g,a),i.ArrayExt.insert(m.sizers,g,re.createSizer(.5)),i.ArrayExt.insert(m.handles,g,this._createHandle()),a.parent=m,m.syncHandles(),i.ArrayExt.insert(u.children,f,m),m.parent=u}else this._root=a}},t.prototype._splitRoot=function(e){var t=this._root;if(t instanceof re.SplitLayoutNode&&t.orientation===e)return t;var n=this._root=new re.SplitLayoutNode(e);return t&&(n.children.push(t),n.sizers.push(re.createSizer(0)),n.handles.push(this._createHandle()),t.parent=n),n},t.prototype._fit=function(){var e=0,t=0;if(this._root){var n=this._root.fit(this._spacing,this._items);e=n.minWidth,t=n.minHeight}var r=this._box=o.ElementExt.boxSizing(this.parent.node);e+=r.horizontalSum,t+=r.verticalSum;var i=this.parent.node.style;i.minWidth=e+"px",i.minHeight=t+"px",this._dirty=!0,this.parent.parent&&a.c.sendMessage(this.parent.parent,A.Msg.FitRequest),this._dirty&&a.c.sendMessage(this.parent,A.Msg.UpdateRequest)},t.prototype._update=function(e,t){if(this._dirty=!1,this._root){e<0&&(e=this.parent.node.offsetWidth),t<0&&(t=this.parent.node.offsetHeight),this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var n=this._box.paddingTop,r=this._box.paddingLeft,i=e-this._box.horizontalSum,a=t-this._box.verticalSum;this._root.update(n,r,i,a,this._spacing,this._items)}},t.prototype._createTabBar=function(){var e=this.renderer.createTabBar(this._document);return e.orientation="horizontal",this.parent&&(e.parent=this.parent,this.attachWidget(e)),e},t.prototype._createHandle=function(){var e=this.renderer.createHandle(),t=e.style;return t.position="absolute",t.top="0",t.left="0",t.width="0",t.height="0",this.parent&&this.parent.node.appendChild(e),e},t}(x);!function(e){function t(e){var t=new _;return t.sizeHint=e,t.size=e,t}function n(e,t){return"tab-area"===e.type?function(e,t){if(0===e.widgets.length)return null;var n=[];if(Object(i.each)(e.widgets,(function(e){t.has(e)||(t.add(e),n.push(e))})),0===n.length)return null;var r=e.currentIndex;-1!==r&&(r<0||r>=n.length)&&(r=0);return{type:"tab-area",widgets:n,currentIndex:r}}(e,t):function(e,t){for(var r=e.orientation,i=[],o=[],a=0,s=e.children.length;a<s;++a){var l=n(e.children[a],t);l&&("tab-area"===l.type||l.orientation!==r?(i.push(l),o.push(Math.abs(e.sizes[a]||0))):(i.push.apply(i,l.children),o.push.apply(o,l.sizes)))}if(0===i.length)return null;if(1===i.length)return i[0];return{type:"split-area",orientation:r,children:i,sizes:o}}(e,t)}function r(n,s,l){return"tab-area"===n.type?function(t,n,r){var a=n.createTabBar(r);return Object(i.each)(t.widgets,(function(t){t.hide(),a.addTab(t.title),e.addAria(t,a)})),a.currentIndex=t.currentIndex,new o(a)}(n,s,l):function(e,n,o){var s=new a(e.orientation);return Object(i.each)(e.children,(function(i,a){var l=r(i,n,o),c=t(e.sizes[a]),u=n.createHandle();s.children.push(l),s.handles.push(u),s.sizers.push(c),l.parent=s})),s.syncHandles(),s.normalizeSizes(),s}(n,s,l)}e.GOLDEN_RATIO=.618,e.createSizer=t,e.normalizeAreaConfig=n,e.realizeAreaConfig=r;var o=function(){function e(e){this.parent=null,this._top=0,this._left=0,this._width=0,this._height=0;var t=new _,n=new _;t.stretch=0,n.stretch=1,this.tabBar=e,this.sizers=[t,n]}return Object.defineProperty(e.prototype,"top",{get:function(){return this._top},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"left",{get:function(){return this._left},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"width",{get:function(){return this._width},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"height",{get:function(){return this._height},enumerable:!0,configurable:!0}),e.prototype.iterAllWidgets=function(){return Object(i.chain)(Object(i.once)(this.tabBar),this.iterUserWidgets())},e.prototype.iterUserWidgets=function(){return Object(i.map)(this.tabBar.titles,(function(e){return e.owner}))},e.prototype.iterSelectedWidgets=function(){var e=this.tabBar.currentTitle;return e?Object(i.once)(e.owner):Object(i.empty)()},e.prototype.iterTabBars=function(){return Object(i.once)(this.tabBar)},e.prototype.iterHandles=function(){return Object(i.empty)()},e.prototype.findTabNode=function(e){return-1!==this.tabBar.titles.indexOf(e.title)?this:null},e.prototype.findSplitNode=function(e){return null},e.prototype.findFirstTabNode=function(){return this},e.prototype.hitTestTabNodes=function(e,t){return e<this._left||e>=this._left+this._width||t<this._top||t>=this._top+this._height?null:this},e.prototype.createConfig=function(){return{type:"tab-area",widgets:this.tabBar.titles.map((function(e){return e.owner})),currentIndex:this.tabBar.currentIndex}},e.prototype.holdAllSizes=function(){},e.prototype.fit=function(e,t){var n=0,r=0,i=t.get(this.tabBar),o=this.tabBar.currentTitle,a=o?t.get(o.owner):void 0,s=this.sizers,l=s[0],c=s[1];return i&&i.fit(),a&&a.fit(),i&&!i.isHidden?(n=Math.max(n,i.minWidth),r+=i.minHeight,l.minSize=i.minHeight,l.maxSize=i.maxHeight):(l.minSize=0,l.maxSize=0),a&&!a.isHidden?(n=Math.max(n,a.minWidth),r+=a.minHeight,c.minSize=a.minHeight,c.maxSize=1/0):(c.minSize=0,c.maxSize=1/0),{minWidth:n,minHeight:r,maxWidth:1/0,maxHeight:1/0}},e.prototype.update=function(e,t,n,r,i,o){this._top=t,this._left=e,this._width=n,this._height=r;var a=o.get(this.tabBar),s=this.tabBar.currentTitle,l=s?o.get(s.owner):void 0;if(y.calc(this.sizers,r),a&&!a.isHidden){var c=this.sizers[0].size;a.update(e,t,n,c),t+=c}if(l&&!l.isHidden){c=this.sizers[1].size;l.update(e,t,n,c)}},e}();e.TabLayoutNode=o;var a=function(){function e(e){this.parent=null,this.normalized=!1,this.children=[],this.sizers=[],this.handles=[],this.orientation=e}return e.prototype.iterAllWidgets=function(){var e=Object(i.map)(this.children,(function(e){return e.iterAllWidgets()}));return new i.ChainIterator(e)},e.prototype.iterUserWidgets=function(){var e=Object(i.map)(this.children,(function(e){return e.iterUserWidgets()}));return new i.ChainIterator(e)},e.prototype.iterSelectedWidgets=function(){var e=Object(i.map)(this.children,(function(e){return e.iterSelectedWidgets()}));return new i.ChainIterator(e)},e.prototype.iterTabBars=function(){var e=Object(i.map)(this.children,(function(e){return e.iterTabBars()}));return new i.ChainIterator(e)},e.prototype.iterHandles=function(){var e=Object(i.map)(this.children,(function(e){return e.iterHandles()}));return Object(i.chain)(this.handles,new i.ChainIterator(e))},e.prototype.findTabNode=function(e){for(var t=0,n=this.children.length;t<n;++t){var r=this.children[t].findTabNode(e);if(r)return r}return null},e.prototype.findSplitNode=function(e){var t=this.handles.indexOf(e);if(-1!==t)return{index:t,node:this};for(var n=0,r=this.children.length;n<r;++n){var i=this.children[n].findSplitNode(e);if(i)return i}return null},e.prototype.findFirstTabNode=function(){return 0===this.children.length?null:this.children[0].findFirstTabNode()},e.prototype.hitTestTabNodes=function(e,t){for(var n=0,r=this.children.length;n<r;++n){var i=this.children[n].hitTestTabNodes(e,t);if(i)return i}return null},e.prototype.createConfig=function(){var e=this.orientation,t=this.createNormalizedSizes();return{type:"split-area",orientation:e,children:this.children.map((function(e){return e.createConfig()})),sizes:t}},e.prototype.syncHandles=function(){var e=this;Object(i.each)(this.handles,(function(t,n){t.setAttribute("data-orientation",e.orientation),n===e.handles.length-1?(t.classList.add("lm-mod-hidden"),t.classList.add("p-mod-hidden")):(t.classList.remove("lm-mod-hidden"),t.classList.remove("p-mod-hidden"))}))},e.prototype.holdSizes=function(){Object(i.each)(this.sizers,(function(e){e.sizeHint=e.size}))},e.prototype.holdAllSizes=function(){Object(i.each)(this.children,(function(e){return e.holdAllSizes()})),this.holdSizes()},e.prototype.normalizeSizes=function(){var e=this.sizers.length;if(0!==e){this.holdSizes();var t=Object(i.reduce)(this.sizers,(function(e,t){return e+t.sizeHint}),0);0===t?Object(i.each)(this.sizers,(function(t){t.size=t.sizeHint=1/e})):Object(i.each)(this.sizers,(function(e){e.size=e.sizeHint/=t})),this.normalized=!0}},e.prototype.createNormalizedSizes=function(){var e=this.sizers.length;if(0===e)return[];var t=this.sizers.map((function(e){return e.size})),n=Object(i.reduce)(t,(function(e,t){return e+t}),0);return 0===n?Object(i.each)(t,(function(n,r){t[r]=1/e})):Object(i.each)(t,(function(e,r){t[r]=e/n})),t},e.prototype.fit=function(e,t){for(var n="horizontal"===this.orientation,r=Math.max(0,this.children.length-1)*e,i=n?r:0,o=n?0:r,a=0,s=this.children.length;a<s;++a){var l=this.children[a].fit(e,t);n?(o=Math.max(o,l.minHeight),i+=l.minWidth,this.sizers[a].minSize=l.minWidth):(i=Math.max(i,l.minWidth),o+=l.minHeight,this.sizers[a].minSize=l.minHeight)}return{minWidth:i,minHeight:o,maxWidth:1/0,maxHeight:1/0}},e.prototype.update=function(e,t,n,r,o,a){var s="horizontal"===this.orientation,l=Math.max(0,this.children.length-1)*o,c=Math.max(0,(s?n:r)-l);this.normalized&&(Object(i.each)(this.sizers,(function(e){e.sizeHint*=c})),this.normalized=!1),y.calc(this.sizers,c);for(var u=0,d=this.children.length;u<d;++u){var h=this.children[u],p=this.sizers[u].size,f=this.handles[u].style;s?(h.update(e,t,p,r,o,a),e+=p,f.top=t+"px",f.left=e+"px",f.width=o+"px",f.height=r+"px",e+=o):(h.update(e,t,n,p,o,a),t+=p,f.top=t+"px",f.left=e+"px",f.width=n+"px",f.height=o+"px",t+=o)}},e}();e.SplitLayoutNode=a,e.addAria=function(e,t){e.node.setAttribute("role","tabpanel");var n=t.renderer;if(n instanceof ne.Renderer){var r=n.createTabKey({title:e.title,current:!1,zIndex:0});e.node.setAttribute("aria-labelledby",r)}},e.removeAria=function(e){e.node.removeAttribute("role"),e.node.removeAttribute("aria-labelledby")}}(re||(re={}));var oe,ae=function(e){function t(n){void 0===n&&(n={});var r=e.call(this)||this;r._drag=null,r._tabsMovable=!0,r._tabsConstrained=!1,r._addButtonEnabled=!1,r._pressData=null,r._layoutModified=new l.Signal(r),r._addRequested=new l.Signal(r),r.addClass("lm-DockPanel"),r.addClass("p-DockPanel"),r._document=n.document||document,r._mode=n.mode||"multiple-document",r._renderer=n.renderer||t.defaultRenderer,r._edges=n.edges||oe.DEFAULT_EDGES,void 0!==n.tabsMovable&&(r._tabsMovable=n.tabsMovable),void 0!==n.tabsConstrained&&(r._tabsConstrained=n.tabsConstrained),void 0!==n.addButtonEnabled&&(r._addButtonEnabled=n.addButtonEnabled),r.dataset.mode=r._mode;var i={createTabBar:function(){return r._createTabBar()},createHandle:function(){return r._createHandle()}};return r.layout=new ie({document:r._document,renderer:i,spacing:n.spacing,hiddenMode:n.hiddenMode}),r.overlay=n.overlay||new t.Overlay,r.node.appendChild(r.overlay.node),r}return g(t,e),t.prototype.dispose=function(){this._releaseMouse(),this.overlay.hide(0),this._drag&&this._drag.dispose(),e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"hiddenMode",{get:function(){return this.layout.hiddenMode},set:function(e){this.layout.hiddenMode=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"layoutModified",{get:function(){return this._layoutModified},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addRequested",{get:function(){return this._addRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"renderer",{get:function(){return this.layout.renderer},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"spacing",{get:function(){return this.layout.spacing},set:function(e){this.layout.spacing=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"mode",{get:function(){return this._mode},set:function(e){if(this._mode!==e){this._mode=e,this.dataset.mode=e;var t=this.layout;switch(e){case"multiple-document":Object(i.each)(t.tabBars(),(function(e){e.show()}));break;case"single-document":t.restoreLayout(oe.createSingleDocumentConfig(this));break;default:throw"unreachable"}a.c.postMessage(this,oe.LayoutModified)}},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabsMovable",{get:function(){return this._tabsMovable},set:function(e){this._tabsMovable=e,Object(i.each)(this.tabBars(),(function(t){t.tabsMovable=e}))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabsConstrained",{get:function(){return this._tabsConstrained},set:function(e){this._tabsConstrained=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addButtonEnabled",{get:function(){return this._addButtonEnabled},set:function(e){this._addButtonEnabled=e,Object(i.each)(this.tabBars(),(function(t){t.addButtonEnabled=e}))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"isEmpty",{get:function(){return this.layout.isEmpty},enumerable:!0,configurable:!0}),t.prototype.widgets=function(){return this.layout.widgets()},t.prototype.selectedWidgets=function(){return this.layout.selectedWidgets()},t.prototype.tabBars=function(){return this.layout.tabBars()},t.prototype.handles=function(){return this.layout.handles()},t.prototype.selectWidget=function(e){var t=Object(i.find)(this.tabBars(),(function(t){return-1!==t.titles.indexOf(e.title)}));if(!t)throw new Error("Widget is not contained in the dock panel.");t.currentTitle=e.title},t.prototype.activateWidget=function(e){this.selectWidget(e),e.activate()},t.prototype.saveLayout=function(){return this.layout.saveLayout()},t.prototype.restoreLayout=function(e){this._mode="multiple-document",this.layout.restoreLayout(e),(o.Platform.IS_EDGE||o.Platform.IS_IE)&&a.c.flush(),a.c.postMessage(this,oe.LayoutModified)},t.prototype.addWidget=function(e,t){void 0===t&&(t={}),"single-document"===this._mode?this.layout.addWidget(e):this.layout.addWidget(e,t),a.c.postMessage(this,oe.LayoutModified)},t.prototype.processMessage=function(t){"layout-modified"===t.type?this._layoutModified.emit(void 0):e.prototype.processMessage.call(this,t)},t.prototype.handleEvent=function(e){switch(e.type){case"lm-dragenter":this._evtDragEnter(e);break;case"lm-dragleave":this._evtDragLeave(e);break;case"lm-dragover":this._evtDragOver(e);break;case"lm-drop":this._evtDrop(e);break;case"mousedown":this._evtMouseDown(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseup":this._evtMouseUp(e);break;case"pointerdown":this._evtMouseDown(e);break;case"pointermove":this._evtMouseMove(e);break;case"pointerup":this._evtMouseUp(e);break;case"keydown":this._evtKeyDown(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("lm-dragenter",this),this.node.addEventListener("lm-dragleave",this),this.node.addEventListener("lm-dragover",this),this.node.addEventListener("lm-drop",this),this.node.addEventListener("mousedown",this),this.node.addEventListener("pointerdown",this)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("lm-dragenter",this),this.node.removeEventListener("lm-dragleave",this),this.node.removeEventListener("lm-dragover",this),this.node.removeEventListener("lm-drop",this),this.node.removeEventListener("mousedown",this),this.node.removeEventListener("pointerdown",this),this._releaseMouse()},t.prototype.onChildAdded=function(e){oe.isGeneratedTabBarProperty.get(e.child)||(e.child.addClass("lm-DockPanel-widget"),e.child.addClass("p-DockPanel-widget"))},t.prototype.onChildRemoved=function(e){oe.isGeneratedTabBarProperty.get(e.child)||(e.child.removeClass("lm-DockPanel-widget"),e.child.removeClass("p-DockPanel-widget"),a.c.postMessage(this,oe.LayoutModified))},t.prototype._evtDragEnter=function(e){e.mimeData.hasData("application/vnd.lumino.widget-factory")&&(e.preventDefault(),e.stopPropagation())},t.prototype._evtDragLeave=function(e){e.preventDefault(),e.stopPropagation(),this.overlay.hide(1)},t.prototype._evtDragOver=function(e){e.preventDefault(),e.stopPropagation(),this._tabsConstrained&&e.source!==this||"invalid"===this._showOverlay(e.clientX,e.clientY)?e.dropAction="none":e.dropAction=e.proposedAction},t.prototype._evtDrop=function(e){if(e.preventDefault(),e.stopPropagation(),this.overlay.hide(0),"none"!==e.proposedAction){var t=e.clientX,n=e.clientY,r=oe.findDropTarget(this,t,n,this._edges),i=r.zone,o=r.target;if("invalid"!==i){var a=e.mimeData.getData("application/vnd.lumino.widget-factory");if("function"==typeof a){var s=a();if(s instanceof A)if(s.contains(this))e.dropAction="none";else{var l=o?oe.getDropRef(o.tabBar):null;switch(i){case"root-all":this.addWidget(s);break;case"root-top":this.addWidget(s,{mode:"split-top"});break;case"root-left":this.addWidget(s,{mode:"split-left"});break;case"root-right":this.addWidget(s,{mode:"split-right"});break;case"root-bottom":this.addWidget(s,{mode:"split-bottom"});break;case"widget-all":this.addWidget(s,{mode:"tab-after",ref:l});break;case"widget-top":this.addWidget(s,{mode:"split-top",ref:l});break;case"widget-left":this.addWidget(s,{mode:"split-left",ref:l});break;case"widget-right":this.addWidget(s,{mode:"split-right",ref:l});break;case"widget-bottom":this.addWidget(s,{mode:"split-bottom",ref:l});break;case"widget-tab":this.addWidget(s,{mode:"tab-after",ref:l});break;default:throw"unreachable"}e.dropAction=e.proposedAction,this.activateWidget(s)}else e.dropAction="none"}else e.dropAction="none"}else e.dropAction="none"}else e.dropAction="none"},t.prototype._evtKeyDown=function(e){e.preventDefault(),e.stopPropagation(),27===e.keyCode&&(this._releaseMouse(),a.c.postMessage(this,oe.LayoutModified))},t.prototype._evtMouseDown=function(e){if(0===e.button){var t=this.layout,n=e.target,r=Object(i.find)(t.handles(),(function(e){return e.contains(n)}));if(r){e.preventDefault(),e.stopPropagation(),this._document.addEventListener("keydown",this,!0),this._document.addEventListener("mouseup",this,!0),this._document.addEventListener("mousemove",this,!0),this._document.addEventListener("pointerup",this,!0),this._document.addEventListener("pointermove",this,!0),this._document.addEventListener("contextmenu",this,!0);var o=r.getBoundingClientRect(),a=e.clientX-o.left,s=e.clientY-o.top,l=window.getComputedStyle(r),c=u.overrideCursor(l.cursor,this._document);this._pressData={handle:r,deltaX:a,deltaY:s,override:c}}}},t.prototype._evtMouseMove=function(e){if(this._pressData){e.preventDefault(),e.stopPropagation();var t=this.node.getBoundingClientRect(),n=e.clientX-t.left-this._pressData.deltaX,r=e.clientY-t.top-this._pressData.deltaY;this.layout.moveHandle(this._pressData.handle,n,r)}},t.prototype._evtMouseUp=function(e){0===e.button&&(e.preventDefault(),e.stopPropagation(),this._releaseMouse(),a.c.postMessage(this,oe.LayoutModified))},t.prototype._releaseMouse=function(){this._pressData&&(this._pressData.override.dispose(),this._pressData=null,this._document.removeEventListener("keydown",this,!0),this._document.removeEventListener("mouseup",this,!0),this._document.removeEventListener("mousemove",this,!0),this._document.removeEventListener("pointerup",this,!0),this._document.removeEventListener("pointermove",this,!0),this._document.removeEventListener("contextmenu",this,!0))},t.prototype._showOverlay=function(e,t){var n,r,i,a,s=oe.findDropTarget(this,e,t,this._edges),l=s.zone,c=s.target;if("invalid"===l)return this.overlay.hide(100),l;var u=o.ElementExt.boxSizing(this.node),d=this.node.getBoundingClientRect();switch(l){case"root-all":n=u.paddingTop,r=u.paddingLeft,i=u.paddingRight,a=u.paddingBottom;break;case"root-top":n=u.paddingTop,r=u.paddingLeft,i=u.paddingRight,a=d.height*oe.GOLDEN_RATIO;break;case"root-left":n=u.paddingTop,r=u.paddingLeft,i=d.width*oe.GOLDEN_RATIO,a=u.paddingBottom;break;case"root-right":n=u.paddingTop,r=d.width*oe.GOLDEN_RATIO,i=u.paddingRight,a=u.paddingBottom;break;case"root-bottom":n=d.height*oe.GOLDEN_RATIO,r=u.paddingLeft,i=u.paddingRight,a=u.paddingBottom;break;case"widget-all":n=c.top,r=c.left,i=c.right,a=c.bottom;break;case"widget-top":n=c.top,r=c.left,i=c.right,a=c.bottom+c.height/2;break;case"widget-left":n=c.top,r=c.left,i=c.right+c.width/2,a=c.bottom;break;case"widget-right":n=c.top,r=c.left+c.width/2,i=c.right,a=c.bottom;break;case"widget-bottom":n=c.top+c.height/2,r=c.left,i=c.right,a=c.bottom;break;case"widget-tab":var h=c.tabBar.node.getBoundingClientRect().height;n=c.top,r=c.left,i=c.right,a=c.bottom+c.height-h;break;default:throw"unreachable"}return this.overlay.show({top:n,left:r,right:i,bottom:a}),l},t.prototype._createTabBar=function(){var e=this._renderer.createTabBar(this._document);return oe.isGeneratedTabBarProperty.set(e,!0),"single-document"===this._mode&&e.hide(),e.tabsMovable=this._tabsMovable,e.allowDeselect=!1,e.addButtonEnabled=this._addButtonEnabled,e.removeBehavior="select-previous-tab",e.insertBehavior="select-tab-if-needed",e.tabMoved.connect(this._onTabMoved,this),e.currentChanged.connect(this._onCurrentChanged,this),e.tabCloseRequested.connect(this._onTabCloseRequested,this),e.tabDetachRequested.connect(this._onTabDetachRequested,this),e.tabActivateRequested.connect(this._onTabActivateRequested,this),e.addRequested.connect(this._onTabAddRequested,this),e},t.prototype._createHandle=function(){return this._renderer.createHandle()},t.prototype._onTabMoved=function(){a.c.postMessage(this,oe.LayoutModified)},t.prototype._onCurrentChanged=function(e,t){var n=t.previousTitle,r=t.currentTitle;n&&n.owner.hide(),r&&r.owner.show(),(o.Platform.IS_EDGE||o.Platform.IS_IE)&&a.c.flush(),a.c.postMessage(this,oe.LayoutModified)},t.prototype._onTabAddRequested=function(e){this._addRequested.emit(e)},t.prototype._onTabActivateRequested=function(e,t){t.title.owner.activate()},t.prototype._onTabCloseRequested=function(e,t){t.title.owner.close()},t.prototype._onTabDetachRequested=function(e,t){var n=this;if(!this._drag){e.releaseMouse();var r=t.title,i=t.tab,o=t.clientX,a=t.clientY,s=new d.MimeData;s.setData("application/vnd.lumino.widget-factory",(function(){return r.owner}));var l=i.cloneNode(!0);this._drag=new u({document:this._document,mimeData:s,dragImage:l,proposedAction:"move",supportedActions:"move",source:this}),i.classList.add("lm-mod-hidden"),i.classList.add("p-mod-hidden");this._drag.start(o,a).then((function(){n._drag=null,i.classList.remove("lm-mod-hidden"),i.classList.remove("p-mod-hidden")}))}},t}(A);!function(e){var t=function(){function e(){this._timer=-1,this._hidden=!0,this.node=document.createElement("div"),this.node.classList.add("lm-DockPanel-overlay"),this.node.classList.add("lm-mod-hidden"),this.node.classList.add("p-DockPanel-overlay"),this.node.classList.add("p-mod-hidden"),this.node.style.position="absolute"}return e.prototype.show=function(e){var t=this.node.style;t.top=e.top+"px",t.left=e.left+"px",t.right=e.right+"px",t.bottom=e.bottom+"px",clearTimeout(this._timer),this._timer=-1,this._hidden&&(this._hidden=!1,this.node.classList.remove("lm-mod-hidden"),this.node.classList.remove("p-mod-hidden"))},e.prototype.hide=function(e){var t=this;if(!this._hidden)return e<=0?(clearTimeout(this._timer),this._timer=-1,this._hidden=!0,this.node.classList.add("lm-mod-hidden"),void this.node.classList.add("p-mod-hidden")):void(-1===this._timer&&(this._timer=window.setTimeout((function(){t._timer=-1,t._hidden=!0,t.node.classList.add("lm-mod-hidden"),t.node.classList.add("p-mod-hidden")}),e)))},e}();e.Overlay=t;var n=function(){function e(){}return e.prototype.createTabBar=function(e){var t=new ne({document:e});return t.addClass("lm-DockPanel-tabBar"),t.addClass("p-DockPanel-tabBar"),t},e.prototype.createHandle=function(){var e=document.createElement("div");return e.className="lm-DockPanel-handle",e.classList.add("p-DockPanel-handle"),e},e}();e.Renderer=n,e.defaultRenderer=new n}(ae||(ae={})),function(e){e.GOLDEN_RATIO=.618,e.DEFAULT_EDGES={top:12,right:40,bottom:40,left:40},e.LayoutModified=new a.a("layout-modified"),e.isGeneratedTabBarProperty=new s.AttachedProperty({name:"isGeneratedTabBar",create:function(){return!1}}),e.createSingleDocumentConfig=function(e){if(e.isEmpty)return{main:null};var t=Object(i.toArray)(e.widgets()),n=e.selectedWidgets().next(),r=n?t.indexOf(n):-1;return{main:{type:"tab-area",widgets:t,currentIndex:r}}},e.findDropTarget=function(e,t,n,r){if(!o.ElementExt.hitTest(e.node,t,n))return{zone:"invalid",target:null};var i=e.layout;if(i.isEmpty)return{zone:"root-all",target:null};if("multiple-document"===e.mode){var a=e.node.getBoundingClientRect(),s=t-a.left+1,l=n-a.top+1,c=a.right-t,u=a.bottom-n;switch(Math.min(l,c,u,s)){case l:if(l<r.top)return{zone:"root-top",target:null};break;case c:if(c<r.right)return{zone:"root-right",target:null};break;case u:if(u<r.bottom)return{zone:"root-bottom",target:null};break;case s:if(s<r.left)return{zone:"root-left",target:null};break;default:throw"unreachable"}}var d=i.hitTestTabAreas(t,n);if(!d)return{zone:"invalid",target:null};if("single-document"===e.mode)return{zone:"widget-all",target:d};var h=d.x-d.left+1,p=d.y-d.top+1,f=d.left+d.width-d.x,m=d.top+d.height-d.y;if(p<d.tabBar.node.getBoundingClientRect().height)return{zone:"widget-tab",target:d};var g,v=Math.round(d.width/3),y=Math.round(d.height/3);if(h>v&&f>v&&p>y&&m>y)return{zone:"widget-all",target:d};switch(h/=v,p/=y,f/=v,m/=y,Math.min(h,p,f,m)){case h:g="widget-left";break;case p:g="widget-top";break;case f:g="widget-right";break;case m:g="widget-bottom";break;default:throw"unreachable"}return{zone:g,target:d}},e.getDropRef=function(e){return 0===e.titles.length?null:e.currentTitle?e.currentTitle.owner:e.titles[e.titles.length-1].owner}}(oe||(oe={}));var se,le,ce=function(){function e(){this._counter=0,this._widgets=[],this._activeWidget=null,this._currentWidget=null,this._numbers=new Map,this._nodes=new Map,this._activeChanged=new l.Signal(this),this._currentChanged=new l.Signal(this)}return e.prototype.dispose=function(){var e=this;this._counter<0||(this._counter=-1,l.Signal.clearData(this),Object(i.each)(this._widgets,(function(t){t.node.removeEventListener("focus",e,!0),t.node.removeEventListener("blur",e,!0)})),this._activeWidget=null,this._currentWidget=null,this._nodes.clear(),this._numbers.clear(),this._widgets.length=0)},Object.defineProperty(e.prototype,"currentChanged",{get:function(){return this._currentChanged},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"activeChanged",{get:function(){return this._activeChanged},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this._counter<0},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"currentWidget",{get:function(){return this._currentWidget},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"activeWidget",{get:function(){return this._activeWidget},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"widgets",{get:function(){return this._widgets},enumerable:!0,configurable:!0}),e.prototype.focusNumber=function(e){var t=this._numbers.get(e);return void 0===t?-1:t},e.prototype.has=function(e){return this._numbers.has(e)},e.prototype.add=function(e){if(!this._numbers.has(e)){var t=e.node.contains(document.activeElement),n=t?this._counter++:-1;this._widgets.push(e),this._numbers.set(e,n),this._nodes.set(e.node,e),e.node.addEventListener("focus",this,!0),e.node.addEventListener("blur",this,!0),e.disposed.connect(this._onWidgetDisposed,this),t&&this._setWidgets(e,e)}},e.prototype.remove=function(e){var t=this;if(this._numbers.has(e)&&(e.disposed.disconnect(this._onWidgetDisposed,this),e.node.removeEventListener("focus",this,!0),e.node.removeEventListener("blur",this,!0),i.ArrayExt.removeFirstOf(this._widgets,e),this._nodes.delete(e.node),this._numbers.delete(e),this._currentWidget===e)){var n=Object(i.filter)(this._widgets,(function(e){return-1!==t._numbers.get(e)})),r=Object(i.max)(n,(function(e,n){return t._numbers.get(e)-t._numbers.get(n)}))||null;this._setWidgets(r,null)}},e.prototype.handleEvent=function(e){switch(e.type){case"focus":this._evtFocus(e);break;case"blur":this._evtBlur(e)}},e.prototype._setWidgets=function(e,t){var n=this._currentWidget;this._currentWidget=e;var r=this._activeWidget;this._activeWidget=t,n!==e&&this._currentChanged.emit({oldValue:n,newValue:e}),r!==t&&this._activeChanged.emit({oldValue:r,newValue:t})},e.prototype._evtFocus=function(e){var t=this._nodes.get(e.currentTarget);t!==this._currentWidget&&this._numbers.set(t,this._counter++),this._setWidgets(t,t)},e.prototype._evtBlur=function(e){var t=this._nodes.get(e.currentTarget),n=e.relatedTarget;n&&(t.node.contains(n)||Object(i.find)(this._widgets,(function(e){return e.node.contains(n)})))||this._setWidgets(this._currentWidget,null)},e.prototype._onWidgetDisposed=function(e){this.remove(e)},e}(),ue=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,t)||this;return n._dirty=!1,n._rowSpacing=4,n._columnSpacing=4,n._items=[],n._rowStarts=[],n._columnStarts=[],n._rowSizers=[new _],n._columnSizers=[new _],n._box=null,void 0!==t.rowCount&&le.reallocSizers(n._rowSizers,t.rowCount),void 0!==t.columnCount&&le.reallocSizers(n._columnSizers,t.columnCount),void 0!==t.rowSpacing&&(n._rowSpacing=le.clampValue(t.rowSpacing)),void 0!==t.columnSpacing&&(n._columnSpacing=le.clampValue(t.columnSpacing)),n}return g(t,e),t.prototype.dispose=function(){Object(i.each)(this._items,(function(e){var t=e.widget;e.dispose(),t.dispose()})),this._box=null,this._items.length=0,this._rowStarts.length=0,this._rowSizers.length=0,this._columnStarts.length=0,this._columnSizers.length=0,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"rowCount",{get:function(){return this._rowSizers.length},set:function(e){e!==this.rowCount&&(le.reallocSizers(this._rowSizers,e),this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"columnCount",{get:function(){return this._columnSizers.length},set:function(e){e!==this.columnCount&&(le.reallocSizers(this._columnSizers,e),this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"rowSpacing",{get:function(){return this._rowSpacing},set:function(e){e=le.clampValue(e),this._rowSpacing!==e&&(this._rowSpacing=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"columnSpacing",{get:function(){return this._columnSpacing},set:function(e){e=le.clampValue(e),this._columnSpacing!==e&&(this._columnSpacing=e,this.parent&&this.parent.fit())},enumerable:!0,configurable:!0}),t.prototype.rowStretch=function(e){var t=this._rowSizers[e];return t?t.stretch:-1},t.prototype.setRowStretch=function(e,t){var n=this._rowSizers[e];n&&(t=le.clampValue(t),n.stretch!==t&&(n.stretch=t,this.parent&&this.parent.update()))},t.prototype.columnStretch=function(e){var t=this._columnSizers[e];return t?t.stretch:-1},t.prototype.setColumnStretch=function(e,t){var n=this._columnSizers[e];n&&(t=le.clampValue(t),n.stretch!==t&&(n.stretch=t,this.parent&&this.parent.update()))},t.prototype.iter=function(){return Object(i.map)(this._items,(function(e){return e.widget}))},t.prototype.addWidget=function(e){-1===i.ArrayExt.findFirstIndex(this._items,(function(t){return t.widget===e}))&&(this._items.push(new L(e)),this.parent&&this.attachWidget(e))},t.prototype.removeWidget=function(e){var t=i.ArrayExt.findFirstIndex(this._items,(function(t){return t.widget===e}));if(-1!==t){var n=i.ArrayExt.removeAt(this._items,t);this.parent&&this.detachWidget(e),n.dispose()}},t.prototype.init=function(){var t=this;e.prototype.init.call(this),Object(i.each)(this,(function(e){t.attachWidget(e)}))},t.prototype.attachWidget=function(e){this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeAttach),this.parent.node.appendChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterAttach),this.parent.fit()},t.prototype.detachWidget=function(e){this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeDetach),this.parent.node.removeChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterDetach),this.parent.fit()},t.prototype.onBeforeShow=function(t){e.prototype.onBeforeShow.call(this,t),this.parent.update()},t.prototype.onBeforeAttach=function(t){e.prototype.onBeforeAttach.call(this,t),this.parent.fit()},t.prototype.onChildShown=function(e){this.parent.fit()},t.prototype.onChildHidden=function(e){this.parent.fit()},t.prototype.onResize=function(e){this.parent.isVisible&&this._update(e.width,e.height)},t.prototype.onUpdateRequest=function(e){this.parent.isVisible&&this._update(-1,-1)},t.prototype.onFitRequest=function(e){this.parent.isAttached&&this._fit()},t.prototype._fit=function(){for(var e=0,n=this.rowCount;e<n;++e)this._rowSizers[e].minSize=0;for(e=0,n=this.columnCount;e<n;++e)this._columnSizers[e].minSize=0;var r=this._items.filter((function(e){return!e.isHidden}));for(e=0,n=r.length;e<n;++e)r[e].fit();var i=this.rowCount-1,s=this.columnCount-1;r.sort(le.rowSpanCmp);for(e=0,n=r.length;e<n;++e){var l=r[e],c=t.getCellConfig(l.widget),u=Math.min(c.row,i),d=Math.min(c.row+c.rowSpan-1,i);le.distributeMin(this._rowSizers,u,d,l.minHeight)}r.sort(le.columnSpanCmp);for(e=0,n=r.length;e<n;++e){l=r[e],c=t.getCellConfig(l.widget);var h=Math.min(c.column,s),p=Math.min(c.column+c.columnSpan-1,s);le.distributeMin(this._columnSizers,h,p,l.minWidth)}if("set-no-constraint"!==this.fitPolicy){var f=i*this._rowSpacing,m=s*this._columnSpacing;for(e=0,n=this.rowCount;e<n;++e)f+=this._rowSizers[e].minSize;for(e=0,n=this.columnCount;e<n;++e)m+=this._columnSizers[e].minSize;var g=this._box=o.ElementExt.boxSizing(this.parent.node);m+=g.horizontalSum,f+=g.verticalSum;var v=this.parent.node.style;v.minWidth=m+"px",v.minHeight=f+"px",this._dirty=!0,this.parent.parent&&a.c.sendMessage(this.parent.parent,A.Msg.FitRequest),this._dirty&&a.c.sendMessage(this.parent,A.Msg.UpdateRequest)}else a.c.sendMessage(this.parent,A.Msg.UpdateRequest)},t.prototype._update=function(e,n){this._dirty=!1,e<0&&(e=this.parent.node.offsetWidth),n<0&&(n=this.parent.node.offsetHeight),this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var r=this._box.paddingTop,i=this._box.paddingLeft,a=e-this._box.horizontalSum,s=n-this._box.verticalSum,l=this.rowCount-1,c=this.columnCount-1,u=l*this._rowSpacing,d=c*this._columnSpacing;y.calc(this._rowSizers,Math.max(0,s-u)),y.calc(this._columnSizers,Math.max(0,a-d));for(var h=0,p=r,f=this.rowCount;h<f;++h)this._rowStarts[h]=p,p+=this._rowSizers[h].size+this._rowSpacing;for(h=0,p=i,f=this.columnCount;h<f;++h)this._columnStarts[h]=p,p+=this._columnSizers[h].size+this._columnSpacing;for(h=0,f=this._items.length;h<f;++h){var m=this._items[h];if(!m.isHidden){var g=t.getCellConfig(m.widget),v=Math.min(g.row,l),_=Math.min(g.column,c),b=Math.min(g.row+g.rowSpan-1,l),M=Math.min(g.column+g.columnSpan-1,c),w=this._columnStarts[_],A=this._rowStarts[v],C=this._columnStarts[M]+this._columnSizers[M].size-w,x=this._rowStarts[b]+this._rowSizers[b].size-A;m.update(w,A,C,x)}}},t}(x);(se=ue||(ue={})).getCellConfig=function(e){return le.cellConfigProperty.get(e)},se.setCellConfig=function(e,t){le.cellConfigProperty.set(e,le.normalizeConfig(t))},function(e){e.cellConfigProperty=new s.AttachedProperty({name:"cellConfig",create:function(){return{row:0,column:0,rowSpan:1,columnSpan:1}},changed:function(e){e.parent&&e.parent.layout instanceof ue&&e.parent.fit()}}),e.normalizeConfig=function(e){return{row:Math.max(0,Math.floor(e.row||0)),column:Math.max(0,Math.floor(e.column||0)),rowSpan:Math.max(1,Math.floor(e.rowSpan||0)),columnSpan:Math.max(1,Math.floor(e.columnSpan||0))}},e.clampValue=function(e){return Math.max(0,Math.floor(e))},e.rowSpanCmp=function(t,n){var r=e.cellConfigProperty.get(t.widget),i=e.cellConfigProperty.get(n.widget);return r.rowSpan-i.rowSpan},e.columnSpanCmp=function(t,n){var r=e.cellConfigProperty.get(t.widget),i=e.cellConfigProperty.get(n.widget);return r.columnSpan-i.columnSpan},e.reallocSizers=function(e,t){for(t=Math.max(1,Math.floor(t));e.length<t;)e.push(new _);e.length>t&&(e.length=t)},e.distributeMin=function(e,t,n,r){if(!(n<t))if(t!==n){for(var i=0,o=t;o<=n;++o)i+=e[o].minSize;if(!(i>=r)){var a=(r-i)/(n-t+1);for(o=t;o<=n;++o)e[o].minSize+=a}}else{var s=e[t];s.minSize=Math.max(s.minSize,r)}}}(le||(le={}));var de,he=function(e){function t(n){void 0===n&&(n={});var r=e.call(this,{node:de.createNode()})||this;return r._activeIndex=-1,r._menus=[],r._childMenu=null,r.addClass("lm-MenuBar"),r.addClass("p-MenuBar"),r.setFlag(A.Flag.DisallowLayout),r.renderer=n.renderer||t.defaultRenderer,r._forceItemsPosition=n.forceItemsPosition||{forceX:!0,forceY:!0},r}return g(t,e),t.prototype.dispose=function(){this._closeChildMenu(),this._menus.length=0,e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"childMenu",{get:function(){return this._childMenu},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"contentNode",{get:function(){return this.node.getElementsByClassName("lm-MenuBar-content")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"activeMenu",{get:function(){return this._menus[this._activeIndex]||null},set:function(e){this.activeIndex=e?this._menus.indexOf(e):-1},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"activeIndex",{get:function(){return this._activeIndex},set:function(e){(e<0||e>=this._menus.length)&&(e=-1),this._activeIndex!==e&&(this._activeIndex=e,this._activeIndex>=0&&this.contentNode.childNodes[this._activeIndex]&&this.contentNode.childNodes[this._activeIndex].focus(),this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"menus",{get:function(){return this._menus},enumerable:!0,configurable:!0}),t.prototype.openActiveMenu=function(){-1!==this._activeIndex&&(this._openChildMenu(),this._childMenu&&(this._childMenu.activeIndex=-1,this._childMenu.activateNextItem()))},t.prototype.addMenu=function(e){this.insertMenu(this._menus.length,e)},t.prototype.insertMenu=function(e,t){this._closeChildMenu();var n=this._menus.indexOf(t),r=Math.max(0,Math.min(e,this._menus.length));if(-1===n)return i.ArrayExt.insert(this._menus,r,t),t.addClass("lm-MenuBar-menu"),t.addClass("p-MenuBar-menu"),t.aboutToClose.connect(this._onMenuAboutToClose,this),t.menuRequested.connect(this._onMenuMenuRequested,this),t.title.changed.connect(this._onTitleChanged,this),void this.update();r===this._menus.length&&r--,n!==r&&(i.ArrayExt.move(this._menus,n,r),this.update())},t.prototype.removeMenu=function(e){this.removeMenuAt(this._menus.indexOf(e))},t.prototype.removeMenuAt=function(e){this._closeChildMenu();var t=i.ArrayExt.removeAt(this._menus,e);t&&(t.aboutToClose.disconnect(this._onMenuAboutToClose,this),t.menuRequested.disconnect(this._onMenuMenuRequested,this),t.title.changed.disconnect(this._onTitleChanged,this),t.removeClass("lm-MenuBar-menu"),t.removeClass("p-MenuBar-menu"),this.update())},t.prototype.clearMenus=function(){if(0!==this._menus.length){this._closeChildMenu();for(var e=0,t=this._menus;e<t.length;e++){var n=t[e];n.aboutToClose.disconnect(this._onMenuAboutToClose,this),n.menuRequested.disconnect(this._onMenuMenuRequested,this),n.title.changed.disconnect(this._onTitleChanged,this),n.removeClass("lm-MenuBar-menu"),n.removeClass("p-MenuBar-menu")}this._menus.length=0,this.update()}},t.prototype.handleEvent=function(e){switch(e.type){case"keydown":this._evtKeyDown(e);break;case"mousedown":this._evtMouseDown(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseleave":this._evtMouseLeave(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("keydown",this),this.node.addEventListener("mousedown",this),this.node.addEventListener("mousemove",this),this.node.addEventListener("mouseleave",this),this.node.addEventListener("contextmenu",this)},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("keydown",this),this.node.removeEventListener("mousedown",this),this.node.removeEventListener("mousemove",this),this.node.removeEventListener("mouseleave",this),this.node.removeEventListener("contextmenu",this),this._closeChildMenu()},t.prototype.onActivateRequest=function(e){this.isAttached&&this.node.focus()},t.prototype.onUpdateRequest=function(e){for(var t=this,n=this._menus,r=this.renderer,i=this._activeIndex,o=new Array(n.length),a=function(e,a){var s=n[e].title,l=e===i;l&&0==n[e].items.length&&(l=!1),o[e]=r.renderItem({title:s,active:l,onfocus:function(){t.activeIndex=e}})},s=0,l=n.length;s<l;++s)a(s);p.VirtualDOM.render(o,this.contentNode)},t.prototype._evtKeyDown=function(e){e.preventDefault(),e.stopPropagation();var t=e.keyCode;if(13!==t&&38!==t&&40!==t){if(27===t)return this._closeChildMenu(),this.activeIndex=-1,void this.node.blur();if(37!==t)if(39!==t){var n=Object(f.a)().keyForKeydownEvent(e);if(n){var r=this._activeIndex+1,i=de.findMnemonic(this._menus,n,r);-1===i.index||i.multiple?-1!==i.index?this.activeIndex=i.index:-1!==i.auto&&(this.activeIndex=i.auto):(this.activeIndex=i.index,this.openActiveMenu())}}else{o=this._activeIndex,a=this._menus.length;this.activeIndex=o===a-1?0:o+1}else{var o=this._activeIndex,a=this._menus.length;this.activeIndex=0===o?a-1:o-1}}else this.openActiveMenu()},t.prototype._evtMouseDown=function(e){if(o.ElementExt.hitTest(this.node,e.clientX,e.clientY)){e.preventDefault(),e.stopPropagation(),e.stopImmediatePropagation();var t=i.ArrayExt.findFirstIndex(this.contentNode.children,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));-1!==t?0===e.button&&(this._childMenu?(this._closeChildMenu(),this.activeIndex=t):(this.activeIndex=t,this._openChildMenu())):this._closeChildMenu()}},t.prototype._evtMouseMove=function(e){var t=i.ArrayExt.findFirstIndex(this.contentNode.children,(function(t){return o.ElementExt.hitTest(t,e.clientX,e.clientY)}));t!==this._activeIndex&&(-1===t&&this._childMenu||(this.activeIndex=t,this._childMenu&&this._openChildMenu()))},t.prototype._evtMouseLeave=function(e){this._childMenu||(this.activeIndex=-1)},t.prototype._openChildMenu=function(){var e=this.activeMenu;if(e){var t=this._childMenu;if(t!==e){this._childMenu=e,t?t.close():(this.addClass("lm-mod-active"),this.addClass("p-mod-active"),document.addEventListener("mousedown",this,!0)),a.c.sendMessage(this,A.Msg.UpdateRequest);var n=this.contentNode.children[this._activeIndex].getBoundingClientRect(),r=n.left,i=n.bottom;e.items.length>0&&e.open(r,i,this._forceItemsPosition)}}else this._closeChildMenu()},t.prototype._closeChildMenu=function(){if(this._childMenu){this.removeClass("lm-mod-active"),this.removeClass("p-mod-active"),document.removeEventListener("mousedown",this,!0);var e=this._childMenu;this._childMenu=null,e.close(),this.activeIndex=-1}},t.prototype._onMenuAboutToClose=function(e){e===this._childMenu&&(this.removeClass("lm-mod-active"),this.removeClass("p-mod-active"),document.removeEventListener("mousedown",this,!0),this._childMenu=null,this.activeIndex=-1)},t.prototype._onMenuMenuRequested=function(e,t){if(e===this._childMenu){var n=this._activeIndex,r=this._menus.length;switch(t){case"next":this.activeIndex=n===r-1?0:n+1;break;case"previous":this.activeIndex=0===n?r-1:n-1}this.openActiveMenu()}},t.prototype._onTitleChanged=function(){this.update()},t}(A);!function(e){var t=function(){function e(){}return e.prototype.renderItem=function(e){var t=this.createItemClass(e),n=this.createItemDataset(e),r=this.createItemARIA(e);return p.h.li(v({className:t,dataset:n,tabindex:"0",onfocus:e.onfocus},r),this.renderIcon(e),this.renderLabel(e))},e.prototype.renderIcon=function(e){var t=this.createIconClass(e);return"string"==typeof e.title.icon?p.h.div({className:t},e.title.iconLabel):p.h.div({className:t},e.title.icon,e.title.iconLabel)},e.prototype.renderLabel=function(e){var t=this.formatLabel(e);return p.h.div({className:"lm-MenuBar-itemLabel p-MenuBar-itemLabel"},t)},e.prototype.createItemClass=function(e){var t="lm-MenuBar-item";return t+=" p-MenuBar-item",e.title.className&&(t+=" "+e.title.className),e.active&&(t+=" lm-mod-active",t+=" p-mod-active"),t},e.prototype.createItemDataset=function(e){return e.title.dataset},e.prototype.createItemARIA=function(e){return{role:"menuitem","aria-haspopup":"true"}},e.prototype.createIconClass=function(e){var t="lm-MenuBar-itemIcon";t+=" p-MenuBar-itemIcon";var n=e.title.iconClass;return n?t+" "+n:t},e.prototype.formatLabel=function(e){var t=e.title,n=t.label,r=t.mnemonic;if(r<0||r>=n.length)return n;var i=n.slice(0,r),o=n.slice(r+1),a=n[r];return[i,p.h.span({className:"lm-MenuBar-itemMnemonic p-MenuBar-itemMnemonic"},a),o]},e}();e.Renderer=t,e.defaultRenderer=new t}(he||(he={})),function(e){e.createNode=function(){var e=document.createElement("div"),t=document.createElement("ul");return t.className="lm-MenuBar-content",t.classList.add("p-MenuBar-content"),e.appendChild(t),t.setAttribute("role","menubar"),e.tabIndex=0,t.tabIndex=0,e},e.findMnemonic=function(e,t,n){for(var r=-1,i=-1,o=!1,a=t.toUpperCase(),s=0,l=e.length;s<l;++s){var c=(s+n)%l,u=e[c].title;if(0!==u.label.length){var d=u.mnemonic;d>=0&&d<u.label.length?u.label[d].toUpperCase()===a&&(-1===r?r=c:o=!0):-1===i&&u.label[0].toUpperCase()===a&&(i=c)}}return{index:r,multiple:o,auto:i}}}(de||(de={}));var pe,fe=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,{node:pe.createNode()})||this;return n._onRepeat=function(){if(n._repeatTimer=-1,n._pressData){var e=n._pressData.part;if("thumb"!==e){n._repeatTimer=window.setTimeout(n._onRepeat,20);var t=n._pressData.mouseX,r=n._pressData.mouseY;if("decrement"!==e)if("increment"!==e){if("track"===e){if(!o.ElementExt.hitTest(n.trackNode,t,r))return;var i=n.thumbNode;if(o.ElementExt.hitTest(i,t,r))return;var a=i.getBoundingClientRect(),s=void 0;return s="horizontal"===n._orientation?t<a.left?"decrement":"increment":r<a.top?"decrement":"increment",void n._pageRequested.emit(s)}}else{if(!o.ElementExt.hitTest(n.incrementNode,t,r))return;n._stepRequested.emit("increment")}else{if(!o.ElementExt.hitTest(n.decrementNode,t,r))return;n._stepRequested.emit("decrement")}}}},n._value=0,n._page=10,n._maximum=100,n._repeatTimer=-1,n._pressData=null,n._thumbMoved=new l.Signal(n),n._stepRequested=new l.Signal(n),n._pageRequested=new l.Signal(n),n.addClass("lm-ScrollBar"),n.addClass("p-ScrollBar"),n.setFlag(A.Flag.DisallowLayout),n._orientation=t.orientation||"vertical",n.dataset.orientation=n._orientation,void 0!==t.maximum&&(n._maximum=Math.max(0,t.maximum)),void 0!==t.page&&(n._page=Math.max(0,t.page)),void 0!==t.value&&(n._value=Math.max(0,Math.min(t.value,n._maximum))),n}return g(t,e),Object.defineProperty(t.prototype,"thumbMoved",{get:function(){return this._thumbMoved},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"stepRequested",{get:function(){return this._stepRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"pageRequested",{get:function(){return this._pageRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"orientation",{get:function(){return this._orientation},set:function(e){this._orientation!==e&&(this._releaseMouse(),this._orientation=e,this.dataset.orientation=e,this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"value",{get:function(){return this._value},set:function(e){e=Math.max(0,Math.min(e,this._maximum)),this._value!==e&&(this._value=e,this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"page",{get:function(){return this._page},set:function(e){e=Math.max(0,e),this._page!==e&&(this._page=e,this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"maximum",{get:function(){return this._maximum},set:function(e){e=Math.max(0,e),this._maximum!==e&&(this._maximum=e,this._value=Math.min(this._value,e),this.update())},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"decrementNode",{get:function(){return this.node.getElementsByClassName("lm-ScrollBar-button")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"incrementNode",{get:function(){return this.node.getElementsByClassName("lm-ScrollBar-button")[1]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"trackNode",{get:function(){return this.node.getElementsByClassName("lm-ScrollBar-track")[0]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"thumbNode",{get:function(){return this.node.getElementsByClassName("lm-ScrollBar-thumb")[0]},enumerable:!0,configurable:!0}),t.prototype.handleEvent=function(e){switch(e.type){case"mousedown":this._evtMouseDown(e);break;case"mousemove":this._evtMouseMove(e);break;case"mouseup":this._evtMouseUp(e);break;case"keydown":this._evtKeyDown(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}},t.prototype.onBeforeAttach=function(e){this.node.addEventListener("mousedown",this),this.update()},t.prototype.onAfterDetach=function(e){this.node.removeEventListener("mousedown",this),this._releaseMouse()},t.prototype.onUpdateRequest=function(e){var t=100*this._value/this._maximum,n=100*this._page/(this._page+this._maximum);t=Math.max(0,Math.min(t,100)),n=Math.max(0,Math.min(n,100));var r=this.thumbNode.style;"horizontal"===this._orientation?(r.top="",r.height="",r.left=t+"%",r.width=n+"%",r.transform="translate("+-t+"%, 0%)"):(r.left="",r.width="",r.top=t+"%",r.height=n+"%",r.transform="translate(0%, "+-t+"%)")},t.prototype._evtKeyDown=function(e){if(e.preventDefault(),e.stopPropagation(),27===e.keyCode){var t=this._pressData?this._pressData.value:-1;this._releaseMouse(),-1!==t&&this._moveThumb(t)}},t.prototype._evtMouseDown=function(e){if(0===e.button&&(this.activate(),!this._pressData)){var t=pe.findPart(this,e.target);if(t){e.preventDefault(),e.stopPropagation();var n=u.overrideCursor("default");if(this._pressData={part:t,override:n,delta:-1,value:-1,mouseX:e.clientX,mouseY:e.clientY},document.addEventListener("mousemove",this,!0),document.addEventListener("mouseup",this,!0),document.addEventListener("keydown",this,!0),document.addEventListener("contextmenu",this,!0),"thumb"===t){var r=this.thumbNode,i=r.getBoundingClientRect();return"horizontal"===this._orientation?this._pressData.delta=e.clientX-i.left:this._pressData.delta=e.clientY-i.top,r.classList.add("lm-mod-active"),r.classList.add("p-mod-active"),void(this._pressData.value=this._value)}if("track"===t){i=this.thumbNode.getBoundingClientRect();var o=void 0;return o="horizontal"===this._orientation?e.clientX<i.left?"decrement":"increment":e.clientY<i.top?"decrement":"increment",this._repeatTimer=window.setTimeout(this._onRepeat,350),void this._pageRequested.emit(o)}return"decrement"===t?(this.decrementNode.classList.add("lm-mod-active"),this.decrementNode.classList.add("p-mod-active"),this._repeatTimer=window.setTimeout(this._onRepeat,350),void this._stepRequested.emit("decrement")):"increment"===t?(this.incrementNode.classList.add("lm-mod-active"),this.incrementNode.classList.add("p-mod-active"),this._repeatTimer=window.setTimeout(this._onRepeat,350),void this._stepRequested.emit("increment")):void 0}}},t.prototype._evtMouseMove=function(e){if(this._pressData&&(e.preventDefault(),e.stopPropagation(),this._pressData.mouseX=e.clientX,this._pressData.mouseY=e.clientY,"thumb"===this._pressData.part)){var t,n,r=this.thumbNode.getBoundingClientRect(),i=this.trackNode.getBoundingClientRect();"horizontal"===this._orientation?(t=e.clientX-i.left-this._pressData.delta,n=i.width-r.width):(t=e.clientY-i.top-this._pressData.delta,n=i.height-r.height);var o=0===n?0:t*this._maximum/n;this._moveThumb(o)}},t.prototype._evtMouseUp=function(e){0===e.button&&(e.preventDefault(),e.stopPropagation(),this._releaseMouse())},t.prototype._releaseMouse=function(){this._pressData&&(clearTimeout(this._repeatTimer),this._repeatTimer=-1,this._pressData.override.dispose(),this._pressData=null,document.removeEventListener("mousemove",this,!0),document.removeEventListener("mouseup",this,!0),document.removeEventListener("keydown",this,!0),document.removeEventListener("contextmenu",this,!0),this.thumbNode.classList.remove("lm-mod-active"),this.decrementNode.classList.remove("lm-mod-active"),this.incrementNode.classList.remove("lm-mod-active"),this.thumbNode.classList.remove("p-mod-active"),this.decrementNode.classList.remove("p-mod-active"),this.incrementNode.classList.remove("p-mod-active"))},t.prototype._moveThumb=function(e){e=Math.max(0,Math.min(e,this._maximum)),this._value!==e&&(this._value=e,this.update(),this._thumbMoved.emit(e))},t}(A);!function(e){e.createNode=function(){var e=document.createElement("div"),t=document.createElement("div"),n=document.createElement("div"),r=document.createElement("div"),i=document.createElement("div");return t.className="lm-ScrollBar-button",n.className="lm-ScrollBar-button",t.dataset.action="decrement",n.dataset.action="increment",r.className="lm-ScrollBar-track",i.className="lm-ScrollBar-thumb",t.classList.add("p-ScrollBar-button"),n.classList.add("p-ScrollBar-button"),r.classList.add("p-ScrollBar-track"),i.classList.add("p-ScrollBar-thumb"),r.appendChild(i),e.appendChild(t),e.appendChild(r),e.appendChild(n),e},e.findPart=function(e,t){return e.thumbNode.contains(t)?"thumb":e.trackNode.contains(t)?"track":e.decrementNode.contains(t)?"decrement":e.incrementNode.contains(t)?"increment":null}}(pe||(pe={}));var me,ge=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._widget=null,t}return g(t,e),t.prototype.dispose=function(){if(this._widget){var t=this._widget;this._widget=null,t.dispose()}e.prototype.dispose.call(this)},Object.defineProperty(t.prototype,"widget",{get:function(){return this._widget},set:function(e){e&&(e.parent=this.parent),this._widget!==e&&(this._widget&&this._widget.dispose(),this._widget=e,this.parent&&e&&this.attachWidget(e))},enumerable:!0,configurable:!0}),t.prototype.iter=function(){return this._widget?Object(i.once)(this._widget):Object(i.empty)()},t.prototype.removeWidget=function(e){this._widget===e&&(this._widget=null,this.parent&&this.detachWidget(e))},t.prototype.init=function(){var t=this;e.prototype.init.call(this),Object(i.each)(this,(function(e){t.attachWidget(e)}))},t.prototype.attachWidget=function(e){this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeAttach),this.parent.node.appendChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterAttach)},t.prototype.detachWidget=function(e){this.parent.isAttached&&a.c.sendMessage(e,A.Msg.BeforeDetach),this.parent.node.removeChild(e.node),this.parent.isAttached&&a.c.sendMessage(e,A.Msg.AfterDetach)},t}(x),ve=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,t)||this;return n._dirty=!1,n._items=[],n._box=null,n._hiddenMode=void 0!==t.hiddenMode?t.hiddenMode:A.HiddenMode.Display,n}return g(t,e),Object.defineProperty(t.prototype,"hiddenMode",{get:function(){return this._hiddenMode},set:function(e){var t=this;this._hiddenMode!==e&&(this._hiddenMode=e,this.widgets.length>1&&this.widgets.forEach((function(e){e.hiddenMode=t._hiddenMode})))},enumerable:!0,configurable:!0}),t.prototype.dispose=function(){Object(i.each)(this._items,(function(e){e.dispose()})),this._box=null,this._items.length=0,e.prototype.dispose.call(this)},t.prototype.attachWidget=function(e,t){this._hiddenMode===A.HiddenMode.Scale&&this._items.length>0?(1===this._items.length&&(this.widgets[0].hiddenMode=A.HiddenMode.Scale),t.hiddenMode=A.HiddenMode.Scale):t.hiddenMode=A.HiddenMode.Display,i.ArrayExt.insert(this._items,e,new L(t)),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeAttach),this.parent.node.appendChild(t.node),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterAttach),this.parent.fit()},t.prototype.moveWidget=function(e,t,n){i.ArrayExt.move(this._items,e,t),this.parent.update()},t.prototype.detachWidget=function(e,t){var n=i.ArrayExt.removeAt(this._items,e);this.parent.isAttached&&a.c.sendMessage(t,A.Msg.BeforeDetach),this.parent.node.removeChild(t.node),this.parent.isAttached&&a.c.sendMessage(t,A.Msg.AfterDetach),n.widget.node.style.zIndex="",this._hiddenMode===A.HiddenMode.Scale&&(t.hiddenMode=A.HiddenMode.Display,1===this._items.length&&(this._items[0].widget.hiddenMode=A.HiddenMode.Display)),n.dispose(),this.parent.fit()},t.prototype.onBeforeShow=function(t){e.prototype.onBeforeShow.call(this,t),this.parent.update()},t.prototype.onBeforeAttach=function(t){e.prototype.onBeforeAttach.call(this,t),this.parent.fit()},t.prototype.onChildShown=function(e){this.parent.fit()},t.prototype.onChildHidden=function(e){this.parent.fit()},t.prototype.onResize=function(e){this.parent.isVisible&&this._update(e.width,e.height)},t.prototype.onUpdateRequest=function(e){this.parent.isVisible&&this._update(-1,-1)},t.prototype.onFitRequest=function(e){this.parent.isAttached&&this._fit()},t.prototype._fit=function(){for(var e=0,t=0,n=0,r=this._items.length;n<r;++n){var i=this._items[n];i.isHidden||(i.fit(),e=Math.max(e,i.minWidth),t=Math.max(t,i.minHeight))}var s=this._box=o.ElementExt.boxSizing(this.parent.node);e+=s.horizontalSum,t+=s.verticalSum;var l=this.parent.node.style;l.minWidth=e+"px",l.minHeight=t+"px",this._dirty=!0,this.parent.parent&&a.c.sendMessage(this.parent.parent,A.Msg.FitRequest),this._dirty&&a.c.sendMessage(this.parent,A.Msg.UpdateRequest)},t.prototype._update=function(e,t){this._dirty=!1;for(var n=0,r=0,i=this._items.length;r<i;++r)n+=+!this._items[r].isHidden;if(0!==n){e<0&&(e=this.parent.node.offsetWidth),t<0&&(t=this.parent.node.offsetHeight),this._box||(this._box=o.ElementExt.boxSizing(this.parent.node));var a=this._box.paddingTop,s=this._box.paddingLeft,l=e-this._box.horizontalSum,c=t-this._box.verticalSum;for(r=0,i=this._items.length;r<i;++r){var u=this._items[r];u.isHidden||(u.widget.node.style.zIndex=""+r,u.update(s,a,l,c))}}},t}(T),ye=function(e){function t(t){void 0===t&&(t={});var n=e.call(this,{layout:me.createLayout(t)})||this;return n._widgetRemoved=new l.Signal(n),n.addClass("lm-StackedPanel"),n.addClass("p-StackedPanel"),n}return g(t,e),Object.defineProperty(t.prototype,"hiddenMode",{get:function(){return this.layout.hiddenMode},set:function(e){this.layout.hiddenMode=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"widgetRemoved",{get:function(){return this._widgetRemoved},enumerable:!0,configurable:!0}),t.prototype.onChildAdded=function(e){e.child.addClass("lm-StackedPanel-child"),e.child.addClass("p-StackedPanel-child")},t.prototype.onChildRemoved=function(e){e.child.removeClass("lm-StackedPanel-child"),e.child.removeClass("p-StackedPanel-child"),this._widgetRemoved.emit(e.child)},t}(z);!function(e){e.createLayout=function(e){return e.layout||new ve}}(me||(me={}));var _e,be=function(e){function t(t){void 0===t&&(t={});var n=e.call(this)||this;n._currentChanged=new l.Signal(n),n._addRequested=new l.Signal(n),n.addClass("lm-TabPanel"),n.addClass("p-TabPanel"),n.tabBar=new ne(t),n.tabBar.addClass("lm-TabPanel-tabBar"),n.stackedPanel=new ye,n.stackedPanel.addClass("lm-TabPanel-stackedPanel"),n.tabBar.addClass("p-TabPanel-tabBar"),n.stackedPanel.addClass("p-TabPanel-stackedPanel"),n.tabBar.tabMoved.connect(n._onTabMoved,n),n.tabBar.currentChanged.connect(n._onCurrentChanged,n),n.tabBar.tabCloseRequested.connect(n._onTabCloseRequested,n),n.tabBar.tabActivateRequested.connect(n._onTabActivateRequested,n),n.tabBar.addRequested.connect(n._onTabAddRequested,n),n.stackedPanel.widgetRemoved.connect(n._onWidgetRemoved,n),n._tabPlacement=t.tabPlacement||"top";var r=_e.directionFromPlacement(n._tabPlacement),i=_e.orientationFromPlacement(n._tabPlacement);n.tabBar.orientation=i,n.tabBar.dataset.placement=n._tabPlacement;var o=new G({direction:r,spacing:0});return G.setStretch(n.tabBar,0),G.setStretch(n.stackedPanel,1),o.addWidget(n.tabBar),o.addWidget(n.stackedPanel),n.layout=o,n}return g(t,e),Object.defineProperty(t.prototype,"currentChanged",{get:function(){return this._currentChanged},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentIndex",{get:function(){return this.tabBar.currentIndex},set:function(e){this.tabBar.currentIndex=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentWidget",{get:function(){var e=this.tabBar.currentTitle;return e?e.owner:null},set:function(e){this.tabBar.currentTitle=e?e.title:null},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabsMovable",{get:function(){return this.tabBar.tabsMovable},set:function(e){this.tabBar.tabsMovable=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addButtonEnabled",{get:function(){return this.tabBar.addButtonEnabled},set:function(e){this.tabBar.addButtonEnabled=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabPlacement",{get:function(){return this._tabPlacement},set:function(e){if(this._tabPlacement!==e){this._tabPlacement=e;var t=_e.directionFromPlacement(e),n=_e.orientationFromPlacement(e);this.tabBar.orientation=n,this.tabBar.dataset.placement=e,this.layout.direction=t}},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"addRequested",{get:function(){return this._addRequested},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"widgets",{get:function(){return this.stackedPanel.widgets},enumerable:!0,configurable:!0}),t.prototype.addWidget=function(e){this.insertWidget(this.widgets.length,e)},t.prototype.insertWidget=function(e,t){t!==this.currentWidget&&t.hide(),this.stackedPanel.insertWidget(e,t),this.tabBar.insertTab(e,t.title),t.node.setAttribute("role","tabpanel");var n=this.tabBar.renderer;if(n instanceof ne.Renderer){var r=n.createTabKey({title:t.title,current:!1,zIndex:0});t.node.setAttribute("aria-labelledby",r)}},t.prototype._onCurrentChanged=function(e,t){var n=t.previousIndex,r=t.previousTitle,i=t.currentIndex,s=t.currentTitle,l=r?r.owner:null,c=s?s.owner:null;l&&l.hide(),c&&c.show(),this._currentChanged.emit({previousIndex:n,previousWidget:l,currentIndex:i,currentWidget:c}),(o.Platform.IS_EDGE||o.Platform.IS_IE)&&a.c.flush()},t.prototype._onTabAddRequested=function(e,t){this._addRequested.emit(e)},t.prototype._onTabActivateRequested=function(e,t){t.title.owner.activate()},t.prototype._onTabCloseRequested=function(e,t){t.title.owner.close()},t.prototype._onTabMoved=function(e,t){this.stackedPanel.insertWidget(t.toIndex,t.title.owner)},t.prototype._onWidgetRemoved=function(e,t){t.node.removeAttribute("role"),t.node.removeAttribute("aria-labelledby"),this.tabBar.removeTab(t.title)},t}(A);!function(e){e.orientationFromPlacement=function(e){return t[e]},e.directionFromPlacement=function(e){return n[e]};var t={top:"horizontal",left:"vertical",right:"vertical",bottom:"horizontal"},n={top:"top-to-bottom",left:"left-to-right",right:"right-to-left",bottom:"bottom-to-top"}}(_e||(_e={}))},function(e,t,n){"use strict";n.r(t),function(e){n.d(t,"Signal",(function(){return o}));var r,i=n(2),o=function(){function e(e){this.sender=e}return e.prototype.connect=function(e,t){return r.connect(this,e,t)},e.prototype.disconnect=function(e,t){return r.disconnect(this,e,t)},e.prototype.emit=function(e){r.emit(this,e)},e}();!function(e){e.disconnectBetween=function(e,t){r.disconnectBetween(e,t)},e.disconnectSender=function(e){r.disconnectSender(e)},e.disconnectReceiver=function(e){r.disconnectReceiver(e)},e.disconnectAll=function(e){r.disconnectAll(e)},e.clearData=function(e){r.disconnectAll(e)},e.getExceptionHandler=function(){return r.exceptionHandler},e.setExceptionHandler=function(e){var t=r.exceptionHandler;return r.exceptionHandler=e,t}}(o||(o={})),function(t){function n(e){var t=o.get(e);t&&0!==t.length&&(Object(i.each)(t,(function(e){if(e.signal){var t=e.thisArg||e.slot;e.signal=null,d(a.get(t))}})),d(t))}function r(e){var t=a.get(e);t&&0!==t.length&&(Object(i.each)(t,(function(e){if(e.signal){var t=e.signal.sender;e.signal=null,d(o.get(t))}})),d(t))}t.exceptionHandler=function(e){console.error(e)},t.connect=function(e,t,n){n=n||void 0;var r=o.get(e.sender);if(r||(r=[],o.set(e.sender,r)),c(r,e,t,n))return!1;var i=n||t,s=a.get(i);s||(s=[],a.set(i,s));var l={signal:e,slot:t,thisArg:n};return r.push(l),s.push(l),!0},t.disconnect=function(e,t,n){n=n||void 0;var r=o.get(e.sender);if(!r||0===r.length)return!1;var i=c(r,e,t,n);if(!i)return!1;var s=n||t,l=a.get(s);return i.signal=null,d(r),d(l),!0},t.disconnectBetween=function(e,t){var n=o.get(e);if(n&&0!==n.length){var r=a.get(t);r&&0!==r.length&&(Object(i.each)(r,(function(t){t.signal&&t.signal.sender===e&&(t.signal=null)})),d(n),d(r))}},t.disconnectSender=n,t.disconnectReceiver=r,t.disconnectAll=function(e){n(e),r(e)},t.emit=function(e,t){var n=o.get(e.sender);if(n&&0!==n.length)for(var r=0,i=n.length;r<i;++r){var a=n[r];a.signal===e&&u(a,t)}};var o=new WeakMap,a=new WeakMap,s=new Set,l="function"==typeof requestAnimationFrame?requestAnimationFrame:e;function c(e,t,n,r){return Object(i.find)(e,(function(e){return e.signal===t&&e.slot===n&&e.thisArg===r}))}function u(e,n){var r=e.signal,i=e.slot,o=e.thisArg;try{i.call(o,r.sender,n)}catch(e){t.exceptionHandler(e)}}function d(e){0===s.size&&l(h),s.add(e)}function h(){s.forEach(p),s.clear()}function p(e){i.ArrayExt.removeAllWhere(e,f)}function f(e){return null===e.signal}}(r||(r={}))}.call(this,n(90).setImmediate)},function(e,t,n){var r;
/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/!function(){"use strict";var n={}.hasOwnProperty;function i(){for(var e=[],t=0;t<arguments.length;t++){var r=arguments[t];if(r){var o=typeof r;if("string"===o||"number"===o)e.push(r);else if(Array.isArray(r)){if(r.length){var a=i.apply(null,r);a&&e.push(a)}}else if("object"===o)if(r.toString===Object.prototype.toString)for(var s in r)n.call(r,s)&&r[s]&&e.push(s);else e.push(r.toString())}}return e.join(" ")}e.exports?(i.default=i,e.exports=i):void 0===(r=function(){return i}.apply(t,[]))||(e.exports=r)}()},function(e,t,n){!function(e){"use strict";e.JSONExt=void 0,function(e){function t(e){return null===e||"boolean"==typeof e||"number"==typeof e||"string"==typeof e}function n(e){return Array.isArray(e)}function r(e,i){if(e===i)return!0;if(t(e)||t(i))return!1;var o=n(e),a=n(i);return o===a&&(o&&a?function(e,t){if(e===t)return!0;if(e.length!==t.length)return!1;for(var n=0,i=e.length;n<i;++n)if(!r(e[n],t[n]))return!1;return!0}(e,i):function(e,t){if(e===t)return!0;for(var n in e)if(void 0!==e[n]&&!(n in t))return!1;for(var n in t)if(void 0!==t[n]&&!(n in e))return!1;for(var n in e){var i=e[n],o=t[n];if(void 0!==i||void 0!==o){if(void 0===i||void 0===o)return!1;if(!r(i,o))return!1}}return!0}(e,i))}function i(e){return t(e)?e:n(e)?function(e){for(var t=new Array(e.length),n=0,r=e.length;n<r;++n)t[n]=i(e[n]);return t}(e):function(e){var t={};for(var n in e){var r=e[n];void 0!==r&&(t[n]=i(r))}return t}(e)}e.emptyObject=Object.freeze({}),e.emptyArray=Object.freeze([]),e.isPrimitive=t,e.isArray=n,e.isObject=function(e){return!t(e)&&!n(e)},e.deepEqual=r,e.deepCopy=i}(e.JSONExt||(e.JSONExt={}));var t=function(){function e(){this._types=[],this._values=[]}return e.prototype.types=function(){return this._types.slice()},e.prototype.hasData=function(e){return-1!==this._types.indexOf(e)},e.prototype.getData=function(e){var t=this._types.indexOf(e);return-1!==t?this._values[t]:void 0},e.prototype.setData=function(e,t){this.clearData(e),this._types.push(e),this._values.push(t)},e.prototype.clearData=function(e){var t=this._types.indexOf(e);-1!==t&&(this._types.splice(t,1),this._values.splice(t,1))},e.prototype.clear=function(){this._types.length=0,this._values.length=0},e}(),n=function(){function e(){var e=this;this.promise=new Promise((function(t,n){e._resolve=t,e._reject=n}))}return e.prototype.resolve=function(e){(0,this._resolve)(e)},e.prototype.reject=function(e){(0,this._reject)(e)},e}(),r=function(e){this.name=e,this._tokenStructuralPropertyT=null};function i(e){for(var t=0,n=0,r=e.length;n<r;++n)n%4==0&&(t=4294967295*Math.random()>>>0),e[n]=255&t,t>>>=8}e.Random=void 0,(e.Random||(e.Random={})).getRandomValues=function(){var e="undefined"!=typeof window&&(window.crypto||window.msCrypto)||null;return e&&"function"==typeof e.getRandomValues?function(t){return e.getRandomValues(t)}:i}(),e.UUID=void 0,(e.UUID||(e.UUID={})).uuid4=function(e){for(var t=new Uint8Array(16),n=new Array(256),r=0;r<16;++r)n[r]="0"+r.toString(16);for(r=16;r<256;++r)n[r]=r.toString(16);return function(){return e(t),t[6]=64|15&t[6],t[8]=128|63&t[8],n[t[0]]+n[t[1]]+n[t[2]]+n[t[3]]+"-"+n[t[4]]+n[t[5]]+"-"+n[t[6]]+n[t[7]]+"-"+n[t[8]]+n[t[9]]+"-"+n[t[10]]+n[t[11]]+n[t[12]]+n[t[13]]+n[t[14]]+n[t[15]]}}(e.Random.getRandomValues),e.MimeData=t,e.PromiseDelegate=n,e.Token=r,Object.defineProperty(e,"__esModule",{value:!0})}(t)},function(e,t,n){(function(e){e.exports=function(){"use strict";var t,r;function i(){return t.apply(null,arguments)}function o(e){return e instanceof Array||"[object Array]"===Object.prototype.toString.call(e)}function a(e){return null!=e&&"[object Object]"===Object.prototype.toString.call(e)}function s(e,t){return Object.prototype.hasOwnProperty.call(e,t)}function l(e){if(Object.getOwnPropertyNames)return 0===Object.getOwnPropertyNames(e).length;var t;for(t in e)if(s(e,t))return!1;return!0}function c(e){return void 0===e}function u(e){return"number"==typeof e||"[object Number]"===Object.prototype.toString.call(e)}function d(e){return e instanceof Date||"[object Date]"===Object.prototype.toString.call(e)}function h(e,t){var n,r=[];for(n=0;n<e.length;++n)r.push(t(e[n],n));return r}function p(e,t){for(var n in t)s(t,n)&&(e[n]=t[n]);return s(t,"toString")&&(e.toString=t.toString),s(t,"valueOf")&&(e.valueOf=t.valueOf),e}function f(e,t,n,r){return xt(e,t,n,r,!0).utc()}function m(e){return null==e._pf&&(e._pf={empty:!1,unusedTokens:[],unusedInput:[],overflow:-2,charsLeftOver:0,nullInput:!1,invalidEra:null,invalidMonth:null,invalidFormat:!1,userInvalidated:!1,iso:!1,parsedDateParts:[],era:null,meridiem:null,rfc2822:!1,weekdayMismatch:!1}),e._pf}function g(e){if(null==e._isValid){var t=m(e),n=r.call(t.parsedDateParts,(function(e){return null!=e})),i=!isNaN(e._d.getTime())&&t.overflow<0&&!t.empty&&!t.invalidEra&&!t.invalidMonth&&!t.invalidWeekday&&!t.weekdayMismatch&&!t.nullInput&&!t.invalidFormat&&!t.userInvalidated&&(!t.meridiem||t.meridiem&&n);if(e._strict&&(i=i&&0===t.charsLeftOver&&0===t.unusedTokens.length&&void 0===t.bigHour),null!=Object.isFrozen&&Object.isFrozen(e))return i;e._isValid=i}return e._isValid}function v(e){var t=f(NaN);return null!=e?p(m(t),e):m(t).userInvalidated=!0,t}r=Array.prototype.some?Array.prototype.some:function(e){var t,n=Object(this),r=n.length>>>0;for(t=0;t<r;t++)if(t in n&&e.call(this,n[t],t,n))return!0;return!1};var y=i.momentProperties=[],_=!1;function b(e,t){var n,r,i;if(c(t._isAMomentObject)||(e._isAMomentObject=t._isAMomentObject),c(t._i)||(e._i=t._i),c(t._f)||(e._f=t._f),c(t._l)||(e._l=t._l),c(t._strict)||(e._strict=t._strict),c(t._tzm)||(e._tzm=t._tzm),c(t._isUTC)||(e._isUTC=t._isUTC),c(t._offset)||(e._offset=t._offset),c(t._pf)||(e._pf=m(t)),c(t._locale)||(e._locale=t._locale),y.length>0)for(n=0;n<y.length;n++)c(i=t[r=y[n]])||(e[r]=i);return e}function M(e){b(this,e),this._d=new Date(null!=e._d?e._d.getTime():NaN),this.isValid()||(this._d=new Date(NaN)),!1===_&&(_=!0,i.updateOffset(this),_=!1)}function w(e){return e instanceof M||null!=e&&null!=e._isAMomentObject}function A(e){!1===i.suppressDeprecationWarnings&&"undefined"!=typeof console&&console.warn&&console.warn("Deprecation warning: "+e)}function C(e,t){var n=!0;return p((function(){if(null!=i.deprecationHandler&&i.deprecationHandler(null,e),n){var r,o,a,l=[];for(o=0;o<arguments.length;o++){if(r="","object"==typeof arguments[o]){for(a in r+="\n["+o+"] ",arguments[0])s(arguments[0],a)&&(r+=a+": "+arguments[0][a]+", ");r=r.slice(0,-2)}else r=arguments[o];l.push(r)}A(e+"\nArguments: "+Array.prototype.slice.call(l).join("")+"\n"+(new Error).stack),n=!1}return t.apply(this,arguments)}),t)}var x,E={};function L(e,t){null!=i.deprecationHandler&&i.deprecationHandler(e,t),E[e]||(A(t),E[e]=!0)}function S(e){return"undefined"!=typeof Function&&e instanceof Function||"[object Function]"===Object.prototype.toString.call(e)}function T(e,t){var n,r=p({},e);for(n in t)s(t,n)&&(a(e[n])&&a(t[n])?(r[n]={},p(r[n],e[n]),p(r[n],t[n])):null!=t[n]?r[n]=t[n]:delete r[n]);for(n in e)s(e,n)&&!s(t,n)&&a(e[n])&&(r[n]=p({},r[n]));return r}function O(e){null!=e&&this.set(e)}function I(e,t,n){var r=""+Math.abs(e),i=t-r.length;return(e>=0?n?"+":"":"-")+Math.pow(10,Math.max(0,i)).toString().substr(1)+r}i.suppressDeprecationWarnings=!1,i.deprecationHandler=null,x=Object.keys?Object.keys:function(e){var t,n=[];for(t in e)s(e,t)&&n.push(t);return n};var k=/(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|N{1,5}|YYYYYY|YYYYY|YYYY|YY|y{2,4}|yo?|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,D=/(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,N={},j={};function P(e,t,n,r){var i=r;"string"==typeof r&&(i=function(){return this[r]()}),e&&(j[e]=i),t&&(j[t[0]]=function(){return I(i.apply(this,arguments),t[1],t[2])}),n&&(j[n]=function(){return this.localeData().ordinal(i.apply(this,arguments),e)})}function z(e,t){return e.isValid()?(t=R(t,e.localeData()),N[t]=N[t]||function(e){var t,n,r,i=e.match(k);for(t=0,n=i.length;t<n;t++)j[i[t]]?i[t]=j[i[t]]:i[t]=(r=i[t]).match(/\[[\s\S]/)?r.replace(/^\[|\]$/g,""):r.replace(/\\/g,"");return function(t){var r,o="";for(r=0;r<n;r++)o+=S(i[r])?i[r].call(t,e):i[r];return o}}(t),N[t](e)):e.localeData().invalidDate()}function R(e,t){var n=5;function r(e){return t.longDateFormat(e)||e}for(D.lastIndex=0;n>=0&&D.test(e);)e=e.replace(D,r),D.lastIndex=0,n-=1;return e}var B={};function H(e,t){var n=e.toLowerCase();B[n]=B[n+"s"]=B[t]=e}function F(e){return"string"==typeof e?B[e]||B[e.toLowerCase()]:void 0}function Y(e){var t,n,r={};for(n in e)s(e,n)&&(t=F(n))&&(r[t]=e[n]);return r}var V={};function U(e,t){V[e]=t}function W(e){return e%4==0&&e%100!=0||e%400==0}function G(e){return e<0?Math.ceil(e)||0:Math.floor(e)}function q(e){var t=+e,n=0;return 0!==t&&isFinite(t)&&(n=G(t)),n}function K(e,t){return function(n){return null!=n?(J(this,e,n),i.updateOffset(this,t),this):X(this,e)}}function X(e,t){return e.isValid()?e._d["get"+(e._isUTC?"UTC":"")+t]():NaN}function J(e,t,n){e.isValid()&&!isNaN(n)&&("FullYear"===t&&W(e.year())&&1===e.month()&&29===e.date()?(n=q(n),e._d["set"+(e._isUTC?"UTC":"")+t](n,e.month(),we(n,e.month()))):e._d["set"+(e._isUTC?"UTC":"")+t](n))}var Q,Z=/\d/,$=/\d\d/,ee=/\d{3}/,te=/\d{4}/,ne=/[+-]?\d{6}/,re=/\d\d?/,ie=/\d\d\d\d?/,oe=/\d\d\d\d\d\d?/,ae=/\d{1,3}/,se=/\d{1,4}/,le=/[+-]?\d{1,6}/,ce=/\d+/,ue=/[+-]?\d+/,de=/Z|[+-]\d\d:?\d\d/gi,he=/Z|[+-]\d\d(?::?\d\d)?/gi,pe=/[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i;function fe(e,t,n){Q[e]=S(t)?t:function(e,r){return e&&n?n:t}}function me(e,t){return s(Q,e)?Q[e](t._strict,t._locale):new RegExp(ge(e.replace("\\","").replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,(function(e,t,n,r,i){return t||n||r||i}))))}function ge(e){return e.replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&")}Q={};var ve,ye={};function _e(e,t){var n,r=t;for("string"==typeof e&&(e=[e]),u(t)&&(r=function(e,n){n[t]=q(e)}),n=0;n<e.length;n++)ye[e[n]]=r}function be(e,t){_e(e,(function(e,n,r,i){r._w=r._w||{},t(e,r._w,r,i)}))}function Me(e,t,n){null!=t&&s(ye,e)&&ye[e](t,n._a,n,e)}function we(e,t){if(isNaN(e)||isNaN(t))return NaN;var n,r=(t%(n=12)+n)%n;return e+=(t-r)/12,1===r?W(e)?29:28:31-r%7%2}ve=Array.prototype.indexOf?Array.prototype.indexOf:function(e){var t;for(t=0;t<this.length;++t)if(this[t]===e)return t;return-1},P("M",["MM",2],"Mo",(function(){return this.month()+1})),P("MMM",0,0,(function(e){return this.localeData().monthsShort(this,e)})),P("MMMM",0,0,(function(e){return this.localeData().months(this,e)})),H("month","M"),U("month",8),fe("M",re),fe("MM",re,$),fe("MMM",(function(e,t){return t.monthsShortRegex(e)})),fe("MMMM",(function(e,t){return t.monthsRegex(e)})),_e(["M","MM"],(function(e,t){t[1]=q(e)-1})),_e(["MMM","MMMM"],(function(e,t,n,r){var i=n._locale.monthsParse(e,r,n._strict);null!=i?t[1]=i:m(n).invalidMonth=e}));var Ae="January_February_March_April_May_June_July_August_September_October_November_December".split("_"),Ce="Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),xe=/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/,Ee=pe,Le=pe;function Se(e,t,n){var r,i,o,a=e.toLocaleLowerCase();if(!this._monthsParse)for(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[],r=0;r<12;++r)o=f([2e3,r]),this._shortMonthsParse[r]=this.monthsShort(o,"").toLocaleLowerCase(),this._longMonthsParse[r]=this.months(o,"").toLocaleLowerCase();return n?"MMM"===t?-1!==(i=ve.call(this._shortMonthsParse,a))?i:null:-1!==(i=ve.call(this._longMonthsParse,a))?i:null:"MMM"===t?-1!==(i=ve.call(this._shortMonthsParse,a))||-1!==(i=ve.call(this._longMonthsParse,a))?i:null:-1!==(i=ve.call(this._longMonthsParse,a))||-1!==(i=ve.call(this._shortMonthsParse,a))?i:null}function Te(e,t){var n;if(!e.isValid())return e;if("string"==typeof t)if(/^\d+$/.test(t))t=q(t);else if(!u(t=e.localeData().monthsParse(t)))return e;return n=Math.min(e.date(),we(e.year(),t)),e._d["set"+(e._isUTC?"UTC":"")+"Month"](t,n),e}function Oe(e){return null!=e?(Te(this,e),i.updateOffset(this,!0),this):X(this,"Month")}function Ie(){function e(e,t){return t.length-e.length}var t,n,r=[],i=[],o=[];for(t=0;t<12;t++)n=f([2e3,t]),r.push(this.monthsShort(n,"")),i.push(this.months(n,"")),o.push(this.months(n,"")),o.push(this.monthsShort(n,""));for(r.sort(e),i.sort(e),o.sort(e),t=0;t<12;t++)r[t]=ge(r[t]),i[t]=ge(i[t]);for(t=0;t<24;t++)o[t]=ge(o[t]);this._monthsRegex=new RegExp("^("+o.join("|")+")","i"),this._monthsShortRegex=this._monthsRegex,this._monthsStrictRegex=new RegExp("^("+i.join("|")+")","i"),this._monthsShortStrictRegex=new RegExp("^("+r.join("|")+")","i")}function ke(e){return W(e)?366:365}P("Y",0,0,(function(){var e=this.year();return e<=9999?I(e,4):"+"+e})),P(0,["YY",2],0,(function(){return this.year()%100})),P(0,["YYYY",4],0,"year"),P(0,["YYYYY",5],0,"year"),P(0,["YYYYYY",6,!0],0,"year"),H("year","y"),U("year",1),fe("Y",ue),fe("YY",re,$),fe("YYYY",se,te),fe("YYYYY",le,ne),fe("YYYYYY",le,ne),_e(["YYYYY","YYYYYY"],0),_e("YYYY",(function(e,t){t[0]=2===e.length?i.parseTwoDigitYear(e):q(e)})),_e("YY",(function(e,t){t[0]=i.parseTwoDigitYear(e)})),_e("Y",(function(e,t){t[0]=parseInt(e,10)})),i.parseTwoDigitYear=function(e){return q(e)+(q(e)>68?1900:2e3)};var De=K("FullYear",!0);function Ne(e,t,n,r,i,o,a){var s;return e<100&&e>=0?(s=new Date(e+400,t,n,r,i,o,a),isFinite(s.getFullYear())&&s.setFullYear(e)):s=new Date(e,t,n,r,i,o,a),s}function je(e){var t,n;return e<100&&e>=0?((n=Array.prototype.slice.call(arguments))[0]=e+400,t=new Date(Date.UTC.apply(null,n)),isFinite(t.getUTCFullYear())&&t.setUTCFullYear(e)):t=new Date(Date.UTC.apply(null,arguments)),t}function Pe(e,t,n){var r=7+t-n;return-(7+je(e,0,r).getUTCDay()-t)%7+r-1}function ze(e,t,n,r,i){var o,a,s=1+7*(t-1)+(7+n-r)%7+Pe(e,r,i);return s<=0?a=ke(o=e-1)+s:s>ke(e)?(o=e+1,a=s-ke(e)):(o=e,a=s),{year:o,dayOfYear:a}}function Re(e,t,n){var r,i,o=Pe(e.year(),t,n),a=Math.floor((e.dayOfYear()-o-1)/7)+1;return a<1?r=a+Be(i=e.year()-1,t,n):a>Be(e.year(),t,n)?(r=a-Be(e.year(),t,n),i=e.year()+1):(i=e.year(),r=a),{week:r,year:i}}function Be(e,t,n){var r=Pe(e,t,n),i=Pe(e+1,t,n);return(ke(e)-r+i)/7}function He(e,t){return e.slice(t,7).concat(e.slice(0,t))}P("w",["ww",2],"wo","week"),P("W",["WW",2],"Wo","isoWeek"),H("week","w"),H("isoWeek","W"),U("week",5),U("isoWeek",5),fe("w",re),fe("ww",re,$),fe("W",re),fe("WW",re,$),be(["w","ww","W","WW"],(function(e,t,n,r){t[r.substr(0,1)]=q(e)})),P("d",0,"do","day"),P("dd",0,0,(function(e){return this.localeData().weekdaysMin(this,e)})),P("ddd",0,0,(function(e){return this.localeData().weekdaysShort(this,e)})),P("dddd",0,0,(function(e){return this.localeData().weekdays(this,e)})),P("e",0,0,"weekday"),P("E",0,0,"isoWeekday"),H("day","d"),H("weekday","e"),H("isoWeekday","E"),U("day",11),U("weekday",11),U("isoWeekday",11),fe("d",re),fe("e",re),fe("E",re),fe("dd",(function(e,t){return t.weekdaysMinRegex(e)})),fe("ddd",(function(e,t){return t.weekdaysShortRegex(e)})),fe("dddd",(function(e,t){return t.weekdaysRegex(e)})),be(["dd","ddd","dddd"],(function(e,t,n,r){var i=n._locale.weekdaysParse(e,r,n._strict);null!=i?t.d=i:m(n).invalidWeekday=e})),be(["d","e","E"],(function(e,t,n,r){t[r]=q(e)}));var Fe="Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),Ye="Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),Ve="Su_Mo_Tu_We_Th_Fr_Sa".split("_"),Ue=pe,We=pe,Ge=pe;function qe(e,t,n){var r,i,o,a=e.toLocaleLowerCase();if(!this._weekdaysParse)for(this._weekdaysParse=[],this._shortWeekdaysParse=[],this._minWeekdaysParse=[],r=0;r<7;++r)o=f([2e3,1]).day(r),this._minWeekdaysParse[r]=this.weekdaysMin(o,"").toLocaleLowerCase(),this._shortWeekdaysParse[r]=this.weekdaysShort(o,"").toLocaleLowerCase(),this._weekdaysParse[r]=this.weekdays(o,"").toLocaleLowerCase();return n?"dddd"===t?-1!==(i=ve.call(this._weekdaysParse,a))?i:null:"ddd"===t?-1!==(i=ve.call(this._shortWeekdaysParse,a))?i:null:-1!==(i=ve.call(this._minWeekdaysParse,a))?i:null:"dddd"===t?-1!==(i=ve.call(this._weekdaysParse,a))||-1!==(i=ve.call(this._shortWeekdaysParse,a))||-1!==(i=ve.call(this._minWeekdaysParse,a))?i:null:"ddd"===t?-1!==(i=ve.call(this._shortWeekdaysParse,a))||-1!==(i=ve.call(this._weekdaysParse,a))||-1!==(i=ve.call(this._minWeekdaysParse,a))?i:null:-1!==(i=ve.call(this._minWeekdaysParse,a))||-1!==(i=ve.call(this._weekdaysParse,a))||-1!==(i=ve.call(this._shortWeekdaysParse,a))?i:null}function Ke(){function e(e,t){return t.length-e.length}var t,n,r,i,o,a=[],s=[],l=[],c=[];for(t=0;t<7;t++)n=f([2e3,1]).day(t),r=ge(this.weekdaysMin(n,"")),i=ge(this.weekdaysShort(n,"")),o=ge(this.weekdays(n,"")),a.push(r),s.push(i),l.push(o),c.push(r),c.push(i),c.push(o);a.sort(e),s.sort(e),l.sort(e),c.sort(e),this._weekdaysRegex=new RegExp("^("+c.join("|")+")","i"),this._weekdaysShortRegex=this._weekdaysRegex,this._weekdaysMinRegex=this._weekdaysRegex,this._weekdaysStrictRegex=new RegExp("^("+l.join("|")+")","i"),this._weekdaysShortStrictRegex=new RegExp("^("+s.join("|")+")","i"),this._weekdaysMinStrictRegex=new RegExp("^("+a.join("|")+")","i")}function Xe(){return this.hours()%12||12}function Je(e,t){P(e,0,0,(function(){return this.localeData().meridiem(this.hours(),this.minutes(),t)}))}function Qe(e,t){return t._meridiemParse}P("H",["HH",2],0,"hour"),P("h",["hh",2],0,Xe),P("k",["kk",2],0,(function(){return this.hours()||24})),P("hmm",0,0,(function(){return""+Xe.apply(this)+I(this.minutes(),2)})),P("hmmss",0,0,(function(){return""+Xe.apply(this)+I(this.minutes(),2)+I(this.seconds(),2)})),P("Hmm",0,0,(function(){return""+this.hours()+I(this.minutes(),2)})),P("Hmmss",0,0,(function(){return""+this.hours()+I(this.minutes(),2)+I(this.seconds(),2)})),Je("a",!0),Je("A",!1),H("hour","h"),U("hour",13),fe("a",Qe),fe("A",Qe),fe("H",re),fe("h",re),fe("k",re),fe("HH",re,$),fe("hh",re,$),fe("kk",re,$),fe("hmm",ie),fe("hmmss",oe),fe("Hmm",ie),fe("Hmmss",oe),_e(["H","HH"],3),_e(["k","kk"],(function(e,t,n){var r=q(e);t[3]=24===r?0:r})),_e(["a","A"],(function(e,t,n){n._isPm=n._locale.isPM(e),n._meridiem=e})),_e(["h","hh"],(function(e,t,n){t[3]=q(e),m(n).bigHour=!0})),_e("hmm",(function(e,t,n){var r=e.length-2;t[3]=q(e.substr(0,r)),t[4]=q(e.substr(r)),m(n).bigHour=!0})),_e("hmmss",(function(e,t,n){var r=e.length-4,i=e.length-2;t[3]=q(e.substr(0,r)),t[4]=q(e.substr(r,2)),t[5]=q(e.substr(i)),m(n).bigHour=!0})),_e("Hmm",(function(e,t,n){var r=e.length-2;t[3]=q(e.substr(0,r)),t[4]=q(e.substr(r))})),_e("Hmmss",(function(e,t,n){var r=e.length-4,i=e.length-2;t[3]=q(e.substr(0,r)),t[4]=q(e.substr(r,2)),t[5]=q(e.substr(i))}));var Ze,$e=K("Hours",!0),et={calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},longDateFormat:{LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},invalidDate:"Invalid date",ordinal:"%d",dayOfMonthOrdinalParse:/\d{1,2}/,relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",w:"a week",ww:"%d weeks",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},months:Ae,monthsShort:Ce,week:{dow:0,doy:6},weekdays:Fe,weekdaysMin:Ve,weekdaysShort:Ye,meridiemParse:/[ap]\.?m?\.?/i},tt={},nt={};function rt(e,t){var n,r=Math.min(e.length,t.length);for(n=0;n<r;n+=1)if(e[n]!==t[n])return n;return r}function it(e){return e?e.toLowerCase().replace("_","-"):e}function ot(t){var r=null;if(void 0===tt[t]&&void 0!==e&&e&&e.exports)try{r=Ze._abbr,n(620)("./"+t),at(r)}catch(e){tt[t]=null}return tt[t]}function at(e,t){var n;return e&&((n=c(t)?lt(e):st(e,t))?Ze=n:"undefined"!=typeof console&&console.warn&&console.warn("Locale "+e+" not found. Did you forget to load it?")),Ze._abbr}function st(e,t){if(null!==t){var n,r=et;if(t.abbr=e,null!=tt[e])L("defineLocaleOverride","use moment.updateLocale(localeName, config) to change an existing locale. moment.defineLocale(localeName, config) should only be used for creating a new locale See http://momentjs.com/guides/#/warnings/define-locale/ for more info."),r=tt[e]._config;else if(null!=t.parentLocale)if(null!=tt[t.parentLocale])r=tt[t.parentLocale]._config;else{if(null==(n=ot(t.parentLocale)))return nt[t.parentLocale]||(nt[t.parentLocale]=[]),nt[t.parentLocale].push({name:e,config:t}),null;r=n._config}return tt[e]=new O(T(r,t)),nt[e]&&nt[e].forEach((function(e){st(e.name,e.config)})),at(e),tt[e]}return delete tt[e],null}function lt(e){var t;if(e&&e._locale&&e._locale._abbr&&(e=e._locale._abbr),!e)return Ze;if(!o(e)){if(t=ot(e))return t;e=[e]}return function(e){for(var t,n,r,i,o=0;o<e.length;){for(t=(i=it(e[o]).split("-")).length,n=(n=it(e[o+1]))?n.split("-"):null;t>0;){if(r=ot(i.slice(0,t).join("-")))return r;if(n&&n.length>=t&&rt(i,n)>=t-1)break;t--}o++}return Ze}(e)}function ct(e){var t,n=e._a;return n&&-2===m(e).overflow&&(t=n[1]<0||n[1]>11?1:n[2]<1||n[2]>we(n[0],n[1])?2:n[3]<0||n[3]>24||24===n[3]&&(0!==n[4]||0!==n[5]||0!==n[6])?3:n[4]<0||n[4]>59?4:n[5]<0||n[5]>59?5:n[6]<0||n[6]>999?6:-1,m(e)._overflowDayOfYear&&(t<0||t>2)&&(t=2),m(e)._overflowWeeks&&-1===t&&(t=7),m(e)._overflowWeekday&&-1===t&&(t=8),m(e).overflow=t),e}var ut=/^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,dt=/^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d|))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,ht=/Z|[+-]\d\d(?::?\d\d)?/,pt=[["YYYYYY-MM-DD",/[+-]\d{6}-\d\d-\d\d/],["YYYY-MM-DD",/\d{4}-\d\d-\d\d/],["GGGG-[W]WW-E",/\d{4}-W\d\d-\d/],["GGGG-[W]WW",/\d{4}-W\d\d/,!1],["YYYY-DDD",/\d{4}-\d{3}/],["YYYY-MM",/\d{4}-\d\d/,!1],["YYYYYYMMDD",/[+-]\d{10}/],["YYYYMMDD",/\d{8}/],["GGGG[W]WWE",/\d{4}W\d{3}/],["GGGG[W]WW",/\d{4}W\d{2}/,!1],["YYYYDDD",/\d{7}/],["YYYYMM",/\d{6}/,!1],["YYYY",/\d{4}/,!1]],ft=[["HH:mm:ss.SSSS",/\d\d:\d\d:\d\d\.\d+/],["HH:mm:ss,SSSS",/\d\d:\d\d:\d\d,\d+/],["HH:mm:ss",/\d\d:\d\d:\d\d/],["HH:mm",/\d\d:\d\d/],["HHmmss.SSSS",/\d\d\d\d\d\d\.\d+/],["HHmmss,SSSS",/\d\d\d\d\d\d,\d+/],["HHmmss",/\d\d\d\d\d\d/],["HHmm",/\d\d\d\d/],["HH",/\d\d/]],mt=/^\/?Date\((-?\d+)/i,gt=/^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/,vt={UT:0,GMT:0,EDT:-240,EST:-300,CDT:-300,CST:-360,MDT:-360,MST:-420,PDT:-420,PST:-480};function yt(e){var t,n,r,i,o,a,s=e._i,l=ut.exec(s)||dt.exec(s);if(l){for(m(e).iso=!0,t=0,n=pt.length;t<n;t++)if(pt[t][1].exec(l[1])){i=pt[t][0],r=!1!==pt[t][2];break}if(null==i)return void(e._isValid=!1);if(l[3]){for(t=0,n=ft.length;t<n;t++)if(ft[t][1].exec(l[3])){o=(l[2]||" ")+ft[t][0];break}if(null==o)return void(e._isValid=!1)}if(!r&&null!=o)return void(e._isValid=!1);if(l[4]){if(!ht.exec(l[4]))return void(e._isValid=!1);a="Z"}e._f=i+(o||"")+(a||""),At(e)}else e._isValid=!1}function _t(e){var t=parseInt(e,10);return t<=49?2e3+t:t<=999?1900+t:t}function bt(e){var t,n,r,i,o,a,s,l,c=gt.exec(e._i.replace(/\([^)]*\)|[\n\t]/g," ").replace(/(\s\s+)/g," ").replace(/^\s\s*/,"").replace(/\s\s*$/,""));if(c){if(n=c[4],r=c[3],i=c[2],o=c[5],a=c[6],s=c[7],l=[_t(n),Ce.indexOf(r),parseInt(i,10),parseInt(o,10),parseInt(a,10)],s&&l.push(parseInt(s,10)),t=l,!function(e,t,n){return!e||Ye.indexOf(e)===new Date(t[0],t[1],t[2]).getDay()||(m(n).weekdayMismatch=!0,n._isValid=!1,!1)}(c[1],t,e))return;e._a=t,e._tzm=function(e,t,n){if(e)return vt[e];if(t)return 0;var r=parseInt(n,10),i=r%100;return(r-i)/100*60+i}(c[8],c[9],c[10]),e._d=je.apply(null,e._a),e._d.setUTCMinutes(e._d.getUTCMinutes()-e._tzm),m(e).rfc2822=!0}else e._isValid=!1}function Mt(e,t,n){return null!=e?e:null!=t?t:n}function wt(e){var t,n,r,o,a,s=[];if(!e._d){for(r=function(e){var t=new Date(i.now());return e._useUTC?[t.getUTCFullYear(),t.getUTCMonth(),t.getUTCDate()]:[t.getFullYear(),t.getMonth(),t.getDate()]}(e),e._w&&null==e._a[2]&&null==e._a[1]&&function(e){var t,n,r,i,o,a,s,l,c;null!=(t=e._w).GG||null!=t.W||null!=t.E?(o=1,a=4,n=Mt(t.GG,e._a[0],Re(Et(),1,4).year),r=Mt(t.W,1),((i=Mt(t.E,1))<1||i>7)&&(l=!0)):(o=e._locale._week.dow,a=e._locale._week.doy,c=Re(Et(),o,a),n=Mt(t.gg,e._a[0],c.year),r=Mt(t.w,c.week),null!=t.d?((i=t.d)<0||i>6)&&(l=!0):null!=t.e?(i=t.e+o,(t.e<0||t.e>6)&&(l=!0)):i=o),r<1||r>Be(n,o,a)?m(e)._overflowWeeks=!0:null!=l?m(e)._overflowWeekday=!0:(s=ze(n,r,i,o,a),e._a[0]=s.year,e._dayOfYear=s.dayOfYear)}(e),null!=e._dayOfYear&&(a=Mt(e._a[0],r[0]),(e._dayOfYear>ke(a)||0===e._dayOfYear)&&(m(e)._overflowDayOfYear=!0),n=je(a,0,e._dayOfYear),e._a[1]=n.getUTCMonth(),e._a[2]=n.getUTCDate()),t=0;t<3&&null==e._a[t];++t)e._a[t]=s[t]=r[t];for(;t<7;t++)e._a[t]=s[t]=null==e._a[t]?2===t?1:0:e._a[t];24===e._a[3]&&0===e._a[4]&&0===e._a[5]&&0===e._a[6]&&(e._nextDay=!0,e._a[3]=0),e._d=(e._useUTC?je:Ne).apply(null,s),o=e._useUTC?e._d.getUTCDay():e._d.getDay(),null!=e._tzm&&e._d.setUTCMinutes(e._d.getUTCMinutes()-e._tzm),e._nextDay&&(e._a[3]=24),e._w&&void 0!==e._w.d&&e._w.d!==o&&(m(e).weekdayMismatch=!0)}}function At(e){if(e._f!==i.ISO_8601)if(e._f!==i.RFC_2822){e._a=[],m(e).empty=!0;var t,n,r,o,a,s,l=""+e._i,c=l.length,u=0;for(r=R(e._f,e._locale).match(k)||[],t=0;t<r.length;t++)o=r[t],(n=(l.match(me(o,e))||[])[0])&&((a=l.substr(0,l.indexOf(n))).length>0&&m(e).unusedInput.push(a),l=l.slice(l.indexOf(n)+n.length),u+=n.length),j[o]?(n?m(e).empty=!1:m(e).unusedTokens.push(o),Me(o,n,e)):e._strict&&!n&&m(e).unusedTokens.push(o);m(e).charsLeftOver=c-u,l.length>0&&m(e).unusedInput.push(l),e._a[3]<=12&&!0===m(e).bigHour&&e._a[3]>0&&(m(e).bigHour=void 0),m(e).parsedDateParts=e._a.slice(0),m(e).meridiem=e._meridiem,e._a[3]=function(e,t,n){var r;return null==n?t:null!=e.meridiemHour?e.meridiemHour(t,n):null!=e.isPM?((r=e.isPM(n))&&t<12&&(t+=12),r||12!==t||(t=0),t):t}(e._locale,e._a[3],e._meridiem),null!==(s=m(e).era)&&(e._a[0]=e._locale.erasConvertYear(s,e._a[0])),wt(e),ct(e)}else bt(e);else yt(e)}function Ct(e){var t=e._i,n=e._f;return e._locale=e._locale||lt(e._l),null===t||void 0===n&&""===t?v({nullInput:!0}):("string"==typeof t&&(e._i=t=e._locale.preparse(t)),w(t)?new M(ct(t)):(d(t)?e._d=t:o(n)?function(e){var t,n,r,i,o,a,s=!1;if(0===e._f.length)return m(e).invalidFormat=!0,void(e._d=new Date(NaN));for(i=0;i<e._f.length;i++)o=0,a=!1,t=b({},e),null!=e._useUTC&&(t._useUTC=e._useUTC),t._f=e._f[i],At(t),g(t)&&(a=!0),o+=m(t).charsLeftOver,o+=10*m(t).unusedTokens.length,m(t).score=o,s?o<r&&(r=o,n=t):(null==r||o<r||a)&&(r=o,n=t,a&&(s=!0));p(e,n||t)}(e):n?At(e):function(e){var t=e._i;c(t)?e._d=new Date(i.now()):d(t)?e._d=new Date(t.valueOf()):"string"==typeof t?function(e){var t=mt.exec(e._i);null===t?(yt(e),!1===e._isValid&&(delete e._isValid,bt(e),!1===e._isValid&&(delete e._isValid,e._strict?e._isValid=!1:i.createFromInputFallback(e)))):e._d=new Date(+t[1])}(e):o(t)?(e._a=h(t.slice(0),(function(e){return parseInt(e,10)})),wt(e)):a(t)?function(e){if(!e._d){var t=Y(e._i),n=void 0===t.day?t.date:t.day;e._a=h([t.year,t.month,n,t.hour,t.minute,t.second,t.millisecond],(function(e){return e&&parseInt(e,10)})),wt(e)}}(e):u(t)?e._d=new Date(t):i.createFromInputFallback(e)}(e),g(e)||(e._d=null),e))}function xt(e,t,n,r,i){var s,c={};return!0!==t&&!1!==t||(r=t,t=void 0),!0!==n&&!1!==n||(r=n,n=void 0),(a(e)&&l(e)||o(e)&&0===e.length)&&(e=void 0),c._isAMomentObject=!0,c._useUTC=c._isUTC=i,c._l=n,c._i=e,c._f=t,c._strict=r,(s=new M(ct(Ct(c))))._nextDay&&(s.add(1,"d"),s._nextDay=void 0),s}function Et(e,t,n,r){return xt(e,t,n,r,!1)}i.createFromInputFallback=C("value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are discouraged. Please refer to http://momentjs.com/guides/#/warnings/js-date/ for more info.",(function(e){e._d=new Date(e._i+(e._useUTC?" UTC":""))})),i.ISO_8601=function(){},i.RFC_2822=function(){};var Lt=C("moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var e=Et.apply(null,arguments);return this.isValid()&&e.isValid()?e<this?this:e:v()})),St=C("moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var e=Et.apply(null,arguments);return this.isValid()&&e.isValid()?e>this?this:e:v()}));function Tt(e,t){var n,r;if(1===t.length&&o(t[0])&&(t=t[0]),!t.length)return Et();for(n=t[0],r=1;r<t.length;++r)t[r].isValid()&&!t[r][e](n)||(n=t[r]);return n}var Ot=["year","quarter","month","week","day","hour","minute","second","millisecond"];function It(e){var t=Y(e),n=t.year||0,r=t.quarter||0,i=t.month||0,o=t.week||t.isoWeek||0,a=t.day||0,l=t.hour||0,c=t.minute||0,u=t.second||0,d=t.millisecond||0;this._isValid=function(e){var t,n,r=!1;for(t in e)if(s(e,t)&&(-1===ve.call(Ot,t)||null!=e[t]&&isNaN(e[t])))return!1;for(n=0;n<Ot.length;++n)if(e[Ot[n]]){if(r)return!1;parseFloat(e[Ot[n]])!==q(e[Ot[n]])&&(r=!0)}return!0}(t),this._milliseconds=+d+1e3*u+6e4*c+1e3*l*60*60,this._days=+a+7*o,this._months=+i+3*r+12*n,this._data={},this._locale=lt(),this._bubble()}function kt(e){return e instanceof It}function Dt(e){return e<0?-1*Math.round(-1*e):Math.round(e)}function Nt(e,t){P(e,0,0,(function(){var e=this.utcOffset(),n="+";return e<0&&(e=-e,n="-"),n+I(~~(e/60),2)+t+I(~~e%60,2)}))}Nt("Z",":"),Nt("ZZ",""),fe("Z",he),fe("ZZ",he),_e(["Z","ZZ"],(function(e,t,n){n._useUTC=!0,n._tzm=Pt(he,e)}));var jt=/([\+\-]|\d\d)/gi;function Pt(e,t){var n,r,i=(t||"").match(e);return null===i?null:0===(r=60*(n=((i[i.length-1]||[])+"").match(jt)||["-",0,0])[1]+q(n[2]))?0:"+"===n[0]?r:-r}function zt(e,t){var n,r;return t._isUTC?(n=t.clone(),r=(w(e)||d(e)?e.valueOf():Et(e).valueOf())-n.valueOf(),n._d.setTime(n._d.valueOf()+r),i.updateOffset(n,!1),n):Et(e).local()}function Rt(e){return-Math.round(e._d.getTimezoneOffset())}function Bt(){return!!this.isValid()&&this._isUTC&&0===this._offset}i.updateOffset=function(){};var Ht=/^(-|\+)?(?:(\d*)[. ])?(\d+):(\d+)(?::(\d+)(\.\d*)?)?$/,Ft=/^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;function Yt(e,t){var n,r,i,o,a,l,c=e,d=null;return kt(e)?c={ms:e._milliseconds,d:e._days,M:e._months}:u(e)||!isNaN(+e)?(c={},t?c[t]=+e:c.milliseconds=+e):(d=Ht.exec(e))?(n="-"===d[1]?-1:1,c={y:0,d:q(d[2])*n,h:q(d[3])*n,m:q(d[4])*n,s:q(d[5])*n,ms:q(Dt(1e3*d[6]))*n}):(d=Ft.exec(e))?(n="-"===d[1]?-1:1,c={y:Vt(d[2],n),M:Vt(d[3],n),w:Vt(d[4],n),d:Vt(d[5],n),h:Vt(d[6],n),m:Vt(d[7],n),s:Vt(d[8],n)}):null==c?c={}:"object"==typeof c&&("from"in c||"to"in c)&&(o=Et(c.from),a=Et(c.to),i=o.isValid()&&a.isValid()?(a=zt(a,o),o.isBefore(a)?l=Ut(o,a):((l=Ut(a,o)).milliseconds=-l.milliseconds,l.months=-l.months),l):{milliseconds:0,months:0},(c={}).ms=i.milliseconds,c.M=i.months),r=new It(c),kt(e)&&s(e,"_locale")&&(r._locale=e._locale),kt(e)&&s(e,"_isValid")&&(r._isValid=e._isValid),r}function Vt(e,t){var n=e&&parseFloat(e.replace(",","."));return(isNaN(n)?0:n)*t}function Ut(e,t){var n={};return n.months=t.month()-e.month()+12*(t.year()-e.year()),e.clone().add(n.months,"M").isAfter(t)&&--n.months,n.milliseconds=+t-+e.clone().add(n.months,"M"),n}function Wt(e,t){return function(n,r){var i;return null===r||isNaN(+r)||(L(t,"moment()."+t+"(period, number) is deprecated. Please use moment()."+t+"(number, period). See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info."),i=n,n=r,r=i),Gt(this,Yt(n,r),e),this}}function Gt(e,t,n,r){var o=t._milliseconds,a=Dt(t._days),s=Dt(t._months);e.isValid()&&(r=null==r||r,s&&Te(e,X(e,"Month")+s*n),a&&J(e,"Date",X(e,"Date")+a*n),o&&e._d.setTime(e._d.valueOf()+o*n),r&&i.updateOffset(e,a||s))}Yt.fn=It.prototype,Yt.invalid=function(){return Yt(NaN)};var qt=Wt(1,"add"),Kt=Wt(-1,"subtract");function Xt(e){return"string"==typeof e||e instanceof String}function Jt(e){return w(e)||d(e)||Xt(e)||u(e)||function(e){var t=o(e),n=!1;return t&&(n=0===e.filter((function(t){return!u(t)&&Xt(e)})).length),t&&n}(e)||function(e){var t,n,r=a(e)&&!l(e),i=!1,o=["years","year","y","months","month","M","days","day","d","dates","date","D","hours","hour","h","minutes","minute","m","seconds","second","s","milliseconds","millisecond","ms"];for(t=0;t<o.length;t+=1)n=o[t],i=i||s(e,n);return r&&i}(e)||null==e}function Qt(e){var t,n=a(e)&&!l(e),r=!1,i=["sameDay","nextDay","lastDay","nextWeek","lastWeek","sameElse"];for(t=0;t<i.length;t+=1)r=r||s(e,i[t]);return n&&r}function Zt(e,t){if(e.date()<t.date())return-Zt(t,e);var n=12*(t.year()-e.year())+(t.month()-e.month()),r=e.clone().add(n,"months");return-(n+(t-r<0?(t-r)/(r-e.clone().add(n-1,"months")):(t-r)/(e.clone().add(n+1,"months")-r)))||0}function $t(e){var t;return void 0===e?this._locale._abbr:(null!=(t=lt(e))&&(this._locale=t),this)}i.defaultFormat="YYYY-MM-DDTHH:mm:ssZ",i.defaultFormatUtc="YYYY-MM-DDTHH:mm:ss[Z]";var en=C("moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",(function(e){return void 0===e?this.localeData():this.locale(e)}));function tn(){return this._locale}function nn(e,t){return(e%t+t)%t}function rn(e,t,n){return e<100&&e>=0?new Date(e+400,t,n)-126227808e5:new Date(e,t,n).valueOf()}function on(e,t,n){return e<100&&e>=0?Date.UTC(e+400,t,n)-126227808e5:Date.UTC(e,t,n)}function an(e,t){return t.erasAbbrRegex(e)}function sn(){var e,t,n=[],r=[],i=[],o=[],a=this.eras();for(e=0,t=a.length;e<t;++e)r.push(ge(a[e].name)),n.push(ge(a[e].abbr)),i.push(ge(a[e].narrow)),o.push(ge(a[e].name)),o.push(ge(a[e].abbr)),o.push(ge(a[e].narrow));this._erasRegex=new RegExp("^("+o.join("|")+")","i"),this._erasNameRegex=new RegExp("^("+r.join("|")+")","i"),this._erasAbbrRegex=new RegExp("^("+n.join("|")+")","i"),this._erasNarrowRegex=new RegExp("^("+i.join("|")+")","i")}function ln(e,t){P(0,[e,e.length],0,t)}function cn(e,t,n,r,i){var o;return null==e?Re(this,r,i).year:(t>(o=Be(e,r,i))&&(t=o),un.call(this,e,t,n,r,i))}function un(e,t,n,r,i){var o=ze(e,t,n,r,i),a=je(o.year,0,o.dayOfYear);return this.year(a.getUTCFullYear()),this.month(a.getUTCMonth()),this.date(a.getUTCDate()),this}P("N",0,0,"eraAbbr"),P("NN",0,0,"eraAbbr"),P("NNN",0,0,"eraAbbr"),P("NNNN",0,0,"eraName"),P("NNNNN",0,0,"eraNarrow"),P("y",["y",1],"yo","eraYear"),P("y",["yy",2],0,"eraYear"),P("y",["yyy",3],0,"eraYear"),P("y",["yyyy",4],0,"eraYear"),fe("N",an),fe("NN",an),fe("NNN",an),fe("NNNN",(function(e,t){return t.erasNameRegex(e)})),fe("NNNNN",(function(e,t){return t.erasNarrowRegex(e)})),_e(["N","NN","NNN","NNNN","NNNNN"],(function(e,t,n,r){var i=n._locale.erasParse(e,r,n._strict);i?m(n).era=i:m(n).invalidEra=e})),fe("y",ce),fe("yy",ce),fe("yyy",ce),fe("yyyy",ce),fe("yo",(function(e,t){return t._eraYearOrdinalRegex||ce})),_e(["y","yy","yyy","yyyy"],0),_e(["yo"],(function(e,t,n,r){var i;n._locale._eraYearOrdinalRegex&&(i=e.match(n._locale._eraYearOrdinalRegex)),n._locale.eraYearOrdinalParse?t[0]=n._locale.eraYearOrdinalParse(e,i):t[0]=parseInt(e,10)})),P(0,["gg",2],0,(function(){return this.weekYear()%100})),P(0,["GG",2],0,(function(){return this.isoWeekYear()%100})),ln("gggg","weekYear"),ln("ggggg","weekYear"),ln("GGGG","isoWeekYear"),ln("GGGGG","isoWeekYear"),H("weekYear","gg"),H("isoWeekYear","GG"),U("weekYear",1),U("isoWeekYear",1),fe("G",ue),fe("g",ue),fe("GG",re,$),fe("gg",re,$),fe("GGGG",se,te),fe("gggg",se,te),fe("GGGGG",le,ne),fe("ggggg",le,ne),be(["gggg","ggggg","GGGG","GGGGG"],(function(e,t,n,r){t[r.substr(0,2)]=q(e)})),be(["gg","GG"],(function(e,t,n,r){t[r]=i.parseTwoDigitYear(e)})),P("Q",0,"Qo","quarter"),H("quarter","Q"),U("quarter",7),fe("Q",Z),_e("Q",(function(e,t){t[1]=3*(q(e)-1)})),P("D",["DD",2],"Do","date"),H("date","D"),U("date",9),fe("D",re),fe("DD",re,$),fe("Do",(function(e,t){return e?t._dayOfMonthOrdinalParse||t._ordinalParse:t._dayOfMonthOrdinalParseLenient})),_e(["D","DD"],2),_e("Do",(function(e,t){t[2]=q(e.match(re)[0])}));var dn=K("Date",!0);P("DDD",["DDDD",3],"DDDo","dayOfYear"),H("dayOfYear","DDD"),U("dayOfYear",4),fe("DDD",ae),fe("DDDD",ee),_e(["DDD","DDDD"],(function(e,t,n){n._dayOfYear=q(e)})),P("m",["mm",2],0,"minute"),H("minute","m"),U("minute",14),fe("m",re),fe("mm",re,$),_e(["m","mm"],4);var hn=K("Minutes",!1);P("s",["ss",2],0,"second"),H("second","s"),U("second",15),fe("s",re),fe("ss",re,$),_e(["s","ss"],5);var pn,fn,mn=K("Seconds",!1);for(P("S",0,0,(function(){return~~(this.millisecond()/100)})),P(0,["SS",2],0,(function(){return~~(this.millisecond()/10)})),P(0,["SSS",3],0,"millisecond"),P(0,["SSSS",4],0,(function(){return 10*this.millisecond()})),P(0,["SSSSS",5],0,(function(){return 100*this.millisecond()})),P(0,["SSSSSS",6],0,(function(){return 1e3*this.millisecond()})),P(0,["SSSSSSS",7],0,(function(){return 1e4*this.millisecond()})),P(0,["SSSSSSSS",8],0,(function(){return 1e5*this.millisecond()})),P(0,["SSSSSSSSS",9],0,(function(){return 1e6*this.millisecond()})),H("millisecond","ms"),U("millisecond",16),fe("S",ae,Z),fe("SS",ae,$),fe("SSS",ae,ee),pn="SSSS";pn.length<=9;pn+="S")fe(pn,ce);function gn(e,t){t[6]=q(1e3*("0."+e))}for(pn="S";pn.length<=9;pn+="S")_e(pn,gn);fn=K("Milliseconds",!1),P("z",0,0,"zoneAbbr"),P("zz",0,0,"zoneName");var vn=M.prototype;function yn(e){return e}vn.add=qt,vn.calendar=function(e,t){1===arguments.length&&(arguments[0]?Jt(arguments[0])?(e=arguments[0],t=void 0):Qt(arguments[0])&&(t=arguments[0],e=void 0):(e=void 0,t=void 0));var n=e||Et(),r=zt(n,this).startOf("day"),o=i.calendarFormat(this,r)||"sameElse",a=t&&(S(t[o])?t[o].call(this,n):t[o]);return this.format(a||this.localeData().calendar(o,this,Et(n)))},vn.clone=function(){return new M(this)},vn.diff=function(e,t,n){var r,i,o;if(!this.isValid())return NaN;if(!(r=zt(e,this)).isValid())return NaN;switch(i=6e4*(r.utcOffset()-this.utcOffset()),t=F(t)){case"year":o=Zt(this,r)/12;break;case"month":o=Zt(this,r);break;case"quarter":o=Zt(this,r)/3;break;case"second":o=(this-r)/1e3;break;case"minute":o=(this-r)/6e4;break;case"hour":o=(this-r)/36e5;break;case"day":o=(this-r-i)/864e5;break;case"week":o=(this-r-i)/6048e5;break;default:o=this-r}return n?o:G(o)},vn.endOf=function(e){var t,n;if(void 0===(e=F(e))||"millisecond"===e||!this.isValid())return this;switch(n=this._isUTC?on:rn,e){case"year":t=n(this.year()+1,0,1)-1;break;case"quarter":t=n(this.year(),this.month()-this.month()%3+3,1)-1;break;case"month":t=n(this.year(),this.month()+1,1)-1;break;case"week":t=n(this.year(),this.month(),this.date()-this.weekday()+7)-1;break;case"isoWeek":t=n(this.year(),this.month(),this.date()-(this.isoWeekday()-1)+7)-1;break;case"day":case"date":t=n(this.year(),this.month(),this.date()+1)-1;break;case"hour":t=this._d.valueOf(),t+=36e5-nn(t+(this._isUTC?0:6e4*this.utcOffset()),36e5)-1;break;case"minute":t=this._d.valueOf(),t+=6e4-nn(t,6e4)-1;break;case"second":t=this._d.valueOf(),t+=1e3-nn(t,1e3)-1}return this._d.setTime(t),i.updateOffset(this,!0),this},vn.format=function(e){e||(e=this.isUtc()?i.defaultFormatUtc:i.defaultFormat);var t=z(this,e);return this.localeData().postformat(t)},vn.from=function(e,t){return this.isValid()&&(w(e)&&e.isValid()||Et(e).isValid())?Yt({to:this,from:e}).locale(this.locale()).humanize(!t):this.localeData().invalidDate()},vn.fromNow=function(e){return this.from(Et(),e)},vn.to=function(e,t){return this.isValid()&&(w(e)&&e.isValid()||Et(e).isValid())?Yt({from:this,to:e}).locale(this.locale()).humanize(!t):this.localeData().invalidDate()},vn.toNow=function(e){return this.to(Et(),e)},vn.get=function(e){return S(this[e=F(e)])?this[e]():this},vn.invalidAt=function(){return m(this).overflow},vn.isAfter=function(e,t){var n=w(e)?e:Et(e);return!(!this.isValid()||!n.isValid())&&("millisecond"===(t=F(t)||"millisecond")?this.valueOf()>n.valueOf():n.valueOf()<this.clone().startOf(t).valueOf())},vn.isBefore=function(e,t){var n=w(e)?e:Et(e);return!(!this.isValid()||!n.isValid())&&("millisecond"===(t=F(t)||"millisecond")?this.valueOf()<n.valueOf():this.clone().endOf(t).valueOf()<n.valueOf())},vn.isBetween=function(e,t,n,r){var i=w(e)?e:Et(e),o=w(t)?t:Et(t);return!!(this.isValid()&&i.isValid()&&o.isValid())&&(("("===(r=r||"()")[0]?this.isAfter(i,n):!this.isBefore(i,n))&&(")"===r[1]?this.isBefore(o,n):!this.isAfter(o,n)))},vn.isSame=function(e,t){var n,r=w(e)?e:Et(e);return!(!this.isValid()||!r.isValid())&&("millisecond"===(t=F(t)||"millisecond")?this.valueOf()===r.valueOf():(n=r.valueOf(),this.clone().startOf(t).valueOf()<=n&&n<=this.clone().endOf(t).valueOf()))},vn.isSameOrAfter=function(e,t){return this.isSame(e,t)||this.isAfter(e,t)},vn.isSameOrBefore=function(e,t){return this.isSame(e,t)||this.isBefore(e,t)},vn.isValid=function(){return g(this)},vn.lang=en,vn.locale=$t,vn.localeData=tn,vn.max=St,vn.min=Lt,vn.parsingFlags=function(){return p({},m(this))},vn.set=function(e,t){if("object"==typeof e){var n,r=function(e){var t,n=[];for(t in e)s(e,t)&&n.push({unit:t,priority:V[t]});return n.sort((function(e,t){return e.priority-t.priority})),n}(e=Y(e));for(n=0;n<r.length;n++)this[r[n].unit](e[r[n].unit])}else if(S(this[e=F(e)]))return this[e](t);return this},vn.startOf=function(e){var t,n;if(void 0===(e=F(e))||"millisecond"===e||!this.isValid())return this;switch(n=this._isUTC?on:rn,e){case"year":t=n(this.year(),0,1);break;case"quarter":t=n(this.year(),this.month()-this.month()%3,1);break;case"month":t=n(this.year(),this.month(),1);break;case"week":t=n(this.year(),this.month(),this.date()-this.weekday());break;case"isoWeek":t=n(this.year(),this.month(),this.date()-(this.isoWeekday()-1));break;case"day":case"date":t=n(this.year(),this.month(),this.date());break;case"hour":t=this._d.valueOf(),t-=nn(t+(this._isUTC?0:6e4*this.utcOffset()),36e5);break;case"minute":t=this._d.valueOf(),t-=nn(t,6e4);break;case"second":t=this._d.valueOf(),t-=nn(t,1e3)}return this._d.setTime(t),i.updateOffset(this,!0),this},vn.subtract=Kt,vn.toArray=function(){var e=this;return[e.year(),e.month(),e.date(),e.hour(),e.minute(),e.second(),e.millisecond()]},vn.toObject=function(){var e=this;return{years:e.year(),months:e.month(),date:e.date(),hours:e.hours(),minutes:e.minutes(),seconds:e.seconds(),milliseconds:e.milliseconds()}},vn.toDate=function(){return new Date(this.valueOf())},vn.toISOString=function(e){if(!this.isValid())return null;var t=!0!==e,n=t?this.clone().utc():this;return n.year()<0||n.year()>9999?z(n,t?"YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYYYY-MM-DD[T]HH:mm:ss.SSSZ"):S(Date.prototype.toISOString)?t?this.toDate().toISOString():new Date(this.valueOf()+60*this.utcOffset()*1e3).toISOString().replace("Z",z(n,"Z")):z(n,t?"YYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYY-MM-DD[T]HH:mm:ss.SSSZ")},vn.inspect=function(){if(!this.isValid())return"moment.invalid(/* "+this._i+" */)";var e,t,n,r="moment",i="";return this.isLocal()||(r=0===this.utcOffset()?"moment.utc":"moment.parseZone",i="Z"),e="["+r+'("]',t=0<=this.year()&&this.year()<=9999?"YYYY":"YYYYYY",n=i+'[")]',this.format(e+t+"-MM-DD[T]HH:mm:ss.SSS"+n)},"undefined"!=typeof Symbol&&null!=Symbol.for&&(vn[Symbol.for("nodejs.util.inspect.custom")]=function(){return"Moment<"+this.format()+">"}),vn.toJSON=function(){return this.isValid()?this.toISOString():null},vn.toString=function(){return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ")},vn.unix=function(){return Math.floor(this.valueOf()/1e3)},vn.valueOf=function(){return this._d.valueOf()-6e4*(this._offset||0)},vn.creationData=function(){return{input:this._i,format:this._f,locale:this._locale,isUTC:this._isUTC,strict:this._strict}},vn.eraName=function(){var e,t,n,r=this.localeData().eras();for(e=0,t=r.length;e<t;++e){if(n=this.clone().startOf("day").valueOf(),r[e].since<=n&&n<=r[e].until)return r[e].name;if(r[e].until<=n&&n<=r[e].since)return r[e].name}return""},vn.eraNarrow=function(){var e,t,n,r=this.localeData().eras();for(e=0,t=r.length;e<t;++e){if(n=this.clone().startOf("day").valueOf(),r[e].since<=n&&n<=r[e].until)return r[e].narrow;if(r[e].until<=n&&n<=r[e].since)return r[e].narrow}return""},vn.eraAbbr=function(){var e,t,n,r=this.localeData().eras();for(e=0,t=r.length;e<t;++e){if(n=this.clone().startOf("day").valueOf(),r[e].since<=n&&n<=r[e].until)return r[e].abbr;if(r[e].until<=n&&n<=r[e].since)return r[e].abbr}return""},vn.eraYear=function(){var e,t,n,r,o=this.localeData().eras();for(e=0,t=o.length;e<t;++e)if(n=o[e].since<=o[e].until?1:-1,r=this.clone().startOf("day").valueOf(),o[e].since<=r&&r<=o[e].until||o[e].until<=r&&r<=o[e].since)return(this.year()-i(o[e].since).year())*n+o[e].offset;return this.year()},vn.year=De,vn.isLeapYear=function(){return W(this.year())},vn.weekYear=function(e){return cn.call(this,e,this.week(),this.weekday(),this.localeData()._week.dow,this.localeData()._week.doy)},vn.isoWeekYear=function(e){return cn.call(this,e,this.isoWeek(),this.isoWeekday(),1,4)},vn.quarter=vn.quarters=function(e){return null==e?Math.ceil((this.month()+1)/3):this.month(3*(e-1)+this.month()%3)},vn.month=Oe,vn.daysInMonth=function(){return we(this.year(),this.month())},vn.week=vn.weeks=function(e){var t=this.localeData().week(this);return null==e?t:this.add(7*(e-t),"d")},vn.isoWeek=vn.isoWeeks=function(e){var t=Re(this,1,4).week;return null==e?t:this.add(7*(e-t),"d")},vn.weeksInYear=function(){var e=this.localeData()._week;return Be(this.year(),e.dow,e.doy)},vn.weeksInWeekYear=function(){var e=this.localeData()._week;return Be(this.weekYear(),e.dow,e.doy)},vn.isoWeeksInYear=function(){return Be(this.year(),1,4)},vn.isoWeeksInISOWeekYear=function(){return Be(this.isoWeekYear(),1,4)},vn.date=dn,vn.day=vn.days=function(e){if(!this.isValid())return null!=e?this:NaN;var t=this._isUTC?this._d.getUTCDay():this._d.getDay();return null!=e?(e=function(e,t){return"string"!=typeof e?e:isNaN(e)?"number"==typeof(e=t.weekdaysParse(e))?e:null:parseInt(e,10)}(e,this.localeData()),this.add(e-t,"d")):t},vn.weekday=function(e){if(!this.isValid())return null!=e?this:NaN;var t=(this.day()+7-this.localeData()._week.dow)%7;return null==e?t:this.add(e-t,"d")},vn.isoWeekday=function(e){if(!this.isValid())return null!=e?this:NaN;if(null!=e){var t=function(e,t){return"string"==typeof e?t.weekdaysParse(e)%7||7:isNaN(e)?null:e}(e,this.localeData());return this.day(this.day()%7?t:t-7)}return this.day()||7},vn.dayOfYear=function(e){var t=Math.round((this.clone().startOf("day")-this.clone().startOf("year"))/864e5)+1;return null==e?t:this.add(e-t,"d")},vn.hour=vn.hours=$e,vn.minute=vn.minutes=hn,vn.second=vn.seconds=mn,vn.millisecond=vn.milliseconds=fn,vn.utcOffset=function(e,t,n){var r,o=this._offset||0;if(!this.isValid())return null!=e?this:NaN;if(null!=e){if("string"==typeof e){if(null===(e=Pt(he,e)))return this}else Math.abs(e)<16&&!n&&(e*=60);return!this._isUTC&&t&&(r=Rt(this)),this._offset=e,this._isUTC=!0,null!=r&&this.add(r,"m"),o!==e&&(!t||this._changeInProgress?Gt(this,Yt(e-o,"m"),1,!1):this._changeInProgress||(this._changeInProgress=!0,i.updateOffset(this,!0),this._changeInProgress=null)),this}return this._isUTC?o:Rt(this)},vn.utc=function(e){return this.utcOffset(0,e)},vn.local=function(e){return this._isUTC&&(this.utcOffset(0,e),this._isUTC=!1,e&&this.subtract(Rt(this),"m")),this},vn.parseZone=function(){if(null!=this._tzm)this.utcOffset(this._tzm,!1,!0);else if("string"==typeof this._i){var e=Pt(de,this._i);null!=e?this.utcOffset(e):this.utcOffset(0,!0)}return this},vn.hasAlignedHourOffset=function(e){return!!this.isValid()&&(e=e?Et(e).utcOffset():0,(this.utcOffset()-e)%60==0)},vn.isDST=function(){return this.utcOffset()>this.clone().month(0).utcOffset()||this.utcOffset()>this.clone().month(5).utcOffset()},vn.isLocal=function(){return!!this.isValid()&&!this._isUTC},vn.isUtcOffset=function(){return!!this.isValid()&&this._isUTC},vn.isUtc=Bt,vn.isUTC=Bt,vn.zoneAbbr=function(){return this._isUTC?"UTC":""},vn.zoneName=function(){return this._isUTC?"Coordinated Universal Time":""},vn.dates=C("dates accessor is deprecated. Use date instead.",dn),vn.months=C("months accessor is deprecated. Use month instead",Oe),vn.years=C("years accessor is deprecated. Use year instead",De),vn.zone=C("moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/",(function(e,t){return null!=e?("string"!=typeof e&&(e=-e),this.utcOffset(e,t),this):-this.utcOffset()})),vn.isDSTShifted=C("isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information",(function(){if(!c(this._isDSTShifted))return this._isDSTShifted;var e,t={};return b(t,this),(t=Ct(t))._a?(e=t._isUTC?f(t._a):Et(t._a),this._isDSTShifted=this.isValid()&&function(e,t,n){var r,i=Math.min(e.length,t.length),o=Math.abs(e.length-t.length),a=0;for(r=0;r<i;r++)(n&&e[r]!==t[r]||!n&&q(e[r])!==q(t[r]))&&a++;return a+o}(t._a,e.toArray())>0):this._isDSTShifted=!1,this._isDSTShifted}));var _n=O.prototype;function bn(e,t,n,r){var i=lt(),o=f().set(r,t);return i[n](o,e)}function Mn(e,t,n){if(u(e)&&(t=e,e=void 0),e=e||"",null!=t)return bn(e,t,n,"month");var r,i=[];for(r=0;r<12;r++)i[r]=bn(e,r,n,"month");return i}function wn(e,t,n,r){"boolean"==typeof e?(u(t)&&(n=t,t=void 0),t=t||""):(n=t=e,e=!1,u(t)&&(n=t,t=void 0),t=t||"");var i,o=lt(),a=e?o._week.dow:0,s=[];if(null!=n)return bn(t,(n+a)%7,r,"day");for(i=0;i<7;i++)s[i]=bn(t,(i+a)%7,r,"day");return s}_n.calendar=function(e,t,n){var r=this._calendar[e]||this._calendar.sameElse;return S(r)?r.call(t,n):r},_n.longDateFormat=function(e){var t=this._longDateFormat[e],n=this._longDateFormat[e.toUpperCase()];return t||!n?t:(this._longDateFormat[e]=n.match(k).map((function(e){return"MMMM"===e||"MM"===e||"DD"===e||"dddd"===e?e.slice(1):e})).join(""),this._longDateFormat[e])},_n.invalidDate=function(){return this._invalidDate},_n.ordinal=function(e){return this._ordinal.replace("%d",e)},_n.preparse=yn,_n.postformat=yn,_n.relativeTime=function(e,t,n,r){var i=this._relativeTime[n];return S(i)?i(e,t,n,r):i.replace(/%d/i,e)},_n.pastFuture=function(e,t){var n=this._relativeTime[e>0?"future":"past"];return S(n)?n(t):n.replace(/%s/i,t)},_n.set=function(e){var t,n;for(n in e)s(e,n)&&(S(t=e[n])?this[n]=t:this["_"+n]=t);this._config=e,this._dayOfMonthOrdinalParseLenient=new RegExp((this._dayOfMonthOrdinalParse.source||this._ordinalParse.source)+"|"+/\d{1,2}/.source)},_n.eras=function(e,t){var n,r,o,a=this._eras||lt("en")._eras;for(n=0,r=a.length;n<r;++n){switch(typeof a[n].since){case"string":o=i(a[n].since).startOf("day"),a[n].since=o.valueOf()}switch(typeof a[n].until){case"undefined":a[n].until=1/0;break;case"string":o=i(a[n].until).startOf("day").valueOf(),a[n].until=o.valueOf()}}return a},_n.erasParse=function(e,t,n){var r,i,o,a,s,l=this.eras();for(e=e.toUpperCase(),r=0,i=l.length;r<i;++r)if(o=l[r].name.toUpperCase(),a=l[r].abbr.toUpperCase(),s=l[r].narrow.toUpperCase(),n)switch(t){case"N":case"NN":case"NNN":if(a===e)return l[r];break;case"NNNN":if(o===e)return l[r];break;case"NNNNN":if(s===e)return l[r]}else if([o,a,s].indexOf(e)>=0)return l[r]},_n.erasConvertYear=function(e,t){var n=e.since<=e.until?1:-1;return void 0===t?i(e.since).year():i(e.since).year()+(t-e.offset)*n},_n.erasAbbrRegex=function(e){return s(this,"_erasAbbrRegex")||sn.call(this),e?this._erasAbbrRegex:this._erasRegex},_n.erasNameRegex=function(e){return s(this,"_erasNameRegex")||sn.call(this),e?this._erasNameRegex:this._erasRegex},_n.erasNarrowRegex=function(e){return s(this,"_erasNarrowRegex")||sn.call(this),e?this._erasNarrowRegex:this._erasRegex},_n.months=function(e,t){return e?o(this._months)?this._months[e.month()]:this._months[(this._months.isFormat||xe).test(t)?"format":"standalone"][e.month()]:o(this._months)?this._months:this._months.standalone},_n.monthsShort=function(e,t){return e?o(this._monthsShort)?this._monthsShort[e.month()]:this._monthsShort[xe.test(t)?"format":"standalone"][e.month()]:o(this._monthsShort)?this._monthsShort:this._monthsShort.standalone},_n.monthsParse=function(e,t,n){var r,i,o;if(this._monthsParseExact)return Se.call(this,e,t,n);for(this._monthsParse||(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[]),r=0;r<12;r++){if(i=f([2e3,r]),n&&!this._longMonthsParse[r]&&(this._longMonthsParse[r]=new RegExp("^"+this.months(i,"").replace(".","")+"$","i"),this._shortMonthsParse[r]=new RegExp("^"+this.monthsShort(i,"").replace(".","")+"$","i")),n||this._monthsParse[r]||(o="^"+this.months(i,"")+"|^"+this.monthsShort(i,""),this._monthsParse[r]=new RegExp(o.replace(".",""),"i")),n&&"MMMM"===t&&this._longMonthsParse[r].test(e))return r;if(n&&"MMM"===t&&this._shortMonthsParse[r].test(e))return r;if(!n&&this._monthsParse[r].test(e))return r}},_n.monthsRegex=function(e){return this._monthsParseExact?(s(this,"_monthsRegex")||Ie.call(this),e?this._monthsStrictRegex:this._monthsRegex):(s(this,"_monthsRegex")||(this._monthsRegex=Le),this._monthsStrictRegex&&e?this._monthsStrictRegex:this._monthsRegex)},_n.monthsShortRegex=function(e){return this._monthsParseExact?(s(this,"_monthsRegex")||Ie.call(this),e?this._monthsShortStrictRegex:this._monthsShortRegex):(s(this,"_monthsShortRegex")||(this._monthsShortRegex=Ee),this._monthsShortStrictRegex&&e?this._monthsShortStrictRegex:this._monthsShortRegex)},_n.week=function(e){return Re(e,this._week.dow,this._week.doy).week},_n.firstDayOfYear=function(){return this._week.doy},_n.firstDayOfWeek=function(){return this._week.dow},_n.weekdays=function(e,t){var n=o(this._weekdays)?this._weekdays:this._weekdays[e&&!0!==e&&this._weekdays.isFormat.test(t)?"format":"standalone"];return!0===e?He(n,this._week.dow):e?n[e.day()]:n},_n.weekdaysMin=function(e){return!0===e?He(this._weekdaysMin,this._week.dow):e?this._weekdaysMin[e.day()]:this._weekdaysMin},_n.weekdaysShort=function(e){return!0===e?He(this._weekdaysShort,this._week.dow):e?this._weekdaysShort[e.day()]:this._weekdaysShort},_n.weekdaysParse=function(e,t,n){var r,i,o;if(this._weekdaysParseExact)return qe.call(this,e,t,n);for(this._weekdaysParse||(this._weekdaysParse=[],this._minWeekdaysParse=[],this._shortWeekdaysParse=[],this._fullWeekdaysParse=[]),r=0;r<7;r++){if(i=f([2e3,1]).day(r),n&&!this._fullWeekdaysParse[r]&&(this._fullWeekdaysParse[r]=new RegExp("^"+this.weekdays(i,"").replace(".","\\.?")+"$","i"),this._shortWeekdaysParse[r]=new RegExp("^"+this.weekdaysShort(i,"").replace(".","\\.?")+"$","i"),this._minWeekdaysParse[r]=new RegExp("^"+this.weekdaysMin(i,"").replace(".","\\.?")+"$","i")),this._weekdaysParse[r]||(o="^"+this.weekdays(i,"")+"|^"+this.weekdaysShort(i,"")+"|^"+this.weekdaysMin(i,""),this._weekdaysParse[r]=new RegExp(o.replace(".",""),"i")),n&&"dddd"===t&&this._fullWeekdaysParse[r].test(e))return r;if(n&&"ddd"===t&&this._shortWeekdaysParse[r].test(e))return r;if(n&&"dd"===t&&this._minWeekdaysParse[r].test(e))return r;if(!n&&this._weekdaysParse[r].test(e))return r}},_n.weekdaysRegex=function(e){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||Ke.call(this),e?this._weekdaysStrictRegex:this._weekdaysRegex):(s(this,"_weekdaysRegex")||(this._weekdaysRegex=Ue),this._weekdaysStrictRegex&&e?this._weekdaysStrictRegex:this._weekdaysRegex)},_n.weekdaysShortRegex=function(e){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||Ke.call(this),e?this._weekdaysShortStrictRegex:this._weekdaysShortRegex):(s(this,"_weekdaysShortRegex")||(this._weekdaysShortRegex=We),this._weekdaysShortStrictRegex&&e?this._weekdaysShortStrictRegex:this._weekdaysShortRegex)},_n.weekdaysMinRegex=function(e){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||Ke.call(this),e?this._weekdaysMinStrictRegex:this._weekdaysMinRegex):(s(this,"_weekdaysMinRegex")||(this._weekdaysMinRegex=Ge),this._weekdaysMinStrictRegex&&e?this._weekdaysMinStrictRegex:this._weekdaysMinRegex)},_n.isPM=function(e){return"p"===(e+"").toLowerCase().charAt(0)},_n.meridiem=function(e,t,n){return e>11?n?"pm":"PM":n?"am":"AM"},at("en",{eras:[{since:"0001-01-01",until:1/0,offset:1,name:"Anno Domini",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"Before Christ",narrow:"BC",abbr:"BC"}],dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(e){var t=e%10;return e+(1===q(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")}}),i.lang=C("moment.lang is deprecated. Use moment.locale instead.",at),i.langData=C("moment.langData is deprecated. Use moment.localeData instead.",lt);var An=Math.abs;function Cn(e,t,n,r){var i=Yt(t,n);return e._milliseconds+=r*i._milliseconds,e._days+=r*i._days,e._months+=r*i._months,e._bubble()}function xn(e){return e<0?Math.floor(e):Math.ceil(e)}function En(e){return 4800*e/146097}function Ln(e){return 146097*e/4800}function Sn(e){return function(){return this.as(e)}}var Tn=Sn("ms"),On=Sn("s"),In=Sn("m"),kn=Sn("h"),Dn=Sn("d"),Nn=Sn("w"),jn=Sn("M"),Pn=Sn("Q"),zn=Sn("y");function Rn(e){return function(){return this.isValid()?this._data[e]:NaN}}var Bn=Rn("milliseconds"),Hn=Rn("seconds"),Fn=Rn("minutes"),Yn=Rn("hours"),Vn=Rn("days"),Un=Rn("months"),Wn=Rn("years"),Gn=Math.round,qn={ss:44,s:45,m:45,h:22,d:26,w:null,M:11};function Kn(e,t,n,r,i){return i.relativeTime(t||1,!!n,e,r)}var Xn=Math.abs;function Jn(e){return(e>0)-(e<0)||+e}function Qn(){if(!this.isValid())return this.localeData().invalidDate();var e,t,n,r,i,o,a,s,l=Xn(this._milliseconds)/1e3,c=Xn(this._days),u=Xn(this._months),d=this.asSeconds();return d?(e=G(l/60),t=G(e/60),l%=60,e%=60,n=G(u/12),u%=12,r=l?l.toFixed(3).replace(/\.?0+$/,""):"",i=d<0?"-":"",o=Jn(this._months)!==Jn(d)?"-":"",a=Jn(this._days)!==Jn(d)?"-":"",s=Jn(this._milliseconds)!==Jn(d)?"-":"",i+"P"+(n?o+n+"Y":"")+(u?o+u+"M":"")+(c?a+c+"D":"")+(t||e||l?"T":"")+(t?s+t+"H":"")+(e?s+e+"M":"")+(l?s+r+"S":"")):"P0D"}var Zn=It.prototype;return Zn.isValid=function(){return this._isValid},Zn.abs=function(){var e=this._data;return this._milliseconds=An(this._milliseconds),this._days=An(this._days),this._months=An(this._months),e.milliseconds=An(e.milliseconds),e.seconds=An(e.seconds),e.minutes=An(e.minutes),e.hours=An(e.hours),e.months=An(e.months),e.years=An(e.years),this},Zn.add=function(e,t){return Cn(this,e,t,1)},Zn.subtract=function(e,t){return Cn(this,e,t,-1)},Zn.as=function(e){if(!this.isValid())return NaN;var t,n,r=this._milliseconds;if("month"===(e=F(e))||"quarter"===e||"year"===e)switch(t=this._days+r/864e5,n=this._months+En(t),e){case"month":return n;case"quarter":return n/3;case"year":return n/12}else switch(t=this._days+Math.round(Ln(this._months)),e){case"week":return t/7+r/6048e5;case"day":return t+r/864e5;case"hour":return 24*t+r/36e5;case"minute":return 1440*t+r/6e4;case"second":return 86400*t+r/1e3;case"millisecond":return Math.floor(864e5*t)+r;default:throw new Error("Unknown unit "+e)}},Zn.asMilliseconds=Tn,Zn.asSeconds=On,Zn.asMinutes=In,Zn.asHours=kn,Zn.asDays=Dn,Zn.asWeeks=Nn,Zn.asMonths=jn,Zn.asQuarters=Pn,Zn.asYears=zn,Zn.valueOf=function(){return this.isValid()?this._milliseconds+864e5*this._days+this._months%12*2592e6+31536e6*q(this._months/12):NaN},Zn._bubble=function(){var e,t,n,r,i,o=this._milliseconds,a=this._days,s=this._months,l=this._data;return o>=0&&a>=0&&s>=0||o<=0&&a<=0&&s<=0||(o+=864e5*xn(Ln(s)+a),a=0,s=0),l.milliseconds=o%1e3,e=G(o/1e3),l.seconds=e%60,t=G(e/60),l.minutes=t%60,n=G(t/60),l.hours=n%24,a+=G(n/24),i=G(En(a)),s+=i,a-=xn(Ln(i)),r=G(s/12),s%=12,l.days=a,l.months=s,l.years=r,this},Zn.clone=function(){return Yt(this)},Zn.get=function(e){return e=F(e),this.isValid()?this[e+"s"]():NaN},Zn.milliseconds=Bn,Zn.seconds=Hn,Zn.minutes=Fn,Zn.hours=Yn,Zn.days=Vn,Zn.weeks=function(){return G(this.days()/7)},Zn.months=Un,Zn.years=Wn,Zn.humanize=function(e,t){if(!this.isValid())return this.localeData().invalidDate();var n,r,i=!1,o=qn;return"object"==typeof e&&(t=e,e=!1),"boolean"==typeof e&&(i=e),"object"==typeof t&&(o=Object.assign({},qn,t),null!=t.s&&null==t.ss&&(o.ss=t.s-1)),n=this.localeData(),r=function(e,t,n,r){var i=Yt(e).abs(),o=Gn(i.as("s")),a=Gn(i.as("m")),s=Gn(i.as("h")),l=Gn(i.as("d")),c=Gn(i.as("M")),u=Gn(i.as("w")),d=Gn(i.as("y")),h=o<=n.ss&&["s",o]||o<n.s&&["ss",o]||a<=1&&["m"]||a<n.m&&["mm",a]||s<=1&&["h"]||s<n.h&&["hh",s]||l<=1&&["d"]||l<n.d&&["dd",l];return null!=n.w&&(h=h||u<=1&&["w"]||u<n.w&&["ww",u]),(h=h||c<=1&&["M"]||c<n.M&&["MM",c]||d<=1&&["y"]||["yy",d])[2]=t,h[3]=+e>0,h[4]=r,Kn.apply(null,h)}(this,!i,o,n),i&&(r=n.pastFuture(+this,r)),n.postformat(r)},Zn.toISOString=Qn,Zn.toString=Qn,Zn.toJSON=Qn,Zn.locale=$t,Zn.localeData=tn,Zn.toIsoString=C("toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",Qn),Zn.lang=en,P("X",0,0,"unix"),P("x",0,0,"valueOf"),fe("x",ue),fe("X",/[+-]?\d+(\.\d{1,3})?/),_e("X",(function(e,t,n){n._d=new Date(1e3*parseFloat(e))})),_e("x",(function(e,t,n){n._d=new Date(q(e))})),
//! moment.js
i.version="2.29.1",t=Et,i.fn=vn,i.min=function(){var e=[].slice.call(arguments,0);return Tt("isBefore",e)},i.max=function(){var e=[].slice.call(arguments,0);return Tt("isAfter",e)},i.now=function(){return Date.now?Date.now():+new Date},i.utc=f,i.unix=function(e){return Et(1e3*e)},i.months=function(e,t){return Mn(e,t,"months")},i.isDate=d,i.locale=at,i.invalid=v,i.duration=Yt,i.isMoment=w,i.weekdays=function(e,t,n){return wn(e,t,n,"weekdays")},i.parseZone=function(){return Et.apply(null,arguments).parseZone()},i.localeData=lt,i.isDuration=kt,i.monthsShort=function(e,t){return Mn(e,t,"monthsShort")},i.weekdaysMin=function(e,t,n){return wn(e,t,n,"weekdaysMin")},i.defineLocale=st,i.updateLocale=function(e,t){if(null!=t){var n,r,i=et;null!=tt[e]&&null!=tt[e].parentLocale?tt[e].set(T(tt[e]._config,t)):(null!=(r=ot(e))&&(i=r._config),t=T(i,t),null==r&&(t.abbr=e),(n=new O(t)).parentLocale=tt[e],tt[e]=n),at(e)}else null!=tt[e]&&(null!=tt[e].parentLocale?(tt[e]=tt[e].parentLocale,e===at()&&at(e)):null!=tt[e]&&delete tt[e]);return tt[e]},i.locales=function(){return x(tt)},i.weekdaysShort=function(e,t,n){return wn(e,t,n,"weekdaysShort")},i.normalizeUnits=F,i.relativeTimeRounding=function(e){return void 0===e?Gn:"function"==typeof e&&(Gn=e,!0)},i.relativeTimeThreshold=function(e,t){return void 0!==qn[e]&&(void 0===t?qn[e]:(qn[e]=t,"s"===e&&(qn.ss=t-1),!0))},i.calendarFormat=function(e,t){var n=e.diff(t,"days",!0);return n<-6?"sameElse":n<-1?"lastWeek":n<0?"lastDay":n<1?"sameDay":n<2?"nextDay":n<7?"nextWeek":"sameElse"},i.prototype=vn,i.HTML5_FMT={DATETIME_LOCAL:"YYYY-MM-DDTHH:mm",DATETIME_LOCAL_SECONDS:"YYYY-MM-DDTHH:mm:ss",DATETIME_LOCAL_MS:"YYYY-MM-DDTHH:mm:ss.SSS",DATE:"YYYY-MM-DD",TIME:"HH:mm",TIME_SECONDS:"HH:mm:ss",TIME_MS:"HH:mm:ss.SSS",WEEK:"GGGG-[W]WW",MONTH:"YYYY-MM"},i}()}).call(this,n(151)(e))},function(e,t,n){"use strict";(function(e,r){n.d(t,"a",(function(){return c})),n.d(t,"b",(function(){return l})),n.d(t,"c",(function(){return s}));var i=n(2),o=n(485),a=function(e,t){return(a=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)};var s,l=function(){function e(e){this.type=e}return Object.defineProperty(e.prototype,"isConflatable",{get:function(){return!1},enumerable:!0,configurable:!0}),e.prototype.conflate=function(e){return!1},e}(),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}a(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}(t,e),Object.defineProperty(t.prototype,"isConflatable",{get:function(){return!0},enumerable:!0,configurable:!0}),t.prototype.conflate=function(e){return!0},t}(l);!function(t){function n(e,t){var n=s.get(e);n&&0!==n.length?Object(i.every)(Object(i.retro)(n),(function(n){return!n||function(e,t,n){var r=!0;try{r="function"==typeof e?e(t,n):e.messageHook(t,n)}catch(e){c(e)}return r}(n,e,t)}))&&f(e,t):f(e,t)}t.sendMessage=n,t.postMessage=function(e,t){t.isConflatable&&Object(i.some)(a,(function(n){return n.handler===e&&(!!n.msg&&(n.msg.type===t.type&&(!!n.msg.isConflatable&&n.msg.conflate(t))))}))||m(e,t)},t.installMessageHook=function(e,t){var n=s.get(e);n&&-1!==n.indexOf(t)||(n?n.push(t):s.set(e,[t]))},t.removeMessageHook=function(e,t){var n=s.get(e);if(n){var r=n.indexOf(t);-1!==r&&(n[r]=null,v(n))}},t.clearData=function(e){var t=s.get(e);t&&t.length>0&&(i.ArrayExt.fill(t,null),v(t)),Object(i.each)(a,(function(t){t.handler===e&&(t.handler=null,t.msg=null)}))},t.flush=function(){d||0===u||(p(u),d=!0,g(),d=!1)},t.getExceptionHandler=function(){return c},t.setExceptionHandler=function(e){var t=c;return c=e,t};var a=new o.a,s=new WeakMap,l=new Set,c=function(e){console.error(e)},u=0,d=!1,h="function"==typeof requestAnimationFrame?requestAnimationFrame:e,p="function"==typeof cancelAnimationFrame?cancelAnimationFrame:r;function f(e,t){try{e.processMessage(t)}catch(e){c(e)}}function m(e,t){a.addLast({handler:e,msg:t}),0===u&&(u=h(g))}function g(){if(u=0,!a.isEmpty){var e={handler:null,msg:null};for(a.addLast(e);;){var t=a.removeFirst();if(t===e)return;t.handler&&t.msg&&n(t.handler,t.msg)}}}function v(e){0===l.size&&h(y),l.add(e)}function y(){l.forEach(_),l.clear()}function _(e){i.ArrayExt.removeAllWhere(e,b)}function b(e){return null===e}}(s||(s={}))}).call(this,n(90).setImmediate,n(90).clearImmediate)},function(e,t,n){"use strict";function r(){var e=this.constructor.getDerivedStateFromProps(this.props,this.state);null!=e&&this.setState(e)}function i(e){this.setState(function(t){var n=this.constructor.getDerivedStateFromProps(e,t);return null!=n?n:null}.bind(this))}function o(e,t){try{var n=this.props,r=this.state;this.props=e,this.state=t,this.__reactInternalSnapshotFlag=!0,this.__reactInternalSnapshot=this.getSnapshotBeforeUpdate(n,r)}finally{this.props=n,this.state=r}}function a(e){var t=e.prototype;if(!t||!t.isReactComponent)throw new Error("Can only polyfill class components");if("function"!=typeof e.getDerivedStateFromProps&&"function"!=typeof t.getSnapshotBeforeUpdate)return e;var n=null,a=null,s=null;if("function"==typeof t.componentWillMount?n="componentWillMount":"function"==typeof t.UNSAFE_componentWillMount&&(n="UNSAFE_componentWillMount"),"function"==typeof t.componentWillReceiveProps?a="componentWillReceiveProps":"function"==typeof t.UNSAFE_componentWillReceiveProps&&(a="UNSAFE_componentWillReceiveProps"),"function"==typeof t.componentWillUpdate?s="componentWillUpdate":"function"==typeof t.UNSAFE_componentWillUpdate&&(s="UNSAFE_componentWillUpdate"),null!==n||null!==a||null!==s){var l=e.displayName||e.name,c="function"==typeof e.getDerivedStateFromProps?"getDerivedStateFromProps()":"getSnapshotBeforeUpdate()";throw Error("Unsafe legacy lifecycles will not be called for components using new component APIs.\n\n"+l+" uses "+c+" but also contains the following legacy lifecycles:"+(null!==n?"\n  "+n:"")+(null!==a?"\n  "+a:"")+(null!==s?"\n  "+s:"")+"\n\nThe above lifecycles should be removed. Learn more about this warning here:\nhttps://fb.me/react-async-component-lifecycle-hooks")}if("function"==typeof e.getDerivedStateFromProps&&(t.componentWillMount=r,t.componentWillReceiveProps=i),"function"==typeof t.getSnapshotBeforeUpdate){if("function"!=typeof t.componentDidUpdate)throw new Error("Cannot polyfill getSnapshotBeforeUpdate() for components that do not define componentDidUpdate() on the prototype");t.componentWillUpdate=o;var u=t.componentDidUpdate;t.componentDidUpdate=function(e,t,n){var r=this.__reactInternalSnapshotFlag?this.__reactInternalSnapshot:n;u.call(this,e,t,r)}}return e}n.r(t),n.d(t,"polyfill",(function(){return a})),r.__suppressDeprecationWarning=!0,i.__suppressDeprecationWarning=!0,o.__suppressDeprecationWarning=!0},function(e,t,n){"use strict";n.d(t,"e",(function(){return l})),n.d(t,"f",(function(){return c})),n.d(t,"i",(function(){return d})),n.d(t,"m",(function(){return h})),n.d(t,"k",(function(){return p})),n.d(t,"l",(function(){return f})),n.d(t,"h",(function(){return m})),n.d(t,"j",(function(){return g})),n.d(t,"n",(function(){return v})),n.d(t,"g",(function(){return b})),n.d(t,"b",(function(){return M})),n.d(t,"d",(function(){return A})),n.d(t,"a",(function(){return x})),n.d(t,"c",(function(){return E}));var r=n(85),i=n(25),o=n(19);Number.MAX_SAFE_INTEGER,Number.MIN_SAFE_INTEGER,o.h;const a=Number.isInteger||(e=>"number"==typeof e&&isFinite(e)&&i.d(e)===e);Number.isNaN,Number.parseInt;class s{constructor(){this.cpos=0,this.cbuf=new Uint8Array(100),this.bufs=[]}}const l=()=>new s,c=e=>{const t=new Uint8Array((e=>{let t=e.cpos;for(let n=0;n<e.bufs.length;n++)t+=e.bufs[n].length;return t})(e));let n=0;for(let r=0;r<e.bufs.length;r++){const i=e.bufs[r];t.set(i,n),n+=i.length}return t.set(r.b(e.cbuf.buffer,0,e.cpos),n),t},u=(e,t)=>{const n=e.cbuf.length;e.cpos===n&&(e.bufs.push(e.cbuf),e.cbuf=new Uint8Array(2*n),e.cpos=0),e.cbuf[e.cpos++]=t},d=u,h=(e,t)=>{for(;t>o.k;)u(e,o.g|o.k&t),t>>>=7;u(e,o.k&t)},p=(e,t)=>{const n=i.e(t);for(n&&(t=-t),u(e,(t>o.j?o.g:0)|(n?o.f:0)|o.j&t),t>>>=6;t>0;)u(e,(t>o.k?o.g:0)|o.k&t),t>>>=7},f=(e,t)=>{const n=unescape(encodeURIComponent(t)),r=n.length;h(e,r);for(let t=0;t<r;t++)u(e,n.codePointAt(t))},m=(e,t)=>g(e,c(t)),g=(e,t)=>{const n=e.cbuf.length,r=e.cpos,o=i.h(n-r,t.length),a=t.length-o;e.cbuf.set(t.subarray(0,o),r),e.cpos+=o,a>0&&(e.bufs.push(e.cbuf),e.cbuf=new Uint8Array(i.g(2*n,a)),e.cbuf.set(t.subarray(o)),e.cpos=a)},v=(e,t)=>{h(e,t.byteLength),g(e,t)},y=(e,t)=>{((e,t)=>{const n=e.cbuf.length;n-e.cpos<t&&(e.bufs.push(r.b(e.cbuf.buffer,0,e.cpos)),e.cbuf=new Uint8Array(2*i.g(n,t)),e.cpos=0)})(e,t);const n=new DataView(e.cbuf.buffer,e.cpos,t);return e.cpos+=t,n},_=new DataView(new ArrayBuffer(4)),b=(e,t)=>{switch(typeof t){case"string":u(e,119),f(e,t);break;case"number":a(t)&&t<=o.h?(u(e,125),p(e,t)):(n=t,_.setFloat32(0,n),_.getFloat32(0)===n?(u(e,124),((e,t)=>{y(e,4).setFloat32(0,t,!1)})(e,t)):(u(e,123),((e,t)=>{y(e,8).setFloat64(0,t,!1)})(e,t)));break;case"bigint":u(e,122),((e,t)=>{y(e,8).setBigInt64(0,t,!1)})(e,t);break;case"object":if(null===t)u(e,126);else if(t instanceof Array){u(e,117),h(e,t.length);for(let n=0;n<t.length;n++)b(e,t[n])}else if(t instanceof Uint8Array)u(e,116),v(e,t);else{u(e,118);const n=Object.keys(t);h(e,n.length);for(let r=0;r<n.length;r++){const i=n[r];f(e,i),b(e,t[i])}}break;case"boolean":u(e,t?120:121);break;default:u(e,127)}var n};class M extends s{constructor(e){super(),this.w=e,this.s=null,this.count=0}write(e){this.s===e?this.count++:(this.count>0&&h(this,this.count-1),this.count=1,this.w(this,e),this.s=e)}}const w=e=>{e.count>0&&(p(e.encoder,1===e.count?e.s:-e.s),e.count>1&&h(e.encoder,e.count-2))};class A{constructor(){this.encoder=new s,this.s=0,this.count=0}write(e){this.s===e?this.count++:(w(this),this.count=1,this.s=e)}toUint8Array(){return w(this),c(this.encoder)}}const C=e=>{if(e.count>0){const t=e.diff<<1|(1===e.count?0:1);p(e.encoder,t),e.count>1&&h(e.encoder,e.count-2)}};class x{constructor(){this.encoder=new s,this.s=0,this.count=0,this.diff=0}write(e){this.diff===e-this.s?(this.s=e,this.count++):(C(this),this.count=1,this.diff=e-this.s,this.s=e)}toUint8Array(){return C(this),c(this.encoder)}}class E{constructor(){this.sarr=[],this.s="",this.lensE=new A}write(e){this.s+=e,this.s.length>19&&(this.sarr.push(this.s),this.s=""),this.lensE.write(e.length)}toUint8Array(){const e=new s;return this.sarr.push(this.s),this.s="",f(e,this.sarr.join("")),g(e,this.lensE.toUint8Array()),c(e)}}},function(e,t,n){"use strict";n.d(t,"e",(function(){return s})),n.d(t,"f",(function(){return l})),n.d(t,"l",(function(){return u})),n.d(t,"h",(function(){return d})),n.d(t,"k",(function(){return h})),n.d(t,"i",(function(){return p})),n.d(t,"j",(function(){return f})),n.d(t,"g",(function(){return v})),n.d(t,"b",(function(){return y})),n.d(t,"d",(function(){return _})),n.d(t,"a",(function(){return b})),n.d(t,"c",(function(){return M}));var r=n(85),i=n(19),o=n(25);class a{constructor(e){this.arr=e,this.pos=0}}const s=e=>new a(e),l=e=>e.pos!==e.arr.length,c=(e,t)=>{const n=r.b(e.arr.buffer,e.pos+e.arr.byteOffset,t);return e.pos+=t,n},u=e=>c(e,h(e)),d=e=>e.arr[e.pos++],h=e=>{let t=0,n=0;for(;;){const r=e.arr[e.pos++];if(t|=(r&i.k)<<n,n+=7,r<i.g)return t>>>0;if(n>35)throw new Error("Integer out of range!")}},p=e=>{let t=e.arr[e.pos++],n=t&i.j,r=6;const o=(t&i.f)>0?-1:1;if(0==(t&i.g))return o*n;for(;;){if(t=e.arr[e.pos++],n|=(t&i.k)<<r,r+=7,t<i.g)return o*(n>>>0);if(r>41)throw new Error("Integer out of range!")}},f=e=>{let t=h(e);if(0===t)return"";{let n=String.fromCodePoint(d(e));if(--t<100)for(;t--;)n+=String.fromCodePoint(d(e));else for(;t>0;){const r=t<1e4?t:1e4,i=e.arr.subarray(e.pos,e.pos+r);e.pos+=r,n+=String.fromCodePoint.apply(null,i),t-=r}return decodeURIComponent(escape(n))}},m=(e,t)=>{const n=new DataView(e.arr.buffer,e.arr.byteOffset+e.pos,t);return e.pos+=t,n},g=[e=>{},e=>null,p,e=>m(e,4).getFloat32(0,!1),e=>m(e,8).getFloat64(0,!1),e=>m(e,8).getBigInt64(0,!1),e=>!1,e=>!0,f,e=>{const t=h(e),n={};for(let r=0;r<t;r++){n[f(e)]=v(e)}return n},e=>{const t=h(e),n=[];for(let r=0;r<t;r++)n.push(v(e));return n},u],v=e=>g[127-d(e)](e);class y extends a{constructor(e,t){super(e),this.reader=t,this.s=null,this.count=0}read(){return 0===this.count&&(this.s=this.reader(this),l(this)?this.count=h(this)+1:this.count=-1),this.count--,this.s}}class _ extends a{constructor(e){super(e),this.s=0,this.count=0}read(){if(0===this.count){this.s=p(this);const e=o.e(this.s);this.count=1,e&&(this.s=-this.s,this.count=h(this)+2)}return this.count--,this.s}}class b extends a{constructor(e){super(e),this.s=0,this.count=0,this.diff=0}read(){if(0===this.count){const e=p(this),t=1&e;this.diff=e>>1,this.count=1,t&&(this.count=h(this)+2)}return this.s+=this.diff,this.count--,this.s}}class M{constructor(e){this.decoder=new _(e),this.str=f(this.decoder),this.spos=0}read(){const e=this.spos+this.decoder.read(),t=this.str.slice(this.spos,e);return this.spos=e,t}}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),i(n(608),t),i(n(610),t),i(n(611),t),i(n(612),t),i(n(617),t),i(n(618),t),i(n(619),t),i(n(210),t)},function(e,t,n){"use strict";n.d(t,"a",(function(){return _}));var r,i=n(6),o=n(4),a=n(0),s=n.n(a),l=n(34),c=n.n(l),u=n(490),d=n.n(u),h=n(491),p=n.n(h),f=n(145),m=n.n(f),g=n(203),v=n(45),y=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};class _{constructor({name:e,svgstr:t,render:n,unrender:r,_loading:i=!1}){if(this._props={},this._svgReplaced=new o.Signal(this),this._svgElement=void 0,this._svgInnerHTML=void 0,this._svgReactAttrs=void 0,!e||!t)return console.error(`When defining a new LabIcon, name and svgstr must both be non-empty strings. name: ${e}, svgstr: ${t}`),b;if(this._loading=i,_._instances.has(e)){const n=_._instances.get(e);return this._loading?(n.svgstr=t,this._loading=!1,n):(console.warn(`Redefining previously loaded icon svgstr. name: ${e}, svgstrOld: ${n.svgstr}, svgstr: ${t}`),n.svgstr=t,n)}this.name=e,this.react=this._initReact(e),this.svgstr=t,this._initRender({render:n,unrender:r}),_._instances.set(this.name,this)}static remove(e){for(;e.firstChild;)e.firstChild.remove();return e.className="",e}static resolve({icon:e}){if(e instanceof _)return e;if("string"==typeof e){const t=_._instances.get(e);return t||(_._debug&&console.warn("Lookup failed for icon, creating loading icon. icon: "+e),new _({name:e,svgstr:m.a,_loading:!0}))}return new _(e)}static resolveElement(e){var{icon:t,iconClass:n,fallback:i}=e,o=y(e,["icon","iconClass","fallback"]);return r.isResolvable(t)?_.resolve({icon:t}).element(o):!n&&i?i.element(o):(o.className=Object(v.a)(n,o.className),r.blankElement(o))}static resolveReact(e){var{icon:t,iconClass:n,fallback:i}=e,o=y(e,["icon","iconClass","fallback"]);if(!r.isResolvable(t))return!n&&i?s.a.createElement(i.react,Object.assign({},o)):(o.className=Object(v.a)(n,o.className),s.a.createElement(r.blankReact,Object.assign({},o)));const a=_.resolve({icon:t});return s.a.createElement(a.react,Object.assign({},o))}static resolveSvg({name:e,svgstr:t}){const n=(new DOMParser).parseFromString(r.svgstrShim(t),"image/svg+xml"),i=n.querySelector("parsererror");if(i){const n=`SVG HTML was malformed for LabIcon instance.\nname: ${e}, svgstr: ${t}`;return _._debug?(console.error(n),i):(console.warn(n),null)}return n.documentElement}static toggleDebug(e){_._debug=null!=e?e:!_._debug}bindprops(e){const t=Object.create(this);return t._props=e,t.react=t._initReact(t.name+"_bind"),t}element(e={}){var t;let n=Object.assign(Object.assign({},this._props),e),{className:i,container:o,label:a,title:s,tag:l="div"}=n,c=y(n,["className","container","label","title","tag"]);const u=null==o?void 0:o.firstChild;if((null===(t=null==u?void 0:u.dataset)||void 0===t?void 0:t.iconId)===this._uuid)return u;if(!this.svgElement)return document.createElement("div");let d=!0;if(o)for(;o.firstChild;)o.firstChild.remove();else o=document.createElement(l),d=!1;null!=a&&(o.textContent=a),r.initContainer({container:o,className:i,styleProps:c,title:s});const h=this.svgElement.cloneNode(!0);return o.appendChild(h),d?h:o}render(e,t){var n;let r=null===(n=null==t?void 0:t.children)||void 0===n?void 0:n[0];"string"!=typeof r&&(r=void 0),this.element(Object.assign({container:e,label:r},null==t?void 0:t.props))}get svgElement(){return void 0===this._svgElement&&(this._svgElement=this._initSvg({uuid:this._uuid})),this._svgElement}get svgInnerHTML(){return void 0===this._svgInnerHTML&&(null===this.svgElement?this._svgInnerHTML=null:this._svgInnerHTML=this.svgElement.innerHTML),this._svgInnerHTML}get svgReactAttrs(){return void 0===this._svgReactAttrs&&(null===this.svgElement?this._svgReactAttrs=null:this._svgReactAttrs=Object(v.b)(this.svgElement,{ignore:["data-icon-id"]})),this._svgReactAttrs}get svgstr(){return this._svgstr}set svgstr(e){this._svgstr=e;const t=i.UUID.uuid4(),n=this._uuid;this._uuid=t,this._svgElement=void 0,this._svgInnerHTML=void 0,this._svgReactAttrs=void 0,document.querySelectorAll(`[data-icon-id="${n}"]`).forEach(e=>{this.svgElement&&e.replaceWith(this.svgElement.cloneNode(!0))}),this._svgReplaced.emit()}_initReact(e){const t=s.a.forwardRef((e={},t)=>{const n=Object.assign(Object.assign({},this._props),e),{className:i,container:o,label:a,title:l,tag:c="div"}=n,u=y(n,["className","container","label","title","tag"]),[,d]=s.a.useState(this._uuid);s.a.useEffect(()=>{const e=()=>{d(this._uuid)};return this._svgReplaced.connect(e),()=>{this._svgReplaced.disconnect(e)}});const h=c;if(!this.svgInnerHTML||!this.svgReactAttrs)return s.a.createElement(s.a.Fragment,null);const p=s.a.createElement("svg",Object.assign({},this.svgReactAttrs,{dangerouslySetInnerHTML:{__html:this.svgInnerHTML},ref:t}));return o?(r.initContainer({container:o,className:i,styleProps:u,title:l}),s.a.createElement(s.a.Fragment,null,p,a)):s.a.createElement(h,{className:Object(v.a)(i,g.a.styleClass(u))},p,a)});return t.displayName="LabIcon_"+e,t}_initRender({render:e,unrender:t}){e?(this.render=e,t&&(this.unrender=t)):t&&console.warn("In _initRender, ignoring unrender arg since render is undefined")}_initSvg({title:e,uuid:t}={}){const n=_.resolveSvg(this);return n?("parsererror"!==n.tagName&&(n.dataset.icon=this.name,t&&(n.dataset.iconId=t),e&&r.setTitleSvg(n,e)),n):n}}_._debug=!1,_._instances=new Map,function(e){function t({container:e,className:t,styleProps:n,title:r}){null!=r&&(e.title=r);const i=g.a.styleClass(n);if(null!=t){const n=Object(v.a)(t,i);return e.className=n,n}return i?(e.classList.add(i),i):""}e.blankElement=function(t){var{className:n="",container:r,label:i,title:o,tag:a="div"}=t,s=y(t,["className","container","label","title","tag"]);if((null==r?void 0:r.className)===n)return r;if(r)for(;r.firstChild;)r.firstChild.remove();else r=document.createElement(a);return null!=i&&(r.textContent=i),e.initContainer({container:r,className:n,styleProps:s,title:o}),r},e.blankReact=s.a.forwardRef((e,n)=>{var{className:r="",container:i,label:o,title:a,tag:l="div"}=e,c=y(e,["className","container","label","title","tag"]);const u=l;return i?(t({container:i,className:r,styleProps:c,title:a}),s.a.createElement(s.a.Fragment,null)):s.a.createElement(u,{className:Object(v.a)(r,g.a.styleClass(c))},n&&M.react({ref:n}),o)}),e.blankReact.displayName="BlankReact",e.initContainer=t,e.isResolvable=function(e){return!(!e||!("string"==typeof e||e.name&&e.svgstr))},e.setTitleSvg=function(e,t){const n=e.getElementsByTagName("title");if(n.length)n[0].textContent=t;else{const n=document.createElement("title");n.textContent=t,e.appendChild(n)}},e.svgstrShim=function(e,t=!0){const[,n,r]=decodeURIComponent(e).replace(/>\s*\n\s*</g,"><").replace(/\s*\n\s*/g," ").match(t?/^(?:data:.*?(;base64)?,)?(.*)/:/(?:(base64).*)?(<svg.*)/);return n?atob(r):r};class n{constructor(e,t){this._icon=e,this._rendererOptions=t}render(e,t){}}e.Renderer=n;e.ElementRenderer=class extends n{render(e,t){var n,r;let i=null===(n=null==t?void 0:t.children)||void 0===n?void 0:n[0];"string"!=typeof i&&(i=void 0),this._icon.element(Object.assign(Object.assign({container:e,label:i},null===(r=this._rendererOptions)||void 0===r?void 0:r.props),null==t?void 0:t.props))}};e.ReactRenderer=class extends n{render(e,t){var n,r;let i=null===(n=null==t?void 0:t.children)||void 0===n?void 0:n[0];"string"!=typeof i&&(i=void 0),c.a.render(s.a.createElement(this._icon.react,Object.assign({container:e,label:i},Object.assign(Object.assign({},null===(r=this._rendererOptions)||void 0===r?void 0:r.props),null==t?void 0:t.props))),e)}unrender(e){c.a.unmountComponentAtNode(e)}}}(r||(r={}));const b=new _({name:"ui-components:bad",svgstr:d.a}),M=new _({name:"ui-components:blank",svgstr:p.a})},function(e,t,n){e.exports=function(){"use strict";var e=navigator.userAgent,t=navigator.platform,n=/gecko\/\d/i.test(e),r=/MSIE \d/.test(e),i=/Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(e),o=/Edge\/(\d+)/.exec(e),a=r||i||o,s=a&&(r?document.documentMode||6:+(o||i)[1]),l=!o&&/WebKit\//.test(e),c=l&&/Qt\/\d+\.\d+/.test(e),u=!o&&/Chrome\//.test(e),d=/Opera\//.test(e),h=/Apple Computer/.test(navigator.vendor),p=/Mac OS X 1\d\D([8-9]|\d\d)\D/.test(e),f=/PhantomJS/.test(e),m=h&&(/Mobile\/\w+/.test(e)||navigator.maxTouchPoints>2),g=/Android/.test(e),v=m||g||/webOS|BlackBerry|Opera Mini|Opera Mobi|IEMobile/i.test(e),y=m||/Mac/.test(t),_=/\bCrOS\b/.test(e),b=/win/i.test(t),M=d&&e.match(/Version\/(\d*\.\d*)/);M&&(M=Number(M[1])),M&&M>=15&&(d=!1,l=!0);var w=y&&(c||d&&(null==M||M<12.11)),A=n||a&&s>=9;function C(e){return new RegExp("(^|\\s)"+e+"(?:$|\\s)\\s*")}var x,E=function(e,t){var n=e.className,r=C(t).exec(n);if(r){var i=n.slice(r.index+r[0].length);e.className=n.slice(0,r.index)+(i?r[1]+i:"")}};function L(e){for(var t=e.childNodes.length;t>0;--t)e.removeChild(e.firstChild);return e}function S(e,t){return L(e).appendChild(t)}function T(e,t,n,r){var i=document.createElement(e);if(n&&(i.className=n),r&&(i.style.cssText=r),"string"==typeof t)i.appendChild(document.createTextNode(t));else if(t)for(var o=0;o<t.length;++o)i.appendChild(t[o]);return i}function O(e,t,n,r){var i=T(e,t,n,r);return i.setAttribute("role","presentation"),i}function I(e,t){if(3==t.nodeType&&(t=t.parentNode),e.contains)return e.contains(t);do{if(11==t.nodeType&&(t=t.host),t==e)return!0}while(t=t.parentNode)}function k(){var e;try{e=document.activeElement}catch(t){e=document.body||null}for(;e&&e.shadowRoot&&e.shadowRoot.activeElement;)e=e.shadowRoot.activeElement;return e}function D(e,t){var n=e.className;C(t).test(n)||(e.className+=(n?" ":"")+t)}function N(e,t){for(var n=e.split(" "),r=0;r<n.length;r++)n[r]&&!C(n[r]).test(t)&&(t+=" "+n[r]);return t}x=document.createRange?function(e,t,n,r){var i=document.createRange();return i.setEnd(r||e,n),i.setStart(e,t),i}:function(e,t,n){var r=document.body.createTextRange();try{r.moveToElementText(e.parentNode)}catch(e){return r}return r.collapse(!0),r.moveEnd("character",n),r.moveStart("character",t),r};var j=function(e){e.select()};function P(e){var t=Array.prototype.slice.call(arguments,1);return function(){return e.apply(null,t)}}function z(e,t,n){for(var r in t||(t={}),e)!e.hasOwnProperty(r)||!1===n&&t.hasOwnProperty(r)||(t[r]=e[r]);return t}function R(e,t,n,r,i){null==t&&-1==(t=e.search(/[^\s\u00a0]/))&&(t=e.length);for(var o=r||0,a=i||0;;){var s=e.indexOf("\t",o);if(s<0||s>=t)return a+(t-o);a+=s-o,a+=n-a%n,o=s+1}}m?j=function(e){e.selectionStart=0,e.selectionEnd=e.value.length}:a&&(j=function(e){try{e.select()}catch(e){}});var B=function(){this.id=null,this.f=null,this.time=0,this.handler=P(this.onTimeout,this)};function H(e,t){for(var n=0;n<e.length;++n)if(e[n]==t)return n;return-1}B.prototype.onTimeout=function(e){e.id=0,e.time<=+new Date?e.f():setTimeout(e.handler,e.time-+new Date)},B.prototype.set=function(e,t){this.f=t;var n=+new Date+e;(!this.id||n<this.time)&&(clearTimeout(this.id),this.id=setTimeout(this.handler,e),this.time=n)};var F={toString:function(){return"CodeMirror.Pass"}},Y={scroll:!1},V={origin:"*mouse"},U={origin:"+move"};function W(e,t,n){for(var r=0,i=0;;){var o=e.indexOf("\t",r);-1==o&&(o=e.length);var a=o-r;if(o==e.length||i+a>=t)return r+Math.min(a,t-i);if(i+=o-r,r=o+1,(i+=n-i%n)>=t)return r}}var G=[""];function q(e){for(;G.length<=e;)G.push(K(G)+" ");return G[e]}function K(e){return e[e.length-1]}function X(e,t){for(var n=[],r=0;r<e.length;r++)n[r]=t(e[r],r);return n}function J(){}function Q(e,t){var n;return Object.create?n=Object.create(e):(J.prototype=e,n=new J),t&&z(t,n),n}var Z=/[\u00df\u0587\u0590-\u05f4\u0600-\u06ff\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/;function $(e){return/\w/.test(e)||e>""&&(e.toUpperCase()!=e.toLowerCase()||Z.test(e))}function ee(e,t){return t?!!(t.source.indexOf("\\w")>-1&&$(e))||t.test(e):$(e)}function te(e){for(var t in e)if(e.hasOwnProperty(t)&&e[t])return!1;return!0}var ne=/[\u0300-\u036f\u0483-\u0489\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u064b-\u065e\u0670\u06d6-\u06dc\u06de-\u06e4\u06e7\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07a6-\u07b0\u07eb-\u07f3\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0900-\u0902\u093c\u0941-\u0948\u094d\u0951-\u0955\u0962\u0963\u0981\u09bc\u09be\u09c1-\u09c4\u09cd\u09d7\u09e2\u09e3\u0a01\u0a02\u0a3c\u0a41\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a70\u0a71\u0a75\u0a81\u0a82\u0abc\u0ac1-\u0ac5\u0ac7\u0ac8\u0acd\u0ae2\u0ae3\u0b01\u0b3c\u0b3e\u0b3f\u0b41-\u0b44\u0b4d\u0b56\u0b57\u0b62\u0b63\u0b82\u0bbe\u0bc0\u0bcd\u0bd7\u0c3e-\u0c40\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62\u0c63\u0cbc\u0cbf\u0cc2\u0cc6\u0ccc\u0ccd\u0cd5\u0cd6\u0ce2\u0ce3\u0d3e\u0d41-\u0d44\u0d4d\u0d57\u0d62\u0d63\u0dca\u0dcf\u0dd2-\u0dd4\u0dd6\u0ddf\u0e31\u0e34-\u0e3a\u0e47-\u0e4e\u0eb1\u0eb4-\u0eb9\u0ebb\u0ebc\u0ec8-\u0ecd\u0f18\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f7e\u0f80-\u0f84\u0f86\u0f87\u0f90-\u0f97\u0f99-\u0fbc\u0fc6\u102d-\u1030\u1032-\u1037\u1039\u103a\u103d\u103e\u1058\u1059\u105e-\u1060\u1071-\u1074\u1082\u1085\u1086\u108d\u109d\u135f\u1712-\u1714\u1732-\u1734\u1752\u1753\u1772\u1773\u17b7-\u17bd\u17c6\u17c9-\u17d3\u17dd\u180b-\u180d\u18a9\u1920-\u1922\u1927\u1928\u1932\u1939-\u193b\u1a17\u1a18\u1a56\u1a58-\u1a5e\u1a60\u1a62\u1a65-\u1a6c\u1a73-\u1a7c\u1a7f\u1b00-\u1b03\u1b34\u1b36-\u1b3a\u1b3c\u1b42\u1b6b-\u1b73\u1b80\u1b81\u1ba2-\u1ba5\u1ba8\u1ba9\u1c2c-\u1c33\u1c36\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1dc0-\u1de6\u1dfd-\u1dff\u200c\u200d\u20d0-\u20f0\u2cef-\u2cf1\u2de0-\u2dff\u302a-\u302f\u3099\u309a\ua66f-\ua672\ua67c\ua67d\ua6f0\ua6f1\ua802\ua806\ua80b\ua825\ua826\ua8c4\ua8e0-\ua8f1\ua926-\ua92d\ua947-\ua951\ua980-\ua982\ua9b3\ua9b6-\ua9b9\ua9bc\uaa29-\uaa2e\uaa31\uaa32\uaa35\uaa36\uaa43\uaa4c\uaab0\uaab2-\uaab4\uaab7\uaab8\uaabe\uaabf\uaac1\uabe5\uabe8\uabed\udc00-\udfff\ufb1e\ufe00-\ufe0f\ufe20-\ufe26\uff9e\uff9f]/;function re(e){return e.charCodeAt(0)>=768&&ne.test(e)}function ie(e,t,n){for(;(n<0?t>0:t<e.length)&&re(e.charAt(t));)t+=n;return t}function oe(e,t,n){for(var r=t>n?-1:1;;){if(t==n)return t;var i=(t+n)/2,o=r<0?Math.ceil(i):Math.floor(i);if(o==t)return e(o)?t:n;e(o)?n=o:t=o+r}}var ae=null;function se(e,t,n){var r;ae=null;for(var i=0;i<e.length;++i){var o=e[i];if(o.from<t&&o.to>t)return i;o.to==t&&(o.from!=o.to&&"before"==n?r=i:ae=i),o.from==t&&(o.from!=o.to&&"before"!=n?r=i:ae=i)}return null!=r?r:ae}var le=function(){var e=/[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac]/,t=/[stwN]/,n=/[LRr]/,r=/[Lb1n]/,i=/[1n]/;function o(e,t,n){this.level=e,this.from=t,this.to=n}return function(a,s){var l="ltr"==s?"L":"R";if(0==a.length||"ltr"==s&&!e.test(a))return!1;for(var c,u=a.length,d=[],h=0;h<u;++h)d.push((c=a.charCodeAt(h))<=247?"bbbbbbbbbtstwsbbbbbbbbbbbbbbssstwNN%%%NNNNNN,N,N1111111111NNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNbbbbbbsbbbbbbbbbbbbbbbbbbbbbbbbbb,N%%%%NNNNLNNNNN%%11NLNNN1LNNNNNLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLN".charAt(c):1424<=c&&c<=1524?"R":1536<=c&&c<=1785?"nnnnnnNNr%%r,rNNmmmmmmmmmmmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmmmmmmmmnnnnnnnnnn%nnrrrmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmnNmmmmmmrrmmNmmmmrr1111111111".charAt(c-1536):1774<=c&&c<=2220?"r":8192<=c&&c<=8203?"w":8204==c?"b":"L");for(var p=0,f=l;p<u;++p){var m=d[p];"m"==m?d[p]=f:f=m}for(var g=0,v=l;g<u;++g){var y=d[g];"1"==y&&"r"==v?d[g]="n":n.test(y)&&(v=y,"r"==y&&(d[g]="R"))}for(var _=1,b=d[0];_<u-1;++_){var M=d[_];"+"==M&&"1"==b&&"1"==d[_+1]?d[_]="1":","!=M||b!=d[_+1]||"1"!=b&&"n"!=b||(d[_]=b),b=M}for(var w=0;w<u;++w){var A=d[w];if(","==A)d[w]="N";else if("%"==A){var C=void 0;for(C=w+1;C<u&&"%"==d[C];++C);for(var x=w&&"!"==d[w-1]||C<u&&"1"==d[C]?"1":"N",E=w;E<C;++E)d[E]=x;w=C-1}}for(var L=0,S=l;L<u;++L){var T=d[L];"L"==S&&"1"==T?d[L]="L":n.test(T)&&(S=T)}for(var O=0;O<u;++O)if(t.test(d[O])){var I=void 0;for(I=O+1;I<u&&t.test(d[I]);++I);for(var k="L"==(O?d[O-1]:l),D=k==("L"==(I<u?d[I]:l))?k?"L":"R":l,N=O;N<I;++N)d[N]=D;O=I-1}for(var j,P=[],z=0;z<u;)if(r.test(d[z])){var R=z;for(++z;z<u&&r.test(d[z]);++z);P.push(new o(0,R,z))}else{var B=z,H=P.length,F="rtl"==s?1:0;for(++z;z<u&&"L"!=d[z];++z);for(var Y=B;Y<z;)if(i.test(d[Y])){B<Y&&(P.splice(H,0,new o(1,B,Y)),H+=F);var V=Y;for(++Y;Y<z&&i.test(d[Y]);++Y);P.splice(H,0,new o(2,V,Y)),H+=F,B=Y}else++Y;B<z&&P.splice(H,0,new o(1,B,z))}return"ltr"==s&&(1==P[0].level&&(j=a.match(/^\s+/))&&(P[0].from=j[0].length,P.unshift(new o(0,0,j[0].length))),1==K(P).level&&(j=a.match(/\s+$/))&&(K(P).to-=j[0].length,P.push(new o(0,u-j[0].length,u)))),"rtl"==s?P.reverse():P}}();function ce(e,t){var n=e.order;return null==n&&(n=e.order=le(e.text,t)),n}var ue=[],de=function(e,t,n){if(e.addEventListener)e.addEventListener(t,n,!1);else if(e.attachEvent)e.attachEvent("on"+t,n);else{var r=e._handlers||(e._handlers={});r[t]=(r[t]||ue).concat(n)}};function he(e,t){return e._handlers&&e._handlers[t]||ue}function pe(e,t,n){if(e.removeEventListener)e.removeEventListener(t,n,!1);else if(e.detachEvent)e.detachEvent("on"+t,n);else{var r=e._handlers,i=r&&r[t];if(i){var o=H(i,n);o>-1&&(r[t]=i.slice(0,o).concat(i.slice(o+1)))}}}function fe(e,t){var n=he(e,t);if(n.length)for(var r=Array.prototype.slice.call(arguments,2),i=0;i<n.length;++i)n[i].apply(null,r)}function me(e,t,n){return"string"==typeof t&&(t={type:t,preventDefault:function(){this.defaultPrevented=!0}}),fe(e,n||t.type,e,t),Me(t)||t.codemirrorIgnore}function ge(e){var t=e._handlers&&e._handlers.cursorActivity;if(t)for(var n=e.curOp.cursorActivityHandlers||(e.curOp.cursorActivityHandlers=[]),r=0;r<t.length;++r)-1==H(n,t[r])&&n.push(t[r])}function ve(e,t){return he(e,t).length>0}function ye(e){e.prototype.on=function(e,t){de(this,e,t)},e.prototype.off=function(e,t){pe(this,e,t)}}function _e(e){e.preventDefault?e.preventDefault():e.returnValue=!1}function be(e){e.stopPropagation?e.stopPropagation():e.cancelBubble=!0}function Me(e){return null!=e.defaultPrevented?e.defaultPrevented:0==e.returnValue}function we(e){_e(e),be(e)}function Ae(e){return e.target||e.srcElement}function Ce(e){var t=e.which;return null==t&&(1&e.button?t=1:2&e.button?t=3:4&e.button&&(t=2)),y&&e.ctrlKey&&1==t&&(t=3),t}var xe,Ee,Le=function(){if(a&&s<9)return!1;var e=T("div");return"draggable"in e||"dragDrop"in e}();function Se(e){if(null==xe){var t=T("span","​");S(e,T("span",[t,document.createTextNode("x")])),0!=e.firstChild.offsetHeight&&(xe=t.offsetWidth<=1&&t.offsetHeight>2&&!(a&&s<8))}var n=xe?T("span","​"):T("span"," ",null,"display: inline-block; width: 1px; margin-right: -1px");return n.setAttribute("cm-text",""),n}function Te(e){if(null!=Ee)return Ee;var t=S(e,document.createTextNode("AخA")),n=x(t,0,1).getBoundingClientRect(),r=x(t,1,2).getBoundingClientRect();return L(e),!(!n||n.left==n.right)&&(Ee=r.right-n.right<3)}var Oe,Ie=3!="\n\nb".split(/\n/).length?function(e){for(var t=0,n=[],r=e.length;t<=r;){var i=e.indexOf("\n",t);-1==i&&(i=e.length);var o=e.slice(t,"\r"==e.charAt(i-1)?i-1:i),a=o.indexOf("\r");-1!=a?(n.push(o.slice(0,a)),t+=a+1):(n.push(o),t=i+1)}return n}:function(e){return e.split(/\r\n?|\n/)},ke=window.getSelection?function(e){try{return e.selectionStart!=e.selectionEnd}catch(e){return!1}}:function(e){var t;try{t=e.ownerDocument.selection.createRange()}catch(e){}return!(!t||t.parentElement()!=e)&&0!=t.compareEndPoints("StartToEnd",t)},De="oncopy"in(Oe=T("div"))||(Oe.setAttribute("oncopy","return;"),"function"==typeof Oe.oncopy),Ne=null,je={},Pe={};function ze(e,t){arguments.length>2&&(t.dependencies=Array.prototype.slice.call(arguments,2)),je[e]=t}function Re(e){if("string"==typeof e&&Pe.hasOwnProperty(e))e=Pe[e];else if(e&&"string"==typeof e.name&&Pe.hasOwnProperty(e.name)){var t=Pe[e.name];"string"==typeof t&&(t={name:t}),(e=Q(t,e)).name=t.name}else{if("string"==typeof e&&/^[\w\-]+\/[\w\-]+\+xml$/.test(e))return Re("application/xml");if("string"==typeof e&&/^[\w\-]+\/[\w\-]+\+json$/.test(e))return Re("application/json")}return"string"==typeof e?{name:e}:e||{name:"null"}}function Be(e,t){t=Re(t);var n=je[t.name];if(!n)return Be(e,"text/plain");var r=n(e,t);if(He.hasOwnProperty(t.name)){var i=He[t.name];for(var o in i)i.hasOwnProperty(o)&&(r.hasOwnProperty(o)&&(r["_"+o]=r[o]),r[o]=i[o])}if(r.name=t.name,t.helperType&&(r.helperType=t.helperType),t.modeProps)for(var a in t.modeProps)r[a]=t.modeProps[a];return r}var He={};function Fe(e,t){z(t,He.hasOwnProperty(e)?He[e]:He[e]={})}function Ye(e,t){if(!0===t)return t;if(e.copyState)return e.copyState(t);var n={};for(var r in t){var i=t[r];i instanceof Array&&(i=i.concat([])),n[r]=i}return n}function Ve(e,t){for(var n;e.innerMode&&(n=e.innerMode(t))&&n.mode!=e;)t=n.state,e=n.mode;return n||{mode:e,state:t}}function Ue(e,t,n){return!e.startState||e.startState(t,n)}var We=function(e,t,n){this.pos=this.start=0,this.string=e,this.tabSize=t||8,this.lastColumnPos=this.lastColumnValue=0,this.lineStart=0,this.lineOracle=n};function Ge(e,t){if((t-=e.first)<0||t>=e.size)throw new Error("There is no line "+(t+e.first)+" in the document.");for(var n=e;!n.lines;)for(var r=0;;++r){var i=n.children[r],o=i.chunkSize();if(t<o){n=i;break}t-=o}return n.lines[t]}function qe(e,t,n){var r=[],i=t.line;return e.iter(t.line,n.line+1,(function(e){var o=e.text;i==n.line&&(o=o.slice(0,n.ch)),i==t.line&&(o=o.slice(t.ch)),r.push(o),++i})),r}function Ke(e,t,n){var r=[];return e.iter(t,n,(function(e){r.push(e.text)})),r}function Xe(e,t){var n=t-e.height;if(n)for(var r=e;r;r=r.parent)r.height+=n}function Je(e){if(null==e.parent)return null;for(var t=e.parent,n=H(t.lines,e),r=t.parent;r;t=r,r=r.parent)for(var i=0;r.children[i]!=t;++i)n+=r.children[i].chunkSize();return n+t.first}function Qe(e,t){var n=e.first;e:do{for(var r=0;r<e.children.length;++r){var i=e.children[r],o=i.height;if(t<o){e=i;continue e}t-=o,n+=i.chunkSize()}return n}while(!e.lines);for(var a=0;a<e.lines.length;++a){var s=e.lines[a].height;if(t<s)break;t-=s}return n+a}function Ze(e,t){return t>=e.first&&t<e.first+e.size}function $e(e,t){return String(e.lineNumberFormatter(t+e.firstLineNumber))}function et(e,t,n){if(void 0===n&&(n=null),!(this instanceof et))return new et(e,t,n);this.line=e,this.ch=t,this.sticky=n}function tt(e,t){return e.line-t.line||e.ch-t.ch}function nt(e,t){return e.sticky==t.sticky&&0==tt(e,t)}function rt(e){return et(e.line,e.ch)}function it(e,t){return tt(e,t)<0?t:e}function ot(e,t){return tt(e,t)<0?e:t}function at(e,t){return Math.max(e.first,Math.min(t,e.first+e.size-1))}function st(e,t){if(t.line<e.first)return et(e.first,0);var n=e.first+e.size-1;return t.line>n?et(n,Ge(e,n).text.length):function(e,t){var n=e.ch;return null==n||n>t?et(e.line,t):n<0?et(e.line,0):e}(t,Ge(e,t.line).text.length)}function lt(e,t){for(var n=[],r=0;r<t.length;r++)n[r]=st(e,t[r]);return n}We.prototype.eol=function(){return this.pos>=this.string.length},We.prototype.sol=function(){return this.pos==this.lineStart},We.prototype.peek=function(){return this.string.charAt(this.pos)||void 0},We.prototype.next=function(){if(this.pos<this.string.length)return this.string.charAt(this.pos++)},We.prototype.eat=function(e){var t=this.string.charAt(this.pos);if("string"==typeof e?t==e:t&&(e.test?e.test(t):e(t)))return++this.pos,t},We.prototype.eatWhile=function(e){for(var t=this.pos;this.eat(e););return this.pos>t},We.prototype.eatSpace=function(){for(var e=this.pos;/[\s\u00a0]/.test(this.string.charAt(this.pos));)++this.pos;return this.pos>e},We.prototype.skipToEnd=function(){this.pos=this.string.length},We.prototype.skipTo=function(e){var t=this.string.indexOf(e,this.pos);if(t>-1)return this.pos=t,!0},We.prototype.backUp=function(e){this.pos-=e},We.prototype.column=function(){return this.lastColumnPos<this.start&&(this.lastColumnValue=R(this.string,this.start,this.tabSize,this.lastColumnPos,this.lastColumnValue),this.lastColumnPos=this.start),this.lastColumnValue-(this.lineStart?R(this.string,this.lineStart,this.tabSize):0)},We.prototype.indentation=function(){return R(this.string,null,this.tabSize)-(this.lineStart?R(this.string,this.lineStart,this.tabSize):0)},We.prototype.match=function(e,t,n){if("string"!=typeof e){var r=this.string.slice(this.pos).match(e);return r&&r.index>0?null:(r&&!1!==t&&(this.pos+=r[0].length),r)}var i=function(e){return n?e.toLowerCase():e};if(i(this.string.substr(this.pos,e.length))==i(e))return!1!==t&&(this.pos+=e.length),!0},We.prototype.current=function(){return this.string.slice(this.start,this.pos)},We.prototype.hideFirstChars=function(e,t){this.lineStart+=e;try{return t()}finally{this.lineStart-=e}},We.prototype.lookAhead=function(e){var t=this.lineOracle;return t&&t.lookAhead(e)},We.prototype.baseToken=function(){var e=this.lineOracle;return e&&e.baseToken(this.pos)};var ct=function(e,t){this.state=e,this.lookAhead=t},ut=function(e,t,n,r){this.state=t,this.doc=e,this.line=n,this.maxLookAhead=r||0,this.baseTokens=null,this.baseTokenPos=1};function dt(e,t,n,r){var i=[e.state.modeGen],o={};bt(e,t.text,e.doc.mode,n,(function(e,t){return i.push(e,t)}),o,r);for(var a=n.state,s=function(r){n.baseTokens=i;var s=e.state.overlays[r],l=1,c=0;n.state=!0,bt(e,t.text,s.mode,n,(function(e,t){for(var n=l;c<e;){var r=i[l];r>e&&i.splice(l,1,e,i[l+1],r),l+=2,c=Math.min(e,r)}if(t)if(s.opaque)i.splice(n,l-n,e,"overlay "+t),l=n+2;else for(;n<l;n+=2){var o=i[n+1];i[n+1]=(o?o+" ":"")+"overlay "+t}}),o),n.state=a,n.baseTokens=null,n.baseTokenPos=1},l=0;l<e.state.overlays.length;++l)s(l);return{styles:i,classes:o.bgClass||o.textClass?o:null}}function ht(e,t,n){if(!t.styles||t.styles[0]!=e.state.modeGen){var r=pt(e,Je(t)),i=t.text.length>e.options.maxHighlightLength&&Ye(e.doc.mode,r.state),o=dt(e,t,r);i&&(r.state=i),t.stateAfter=r.save(!i),t.styles=o.styles,o.classes?t.styleClasses=o.classes:t.styleClasses&&(t.styleClasses=null),n===e.doc.highlightFrontier&&(e.doc.modeFrontier=Math.max(e.doc.modeFrontier,++e.doc.highlightFrontier))}return t.styles}function pt(e,t,n){var r=e.doc,i=e.display;if(!r.mode.startState)return new ut(r,!0,t);var o=function(e,t,n){for(var r,i,o=e.doc,a=n?-1:t-(e.doc.mode.innerMode?1e3:100),s=t;s>a;--s){if(s<=o.first)return o.first;var l=Ge(o,s-1),c=l.stateAfter;if(c&&(!n||s+(c instanceof ct?c.lookAhead:0)<=o.modeFrontier))return s;var u=R(l.text,null,e.options.tabSize);(null==i||r>u)&&(i=s-1,r=u)}return i}(e,t,n),a=o>r.first&&Ge(r,o-1).stateAfter,s=a?ut.fromSaved(r,a,o):new ut(r,Ue(r.mode),o);return r.iter(o,t,(function(n){ft(e,n.text,s);var r=s.line;n.stateAfter=r==t-1||r%5==0||r>=i.viewFrom&&r<i.viewTo?s.save():null,s.nextLine()})),n&&(r.modeFrontier=s.line),s}function ft(e,t,n,r){var i=e.doc.mode,o=new We(t,e.options.tabSize,n);for(o.start=o.pos=r||0,""==t&&mt(i,n.state);!o.eol();)gt(i,o,n.state),o.start=o.pos}function mt(e,t){if(e.blankLine)return e.blankLine(t);if(e.innerMode){var n=Ve(e,t);return n.mode.blankLine?n.mode.blankLine(n.state):void 0}}function gt(e,t,n,r){for(var i=0;i<10;i++){r&&(r[0]=Ve(e,n).mode);var o=e.token(t,n);if(t.pos>t.start)return o}throw new Error("Mode "+e.name+" failed to advance stream.")}ut.prototype.lookAhead=function(e){var t=this.doc.getLine(this.line+e);return null!=t&&e>this.maxLookAhead&&(this.maxLookAhead=e),t},ut.prototype.baseToken=function(e){if(!this.baseTokens)return null;for(;this.baseTokens[this.baseTokenPos]<=e;)this.baseTokenPos+=2;var t=this.baseTokens[this.baseTokenPos+1];return{type:t&&t.replace(/( |^)overlay .*/,""),size:this.baseTokens[this.baseTokenPos]-e}},ut.prototype.nextLine=function(){this.line++,this.maxLookAhead>0&&this.maxLookAhead--},ut.fromSaved=function(e,t,n){return t instanceof ct?new ut(e,Ye(e.mode,t.state),n,t.lookAhead):new ut(e,Ye(e.mode,t),n)},ut.prototype.save=function(e){var t=!1!==e?Ye(this.doc.mode,this.state):this.state;return this.maxLookAhead>0?new ct(t,this.maxLookAhead):t};var vt=function(e,t,n){this.start=e.start,this.end=e.pos,this.string=e.current(),this.type=t||null,this.state=n};function yt(e,t,n,r){var i,o,a=e.doc,s=a.mode,l=Ge(a,(t=st(a,t)).line),c=pt(e,t.line,n),u=new We(l.text,e.options.tabSize,c);for(r&&(o=[]);(r||u.pos<t.ch)&&!u.eol();)u.start=u.pos,i=gt(s,u,c.state),r&&o.push(new vt(u,i,Ye(a.mode,c.state)));return r?o:new vt(u,i,c.state)}function _t(e,t){if(e)for(;;){var n=e.match(/(?:^|\s+)line-(background-)?(\S+)/);if(!n)break;e=e.slice(0,n.index)+e.slice(n.index+n[0].length);var r=n[1]?"bgClass":"textClass";null==t[r]?t[r]=n[2]:new RegExp("(?:^|\\s)"+n[2]+"(?:$|\\s)").test(t[r])||(t[r]+=" "+n[2])}return e}function bt(e,t,n,r,i,o,a){var s=n.flattenSpans;null==s&&(s=e.options.flattenSpans);var l,c=0,u=null,d=new We(t,e.options.tabSize,r),h=e.options.addModeClass&&[null];for(""==t&&_t(mt(n,r.state),o);!d.eol();){if(d.pos>e.options.maxHighlightLength?(s=!1,a&&ft(e,t,r,d.pos),d.pos=t.length,l=null):l=_t(gt(n,d,r.state,h),o),h){var p=h[0].name;p&&(l="m-"+(l?p+" "+l:p))}if(!s||u!=l){for(;c<d.start;)i(c=Math.min(d.start,c+5e3),u);u=l}d.start=d.pos}for(;c<d.pos;){var f=Math.min(d.pos,c+5e3);i(f,u),c=f}}var Mt=!1,wt=!1;function At(e,t,n){this.marker=e,this.from=t,this.to=n}function Ct(e,t){if(e)for(var n=0;n<e.length;++n){var r=e[n];if(r.marker==t)return r}}function xt(e,t){for(var n,r=0;r<e.length;++r)e[r]!=t&&(n||(n=[])).push(e[r]);return n}function Et(e,t){if(t.full)return null;var n=Ze(e,t.from.line)&&Ge(e,t.from.line).markedSpans,r=Ze(e,t.to.line)&&Ge(e,t.to.line).markedSpans;if(!n&&!r)return null;var i=t.from.ch,o=t.to.ch,a=0==tt(t.from,t.to),s=function(e,t,n){var r;if(e)for(var i=0;i<e.length;++i){var o=e[i],a=o.marker;if(null==o.from||(a.inclusiveLeft?o.from<=t:o.from<t)||o.from==t&&"bookmark"==a.type&&(!n||!o.marker.insertLeft)){var s=null==o.to||(a.inclusiveRight?o.to>=t:o.to>t);(r||(r=[])).push(new At(a,o.from,s?null:o.to))}}return r}(n,i,a),l=function(e,t,n){var r;if(e)for(var i=0;i<e.length;++i){var o=e[i],a=o.marker;if(null==o.to||(a.inclusiveRight?o.to>=t:o.to>t)||o.from==t&&"bookmark"==a.type&&(!n||o.marker.insertLeft)){var s=null==o.from||(a.inclusiveLeft?o.from<=t:o.from<t);(r||(r=[])).push(new At(a,s?null:o.from-t,null==o.to?null:o.to-t))}}return r}(r,o,a),c=1==t.text.length,u=K(t.text).length+(c?i:0);if(s)for(var d=0;d<s.length;++d){var h=s[d];if(null==h.to){var p=Ct(l,h.marker);p?c&&(h.to=null==p.to?null:p.to+u):h.to=i}}if(l)for(var f=0;f<l.length;++f){var m=l[f];null!=m.to&&(m.to+=u),null==m.from?Ct(s,m.marker)||(m.from=u,c&&(s||(s=[])).push(m)):(m.from+=u,c&&(s||(s=[])).push(m))}s&&(s=Lt(s)),l&&l!=s&&(l=Lt(l));var g=[s];if(!c){var v,y=t.text.length-2;if(y>0&&s)for(var _=0;_<s.length;++_)null==s[_].to&&(v||(v=[])).push(new At(s[_].marker,null,null));for(var b=0;b<y;++b)g.push(v);g.push(l)}return g}function Lt(e){for(var t=0;t<e.length;++t){var n=e[t];null!=n.from&&n.from==n.to&&!1!==n.marker.clearWhenEmpty&&e.splice(t--,1)}return e.length?e:null}function St(e){var t=e.markedSpans;if(t){for(var n=0;n<t.length;++n)t[n].marker.detachLine(e);e.markedSpans=null}}function Tt(e,t){if(t){for(var n=0;n<t.length;++n)t[n].marker.attachLine(e);e.markedSpans=t}}function Ot(e){return e.inclusiveLeft?-1:0}function It(e){return e.inclusiveRight?1:0}function kt(e,t){var n=e.lines.length-t.lines.length;if(0!=n)return n;var r=e.find(),i=t.find(),o=tt(r.from,i.from)||Ot(e)-Ot(t);if(o)return-o;var a=tt(r.to,i.to)||It(e)-It(t);return a||t.id-e.id}function Dt(e,t){var n,r=wt&&e.markedSpans;if(r)for(var i=void 0,o=0;o<r.length;++o)(i=r[o]).marker.collapsed&&null==(t?i.from:i.to)&&(!n||kt(n,i.marker)<0)&&(n=i.marker);return n}function Nt(e){return Dt(e,!0)}function jt(e){return Dt(e,!1)}function Pt(e,t){var n,r=wt&&e.markedSpans;if(r)for(var i=0;i<r.length;++i){var o=r[i];o.marker.collapsed&&(null==o.from||o.from<t)&&(null==o.to||o.to>t)&&(!n||kt(n,o.marker)<0)&&(n=o.marker)}return n}function zt(e,t,n,r,i){var o=Ge(e,t),a=wt&&o.markedSpans;if(a)for(var s=0;s<a.length;++s){var l=a[s];if(l.marker.collapsed){var c=l.marker.find(0),u=tt(c.from,n)||Ot(l.marker)-Ot(i),d=tt(c.to,r)||It(l.marker)-It(i);if(!(u>=0&&d<=0||u<=0&&d>=0)&&(u<=0&&(l.marker.inclusiveRight&&i.inclusiveLeft?tt(c.to,n)>=0:tt(c.to,n)>0)||u>=0&&(l.marker.inclusiveRight&&i.inclusiveLeft?tt(c.from,r)<=0:tt(c.from,r)<0)))return!0}}}function Rt(e){for(var t;t=Nt(e);)e=t.find(-1,!0).line;return e}function Bt(e,t){var n=Ge(e,t),r=Rt(n);return n==r?t:Je(r)}function Ht(e,t){if(t>e.lastLine())return t;var n,r=Ge(e,t);if(!Ft(e,r))return t;for(;n=jt(r);)r=n.find(1,!0).line;return Je(r)+1}function Ft(e,t){var n=wt&&t.markedSpans;if(n)for(var r=void 0,i=0;i<n.length;++i)if((r=n[i]).marker.collapsed){if(null==r.from)return!0;if(!r.marker.widgetNode&&0==r.from&&r.marker.inclusiveLeft&&Yt(e,t,r))return!0}}function Yt(e,t,n){if(null==n.to){var r=n.marker.find(1,!0);return Yt(e,r.line,Ct(r.line.markedSpans,n.marker))}if(n.marker.inclusiveRight&&n.to==t.text.length)return!0;for(var i=void 0,o=0;o<t.markedSpans.length;++o)if((i=t.markedSpans[o]).marker.collapsed&&!i.marker.widgetNode&&i.from==n.to&&(null==i.to||i.to!=n.from)&&(i.marker.inclusiveLeft||n.marker.inclusiveRight)&&Yt(e,t,i))return!0}function Vt(e){for(var t=0,n=(e=Rt(e)).parent,r=0;r<n.lines.length;++r){var i=n.lines[r];if(i==e)break;t+=i.height}for(var o=n.parent;o;o=(n=o).parent)for(var a=0;a<o.children.length;++a){var s=o.children[a];if(s==n)break;t+=s.height}return t}function Ut(e){if(0==e.height)return 0;for(var t,n=e.text.length,r=e;t=Nt(r);){var i=t.find(0,!0);r=i.from.line,n+=i.from.ch-i.to.ch}for(r=e;t=jt(r);){var o=t.find(0,!0);n-=r.text.length-o.from.ch,n+=(r=o.to.line).text.length-o.to.ch}return n}function Wt(e){var t=e.display,n=e.doc;t.maxLine=Ge(n,n.first),t.maxLineLength=Ut(t.maxLine),t.maxLineChanged=!0,n.iter((function(e){var n=Ut(e);n>t.maxLineLength&&(t.maxLineLength=n,t.maxLine=e)}))}var Gt=function(e,t,n){this.text=e,Tt(this,t),this.height=n?n(this):1};function qt(e){e.parent=null,St(e)}Gt.prototype.lineNo=function(){return Je(this)},ye(Gt);var Kt={},Xt={};function Jt(e,t){if(!e||/^\s*$/.test(e))return null;var n=t.addModeClass?Xt:Kt;return n[e]||(n[e]=e.replace(/\S+/g,"cm-$&"))}function Qt(e,t){var n=O("span",null,null,l?"padding-right: .1px":null),r={pre:O("pre",[n],"CodeMirror-line"),content:n,col:0,pos:0,cm:e,trailingSpace:!1,splitSpaces:e.getOption("lineWrapping")};t.measure={};for(var i=0;i<=(t.rest?t.rest.length:0);i++){var o=i?t.rest[i-1]:t.line,a=void 0;r.pos=0,r.addToken=$t,Te(e.display.measure)&&(a=ce(o,e.doc.direction))&&(r.addToken=en(r.addToken,a)),r.map=[],nn(o,r,ht(e,o,t!=e.display.externalMeasured&&Je(o))),o.styleClasses&&(o.styleClasses.bgClass&&(r.bgClass=N(o.styleClasses.bgClass,r.bgClass||"")),o.styleClasses.textClass&&(r.textClass=N(o.styleClasses.textClass,r.textClass||""))),0==r.map.length&&r.map.push(0,0,r.content.appendChild(Se(e.display.measure))),0==i?(t.measure.map=r.map,t.measure.cache={}):((t.measure.maps||(t.measure.maps=[])).push(r.map),(t.measure.caches||(t.measure.caches=[])).push({}))}if(l){var s=r.content.lastChild;(/\bcm-tab\b/.test(s.className)||s.querySelector&&s.querySelector(".cm-tab"))&&(r.content.className="cm-tab-wrap-hack")}return fe(e,"renderLine",e,t.line,r.pre),r.pre.className&&(r.textClass=N(r.pre.className,r.textClass||"")),r}function Zt(e){var t=T("span","•","cm-invalidchar");return t.title="\\u"+e.charCodeAt(0).toString(16),t.setAttribute("aria-label",t.title),t}function $t(e,t,n,r,i,o,l){if(t){var c,u=e.splitSpaces?function(e,t){if(e.length>1&&!/  /.test(e))return e;for(var n=t,r="",i=0;i<e.length;i++){var o=e.charAt(i);" "!=o||!n||i!=e.length-1&&32!=e.charCodeAt(i+1)||(o=" "),r+=o,n=" "==o}return r}(t,e.trailingSpace):t,d=e.cm.state.specialChars,h=!1;if(d.test(t)){c=document.createDocumentFragment();for(var p=0;;){d.lastIndex=p;var f=d.exec(t),m=f?f.index-p:t.length-p;if(m){var g=document.createTextNode(u.slice(p,p+m));a&&s<9?c.appendChild(T("span",[g])):c.appendChild(g),e.map.push(e.pos,e.pos+m,g),e.col+=m,e.pos+=m}if(!f)break;p+=m+1;var v=void 0;if("\t"==f[0]){var y=e.cm.options.tabSize,_=y-e.col%y;(v=c.appendChild(T("span",q(_),"cm-tab"))).setAttribute("role","presentation"),v.setAttribute("cm-text","\t"),e.col+=_}else"\r"==f[0]||"\n"==f[0]?((v=c.appendChild(T("span","\r"==f[0]?"␍":"␤","cm-invalidchar"))).setAttribute("cm-text",f[0]),e.col+=1):((v=e.cm.options.specialCharPlaceholder(f[0])).setAttribute("cm-text",f[0]),a&&s<9?c.appendChild(T("span",[v])):c.appendChild(v),e.col+=1);e.map.push(e.pos,e.pos+1,v),e.pos++}}else e.col+=t.length,c=document.createTextNode(u),e.map.push(e.pos,e.pos+t.length,c),a&&s<9&&(h=!0),e.pos+=t.length;if(e.trailingSpace=32==u.charCodeAt(t.length-1),n||r||i||h||o||l){var b=n||"";r&&(b+=r),i&&(b+=i);var M=T("span",[c],b,o);if(l)for(var w in l)l.hasOwnProperty(w)&&"style"!=w&&"class"!=w&&M.setAttribute(w,l[w]);return e.content.appendChild(M)}e.content.appendChild(c)}}function en(e,t){return function(n,r,i,o,a,s,l){i=i?i+" cm-force-border":"cm-force-border";for(var c=n.pos,u=c+r.length;;){for(var d=void 0,h=0;h<t.length&&!((d=t[h]).to>c&&d.from<=c);h++);if(d.to>=u)return e(n,r,i,o,a,s,l);e(n,r.slice(0,d.to-c),i,o,null,s,l),o=null,r=r.slice(d.to-c),c=d.to}}}function tn(e,t,n,r){var i=!r&&n.widgetNode;i&&e.map.push(e.pos,e.pos+t,i),!r&&e.cm.display.input.needsContentAttribute&&(i||(i=e.content.appendChild(document.createElement("span"))),i.setAttribute("cm-marker",n.id)),i&&(e.cm.display.input.setUneditable(i),e.content.appendChild(i)),e.pos+=t,e.trailingSpace=!1}function nn(e,t,n){var r=e.markedSpans,i=e.text,o=0;if(r)for(var a,s,l,c,u,d,h,p=i.length,f=0,m=1,g="",v=0;;){if(v==f){l=c=u=s="",h=null,d=null,v=1/0;for(var y=[],_=void 0,b=0;b<r.length;++b){var M=r[b],w=M.marker;if("bookmark"==w.type&&M.from==f&&w.widgetNode)y.push(w);else if(M.from<=f&&(null==M.to||M.to>f||w.collapsed&&M.to==f&&M.from==f)){if(null!=M.to&&M.to!=f&&v>M.to&&(v=M.to,c=""),w.className&&(l+=" "+w.className),w.css&&(s=(s?s+";":"")+w.css),w.startStyle&&M.from==f&&(u+=" "+w.startStyle),w.endStyle&&M.to==v&&(_||(_=[])).push(w.endStyle,M.to),w.title&&((h||(h={})).title=w.title),w.attributes)for(var A in w.attributes)(h||(h={}))[A]=w.attributes[A];w.collapsed&&(!d||kt(d.marker,w)<0)&&(d=M)}else M.from>f&&v>M.from&&(v=M.from)}if(_)for(var C=0;C<_.length;C+=2)_[C+1]==v&&(c+=" "+_[C]);if(!d||d.from==f)for(var x=0;x<y.length;++x)tn(t,0,y[x]);if(d&&(d.from||0)==f){if(tn(t,(null==d.to?p+1:d.to)-f,d.marker,null==d.from),null==d.to)return;d.to==f&&(d=!1)}}if(f>=p)break;for(var E=Math.min(p,v);;){if(g){var L=f+g.length;if(!d){var S=L>E?g.slice(0,E-f):g;t.addToken(t,S,a?a+l:l,u,f+S.length==v?c:"",s,h)}if(L>=E){g=g.slice(E-f),f=E;break}f=L,u=""}g=i.slice(o,o=n[m++]),a=Jt(n[m++],t.cm.options)}}else for(var T=1;T<n.length;T+=2)t.addToken(t,i.slice(o,o=n[T]),Jt(n[T+1],t.cm.options))}function rn(e,t,n){this.line=t,this.rest=function(e){for(var t,n;t=jt(e);)e=t.find(1,!0).line,(n||(n=[])).push(e);return n}(t),this.size=this.rest?Je(K(this.rest))-n+1:1,this.node=this.text=null,this.hidden=Ft(e,t)}function on(e,t,n){for(var r,i=[],o=t;o<n;o=r){var a=new rn(e.doc,Ge(e.doc,o),o);r=o+a.size,i.push(a)}return i}var an=null,sn=null;function ln(e,t){var n=he(e,t);if(n.length){var r,i=Array.prototype.slice.call(arguments,2);an?r=an.delayedCallbacks:sn?r=sn:(r=sn=[],setTimeout(cn,0));for(var o=function(e){r.push((function(){return n[e].apply(null,i)}))},a=0;a<n.length;++a)o(a)}}function cn(){var e=sn;sn=null;for(var t=0;t<e.length;++t)e[t]()}function un(e,t,n,r){for(var i=0;i<t.changes.length;i++){var o=t.changes[i];"text"==o?pn(e,t):"gutter"==o?mn(e,t,n,r):"class"==o?fn(e,t):"widget"==o&&gn(e,t,r)}t.changes=null}function dn(e){return e.node==e.text&&(e.node=T("div",null,null,"position: relative"),e.text.parentNode&&e.text.parentNode.replaceChild(e.node,e.text),e.node.appendChild(e.text),a&&s<8&&(e.node.style.zIndex=2)),e.node}function hn(e,t){var n=e.display.externalMeasured;return n&&n.line==t.line?(e.display.externalMeasured=null,t.measure=n.measure,n.built):Qt(e,t)}function pn(e,t){var n=t.text.className,r=hn(e,t);t.text==t.node&&(t.node=r.pre),t.text.parentNode.replaceChild(r.pre,t.text),t.text=r.pre,r.bgClass!=t.bgClass||r.textClass!=t.textClass?(t.bgClass=r.bgClass,t.textClass=r.textClass,fn(e,t)):n&&(t.text.className=n)}function fn(e,t){!function(e,t){var n=t.bgClass?t.bgClass+" "+(t.line.bgClass||""):t.line.bgClass;if(n&&(n+=" CodeMirror-linebackground"),t.background)n?t.background.className=n:(t.background.parentNode.removeChild(t.background),t.background=null);else if(n){var r=dn(t);t.background=r.insertBefore(T("div",null,n),r.firstChild),e.display.input.setUneditable(t.background)}}(e,t),t.line.wrapClass?dn(t).className=t.line.wrapClass:t.node!=t.text&&(t.node.className="");var n=t.textClass?t.textClass+" "+(t.line.textClass||""):t.line.textClass;t.text.className=n||""}function mn(e,t,n,r){if(t.gutter&&(t.node.removeChild(t.gutter),t.gutter=null),t.gutterBackground&&(t.node.removeChild(t.gutterBackground),t.gutterBackground=null),t.line.gutterClass){var i=dn(t);t.gutterBackground=T("div",null,"CodeMirror-gutter-background "+t.line.gutterClass,"left: "+(e.options.fixedGutter?r.fixedPos:-r.gutterTotalWidth)+"px; width: "+r.gutterTotalWidth+"px"),e.display.input.setUneditable(t.gutterBackground),i.insertBefore(t.gutterBackground,t.text)}var o=t.line.gutterMarkers;if(e.options.lineNumbers||o){var a=dn(t),s=t.gutter=T("div",null,"CodeMirror-gutter-wrapper","left: "+(e.options.fixedGutter?r.fixedPos:-r.gutterTotalWidth)+"px");if(s.setAttribute("aria-hidden","true"),e.display.input.setUneditable(s),a.insertBefore(s,t.text),t.line.gutterClass&&(s.className+=" "+t.line.gutterClass),!e.options.lineNumbers||o&&o["CodeMirror-linenumbers"]||(t.lineNumber=s.appendChild(T("div",$e(e.options,n),"CodeMirror-linenumber CodeMirror-gutter-elt","left: "+r.gutterLeft["CodeMirror-linenumbers"]+"px; width: "+e.display.lineNumInnerWidth+"px"))),o)for(var l=0;l<e.display.gutterSpecs.length;++l){var c=e.display.gutterSpecs[l].className,u=o.hasOwnProperty(c)&&o[c];u&&s.appendChild(T("div",[u],"CodeMirror-gutter-elt","left: "+r.gutterLeft[c]+"px; width: "+r.gutterWidth[c]+"px"))}}}function gn(e,t,n){t.alignable&&(t.alignable=null);for(var r=C("CodeMirror-linewidget"),i=t.node.firstChild,o=void 0;i;i=o)o=i.nextSibling,r.test(i.className)&&t.node.removeChild(i);yn(e,t,n)}function vn(e,t,n,r){var i=hn(e,t);return t.text=t.node=i.pre,i.bgClass&&(t.bgClass=i.bgClass),i.textClass&&(t.textClass=i.textClass),fn(e,t),mn(e,t,n,r),yn(e,t,r),t.node}function yn(e,t,n){if(_n(e,t.line,t,n,!0),t.rest)for(var r=0;r<t.rest.length;r++)_n(e,t.rest[r],t,n,!1)}function _n(e,t,n,r,i){if(t.widgets)for(var o=dn(n),a=0,s=t.widgets;a<s.length;++a){var l=s[a],c=T("div",[l.node],"CodeMirror-linewidget"+(l.className?" "+l.className:""));l.handleMouseEvents||c.setAttribute("cm-ignore-events","true"),bn(l,c,n,r),e.display.input.setUneditable(c),i&&l.above?o.insertBefore(c,n.gutter||n.text):o.appendChild(c),ln(l,"redraw")}}function bn(e,t,n,r){if(e.noHScroll){(n.alignable||(n.alignable=[])).push(t);var i=r.wrapperWidth;t.style.left=r.fixedPos+"px",e.coverGutter||(i-=r.gutterTotalWidth,t.style.paddingLeft=r.gutterTotalWidth+"px"),t.style.width=i+"px"}e.coverGutter&&(t.style.zIndex=5,t.style.position="relative",e.noHScroll||(t.style.marginLeft=-r.gutterTotalWidth+"px"))}function Mn(e){if(null!=e.height)return e.height;var t=e.doc.cm;if(!t)return 0;if(!I(document.body,e.node)){var n="position: relative;";e.coverGutter&&(n+="margin-left: -"+t.display.gutters.offsetWidth+"px;"),e.noHScroll&&(n+="width: "+t.display.wrapper.clientWidth+"px;"),S(t.display.measure,T("div",[e.node],null,n))}return e.height=e.node.parentNode.offsetHeight}function wn(e,t){for(var n=Ae(t);n!=e.wrapper;n=n.parentNode)if(!n||1==n.nodeType&&"true"==n.getAttribute("cm-ignore-events")||n.parentNode==e.sizer&&n!=e.mover)return!0}function An(e){return e.lineSpace.offsetTop}function Cn(e){return e.mover.offsetHeight-e.lineSpace.offsetHeight}function xn(e){if(e.cachedPaddingH)return e.cachedPaddingH;var t=S(e.measure,T("pre","x","CodeMirror-line-like")),n=window.getComputedStyle?window.getComputedStyle(t):t.currentStyle,r={left:parseInt(n.paddingLeft),right:parseInt(n.paddingRight)};return isNaN(r.left)||isNaN(r.right)||(e.cachedPaddingH=r),r}function En(e){return 50-e.display.nativeBarWidth}function Ln(e){return e.display.scroller.clientWidth-En(e)-e.display.barWidth}function Sn(e){return e.display.scroller.clientHeight-En(e)-e.display.barHeight}function Tn(e,t,n){if(e.line==t)return{map:e.measure.map,cache:e.measure.cache};for(var r=0;r<e.rest.length;r++)if(e.rest[r]==t)return{map:e.measure.maps[r],cache:e.measure.caches[r]};for(var i=0;i<e.rest.length;i++)if(Je(e.rest[i])>n)return{map:e.measure.maps[i],cache:e.measure.caches[i],before:!0}}function On(e,t,n,r){return Dn(e,kn(e,t),n,r)}function In(e,t){if(t>=e.display.viewFrom&&t<e.display.viewTo)return e.display.view[ur(e,t)];var n=e.display.externalMeasured;return n&&t>=n.lineN&&t<n.lineN+n.size?n:void 0}function kn(e,t){var n=Je(t),r=In(e,n);r&&!r.text?r=null:r&&r.changes&&(un(e,r,n,or(e)),e.curOp.forceUpdate=!0),r||(r=function(e,t){var n=Je(t=Rt(t)),r=e.display.externalMeasured=new rn(e.doc,t,n);r.lineN=n;var i=r.built=Qt(e,r);return r.text=i.pre,S(e.display.lineMeasure,i.pre),r}(e,t));var i=Tn(r,t,n);return{line:t,view:r,rect:null,map:i.map,cache:i.cache,before:i.before,hasHeights:!1}}function Dn(e,t,n,r,i){t.before&&(n=-1);var o,l=n+(r||"");return t.cache.hasOwnProperty(l)?o=t.cache[l]:(t.rect||(t.rect=t.view.text.getBoundingClientRect()),t.hasHeights||(function(e,t,n){var r=e.options.lineWrapping,i=r&&Ln(e);if(!t.measure.heights||r&&t.measure.width!=i){var o=t.measure.heights=[];if(r){t.measure.width=i;for(var a=t.text.firstChild.getClientRects(),s=0;s<a.length-1;s++){var l=a[s],c=a[s+1];Math.abs(l.bottom-c.bottom)>2&&o.push((l.bottom+c.top)/2-n.top)}}o.push(n.bottom-n.top)}}(e,t.view,t.rect),t.hasHeights=!0),(o=function(e,t,n,r){var i,o=Pn(t.map,n,r),l=o.node,c=o.start,u=o.end,d=o.collapse;if(3==l.nodeType){for(var h=0;h<4;h++){for(;c&&re(t.line.text.charAt(o.coverStart+c));)--c;for(;o.coverStart+u<o.coverEnd&&re(t.line.text.charAt(o.coverStart+u));)++u;if((i=a&&s<9&&0==c&&u==o.coverEnd-o.coverStart?l.parentNode.getBoundingClientRect():zn(x(l,c,u).getClientRects(),r)).left||i.right||0==c)break;u=c,c-=1,d="right"}a&&s<11&&(i=function(e,t){if(!window.screen||null==screen.logicalXDPI||screen.logicalXDPI==screen.deviceXDPI||!function(e){if(null!=Ne)return Ne;var t=S(e,T("span","x")),n=t.getBoundingClientRect(),r=x(t,0,1).getBoundingClientRect();return Ne=Math.abs(n.left-r.left)>1}(e))return t;var n=screen.logicalXDPI/screen.deviceXDPI,r=screen.logicalYDPI/screen.deviceYDPI;return{left:t.left*n,right:t.right*n,top:t.top*r,bottom:t.bottom*r}}(e.display.measure,i))}else{var p;c>0&&(d=r="right"),i=e.options.lineWrapping&&(p=l.getClientRects()).length>1?p["right"==r?p.length-1:0]:l.getBoundingClientRect()}if(a&&s<9&&!c&&(!i||!i.left&&!i.right)){var f=l.parentNode.getClientRects()[0];i=f?{left:f.left,right:f.left+ir(e.display),top:f.top,bottom:f.bottom}:jn}for(var m=i.top-t.rect.top,g=i.bottom-t.rect.top,v=(m+g)/2,y=t.view.measure.heights,_=0;_<y.length-1&&!(v<y[_]);_++);var b=_?y[_-1]:0,M=y[_],w={left:("right"==d?i.right:i.left)-t.rect.left,right:("left"==d?i.left:i.right)-t.rect.left,top:b,bottom:M};return i.left||i.right||(w.bogus=!0),e.options.singleCursorHeightPerLine||(w.rtop=m,w.rbottom=g),w}(e,t,n,r)).bogus||(t.cache[l]=o)),{left:o.left,right:o.right,top:i?o.rtop:o.top,bottom:i?o.rbottom:o.bottom}}var Nn,jn={left:0,right:0,top:0,bottom:0};function Pn(e,t,n){for(var r,i,o,a,s,l,c=0;c<e.length;c+=3)if(s=e[c],l=e[c+1],t<s?(i=0,o=1,a="left"):t<l?o=1+(i=t-s):(c==e.length-3||t==l&&e[c+3]>t)&&(i=(o=l-s)-1,t>=l&&(a="right")),null!=i){if(r=e[c+2],s==l&&n==(r.insertLeft?"left":"right")&&(a=n),"left"==n&&0==i)for(;c&&e[c-2]==e[c-3]&&e[c-1].insertLeft;)r=e[2+(c-=3)],a="left";if("right"==n&&i==l-s)for(;c<e.length-3&&e[c+3]==e[c+4]&&!e[c+5].insertLeft;)r=e[(c+=3)+2],a="right";break}return{node:r,start:i,end:o,collapse:a,coverStart:s,coverEnd:l}}function zn(e,t){var n=jn;if("left"==t)for(var r=0;r<e.length&&(n=e[r]).left==n.right;r++);else for(var i=e.length-1;i>=0&&(n=e[i]).left==n.right;i--);return n}function Rn(e){if(e.measure&&(e.measure.cache={},e.measure.heights=null,e.rest))for(var t=0;t<e.rest.length;t++)e.measure.caches[t]={}}function Bn(e){e.display.externalMeasure=null,L(e.display.lineMeasure);for(var t=0;t<e.display.view.length;t++)Rn(e.display.view[t])}function Hn(e){Bn(e),e.display.cachedCharWidth=e.display.cachedTextHeight=e.display.cachedPaddingH=null,e.options.lineWrapping||(e.display.maxLineChanged=!0),e.display.lineNumChars=null}function Fn(){return u&&g?-(document.body.getBoundingClientRect().left-parseInt(getComputedStyle(document.body).marginLeft)):window.pageXOffset||(document.documentElement||document.body).scrollLeft}function Yn(){return u&&g?-(document.body.getBoundingClientRect().top-parseInt(getComputedStyle(document.body).marginTop)):window.pageYOffset||(document.documentElement||document.body).scrollTop}function Vn(e){var t=0;if(e.widgets)for(var n=0;n<e.widgets.length;++n)e.widgets[n].above&&(t+=Mn(e.widgets[n]));return t}function Un(e,t,n,r,i){if(!i){var o=Vn(t);n.top+=o,n.bottom+=o}if("line"==r)return n;r||(r="local");var a=Vt(t);if("local"==r?a+=An(e.display):a-=e.display.viewOffset,"page"==r||"window"==r){var s=e.display.lineSpace.getBoundingClientRect();a+=s.top+("window"==r?0:Yn());var l=s.left+("window"==r?0:Fn());n.left+=l,n.right+=l}return n.top+=a,n.bottom+=a,n}function Wn(e,t,n){if("div"==n)return t;var r=t.left,i=t.top;if("page"==n)r-=Fn(),i-=Yn();else if("local"==n||!n){var o=e.display.sizer.getBoundingClientRect();r+=o.left,i+=o.top}var a=e.display.lineSpace.getBoundingClientRect();return{left:r-a.left,top:i-a.top}}function Gn(e,t,n,r,i){return r||(r=Ge(e.doc,t.line)),Un(e,r,On(e,r,t.ch,i),n)}function qn(e,t,n,r,i,o){function a(t,a){var s=Dn(e,i,t,a?"right":"left",o);return a?s.left=s.right:s.right=s.left,Un(e,r,s,n)}r=r||Ge(e.doc,t.line),i||(i=kn(e,r));var s=ce(r,e.doc.direction),l=t.ch,c=t.sticky;if(l>=r.text.length?(l=r.text.length,c="before"):l<=0&&(l=0,c="after"),!s)return a("before"==c?l-1:l,"before"==c);function u(e,t,n){return a(n?e-1:e,1==s[t].level!=n)}var d=se(s,l,c),h=ae,p=u(l,d,"before"==c);return null!=h&&(p.other=u(l,h,"before"!=c)),p}function Kn(e,t){var n=0;t=st(e.doc,t),e.options.lineWrapping||(n=ir(e.display)*t.ch);var r=Ge(e.doc,t.line),i=Vt(r)+An(e.display);return{left:n,right:n,top:i,bottom:i+r.height}}function Xn(e,t,n,r,i){var o=et(e,t,n);return o.xRel=i,r&&(o.outside=r),o}function Jn(e,t,n){var r=e.doc;if((n+=e.display.viewOffset)<0)return Xn(r.first,0,null,-1,-1);var i=Qe(r,n),o=r.first+r.size-1;if(i>o)return Xn(r.first+r.size-1,Ge(r,o).text.length,null,1,1);t<0&&(t=0);for(var a=Ge(r,i);;){var s=er(e,a,i,t,n),l=Pt(a,s.ch+(s.xRel>0||s.outside>0?1:0));if(!l)return s;var c=l.find(1);if(c.line==i)return c;a=Ge(r,i=c.line)}}function Qn(e,t,n,r){r-=Vn(t);var i=t.text.length,o=oe((function(t){return Dn(e,n,t-1).bottom<=r}),i,0);return{begin:o,end:i=oe((function(t){return Dn(e,n,t).top>r}),o,i)}}function Zn(e,t,n,r){return n||(n=kn(e,t)),Qn(e,t,n,Un(e,t,Dn(e,n,r),"line").top)}function $n(e,t,n,r){return!(e.bottom<=n)&&(e.top>n||(r?e.left:e.right)>t)}function er(e,t,n,r,i){i-=Vt(t);var o=kn(e,t),a=Vn(t),s=0,l=t.text.length,c=!0,u=ce(t,e.doc.direction);if(u){var d=(e.options.lineWrapping?nr:tr)(e,t,n,o,u,r,i);s=(c=1!=d.level)?d.from:d.to-1,l=c?d.to:d.from-1}var h,p,f=null,m=null,g=oe((function(t){var n=Dn(e,o,t);return n.top+=a,n.bottom+=a,!!$n(n,r,i,!1)&&(n.top<=i&&n.left<=r&&(f=t,m=n),!0)}),s,l),v=!1;if(m){var y=r-m.left<m.right-r,_=y==c;g=f+(_?0:1),p=_?"after":"before",h=y?m.left:m.right}else{c||g!=l&&g!=s||g++,p=0==g?"after":g==t.text.length?"before":Dn(e,o,g-(c?1:0)).bottom+a<=i==c?"after":"before";var b=qn(e,et(n,g,p),"line",t,o);h=b.left,v=i<b.top?-1:i>=b.bottom?1:0}return Xn(n,g=ie(t.text,g,1),p,v,r-h)}function tr(e,t,n,r,i,o,a){var s=oe((function(s){var l=i[s],c=1!=l.level;return $n(qn(e,et(n,c?l.to:l.from,c?"before":"after"),"line",t,r),o,a,!0)}),0,i.length-1),l=i[s];if(s>0){var c=1!=l.level,u=qn(e,et(n,c?l.from:l.to,c?"after":"before"),"line",t,r);$n(u,o,a,!0)&&u.top>a&&(l=i[s-1])}return l}function nr(e,t,n,r,i,o,a){var s=Qn(e,t,r,a),l=s.begin,c=s.end;/\s/.test(t.text.charAt(c-1))&&c--;for(var u=null,d=null,h=0;h<i.length;h++){var p=i[h];if(!(p.from>=c||p.to<=l)){var f=Dn(e,r,1!=p.level?Math.min(c,p.to)-1:Math.max(l,p.from)).right,m=f<o?o-f+1e9:f-o;(!u||d>m)&&(u=p,d=m)}}return u||(u=i[i.length-1]),u.from<l&&(u={from:l,to:u.to,level:u.level}),u.to>c&&(u={from:u.from,to:c,level:u.level}),u}function rr(e){if(null!=e.cachedTextHeight)return e.cachedTextHeight;if(null==Nn){Nn=T("pre",null,"CodeMirror-line-like");for(var t=0;t<49;++t)Nn.appendChild(document.createTextNode("x")),Nn.appendChild(T("br"));Nn.appendChild(document.createTextNode("x"))}S(e.measure,Nn);var n=Nn.offsetHeight/50;return n>3&&(e.cachedTextHeight=n),L(e.measure),n||1}function ir(e){if(null!=e.cachedCharWidth)return e.cachedCharWidth;var t=T("span","xxxxxxxxxx"),n=T("pre",[t],"CodeMirror-line-like");S(e.measure,n);var r=t.getBoundingClientRect(),i=(r.right-r.left)/10;return i>2&&(e.cachedCharWidth=i),i||10}function or(e){for(var t=e.display,n={},r={},i=t.gutters.clientLeft,o=t.gutters.firstChild,a=0;o;o=o.nextSibling,++a){var s=e.display.gutterSpecs[a].className;n[s]=o.offsetLeft+o.clientLeft+i,r[s]=o.clientWidth}return{fixedPos:ar(t),gutterTotalWidth:t.gutters.offsetWidth,gutterLeft:n,gutterWidth:r,wrapperWidth:t.wrapper.clientWidth}}function ar(e){return e.scroller.getBoundingClientRect().left-e.sizer.getBoundingClientRect().left}function sr(e){var t=rr(e.display),n=e.options.lineWrapping,r=n&&Math.max(5,e.display.scroller.clientWidth/ir(e.display)-3);return function(i){if(Ft(e.doc,i))return 0;var o=0;if(i.widgets)for(var a=0;a<i.widgets.length;a++)i.widgets[a].height&&(o+=i.widgets[a].height);return n?o+(Math.ceil(i.text.length/r)||1)*t:o+t}}function lr(e){var t=e.doc,n=sr(e);t.iter((function(e){var t=n(e);t!=e.height&&Xe(e,t)}))}function cr(e,t,n,r){var i=e.display;if(!n&&"true"==Ae(t).getAttribute("cm-not-content"))return null;var o,a,s=i.lineSpace.getBoundingClientRect();try{o=t.clientX-s.left,a=t.clientY-s.top}catch(e){return null}var l,c=Jn(e,o,a);if(r&&c.xRel>0&&(l=Ge(e.doc,c.line).text).length==c.ch){var u=R(l,l.length,e.options.tabSize)-l.length;c=et(c.line,Math.max(0,Math.round((o-xn(e.display).left)/ir(e.display))-u))}return c}function ur(e,t){if(t>=e.display.viewTo)return null;if((t-=e.display.viewFrom)<0)return null;for(var n=e.display.view,r=0;r<n.length;r++)if((t-=n[r].size)<0)return r}function dr(e,t,n,r){null==t&&(t=e.doc.first),null==n&&(n=e.doc.first+e.doc.size),r||(r=0);var i=e.display;if(r&&n<i.viewTo&&(null==i.updateLineNumbers||i.updateLineNumbers>t)&&(i.updateLineNumbers=t),e.curOp.viewChanged=!0,t>=i.viewTo)wt&&Bt(e.doc,t)<i.viewTo&&pr(e);else if(n<=i.viewFrom)wt&&Ht(e.doc,n+r)>i.viewFrom?pr(e):(i.viewFrom+=r,i.viewTo+=r);else if(t<=i.viewFrom&&n>=i.viewTo)pr(e);else if(t<=i.viewFrom){var o=fr(e,n,n+r,1);o?(i.view=i.view.slice(o.index),i.viewFrom=o.lineN,i.viewTo+=r):pr(e)}else if(n>=i.viewTo){var a=fr(e,t,t,-1);a?(i.view=i.view.slice(0,a.index),i.viewTo=a.lineN):pr(e)}else{var s=fr(e,t,t,-1),l=fr(e,n,n+r,1);s&&l?(i.view=i.view.slice(0,s.index).concat(on(e,s.lineN,l.lineN)).concat(i.view.slice(l.index)),i.viewTo+=r):pr(e)}var c=i.externalMeasured;c&&(n<c.lineN?c.lineN+=r:t<c.lineN+c.size&&(i.externalMeasured=null))}function hr(e,t,n){e.curOp.viewChanged=!0;var r=e.display,i=e.display.externalMeasured;if(i&&t>=i.lineN&&t<i.lineN+i.size&&(r.externalMeasured=null),!(t<r.viewFrom||t>=r.viewTo)){var o=r.view[ur(e,t)];if(null!=o.node){var a=o.changes||(o.changes=[]);-1==H(a,n)&&a.push(n)}}}function pr(e){e.display.viewFrom=e.display.viewTo=e.doc.first,e.display.view=[],e.display.viewOffset=0}function fr(e,t,n,r){var i,o=ur(e,t),a=e.display.view;if(!wt||n==e.doc.first+e.doc.size)return{index:o,lineN:n};for(var s=e.display.viewFrom,l=0;l<o;l++)s+=a[l].size;if(s!=t){if(r>0){if(o==a.length-1)return null;i=s+a[o].size-t,o++}else i=s-t;t+=i,n+=i}for(;Bt(e.doc,n)!=n;){if(o==(r<0?0:a.length-1))return null;n+=r*a[o-(r<0?1:0)].size,o+=r}return{index:o,lineN:n}}function mr(e){for(var t=e.display.view,n=0,r=0;r<t.length;r++){var i=t[r];i.hidden||i.node&&!i.changes||++n}return n}function gr(e){e.display.input.showSelection(e.display.input.prepareSelection())}function vr(e,t){void 0===t&&(t=!0);for(var n=e.doc,r={},i=r.cursors=document.createDocumentFragment(),o=r.selection=document.createDocumentFragment(),a=0;a<n.sel.ranges.length;a++)if(t||a!=n.sel.primIndex){var s=n.sel.ranges[a];if(!(s.from().line>=e.display.viewTo||s.to().line<e.display.viewFrom)){var l=s.empty();(l||e.options.showCursorWhenSelecting)&&yr(e,s.head,i),l||br(e,s,o)}}return r}function yr(e,t,n){var r=qn(e,t,"div",null,null,!e.options.singleCursorHeightPerLine),i=n.appendChild(T("div"," ","CodeMirror-cursor"));if(i.style.left=r.left+"px",i.style.top=r.top+"px",i.style.height=Math.max(0,r.bottom-r.top)*e.options.cursorHeight+"px",r.other){var o=n.appendChild(T("div"," ","CodeMirror-cursor CodeMirror-secondarycursor"));o.style.display="",o.style.left=r.other.left+"px",o.style.top=r.other.top+"px",o.style.height=.85*(r.other.bottom-r.other.top)+"px"}}function _r(e,t){return e.top-t.top||e.left-t.left}function br(e,t,n){var r=e.display,i=e.doc,o=document.createDocumentFragment(),a=xn(e.display),s=a.left,l=Math.max(r.sizerWidth,Ln(e)-r.sizer.offsetLeft)-a.right,c="ltr"==i.direction;function u(e,t,n,r){t<0&&(t=0),t=Math.round(t),r=Math.round(r),o.appendChild(T("div",null,"CodeMirror-selected","position: absolute; left: "+e+"px;\n                             top: "+t+"px; width: "+(null==n?l-e:n)+"px;\n                             height: "+(r-t)+"px"))}function d(t,n,r){var o,a,d=Ge(i,t),h=d.text.length;function p(n,r){return Gn(e,et(t,n),"div",d,r)}function f(t,n,r){var i=Zn(e,d,null,t),o="ltr"==n==("after"==r)?"left":"right";return p("after"==r?i.begin:i.end-(/\s/.test(d.text.charAt(i.end-1))?2:1),o)[o]}var m=ce(d,i.direction);return function(e,t,n,r){if(!e)return r(t,n,"ltr",0);for(var i=!1,o=0;o<e.length;++o){var a=e[o];(a.from<n&&a.to>t||t==n&&a.to==t)&&(r(Math.max(a.from,t),Math.min(a.to,n),1==a.level?"rtl":"ltr",o),i=!0)}i||r(t,n,"ltr")}(m,n||0,null==r?h:r,(function(e,t,i,d){var g="ltr"==i,v=p(e,g?"left":"right"),y=p(t-1,g?"right":"left"),_=null==n&&0==e,b=null==r&&t==h,M=0==d,w=!m||d==m.length-1;if(y.top-v.top<=3){var A=(c?b:_)&&w,C=(c?_:b)&&M?s:(g?v:y).left,x=A?l:(g?y:v).right;u(C,v.top,x-C,v.bottom)}else{var E,L,S,T;g?(E=c&&_&&M?s:v.left,L=c?l:f(e,i,"before"),S=c?s:f(t,i,"after"),T=c&&b&&w?l:y.right):(E=c?f(e,i,"before"):s,L=!c&&_&&M?l:v.right,S=!c&&b&&w?s:y.left,T=c?f(t,i,"after"):l),u(E,v.top,L-E,v.bottom),v.bottom<y.top&&u(s,v.bottom,null,y.top),u(S,y.top,T-S,y.bottom)}(!o||_r(v,o)<0)&&(o=v),_r(y,o)<0&&(o=y),(!a||_r(v,a)<0)&&(a=v),_r(y,a)<0&&(a=y)})),{start:o,end:a}}var h=t.from(),p=t.to();if(h.line==p.line)d(h.line,h.ch,p.ch);else{var f=Ge(i,h.line),m=Ge(i,p.line),g=Rt(f)==Rt(m),v=d(h.line,h.ch,g?f.text.length+1:null).end,y=d(p.line,g?0:null,p.ch).start;g&&(v.top<y.top-2?(u(v.right,v.top,null,v.bottom),u(s,y.top,y.left,y.bottom)):u(v.right,v.top,y.left-v.right,v.bottom)),v.bottom<y.top&&u(s,v.bottom,null,y.top)}n.appendChild(o)}function Mr(e){if(e.state.focused){var t=e.display;clearInterval(t.blinker);var n=!0;t.cursorDiv.style.visibility="",e.options.cursorBlinkRate>0?t.blinker=setInterval((function(){e.hasFocus()||xr(e),t.cursorDiv.style.visibility=(n=!n)?"":"hidden"}),e.options.cursorBlinkRate):e.options.cursorBlinkRate<0&&(t.cursorDiv.style.visibility="hidden")}}function wr(e){e.hasFocus()||(e.display.input.focus(),e.state.focused||Cr(e))}function Ar(e){e.state.delayingBlurEvent=!0,setTimeout((function(){e.state.delayingBlurEvent&&(e.state.delayingBlurEvent=!1,e.state.focused&&xr(e))}),100)}function Cr(e,t){e.state.delayingBlurEvent&&!e.state.draggingText&&(e.state.delayingBlurEvent=!1),"nocursor"!=e.options.readOnly&&(e.state.focused||(fe(e,"focus",e,t),e.state.focused=!0,D(e.display.wrapper,"CodeMirror-focused"),e.curOp||e.display.selForContextMenu==e.doc.sel||(e.display.input.reset(),l&&setTimeout((function(){return e.display.input.reset(!0)}),20)),e.display.input.receivedFocus()),Mr(e))}function xr(e,t){e.state.delayingBlurEvent||(e.state.focused&&(fe(e,"blur",e,t),e.state.focused=!1,E(e.display.wrapper,"CodeMirror-focused")),clearInterval(e.display.blinker),setTimeout((function(){e.state.focused||(e.display.shift=!1)}),150))}function Er(e){for(var t=e.display,n=t.lineDiv.offsetTop,r=0;r<t.view.length;r++){var i=t.view[r],o=e.options.lineWrapping,l=void 0,c=0;if(!i.hidden){if(a&&s<8){var u=i.node.offsetTop+i.node.offsetHeight;l=u-n,n=u}else{var d=i.node.getBoundingClientRect();l=d.bottom-d.top,!o&&i.text.firstChild&&(c=i.text.firstChild.getBoundingClientRect().right-d.left-1)}var h=i.line.height-l;if((h>.005||h<-.005)&&(Xe(i.line,l),Lr(i.line),i.rest))for(var p=0;p<i.rest.length;p++)Lr(i.rest[p]);if(c>e.display.sizerWidth){var f=Math.ceil(c/ir(e.display));f>e.display.maxLineLength&&(e.display.maxLineLength=f,e.display.maxLine=i.line,e.display.maxLineChanged=!0)}}}}function Lr(e){if(e.widgets)for(var t=0;t<e.widgets.length;++t){var n=e.widgets[t],r=n.node.parentNode;r&&(n.height=r.offsetHeight)}}function Sr(e,t,n){var r=n&&null!=n.top?Math.max(0,n.top):e.scroller.scrollTop;r=Math.floor(r-An(e));var i=n&&null!=n.bottom?n.bottom:r+e.wrapper.clientHeight,o=Qe(t,r),a=Qe(t,i);if(n&&n.ensure){var s=n.ensure.from.line,l=n.ensure.to.line;s<o?(o=s,a=Qe(t,Vt(Ge(t,s))+e.wrapper.clientHeight)):Math.min(l,t.lastLine())>=a&&(o=Qe(t,Vt(Ge(t,l))-e.wrapper.clientHeight),a=l)}return{from:o,to:Math.max(a,o+1)}}function Tr(e,t){var n=e.display,r=rr(e.display);t.top<0&&(t.top=0);var i=e.curOp&&null!=e.curOp.scrollTop?e.curOp.scrollTop:n.scroller.scrollTop,o=Sn(e),a={};t.bottom-t.top>o&&(t.bottom=t.top+o);var s=e.doc.height+Cn(n),l=t.top<r,c=t.bottom>s-r;if(t.top<i)a.scrollTop=l?0:t.top;else if(t.bottom>i+o){var u=Math.min(t.top,(c?s:t.bottom)-o);u!=i&&(a.scrollTop=u)}var d=e.options.fixedGutter?0:n.gutters.offsetWidth,h=e.curOp&&null!=e.curOp.scrollLeft?e.curOp.scrollLeft:n.scroller.scrollLeft-d,p=Ln(e)-n.gutters.offsetWidth,f=t.right-t.left>p;return f&&(t.right=t.left+p),t.left<10?a.scrollLeft=0:t.left<h?a.scrollLeft=Math.max(0,t.left+d-(f?0:10)):t.right>p+h-3&&(a.scrollLeft=t.right+(f?0:10)-p),a}function Or(e,t){null!=t&&(Dr(e),e.curOp.scrollTop=(null==e.curOp.scrollTop?e.doc.scrollTop:e.curOp.scrollTop)+t)}function Ir(e){Dr(e);var t=e.getCursor();e.curOp.scrollToPos={from:t,to:t,margin:e.options.cursorScrollMargin}}function kr(e,t,n){null==t&&null==n||Dr(e),null!=t&&(e.curOp.scrollLeft=t),null!=n&&(e.curOp.scrollTop=n)}function Dr(e){var t=e.curOp.scrollToPos;t&&(e.curOp.scrollToPos=null,Nr(e,Kn(e,t.from),Kn(e,t.to),t.margin))}function Nr(e,t,n,r){var i=Tr(e,{left:Math.min(t.left,n.left),top:Math.min(t.top,n.top)-r,right:Math.max(t.right,n.right),bottom:Math.max(t.bottom,n.bottom)+r});kr(e,i.scrollLeft,i.scrollTop)}function jr(e,t){Math.abs(e.doc.scrollTop-t)<2||(n||li(e,{top:t}),Pr(e,t,!0),n&&li(e),ri(e,100))}function Pr(e,t,n){t=Math.max(0,Math.min(e.display.scroller.scrollHeight-e.display.scroller.clientHeight,t)),(e.display.scroller.scrollTop!=t||n)&&(e.doc.scrollTop=t,e.display.scrollbars.setScrollTop(t),e.display.scroller.scrollTop!=t&&(e.display.scroller.scrollTop=t))}function zr(e,t,n,r){t=Math.max(0,Math.min(t,e.display.scroller.scrollWidth-e.display.scroller.clientWidth)),(n?t==e.doc.scrollLeft:Math.abs(e.doc.scrollLeft-t)<2)&&!r||(e.doc.scrollLeft=t,di(e),e.display.scroller.scrollLeft!=t&&(e.display.scroller.scrollLeft=t),e.display.scrollbars.setScrollLeft(t))}function Rr(e){var t=e.display,n=t.gutters.offsetWidth,r=Math.round(e.doc.height+Cn(e.display));return{clientHeight:t.scroller.clientHeight,viewHeight:t.wrapper.clientHeight,scrollWidth:t.scroller.scrollWidth,clientWidth:t.scroller.clientWidth,viewWidth:t.wrapper.clientWidth,barLeft:e.options.fixedGutter?n:0,docHeight:r,scrollHeight:r+En(e)+t.barHeight,nativeBarWidth:t.nativeBarWidth,gutterWidth:n}}var Br=function(e,t,n){this.cm=n;var r=this.vert=T("div",[T("div",null,null,"min-width: 1px")],"CodeMirror-vscrollbar"),i=this.horiz=T("div",[T("div",null,null,"height: 100%; min-height: 1px")],"CodeMirror-hscrollbar");r.tabIndex=i.tabIndex=-1,e(r),e(i),de(r,"scroll",(function(){r.clientHeight&&t(r.scrollTop,"vertical")})),de(i,"scroll",(function(){i.clientWidth&&t(i.scrollLeft,"horizontal")})),this.checkedZeroWidth=!1,a&&s<8&&(this.horiz.style.minHeight=this.vert.style.minWidth="18px")};Br.prototype.update=function(e){var t=e.scrollWidth>e.clientWidth+1,n=e.scrollHeight>e.clientHeight+1,r=e.nativeBarWidth;if(n){this.vert.style.display="block",this.vert.style.bottom=t?r+"px":"0";var i=e.viewHeight-(t?r:0);this.vert.firstChild.style.height=Math.max(0,e.scrollHeight-e.clientHeight+i)+"px"}else this.vert.style.display="",this.vert.firstChild.style.height="0";if(t){this.horiz.style.display="block",this.horiz.style.right=n?r+"px":"0",this.horiz.style.left=e.barLeft+"px";var o=e.viewWidth-e.barLeft-(n?r:0);this.horiz.firstChild.style.width=Math.max(0,e.scrollWidth-e.clientWidth+o)+"px"}else this.horiz.style.display="",this.horiz.firstChild.style.width="0";return!this.checkedZeroWidth&&e.clientHeight>0&&(0==r&&this.zeroWidthHack(),this.checkedZeroWidth=!0),{right:n?r:0,bottom:t?r:0}},Br.prototype.setScrollLeft=function(e){this.horiz.scrollLeft!=e&&(this.horiz.scrollLeft=e),this.disableHoriz&&this.enableZeroWidthBar(this.horiz,this.disableHoriz,"horiz")},Br.prototype.setScrollTop=function(e){this.vert.scrollTop!=e&&(this.vert.scrollTop=e),this.disableVert&&this.enableZeroWidthBar(this.vert,this.disableVert,"vert")},Br.prototype.zeroWidthHack=function(){var e=y&&!p?"12px":"18px";this.horiz.style.height=this.vert.style.width=e,this.horiz.style.pointerEvents=this.vert.style.pointerEvents="none",this.disableHoriz=new B,this.disableVert=new B},Br.prototype.enableZeroWidthBar=function(e,t,n){e.style.pointerEvents="auto",t.set(1e3,(function r(){var i=e.getBoundingClientRect();("vert"==n?document.elementFromPoint(i.right-1,(i.top+i.bottom)/2):document.elementFromPoint((i.right+i.left)/2,i.bottom-1))!=e?e.style.pointerEvents="none":t.set(1e3,r)}))},Br.prototype.clear=function(){var e=this.horiz.parentNode;e.removeChild(this.horiz),e.removeChild(this.vert)};var Hr=function(){};function Fr(e,t){t||(t=Rr(e));var n=e.display.barWidth,r=e.display.barHeight;Yr(e,t);for(var i=0;i<4&&n!=e.display.barWidth||r!=e.display.barHeight;i++)n!=e.display.barWidth&&e.options.lineWrapping&&Er(e),Yr(e,Rr(e)),n=e.display.barWidth,r=e.display.barHeight}function Yr(e,t){var n=e.display,r=n.scrollbars.update(t);n.sizer.style.paddingRight=(n.barWidth=r.right)+"px",n.sizer.style.paddingBottom=(n.barHeight=r.bottom)+"px",n.heightForcer.style.borderBottom=r.bottom+"px solid transparent",r.right&&r.bottom?(n.scrollbarFiller.style.display="block",n.scrollbarFiller.style.height=r.bottom+"px",n.scrollbarFiller.style.width=r.right+"px"):n.scrollbarFiller.style.display="",r.bottom&&e.options.coverGutterNextToScrollbar&&e.options.fixedGutter?(n.gutterFiller.style.display="block",n.gutterFiller.style.height=r.bottom+"px",n.gutterFiller.style.width=t.gutterWidth+"px"):n.gutterFiller.style.display=""}Hr.prototype.update=function(){return{bottom:0,right:0}},Hr.prototype.setScrollLeft=function(){},Hr.prototype.setScrollTop=function(){},Hr.prototype.clear=function(){};var Vr={native:Br,null:Hr};function Ur(e){e.display.scrollbars&&(e.display.scrollbars.clear(),e.display.scrollbars.addClass&&E(e.display.wrapper,e.display.scrollbars.addClass)),e.display.scrollbars=new Vr[e.options.scrollbarStyle]((function(t){e.display.wrapper.insertBefore(t,e.display.scrollbarFiller),de(t,"mousedown",(function(){e.state.focused&&setTimeout((function(){return e.display.input.focus()}),0)})),t.setAttribute("cm-not-content","true")}),(function(t,n){"horizontal"==n?zr(e,t):jr(e,t)}),e),e.display.scrollbars.addClass&&D(e.display.wrapper,e.display.scrollbars.addClass)}var Wr=0;function Gr(e){var t;e.curOp={cm:e,viewChanged:!1,startHeight:e.doc.height,forceUpdate:!1,updateInput:0,typing:!1,changeObjs:null,cursorActivityHandlers:null,cursorActivityCalled:0,selectionChanged:!1,updateMaxLine:!1,scrollLeft:null,scrollTop:null,scrollToPos:null,focus:!1,id:++Wr,markArrays:null},t=e.curOp,an?an.ops.push(t):t.ownsGroup=an={ops:[t],delayedCallbacks:[]}}function qr(e){var t=e.curOp;t&&function(e,t){var n=e.ownsGroup;if(n)try{!function(e){var t=e.delayedCallbacks,n=0;do{for(;n<t.length;n++)t[n].call(null);for(var r=0;r<e.ops.length;r++){var i=e.ops[r];if(i.cursorActivityHandlers)for(;i.cursorActivityCalled<i.cursorActivityHandlers.length;)i.cursorActivityHandlers[i.cursorActivityCalled++].call(null,i.cm)}}while(n<t.length)}(n)}finally{an=null,t(n)}}(t,(function(e){for(var t=0;t<e.ops.length;t++)e.ops[t].cm.curOp=null;!function(e){for(var t=e.ops,n=0;n<t.length;n++)Kr(t[n]);for(var r=0;r<t.length;r++)Xr(t[r]);for(var i=0;i<t.length;i++)Jr(t[i]);for(var o=0;o<t.length;o++)Qr(t[o]);for(var a=0;a<t.length;a++)Zr(t[a])}(e)}))}function Kr(e){var t=e.cm,n=t.display;!function(e){var t=e.display;!t.scrollbarsClipped&&t.scroller.offsetWidth&&(t.nativeBarWidth=t.scroller.offsetWidth-t.scroller.clientWidth,t.heightForcer.style.height=En(e)+"px",t.sizer.style.marginBottom=-t.nativeBarWidth+"px",t.sizer.style.borderRightWidth=En(e)+"px",t.scrollbarsClipped=!0)}(t),e.updateMaxLine&&Wt(t),e.mustUpdate=e.viewChanged||e.forceUpdate||null!=e.scrollTop||e.scrollToPos&&(e.scrollToPos.from.line<n.viewFrom||e.scrollToPos.to.line>=n.viewTo)||n.maxLineChanged&&t.options.lineWrapping,e.update=e.mustUpdate&&new oi(t,e.mustUpdate&&{top:e.scrollTop,ensure:e.scrollToPos},e.forceUpdate)}function Xr(e){e.updatedDisplay=e.mustUpdate&&ai(e.cm,e.update)}function Jr(e){var t=e.cm,n=t.display;e.updatedDisplay&&Er(t),e.barMeasure=Rr(t),n.maxLineChanged&&!t.options.lineWrapping&&(e.adjustWidthTo=On(t,n.maxLine,n.maxLine.text.length).left+3,t.display.sizerWidth=e.adjustWidthTo,e.barMeasure.scrollWidth=Math.max(n.scroller.clientWidth,n.sizer.offsetLeft+e.adjustWidthTo+En(t)+t.display.barWidth),e.maxScrollLeft=Math.max(0,n.sizer.offsetLeft+e.adjustWidthTo-Ln(t))),(e.updatedDisplay||e.selectionChanged)&&(e.preparedSelection=n.input.prepareSelection())}function Qr(e){var t=e.cm;null!=e.adjustWidthTo&&(t.display.sizer.style.minWidth=e.adjustWidthTo+"px",e.maxScrollLeft<t.doc.scrollLeft&&zr(t,Math.min(t.display.scroller.scrollLeft,e.maxScrollLeft),!0),t.display.maxLineChanged=!1);var n=e.focus&&e.focus==k();e.preparedSelection&&t.display.input.showSelection(e.preparedSelection,n),(e.updatedDisplay||e.startHeight!=t.doc.height)&&Fr(t,e.barMeasure),e.updatedDisplay&&ui(t,e.barMeasure),e.selectionChanged&&Mr(t),t.state.focused&&e.updateInput&&t.display.input.reset(e.typing),n&&wr(e.cm)}function Zr(e){var t=e.cm,n=t.display,r=t.doc;e.updatedDisplay&&si(t,e.update),null==n.wheelStartX||null==e.scrollTop&&null==e.scrollLeft&&!e.scrollToPos||(n.wheelStartX=n.wheelStartY=null),null!=e.scrollTop&&Pr(t,e.scrollTop,e.forceScroll),null!=e.scrollLeft&&zr(t,e.scrollLeft,!0,!0),e.scrollToPos&&function(e,t){if(!me(e,"scrollCursorIntoView")){var n=e.display,r=n.sizer.getBoundingClientRect(),i=null;if(t.top+r.top<0?i=!0:t.bottom+r.top>(window.innerHeight||document.documentElement.clientHeight)&&(i=!1),null!=i&&!f){var o=T("div","​",null,"position: absolute;\n                         top: "+(t.top-n.viewOffset-An(e.display))+"px;\n                         height: "+(t.bottom-t.top+En(e)+n.barHeight)+"px;\n                         left: "+t.left+"px; width: "+Math.max(2,t.right-t.left)+"px;");e.display.lineSpace.appendChild(o),o.scrollIntoView(i),e.display.lineSpace.removeChild(o)}}}(t,function(e,t,n,r){var i;null==r&&(r=0),e.options.lineWrapping||t!=n||(n="before"==t.sticky?et(t.line,t.ch+1,"before"):t,t=t.ch?et(t.line,"before"==t.sticky?t.ch-1:t.ch,"after"):t);for(var o=0;o<5;o++){var a=!1,s=qn(e,t),l=n&&n!=t?qn(e,n):s,c=Tr(e,i={left:Math.min(s.left,l.left),top:Math.min(s.top,l.top)-r,right:Math.max(s.left,l.left),bottom:Math.max(s.bottom,l.bottom)+r}),u=e.doc.scrollTop,d=e.doc.scrollLeft;if(null!=c.scrollTop&&(jr(e,c.scrollTop),Math.abs(e.doc.scrollTop-u)>1&&(a=!0)),null!=c.scrollLeft&&(zr(e,c.scrollLeft),Math.abs(e.doc.scrollLeft-d)>1&&(a=!0)),!a)break}return i}(t,st(r,e.scrollToPos.from),st(r,e.scrollToPos.to),e.scrollToPos.margin));var i=e.maybeHiddenMarkers,o=e.maybeUnhiddenMarkers;if(i)for(var a=0;a<i.length;++a)i[a].lines.length||fe(i[a],"hide");if(o)for(var s=0;s<o.length;++s)o[s].lines.length&&fe(o[s],"unhide");n.wrapper.offsetHeight&&(r.scrollTop=t.display.scroller.scrollTop),e.changeObjs&&fe(t,"changes",t,e.changeObjs),e.update&&e.update.finish()}function $r(e,t){if(e.curOp)return t();Gr(e);try{return t()}finally{qr(e)}}function ei(e,t){return function(){if(e.curOp)return t.apply(e,arguments);Gr(e);try{return t.apply(e,arguments)}finally{qr(e)}}}function ti(e){return function(){if(this.curOp)return e.apply(this,arguments);Gr(this);try{return e.apply(this,arguments)}finally{qr(this)}}}function ni(e){return function(){var t=this.cm;if(!t||t.curOp)return e.apply(this,arguments);Gr(t);try{return e.apply(this,arguments)}finally{qr(t)}}}function ri(e,t){e.doc.highlightFrontier<e.display.viewTo&&e.state.highlight.set(t,P(ii,e))}function ii(e){var t=e.doc;if(!(t.highlightFrontier>=e.display.viewTo)){var n=+new Date+e.options.workTime,r=pt(e,t.highlightFrontier),i=[];t.iter(r.line,Math.min(t.first+t.size,e.display.viewTo+500),(function(o){if(r.line>=e.display.viewFrom){var a=o.styles,s=o.text.length>e.options.maxHighlightLength?Ye(t.mode,r.state):null,l=dt(e,o,r,!0);s&&(r.state=s),o.styles=l.styles;var c=o.styleClasses,u=l.classes;u?o.styleClasses=u:c&&(o.styleClasses=null);for(var d=!a||a.length!=o.styles.length||c!=u&&(!c||!u||c.bgClass!=u.bgClass||c.textClass!=u.textClass),h=0;!d&&h<a.length;++h)d=a[h]!=o.styles[h];d&&i.push(r.line),o.stateAfter=r.save(),r.nextLine()}else o.text.length<=e.options.maxHighlightLength&&ft(e,o.text,r),o.stateAfter=r.line%5==0?r.save():null,r.nextLine();if(+new Date>n)return ri(e,e.options.workDelay),!0})),t.highlightFrontier=r.line,t.modeFrontier=Math.max(t.modeFrontier,r.line),i.length&&$r(e,(function(){for(var t=0;t<i.length;t++)hr(e,i[t],"text")}))}}var oi=function(e,t,n){var r=e.display;this.viewport=t,this.visible=Sr(r,e.doc,t),this.editorIsHidden=!r.wrapper.offsetWidth,this.wrapperHeight=r.wrapper.clientHeight,this.wrapperWidth=r.wrapper.clientWidth,this.oldDisplayWidth=Ln(e),this.force=n,this.dims=or(e),this.events=[]};function ai(e,t){var n=e.display,r=e.doc;if(t.editorIsHidden)return pr(e),!1;if(!t.force&&t.visible.from>=n.viewFrom&&t.visible.to<=n.viewTo&&(null==n.updateLineNumbers||n.updateLineNumbers>=n.viewTo)&&n.renderedView==n.view&&0==mr(e))return!1;hi(e)&&(pr(e),t.dims=or(e));var i=r.first+r.size,o=Math.max(t.visible.from-e.options.viewportMargin,r.first),a=Math.min(i,t.visible.to+e.options.viewportMargin);n.viewFrom<o&&o-n.viewFrom<20&&(o=Math.max(r.first,n.viewFrom)),n.viewTo>a&&n.viewTo-a<20&&(a=Math.min(i,n.viewTo)),wt&&(o=Bt(e.doc,o),a=Ht(e.doc,a));var s=o!=n.viewFrom||a!=n.viewTo||n.lastWrapHeight!=t.wrapperHeight||n.lastWrapWidth!=t.wrapperWidth;!function(e,t,n){var r=e.display;0==r.view.length||t>=r.viewTo||n<=r.viewFrom?(r.view=on(e,t,n),r.viewFrom=t):(r.viewFrom>t?r.view=on(e,t,r.viewFrom).concat(r.view):r.viewFrom<t&&(r.view=r.view.slice(ur(e,t))),r.viewFrom=t,r.viewTo<n?r.view=r.view.concat(on(e,r.viewTo,n)):r.viewTo>n&&(r.view=r.view.slice(0,ur(e,n)))),r.viewTo=n}(e,o,a),n.viewOffset=Vt(Ge(e.doc,n.viewFrom)),e.display.mover.style.top=n.viewOffset+"px";var c=mr(e);if(!s&&0==c&&!t.force&&n.renderedView==n.view&&(null==n.updateLineNumbers||n.updateLineNumbers>=n.viewTo))return!1;var u=function(e){if(e.hasFocus())return null;var t=k();if(!t||!I(e.display.lineDiv,t))return null;var n={activeElt:t};if(window.getSelection){var r=window.getSelection();r.anchorNode&&r.extend&&I(e.display.lineDiv,r.anchorNode)&&(n.anchorNode=r.anchorNode,n.anchorOffset=r.anchorOffset,n.focusNode=r.focusNode,n.focusOffset=r.focusOffset)}return n}(e);return c>4&&(n.lineDiv.style.display="none"),function(e,t,n){var r=e.display,i=e.options.lineNumbers,o=r.lineDiv,a=o.firstChild;function s(t){var n=t.nextSibling;return l&&y&&e.display.currentWheelTarget==t?t.style.display="none":t.parentNode.removeChild(t),n}for(var c=r.view,u=r.viewFrom,d=0;d<c.length;d++){var h=c[d];if(h.hidden);else if(h.node&&h.node.parentNode==o){for(;a!=h.node;)a=s(a);var p=i&&null!=t&&t<=u&&h.lineNumber;h.changes&&(H(h.changes,"gutter")>-1&&(p=!1),un(e,h,u,n)),p&&(L(h.lineNumber),h.lineNumber.appendChild(document.createTextNode($e(e.options,u)))),a=h.node.nextSibling}else{var f=vn(e,h,u,n);o.insertBefore(f,a)}u+=h.size}for(;a;)a=s(a)}(e,n.updateLineNumbers,t.dims),c>4&&(n.lineDiv.style.display=""),n.renderedView=n.view,function(e){if(e&&e.activeElt&&e.activeElt!=k()&&(e.activeElt.focus(),!/^(INPUT|TEXTAREA)$/.test(e.activeElt.nodeName)&&e.anchorNode&&I(document.body,e.anchorNode)&&I(document.body,e.focusNode))){var t=window.getSelection(),n=document.createRange();n.setEnd(e.anchorNode,e.anchorOffset),n.collapse(!1),t.removeAllRanges(),t.addRange(n),t.extend(e.focusNode,e.focusOffset)}}(u),L(n.cursorDiv),L(n.selectionDiv),n.gutters.style.height=n.sizer.style.minHeight=0,s&&(n.lastWrapHeight=t.wrapperHeight,n.lastWrapWidth=t.wrapperWidth,ri(e,400)),n.updateLineNumbers=null,!0}function si(e,t){for(var n=t.viewport,r=!0;;r=!1){if(r&&e.options.lineWrapping&&t.oldDisplayWidth!=Ln(e))r&&(t.visible=Sr(e.display,e.doc,n));else if(n&&null!=n.top&&(n={top:Math.min(e.doc.height+Cn(e.display)-Sn(e),n.top)}),t.visible=Sr(e.display,e.doc,n),t.visible.from>=e.display.viewFrom&&t.visible.to<=e.display.viewTo)break;if(!ai(e,t))break;Er(e);var i=Rr(e);gr(e),Fr(e,i),ui(e,i),t.force=!1}t.signal(e,"update",e),e.display.viewFrom==e.display.reportedViewFrom&&e.display.viewTo==e.display.reportedViewTo||(t.signal(e,"viewportChange",e,e.display.viewFrom,e.display.viewTo),e.display.reportedViewFrom=e.display.viewFrom,e.display.reportedViewTo=e.display.viewTo)}function li(e,t){var n=new oi(e,t);if(ai(e,n)){Er(e),si(e,n);var r=Rr(e);gr(e),Fr(e,r),ui(e,r),n.finish()}}function ci(e){var t=e.gutters.offsetWidth;e.sizer.style.marginLeft=t+"px",ln(e,"gutterChanged",e)}function ui(e,t){e.display.sizer.style.minHeight=t.docHeight+"px",e.display.heightForcer.style.top=t.docHeight+"px",e.display.gutters.style.height=t.docHeight+e.display.barHeight+En(e)+"px"}function di(e){var t=e.display,n=t.view;if(t.alignWidgets||t.gutters.firstChild&&e.options.fixedGutter){for(var r=ar(t)-t.scroller.scrollLeft+e.doc.scrollLeft,i=t.gutters.offsetWidth,o=r+"px",a=0;a<n.length;a++)if(!n[a].hidden){e.options.fixedGutter&&(n[a].gutter&&(n[a].gutter.style.left=o),n[a].gutterBackground&&(n[a].gutterBackground.style.left=o));var s=n[a].alignable;if(s)for(var l=0;l<s.length;l++)s[l].style.left=o}e.options.fixedGutter&&(t.gutters.style.left=r+i+"px")}}function hi(e){if(!e.options.lineNumbers)return!1;var t=e.doc,n=$e(e.options,t.first+t.size-1),r=e.display;if(n.length!=r.lineNumChars){var i=r.measure.appendChild(T("div",[T("div",n)],"CodeMirror-linenumber CodeMirror-gutter-elt")),o=i.firstChild.offsetWidth,a=i.offsetWidth-o;return r.lineGutter.style.width="",r.lineNumInnerWidth=Math.max(o,r.lineGutter.offsetWidth-a)+1,r.lineNumWidth=r.lineNumInnerWidth+a,r.lineNumChars=r.lineNumInnerWidth?n.length:-1,r.lineGutter.style.width=r.lineNumWidth+"px",ci(e.display),!0}return!1}function pi(e,t){for(var n=[],r=!1,i=0;i<e.length;i++){var o=e[i],a=null;if("string"!=typeof o&&(a=o.style,o=o.className),"CodeMirror-linenumbers"==o){if(!t)continue;r=!0}n.push({className:o,style:a})}return t&&!r&&n.push({className:"CodeMirror-linenumbers",style:null}),n}function fi(e){var t=e.gutters,n=e.gutterSpecs;L(t),e.lineGutter=null;for(var r=0;r<n.length;++r){var i=n[r],o=i.className,a=i.style,s=t.appendChild(T("div",null,"CodeMirror-gutter "+o));a&&(s.style.cssText=a),"CodeMirror-linenumbers"==o&&(e.lineGutter=s,s.style.width=(e.lineNumWidth||1)+"px")}t.style.display=n.length?"":"none",ci(e)}function mi(e){fi(e.display),dr(e),di(e)}function gi(e,t,r,i){var o=this;this.input=r,o.scrollbarFiller=T("div",null,"CodeMirror-scrollbar-filler"),o.scrollbarFiller.setAttribute("cm-not-content","true"),o.gutterFiller=T("div",null,"CodeMirror-gutter-filler"),o.gutterFiller.setAttribute("cm-not-content","true"),o.lineDiv=O("div",null,"CodeMirror-code"),o.selectionDiv=T("div",null,null,"position: relative; z-index: 1"),o.cursorDiv=T("div",null,"CodeMirror-cursors"),o.measure=T("div",null,"CodeMirror-measure"),o.lineMeasure=T("div",null,"CodeMirror-measure"),o.lineSpace=O("div",[o.measure,o.lineMeasure,o.selectionDiv,o.cursorDiv,o.lineDiv],null,"position: relative; outline: none");var c=O("div",[o.lineSpace],"CodeMirror-lines");o.mover=T("div",[c],null,"position: relative"),o.sizer=T("div",[o.mover],"CodeMirror-sizer"),o.sizerWidth=null,o.heightForcer=T("div",null,null,"position: absolute; height: 50px; width: 1px;"),o.gutters=T("div",null,"CodeMirror-gutters"),o.lineGutter=null,o.scroller=T("div",[o.sizer,o.heightForcer,o.gutters],"CodeMirror-scroll"),o.scroller.setAttribute("tabIndex","-1"),o.wrapper=T("div",[o.scrollbarFiller,o.gutterFiller,o.scroller],"CodeMirror"),a&&s<8&&(o.gutters.style.zIndex=-1,o.scroller.style.paddingRight=0),l||n&&v||(o.scroller.draggable=!0),e&&(e.appendChild?e.appendChild(o.wrapper):e(o.wrapper)),o.viewFrom=o.viewTo=t.first,o.reportedViewFrom=o.reportedViewTo=t.first,o.view=[],o.renderedView=null,o.externalMeasured=null,o.viewOffset=0,o.lastWrapHeight=o.lastWrapWidth=0,o.updateLineNumbers=null,o.nativeBarWidth=o.barHeight=o.barWidth=0,o.scrollbarsClipped=!1,o.lineNumWidth=o.lineNumInnerWidth=o.lineNumChars=null,o.alignWidgets=!1,o.cachedCharWidth=o.cachedTextHeight=o.cachedPaddingH=null,o.maxLine=null,o.maxLineLength=0,o.maxLineChanged=!1,o.wheelDX=o.wheelDY=o.wheelStartX=o.wheelStartY=null,o.shift=!1,o.selForContextMenu=null,o.activeTouch=null,o.gutterSpecs=pi(i.gutters,i.lineNumbers),fi(o),r.init(o)}oi.prototype.signal=function(e,t){ve(e,t)&&this.events.push(arguments)},oi.prototype.finish=function(){for(var e=0;e<this.events.length;e++)fe.apply(null,this.events[e])};var vi=0,yi=null;function _i(e){var t=e.wheelDeltaX,n=e.wheelDeltaY;return null==t&&e.detail&&e.axis==e.HORIZONTAL_AXIS&&(t=e.detail),null==n&&e.detail&&e.axis==e.VERTICAL_AXIS?n=e.detail:null==n&&(n=e.wheelDelta),{x:t,y:n}}function bi(e){var t=_i(e);return t.x*=yi,t.y*=yi,t}function Mi(e,t){var r=_i(t),i=r.x,o=r.y,a=e.display,s=a.scroller,c=s.scrollWidth>s.clientWidth,u=s.scrollHeight>s.clientHeight;if(i&&c||o&&u){if(o&&y&&l)e:for(var h=t.target,p=a.view;h!=s;h=h.parentNode)for(var f=0;f<p.length;f++)if(p[f].node==h){e.display.currentWheelTarget=h;break e}if(i&&!n&&!d&&null!=yi)return o&&u&&jr(e,Math.max(0,s.scrollTop+o*yi)),zr(e,Math.max(0,s.scrollLeft+i*yi)),(!o||o&&u)&&_e(t),void(a.wheelStartX=null);if(o&&null!=yi){var m=o*yi,g=e.doc.scrollTop,v=g+a.wrapper.clientHeight;m<0?g=Math.max(0,g+m-50):v=Math.min(e.doc.height,v+m+50),li(e,{top:g,bottom:v})}vi<20&&(null==a.wheelStartX?(a.wheelStartX=s.scrollLeft,a.wheelStartY=s.scrollTop,a.wheelDX=i,a.wheelDY=o,setTimeout((function(){if(null!=a.wheelStartX){var e=s.scrollLeft-a.wheelStartX,t=s.scrollTop-a.wheelStartY,n=t&&a.wheelDY&&t/a.wheelDY||e&&a.wheelDX&&e/a.wheelDX;a.wheelStartX=a.wheelStartY=null,n&&(yi=(yi*vi+n)/(vi+1),++vi)}}),200)):(a.wheelDX+=i,a.wheelDY+=o))}}a?yi=-.53:n?yi=15:u?yi=-.7:h&&(yi=-1/3);var wi=function(e,t){this.ranges=e,this.primIndex=t};wi.prototype.primary=function(){return this.ranges[this.primIndex]},wi.prototype.equals=function(e){if(e==this)return!0;if(e.primIndex!=this.primIndex||e.ranges.length!=this.ranges.length)return!1;for(var t=0;t<this.ranges.length;t++){var n=this.ranges[t],r=e.ranges[t];if(!nt(n.anchor,r.anchor)||!nt(n.head,r.head))return!1}return!0},wi.prototype.deepCopy=function(){for(var e=[],t=0;t<this.ranges.length;t++)e[t]=new Ai(rt(this.ranges[t].anchor),rt(this.ranges[t].head));return new wi(e,this.primIndex)},wi.prototype.somethingSelected=function(){for(var e=0;e<this.ranges.length;e++)if(!this.ranges[e].empty())return!0;return!1},wi.prototype.contains=function(e,t){t||(t=e);for(var n=0;n<this.ranges.length;n++){var r=this.ranges[n];if(tt(t,r.from())>=0&&tt(e,r.to())<=0)return n}return-1};var Ai=function(e,t){this.anchor=e,this.head=t};function Ci(e,t,n){var r=e&&e.options.selectionsMayTouch,i=t[n];t.sort((function(e,t){return tt(e.from(),t.from())})),n=H(t,i);for(var o=1;o<t.length;o++){var a=t[o],s=t[o-1],l=tt(s.to(),a.from());if(r&&!a.empty()?l>0:l>=0){var c=ot(s.from(),a.from()),u=it(s.to(),a.to()),d=s.empty()?a.from()==a.head:s.from()==s.head;o<=n&&--n,t.splice(--o,2,new Ai(d?u:c,d?c:u))}}return new wi(t,n)}function xi(e,t){return new wi([new Ai(e,t||e)],0)}function Ei(e){return e.text?et(e.from.line+e.text.length-1,K(e.text).length+(1==e.text.length?e.from.ch:0)):e.to}function Li(e,t){if(tt(e,t.from)<0)return e;if(tt(e,t.to)<=0)return Ei(t);var n=e.line+t.text.length-(t.to.line-t.from.line)-1,r=e.ch;return e.line==t.to.line&&(r+=Ei(t).ch-t.to.ch),et(n,r)}function Si(e,t){for(var n=[],r=0;r<e.sel.ranges.length;r++){var i=e.sel.ranges[r];n.push(new Ai(Li(i.anchor,t),Li(i.head,t)))}return Ci(e.cm,n,e.sel.primIndex)}function Ti(e,t,n){return e.line==t.line?et(n.line,e.ch-t.ch+n.ch):et(n.line+(e.line-t.line),e.ch)}function Oi(e){e.doc.mode=Be(e.options,e.doc.modeOption),Ii(e)}function Ii(e){e.doc.iter((function(e){e.stateAfter&&(e.stateAfter=null),e.styles&&(e.styles=null)})),e.doc.modeFrontier=e.doc.highlightFrontier=e.doc.first,ri(e,100),e.state.modeGen++,e.curOp&&dr(e)}function ki(e,t){return 0==t.from.ch&&0==t.to.ch&&""==K(t.text)&&(!e.cm||e.cm.options.wholeLineUpdateBefore)}function Di(e,t,n,r){function i(e){return n?n[e]:null}function o(e,n,i){!function(e,t,n,r){e.text=t,e.stateAfter&&(e.stateAfter=null),e.styles&&(e.styles=null),null!=e.order&&(e.order=null),St(e),Tt(e,n);var i=r?r(e):1;i!=e.height&&Xe(e,i)}(e,n,i,r),ln(e,"change",e,t)}function a(e,t){for(var n=[],o=e;o<t;++o)n.push(new Gt(c[o],i(o),r));return n}var s=t.from,l=t.to,c=t.text,u=Ge(e,s.line),d=Ge(e,l.line),h=K(c),p=i(c.length-1),f=l.line-s.line;if(t.full)e.insert(0,a(0,c.length)),e.remove(c.length,e.size-c.length);else if(ki(e,t)){var m=a(0,c.length-1);o(d,d.text,p),f&&e.remove(s.line,f),m.length&&e.insert(s.line,m)}else if(u==d)if(1==c.length)o(u,u.text.slice(0,s.ch)+h+u.text.slice(l.ch),p);else{var g=a(1,c.length-1);g.push(new Gt(h+u.text.slice(l.ch),p,r)),o(u,u.text.slice(0,s.ch)+c[0],i(0)),e.insert(s.line+1,g)}else if(1==c.length)o(u,u.text.slice(0,s.ch)+c[0]+d.text.slice(l.ch),i(0)),e.remove(s.line+1,f);else{o(u,u.text.slice(0,s.ch)+c[0],i(0)),o(d,h+d.text.slice(l.ch),p);var v=a(1,c.length-1);f>1&&e.remove(s.line+1,f-1),e.insert(s.line+1,v)}ln(e,"change",e,t)}function Ni(e,t,n){!function e(r,i,o){if(r.linked)for(var a=0;a<r.linked.length;++a){var s=r.linked[a];if(s.doc!=i){var l=o&&s.sharedHist;n&&!l||(t(s.doc,l),e(s.doc,r,l))}}}(e,null,!0)}function ji(e,t){if(t.cm)throw new Error("This document is already in use.");e.doc=t,t.cm=e,lr(e),Oi(e),Pi(e),e.options.direction=t.direction,e.options.lineWrapping||Wt(e),e.options.mode=t.modeOption,dr(e)}function Pi(e){("rtl"==e.doc.direction?D:E)(e.display.lineDiv,"CodeMirror-rtl")}function zi(e){this.done=[],this.undone=[],this.undoDepth=e?e.undoDepth:1/0,this.lastModTime=this.lastSelTime=0,this.lastOp=this.lastSelOp=null,this.lastOrigin=this.lastSelOrigin=null,this.generation=this.maxGeneration=e?e.maxGeneration:1}function Ri(e,t){var n={from:rt(t.from),to:Ei(t),text:qe(e,t.from,t.to)};return Vi(e,n,t.from.line,t.to.line+1),Ni(e,(function(e){return Vi(e,n,t.from.line,t.to.line+1)}),!0),n}function Bi(e){for(;e.length&&K(e).ranges;)e.pop()}function Hi(e,t,n,r){var i=e.history;i.undone.length=0;var o,a,s=+new Date;if((i.lastOp==r||i.lastOrigin==t.origin&&t.origin&&("+"==t.origin.charAt(0)&&i.lastModTime>s-(e.cm?e.cm.options.historyEventDelay:500)||"*"==t.origin.charAt(0)))&&(o=function(e,t){return t?(Bi(e.done),K(e.done)):e.done.length&&!K(e.done).ranges?K(e.done):e.done.length>1&&!e.done[e.done.length-2].ranges?(e.done.pop(),K(e.done)):void 0}(i,i.lastOp==r)))a=K(o.changes),0==tt(t.from,t.to)&&0==tt(t.from,a.to)?a.to=Ei(t):o.changes.push(Ri(e,t));else{var l=K(i.done);for(l&&l.ranges||Yi(e.sel,i.done),o={changes:[Ri(e,t)],generation:i.generation},i.done.push(o);i.done.length>i.undoDepth;)i.done.shift(),i.done[0].ranges||i.done.shift()}i.done.push(n),i.generation=++i.maxGeneration,i.lastModTime=i.lastSelTime=s,i.lastOp=i.lastSelOp=r,i.lastOrigin=i.lastSelOrigin=t.origin,a||fe(e,"historyAdded")}function Fi(e,t,n,r){var i=e.history,o=r&&r.origin;n==i.lastSelOp||o&&i.lastSelOrigin==o&&(i.lastModTime==i.lastSelTime&&i.lastOrigin==o||function(e,t,n,r){var i=t.charAt(0);return"*"==i||"+"==i&&n.ranges.length==r.ranges.length&&n.somethingSelected()==r.somethingSelected()&&new Date-e.history.lastSelTime<=(e.cm?e.cm.options.historyEventDelay:500)}(e,o,K(i.done),t))?i.done[i.done.length-1]=t:Yi(t,i.done),i.lastSelTime=+new Date,i.lastSelOrigin=o,i.lastSelOp=n,r&&!1!==r.clearRedo&&Bi(i.undone)}function Yi(e,t){var n=K(t);n&&n.ranges&&n.equals(e)||t.push(e)}function Vi(e,t,n,r){var i=t["spans_"+e.id],o=0;e.iter(Math.max(e.first,n),Math.min(e.first+e.size,r),(function(n){n.markedSpans&&((i||(i=t["spans_"+e.id]={}))[o]=n.markedSpans),++o}))}function Ui(e){if(!e)return null;for(var t,n=0;n<e.length;++n)e[n].marker.explicitlyCleared?t||(t=e.slice(0,n)):t&&t.push(e[n]);return t?t.length?t:null:e}function Wi(e,t){var n=function(e,t){var n=t["spans_"+e.id];if(!n)return null;for(var r=[],i=0;i<t.text.length;++i)r.push(Ui(n[i]));return r}(e,t),r=Et(e,t);if(!n)return r;if(!r)return n;for(var i=0;i<n.length;++i){var o=n[i],a=r[i];if(o&&a)e:for(var s=0;s<a.length;++s){for(var l=a[s],c=0;c<o.length;++c)if(o[c].marker==l.marker)continue e;o.push(l)}else a&&(n[i]=a)}return n}function Gi(e,t,n){for(var r=[],i=0;i<e.length;++i){var o=e[i];if(o.ranges)r.push(n?wi.prototype.deepCopy.call(o):o);else{var a=o.changes,s=[];r.push({changes:s});for(var l=0;l<a.length;++l){var c=a[l],u=void 0;if(s.push({from:c.from,to:c.to,text:c.text}),t)for(var d in c)(u=d.match(/^spans_(\d+)$/))&&H(t,Number(u[1]))>-1&&(K(s)[d]=c[d],delete c[d])}}}return r}function qi(e,t,n,r){if(r){var i=e.anchor;if(n){var o=tt(t,i)<0;o!=tt(n,i)<0?(i=t,t=n):o!=tt(t,n)<0&&(t=n)}return new Ai(i,t)}return new Ai(n||t,t)}function Ki(e,t,n,r,i){null==i&&(i=e.cm&&(e.cm.display.shift||e.extend)),$i(e,new wi([qi(e.sel.primary(),t,n,i)],0),r)}function Xi(e,t,n){for(var r=[],i=e.cm&&(e.cm.display.shift||e.extend),o=0;o<e.sel.ranges.length;o++)r[o]=qi(e.sel.ranges[o],t[o],null,i);$i(e,Ci(e.cm,r,e.sel.primIndex),n)}function Ji(e,t,n,r){var i=e.sel.ranges.slice(0);i[t]=n,$i(e,Ci(e.cm,i,e.sel.primIndex),r)}function Qi(e,t,n,r){$i(e,xi(t,n),r)}function Zi(e,t,n){var r=e.history.done,i=K(r);i&&i.ranges?(r[r.length-1]=t,eo(e,t,n)):$i(e,t,n)}function $i(e,t,n){eo(e,t,n),Fi(e,e.sel,e.cm?e.cm.curOp.id:NaN,n)}function eo(e,t,n){(ve(e,"beforeSelectionChange")||e.cm&&ve(e.cm,"beforeSelectionChange"))&&(t=function(e,t,n){var r={ranges:t.ranges,update:function(t){this.ranges=[];for(var n=0;n<t.length;n++)this.ranges[n]=new Ai(st(e,t[n].anchor),st(e,t[n].head))},origin:n&&n.origin};return fe(e,"beforeSelectionChange",e,r),e.cm&&fe(e.cm,"beforeSelectionChange",e.cm,r),r.ranges!=t.ranges?Ci(e.cm,r.ranges,r.ranges.length-1):t}(e,t,n));var r=n&&n.bias||(tt(t.primary().head,e.sel.primary().head)<0?-1:1);to(e,ro(e,t,r,!0)),n&&!1===n.scroll||!e.cm||"nocursor"==e.cm.getOption("readOnly")||Ir(e.cm)}function to(e,t){t.equals(e.sel)||(e.sel=t,e.cm&&(e.cm.curOp.updateInput=1,e.cm.curOp.selectionChanged=!0,ge(e.cm)),ln(e,"cursorActivity",e))}function no(e){to(e,ro(e,e.sel,null,!1))}function ro(e,t,n,r){for(var i,o=0;o<t.ranges.length;o++){var a=t.ranges[o],s=t.ranges.length==e.sel.ranges.length&&e.sel.ranges[o],l=oo(e,a.anchor,s&&s.anchor,n,r),c=oo(e,a.head,s&&s.head,n,r);(i||l!=a.anchor||c!=a.head)&&(i||(i=t.ranges.slice(0,o)),i[o]=new Ai(l,c))}return i?Ci(e.cm,i,t.primIndex):t}function io(e,t,n,r,i){var o=Ge(e,t.line);if(o.markedSpans)for(var a=0;a<o.markedSpans.length;++a){var s=o.markedSpans[a],l=s.marker,c="selectLeft"in l?!l.selectLeft:l.inclusiveLeft,u="selectRight"in l?!l.selectRight:l.inclusiveRight;if((null==s.from||(c?s.from<=t.ch:s.from<t.ch))&&(null==s.to||(u?s.to>=t.ch:s.to>t.ch))){if(i&&(fe(l,"beforeCursorEnter"),l.explicitlyCleared)){if(o.markedSpans){--a;continue}break}if(!l.atomic)continue;if(n){var d=l.find(r<0?1:-1),h=void 0;if((r<0?u:c)&&(d=ao(e,d,-r,d&&d.line==t.line?o:null)),d&&d.line==t.line&&(h=tt(d,n))&&(r<0?h<0:h>0))return io(e,d,t,r,i)}var p=l.find(r<0?-1:1);return(r<0?c:u)&&(p=ao(e,p,r,p.line==t.line?o:null)),p?io(e,p,t,r,i):null}}return t}function oo(e,t,n,r,i){var o=r||1,a=io(e,t,n,o,i)||!i&&io(e,t,n,o,!0)||io(e,t,n,-o,i)||!i&&io(e,t,n,-o,!0);return a||(e.cantEdit=!0,et(e.first,0))}function ao(e,t,n,r){return n<0&&0==t.ch?t.line>e.first?st(e,et(t.line-1)):null:n>0&&t.ch==(r||Ge(e,t.line)).text.length?t.line<e.first+e.size-1?et(t.line+1,0):null:new et(t.line,t.ch+n)}function so(e){e.setSelection(et(e.firstLine(),0),et(e.lastLine()),Y)}function lo(e,t,n){var r={canceled:!1,from:t.from,to:t.to,text:t.text,origin:t.origin,cancel:function(){return r.canceled=!0}};return n&&(r.update=function(t,n,i,o){t&&(r.from=st(e,t)),n&&(r.to=st(e,n)),i&&(r.text=i),void 0!==o&&(r.origin=o)}),fe(e,"beforeChange",e,r),e.cm&&fe(e.cm,"beforeChange",e.cm,r),r.canceled?(e.cm&&(e.cm.curOp.updateInput=2),null):{from:r.from,to:r.to,text:r.text,origin:r.origin}}function co(e,t,n){if(e.cm){if(!e.cm.curOp)return ei(e.cm,co)(e,t,n);if(e.cm.state.suppressEdits)return}if(!(ve(e,"beforeChange")||e.cm&&ve(e.cm,"beforeChange"))||(t=lo(e,t,!0))){var r=Mt&&!n&&function(e,t,n){var r=null;if(e.iter(t.line,n.line+1,(function(e){if(e.markedSpans)for(var t=0;t<e.markedSpans.length;++t){var n=e.markedSpans[t].marker;!n.readOnly||r&&-1!=H(r,n)||(r||(r=[])).push(n)}})),!r)return null;for(var i=[{from:t,to:n}],o=0;o<r.length;++o)for(var a=r[o],s=a.find(0),l=0;l<i.length;++l){var c=i[l];if(!(tt(c.to,s.from)<0||tt(c.from,s.to)>0)){var u=[l,1],d=tt(c.from,s.from),h=tt(c.to,s.to);(d<0||!a.inclusiveLeft&&!d)&&u.push({from:c.from,to:s.from}),(h>0||!a.inclusiveRight&&!h)&&u.push({from:s.to,to:c.to}),i.splice.apply(i,u),l+=u.length-3}}return i}(e,t.from,t.to);if(r)for(var i=r.length-1;i>=0;--i)uo(e,{from:r[i].from,to:r[i].to,text:i?[""]:t.text,origin:t.origin});else uo(e,t)}}function uo(e,t){if(1!=t.text.length||""!=t.text[0]||0!=tt(t.from,t.to)){var n=Si(e,t);Hi(e,t,n,e.cm?e.cm.curOp.id:NaN),fo(e,t,n,Et(e,t));var r=[];Ni(e,(function(e,n){n||-1!=H(r,e.history)||(yo(e.history,t),r.push(e.history)),fo(e,t,null,Et(e,t))}))}}function ho(e,t,n){var r=e.cm&&e.cm.state.suppressEdits;if(!r||n){for(var i,o=e.history,a=e.sel,s="undo"==t?o.done:o.undone,l="undo"==t?o.undone:o.done,c=0;c<s.length&&(i=s[c],n?!i.ranges||i.equals(e.sel):i.ranges);c++);if(c!=s.length){for(o.lastOrigin=o.lastSelOrigin=null;;){if(!(i=s.pop()).ranges){if(r)return void s.push(i);break}if(Yi(i,l),n&&!i.equals(e.sel))return void $i(e,i,{clearRedo:!1});a=i}var u=[];Yi(a,l),l.push({changes:u,generation:o.generation}),o.generation=i.generation||++o.maxGeneration;for(var d=ve(e,"beforeChange")||e.cm&&ve(e.cm,"beforeChange"),h=function(n){var r=i.changes[n];if(r.origin=t,d&&!lo(e,r,!1))return s.length=0,{};u.push(Ri(e,r));var o=n?Si(e,r):K(s);fo(e,r,o,Wi(e,r)),!n&&e.cm&&e.cm.scrollIntoView({from:r.from,to:Ei(r)});var a=[];Ni(e,(function(e,t){t||-1!=H(a,e.history)||(yo(e.history,r),a.push(e.history)),fo(e,r,null,Wi(e,r))}))},p=i.changes.length-1;p>=0;--p){var f=h(p);if(f)return f.v}}}}function po(e,t){if(0!=t&&(e.first+=t,e.sel=new wi(X(e.sel.ranges,(function(e){return new Ai(et(e.anchor.line+t,e.anchor.ch),et(e.head.line+t,e.head.ch))})),e.sel.primIndex),e.cm)){dr(e.cm,e.first,e.first-t,t);for(var n=e.cm.display,r=n.viewFrom;r<n.viewTo;r++)hr(e.cm,r,"gutter")}}function fo(e,t,n,r){if(e.cm&&!e.cm.curOp)return ei(e.cm,fo)(e,t,n,r);if(t.to.line<e.first)po(e,t.text.length-1-(t.to.line-t.from.line));else if(!(t.from.line>e.lastLine())){if(t.from.line<e.first){var i=t.text.length-1-(e.first-t.from.line);po(e,i),t={from:et(e.first,0),to:et(t.to.line+i,t.to.ch),text:[K(t.text)],origin:t.origin}}var o=e.lastLine();t.to.line>o&&(t={from:t.from,to:et(o,Ge(e,o).text.length),text:[t.text[0]],origin:t.origin}),t.removed=qe(e,t.from,t.to),n||(n=Si(e,t)),e.cm?function(e,t,n){var r=e.doc,i=e.display,o=t.from,a=t.to,s=!1,l=o.line;e.options.lineWrapping||(l=Je(Rt(Ge(r,o.line))),r.iter(l,a.line+1,(function(e){if(e==i.maxLine)return s=!0,!0}))),r.sel.contains(t.from,t.to)>-1&&ge(e),Di(r,t,n,sr(e)),e.options.lineWrapping||(r.iter(l,o.line+t.text.length,(function(e){var t=Ut(e);t>i.maxLineLength&&(i.maxLine=e,i.maxLineLength=t,i.maxLineChanged=!0,s=!1)})),s&&(e.curOp.updateMaxLine=!0)),function(e,t){if(e.modeFrontier=Math.min(e.modeFrontier,t),!(e.highlightFrontier<t-10)){for(var n=e.first,r=t-1;r>n;r--){var i=Ge(e,r).stateAfter;if(i&&(!(i instanceof ct)||r+i.lookAhead<t)){n=r+1;break}}e.highlightFrontier=Math.min(e.highlightFrontier,n)}}(r,o.line),ri(e,400);var c=t.text.length-(a.line-o.line)-1;t.full?dr(e):o.line!=a.line||1!=t.text.length||ki(e.doc,t)?dr(e,o.line,a.line+1,c):hr(e,o.line,"text");var u=ve(e,"changes"),d=ve(e,"change");if(d||u){var h={from:o,to:a,text:t.text,removed:t.removed,origin:t.origin};d&&ln(e,"change",e,h),u&&(e.curOp.changeObjs||(e.curOp.changeObjs=[])).push(h)}e.display.selForContextMenu=null}(e.cm,t,r):Di(e,t,r),eo(e,n,Y),e.cantEdit&&oo(e,et(e.firstLine(),0))&&(e.cantEdit=!1)}}function mo(e,t,n,r,i){var o;r||(r=n),tt(r,n)<0&&(n=(o=[r,n])[0],r=o[1]),"string"==typeof t&&(t=e.splitLines(t)),co(e,{from:n,to:r,text:t,origin:i})}function go(e,t,n,r){n<e.line?e.line+=r:t<e.line&&(e.line=t,e.ch=0)}function vo(e,t,n,r){for(var i=0;i<e.length;++i){var o=e[i],a=!0;if(o.ranges){o.copied||((o=e[i]=o.deepCopy()).copied=!0);for(var s=0;s<o.ranges.length;s++)go(o.ranges[s].anchor,t,n,r),go(o.ranges[s].head,t,n,r)}else{for(var l=0;l<o.changes.length;++l){var c=o.changes[l];if(n<c.from.line)c.from=et(c.from.line+r,c.from.ch),c.to=et(c.to.line+r,c.to.ch);else if(t<=c.to.line){a=!1;break}}a||(e.splice(0,i+1),i=0)}}}function yo(e,t){var n=t.from.line,r=t.to.line,i=t.text.length-(r-n)-1;vo(e.done,n,r,i),vo(e.undone,n,r,i)}function _o(e,t,n,r){var i=t,o=t;return"number"==typeof t?o=Ge(e,at(e,t)):i=Je(t),null==i?null:(r(o,i)&&e.cm&&hr(e.cm,i,n),o)}function bo(e){this.lines=e,this.parent=null;for(var t=0,n=0;n<e.length;++n)e[n].parent=this,t+=e[n].height;this.height=t}function Mo(e){this.children=e;for(var t=0,n=0,r=0;r<e.length;++r){var i=e[r];t+=i.chunkSize(),n+=i.height,i.parent=this}this.size=t,this.height=n,this.parent=null}Ai.prototype.from=function(){return ot(this.anchor,this.head)},Ai.prototype.to=function(){return it(this.anchor,this.head)},Ai.prototype.empty=function(){return this.head.line==this.anchor.line&&this.head.ch==this.anchor.ch},bo.prototype={chunkSize:function(){return this.lines.length},removeInner:function(e,t){for(var n=e,r=e+t;n<r;++n){var i=this.lines[n];this.height-=i.height,qt(i),ln(i,"delete")}this.lines.splice(e,t)},collapse:function(e){e.push.apply(e,this.lines)},insertInner:function(e,t,n){this.height+=n,this.lines=this.lines.slice(0,e).concat(t).concat(this.lines.slice(e));for(var r=0;r<t.length;++r)t[r].parent=this},iterN:function(e,t,n){for(var r=e+t;e<r;++e)if(n(this.lines[e]))return!0}},Mo.prototype={chunkSize:function(){return this.size},removeInner:function(e,t){this.size-=t;for(var n=0;n<this.children.length;++n){var r=this.children[n],i=r.chunkSize();if(e<i){var o=Math.min(t,i-e),a=r.height;if(r.removeInner(e,o),this.height-=a-r.height,i==o&&(this.children.splice(n--,1),r.parent=null),0==(t-=o))break;e=0}else e-=i}if(this.size-t<25&&(this.children.length>1||!(this.children[0]instanceof bo))){var s=[];this.collapse(s),this.children=[new bo(s)],this.children[0].parent=this}},collapse:function(e){for(var t=0;t<this.children.length;++t)this.children[t].collapse(e)},insertInner:function(e,t,n){this.size+=t.length,this.height+=n;for(var r=0;r<this.children.length;++r){var i=this.children[r],o=i.chunkSize();if(e<=o){if(i.insertInner(e,t,n),i.lines&&i.lines.length>50){for(var a=i.lines.length%25+25,s=a;s<i.lines.length;){var l=new bo(i.lines.slice(s,s+=25));i.height-=l.height,this.children.splice(++r,0,l),l.parent=this}i.lines=i.lines.slice(0,a),this.maybeSpill()}break}e-=o}},maybeSpill:function(){if(!(this.children.length<=10)){var e=this;do{var t=new Mo(e.children.splice(e.children.length-5,5));if(e.parent){e.size-=t.size,e.height-=t.height;var n=H(e.parent.children,e);e.parent.children.splice(n+1,0,t)}else{var r=new Mo(e.children);r.parent=e,e.children=[r,t],e=r}t.parent=e.parent}while(e.children.length>10);e.parent.maybeSpill()}},iterN:function(e,t,n){for(var r=0;r<this.children.length;++r){var i=this.children[r],o=i.chunkSize();if(e<o){var a=Math.min(t,o-e);if(i.iterN(e,a,n))return!0;if(0==(t-=a))break;e=0}else e-=o}}};var wo=function(e,t,n){if(n)for(var r in n)n.hasOwnProperty(r)&&(this[r]=n[r]);this.doc=e,this.node=t};function Ao(e,t,n){Vt(t)<(e.curOp&&e.curOp.scrollTop||e.doc.scrollTop)&&Or(e,n)}wo.prototype.clear=function(){var e=this.doc.cm,t=this.line.widgets,n=this.line,r=Je(n);if(null!=r&&t){for(var i=0;i<t.length;++i)t[i]==this&&t.splice(i--,1);t.length||(n.widgets=null);var o=Mn(this);Xe(n,Math.max(0,n.height-o)),e&&($r(e,(function(){Ao(e,n,-o),hr(e,r,"widget")})),ln(e,"lineWidgetCleared",e,this,r))}},wo.prototype.changed=function(){var e=this,t=this.height,n=this.doc.cm,r=this.line;this.height=null;var i=Mn(this)-t;i&&(Ft(this.doc,r)||Xe(r,r.height+i),n&&$r(n,(function(){n.curOp.forceUpdate=!0,Ao(n,r,i),ln(n,"lineWidgetChanged",n,e,Je(r))})))},ye(wo);var Co=0,xo=function(e,t){this.lines=[],this.type=t,this.doc=e,this.id=++Co};function Eo(e,t,n,r,i){if(r&&r.shared)return function(e,t,n,r,i){(r=z(r)).shared=!1;var o=[Eo(e,t,n,r,i)],a=o[0],s=r.widgetNode;return Ni(e,(function(e){s&&(r.widgetNode=s.cloneNode(!0)),o.push(Eo(e,st(e,t),st(e,n),r,i));for(var l=0;l<e.linked.length;++l)if(e.linked[l].isParent)return;a=K(o)})),new Lo(o,a)}(e,t,n,r,i);if(e.cm&&!e.cm.curOp)return ei(e.cm,Eo)(e,t,n,r,i);var o=new xo(e,i),a=tt(t,n);if(r&&z(r,o,!1),a>0||0==a&&!1!==o.clearWhenEmpty)return o;if(o.replacedWith&&(o.collapsed=!0,o.widgetNode=O("span",[o.replacedWith],"CodeMirror-widget"),r.handleMouseEvents||o.widgetNode.setAttribute("cm-ignore-events","true"),r.insertLeft&&(o.widgetNode.insertLeft=!0)),o.collapsed){if(zt(e,t.line,t,n,o)||t.line!=n.line&&zt(e,n.line,t,n,o))throw new Error("Inserting collapsed marker partially overlapping an existing one");wt=!0}o.addToHistory&&Hi(e,{from:t,to:n,origin:"markText"},e.sel,NaN);var s,l=t.line,c=e.cm;if(e.iter(l,n.line+1,(function(r){c&&o.collapsed&&!c.options.lineWrapping&&Rt(r)==c.display.maxLine&&(s=!0),o.collapsed&&l!=t.line&&Xe(r,0),function(e,t,n){var r=n&&window.WeakSet&&(n.markedSpans||(n.markedSpans=new WeakSet));r&&r.has(e.markedSpans)?e.markedSpans.push(t):(e.markedSpans=e.markedSpans?e.markedSpans.concat([t]):[t],r&&r.add(e.markedSpans)),t.marker.attachLine(e)}(r,new At(o,l==t.line?t.ch:null,l==n.line?n.ch:null),e.cm&&e.cm.curOp),++l})),o.collapsed&&e.iter(t.line,n.line+1,(function(t){Ft(e,t)&&Xe(t,0)})),o.clearOnEnter&&de(o,"beforeCursorEnter",(function(){return o.clear()})),o.readOnly&&(Mt=!0,(e.history.done.length||e.history.undone.length)&&e.clearHistory()),o.collapsed&&(o.id=++Co,o.atomic=!0),c){if(s&&(c.curOp.updateMaxLine=!0),o.collapsed)dr(c,t.line,n.line+1);else if(o.className||o.startStyle||o.endStyle||o.css||o.attributes||o.title)for(var u=t.line;u<=n.line;u++)hr(c,u,"text");o.atomic&&no(c.doc),ln(c,"markerAdded",c,o)}return o}xo.prototype.clear=function(){if(!this.explicitlyCleared){var e=this.doc.cm,t=e&&!e.curOp;if(t&&Gr(e),ve(this,"clear")){var n=this.find();n&&ln(this,"clear",n.from,n.to)}for(var r=null,i=null,o=0;o<this.lines.length;++o){var a=this.lines[o],s=Ct(a.markedSpans,this);e&&!this.collapsed?hr(e,Je(a),"text"):e&&(null!=s.to&&(i=Je(a)),null!=s.from&&(r=Je(a))),a.markedSpans=xt(a.markedSpans,s),null==s.from&&this.collapsed&&!Ft(this.doc,a)&&e&&Xe(a,rr(e.display))}if(e&&this.collapsed&&!e.options.lineWrapping)for(var l=0;l<this.lines.length;++l){var c=Rt(this.lines[l]),u=Ut(c);u>e.display.maxLineLength&&(e.display.maxLine=c,e.display.maxLineLength=u,e.display.maxLineChanged=!0)}null!=r&&e&&this.collapsed&&dr(e,r,i+1),this.lines.length=0,this.explicitlyCleared=!0,this.atomic&&this.doc.cantEdit&&(this.doc.cantEdit=!1,e&&no(e.doc)),e&&ln(e,"markerCleared",e,this,r,i),t&&qr(e),this.parent&&this.parent.clear()}},xo.prototype.find=function(e,t){var n,r;null==e&&"bookmark"==this.type&&(e=1);for(var i=0;i<this.lines.length;++i){var o=this.lines[i],a=Ct(o.markedSpans,this);if(null!=a.from&&(n=et(t?o:Je(o),a.from),-1==e))return n;if(null!=a.to&&(r=et(t?o:Je(o),a.to),1==e))return r}return n&&{from:n,to:r}},xo.prototype.changed=function(){var e=this,t=this.find(-1,!0),n=this,r=this.doc.cm;t&&r&&$r(r,(function(){var i=t.line,o=Je(t.line),a=In(r,o);if(a&&(Rn(a),r.curOp.selectionChanged=r.curOp.forceUpdate=!0),r.curOp.updateMaxLine=!0,!Ft(n.doc,i)&&null!=n.height){var s=n.height;n.height=null;var l=Mn(n)-s;l&&Xe(i,i.height+l)}ln(r,"markerChanged",r,e)}))},xo.prototype.attachLine=function(e){if(!this.lines.length&&this.doc.cm){var t=this.doc.cm.curOp;t.maybeHiddenMarkers&&-1!=H(t.maybeHiddenMarkers,this)||(t.maybeUnhiddenMarkers||(t.maybeUnhiddenMarkers=[])).push(this)}this.lines.push(e)},xo.prototype.detachLine=function(e){if(this.lines.splice(H(this.lines,e),1),!this.lines.length&&this.doc.cm){var t=this.doc.cm.curOp;(t.maybeHiddenMarkers||(t.maybeHiddenMarkers=[])).push(this)}},ye(xo);var Lo=function(e,t){this.markers=e,this.primary=t;for(var n=0;n<e.length;++n)e[n].parent=this};function So(e){return e.findMarks(et(e.first,0),e.clipPos(et(e.lastLine())),(function(e){return e.parent}))}function To(e){for(var t=function(t){var n=e[t],r=[n.primary.doc];Ni(n.primary.doc,(function(e){return r.push(e)}));for(var i=0;i<n.markers.length;i++){var o=n.markers[i];-1==H(r,o.doc)&&(o.parent=null,n.markers.splice(i--,1))}},n=0;n<e.length;n++)t(n)}Lo.prototype.clear=function(){if(!this.explicitlyCleared){this.explicitlyCleared=!0;for(var e=0;e<this.markers.length;++e)this.markers[e].clear();ln(this,"clear")}},Lo.prototype.find=function(e,t){return this.primary.find(e,t)},ye(Lo);var Oo=0,Io=function(e,t,n,r,i){if(!(this instanceof Io))return new Io(e,t,n,r,i);null==n&&(n=0),Mo.call(this,[new bo([new Gt("",null)])]),this.first=n,this.scrollTop=this.scrollLeft=0,this.cantEdit=!1,this.cleanGeneration=1,this.modeFrontier=this.highlightFrontier=n;var o=et(n,0);this.sel=xi(o),this.history=new zi(null),this.id=++Oo,this.modeOption=t,this.lineSep=r,this.direction="rtl"==i?"rtl":"ltr",this.extend=!1,"string"==typeof e&&(e=this.splitLines(e)),Di(this,{from:o,to:o,text:e}),$i(this,xi(o),Y)};Io.prototype=Q(Mo.prototype,{constructor:Io,iter:function(e,t,n){n?this.iterN(e-this.first,t-e,n):this.iterN(this.first,this.first+this.size,e)},insert:function(e,t){for(var n=0,r=0;r<t.length;++r)n+=t[r].height;this.insertInner(e-this.first,t,n)},remove:function(e,t){this.removeInner(e-this.first,t)},getValue:function(e){var t=Ke(this,this.first,this.first+this.size);return!1===e?t:t.join(e||this.lineSeparator())},setValue:ni((function(e){var t=et(this.first,0),n=this.first+this.size-1;co(this,{from:t,to:et(n,Ge(this,n).text.length),text:this.splitLines(e),origin:"setValue",full:!0},!0),this.cm&&kr(this.cm,0,0),$i(this,xi(t),Y)})),replaceRange:function(e,t,n,r){mo(this,e,t=st(this,t),n=n?st(this,n):t,r)},getRange:function(e,t,n){var r=qe(this,st(this,e),st(this,t));return!1===n?r:r.join(n||this.lineSeparator())},getLine:function(e){var t=this.getLineHandle(e);return t&&t.text},getLineHandle:function(e){if(Ze(this,e))return Ge(this,e)},getLineNumber:function(e){return Je(e)},getLineHandleVisualStart:function(e){return"number"==typeof e&&(e=Ge(this,e)),Rt(e)},lineCount:function(){return this.size},firstLine:function(){return this.first},lastLine:function(){return this.first+this.size-1},clipPos:function(e){return st(this,e)},getCursor:function(e){var t=this.sel.primary();return null==e||"head"==e?t.head:"anchor"==e?t.anchor:"end"==e||"to"==e||!1===e?t.to():t.from()},listSelections:function(){return this.sel.ranges},somethingSelected:function(){return this.sel.somethingSelected()},setCursor:ni((function(e,t,n){Qi(this,st(this,"number"==typeof e?et(e,t||0):e),null,n)})),setSelection:ni((function(e,t,n){Qi(this,st(this,e),st(this,t||e),n)})),extendSelection:ni((function(e,t,n){Ki(this,st(this,e),t&&st(this,t),n)})),extendSelections:ni((function(e,t){Xi(this,lt(this,e),t)})),extendSelectionsBy:ni((function(e,t){Xi(this,lt(this,X(this.sel.ranges,e)),t)})),setSelections:ni((function(e,t,n){if(e.length){for(var r=[],i=0;i<e.length;i++)r[i]=new Ai(st(this,e[i].anchor),st(this,e[i].head||e[i].anchor));null==t&&(t=Math.min(e.length-1,this.sel.primIndex)),$i(this,Ci(this.cm,r,t),n)}})),addSelection:ni((function(e,t,n){var r=this.sel.ranges.slice(0);r.push(new Ai(st(this,e),st(this,t||e))),$i(this,Ci(this.cm,r,r.length-1),n)})),getSelection:function(e){for(var t,n=this.sel.ranges,r=0;r<n.length;r++){var i=qe(this,n[r].from(),n[r].to());t=t?t.concat(i):i}return!1===e?t:t.join(e||this.lineSeparator())},getSelections:function(e){for(var t=[],n=this.sel.ranges,r=0;r<n.length;r++){var i=qe(this,n[r].from(),n[r].to());!1!==e&&(i=i.join(e||this.lineSeparator())),t[r]=i}return t},replaceSelection:function(e,t,n){for(var r=[],i=0;i<this.sel.ranges.length;i++)r[i]=e;this.replaceSelections(r,t,n||"+input")},replaceSelections:ni((function(e,t,n){for(var r=[],i=this.sel,o=0;o<i.ranges.length;o++){var a=i.ranges[o];r[o]={from:a.from(),to:a.to(),text:this.splitLines(e[o]),origin:n}}for(var s=t&&"end"!=t&&function(e,t,n){for(var r=[],i=et(e.first,0),o=i,a=0;a<t.length;a++){var s=t[a],l=Ti(s.from,i,o),c=Ti(Ei(s),i,o);if(i=s.to,o=c,"around"==n){var u=e.sel.ranges[a],d=tt(u.head,u.anchor)<0;r[a]=new Ai(d?c:l,d?l:c)}else r[a]=new Ai(l,l)}return new wi(r,e.sel.primIndex)}(this,r,t),l=r.length-1;l>=0;l--)co(this,r[l]);s?Zi(this,s):this.cm&&Ir(this.cm)})),undo:ni((function(){ho(this,"undo")})),redo:ni((function(){ho(this,"redo")})),undoSelection:ni((function(){ho(this,"undo",!0)})),redoSelection:ni((function(){ho(this,"redo",!0)})),setExtending:function(e){this.extend=e},getExtending:function(){return this.extend},historySize:function(){for(var e=this.history,t=0,n=0,r=0;r<e.done.length;r++)e.done[r].ranges||++t;for(var i=0;i<e.undone.length;i++)e.undone[i].ranges||++n;return{undo:t,redo:n}},clearHistory:function(){var e=this;this.history=new zi(this.history),Ni(this,(function(t){return t.history=e.history}),!0)},markClean:function(){this.cleanGeneration=this.changeGeneration(!0)},changeGeneration:function(e){return e&&(this.history.lastOp=this.history.lastSelOp=this.history.lastOrigin=null),this.history.generation},isClean:function(e){return this.history.generation==(e||this.cleanGeneration)},getHistory:function(){return{done:Gi(this.history.done),undone:Gi(this.history.undone)}},setHistory:function(e){var t=this.history=new zi(this.history);t.done=Gi(e.done.slice(0),null,!0),t.undone=Gi(e.undone.slice(0),null,!0)},setGutterMarker:ni((function(e,t,n){return _o(this,e,"gutter",(function(e){var r=e.gutterMarkers||(e.gutterMarkers={});return r[t]=n,!n&&te(r)&&(e.gutterMarkers=null),!0}))})),clearGutter:ni((function(e){var t=this;this.iter((function(n){n.gutterMarkers&&n.gutterMarkers[e]&&_o(t,n,"gutter",(function(){return n.gutterMarkers[e]=null,te(n.gutterMarkers)&&(n.gutterMarkers=null),!0}))}))})),lineInfo:function(e){var t;if("number"==typeof e){if(!Ze(this,e))return null;if(t=e,!(e=Ge(this,e)))return null}else if(null==(t=Je(e)))return null;return{line:t,handle:e,text:e.text,gutterMarkers:e.gutterMarkers,textClass:e.textClass,bgClass:e.bgClass,wrapClass:e.wrapClass,widgets:e.widgets}},addLineClass:ni((function(e,t,n){return _o(this,e,"gutter"==t?"gutter":"class",(function(e){var r="text"==t?"textClass":"background"==t?"bgClass":"gutter"==t?"gutterClass":"wrapClass";if(e[r]){if(C(n).test(e[r]))return!1;e[r]+=" "+n}else e[r]=n;return!0}))})),removeLineClass:ni((function(e,t,n){return _o(this,e,"gutter"==t?"gutter":"class",(function(e){var r="text"==t?"textClass":"background"==t?"bgClass":"gutter"==t?"gutterClass":"wrapClass",i=e[r];if(!i)return!1;if(null==n)e[r]=null;else{var o=i.match(C(n));if(!o)return!1;var a=o.index+o[0].length;e[r]=i.slice(0,o.index)+(o.index&&a!=i.length?" ":"")+i.slice(a)||null}return!0}))})),addLineWidget:ni((function(e,t,n){return function(e,t,n,r){var i=new wo(e,n,r),o=e.cm;return o&&i.noHScroll&&(o.display.alignWidgets=!0),_o(e,t,"widget",(function(t){var n=t.widgets||(t.widgets=[]);if(null==i.insertAt?n.push(i):n.splice(Math.min(n.length,Math.max(0,i.insertAt)),0,i),i.line=t,o&&!Ft(e,t)){var r=Vt(t)<e.scrollTop;Xe(t,t.height+Mn(i)),r&&Or(o,i.height),o.curOp.forceUpdate=!0}return!0})),o&&ln(o,"lineWidgetAdded",o,i,"number"==typeof t?t:Je(t)),i}(this,e,t,n)})),removeLineWidget:function(e){e.clear()},markText:function(e,t,n){return Eo(this,st(this,e),st(this,t),n,n&&n.type||"range")},setBookmark:function(e,t){var n={replacedWith:t&&(null==t.nodeType?t.widget:t),insertLeft:t&&t.insertLeft,clearWhenEmpty:!1,shared:t&&t.shared,handleMouseEvents:t&&t.handleMouseEvents};return Eo(this,e=st(this,e),e,n,"bookmark")},findMarksAt:function(e){var t=[],n=Ge(this,(e=st(this,e)).line).markedSpans;if(n)for(var r=0;r<n.length;++r){var i=n[r];(null==i.from||i.from<=e.ch)&&(null==i.to||i.to>=e.ch)&&t.push(i.marker.parent||i.marker)}return t},findMarks:function(e,t,n){e=st(this,e),t=st(this,t);var r=[],i=e.line;return this.iter(e.line,t.line+1,(function(o){var a=o.markedSpans;if(a)for(var s=0;s<a.length;s++){var l=a[s];null!=l.to&&i==e.line&&e.ch>=l.to||null==l.from&&i!=e.line||null!=l.from&&i==t.line&&l.from>=t.ch||n&&!n(l.marker)||r.push(l.marker.parent||l.marker)}++i})),r},getAllMarks:function(){var e=[];return this.iter((function(t){var n=t.markedSpans;if(n)for(var r=0;r<n.length;++r)null!=n[r].from&&e.push(n[r].marker)})),e},posFromIndex:function(e){var t,n=this.first,r=this.lineSeparator().length;return this.iter((function(i){var o=i.text.length+r;if(o>e)return t=e,!0;e-=o,++n})),st(this,et(n,t))},indexFromPos:function(e){var t=(e=st(this,e)).ch;if(e.line<this.first||e.ch<0)return 0;var n=this.lineSeparator().length;return this.iter(this.first,e.line,(function(e){t+=e.text.length+n})),t},copy:function(e){var t=new Io(Ke(this,this.first,this.first+this.size),this.modeOption,this.first,this.lineSep,this.direction);return t.scrollTop=this.scrollTop,t.scrollLeft=this.scrollLeft,t.sel=this.sel,t.extend=!1,e&&(t.history.undoDepth=this.history.undoDepth,t.setHistory(this.getHistory())),t},linkedDoc:function(e){e||(e={});var t=this.first,n=this.first+this.size;null!=e.from&&e.from>t&&(t=e.from),null!=e.to&&e.to<n&&(n=e.to);var r=new Io(Ke(this,t,n),e.mode||this.modeOption,t,this.lineSep,this.direction);return e.sharedHist&&(r.history=this.history),(this.linked||(this.linked=[])).push({doc:r,sharedHist:e.sharedHist}),r.linked=[{doc:this,isParent:!0,sharedHist:e.sharedHist}],function(e,t){for(var n=0;n<t.length;n++){var r=t[n],i=r.find(),o=e.clipPos(i.from),a=e.clipPos(i.to);if(tt(o,a)){var s=Eo(e,o,a,r.primary,r.primary.type);r.markers.push(s),s.parent=r}}}(r,So(this)),r},unlinkDoc:function(e){if(e instanceof La&&(e=e.doc),this.linked)for(var t=0;t<this.linked.length;++t)if(this.linked[t].doc==e){this.linked.splice(t,1),e.unlinkDoc(this),To(So(this));break}if(e.history==this.history){var n=[e.id];Ni(e,(function(e){return n.push(e.id)}),!0),e.history=new zi(null),e.history.done=Gi(this.history.done,n),e.history.undone=Gi(this.history.undone,n)}},iterLinkedDocs:function(e){Ni(this,e)},getMode:function(){return this.mode},getEditor:function(){return this.cm},splitLines:function(e){return this.lineSep?e.split(this.lineSep):Ie(e)},lineSeparator:function(){return this.lineSep||"\n"},setDirection:ni((function(e){var t;"rtl"!=e&&(e="ltr"),e!=this.direction&&(this.direction=e,this.iter((function(e){return e.order=null})),this.cm&&$r(t=this.cm,(function(){Pi(t),dr(t)})))}))}),Io.prototype.eachLine=Io.prototype.iter;var ko=0;function Do(e){var t=this;if(No(t),!me(t,e)&&!wn(t.display,e)){_e(e),a&&(ko=+new Date);var n=cr(t,e,!0),r=e.dataTransfer.files;if(n&&!t.isReadOnly())if(r&&r.length&&window.FileReader&&window.File)for(var i=r.length,o=Array(i),s=0,l=function(){++s==i&&ei(t,(function(){var e={from:n=st(t.doc,n),to:n,text:t.doc.splitLines(o.filter((function(e){return null!=e})).join(t.doc.lineSeparator())),origin:"paste"};co(t.doc,e),Zi(t.doc,xi(st(t.doc,n),st(t.doc,Ei(e))))}))()},c=function(e,n){if(t.options.allowDropFileTypes&&-1==H(t.options.allowDropFileTypes,e.type))l();else{var r=new FileReader;r.onerror=function(){return l()},r.onload=function(){var e=r.result;/[\x00-\x08\x0e-\x1f]{2}/.test(e)||(o[n]=e),l()},r.readAsText(e)}},u=0;u<r.length;u++)c(r[u],u);else{if(t.state.draggingText&&t.doc.sel.contains(n)>-1)return t.state.draggingText(e),void setTimeout((function(){return t.display.input.focus()}),20);try{var d=e.dataTransfer.getData("Text");if(d){var h;if(t.state.draggingText&&!t.state.draggingText.copy&&(h=t.listSelections()),eo(t.doc,xi(n,n)),h)for(var p=0;p<h.length;++p)mo(t.doc,"",h[p].anchor,h[p].head,"drag");t.replaceSelection(d,"around","paste"),t.display.input.focus()}}catch(e){}}}}function No(e){e.display.dragCursor&&(e.display.lineSpace.removeChild(e.display.dragCursor),e.display.dragCursor=null)}function jo(e){if(document.getElementsByClassName){for(var t=document.getElementsByClassName("CodeMirror"),n=[],r=0;r<t.length;r++){var i=t[r].CodeMirror;i&&n.push(i)}n.length&&n[0].operation((function(){for(var t=0;t<n.length;t++)e(n[t])}))}}var Po=!1;function zo(){var e;Po||(de(window,"resize",(function(){null==e&&(e=setTimeout((function(){e=null,jo(Ro)}),100))})),de(window,"blur",(function(){return jo(xr)})),Po=!0)}function Ro(e){var t=e.display;t.cachedCharWidth=t.cachedTextHeight=t.cachedPaddingH=null,t.scrollbarsClipped=!1,e.setSize()}for(var Bo={3:"Pause",8:"Backspace",9:"Tab",13:"Enter",16:"Shift",17:"Ctrl",18:"Alt",19:"Pause",20:"CapsLock",27:"Esc",32:"Space",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"Left",38:"Up",39:"Right",40:"Down",44:"PrintScrn",45:"Insert",46:"Delete",59:";",61:"=",91:"Mod",92:"Mod",93:"Mod",106:"*",107:"=",109:"-",110:".",111:"/",145:"ScrollLock",173:"-",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'",224:"Mod",63232:"Up",63233:"Down",63234:"Left",63235:"Right",63272:"Delete",63273:"Home",63275:"End",63276:"PageUp",63277:"PageDown",63302:"Insert"},Ho=0;Ho<10;Ho++)Bo[Ho+48]=Bo[Ho+96]=String(Ho);for(var Fo=65;Fo<=90;Fo++)Bo[Fo]=String.fromCharCode(Fo);for(var Yo=1;Yo<=12;Yo++)Bo[Yo+111]=Bo[Yo+63235]="F"+Yo;var Vo={};function Uo(e){var t,n,r,i,o=e.split(/-(?!$)/);e=o[o.length-1];for(var a=0;a<o.length-1;a++){var s=o[a];if(/^(cmd|meta|m)$/i.test(s))i=!0;else if(/^a(lt)?$/i.test(s))t=!0;else if(/^(c|ctrl|control)$/i.test(s))n=!0;else{if(!/^s(hift)?$/i.test(s))throw new Error("Unrecognized modifier name: "+s);r=!0}}return t&&(e="Alt-"+e),n&&(e="Ctrl-"+e),i&&(e="Cmd-"+e),r&&(e="Shift-"+e),e}function Wo(e){var t={};for(var n in e)if(e.hasOwnProperty(n)){var r=e[n];if(/^(name|fallthrough|(de|at)tach)$/.test(n))continue;if("..."==r){delete e[n];continue}for(var i=X(n.split(" "),Uo),o=0;o<i.length;o++){var a=void 0,s=void 0;o==i.length-1?(s=i.join(" "),a=r):(s=i.slice(0,o+1).join(" "),a="...");var l=t[s];if(l){if(l!=a)throw new Error("Inconsistent bindings for "+s)}else t[s]=a}delete e[n]}for(var c in t)e[c]=t[c];return e}function Go(e,t,n,r){var i=(t=Jo(t)).call?t.call(e,r):t[e];if(!1===i)return"nothing";if("..."===i)return"multi";if(null!=i&&n(i))return"handled";if(t.fallthrough){if("[object Array]"!=Object.prototype.toString.call(t.fallthrough))return Go(e,t.fallthrough,n,r);for(var o=0;o<t.fallthrough.length;o++){var a=Go(e,t.fallthrough[o],n,r);if(a)return a}}}function qo(e){var t="string"==typeof e?e:Bo[e.keyCode];return"Ctrl"==t||"Alt"==t||"Shift"==t||"Mod"==t}function Ko(e,t,n){var r=e;return t.altKey&&"Alt"!=r&&(e="Alt-"+e),(w?t.metaKey:t.ctrlKey)&&"Ctrl"!=r&&(e="Ctrl-"+e),(w?t.ctrlKey:t.metaKey)&&"Mod"!=r&&(e="Cmd-"+e),!n&&t.shiftKey&&"Shift"!=r&&(e="Shift-"+e),e}function Xo(e,t){if(d&&34==e.keyCode&&e.char)return!1;var n=Bo[e.keyCode];return null!=n&&!e.altGraphKey&&(3==e.keyCode&&e.code&&(n=e.code),Ko(n,e,t))}function Jo(e){return"string"==typeof e?Vo[e]:e}function Qo(e,t){for(var n=e.doc.sel.ranges,r=[],i=0;i<n.length;i++){for(var o=t(n[i]);r.length&&tt(o.from,K(r).to)<=0;){var a=r.pop();if(tt(a.from,o.from)<0){o.from=a.from;break}}r.push(o)}$r(e,(function(){for(var t=r.length-1;t>=0;t--)mo(e.doc,"",r[t].from,r[t].to,"+delete");Ir(e)}))}function Zo(e,t,n){var r=ie(e.text,t+n,n);return r<0||r>e.text.length?null:r}function $o(e,t,n){var r=Zo(e,t.ch,n);return null==r?null:new et(t.line,r,n<0?"after":"before")}function ea(e,t,n,r,i){if(e){"rtl"==t.doc.direction&&(i=-i);var o=ce(n,t.doc.direction);if(o){var a,s=i<0?K(o):o[0],l=i<0==(1==s.level)?"after":"before";if(s.level>0||"rtl"==t.doc.direction){var c=kn(t,n);a=i<0?n.text.length-1:0;var u=Dn(t,c,a).top;a=oe((function(e){return Dn(t,c,e).top==u}),i<0==(1==s.level)?s.from:s.to-1,a),"before"==l&&(a=Zo(n,a,1))}else a=i<0?s.to:s.from;return new et(r,a,l)}}return new et(r,i<0?n.text.length:0,i<0?"before":"after")}Vo.basic={Left:"goCharLeft",Right:"goCharRight",Up:"goLineUp",Down:"goLineDown",End:"goLineEnd",Home:"goLineStartSmart",PageUp:"goPageUp",PageDown:"goPageDown",Delete:"delCharAfter",Backspace:"delCharBefore","Shift-Backspace":"delCharBefore",Tab:"defaultTab","Shift-Tab":"indentAuto",Enter:"newlineAndIndent",Insert:"toggleOverwrite",Esc:"singleSelection"},Vo.pcDefault={"Ctrl-A":"selectAll","Ctrl-D":"deleteLine","Ctrl-Z":"undo","Shift-Ctrl-Z":"redo","Ctrl-Y":"redo","Ctrl-Home":"goDocStart","Ctrl-End":"goDocEnd","Ctrl-Up":"goLineUp","Ctrl-Down":"goLineDown","Ctrl-Left":"goGroupLeft","Ctrl-Right":"goGroupRight","Alt-Left":"goLineStart","Alt-Right":"goLineEnd","Ctrl-Backspace":"delGroupBefore","Ctrl-Delete":"delGroupAfter","Ctrl-S":"save","Ctrl-F":"find","Ctrl-G":"findNext","Shift-Ctrl-G":"findPrev","Shift-Ctrl-F":"replace","Shift-Ctrl-R":"replaceAll","Ctrl-[":"indentLess","Ctrl-]":"indentMore","Ctrl-U":"undoSelection","Shift-Ctrl-U":"redoSelection","Alt-U":"redoSelection",fallthrough:"basic"},Vo.emacsy={"Ctrl-F":"goCharRight","Ctrl-B":"goCharLeft","Ctrl-P":"goLineUp","Ctrl-N":"goLineDown","Ctrl-A":"goLineStart","Ctrl-E":"goLineEnd","Ctrl-V":"goPageDown","Shift-Ctrl-V":"goPageUp","Ctrl-D":"delCharAfter","Ctrl-H":"delCharBefore","Alt-Backspace":"delWordBefore","Ctrl-K":"killLine","Ctrl-T":"transposeChars","Ctrl-O":"openLine"},Vo.macDefault={"Cmd-A":"selectAll","Cmd-D":"deleteLine","Cmd-Z":"undo","Shift-Cmd-Z":"redo","Cmd-Y":"redo","Cmd-Home":"goDocStart","Cmd-Up":"goDocStart","Cmd-End":"goDocEnd","Cmd-Down":"goDocEnd","Alt-Left":"goGroupLeft","Alt-Right":"goGroupRight","Cmd-Left":"goLineLeft","Cmd-Right":"goLineRight","Alt-Backspace":"delGroupBefore","Ctrl-Alt-Backspace":"delGroupAfter","Alt-Delete":"delGroupAfter","Cmd-S":"save","Cmd-F":"find","Cmd-G":"findNext","Shift-Cmd-G":"findPrev","Cmd-Alt-F":"replace","Shift-Cmd-Alt-F":"replaceAll","Cmd-[":"indentLess","Cmd-]":"indentMore","Cmd-Backspace":"delWrappedLineLeft","Cmd-Delete":"delWrappedLineRight","Cmd-U":"undoSelection","Shift-Cmd-U":"redoSelection","Ctrl-Up":"goDocStart","Ctrl-Down":"goDocEnd",fallthrough:["basic","emacsy"]},Vo.default=y?Vo.macDefault:Vo.pcDefault;var ta={selectAll:so,singleSelection:function(e){return e.setSelection(e.getCursor("anchor"),e.getCursor("head"),Y)},killLine:function(e){return Qo(e,(function(t){if(t.empty()){var n=Ge(e.doc,t.head.line).text.length;return t.head.ch==n&&t.head.line<e.lastLine()?{from:t.head,to:et(t.head.line+1,0)}:{from:t.head,to:et(t.head.line,n)}}return{from:t.from(),to:t.to()}}))},deleteLine:function(e){return Qo(e,(function(t){return{from:et(t.from().line,0),to:st(e.doc,et(t.to().line+1,0))}}))},delLineLeft:function(e){return Qo(e,(function(e){return{from:et(e.from().line,0),to:e.from()}}))},delWrappedLineLeft:function(e){return Qo(e,(function(t){var n=e.charCoords(t.head,"div").top+5;return{from:e.coordsChar({left:0,top:n},"div"),to:t.from()}}))},delWrappedLineRight:function(e){return Qo(e,(function(t){var n=e.charCoords(t.head,"div").top+5,r=e.coordsChar({left:e.display.lineDiv.offsetWidth+100,top:n},"div");return{from:t.from(),to:r}}))},undo:function(e){return e.undo()},redo:function(e){return e.redo()},undoSelection:function(e){return e.undoSelection()},redoSelection:function(e){return e.redoSelection()},goDocStart:function(e){return e.extendSelection(et(e.firstLine(),0))},goDocEnd:function(e){return e.extendSelection(et(e.lastLine()))},goLineStart:function(e){return e.extendSelectionsBy((function(t){return na(e,t.head.line)}),{origin:"+move",bias:1})},goLineStartSmart:function(e){return e.extendSelectionsBy((function(t){return ra(e,t.head)}),{origin:"+move",bias:1})},goLineEnd:function(e){return e.extendSelectionsBy((function(t){return function(e,t){var n=Ge(e.doc,t),r=function(e){for(var t;t=jt(e);)e=t.find(1,!0).line;return e}(n);return r!=n&&(t=Je(r)),ea(!0,e,n,t,-1)}(e,t.head.line)}),{origin:"+move",bias:-1})},goLineRight:function(e){return e.extendSelectionsBy((function(t){var n=e.cursorCoords(t.head,"div").top+5;return e.coordsChar({left:e.display.lineDiv.offsetWidth+100,top:n},"div")}),U)},goLineLeft:function(e){return e.extendSelectionsBy((function(t){var n=e.cursorCoords(t.head,"div").top+5;return e.coordsChar({left:0,top:n},"div")}),U)},goLineLeftSmart:function(e){return e.extendSelectionsBy((function(t){var n=e.cursorCoords(t.head,"div").top+5,r=e.coordsChar({left:0,top:n},"div");return r.ch<e.getLine(r.line).search(/\S/)?ra(e,t.head):r}),U)},goLineUp:function(e){return e.moveV(-1,"line")},goLineDown:function(e){return e.moveV(1,"line")},goPageUp:function(e){return e.moveV(-1,"page")},goPageDown:function(e){return e.moveV(1,"page")},goCharLeft:function(e){return e.moveH(-1,"char")},goCharRight:function(e){return e.moveH(1,"char")},goColumnLeft:function(e){return e.moveH(-1,"column")},goColumnRight:function(e){return e.moveH(1,"column")},goWordLeft:function(e){return e.moveH(-1,"word")},goGroupRight:function(e){return e.moveH(1,"group")},goGroupLeft:function(e){return e.moveH(-1,"group")},goWordRight:function(e){return e.moveH(1,"word")},delCharBefore:function(e){return e.deleteH(-1,"codepoint")},delCharAfter:function(e){return e.deleteH(1,"char")},delWordBefore:function(e){return e.deleteH(-1,"word")},delWordAfter:function(e){return e.deleteH(1,"word")},delGroupBefore:function(e){return e.deleteH(-1,"group")},delGroupAfter:function(e){return e.deleteH(1,"group")},indentAuto:function(e){return e.indentSelection("smart")},indentMore:function(e){return e.indentSelection("add")},indentLess:function(e){return e.indentSelection("subtract")},insertTab:function(e){return e.replaceSelection("\t")},insertSoftTab:function(e){for(var t=[],n=e.listSelections(),r=e.options.tabSize,i=0;i<n.length;i++){var o=n[i].from(),a=R(e.getLine(o.line),o.ch,r);t.push(q(r-a%r))}e.replaceSelections(t)},defaultTab:function(e){e.somethingSelected()?e.indentSelection("add"):e.execCommand("insertTab")},transposeChars:function(e){return $r(e,(function(){for(var t=e.listSelections(),n=[],r=0;r<t.length;r++)if(t[r].empty()){var i=t[r].head,o=Ge(e.doc,i.line).text;if(o)if(i.ch==o.length&&(i=new et(i.line,i.ch-1)),i.ch>0)i=new et(i.line,i.ch+1),e.replaceRange(o.charAt(i.ch-1)+o.charAt(i.ch-2),et(i.line,i.ch-2),i,"+transpose");else if(i.line>e.doc.first){var a=Ge(e.doc,i.line-1).text;a&&(i=new et(i.line,1),e.replaceRange(o.charAt(0)+e.doc.lineSeparator()+a.charAt(a.length-1),et(i.line-1,a.length-1),i,"+transpose"))}n.push(new Ai(i,i))}e.setSelections(n)}))},newlineAndIndent:function(e){return $r(e,(function(){for(var t=e.listSelections(),n=t.length-1;n>=0;n--)e.replaceRange(e.doc.lineSeparator(),t[n].anchor,t[n].head,"+input");t=e.listSelections();for(var r=0;r<t.length;r++)e.indentLine(t[r].from().line,null,!0);Ir(e)}))},openLine:function(e){return e.replaceSelection("\n","start")},toggleOverwrite:function(e){return e.toggleOverwrite()}};function na(e,t){var n=Ge(e.doc,t),r=Rt(n);return r!=n&&(t=Je(r)),ea(!0,e,r,t,1)}function ra(e,t){var n=na(e,t.line),r=Ge(e.doc,n.line),i=ce(r,e.doc.direction);if(!i||0==i[0].level){var o=Math.max(n.ch,r.text.search(/\S/)),a=t.line==n.line&&t.ch<=o&&t.ch;return et(n.line,a?0:o,n.sticky)}return n}function ia(e,t,n){if("string"==typeof t&&!(t=ta[t]))return!1;e.display.input.ensurePolled();var r=e.display.shift,i=!1;try{e.isReadOnly()&&(e.state.suppressEdits=!0),n&&(e.display.shift=!1),i=t(e)!=F}finally{e.display.shift=r,e.state.suppressEdits=!1}return i}var oa=new B;function aa(e,t,n,r){var i=e.state.keySeq;if(i){if(qo(t))return"handled";if(/\'$/.test(t)?e.state.keySeq=null:oa.set(50,(function(){e.state.keySeq==i&&(e.state.keySeq=null,e.display.input.reset())})),sa(e,i+" "+t,n,r))return!0}return sa(e,t,n,r)}function sa(e,t,n,r){var i=function(e,t,n){for(var r=0;r<e.state.keyMaps.length;r++){var i=Go(t,e.state.keyMaps[r],n,e);if(i)return i}return e.options.extraKeys&&Go(t,e.options.extraKeys,n,e)||Go(t,e.options.keyMap,n,e)}(e,t,r);return"multi"==i&&(e.state.keySeq=t),"handled"==i&&ln(e,"keyHandled",e,t,n),"handled"!=i&&"multi"!=i||(_e(n),Mr(e)),!!i}function la(e,t){var n=Xo(t,!0);return!!n&&(t.shiftKey&&!e.state.keySeq?aa(e,"Shift-"+n,t,(function(t){return ia(e,t,!0)}))||aa(e,n,t,(function(t){if("string"==typeof t?/^go[A-Z]/.test(t):t.motion)return ia(e,t)})):aa(e,n,t,(function(t){return ia(e,t)})))}var ca=null;function ua(e){var t=this;if(!(e.target&&e.target!=t.display.input.getField()||(t.curOp.focus=k(),me(t,e)))){a&&s<11&&27==e.keyCode&&(e.returnValue=!1);var r=e.keyCode;t.display.shift=16==r||e.shiftKey;var i=la(t,e);d&&(ca=i?r:null,i||88!=r||De||!(y?e.metaKey:e.ctrlKey)||t.replaceSelection("",null,"cut")),n&&!y&&!i&&46==r&&e.shiftKey&&!e.ctrlKey&&document.execCommand&&document.execCommand("cut"),18!=r||/\bCodeMirror-crosshair\b/.test(t.display.lineDiv.className)||function(e){var t=e.display.lineDiv;function n(e){18!=e.keyCode&&e.altKey||(E(t,"CodeMirror-crosshair"),pe(document,"keyup",n),pe(document,"mouseover",n))}D(t,"CodeMirror-crosshair"),de(document,"keyup",n),de(document,"mouseover",n)}(t)}}function da(e){16==e.keyCode&&(this.doc.sel.shift=!1),me(this,e)}function ha(e){var t=this;if(!(e.target&&e.target!=t.display.input.getField()||wn(t.display,e)||me(t,e)||e.ctrlKey&&!e.altKey||y&&e.metaKey)){var n=e.keyCode,r=e.charCode;if(d&&n==ca)return ca=null,void _e(e);if(!d||e.which&&!(e.which<10)||!la(t,e)){var i=String.fromCharCode(null==r?n:r);"\b"!=i&&(function(e,t,n){return aa(e,"'"+n+"'",t,(function(t){return ia(e,t,!0)}))}(t,e,i)||t.display.input.onKeyPress(e))}}}var pa,fa,ma=function(e,t,n){this.time=e,this.pos=t,this.button=n};function ga(e){var t=this,n=t.display;if(!(me(t,e)||n.activeTouch&&n.input.supportsTouch()))if(n.input.ensurePolled(),n.shift=e.shiftKey,wn(n,e))l||(n.scroller.draggable=!1,setTimeout((function(){return n.scroller.draggable=!0}),100));else if(!_a(t,e)){var r=cr(t,e),i=Ce(e),o=r?function(e,t){var n=+new Date;return fa&&fa.compare(n,e,t)?(pa=fa=null,"triple"):pa&&pa.compare(n,e,t)?(fa=new ma(n,e,t),pa=null,"double"):(pa=new ma(n,e,t),fa=null,"single")}(r,i):"single";window.focus(),1==i&&t.state.selectingText&&t.state.selectingText(e),r&&function(e,t,n,r,i){var o="Click";return"double"==r?o="Double"+o:"triple"==r&&(o="Triple"+o),aa(e,Ko(o=(1==t?"Left":2==t?"Middle":"Right")+o,i),i,(function(t){if("string"==typeof t&&(t=ta[t]),!t)return!1;var r=!1;try{e.isReadOnly()&&(e.state.suppressEdits=!0),r=t(e,n)!=F}finally{e.state.suppressEdits=!1}return r}))}(t,i,r,o,e)||(1==i?r?function(e,t,n,r){a?setTimeout(P(wr,e),0):e.curOp.focus=k();var i,o=function(e,t,n){var r=e.getOption("configureMouse"),i=r?r(e,t,n):{};if(null==i.unit){var o=_?n.shiftKey&&n.metaKey:n.altKey;i.unit=o?"rectangle":"single"==t?"char":"double"==t?"word":"line"}return(null==i.extend||e.doc.extend)&&(i.extend=e.doc.extend||n.shiftKey),null==i.addNew&&(i.addNew=y?n.metaKey:n.ctrlKey),null==i.moveOnDrag&&(i.moveOnDrag=!(y?n.altKey:n.ctrlKey)),i}(e,n,r),c=e.doc.sel;e.options.dragDrop&&Le&&!e.isReadOnly()&&"single"==n&&(i=c.contains(t))>-1&&(tt((i=c.ranges[i]).from(),t)<0||t.xRel>0)&&(tt(i.to(),t)>0||t.xRel<0)?function(e,t,n,r){var i=e.display,o=!1,c=ei(e,(function(t){l&&(i.scroller.draggable=!1),e.state.draggingText=!1,e.state.delayingBlurEvent&&(e.hasFocus()?e.state.delayingBlurEvent=!1:Ar(e)),pe(i.wrapper.ownerDocument,"mouseup",c),pe(i.wrapper.ownerDocument,"mousemove",u),pe(i.scroller,"dragstart",d),pe(i.scroller,"drop",c),o||(_e(t),r.addNew||Ki(e.doc,n,null,null,r.extend),l&&!h||a&&9==s?setTimeout((function(){i.wrapper.ownerDocument.body.focus({preventScroll:!0}),i.input.focus()}),20):i.input.focus())})),u=function(e){o=o||Math.abs(t.clientX-e.clientX)+Math.abs(t.clientY-e.clientY)>=10},d=function(){return o=!0};l&&(i.scroller.draggable=!0),e.state.draggingText=c,c.copy=!r.moveOnDrag,de(i.wrapper.ownerDocument,"mouseup",c),de(i.wrapper.ownerDocument,"mousemove",u),de(i.scroller,"dragstart",d),de(i.scroller,"drop",c),e.state.delayingBlurEvent=!0,setTimeout((function(){return i.input.focus()}),20),i.scroller.dragDrop&&i.scroller.dragDrop()}(e,r,t,o):function(e,t,n,r){a&&Ar(e);var i=e.display,o=e.doc;_e(t);var s,l,c=o.sel,u=c.ranges;if(r.addNew&&!r.extend?(l=o.sel.contains(n),s=l>-1?u[l]:new Ai(n,n)):(s=o.sel.primary(),l=o.sel.primIndex),"rectangle"==r.unit)r.addNew||(s=new Ai(n,n)),n=cr(e,t,!0,!0),l=-1;else{var d=va(e,n,r.unit);s=r.extend?qi(s,d.anchor,d.head,r.extend):d}r.addNew?-1==l?(l=u.length,$i(o,Ci(e,u.concat([s]),l),{scroll:!1,origin:"*mouse"})):u.length>1&&u[l].empty()&&"char"==r.unit&&!r.extend?($i(o,Ci(e,u.slice(0,l).concat(u.slice(l+1)),0),{scroll:!1,origin:"*mouse"}),c=o.sel):Ji(o,l,s,V):(l=0,$i(o,new wi([s],0),V),c=o.sel);var h=n;function p(t){if(0!=tt(h,t))if(h=t,"rectangle"==r.unit){for(var i=[],a=e.options.tabSize,u=R(Ge(o,n.line).text,n.ch,a),d=R(Ge(o,t.line).text,t.ch,a),p=Math.min(u,d),f=Math.max(u,d),m=Math.min(n.line,t.line),g=Math.min(e.lastLine(),Math.max(n.line,t.line));m<=g;m++){var v=Ge(o,m).text,y=W(v,p,a);p==f?i.push(new Ai(et(m,y),et(m,y))):v.length>y&&i.push(new Ai(et(m,y),et(m,W(v,f,a))))}i.length||i.push(new Ai(n,n)),$i(o,Ci(e,c.ranges.slice(0,l).concat(i),l),{origin:"*mouse",scroll:!1}),e.scrollIntoView(t)}else{var _,b=s,M=va(e,t,r.unit),w=b.anchor;tt(M.anchor,w)>0?(_=M.head,w=ot(b.from(),M.anchor)):(_=M.anchor,w=it(b.to(),M.head));var A=c.ranges.slice(0);A[l]=function(e,t){var n=t.anchor,r=t.head,i=Ge(e.doc,n.line);if(0==tt(n,r)&&n.sticky==r.sticky)return t;var o=ce(i);if(!o)return t;var a=se(o,n.ch,n.sticky),s=o[a];if(s.from!=n.ch&&s.to!=n.ch)return t;var l,c=a+(s.from==n.ch==(1!=s.level)?0:1);if(0==c||c==o.length)return t;if(r.line!=n.line)l=(r.line-n.line)*("ltr"==e.doc.direction?1:-1)>0;else{var u=se(o,r.ch,r.sticky),d=u-a||(r.ch-n.ch)*(1==s.level?-1:1);l=u==c-1||u==c?d<0:d>0}var h=o[c+(l?-1:0)],p=l==(1==h.level),f=p?h.from:h.to,m=p?"after":"before";return n.ch==f&&n.sticky==m?t:new Ai(new et(n.line,f,m),r)}(e,new Ai(st(o,w),_)),$i(o,Ci(e,A,l),V)}}var f=i.wrapper.getBoundingClientRect(),m=0;function g(t){e.state.selectingText=!1,m=1/0,t&&(_e(t),i.input.focus()),pe(i.wrapper.ownerDocument,"mousemove",v),pe(i.wrapper.ownerDocument,"mouseup",y),o.history.lastSelOrigin=null}var v=ei(e,(function(t){0!==t.buttons&&Ce(t)?function t(n){var a=++m,s=cr(e,n,!0,"rectangle"==r.unit);if(s)if(0!=tt(s,h)){e.curOp.focus=k(),p(s);var l=Sr(i,o);(s.line>=l.to||s.line<l.from)&&setTimeout(ei(e,(function(){m==a&&t(n)})),150)}else{var c=n.clientY<f.top?-20:n.clientY>f.bottom?20:0;c&&setTimeout(ei(e,(function(){m==a&&(i.scroller.scrollTop+=c,t(n))})),50)}}(t):g(t)})),y=ei(e,g);e.state.selectingText=y,de(i.wrapper.ownerDocument,"mousemove",v),de(i.wrapper.ownerDocument,"mouseup",y)}(e,r,t,o)}(t,r,o,e):Ae(e)==n.scroller&&_e(e):2==i?(r&&Ki(t.doc,r),setTimeout((function(){return n.input.focus()}),20)):3==i&&(A?t.display.input.onContextMenu(e):Ar(t)))}}function va(e,t,n){if("char"==n)return new Ai(t,t);if("word"==n)return e.findWordAt(t);if("line"==n)return new Ai(et(t.line,0),st(e.doc,et(t.line+1,0)));var r=n(e,t);return new Ai(r.from,r.to)}function ya(e,t,n,r){var i,o;if(t.touches)i=t.touches[0].clientX,o=t.touches[0].clientY;else try{i=t.clientX,o=t.clientY}catch(e){return!1}if(i>=Math.floor(e.display.gutters.getBoundingClientRect().right))return!1;r&&_e(t);var a=e.display,s=a.lineDiv.getBoundingClientRect();if(o>s.bottom||!ve(e,n))return Me(t);o-=s.top-a.viewOffset;for(var l=0;l<e.display.gutterSpecs.length;++l){var c=a.gutters.childNodes[l];if(c&&c.getBoundingClientRect().right>=i)return fe(e,n,e,Qe(e.doc,o),e.display.gutterSpecs[l].className,t),Me(t)}}function _a(e,t){return ya(e,t,"gutterClick",!0)}function ba(e,t){wn(e.display,t)||function(e,t){return!!ve(e,"gutterContextMenu")&&ya(e,t,"gutterContextMenu",!1)}(e,t)||me(e,t,"contextmenu")||A||e.display.input.onContextMenu(t)}function Ma(e){e.display.wrapper.className=e.display.wrapper.className.replace(/\s*cm-s-\S+/g,"")+e.options.theme.replace(/(^|\s)\s*/g," cm-s-"),Hn(e)}ma.prototype.compare=function(e,t,n){return this.time+400>e&&0==tt(t,this.pos)&&n==this.button};var wa={toString:function(){return"CodeMirror.Init"}},Aa={},Ca={};function xa(e,t,n){if(!t!=!(n&&n!=wa)){var r=e.display.dragFunctions,i=t?de:pe;i(e.display.scroller,"dragstart",r.start),i(e.display.scroller,"dragenter",r.enter),i(e.display.scroller,"dragover",r.over),i(e.display.scroller,"dragleave",r.leave),i(e.display.scroller,"drop",r.drop)}}function Ea(e){e.options.lineWrapping?(D(e.display.wrapper,"CodeMirror-wrap"),e.display.sizer.style.minWidth="",e.display.sizerWidth=null):(E(e.display.wrapper,"CodeMirror-wrap"),Wt(e)),lr(e),dr(e),Hn(e),setTimeout((function(){return Fr(e)}),100)}function La(e,t){var n=this;if(!(this instanceof La))return new La(e,t);this.options=t=t?z(t):{},z(Aa,t,!1);var r=t.value;"string"==typeof r?r=new Io(r,t.mode,null,t.lineSeparator,t.direction):t.mode&&(r.modeOption=t.mode),this.doc=r;var i=new La.inputStyles[t.inputStyle](this),o=this.display=new gi(e,r,i,t);for(var c in o.wrapper.CodeMirror=this,Ma(this),t.lineWrapping&&(this.display.wrapper.className+=" CodeMirror-wrap"),Ur(this),this.state={keyMaps:[],overlays:[],modeGen:0,overwrite:!1,delayingBlurEvent:!1,focused:!1,suppressEdits:!1,pasteIncoming:-1,cutIncoming:-1,selectingText:!1,draggingText:!1,highlight:new B,keySeq:null,specialChars:null},t.autofocus&&!v&&o.input.focus(),a&&s<11&&setTimeout((function(){return n.display.input.reset(!0)}),20),function(e){var t=e.display;de(t.scroller,"mousedown",ei(e,ga)),de(t.scroller,"dblclick",a&&s<11?ei(e,(function(t){if(!me(e,t)){var n=cr(e,t);if(n&&!_a(e,t)&&!wn(e.display,t)){_e(t);var r=e.findWordAt(n);Ki(e.doc,r.anchor,r.head)}}})):function(t){return me(e,t)||_e(t)}),de(t.scroller,"contextmenu",(function(t){return ba(e,t)})),de(t.input.getField(),"contextmenu",(function(n){t.scroller.contains(n.target)||ba(e,n)}));var n,r={end:0};function i(){t.activeTouch&&(n=setTimeout((function(){return t.activeTouch=null}),1e3),(r=t.activeTouch).end=+new Date)}function o(e,t){if(null==t.left)return!0;var n=t.left-e.left,r=t.top-e.top;return n*n+r*r>400}de(t.scroller,"touchstart",(function(i){if(!me(e,i)&&!function(e){if(1!=e.touches.length)return!1;var t=e.touches[0];return t.radiusX<=1&&t.radiusY<=1}(i)&&!_a(e,i)){t.input.ensurePolled(),clearTimeout(n);var o=+new Date;t.activeTouch={start:o,moved:!1,prev:o-r.end<=300?r:null},1==i.touches.length&&(t.activeTouch.left=i.touches[0].pageX,t.activeTouch.top=i.touches[0].pageY)}})),de(t.scroller,"touchmove",(function(){t.activeTouch&&(t.activeTouch.moved=!0)})),de(t.scroller,"touchend",(function(n){var r=t.activeTouch;if(r&&!wn(t,n)&&null!=r.left&&!r.moved&&new Date-r.start<300){var a,s=e.coordsChar(t.activeTouch,"page");a=!r.prev||o(r,r.prev)?new Ai(s,s):!r.prev.prev||o(r,r.prev.prev)?e.findWordAt(s):new Ai(et(s.line,0),st(e.doc,et(s.line+1,0))),e.setSelection(a.anchor,a.head),e.focus(),_e(n)}i()})),de(t.scroller,"touchcancel",i),de(t.scroller,"scroll",(function(){t.scroller.clientHeight&&(jr(e,t.scroller.scrollTop),zr(e,t.scroller.scrollLeft,!0),fe(e,"scroll",e))})),de(t.scroller,"mousewheel",(function(t){return Mi(e,t)})),de(t.scroller,"DOMMouseScroll",(function(t){return Mi(e,t)})),de(t.wrapper,"scroll",(function(){return t.wrapper.scrollTop=t.wrapper.scrollLeft=0})),t.dragFunctions={enter:function(t){me(e,t)||we(t)},over:function(t){me(e,t)||(function(e,t){var n=cr(e,t);if(n){var r=document.createDocumentFragment();yr(e,n,r),e.display.dragCursor||(e.display.dragCursor=T("div",null,"CodeMirror-cursors CodeMirror-dragcursors"),e.display.lineSpace.insertBefore(e.display.dragCursor,e.display.cursorDiv)),S(e.display.dragCursor,r)}}(e,t),we(t))},start:function(t){return function(e,t){if(a&&(!e.state.draggingText||+new Date-ko<100))we(t);else if(!me(e,t)&&!wn(e.display,t)&&(t.dataTransfer.setData("Text",e.getSelection()),t.dataTransfer.effectAllowed="copyMove",t.dataTransfer.setDragImage&&!h)){var n=T("img",null,null,"position: fixed; left: 0; top: 0;");n.src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==",d&&(n.width=n.height=1,e.display.wrapper.appendChild(n),n._top=n.offsetTop),t.dataTransfer.setDragImage(n,0,0),d&&n.parentNode.removeChild(n)}}(e,t)},drop:ei(e,Do),leave:function(t){me(e,t)||No(e)}};var l=t.input.getField();de(l,"keyup",(function(t){return da.call(e,t)})),de(l,"keydown",ei(e,ua)),de(l,"keypress",ei(e,ha)),de(l,"focus",(function(t){return Cr(e,t)})),de(l,"blur",(function(t){return xr(e,t)}))}(this),zo(),Gr(this),this.curOp.forceUpdate=!0,ji(this,r),t.autofocus&&!v||this.hasFocus()?setTimeout((function(){n.hasFocus()&&!n.state.focused&&Cr(n)}),20):xr(this),Ca)Ca.hasOwnProperty(c)&&Ca[c](this,t[c],wa);hi(this),t.finishInit&&t.finishInit(this);for(var u=0;u<Sa.length;++u)Sa[u](this);qr(this),l&&t.lineWrapping&&"optimizelegibility"==getComputedStyle(o.lineDiv).textRendering&&(o.lineDiv.style.textRendering="auto")}La.defaults=Aa,La.optionHandlers=Ca;var Sa=[];function Ta(e,t,n,r){var i,o=e.doc;null==n&&(n="add"),"smart"==n&&(o.mode.indent?i=pt(e,t).state:n="prev");var a=e.options.tabSize,s=Ge(o,t),l=R(s.text,null,a);s.stateAfter&&(s.stateAfter=null);var c,u=s.text.match(/^\s*/)[0];if(r||/\S/.test(s.text)){if("smart"==n&&((c=o.mode.indent(i,s.text.slice(u.length),s.text))==F||c>150)){if(!r)return;n="prev"}}else c=0,n="not";"prev"==n?c=t>o.first?R(Ge(o,t-1).text,null,a):0:"add"==n?c=l+e.options.indentUnit:"subtract"==n?c=l-e.options.indentUnit:"number"==typeof n&&(c=l+n),c=Math.max(0,c);var d="",h=0;if(e.options.indentWithTabs)for(var p=Math.floor(c/a);p;--p)h+=a,d+="\t";if(h<c&&(d+=q(c-h)),d!=u)return mo(o,d,et(t,0),et(t,u.length),"+input"),s.stateAfter=null,!0;for(var f=0;f<o.sel.ranges.length;f++){var m=o.sel.ranges[f];if(m.head.line==t&&m.head.ch<u.length){var g=et(t,u.length);Ji(o,f,new Ai(g,g));break}}}La.defineInitHook=function(e){return Sa.push(e)};var Oa=null;function Ia(e){Oa=e}function ka(e,t,n,r,i){var o=e.doc;e.display.shift=!1,r||(r=o.sel);var a=+new Date-200,s="paste"==i||e.state.pasteIncoming>a,l=Ie(t),c=null;if(s&&r.ranges.length>1)if(Oa&&Oa.text.join("\n")==t){if(r.ranges.length%Oa.text.length==0){c=[];for(var u=0;u<Oa.text.length;u++)c.push(o.splitLines(Oa.text[u]))}}else l.length==r.ranges.length&&e.options.pasteLinesPerSelection&&(c=X(l,(function(e){return[e]})));for(var d=e.curOp.updateInput,h=r.ranges.length-1;h>=0;h--){var p=r.ranges[h],f=p.from(),m=p.to();p.empty()&&(n&&n>0?f=et(f.line,f.ch-n):e.state.overwrite&&!s?m=et(m.line,Math.min(Ge(o,m.line).text.length,m.ch+K(l).length)):s&&Oa&&Oa.lineWise&&Oa.text.join("\n")==l.join("\n")&&(f=m=et(f.line,0)));var g={from:f,to:m,text:c?c[h%c.length]:l,origin:i||(s?"paste":e.state.cutIncoming>a?"cut":"+input")};co(e.doc,g),ln(e,"inputRead",e,g)}t&&!s&&Na(e,t),Ir(e),e.curOp.updateInput<2&&(e.curOp.updateInput=d),e.curOp.typing=!0,e.state.pasteIncoming=e.state.cutIncoming=-1}function Da(e,t){var n=e.clipboardData&&e.clipboardData.getData("Text");if(n)return e.preventDefault(),t.isReadOnly()||t.options.disableInput||$r(t,(function(){return ka(t,n,0,null,"paste")})),!0}function Na(e,t){if(e.options.electricChars&&e.options.smartIndent)for(var n=e.doc.sel,r=n.ranges.length-1;r>=0;r--){var i=n.ranges[r];if(!(i.head.ch>100||r&&n.ranges[r-1].head.line==i.head.line)){var o=e.getModeAt(i.head),a=!1;if(o.electricChars){for(var s=0;s<o.electricChars.length;s++)if(t.indexOf(o.electricChars.charAt(s))>-1){a=Ta(e,i.head.line,"smart");break}}else o.electricInput&&o.electricInput.test(Ge(e.doc,i.head.line).text.slice(0,i.head.ch))&&(a=Ta(e,i.head.line,"smart"));a&&ln(e,"electricInput",e,i.head.line)}}}function ja(e){for(var t=[],n=[],r=0;r<e.doc.sel.ranges.length;r++){var i=e.doc.sel.ranges[r].head.line,o={anchor:et(i,0),head:et(i+1,0)};n.push(o),t.push(e.getRange(o.anchor,o.head))}return{text:t,ranges:n}}function Pa(e,t,n,r){e.setAttribute("autocorrect",n?"":"off"),e.setAttribute("autocapitalize",r?"":"off"),e.setAttribute("spellcheck",!!t)}function za(){var e=T("textarea",null,null,"position: absolute; bottom: -1em; padding: 0; width: 1px; height: 1em; outline: none"),t=T("div",[e],null,"overflow: hidden; position: relative; width: 3px; height: 0px;");return l?e.style.width="1000px":e.setAttribute("wrap","off"),m&&(e.style.border="1px solid black"),Pa(e),t}function Ra(e,t,n,r,i){var o=t,a=n,s=Ge(e,t.line),l=i&&"rtl"==e.direction?-n:n;function c(o){var a,c;if("codepoint"==r){var u=s.text.charCodeAt(t.ch+(n>0?0:-1));if(isNaN(u))a=null;else{var d=n>0?u>=55296&&u<56320:u>=56320&&u<57343;a=new et(t.line,Math.max(0,Math.min(s.text.length,t.ch+n*(d?2:1))),-n)}}else a=i?function(e,t,n,r){var i=ce(t,e.doc.direction);if(!i)return $o(t,n,r);n.ch>=t.text.length?(n.ch=t.text.length,n.sticky="before"):n.ch<=0&&(n.ch=0,n.sticky="after");var o=se(i,n.ch,n.sticky),a=i[o];if("ltr"==e.doc.direction&&a.level%2==0&&(r>0?a.to>n.ch:a.from<n.ch))return $o(t,n,r);var s,l=function(e,n){return Zo(t,e instanceof et?e.ch:e,n)},c=function(n){return e.options.lineWrapping?(s=s||kn(e,t),Zn(e,t,s,n)):{begin:0,end:t.text.length}},u=c("before"==n.sticky?l(n,-1):n.ch);if("rtl"==e.doc.direction||1==a.level){var d=1==a.level==r<0,h=l(n,d?1:-1);if(null!=h&&(d?h<=a.to&&h<=u.end:h>=a.from&&h>=u.begin)){var p=d?"before":"after";return new et(n.line,h,p)}}var f=function(e,t,r){for(var o=function(e,t){return t?new et(n.line,l(e,1),"before"):new et(n.line,e,"after")};e>=0&&e<i.length;e+=t){var a=i[e],s=t>0==(1!=a.level),c=s?r.begin:l(r.end,-1);if(a.from<=c&&c<a.to)return o(c,s);if(c=s?a.from:l(a.to,-1),r.begin<=c&&c<r.end)return o(c,s)}},m=f(o+r,r,u);if(m)return m;var g=r>0?u.end:l(u.begin,-1);return null==g||r>0&&g==t.text.length||!(m=f(r>0?0:i.length-1,r,c(g)))?null:m}(e.cm,s,t,n):$o(s,t,n);if(null==a){if(o||(c=t.line+l)<e.first||c>=e.first+e.size||(t=new et(c,t.ch,t.sticky),!(s=Ge(e,c))))return!1;t=ea(i,e.cm,s,t.line,l)}else t=a;return!0}if("char"==r||"codepoint"==r)c();else if("column"==r)c(!0);else if("word"==r||"group"==r)for(var u=null,d="group"==r,h=e.cm&&e.cm.getHelper(t,"wordChars"),p=!0;!(n<0)||c(!p);p=!1){var f=s.text.charAt(t.ch)||"\n",m=ee(f,h)?"w":d&&"\n"==f?"n":!d||/\s/.test(f)?null:"p";if(!d||p||m||(m="s"),u&&u!=m){n<0&&(n=1,c(),t.sticky="after");break}if(m&&(u=m),n>0&&!c(!p))break}var g=oo(e,t,o,a,!0);return nt(o,g)&&(g.hitSide=!0),g}function Ba(e,t,n,r){var i,o,a=e.doc,s=t.left;if("page"==r){var l=Math.min(e.display.wrapper.clientHeight,window.innerHeight||document.documentElement.clientHeight),c=Math.max(l-.5*rr(e.display),3);i=(n>0?t.bottom:t.top)+n*c}else"line"==r&&(i=n>0?t.bottom+3:t.top-3);for(;(o=Jn(e,s,i)).outside;){if(n<0?i<=0:i>=a.height){o.hitSide=!0;break}i+=5*n}return o}var Ha=function(e){this.cm=e,this.lastAnchorNode=this.lastAnchorOffset=this.lastFocusNode=this.lastFocusOffset=null,this.polling=new B,this.composing=null,this.gracePeriod=!1,this.readDOMTimeout=null};function Fa(e,t){var n=In(e,t.line);if(!n||n.hidden)return null;var r=Ge(e.doc,t.line),i=Tn(n,r,t.line),o=ce(r,e.doc.direction),a="left";o&&(a=se(o,t.ch)%2?"right":"left");var s=Pn(i.map,t.ch,a);return s.offset="right"==s.collapse?s.end:s.start,s}function Ya(e,t){return t&&(e.bad=!0),e}function Va(e,t,n){var r;if(t==e.display.lineDiv){if(!(r=e.display.lineDiv.childNodes[n]))return Ya(e.clipPos(et(e.display.viewTo-1)),!0);t=null,n=0}else for(r=t;;r=r.parentNode){if(!r||r==e.display.lineDiv)return null;if(r.parentNode&&r.parentNode==e.display.lineDiv)break}for(var i=0;i<e.display.view.length;i++){var o=e.display.view[i];if(o.node==r)return Ua(o,t,n)}}function Ua(e,t,n){var r=e.text.firstChild,i=!1;if(!t||!I(r,t))return Ya(et(Je(e.line),0),!0);if(t==r&&(i=!0,t=r.childNodes[n],n=0,!t)){var o=e.rest?K(e.rest):e.line;return Ya(et(Je(o),o.text.length),i)}var a=3==t.nodeType?t:null,s=t;for(a||1!=t.childNodes.length||3!=t.firstChild.nodeType||(a=t.firstChild,n&&(n=a.nodeValue.length));s.parentNode!=r;)s=s.parentNode;var l=e.measure,c=l.maps;function u(t,n,r){for(var i=-1;i<(c?c.length:0);i++)for(var o=i<0?l.map:c[i],a=0;a<o.length;a+=3){var s=o[a+2];if(s==t||s==n){var u=Je(i<0?e.line:e.rest[i]),d=o[a]+r;return(r<0||s!=t)&&(d=o[a+(r?1:0)]),et(u,d)}}}var d=u(a,s,n);if(d)return Ya(d,i);for(var h=s.nextSibling,p=a?a.nodeValue.length-n:0;h;h=h.nextSibling){if(d=u(h,h.firstChild,0))return Ya(et(d.line,d.ch-p),i);p+=h.textContent.length}for(var f=s.previousSibling,m=n;f;f=f.previousSibling){if(d=u(f,f.firstChild,-1))return Ya(et(d.line,d.ch+m),i);m+=f.textContent.length}}Ha.prototype.init=function(e){var t=this,n=this,r=n.cm,i=n.div=e.lineDiv;function o(e){for(var t=e.target;t;t=t.parentNode){if(t==i)return!0;if(/\bCodeMirror-(?:line)?widget\b/.test(t.className))break}return!1}function a(e){if(o(e)&&!me(r,e)){if(r.somethingSelected())Ia({lineWise:!1,text:r.getSelections()}),"cut"==e.type&&r.replaceSelection("",null,"cut");else{if(!r.options.lineWiseCopyCut)return;var t=ja(r);Ia({lineWise:!0,text:t.text}),"cut"==e.type&&r.operation((function(){r.setSelections(t.ranges,0,Y),r.replaceSelection("",null,"cut")}))}if(e.clipboardData){e.clipboardData.clearData();var a=Oa.text.join("\n");if(e.clipboardData.setData("Text",a),e.clipboardData.getData("Text")==a)return void e.preventDefault()}var s=za(),l=s.firstChild;r.display.lineSpace.insertBefore(s,r.display.lineSpace.firstChild),l.value=Oa.text.join("\n");var c=k();j(l),setTimeout((function(){r.display.lineSpace.removeChild(s),c.focus(),c==i&&n.showPrimarySelection()}),50)}}i.contentEditable=!0,Pa(i,r.options.spellcheck,r.options.autocorrect,r.options.autocapitalize),de(i,"paste",(function(e){!o(e)||me(r,e)||Da(e,r)||s<=11&&setTimeout(ei(r,(function(){return t.updateFromDOM()})),20)})),de(i,"compositionstart",(function(e){t.composing={data:e.data,done:!1}})),de(i,"compositionupdate",(function(e){t.composing||(t.composing={data:e.data,done:!1})})),de(i,"compositionend",(function(e){t.composing&&(e.data!=t.composing.data&&t.readFromDOMSoon(),t.composing.done=!0)})),de(i,"touchstart",(function(){return n.forceCompositionEnd()})),de(i,"input",(function(){t.composing||t.readFromDOMSoon()})),de(i,"copy",a),de(i,"cut",a)},Ha.prototype.screenReaderLabelChanged=function(e){e?this.div.setAttribute("aria-label",e):this.div.removeAttribute("aria-label")},Ha.prototype.prepareSelection=function(){var e=vr(this.cm,!1);return e.focus=k()==this.div,e},Ha.prototype.showSelection=function(e,t){e&&this.cm.display.view.length&&((e.focus||t)&&this.showPrimarySelection(),this.showMultipleSelections(e))},Ha.prototype.getSelection=function(){return this.cm.display.wrapper.ownerDocument.getSelection()},Ha.prototype.showPrimarySelection=function(){var e=this.getSelection(),t=this.cm,r=t.doc.sel.primary(),i=r.from(),o=r.to();if(t.display.viewTo==t.display.viewFrom||i.line>=t.display.viewTo||o.line<t.display.viewFrom)e.removeAllRanges();else{var a=Va(t,e.anchorNode,e.anchorOffset),s=Va(t,e.focusNode,e.focusOffset);if(!a||a.bad||!s||s.bad||0!=tt(ot(a,s),i)||0!=tt(it(a,s),o)){var l=t.display.view,c=i.line>=t.display.viewFrom&&Fa(t,i)||{node:l[0].measure.map[2],offset:0},u=o.line<t.display.viewTo&&Fa(t,o);if(!u){var d=l[l.length-1].measure,h=d.maps?d.maps[d.maps.length-1]:d.map;u={node:h[h.length-1],offset:h[h.length-2]-h[h.length-3]}}if(c&&u){var p,f=e.rangeCount&&e.getRangeAt(0);try{p=x(c.node,c.offset,u.offset,u.node)}catch(e){}p&&(!n&&t.state.focused?(e.collapse(c.node,c.offset),p.collapsed||(e.removeAllRanges(),e.addRange(p))):(e.removeAllRanges(),e.addRange(p)),f&&null==e.anchorNode?e.addRange(f):n&&this.startGracePeriod()),this.rememberSelection()}else e.removeAllRanges()}}},Ha.prototype.startGracePeriod=function(){var e=this;clearTimeout(this.gracePeriod),this.gracePeriod=setTimeout((function(){e.gracePeriod=!1,e.selectionChanged()&&e.cm.operation((function(){return e.cm.curOp.selectionChanged=!0}))}),20)},Ha.prototype.showMultipleSelections=function(e){S(this.cm.display.cursorDiv,e.cursors),S(this.cm.display.selectionDiv,e.selection)},Ha.prototype.rememberSelection=function(){var e=this.getSelection();this.lastAnchorNode=e.anchorNode,this.lastAnchorOffset=e.anchorOffset,this.lastFocusNode=e.focusNode,this.lastFocusOffset=e.focusOffset},Ha.prototype.selectionInEditor=function(){var e=this.getSelection();if(!e.rangeCount)return!1;var t=e.getRangeAt(0).commonAncestorContainer;return I(this.div,t)},Ha.prototype.focus=function(){"nocursor"!=this.cm.options.readOnly&&(this.selectionInEditor()&&k()==this.div||this.showSelection(this.prepareSelection(),!0),this.div.focus())},Ha.prototype.blur=function(){this.div.blur()},Ha.prototype.getField=function(){return this.div},Ha.prototype.supportsTouch=function(){return!0},Ha.prototype.receivedFocus=function(){var e=this;this.selectionInEditor()?this.pollSelection():$r(this.cm,(function(){return e.cm.curOp.selectionChanged=!0})),this.polling.set(this.cm.options.pollInterval,(function t(){e.cm.state.focused&&(e.pollSelection(),e.polling.set(e.cm.options.pollInterval,t))}))},Ha.prototype.selectionChanged=function(){var e=this.getSelection();return e.anchorNode!=this.lastAnchorNode||e.anchorOffset!=this.lastAnchorOffset||e.focusNode!=this.lastFocusNode||e.focusOffset!=this.lastFocusOffset},Ha.prototype.pollSelection=function(){if(null==this.readDOMTimeout&&!this.gracePeriod&&this.selectionChanged()){var e=this.getSelection(),t=this.cm;if(g&&u&&this.cm.display.gutterSpecs.length&&function(e){for(var t=e;t;t=t.parentNode)if(/CodeMirror-gutter-wrapper/.test(t.className))return!0;return!1}(e.anchorNode))return this.cm.triggerOnKeyDown({type:"keydown",keyCode:8,preventDefault:Math.abs}),this.blur(),void this.focus();if(!this.composing){this.rememberSelection();var n=Va(t,e.anchorNode,e.anchorOffset),r=Va(t,e.focusNode,e.focusOffset);n&&r&&$r(t,(function(){$i(t.doc,xi(n,r),Y),(n.bad||r.bad)&&(t.curOp.selectionChanged=!0)}))}}},Ha.prototype.pollContent=function(){null!=this.readDOMTimeout&&(clearTimeout(this.readDOMTimeout),this.readDOMTimeout=null);var e,t,n,r=this.cm,i=r.display,o=r.doc.sel.primary(),a=o.from(),s=o.to();if(0==a.ch&&a.line>r.firstLine()&&(a=et(a.line-1,Ge(r.doc,a.line-1).length)),s.ch==Ge(r.doc,s.line).text.length&&s.line<r.lastLine()&&(s=et(s.line+1,0)),a.line<i.viewFrom||s.line>i.viewTo-1)return!1;a.line==i.viewFrom||0==(e=ur(r,a.line))?(t=Je(i.view[0].line),n=i.view[0].node):(t=Je(i.view[e].line),n=i.view[e-1].node.nextSibling);var l,c,u=ur(r,s.line);if(u==i.view.length-1?(l=i.viewTo-1,c=i.lineDiv.lastChild):(l=Je(i.view[u+1].line)-1,c=i.view[u+1].node.previousSibling),!n)return!1;for(var d=r.doc.splitLines(function(e,t,n,r,i){var o="",a=!1,s=e.doc.lineSeparator(),l=!1;function c(){a&&(o+=s,l&&(o+=s),a=l=!1)}function u(e){e&&(c(),o+=e)}function d(t){if(1==t.nodeType){var n=t.getAttribute("cm-text");if(n)return void u(n);var o,h=t.getAttribute("cm-marker");if(h){var p=e.findMarks(et(r,0),et(i+1,0),(g=+h,function(e){return e.id==g}));return void(p.length&&(o=p[0].find(0))&&u(qe(e.doc,o.from,o.to).join(s)))}if("false"==t.getAttribute("contenteditable"))return;var f=/^(pre|div|p|li|table|br)$/i.test(t.nodeName);if(!/^br$/i.test(t.nodeName)&&0==t.textContent.length)return;f&&c();for(var m=0;m<t.childNodes.length;m++)d(t.childNodes[m]);/^(pre|p)$/i.test(t.nodeName)&&(l=!0),f&&(a=!0)}else 3==t.nodeType&&u(t.nodeValue.replace(/\u200b/g,"").replace(/\u00a0/g," "));var g}for(;d(t),t!=n;)t=t.nextSibling,l=!1;return o}(r,n,c,t,l)),h=qe(r.doc,et(t,0),et(l,Ge(r.doc,l).text.length));d.length>1&&h.length>1;)if(K(d)==K(h))d.pop(),h.pop(),l--;else{if(d[0]!=h[0])break;d.shift(),h.shift(),t++}for(var p=0,f=0,m=d[0],g=h[0],v=Math.min(m.length,g.length);p<v&&m.charCodeAt(p)==g.charCodeAt(p);)++p;for(var y=K(d),_=K(h),b=Math.min(y.length-(1==d.length?p:0),_.length-(1==h.length?p:0));f<b&&y.charCodeAt(y.length-f-1)==_.charCodeAt(_.length-f-1);)++f;if(1==d.length&&1==h.length&&t==a.line)for(;p&&p>a.ch&&y.charCodeAt(y.length-f-1)==_.charCodeAt(_.length-f-1);)p--,f++;d[d.length-1]=y.slice(0,y.length-f).replace(/^\u200b+/,""),d[0]=d[0].slice(p).replace(/\u200b+$/,"");var M=et(t,p),w=et(l,h.length?K(h).length-f:0);return d.length>1||d[0]||tt(M,w)?(mo(r.doc,d,M,w,"+input"),!0):void 0},Ha.prototype.ensurePolled=function(){this.forceCompositionEnd()},Ha.prototype.reset=function(){this.forceCompositionEnd()},Ha.prototype.forceCompositionEnd=function(){this.composing&&(clearTimeout(this.readDOMTimeout),this.composing=null,this.updateFromDOM(),this.div.blur(),this.div.focus())},Ha.prototype.readFromDOMSoon=function(){var e=this;null==this.readDOMTimeout&&(this.readDOMTimeout=setTimeout((function(){if(e.readDOMTimeout=null,e.composing){if(!e.composing.done)return;e.composing=null}e.updateFromDOM()}),80))},Ha.prototype.updateFromDOM=function(){var e=this;!this.cm.isReadOnly()&&this.pollContent()||$r(this.cm,(function(){return dr(e.cm)}))},Ha.prototype.setUneditable=function(e){e.contentEditable="false"},Ha.prototype.onKeyPress=function(e){0==e.charCode||this.composing||(e.preventDefault(),this.cm.isReadOnly()||ei(this.cm,ka)(this.cm,String.fromCharCode(null==e.charCode?e.keyCode:e.charCode),0))},Ha.prototype.readOnlyChanged=function(e){this.div.contentEditable=String("nocursor"!=e)},Ha.prototype.onContextMenu=function(){},Ha.prototype.resetPosition=function(){},Ha.prototype.needsContentAttribute=!0;var Wa=function(e){this.cm=e,this.prevInput="",this.pollingFast=!1,this.polling=new B,this.hasSelection=!1,this.composing=null};Wa.prototype.init=function(e){var t=this,n=this,r=this.cm;this.createField(e);var i=this.textarea;function o(e){if(!me(r,e)){if(r.somethingSelected())Ia({lineWise:!1,text:r.getSelections()});else{if(!r.options.lineWiseCopyCut)return;var t=ja(r);Ia({lineWise:!0,text:t.text}),"cut"==e.type?r.setSelections(t.ranges,null,Y):(n.prevInput="",i.value=t.text.join("\n"),j(i))}"cut"==e.type&&(r.state.cutIncoming=+new Date)}}e.wrapper.insertBefore(this.wrapper,e.wrapper.firstChild),m&&(i.style.width="0px"),de(i,"input",(function(){a&&s>=9&&t.hasSelection&&(t.hasSelection=null),n.poll()})),de(i,"paste",(function(e){me(r,e)||Da(e,r)||(r.state.pasteIncoming=+new Date,n.fastPoll())})),de(i,"cut",o),de(i,"copy",o),de(e.scroller,"paste",(function(t){if(!wn(e,t)&&!me(r,t)){if(!i.dispatchEvent)return r.state.pasteIncoming=+new Date,void n.focus();var o=new Event("paste");o.clipboardData=t.clipboardData,i.dispatchEvent(o)}})),de(e.lineSpace,"selectstart",(function(t){wn(e,t)||_e(t)})),de(i,"compositionstart",(function(){var e=r.getCursor("from");n.composing&&n.composing.range.clear(),n.composing={start:e,range:r.markText(e,r.getCursor("to"),{className:"CodeMirror-composing"})}})),de(i,"compositionend",(function(){n.composing&&(n.poll(),n.composing.range.clear(),n.composing=null)}))},Wa.prototype.createField=function(e){this.wrapper=za(),this.textarea=this.wrapper.firstChild},Wa.prototype.screenReaderLabelChanged=function(e){e?this.textarea.setAttribute("aria-label",e):this.textarea.removeAttribute("aria-label")},Wa.prototype.prepareSelection=function(){var e=this.cm,t=e.display,n=e.doc,r=vr(e);if(e.options.moveInputWithCursor){var i=qn(e,n.sel.primary().head,"div"),o=t.wrapper.getBoundingClientRect(),a=t.lineDiv.getBoundingClientRect();r.teTop=Math.max(0,Math.min(t.wrapper.clientHeight-10,i.top+a.top-o.top)),r.teLeft=Math.max(0,Math.min(t.wrapper.clientWidth-10,i.left+a.left-o.left))}return r},Wa.prototype.showSelection=function(e){var t=this.cm.display;S(t.cursorDiv,e.cursors),S(t.selectionDiv,e.selection),null!=e.teTop&&(this.wrapper.style.top=e.teTop+"px",this.wrapper.style.left=e.teLeft+"px")},Wa.prototype.reset=function(e){if(!this.contextMenuPending&&!this.composing){var t=this.cm;if(t.somethingSelected()){this.prevInput="";var n=t.getSelection();this.textarea.value=n,t.state.focused&&j(this.textarea),a&&s>=9&&(this.hasSelection=n)}else e||(this.prevInput=this.textarea.value="",a&&s>=9&&(this.hasSelection=null))}},Wa.prototype.getField=function(){return this.textarea},Wa.prototype.supportsTouch=function(){return!1},Wa.prototype.focus=function(){if("nocursor"!=this.cm.options.readOnly&&(!v||k()!=this.textarea))try{this.textarea.focus()}catch(e){}},Wa.prototype.blur=function(){this.textarea.blur()},Wa.prototype.resetPosition=function(){this.wrapper.style.top=this.wrapper.style.left=0},Wa.prototype.receivedFocus=function(){this.slowPoll()},Wa.prototype.slowPoll=function(){var e=this;this.pollingFast||this.polling.set(this.cm.options.pollInterval,(function(){e.poll(),e.cm.state.focused&&e.slowPoll()}))},Wa.prototype.fastPoll=function(){var e=!1,t=this;t.pollingFast=!0,t.polling.set(20,(function n(){t.poll()||e?(t.pollingFast=!1,t.slowPoll()):(e=!0,t.polling.set(60,n))}))},Wa.prototype.poll=function(){var e=this,t=this.cm,n=this.textarea,r=this.prevInput;if(this.contextMenuPending||!t.state.focused||ke(n)&&!r&&!this.composing||t.isReadOnly()||t.options.disableInput||t.state.keySeq)return!1;var i=n.value;if(i==r&&!t.somethingSelected())return!1;if(a&&s>=9&&this.hasSelection===i||y&&/[\uf700-\uf7ff]/.test(i))return t.display.input.reset(),!1;if(t.doc.sel==t.display.selForContextMenu){var o=i.charCodeAt(0);if(8203!=o||r||(r="​"),8666==o)return this.reset(),this.cm.execCommand("undo")}for(var l=0,c=Math.min(r.length,i.length);l<c&&r.charCodeAt(l)==i.charCodeAt(l);)++l;return $r(t,(function(){ka(t,i.slice(l),r.length-l,null,e.composing?"*compose":null),i.length>1e3||i.indexOf("\n")>-1?n.value=e.prevInput="":e.prevInput=i,e.composing&&(e.composing.range.clear(),e.composing.range=t.markText(e.composing.start,t.getCursor("to"),{className:"CodeMirror-composing"}))})),!0},Wa.prototype.ensurePolled=function(){this.pollingFast&&this.poll()&&(this.pollingFast=!1)},Wa.prototype.onKeyPress=function(){a&&s>=9&&(this.hasSelection=null),this.fastPoll()},Wa.prototype.onContextMenu=function(e){var t=this,n=t.cm,r=n.display,i=t.textarea;t.contextMenuPending&&t.contextMenuPending();var o=cr(n,e),c=r.scroller.scrollTop;if(o&&!d){n.options.resetSelectionOnContextMenu&&-1==n.doc.sel.contains(o)&&ei(n,$i)(n.doc,xi(o),Y);var u,h=i.style.cssText,p=t.wrapper.style.cssText,f=t.wrapper.offsetParent.getBoundingClientRect();if(t.wrapper.style.cssText="position: static",i.style.cssText="position: absolute; width: 30px; height: 30px;\n      top: "+(e.clientY-f.top-5)+"px; left: "+(e.clientX-f.left-5)+"px;\n      z-index: 1000; background: "+(a?"rgba(255, 255, 255, .05)":"transparent")+";\n      outline: none; border-width: 0; outline: none; overflow: hidden; opacity: .05; filter: alpha(opacity=5);",l&&(u=window.scrollY),r.input.focus(),l&&window.scrollTo(null,u),r.input.reset(),n.somethingSelected()||(i.value=t.prevInput=" "),t.contextMenuPending=v,r.selForContextMenu=n.doc.sel,clearTimeout(r.detectingSelectAll),a&&s>=9&&g(),A){we(e);var m=function(){pe(window,"mouseup",m),setTimeout(v,20)};de(window,"mouseup",m)}else setTimeout(v,50)}function g(){if(null!=i.selectionStart){var e=n.somethingSelected(),o="​"+(e?i.value:"");i.value="⇚",i.value=o,t.prevInput=e?"":"​",i.selectionStart=1,i.selectionEnd=o.length,r.selForContextMenu=n.doc.sel}}function v(){if(t.contextMenuPending==v&&(t.contextMenuPending=!1,t.wrapper.style.cssText=p,i.style.cssText=h,a&&s<9&&r.scrollbars.setScrollTop(r.scroller.scrollTop=c),null!=i.selectionStart)){(!a||a&&s<9)&&g();var e=0,o=function(){r.selForContextMenu==n.doc.sel&&0==i.selectionStart&&i.selectionEnd>0&&"​"==t.prevInput?ei(n,so)(n):e++<10?r.detectingSelectAll=setTimeout(o,500):(r.selForContextMenu=null,r.input.reset())};r.detectingSelectAll=setTimeout(o,200)}}},Wa.prototype.readOnlyChanged=function(e){e||this.reset(),this.textarea.disabled="nocursor"==e,this.textarea.readOnly=!!e},Wa.prototype.setUneditable=function(){},Wa.prototype.needsContentAttribute=!1,function(e){var t=e.optionHandlers;function n(n,r,i,o){e.defaults[n]=r,i&&(t[n]=o?function(e,t,n){n!=wa&&i(e,t,n)}:i)}e.defineOption=n,e.Init=wa,n("value","",(function(e,t){return e.setValue(t)}),!0),n("mode",null,(function(e,t){e.doc.modeOption=t,Oi(e)}),!0),n("indentUnit",2,Oi,!0),n("indentWithTabs",!1),n("smartIndent",!0),n("tabSize",4,(function(e){Ii(e),Hn(e),dr(e)}),!0),n("lineSeparator",null,(function(e,t){if(e.doc.lineSep=t,t){var n=[],r=e.doc.first;e.doc.iter((function(e){for(var i=0;;){var o=e.text.indexOf(t,i);if(-1==o)break;i=o+t.length,n.push(et(r,o))}r++}));for(var i=n.length-1;i>=0;i--)mo(e.doc,t,n[i],et(n[i].line,n[i].ch+t.length))}})),n("specialChars",/[\u0000-\u001f\u007f-\u009f\u00ad\u061c\u200b\u200e\u200f\u2028\u2029\ufeff\ufff9-\ufffc]/g,(function(e,t,n){e.state.specialChars=new RegExp(t.source+(t.test("\t")?"":"|\t"),"g"),n!=wa&&e.refresh()})),n("specialCharPlaceholder",Zt,(function(e){return e.refresh()}),!0),n("electricChars",!0),n("inputStyle",v?"contenteditable":"textarea",(function(){throw new Error("inputStyle can not (yet) be changed in a running editor")}),!0),n("spellcheck",!1,(function(e,t){return e.getInputField().spellcheck=t}),!0),n("autocorrect",!1,(function(e,t){return e.getInputField().autocorrect=t}),!0),n("autocapitalize",!1,(function(e,t){return e.getInputField().autocapitalize=t}),!0),n("rtlMoveVisually",!b),n("wholeLineUpdateBefore",!0),n("theme","default",(function(e){Ma(e),mi(e)}),!0),n("keyMap","default",(function(e,t,n){var r=Jo(t),i=n!=wa&&Jo(n);i&&i.detach&&i.detach(e,r),r.attach&&r.attach(e,i||null)})),n("extraKeys",null),n("configureMouse",null),n("lineWrapping",!1,Ea,!0),n("gutters",[],(function(e,t){e.display.gutterSpecs=pi(t,e.options.lineNumbers),mi(e)}),!0),n("fixedGutter",!0,(function(e,t){e.display.gutters.style.left=t?ar(e.display)+"px":"0",e.refresh()}),!0),n("coverGutterNextToScrollbar",!1,(function(e){return Fr(e)}),!0),n("scrollbarStyle","native",(function(e){Ur(e),Fr(e),e.display.scrollbars.setScrollTop(e.doc.scrollTop),e.display.scrollbars.setScrollLeft(e.doc.scrollLeft)}),!0),n("lineNumbers",!1,(function(e,t){e.display.gutterSpecs=pi(e.options.gutters,t),mi(e)}),!0),n("firstLineNumber",1,mi,!0),n("lineNumberFormatter",(function(e){return e}),mi,!0),n("showCursorWhenSelecting",!1,gr,!0),n("resetSelectionOnContextMenu",!0),n("lineWiseCopyCut",!0),n("pasteLinesPerSelection",!0),n("selectionsMayTouch",!1),n("readOnly",!1,(function(e,t){"nocursor"==t&&(xr(e),e.display.input.blur()),e.display.input.readOnlyChanged(t)})),n("screenReaderLabel",null,(function(e,t){t=""===t?null:t,e.display.input.screenReaderLabelChanged(t)})),n("disableInput",!1,(function(e,t){t||e.display.input.reset()}),!0),n("dragDrop",!0,xa),n("allowDropFileTypes",null),n("cursorBlinkRate",530),n("cursorScrollMargin",0),n("cursorHeight",1,gr,!0),n("singleCursorHeightPerLine",!0,gr,!0),n("workTime",100),n("workDelay",100),n("flattenSpans",!0,Ii,!0),n("addModeClass",!1,Ii,!0),n("pollInterval",100),n("undoDepth",200,(function(e,t){return e.doc.history.undoDepth=t})),n("historyEventDelay",1250),n("viewportMargin",10,(function(e){return e.refresh()}),!0),n("maxHighlightLength",1e4,Ii,!0),n("moveInputWithCursor",!0,(function(e,t){t||e.display.input.resetPosition()})),n("tabindex",null,(function(e,t){return e.display.input.getField().tabIndex=t||""})),n("autofocus",null),n("direction","ltr",(function(e,t){return e.doc.setDirection(t)}),!0),n("phrases",null)}(La),function(e){var t=e.optionHandlers,n=e.helpers={};e.prototype={constructor:e,focus:function(){window.focus(),this.display.input.focus()},setOption:function(e,n){var r=this.options,i=r[e];r[e]==n&&"mode"!=e||(r[e]=n,t.hasOwnProperty(e)&&ei(this,t[e])(this,n,i),fe(this,"optionChange",this,e))},getOption:function(e){return this.options[e]},getDoc:function(){return this.doc},addKeyMap:function(e,t){this.state.keyMaps[t?"push":"unshift"](Jo(e))},removeKeyMap:function(e){for(var t=this.state.keyMaps,n=0;n<t.length;++n)if(t[n]==e||t[n].name==e)return t.splice(n,1),!0},addOverlay:ti((function(t,n){var r=t.token?t:e.getMode(this.options,t);if(r.startState)throw new Error("Overlays may not be stateful.");!function(e,t,n){for(var r=0,i=n(t);r<e.length&&n(e[r])<=i;)r++;e.splice(r,0,t)}(this.state.overlays,{mode:r,modeSpec:t,opaque:n&&n.opaque,priority:n&&n.priority||0},(function(e){return e.priority})),this.state.modeGen++,dr(this)})),removeOverlay:ti((function(e){for(var t=this.state.overlays,n=0;n<t.length;++n){var r=t[n].modeSpec;if(r==e||"string"==typeof e&&r.name==e)return t.splice(n,1),this.state.modeGen++,void dr(this)}})),indentLine:ti((function(e,t,n){"string"!=typeof t&&"number"!=typeof t&&(t=null==t?this.options.smartIndent?"smart":"prev":t?"add":"subtract"),Ze(this.doc,e)&&Ta(this,e,t,n)})),indentSelection:ti((function(e){for(var t=this.doc.sel.ranges,n=-1,r=0;r<t.length;r++){var i=t[r];if(i.empty())i.head.line>n&&(Ta(this,i.head.line,e,!0),n=i.head.line,r==this.doc.sel.primIndex&&Ir(this));else{var o=i.from(),a=i.to(),s=Math.max(n,o.line);n=Math.min(this.lastLine(),a.line-(a.ch?0:1))+1;for(var l=s;l<n;++l)Ta(this,l,e);var c=this.doc.sel.ranges;0==o.ch&&t.length==c.length&&c[r].from().ch>0&&Ji(this.doc,r,new Ai(o,c[r].to()),Y)}}})),getTokenAt:function(e,t){return yt(this,e,t)},getLineTokens:function(e,t){return yt(this,et(e),t,!0)},getTokenTypeAt:function(e){e=st(this.doc,e);var t,n=ht(this,Ge(this.doc,e.line)),r=0,i=(n.length-1)/2,o=e.ch;if(0==o)t=n[2];else for(;;){var a=r+i>>1;if((a?n[2*a-1]:0)>=o)i=a;else{if(!(n[2*a+1]<o)){t=n[2*a+2];break}r=a+1}}var s=t?t.indexOf("overlay "):-1;return s<0?t:0==s?null:t.slice(0,s-1)},getModeAt:function(t){var n=this.doc.mode;return n.innerMode?e.innerMode(n,this.getTokenAt(t).state).mode:n},getHelper:function(e,t){return this.getHelpers(e,t)[0]},getHelpers:function(e,t){var r=[];if(!n.hasOwnProperty(t))return r;var i=n[t],o=this.getModeAt(e);if("string"==typeof o[t])i[o[t]]&&r.push(i[o[t]]);else if(o[t])for(var a=0;a<o[t].length;a++){var s=i[o[t][a]];s&&r.push(s)}else o.helperType&&i[o.helperType]?r.push(i[o.helperType]):i[o.name]&&r.push(i[o.name]);for(var l=0;l<i._global.length;l++){var c=i._global[l];c.pred(o,this)&&-1==H(r,c.val)&&r.push(c.val)}return r},getStateAfter:function(e,t){var n=this.doc;return pt(this,(e=at(n,null==e?n.first+n.size-1:e))+1,t).state},cursorCoords:function(e,t){var n=this.doc.sel.primary();return qn(this,null==e?n.head:"object"==typeof e?st(this.doc,e):e?n.from():n.to(),t||"page")},charCoords:function(e,t){return Gn(this,st(this.doc,e),t||"page")},coordsChar:function(e,t){return Jn(this,(e=Wn(this,e,t||"page")).left,e.top)},lineAtHeight:function(e,t){return e=Wn(this,{top:e,left:0},t||"page").top,Qe(this.doc,e+this.display.viewOffset)},heightAtLine:function(e,t,n){var r,i=!1;if("number"==typeof e){var o=this.doc.first+this.doc.size-1;e<this.doc.first?e=this.doc.first:e>o&&(e=o,i=!0),r=Ge(this.doc,e)}else r=e;return Un(this,r,{top:0,left:0},t||"page",n||i).top+(i?this.doc.height-Vt(r):0)},defaultTextHeight:function(){return rr(this.display)},defaultCharWidth:function(){return ir(this.display)},getViewport:function(){return{from:this.display.viewFrom,to:this.display.viewTo}},addWidget:function(e,t,n,r,i){var o,a,s,l=this.display,c=(e=qn(this,st(this.doc,e))).bottom,u=e.left;if(t.style.position="absolute",t.setAttribute("cm-ignore-events","true"),this.display.input.setUneditable(t),l.sizer.appendChild(t),"over"==r)c=e.top;else if("above"==r||"near"==r){var d=Math.max(l.wrapper.clientHeight,this.doc.height),h=Math.max(l.sizer.clientWidth,l.lineSpace.clientWidth);("above"==r||e.bottom+t.offsetHeight>d)&&e.top>t.offsetHeight?c=e.top-t.offsetHeight:e.bottom+t.offsetHeight<=d&&(c=e.bottom),u+t.offsetWidth>h&&(u=h-t.offsetWidth)}t.style.top=c+"px",t.style.left=t.style.right="","right"==i?(u=l.sizer.clientWidth-t.offsetWidth,t.style.right="0px"):("left"==i?u=0:"middle"==i&&(u=(l.sizer.clientWidth-t.offsetWidth)/2),t.style.left=u+"px"),n&&(o=this,a={left:u,top:c,right:u+t.offsetWidth,bottom:c+t.offsetHeight},null!=(s=Tr(o,a)).scrollTop&&jr(o,s.scrollTop),null!=s.scrollLeft&&zr(o,s.scrollLeft))},triggerOnKeyDown:ti(ua),triggerOnKeyPress:ti(ha),triggerOnKeyUp:da,triggerOnMouseDown:ti(ga),execCommand:function(e){if(ta.hasOwnProperty(e))return ta[e].call(null,this)},triggerElectric:ti((function(e){Na(this,e)})),findPosH:function(e,t,n,r){var i=1;t<0&&(i=-1,t=-t);for(var o=st(this.doc,e),a=0;a<t&&!(o=Ra(this.doc,o,i,n,r)).hitSide;++a);return o},moveH:ti((function(e,t){var n=this;this.extendSelectionsBy((function(r){return n.display.shift||n.doc.extend||r.empty()?Ra(n.doc,r.head,e,t,n.options.rtlMoveVisually):e<0?r.from():r.to()}),U)})),deleteH:ti((function(e,t){var n=this.doc.sel,r=this.doc;n.somethingSelected()?r.replaceSelection("",null,"+delete"):Qo(this,(function(n){var i=Ra(r,n.head,e,t,!1);return e<0?{from:i,to:n.head}:{from:n.head,to:i}}))})),findPosV:function(e,t,n,r){var i=1,o=r;t<0&&(i=-1,t=-t);for(var a=st(this.doc,e),s=0;s<t;++s){var l=qn(this,a,"div");if(null==o?o=l.left:l.left=o,(a=Ba(this,l,i,n)).hitSide)break}return a},moveV:ti((function(e,t){var n=this,r=this.doc,i=[],o=!this.display.shift&&!r.extend&&r.sel.somethingSelected();if(r.extendSelectionsBy((function(a){if(o)return e<0?a.from():a.to();var s=qn(n,a.head,"div");null!=a.goalColumn&&(s.left=a.goalColumn),i.push(s.left);var l=Ba(n,s,e,t);return"page"==t&&a==r.sel.primary()&&Or(n,Gn(n,l,"div").top-s.top),l}),U),i.length)for(var a=0;a<r.sel.ranges.length;a++)r.sel.ranges[a].goalColumn=i[a]})),findWordAt:function(e){var t=Ge(this.doc,e.line).text,n=e.ch,r=e.ch;if(t){var i=this.getHelper(e,"wordChars");"before"!=e.sticky&&r!=t.length||!n?++r:--n;for(var o=t.charAt(n),a=ee(o,i)?function(e){return ee(e,i)}:/\s/.test(o)?function(e){return/\s/.test(e)}:function(e){return!/\s/.test(e)&&!ee(e)};n>0&&a(t.charAt(n-1));)--n;for(;r<t.length&&a(t.charAt(r));)++r}return new Ai(et(e.line,n),et(e.line,r))},toggleOverwrite:function(e){null!=e&&e==this.state.overwrite||((this.state.overwrite=!this.state.overwrite)?D(this.display.cursorDiv,"CodeMirror-overwrite"):E(this.display.cursorDiv,"CodeMirror-overwrite"),fe(this,"overwriteToggle",this,this.state.overwrite))},hasFocus:function(){return this.display.input.getField()==k()},isReadOnly:function(){return!(!this.options.readOnly&&!this.doc.cantEdit)},scrollTo:ti((function(e,t){kr(this,e,t)})),getScrollInfo:function(){var e=this.display.scroller;return{left:e.scrollLeft,top:e.scrollTop,height:e.scrollHeight-En(this)-this.display.barHeight,width:e.scrollWidth-En(this)-this.display.barWidth,clientHeight:Sn(this),clientWidth:Ln(this)}},scrollIntoView:ti((function(e,t){null==e?(e={from:this.doc.sel.primary().head,to:null},null==t&&(t=this.options.cursorScrollMargin)):"number"==typeof e?e={from:et(e,0),to:null}:null==e.from&&(e={from:e,to:null}),e.to||(e.to=e.from),e.margin=t||0,null!=e.from.line?function(e,t){Dr(e),e.curOp.scrollToPos=t}(this,e):Nr(this,e.from,e.to,e.margin)})),setSize:ti((function(e,t){var n=this,r=function(e){return"number"==typeof e||/^\d+$/.test(String(e))?e+"px":e};null!=e&&(this.display.wrapper.style.width=r(e)),null!=t&&(this.display.wrapper.style.height=r(t)),this.options.lineWrapping&&Bn(this);var i=this.display.viewFrom;this.doc.iter(i,this.display.viewTo,(function(e){if(e.widgets)for(var t=0;t<e.widgets.length;t++)if(e.widgets[t].noHScroll){hr(n,i,"widget");break}++i})),this.curOp.forceUpdate=!0,fe(this,"refresh",this)})),operation:function(e){return $r(this,e)},startOperation:function(){return Gr(this)},endOperation:function(){return qr(this)},refresh:ti((function(){var e=this.display.cachedTextHeight;dr(this),this.curOp.forceUpdate=!0,Hn(this),kr(this,this.doc.scrollLeft,this.doc.scrollTop),ci(this.display),(null==e||Math.abs(e-rr(this.display))>.5||this.options.lineWrapping)&&lr(this),fe(this,"refresh",this)})),swapDoc:ti((function(e){var t=this.doc;return t.cm=null,this.state.selectingText&&this.state.selectingText(),ji(this,e),Hn(this),this.display.input.reset(),kr(this,e.scrollLeft,e.scrollTop),this.curOp.forceScroll=!0,ln(this,"swapDoc",this,t),t})),phrase:function(e){var t=this.options.phrases;return t&&Object.prototype.hasOwnProperty.call(t,e)?t[e]:e},getInputField:function(){return this.display.input.getField()},getWrapperElement:function(){return this.display.wrapper},getScrollerElement:function(){return this.display.scroller},getGutterElement:function(){return this.display.gutters}},ye(e),e.registerHelper=function(t,r,i){n.hasOwnProperty(t)||(n[t]=e[t]={_global:[]}),n[t][r]=i},e.registerGlobalHelper=function(t,r,i,o){e.registerHelper(t,r,o),n[t]._global.push({pred:i,val:o})}}(La);var Ga="iter insert remove copy getEditor constructor".split(" ");for(var qa in Io.prototype)Io.prototype.hasOwnProperty(qa)&&H(Ga,qa)<0&&(La.prototype[qa]=function(e){return function(){return e.apply(this.doc,arguments)}}(Io.prototype[qa]));return ye(Io),La.inputStyles={textarea:Wa,contenteditable:Ha},La.defineMode=function(e){La.defaults.mode||"null"==e||(La.defaults.mode=e),ze.apply(this,arguments)},La.defineMIME=function(e,t){Pe[e]=t},La.defineMode("null",(function(){return{token:function(e){return e.skipToEnd()}}})),La.defineMIME("text/plain","null"),La.defineExtension=function(e,t){La.prototype[e]=t},La.defineDocExtension=function(e,t){Io.prototype[e]=t},La.fromTextArea=function(e,t){if((t=t?z(t):{}).value=e.value,!t.tabindex&&e.tabIndex&&(t.tabindex=e.tabIndex),!t.placeholder&&e.placeholder&&(t.placeholder=e.placeholder),null==t.autofocus){var n=k();t.autofocus=n==e||null!=e.getAttribute("autofocus")&&n==document.body}function r(){e.value=s.getValue()}var i;if(e.form&&(de(e.form,"submit",r),!t.leaveSubmitMethodAlone)){var o=e.form;i=o.submit;try{var a=o.submit=function(){r(),o.submit=i,o.submit(),o.submit=a}}catch(e){}}t.finishInit=function(n){n.save=r,n.getTextArea=function(){return e},n.toTextArea=function(){n.toTextArea=isNaN,r(),e.parentNode.removeChild(n.getWrapperElement()),e.style.display="",e.form&&(pe(e.form,"submit",r),t.leaveSubmitMethodAlone||"function"!=typeof e.form.submit||(e.form.submit=i))}},e.style.display="none";var s=La((function(t){return e.parentNode.insertBefore(t,e.nextSibling)}),t);return s},function(e){e.off=pe,e.on=de,e.wheelEventPixels=bi,e.Doc=Io,e.splitLines=Ie,e.countColumn=R,e.findColumn=W,e.isWordChar=$,e.Pass=F,e.signal=fe,e.Line=Gt,e.changeEnd=Ei,e.scrollbarModel=Vr,e.Pos=et,e.cmpPos=tt,e.modes=je,e.mimeModes=Pe,e.resolveMode=Re,e.getMode=Be,e.modeExtensions=He,e.extendMode=Fe,e.copyState=Ye,e.startState=Ue,e.innerMode=Ve,e.commands=ta,e.keyMap=Vo,e.keyName=Xo,e.isModifierKey=qo,e.lookupKey=Go,e.normalizeKeyMap=Wo,e.StringStream=We,e.SharedTextMarker=Lo,e.TextMarker=xo,e.LineWidget=wo,e.e_preventDefault=_e,e.e_stopPropagation=be,e.e_stop=we,e.addClass=D,e.contains=I,e.rmClass=E,e.keyNames=Bo}(La),La.version="5.61.1",La}()},function(e,t,n){"use strict";n.r(t),n.d(t,"ManagerBase",(function(){return k})),n.d(t,"serialize_state",(function(){return D})),n.d(t,"unpack_models",(function(){return q})),n.d(t,"WidgetModel",(function(){return X})),n.d(t,"DOMWidgetModel",(function(){return J})),n.d(t,"WidgetView",(function(){return Q})),n.d(t,"JupyterPhosphorWidget",(function(){return Z})),n.d(t,"JupyterPhosphorPanelWidget",(function(){return $})),n.d(t,"DOMWidgetView",(function(){return ee})),n.d(t,"LayoutModel",(function(){return re})),n.d(t,"LayoutView",(function(){return ie})),n.d(t,"StyleModel",(function(){return ae})),n.d(t,"StyleView",(function(){return se})),n.d(t,"shims",(function(){return K})),n.d(t,"ViewList",(function(){return ue})),n.d(t,"JUPYTER_WIDGETS_VERSION",(function(){return E})),n.d(t,"PROTOCOL_VERSION",(function(){return L})),n.d(t,"difference",(function(){return h})),n.d(t,"isEqual",(function(){return p})),n.d(t,"assign",(function(){return f})),n.d(t,"uuid",(function(){return m})),n.d(t,"WrappedError",(function(){return g})),n.d(t,"resolvePromisesDict",(function(){return v})),n.d(t,"reject",(function(){return y})),n.d(t,"put_buffers",(function(){return _})),n.d(t,"remove_buffers",(function(){return b})),n.d(t,"bufferToHex",(function(){return w})),n.d(t,"hexToBuffer",(function(){return A})),n.d(t,"bufferToBase64",(function(){return C})),n.d(t,"base64ToBuffer",(function(){return x})),n.d(t,"IJupyterWidgetRegistry",(function(){return de}));var r,i=n(143),o=n(6),a=n(577),s=n.n(a),l=n(578),c=n.n(l),u=(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),d=function(){return(d=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function h(e,t){return e.filter((function(e){return-1===t.indexOf(e)}))}function p(e,t){return s()(e,t)}var f=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e};function m(){return o.UUID.uuid4()}var g=function(e){function t(n,r){var i=e.call(this,n)||this;return console.warn("WrappedError has been deprecated!"),i.error_stack=r instanceof t?r.error_stack:[r],i.error_stack.push(i),i}return u(t,e),t}(Error);function v(e){var t=Object.keys(e),n=[];return t.forEach((function(t){n.push(e[t])})),Promise.all(n).then((function(e){for(var n={},r=0;r<t.length;r++)n[t[r]]=e[r];return n}))}function y(e,t){return function(n){throw t&&console.error(new Error(e)),n}}function _(e,t,n){for(var r=0;r<t.length;r++){for(var i=t[r],o=e,a=0;a<i.length-1;a++)o=o[i[a]];o[i[i.length-1]]=n[r]}}function b(e){var t=[],n=[];return{state:function e(r,i){if(r.toJSON&&(r=r.toJSON()),Array.isArray(r))for(var o=!1,a=0;a<r.length;a++){if(l=r[a])if(l instanceof ArrayBuffer||ArrayBuffer.isView(l))o||(r=r.slice(),o=!0),t.push(ArrayBuffer.isView(l)?l.buffer:l),n.push(i.concat([a])),r[a]=null;else(u=e(l,i.concat([a])))!==l&&(o||(r=r.slice(),o=!0),r[a]=u)}else if(c()(r))for(var s in r){var l,u;o=!1;if(r.hasOwnProperty(s))if(l=r[s])if(l instanceof ArrayBuffer||ArrayBuffer.isView(l))o||(r=d({},r),o=!0),t.push(ArrayBuffer.isView(l)?l.buffer:l),n.push(i.concat([s])),delete r[s];else(u=e(l,i.concat([s])))!==l&&(o||(r=d({},r),o=!0),r[s]=u)}return r}(e,[]),buffers:t,buffer_paths:n}}var M=["00","01","02","03","04","05","06","07","08","09","0A","0B","0C","0D","0E","0F","10","11","12","13","14","15","16","17","18","19","1A","1B","1C","1D","1E","1F","20","21","22","23","24","25","26","27","28","29","2A","2B","2C","2D","2E","2F","30","31","32","33","34","35","36","37","38","39","3A","3B","3C","3D","3E","3F","40","41","42","43","44","45","46","47","48","49","4A","4B","4C","4D","4E","4F","50","51","52","53","54","55","56","57","58","59","5A","5B","5C","5D","5E","5F","60","61","62","63","64","65","66","67","68","69","6A","6B","6C","6D","6E","6F","70","71","72","73","74","75","76","77","78","79","7A","7B","7C","7D","7E","7F","80","81","82","83","84","85","86","87","88","89","8A","8B","8C","8D","8E","8F","90","91","92","93","94","95","96","97","98","99","9A","9B","9C","9D","9E","9F","A0","A1","A2","A3","A4","A5","A6","A7","A8","A9","AA","AB","AC","AD","AE","AF","B0","B1","B2","B3","B4","B5","B6","B7","B8","B9","BA","BB","BC","BD","BE","BF","C0","C1","C2","C3","C4","C5","C6","C7","C8","C9","CA","CB","CC","CD","CE","CF","D0","D1","D2","D3","D4","D5","D6","D7","D8","D9","DA","DB","DC","DD","DE","DF","E0","E1","E2","E3","E4","E5","E6","E7","E8","E9","EA","EB","EC","ED","EE","EF","F0","F1","F2","F3","F4","F5","F6","F7","F8","F9","FA","FB","FC","FD","FE","FF"];function w(e){for(var t=new Uint8Array(e),n=[],r=0;r<t.length;r++)n.push(M[t[r]]);return n.join("")}function A(e){for(var t=new Uint8Array(e.length/2),n=0;n<e.length;n+=2)t[n/2]=parseInt(e.slice(n,n+2),16);return t.buffer}function C(e){return Object(i.fromByteArray)(new Uint8Array(e))}function x(e){return Object(i.toByteArray)(e).buffer}var E="1.2.0",L="2.0.0",S=function(){return(S=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},T=function(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{l(r.next(e))}catch(e){o(e)}}function s(e){try{l(r.throw(e))}catch(e){o(e)}}function l(e){var t;e.done?i(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,s)}l((r=r.apply(e,t||[])).next())}))},O=function(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}},I=L.split(".",1)[0],k=function(){function e(){this.comm_target_name="jupyter.widget",this._models=Object.create(null)}return e.prototype.display_model=function(e,t,n){var r=this;return void 0===n&&(n={}),this.create_view(t,n).then((function(t){return r.display_view(e,t,n)})).catch(y("Could not create view",!0))},e.prototype.setViewOptions=function(e){return void 0===e&&(e={}),e},e.prototype.create_view=function(e,t){var n=this;void 0===t&&(t={});var r=e.state_change=e.state_change.then((function(){return n.loadClass(e.get("_view_name"),e.get("_view_module"),e.get("_view_module_version")).then((function(r){var i=new r({model:e,options:n.setViewOptions(t)});return i.listenTo(e,"destroy",i.remove),Promise.resolve(i.render()).then((function(){return i}))})).catch(y("Could not create a view for model id "+e.model_id,!0))})),i=m();return e.views[i]=r,r.then((function(e){e.once("remove",(function(){delete e.model.views[i]}),n)})),e.state_change},e.prototype.callbacks=function(e){return{}},e.prototype.get_model=function(e){return this._models[e]},e.prototype.handle_comm_open=function(e,t){var n=(t.metadata||{}).version||"";if(n.split(".",1)[0]!==I){var r="Wrong widget protocol version: received protocol version '"+n+"', but was expecting major version '"+I+"'";return console.error(r),Promise.reject(r)}var i=t.content.data,o=i.buffer_paths||[],a=(t.buffers||[]).map((function(e){return e instanceof DataView?e:new DataView(e instanceof ArrayBuffer?e:e.buffer)}));return _(i.state,o,a),this.new_model({model_name:i.state._model_name,model_module:i.state._model_module,model_module_version:i.state._model_module_version,comm:e},i.state).catch(y("Could not create a model.",!0))},e.prototype.new_widget=function(e,t){var n,r=this;if(void 0===t&&(t={}),void 0===e.view_name||void 0===e.view_module||void 0===e.view_module_version)return Promise.reject("new_widget(...) must be given view information in the options.");n=e.comm?Promise.resolve(e.comm):this._create_comm(this.comm_target_name,e.model_id,{state:{_model_module:e.model_module,_model_module_version:e.model_module_version,_model_name:e.model_name,_view_module:e.view_module,_view_module_version:e.view_module_version,_view_name:e.view_name}},{version:L});var i=S({},e);return n.then((function(e){return i.comm=e,r.new_model(i,t).then((function(e){return e.sync("create",e),e}))}),(function(){return i.model_id||(i.model_id=m()),r.new_model(i,t)}))},e.prototype.register_model=function(e,t){var n=this;this._models[e]=t,t.then((function(t){t.once("comm:close",(function(){delete n._models[e]}))}))},e.prototype.new_model=function(e,t){return void 0===t&&(t={}),T(this,void 0,void 0,(function(){var n,r;return O(this,(function(i){switch(i.label){case 0:if(e.model_id)n=e.model_id;else{if(!e.comm)throw new Error("Neither comm nor model_id provided in options object. At least one must exist.");n=e.model_id=e.comm.comm_id}return r=this._make_model(e,t),this.register_model(n,r),[4,r];case 1:return[2,i.sent()]}}))}))},e.prototype._make_model=function(e,t){return void 0===t&&(t={}),T(this,void 0,void 0,(function(){var n,r,i,o,a,s,l;return O(this,(function(c){switch(c.label){case 0:n=e.model_id,r=this.loadClass(e.model_name,e.model_module,e.model_module_version),c.label=1;case 1:return c.trys.push([1,3,,4]),[4,r];case 2:return i=c.sent(),[3,4];case 3:throw o=c.sent(),console.error("Could not instantiate widget"),o;case 4:if(!i)throw new Error("Cannot find model module "+e.model_module+"@"+e.model_module_version+", "+e.model_name);return[4,i._deserialize_state(t,this)];case 5:return a=c.sent(),s={widget_manager:this,model_id:n,comm:e.comm},(l=new i(a,s)).name=e.model_name,l.module=e.model_module,[2,l]}}))}))},e.prototype.clear_state=function(){var e=this;return v(this._models).then((function(t){Object.keys(t).forEach((function(e){return t[e].close()})),e._models=Object.create(null)}))},e.prototype.get_state=function(e){var t=this;void 0===e&&(e={});var n=Object.keys(this._models).map((function(e){return t._models[e]}));return Promise.all(n).then((function(t){return D(t,e)}))},e.prototype.set_state=function(e){var t=this;if(!(e.version_major&&e.version_major<=2))throw"Unsupported widget state format";var n=e.state;return this._get_comm_info().then((function(e){return Promise.all(Object.keys(n).map((function(r){var i={base64:x,hex:A},o=n[r],a=o.state;if(o.buffers){var s=o.buffers.map((function(e){return e.path})),l=o.buffers.map((function(e){return new DataView(i[e.encoding](e.data))}));_(o.state,s,l)}if(t._models[r])return t._models[r].then((function(e){return e.constructor._deserialize_state(a||{},t).then((function(t){return e.set_state(t),e}))}));var c={model_id:r,model_name:o.model_name,model_module:o.model_module,model_module_version:o.model_module_version};return e.hasOwnProperty(r)?t._create_comm(t.comm_target_name,r).then((function(e){return c.comm=e,t.new_model(c)})):t.new_model(c,a)})))}))},e.prototype.disconnect=function(){var e=this;Object.keys(this._models).forEach((function(t){e._models[t].then((function(e){e.comm_live=!1}))}))},e.prototype.resolveUrl=function(e){return Promise.resolve(e)},e.prototype.filterExistingModelState=function(e){var t=this,n=e.state;return n=Object.keys(n).filter((function(e){return!t._models[e]})).reduce((function(e,t){return e[t]=n[t],e}),{}),S(S({},e),{state:n})},e}();function D(e,t){void 0===t&&(t={});var n={};return e.forEach((function(e){var r=e.model_id,i=b(e.serialize(e.get_state(t.drop_defaults))),o=i.buffers.map((function(e,t){return{data:C(e),path:i.buffer_paths[t],encoding:"base64"}}));n[r]={model_name:e.name,model_module:e.module,model_module_version:e.get("_model_module_version"),state:i.state},o.length>0&&(n[r].buffers=o)})),{version_major:2,version_minor:0,state:n}}var N=function(){return(N=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function j(e,t,n){if(null==e)return this;var r;if("object"==typeof e?(r=e,n=t):(r={})[e]=t,n||(n={}),!this._validate(r,n))return!1;var i=n.unset,o=n.silent,a=[],s=this._changing;this._changing=!0,s||(this._previousAttributes=N({},this.attributes),this.changed={});var l=this.attributes,c=this.changed,u=this._previousAttributes;for(var d in r)t=r[d],p(l[d],t)||a.push(d),p(u[d],t)?delete c[d]:c[d]=t,i?delete l[d]:l[d]=t;if(this.id=this.get(this.idAttribute),!o){a.length&&(this._pending=n);for(var h=0;h<a.length;h++)this.trigger("change:"+a[h],this,l[a[h]],n)}if(s)return this;if(!o)for(;this._pending;)n=this._pending,this._pending=!1,this.trigger("change",this,n);return this._pending=!1,this._changing=!1,this}var P=n(147),z=n(41),R=n.n(z),B=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),H=Element.prototype,F=H.matches||H.webkitMatchesSelector||H.mozMatchesSelector||H.msMatchesSelector||H.oMatchesSelector||function(e){for(var t=(this.document||this.ownerDocument).querySelectorAll(e),n=t.length;--n>=0&&t.item(n)!==this;);return n>-1},Y=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return B(t,e),t.prototype._removeElement=function(){this.undelegateEvents(),this.el.parentNode&&this.el.parentNode.removeChild(this.el)},t.prototype._setElement=function(e){this.el=e},t.prototype._setAttributes=function(e){for(var t in e)t in this.el?this.el[t]=e[t]:this.el.setAttribute(t,e[t])},t.prototype.delegate=function(e,t,n){"string"!=typeof t&&(n=t,t=null),void 0===this._domEvents&&(this._domEvents=[]);var r=this.el,i=t?function(e){for(var i=e.target||e.srcElement;i&&i!==r;i=i.parentNode)if(F.call(i,t))return e.delegateTarget=i,n.handleEvent?n.handleEvent(e):n(e)}:n;return this.el.addEventListener(e,i,!1),this._domEvents.push({eventName:e,handler:i,listener:n,selector:t}),i},t.prototype.undelegate=function(e,t,n){if("function"==typeof t&&(n=t,t=null),this.el&&this._domEvents)for(var r=this._domEvents.slice(),i=r.length;i--;){var o=r[i];!(o.eventName!==e||n&&o.listener!==n||t&&o.selector!==t)&&(this.el.removeEventListener(o.eventName,o.handler,!1),this._domEvents.splice(i,1))}return this},t.prototype.undelegateEvents=function(){if(this.el&&this._domEvents){for(var e=this._domEvents.length,t=0;t<e;t++){var n=this._domEvents[t];this.el.removeEventListener(n.eventName,n.handler,!1)}this._domEvents.length=0}return this},t}(P.View),V=n(3),U=n(8),W=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),G=function(){return(G=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function q(e,t){if(Array.isArray(e)){var n=[];return e.forEach((function(e,r){n.push(q(e,t))})),Promise.all(n)}if(e instanceof Object){var r={};return Object.keys(e).forEach((function(n){r[n]=q(e[n],t)})),v(r)}return"string"==typeof e&&"IPY_MODEL_"===e.slice(0,10)?t.get_model(e.slice(10,e.length)):Promise.resolve(e)}var K,X=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return W(t,e),t.prototype.defaults=function(){return{_model_module:"@jupyter-widgets/base",_model_name:"WidgetModel",_model_module_version:E,_view_module:"@jupyter-widgets/base",_view_name:null,_view_module_version:E,_view_count:null}},t.prototype.isNew=function(){return!1},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),this.widget_manager=n.widget_manager,this.model_id=n.model_id;var r=n.comm;this.views=Object.create(null),this.state_change=Promise.resolve(),this._closed=!1,this._state_lock=null,this._msg_buffer=null,this._msg_buffer_callbacks=null,this._pending_msgs=0,this._buffered_state_diff={},r?(this.comm=r,r.on_close(this._handle_comm_closed.bind(this)),r.on_msg(this._handle_comm_msg.bind(this)),this.comm_live=!0):this.comm_live=!1},Object.defineProperty(t.prototype,"comm_live",{get:function(){return this._comm_live},set:function(e){this._comm_live=e,this.trigger("comm_live_update")},enumerable:!0,configurable:!0}),t.prototype.send=function(e,t,n){if(void 0!==this.comm){var r={method:"custom",content:e};this.comm.send(r,t,{},n)}},t.prototype.close=function(e){var t=this;if(void 0===e&&(e=!1),!this._closed){this._closed=!0,this.comm&&!e&&this.comm.close(),this.stopListening(),this.trigger("destroy",this),this.comm&&delete this.comm;var n=Object.keys(this.views).map((function(e){return t.views[e].then((function(e){return e.remove()}))}));return delete this.views,Promise.all(n).then((function(){}))}},t.prototype._handle_comm_closed=function(e){this.trigger("comm:close"),this.close(!0)},t.prototype._handle_comm_msg=function(e){var t=this,n=e.content.data;switch(n.method){case"update":return this.state_change=this.state_change.then((function(){var r=n.state;return _(r,n.buffer_paths||[],(e.buffers||[]).map((function(e){return e instanceof DataView?e:new DataView(e instanceof ArrayBuffer?e:e.buffer)}))),t.constructor._deserialize_state(r,t.widget_manager)})).then((function(e){t.set_state(e)})).catch(y("Could not process update msg for model id: "+this.model_id,!0)),this.state_change;case"custom":return this.trigger("msg:custom",n.content,e.buffers),Promise.resolve()}},t.prototype.set_state=function(e){this._state_lock=e;try{this.set(e)}catch(e){console.error("Error setting state: "+e.message)}finally{this._state_lock=null}},t.prototype.get_state=function(e){var t=this.attributes;if(e){var n=this.defaults,r="function"==typeof n?n.call(this):n,i={};return Object.keys(t).forEach((function(e){p(t[e],r[e])||(i[e]=t[e])})),i}return G({},t)},t.prototype._handle_status=function(e){void 0!==this.comm&&"idle"===e.content.execution_state&&(this._pending_msgs--,null!==this._msg_buffer&&this._pending_msgs<1&&(this.send_sync_message(this._msg_buffer,this._msg_buffer_callbacks),this._msg_buffer=null,this._msg_buffer_callbacks=null))},t.prototype.callbacks=function(e){return this.widget_manager.callbacks(e)},t.prototype.set=function(e,t,n){var r=j.call(this,e,t,n);if(void 0!==this._buffered_state_diff){var i=this.changedAttributes()||{};if(this._state_lock)for(var o=0,a=Object.keys(this._state_lock);o<a.length;o++){var s=a[o];i[s]===this._state_lock[s]&&delete i[s]}this._buffered_state_diff=f(this._buffered_state_diff,i)}return r},t.prototype.sync=function(e,t,n){if(void 0===n&&(n={}),void 0===this.comm)throw"Syncing error: no comm channel defined";var r="patch"===e?n.attrs:t.get_state(n.drop_defaults);if(this._state_lock)for(var i=0,o=Object.keys(this._state_lock);i<o.length;i++){var a=o[i];r[a]===this._state_lock[a]&&delete r[a]}var s=this.serialize(r);if(Object.keys(s).length>0){var l=n.callbacks||this.callbacks();if(this._pending_msgs>=1){switch(e){case"patch":this._msg_buffer=f(this._msg_buffer||{},s);break;case"update":case"create":this._msg_buffer=s;break;default:throw"unrecognized syncing method"}this._msg_buffer_callbacks=l}else this.send_sync_message(r,l)}},t.prototype.serialize=function(e){for(var t=this.constructor.serializers||{},n=0,r=Object.keys(e);n<r.length;n++){var i=r[n];try{t[i]&&t[i].serialize?e[i]=t[i].serialize(e[i],this):e[i]=JSON.parse(JSON.stringify(e[i])),e[i]&&e[i].toJSON&&(e[i]=e[i].toJSON())}catch(e){throw console.error("Error serializing widget state attribute: ",i),e}}return e},t.prototype.send_sync_message=function(e,t){var n=this;void 0===t&&(t={});try{t.iopub=t.iopub||{};var r=t.iopub.status;t.iopub.status=function(e){n._handle_status(e),r&&r(e)};var i=b(e);this.comm.send({method:"update",state:i.state,buffer_paths:i.buffer_paths},t,{},i.buffers),this._pending_msgs++}catch(e){console.error("Could not send widget sync message",e)}},t.prototype.save_changes=function(e){if(this.comm_live){var t={patch:!0};e&&(t.callbacks=e),this.save(this._buffered_state_diff,t),this._buffered_state_diff={}}},t.prototype.on_some_change=function(e,t,n){var r=this;this.on("change",(function(){e.some(r.hasChanged,r)&&t.apply(n,arguments)}),this)},t.prototype.toJSON=function(e){return"IPY_MODEL_"+this.model_id},t._deserialize_state=function(e,t){var n,r=this.serializers;if(r)for(var i in n={},e)r[i]&&r[i].deserialize?n[i]=r[i].deserialize(e[i],t):n[i]=e[i];else n=e;return v(n)},t}(P.Model),J=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return W(t,e),t.prototype.defaults=function(){return f(e.prototype.defaults.call(this),{_dom_classes:[]})},t.serializers=G(G({},X.serializers),{layout:{deserialize:q},style:{deserialize:q}}),t}(X),Q=function(e){function t(t){return e.call(this,t)||this}return W(t,e),t.prototype.initialize=function(e){var t=this;this.listenTo(this.model,"change",(function(){var e=Object.keys(t.model.changedAttributes()||{});"_view_count"===e[0]&&1===e.length||t.update()})),this.options=e.options,this.once("remove",(function(){"number"==typeof t.model.get("_view_count")&&(t.model.set("_view_count",t.model.get("_view_count")-1),t.model.save_changes())})),this.once("displayed",(function(){"number"==typeof t.model.get("_view_count")&&(t.model.set("_view_count",t.model.get("_view_count")+1),t.model.save_changes())})),this.displayed=new Promise((function(e,n){t.once("displayed",e)}))},t.prototype.update=function(e){},t.prototype.render=function(){},t.prototype.create_child_view=function(e,t){return void 0===t&&(t={}),t=G({parent:this},t),this.model.widget_manager.create_view(e,t).catch(y("Could not create child view",!0))},t.prototype.callbacks=function(){return this.model.callbacks(this)},t.prototype.send=function(e,t){this.model.send(e,this.callbacks(),t)},t.prototype.touch=function(){this.model.save_changes(this.callbacks())},t.prototype.remove=function(){return e.prototype.remove.call(this),this.trigger("remove"),this},t}(Y),Z=function(e){function t(t){var n=this,r=t.view;return delete t.view,(n=e.call(this,t)||this)._view=r,n}return W(t,e),t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._view&&this._view.remove(),this._view=null)},t.prototype.processMessage=function(t){e.prototype.processMessage.call(this,t),this._view.processPhosphorMessage(t)},t}(V.Widget),$=function(e){function t(t){var n=this,r=t.view;return delete t.view,(n=e.call(this,t)||this)._view=r,n}return W(t,e),t.prototype.processMessage=function(t){e.prototype.processMessage.call(this,t),this._view.processPhosphorMessage(t)},t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._view&&this._view.remove(),this._view=null)},t}(V.Panel),ee=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return W(t,e),t.prototype.initialize=function(t){var n=this;e.prototype.initialize.call(this,t),this.listenTo(this.model,"change:_dom_classes",(function(e,t){var r=e.previous("_dom_classes");n.update_classes(r,t)})),this.layoutPromise=Promise.resolve(),this.listenTo(this.model,"change:layout",(function(e,t){n.setLayout(t,e.previous("layout"))})),this.stylePromise=Promise.resolve(),this.listenTo(this.model,"change:style",(function(e,t){n.setStyle(t,e.previous("style"))})),this.displayed.then((function(){n.update_classes([],n.model.get("_dom_classes")),n.setLayout(n.model.get("layout")),n.setStyle(n.model.get("style"))})),this._comm_live_update(),this.listenTo(this.model,"comm_live_update",(function(){n._comm_live_update()}))},t.prototype.setLayout=function(e,t){var n=this;e&&(this.layoutPromise=this.layoutPromise.then((function(t){return t&&(t.unlayout(),n.stopListening(t.model),t.remove()),n.create_child_view(e).then((function(e){return n.displayed.then((function(){return e.trigger("displayed"),n.listenTo(e.model,"change",(function(){U.c.postMessage(n.pWidget,V.Widget.ResizeMessage.UnknownSize)})),U.c.postMessage(n.pWidget,V.Widget.ResizeMessage.UnknownSize),e}))})).catch(y("Could not add LayoutView to DOMWidgetView",!0))})))},t.prototype.setStyle=function(e,t){var n=this;e&&(this.stylePromise=this.stylePromise.then((function(t){return t&&(t.unstyle(),n.stopListening(t.model),t.remove()),n.create_child_view(e).then((function(e){return n.displayed.then((function(){return e.trigger("displayed"),e}))})).catch(y("Could not add styleView to DOMWidgetView",!0))})))},t.prototype.update_classes=function(e,t,n){void 0===n&&(n=this.el),h(e,t).map((function(e){n.classList?n.classList.remove(e):n.setAttribute("class",n.getAttribute("class").replace(e,""))})),h(t,e).map((function(e){n.classList?n.classList.add(e):n.setAttribute("class",n.getAttribute("class").concat(" ",e))}))},t.prototype.update_mapped_classes=function(e,t,n){var r=this.model.previous(t),i=e[r]?e[r]:[],o=e[r=this.model.get(t)]?e[r]:[];this.update_classes(i,o,n||this.el)},t.prototype.set_mapped_classes=function(e,t,n){var r=this.model.get(t),i=e[r]?e[r]:[];this.update_classes([],i,n||this.el)},t.prototype._setElement=function(e){this.pWidget&&this.pWidget.dispose(),this.$el=e instanceof R.a?e:R()(e),this.el=this.$el[0],this.pWidget=new Z({node:e,view:this})},t.prototype.remove=function(){return this.pWidget&&this.pWidget.dispose(),e.prototype.remove.call(this)},t.prototype.processPhosphorMessage=function(e){switch(e.type){case"after-attach":this.trigger("displayed")}},t.prototype._comm_live_update=function(){this.model.comm_live?this.pWidget.removeClass("jupyter-widgets-disconnected"):this.pWidget.addClass("jupyter-widgets-disconnected")},t}(Q),te=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),ne={align_content:null,align_items:null,align_self:null,border:null,bottom:null,display:null,flex:null,flex_flow:null,height:null,justify_content:null,justify_items:null,left:null,margin:null,max_height:null,max_width:null,min_height:null,min_width:null,overflow:null,overflow_x:null,overflow_y:null,order:null,padding:null,right:null,top:null,visibility:null,width:null,object_fit:null,object_position:null,grid_auto_columns:null,grid_auto_flow:null,grid_auto_rows:null,grid_gap:null,grid_template_rows:null,grid_template_columns:null,grid_template_areas:null,grid_row:null,grid_column:null,grid_area:null},re=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return te(t,e),t.prototype.defaults=function(){return f(e.prototype.defaults.call(this),{_model_name:"LayoutModel",_view_name:"LayoutView"},ne)},t}(X),ie=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return te(t,e),t.prototype.initialize=function(t){this._traitNames=[],e.prototype.initialize.call(this,t);for(var n=0,r=Object.keys(ne);n<r.length;n++){var i=r[n];this.registerTrait(i)}},t.prototype.registerTrait=function(e){var t=this;if(this._traitNames.push(e),"overflow_x"===e||"overflow_y"===e)return this.listenTo(this.model,"change:"+e,(function(n,r){t.handleOverflowChange(e,r)})),void this.handleOverflowChange(e,this.model.get(e));this.listenTo(this.model,"change:"+e,(function(n,r){t.handleChange(e,r)})),this.handleChange(e,this.model.get(e))},t.prototype.css_name=function(e){return e.replace(/_/g,"-")},t.prototype.handleChange=function(e,t){var n=this.options.parent;n?null===t?n.el.style.removeProperty(this.css_name(e)):n.el.style[this.css_name(e)]=t:console.warn("Style not applied because a parent view does not exist")},t.prototype.handleOverflowChange=function(e,t){var n=this.options.parent;n?null===t?null===this.model.get("overflow")&&n.el.style.removeProperty(this.css_name(e)):n.el.style[this.css_name(e)]=t:console.warn("Style not applied because a parent view does not exist")},t.prototype.unlayout=function(){var e=this,t=this.options.parent;this._traitNames.forEach((function(n){t?t.el.style.removeProperty(e.css_name(n)):console.warn("Style not removed because a parent view does not exist")}),this)},t}(Q),oe=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),ae=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return oe(t,e),t.prototype.defaults=function(){var t=this.constructor;return f(e.prototype.defaults.call(this),{_model_name:"StyleModel",_view_name:"StyleView"},Object.keys(t.styleProperties).reduce((function(e,n){return e[n]=t.styleProperties[n].default,e}),{}))},t.styleProperties={},t}(X),se=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return oe(t,e),t.prototype.initialize=function(t){this._traitNames=[],e.prototype.initialize.call(this,t);for(var n=this.model.constructor,r=0,i=Object.keys(n.styleProperties);r<i.length;r++){var o=i[r];this.registerTrait(o)}this.style()},t.prototype.registerTrait=function(e){var t=this;this._traitNames.push(e),this.listenTo(this.model,"change:"+e,(function(n,r){t.handleChange(e,r)}))},t.prototype.handleChange=function(e,t){var n=this.options.parent;if(n){var r=this.model.constructor.styleProperties,i=r[e].attribute,o=r[e].selector,a=o?n.el.querySelectorAll(o):[n.el];if(null===t)for(var s=0;s!==a.length;++s)a[s].style.removeProperty(i);else for(s=0;s!==a.length;++s)a[s].style[i]=t}else console.warn("Style not applied because a parent view does not exist")},t.prototype.style=function(){for(var e=0,t=this._traitNames;e<t.length;e++){var n=t[e];this.handleChange(n,this.model.get(n))}},t.prototype.unstyle=function(){var e=this.options.parent,t=this.model.constructor.styleProperties;this._traitNames.forEach((function(n){if(e)for(var r=t[n].attribute,i=t[n].selector,o=i?e.el.querySelectorAll(i):[e.el],a=0;a!==o.length;++a)o[a].style.removeProperty(r);else console.warn("Style not removed because a parent view does not exist")}),this)},t}(Q),le=function(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{l(r.next(e))}catch(e){o(e)}}function s(e){try{l(r.throw(e))}catch(e){o(e)}}function l(e){var t;e.done?i(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,s)}l((r=r.apply(e,t||[])).next())}))},ce=function(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}};!function(e){!function(e){var t=function(){function e(e){this.targets=Object.create(null),this.comms=Object.create(null),this.kernel=null,this.jsServicesKernel=null,this.init_kernel(e)}return e.prototype.init_kernel=function(e){this.kernel=e,this.jsServicesKernel=e},e.prototype.new_comm=function(e,t,r,i,o,a){return le(this,void 0,void 0,(function(){var s,l;return ce(this,(function(c){return s=this.jsServicesKernel.createComm(e,o),l=new n(s),this.register_comm(l),l.open(t,r,i,a),[2,l]}))}))},e.prototype.register_target=function(e,t){var r=this,i=this.jsServicesKernel.registerCommTarget(e,(function(e,i){var o=new n(e);r.register_comm(o);try{return t(o,i)}catch(e){o.close(),console.error(e),console.error(new Error("Exception opening new comm"))}}));this.targets[e]=i},e.prototype.unregister_target=function(e,t){this.targets[e].dispose(),delete this.targets[e]},e.prototype.register_comm=function(e){return this.comms[e.comm_id]=Promise.resolve(e),e.kernel=this.kernel,e.comm_id},e}();e.CommManager=t;var n=function(){function e(e){this.jsServicesComm=null,this.kernel=null,this.jsServicesComm=e}return Object.defineProperty(e.prototype,"comm_id",{get:function(){return this.jsServicesComm.commId},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"target_name",{get:function(){return this.jsServicesComm.targetName},enumerable:!0,configurable:!0}),e.prototype.open=function(e,t,n,r){var i=this.jsServicesComm.open(e,n,r);return this._hookupCallbacks(i,t),i.msg.header.msg_id},e.prototype.send=function(e,t,n,r){var i=this.jsServicesComm.send(e,n,r);return this._hookupCallbacks(i,t),i.msg.header.msg_id},e.prototype.close=function(e,t,n,r){var i=this.jsServicesComm.close(e,n,r);return this._hookupCallbacks(i,t),i.msg.header.msg_id},e.prototype.on_msg=function(e){this.jsServicesComm.onMsg=e.bind(this)},e.prototype.on_close=function(e){this.jsServicesComm.onClose=e.bind(this)},e.prototype._hookupCallbacks=function(e,t){t&&(e.onReply=function(e){t.shell&&t.shell.reply&&t.shell.reply(e)},e.onStdin=function(e){t.input&&t.input(e)},e.onIOPub=function(e){if(t.iopub)if(t.iopub.status&&"status"===e.header.msg_type)t.iopub.status(e);else if(t.iopub.clear_output&&"clear_output"===e.header.msg_type)t.iopub.clear_output(e);else if(t.iopub.output)switch(e.header.msg_type){case"display_data":case"execute_result":case"stream":case"error":t.iopub.output(e)}})},e}();e.Comm=n}(e.services||(e.services={}))}(K||(K={}));var ue=function(){function e(e,t,n){this.initialize(e,t,n)}return e.prototype.initialize=function(e,t,n){this._handler_context=n||this,this._models=[],this.views=[],this._create_view=e,this._remove_view=t||function(e){e.remove()}},e.prototype.update=function(e,t,n,r){var i=n||this._remove_view,o=t||this._create_view;r=r||this._handler_context;for(var a=0;a<e.length&&!(a>=this._models.length||e[a]!==this._models[a]);a++);for(var s=a,l=this.views.splice(s,this.views.length-s),c=0;c<l.length;c++)l[c].then((function(e){i.call(r,e)}));for(;a<e.length;a++)this.views.push(Promise.resolve(o.call(r,e[a],a)));return this._models=e.slice(),Promise.all(this.views)},e.prototype.remove=function(){var e=this;return Promise.all(this.views).then((function(t){t.forEach((function(t){return e._remove_view.call(e._handler_context,t)})),e.views=[],e._models=[]}))},e.prototype.dispose=function(){this.views=null,this._models=null},e}(),de=new o.Token("jupyter.extensions.jupyterWidgetRegistry")},function(e,t,n){"use strict";n.r(t),n.d(t,"default",(function(){return wn})),n.d(t,"VERSION",(function(){return i.e})),n.d(t,"restArguments",(function(){return o})),n.d(t,"isObject",(function(){return a})),n.d(t,"isNull",(function(){return s})),n.d(t,"isUndefined",(function(){return l})),n.d(t,"isBoolean",(function(){return c})),n.d(t,"isElement",(function(){return u})),n.d(t,"isString",(function(){return h})),n.d(t,"isNumber",(function(){return p})),n.d(t,"isDate",(function(){return f})),n.d(t,"isRegExp",(function(){return m})),n.d(t,"isError",(function(){return g})),n.d(t,"isSymbol",(function(){return v})),n.d(t,"isArrayBuffer",(function(){return y})),n.d(t,"isDataView",(function(){return E})),n.d(t,"isArray",(function(){return L})),n.d(t,"isFunction",(function(){return M})),n.d(t,"isArguments",(function(){return O})),n.d(t,"isFinite",(function(){return I})),n.d(t,"isNaN",(function(){return k})),n.d(t,"isTypedArray",(function(){return B})),n.d(t,"isEmpty",(function(){return V})),n.d(t,"isMatch",(function(){return U})),n.d(t,"isEqual",(function(){return K})),n.d(t,"isMap",(function(){return re})),n.d(t,"isWeakMap",(function(){return ie})),n.d(t,"isSet",(function(){return oe})),n.d(t,"isWeakSet",(function(){return ae})),n.d(t,"keys",(function(){return Y})),n.d(t,"allKeys",(function(){return X})),n.d(t,"values",(function(){return se})),n.d(t,"pairs",(function(){return le})),n.d(t,"invert",(function(){return ce})),n.d(t,"functions",(function(){return ue})),n.d(t,"methods",(function(){return ue})),n.d(t,"extend",(function(){return he})),n.d(t,"extendOwn",(function(){return pe})),n.d(t,"assign",(function(){return pe})),n.d(t,"defaults",(function(){return fe})),n.d(t,"create",(function(){return ge})),n.d(t,"clone",(function(){return ve})),n.d(t,"tap",(function(){return ye})),n.d(t,"get",(function(){return we})),n.d(t,"has",(function(){return Ae})),n.d(t,"mapObject",(function(){return Ie})),n.d(t,"identity",(function(){return Ce})),n.d(t,"constant",(function(){return D})),n.d(t,"noop",(function(){return ke})),n.d(t,"toPath",(function(){return _e})),n.d(t,"property",(function(){return Ee})),n.d(t,"propertyOf",(function(){return De})),n.d(t,"matcher",(function(){return xe})),n.d(t,"matches",(function(){return xe})),n.d(t,"times",(function(){return Ne})),n.d(t,"random",(function(){return je})),n.d(t,"now",(function(){return Pe})),n.d(t,"escape",(function(){return Be})),n.d(t,"unescape",(function(){return He})),n.d(t,"templateSettings",(function(){return Fe})),n.d(t,"template",(function(){return qe})),n.d(t,"result",(function(){return Ke})),n.d(t,"uniqueId",(function(){return Je})),n.d(t,"chain",(function(){return Qe})),n.d(t,"iteratee",(function(){return Te})),n.d(t,"partial",(function(){return et})),n.d(t,"bind",(function(){return tt})),n.d(t,"bindAll",(function(){return it})),n.d(t,"memoize",(function(){return ot})),n.d(t,"delay",(function(){return at})),n.d(t,"defer",(function(){return st})),n.d(t,"throttle",(function(){return lt})),n.d(t,"debounce",(function(){return ct})),n.d(t,"wrap",(function(){return ut})),n.d(t,"negate",(function(){return dt})),n.d(t,"compose",(function(){return ht})),n.d(t,"after",(function(){return pt})),n.d(t,"before",(function(){return ft})),n.d(t,"once",(function(){return mt})),n.d(t,"findKey",(function(){return gt})),n.d(t,"findIndex",(function(){return yt})),n.d(t,"findLastIndex",(function(){return _t})),n.d(t,"sortedIndex",(function(){return bt})),n.d(t,"indexOf",(function(){return wt})),n.d(t,"lastIndexOf",(function(){return At})),n.d(t,"find",(function(){return Ct})),n.d(t,"detect",(function(){return Ct})),n.d(t,"findWhere",(function(){return xt})),n.d(t,"each",(function(){return Et})),n.d(t,"forEach",(function(){return Et})),n.d(t,"map",(function(){return Lt})),n.d(t,"collect",(function(){return Lt})),n.d(t,"reduce",(function(){return Tt})),n.d(t,"foldl",(function(){return Tt})),n.d(t,"inject",(function(){return Tt})),n.d(t,"reduceRight",(function(){return Ot})),n.d(t,"foldr",(function(){return Ot})),n.d(t,"filter",(function(){return It})),n.d(t,"select",(function(){return It})),n.d(t,"reject",(function(){return kt})),n.d(t,"every",(function(){return Dt})),n.d(t,"all",(function(){return Dt})),n.d(t,"some",(function(){return Nt})),n.d(t,"any",(function(){return Nt})),n.d(t,"contains",(function(){return jt})),n.d(t,"includes",(function(){return jt})),n.d(t,"include",(function(){return jt})),n.d(t,"invoke",(function(){return Pt})),n.d(t,"pluck",(function(){return zt})),n.d(t,"where",(function(){return Rt})),n.d(t,"max",(function(){return Bt})),n.d(t,"min",(function(){return Ht})),n.d(t,"shuffle",(function(){return Ut})),n.d(t,"sample",(function(){return Vt})),n.d(t,"sortBy",(function(){return Wt})),n.d(t,"groupBy",(function(){return qt})),n.d(t,"indexBy",(function(){return Kt})),n.d(t,"countBy",(function(){return Xt})),n.d(t,"partition",(function(){return Jt})),n.d(t,"toArray",(function(){return Yt})),n.d(t,"size",(function(){return Qt})),n.d(t,"pick",(function(){return $t})),n.d(t,"omit",(function(){return en})),n.d(t,"first",(function(){return nn})),n.d(t,"head",(function(){return nn})),n.d(t,"take",(function(){return nn})),n.d(t,"initial",(function(){return tn})),n.d(t,"last",(function(){return on})),n.d(t,"rest",(function(){return rn})),n.d(t,"tail",(function(){return rn})),n.d(t,"drop",(function(){return rn})),n.d(t,"compact",(function(){return an})),n.d(t,"flatten",(function(){return sn})),n.d(t,"without",(function(){return cn})),n.d(t,"uniq",(function(){return un})),n.d(t,"unique",(function(){return un})),n.d(t,"union",(function(){return dn})),n.d(t,"intersection",(function(){return hn})),n.d(t,"difference",(function(){return ln})),n.d(t,"unzip",(function(){return pn})),n.d(t,"transpose",(function(){return pn})),n.d(t,"zip",(function(){return fn})),n.d(t,"object",(function(){return mn})),n.d(t,"range",(function(){return gn})),n.d(t,"chunk",(function(){return vn})),n.d(t,"mixin",(function(){return _n}));var r={};n.r(r),n.d(r,"VERSION",(function(){return i.e})),n.d(r,"restArguments",(function(){return o})),n.d(r,"isObject",(function(){return a})),n.d(r,"isNull",(function(){return s})),n.d(r,"isUndefined",(function(){return l})),n.d(r,"isBoolean",(function(){return c})),n.d(r,"isElement",(function(){return u})),n.d(r,"isString",(function(){return h})),n.d(r,"isNumber",(function(){return p})),n.d(r,"isDate",(function(){return f})),n.d(r,"isRegExp",(function(){return m})),n.d(r,"isError",(function(){return g})),n.d(r,"isSymbol",(function(){return v})),n.d(r,"isArrayBuffer",(function(){return y})),n.d(r,"isDataView",(function(){return E})),n.d(r,"isArray",(function(){return L})),n.d(r,"isFunction",(function(){return M})),n.d(r,"isArguments",(function(){return O})),n.d(r,"isFinite",(function(){return I})),n.d(r,"isNaN",(function(){return k})),n.d(r,"isTypedArray",(function(){return B})),n.d(r,"isEmpty",(function(){return V})),n.d(r,"isMatch",(function(){return U})),n.d(r,"isEqual",(function(){return K})),n.d(r,"isMap",(function(){return re})),n.d(r,"isWeakMap",(function(){return ie})),n.d(r,"isSet",(function(){return oe})),n.d(r,"isWeakSet",(function(){return ae})),n.d(r,"keys",(function(){return Y})),n.d(r,"allKeys",(function(){return X})),n.d(r,"values",(function(){return se})),n.d(r,"pairs",(function(){return le})),n.d(r,"invert",(function(){return ce})),n.d(r,"functions",(function(){return ue})),n.d(r,"methods",(function(){return ue})),n.d(r,"extend",(function(){return he})),n.d(r,"extendOwn",(function(){return pe})),n.d(r,"assign",(function(){return pe})),n.d(r,"defaults",(function(){return fe})),n.d(r,"create",(function(){return ge})),n.d(r,"clone",(function(){return ve})),n.d(r,"tap",(function(){return ye})),n.d(r,"get",(function(){return we})),n.d(r,"has",(function(){return Ae})),n.d(r,"mapObject",(function(){return Ie})),n.d(r,"identity",(function(){return Ce})),n.d(r,"constant",(function(){return D})),n.d(r,"noop",(function(){return ke})),n.d(r,"toPath",(function(){return _e})),n.d(r,"property",(function(){return Ee})),n.d(r,"propertyOf",(function(){return De})),n.d(r,"matcher",(function(){return xe})),n.d(r,"matches",(function(){return xe})),n.d(r,"times",(function(){return Ne})),n.d(r,"random",(function(){return je})),n.d(r,"now",(function(){return Pe})),n.d(r,"escape",(function(){return Be})),n.d(r,"unescape",(function(){return He})),n.d(r,"templateSettings",(function(){return Fe})),n.d(r,"template",(function(){return qe})),n.d(r,"result",(function(){return Ke})),n.d(r,"uniqueId",(function(){return Je})),n.d(r,"chain",(function(){return Qe})),n.d(r,"iteratee",(function(){return Te})),n.d(r,"partial",(function(){return et})),n.d(r,"bind",(function(){return tt})),n.d(r,"bindAll",(function(){return it})),n.d(r,"memoize",(function(){return ot})),n.d(r,"delay",(function(){return at})),n.d(r,"defer",(function(){return st})),n.d(r,"throttle",(function(){return lt})),n.d(r,"debounce",(function(){return ct})),n.d(r,"wrap",(function(){return ut})),n.d(r,"negate",(function(){return dt})),n.d(r,"compose",(function(){return ht})),n.d(r,"after",(function(){return pt})),n.d(r,"before",(function(){return ft})),n.d(r,"once",(function(){return mt})),n.d(r,"findKey",(function(){return gt})),n.d(r,"findIndex",(function(){return yt})),n.d(r,"findLastIndex",(function(){return _t})),n.d(r,"sortedIndex",(function(){return bt})),n.d(r,"indexOf",(function(){return wt})),n.d(r,"lastIndexOf",(function(){return At})),n.d(r,"find",(function(){return Ct})),n.d(r,"detect",(function(){return Ct})),n.d(r,"findWhere",(function(){return xt})),n.d(r,"each",(function(){return Et})),n.d(r,"forEach",(function(){return Et})),n.d(r,"map",(function(){return Lt})),n.d(r,"collect",(function(){return Lt})),n.d(r,"reduce",(function(){return Tt})),n.d(r,"foldl",(function(){return Tt})),n.d(r,"inject",(function(){return Tt})),n.d(r,"reduceRight",(function(){return Ot})),n.d(r,"foldr",(function(){return Ot})),n.d(r,"filter",(function(){return It})),n.d(r,"select",(function(){return It})),n.d(r,"reject",(function(){return kt})),n.d(r,"every",(function(){return Dt})),n.d(r,"all",(function(){return Dt})),n.d(r,"some",(function(){return Nt})),n.d(r,"any",(function(){return Nt})),n.d(r,"contains",(function(){return jt})),n.d(r,"includes",(function(){return jt})),n.d(r,"include",(function(){return jt})),n.d(r,"invoke",(function(){return Pt})),n.d(r,"pluck",(function(){return zt})),n.d(r,"where",(function(){return Rt})),n.d(r,"max",(function(){return Bt})),n.d(r,"min",(function(){return Ht})),n.d(r,"shuffle",(function(){return Ut})),n.d(r,"sample",(function(){return Vt})),n.d(r,"sortBy",(function(){return Wt})),n.d(r,"groupBy",(function(){return qt})),n.d(r,"indexBy",(function(){return Kt})),n.d(r,"countBy",(function(){return Xt})),n.d(r,"partition",(function(){return Jt})),n.d(r,"toArray",(function(){return Yt})),n.d(r,"size",(function(){return Qt})),n.d(r,"pick",(function(){return $t})),n.d(r,"omit",(function(){return en})),n.d(r,"first",(function(){return nn})),n.d(r,"head",(function(){return nn})),n.d(r,"take",(function(){return nn})),n.d(r,"initial",(function(){return tn})),n.d(r,"last",(function(){return on})),n.d(r,"rest",(function(){return rn})),n.d(r,"tail",(function(){return rn})),n.d(r,"drop",(function(){return rn})),n.d(r,"compact",(function(){return an})),n.d(r,"flatten",(function(){return sn})),n.d(r,"without",(function(){return cn})),n.d(r,"uniq",(function(){return un})),n.d(r,"unique",(function(){return un})),n.d(r,"union",(function(){return dn})),n.d(r,"intersection",(function(){return hn})),n.d(r,"difference",(function(){return ln})),n.d(r,"unzip",(function(){return pn})),n.d(r,"transpose",(function(){return pn})),n.d(r,"zip",(function(){return fn})),n.d(r,"object",(function(){return mn})),n.d(r,"range",(function(){return gn})),n.d(r,"chunk",(function(){return vn})),n.d(r,"mixin",(function(){return _n})),n.d(r,"default",(function(){return bn}));var i=n(20);function o(e,t){return t=null==t?e.length-1:+t,function(){for(var n=Math.max(arguments.length-t,0),r=Array(n),i=0;i<n;i++)r[i]=arguments[i+t];switch(t){case 0:return e.call(this,r);case 1:return e.call(this,arguments[0],r);case 2:return e.call(this,arguments[0],arguments[1],r)}var o=Array(t+1);for(i=0;i<t;i++)o[i]=arguments[i];return o[t]=r,e.apply(this,o)}}function a(e){var t=typeof e;return"function"===t||"object"===t&&!!e}function s(e){return null===e}function l(e){return void 0===e}function c(e){return!0===e||!1===e||"[object Boolean]"===i.t.call(e)}function u(e){return!(!e||1!==e.nodeType)}function d(e){var t="[object "+e+"]";return function(e){return i.t.call(e)===t}}var h=d("String"),p=d("Number"),f=d("Date"),m=d("RegExp"),g=d("Error"),v=d("Symbol"),y=d("ArrayBuffer"),_=d("Function"),b=i.p.document&&i.p.document.childNodes;"object"!=typeof Int8Array&&"function"!=typeof b&&(_=function(e){return"function"==typeof e||!1});var M=_,w=d("Object"),A=i.s&&w(new DataView(new ArrayBuffer(8))),C="undefined"!=typeof Map&&w(new Map),x=d("DataView");var E=A?function(e){return null!=e&&M(e.getInt8)&&y(e.buffer)}:x,L=i.k||d("Array");function S(e,t){return null!=e&&i.i.call(e,t)}var T=d("Arguments");!function(){T(arguments)||(T=function(e){return S(e,"callee")})}();var O=T;function I(e){return!v(e)&&Object(i.f)(e)&&!isNaN(parseFloat(e))}function k(e){return p(e)&&Object(i.g)(e)}function D(e){return function(){return e}}function N(e){return function(t){var n=e(t);return"number"==typeof n&&n>=0&&n<=i.b}}function j(e){return function(t){return null==t?void 0:t[e]}}var P=j("byteLength"),z=N(P),R=/\[object ((I|Ui)nt(8|16|32)|Float(32|64)|Uint8Clamped|Big(I|Ui)nt64)Array\]/;var B=i.r?function(e){return i.l?Object(i.l)(e)&&!E(e):z(e)&&R.test(i.t.call(e))}:D(!1),H=j("length");function F(e,t){t=function(e){for(var t={},n=e.length,r=0;r<n;++r)t[e[r]]=!0;return{contains:function(e){return!0===t[e]},push:function(n){return t[n]=!0,e.push(n)}}}(t);var n=i.n.length,r=e.constructor,o=M(r)&&r.prototype||i.c,a="constructor";for(S(e,a)&&!t.contains(a)&&t.push(a);n--;)(a=i.n[n])in e&&e[a]!==o[a]&&!t.contains(a)&&t.push(a)}function Y(e){if(!a(e))return[];if(i.m)return Object(i.m)(e);var t=[];for(var n in e)S(e,n)&&t.push(n);return i.h&&F(e,t),t}function V(e){if(null==e)return!0;var t=H(e);return"number"==typeof t&&(L(e)||h(e)||O(e))?0===t:0===H(Y(e))}function U(e,t){var n=Y(t),r=n.length;if(null==e)return!r;for(var i=Object(e),o=0;o<r;o++){var a=n[o];if(t[a]!==i[a]||!(a in i))return!1}return!0}function W(e){return e instanceof W?e:this instanceof W?void(this._wrapped=e):new W(e)}function G(e){return new Uint8Array(e.buffer||e,e.byteOffset||0,P(e))}W.VERSION=i.e,W.prototype.value=function(){return this._wrapped},W.prototype.valueOf=W.prototype.toJSON=W.prototype.value,W.prototype.toString=function(){return String(this._wrapped)};function q(e,t,n,r){if(e===t)return 0!==e||1/e==1/t;if(null==e||null==t)return!1;if(e!=e)return t!=t;var o=typeof e;return("function"===o||"object"===o||"object"==typeof t)&&function e(t,n,r,o){t instanceof W&&(t=t._wrapped);n instanceof W&&(n=n._wrapped);var a=i.t.call(t);if(a!==i.t.call(n))return!1;if(A&&"[object Object]"==a&&E(t)){if(!E(n))return!1;a="[object DataView]"}switch(a){case"[object RegExp]":case"[object String]":return""+t==""+n;case"[object Number]":return+t!=+t?+n!=+n:0==+t?1/+t==1/n:+t==+n;case"[object Date]":case"[object Boolean]":return+t==+n;case"[object Symbol]":return i.d.valueOf.call(t)===i.d.valueOf.call(n);case"[object ArrayBuffer]":case"[object DataView]":return e(G(t),G(n),r,o)}var s="[object Array]"===a;if(!s&&B(t)){if(P(t)!==P(n))return!1;if(t.buffer===n.buffer&&t.byteOffset===n.byteOffset)return!0;s=!0}if(!s){if("object"!=typeof t||"object"!=typeof n)return!1;var l=t.constructor,c=n.constructor;if(l!==c&&!(M(l)&&l instanceof l&&M(c)&&c instanceof c)&&"constructor"in t&&"constructor"in n)return!1}o=o||[];var u=(r=r||[]).length;for(;u--;)if(r[u]===t)return o[u]===n;if(r.push(t),o.push(n),s){if((u=t.length)!==n.length)return!1;for(;u--;)if(!q(t[u],n[u],r,o))return!1}else{var d,h=Y(t);if(u=h.length,Y(n).length!==u)return!1;for(;u--;)if(d=h[u],!S(n,d)||!q(t[d],n[d],r,o))return!1}return r.pop(),o.pop(),!0}(e,t,n,r)}function K(e,t){return q(e,t)}function X(e){if(!a(e))return[];var t=[];for(var n in e)t.push(n);return i.h&&F(e,t),t}function J(e){var t=H(e);return function(n){if(null==n)return!1;var r=X(n);if(H(r))return!1;for(var i=0;i<t;i++)if(!M(n[e[i]]))return!1;return e!==te||!M(n[Q])}}var Q="forEach",Z=["clear","delete"],$=["get","has","set"],ee=Z.concat(Q,$),te=Z.concat($),ne=["add"].concat(Z,Q,"has"),re=C?J(ee):d("Map"),ie=C?J(te):d("WeakMap"),oe=C?J(ne):d("Set"),ae=d("WeakSet");function se(e){for(var t=Y(e),n=t.length,r=Array(n),i=0;i<n;i++)r[i]=e[t[i]];return r}function le(e){for(var t=Y(e),n=t.length,r=Array(n),i=0;i<n;i++)r[i]=[t[i],e[t[i]]];return r}function ce(e){for(var t={},n=Y(e),r=0,i=n.length;r<i;r++)t[e[n[r]]]=n[r];return t}function ue(e){var t=[];for(var n in e)M(e[n])&&t.push(n);return t.sort()}function de(e,t){return function(n){var r=arguments.length;if(t&&(n=Object(n)),r<2||null==n)return n;for(var i=1;i<r;i++)for(var o=arguments[i],a=e(o),s=a.length,l=0;l<s;l++){var c=a[l];t&&void 0!==n[c]||(n[c]=o[c])}return n}}var he=de(X),pe=de(Y),fe=de(X,!0);function me(e){if(!a(e))return{};if(i.j)return Object(i.j)(e);var t=function(){};t.prototype=e;var n=new t;return t.prototype=null,n}function ge(e,t){var n=me(e);return t&&pe(n,t),n}function ve(e){return a(e)?L(e)?e.slice():he({},e):e}function ye(e,t){return t(e),e}function _e(e){return L(e)?e:[e]}function be(e){return W.toPath(e)}function Me(e,t){for(var n=t.length,r=0;r<n;r++){if(null==e)return;e=e[t[r]]}return n?e:void 0}function we(e,t,n){var r=Me(e,be(t));return l(r)?n:r}function Ae(e,t){for(var n=(t=be(t)).length,r=0;r<n;r++){var i=t[r];if(!S(e,i))return!1;e=e[i]}return!!n}function Ce(e){return e}function xe(e){return e=pe({},e),function(t){return U(t,e)}}function Ee(e){return e=be(e),function(t){return Me(t,e)}}function Le(e,t,n){if(void 0===t)return e;switch(null==n?3:n){case 1:return function(n){return e.call(t,n)};case 3:return function(n,r,i){return e.call(t,n,r,i)};case 4:return function(n,r,i,o){return e.call(t,n,r,i,o)}}return function(){return e.apply(t,arguments)}}function Se(e,t,n){return null==e?Ce:M(e)?Le(e,t,n):a(e)&&!L(e)?xe(e):Ee(e)}function Te(e,t){return Se(e,t,1/0)}function Oe(e,t,n){return W.iteratee!==Te?W.iteratee(e,t):Se(e,t,n)}function Ie(e,t,n){t=Oe(t,n);for(var r=Y(e),i=r.length,o={},a=0;a<i;a++){var s=r[a];o[s]=t(e[s],s,e)}return o}function ke(){}function De(e){return null==e?ke:function(t){return we(e,t)}}function Ne(e,t,n){var r=Array(Math.max(0,e));t=Le(t,n,1);for(var i=0;i<e;i++)r[i]=t(i);return r}function je(e,t){return null==t&&(t=e,e=0),e+Math.floor(Math.random()*(t-e+1))}W.toPath=_e,W.iteratee=Te;var Pe=Date.now||function(){return(new Date).getTime()};function ze(e){var t=function(t){return e[t]},n="(?:"+Y(e).join("|")+")",r=RegExp(n),i=RegExp(n,"g");return function(e){return e=null==e?"":""+e,r.test(e)?e.replace(i,t):e}}var Re={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},Be=ze(Re),He=ze(ce(Re)),Fe=W.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g},Ye=/(.)^/,Ve={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},Ue=/\\|'|\r|\n|\u2028|\u2029/g;function We(e){return"\\"+Ve[e]}var Ge=/^\s*(\w|\$)+\s*$/;function qe(e,t,n){!t&&n&&(t=n),t=fe({},t,W.templateSettings);var r=RegExp([(t.escape||Ye).source,(t.interpolate||Ye).source,(t.evaluate||Ye).source].join("|")+"|$","g"),i=0,o="__p+='";e.replace(r,(function(t,n,r,a,s){return o+=e.slice(i,s).replace(Ue,We),i=s+t.length,n?o+="'+\n((__t=("+n+"))==null?'':_.escape(__t))+\n'":r?o+="'+\n((__t=("+r+"))==null?'':__t)+\n'":a&&(o+="';\n"+a+"\n__p+='"),t})),o+="';\n";var a,s=t.variable;if(s){if(!Ge.test(s))throw new Error("variable is not a bare identifier: "+s)}else o="with(obj||{}){\n"+o+"}\n",s="obj";o="var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};\n"+o+"return __p;\n";try{a=new Function(s,"_",o)}catch(e){throw e.source=o,e}var l=function(e){return a.call(this,e,W)};return l.source="function("+s+"){\n"+o+"}",l}function Ke(e,t,n){var r=(t=be(t)).length;if(!r)return M(n)?n.call(e):n;for(var i=0;i<r;i++){var o=null==e?void 0:e[t[i]];void 0===o&&(o=n,i=r),e=M(o)?o.call(e):o}return e}var Xe=0;function Je(e){var t=++Xe+"";return e?e+t:t}function Qe(e){var t=W(e);return t._chain=!0,t}function Ze(e,t,n,r,i){if(!(r instanceof t))return e.apply(n,i);var o=me(e.prototype),s=e.apply(o,i);return a(s)?s:o}var $e=o((function(e,t){var n=$e.placeholder,r=function(){for(var i=0,o=t.length,a=Array(o),s=0;s<o;s++)a[s]=t[s]===n?arguments[i++]:t[s];for(;i<arguments.length;)a.push(arguments[i++]);return Ze(e,r,this,this,a)};return r}));$e.placeholder=W;var et=$e,tt=o((function(e,t,n){if(!M(e))throw new TypeError("Bind must be called on a function");var r=o((function(i){return Ze(e,r,t,this,n.concat(i))}));return r})),nt=N(H);function rt(e,t,n,r){if(r=r||[],t||0===t){if(t<=0)return r.concat(e)}else t=1/0;for(var i=r.length,o=0,a=H(e);o<a;o++){var s=e[o];if(nt(s)&&(L(s)||O(s)))if(t>1)rt(s,t-1,n,r),i=r.length;else for(var l=0,c=s.length;l<c;)r[i++]=s[l++];else n||(r[i++]=s)}return r}var it=o((function(e,t){var n=(t=rt(t,!1,!1)).length;if(n<1)throw new Error("bindAll must be passed function names");for(;n--;){var r=t[n];e[r]=tt(e[r],e)}return e}));function ot(e,t){var n=function(r){var i=n.cache,o=""+(t?t.apply(this,arguments):r);return S(i,o)||(i[o]=e.apply(this,arguments)),i[o]};return n.cache={},n}var at=o((function(e,t,n){return setTimeout((function(){return e.apply(null,n)}),t)})),st=et(at,W,1);function lt(e,t,n){var r,i,o,a,s=0;n||(n={});var l=function(){s=!1===n.leading?0:Pe(),r=null,a=e.apply(i,o),r||(i=o=null)},c=function(){var c=Pe();s||!1!==n.leading||(s=c);var u=t-(c-s);return i=this,o=arguments,u<=0||u>t?(r&&(clearTimeout(r),r=null),s=c,a=e.apply(i,o),r||(i=o=null)):r||!1===n.trailing||(r=setTimeout(l,u)),a};return c.cancel=function(){clearTimeout(r),s=0,r=i=o=null},c}function ct(e,t,n){var r,i,a,s,l,c=function(){var o=Pe()-i;t>o?r=setTimeout(c,t-o):(r=null,n||(s=e.apply(l,a)),r||(a=l=null))},u=o((function(o){return l=this,a=o,i=Pe(),r||(r=setTimeout(c,t),n&&(s=e.apply(l,a))),s}));return u.cancel=function(){clearTimeout(r),r=a=l=null},u}function ut(e,t){return et(t,e)}function dt(e){return function(){return!e.apply(this,arguments)}}function ht(){var e=arguments,t=e.length-1;return function(){for(var n=t,r=e[t].apply(this,arguments);n--;)r=e[n].call(this,r);return r}}function pt(e,t){return function(){if(--e<1)return t.apply(this,arguments)}}function ft(e,t){var n;return function(){return--e>0&&(n=t.apply(this,arguments)),e<=1&&(t=null),n}}var mt=et(ft,2);function gt(e,t,n){t=Oe(t,n);for(var r,i=Y(e),o=0,a=i.length;o<a;o++)if(t(e[r=i[o]],r,e))return r}function vt(e){return function(t,n,r){n=Oe(n,r);for(var i=H(t),o=e>0?0:i-1;o>=0&&o<i;o+=e)if(n(t[o],o,t))return o;return-1}}var yt=vt(1),_t=vt(-1);function bt(e,t,n,r){for(var i=(n=Oe(n,r,1))(t),o=0,a=H(e);o<a;){var s=Math.floor((o+a)/2);n(e[s])<i?o=s+1:a=s}return o}function Mt(e,t,n){return function(r,o,a){var s=0,l=H(r);if("number"==typeof a)e>0?s=a>=0?a:Math.max(a+l,s):l=a>=0?Math.min(a+1,l):a+l+1;else if(n&&a&&l)return r[a=n(r,o)]===o?a:-1;if(o!=o)return(a=t(i.q.call(r,s,l),k))>=0?a+s:-1;for(a=e>0?s:l-1;a>=0&&a<l;a+=e)if(r[a]===o)return a;return-1}}var wt=Mt(1,yt,bt),At=Mt(-1,_t);function Ct(e,t,n){var r=(nt(e)?yt:gt)(e,t,n);if(void 0!==r&&-1!==r)return e[r]}function xt(e,t){return Ct(e,xe(t))}function Et(e,t,n){var r,i;if(t=Le(t,n),nt(e))for(r=0,i=e.length;r<i;r++)t(e[r],r,e);else{var o=Y(e);for(r=0,i=o.length;r<i;r++)t(e[o[r]],o[r],e)}return e}function Lt(e,t,n){t=Oe(t,n);for(var r=!nt(e)&&Y(e),i=(r||e).length,o=Array(i),a=0;a<i;a++){var s=r?r[a]:a;o[a]=t(e[s],s,e)}return o}function St(e){var t=function(t,n,r,i){var o=!nt(t)&&Y(t),a=(o||t).length,s=e>0?0:a-1;for(i||(r=t[o?o[s]:s],s+=e);s>=0&&s<a;s+=e){var l=o?o[s]:s;r=n(r,t[l],l,t)}return r};return function(e,n,r,i){var o=arguments.length>=3;return t(e,Le(n,i,4),r,o)}}var Tt=St(1),Ot=St(-1);function It(e,t,n){var r=[];return t=Oe(t,n),Et(e,(function(e,n,i){t(e,n,i)&&r.push(e)})),r}function kt(e,t,n){return It(e,dt(Oe(t)),n)}function Dt(e,t,n){t=Oe(t,n);for(var r=!nt(e)&&Y(e),i=(r||e).length,o=0;o<i;o++){var a=r?r[o]:o;if(!t(e[a],a,e))return!1}return!0}function Nt(e,t,n){t=Oe(t,n);for(var r=!nt(e)&&Y(e),i=(r||e).length,o=0;o<i;o++){var a=r?r[o]:o;if(t(e[a],a,e))return!0}return!1}function jt(e,t,n,r){return nt(e)||(e=se(e)),("number"!=typeof n||r)&&(n=0),wt(e,t,n)>=0}var Pt=o((function(e,t,n){var r,i;return M(t)?i=t:(t=be(t),r=t.slice(0,-1),t=t[t.length-1]),Lt(e,(function(e){var o=i;if(!o){if(r&&r.length&&(e=Me(e,r)),null==e)return;o=e[t]}return null==o?o:o.apply(e,n)}))}));function zt(e,t){return Lt(e,Ee(t))}function Rt(e,t){return It(e,xe(t))}function Bt(e,t,n){var r,i,o=-1/0,a=-1/0;if(null==t||"number"==typeof t&&"object"!=typeof e[0]&&null!=e)for(var s=0,l=(e=nt(e)?e:se(e)).length;s<l;s++)null!=(r=e[s])&&r>o&&(o=r);else t=Oe(t,n),Et(e,(function(e,n,r){((i=t(e,n,r))>a||i===-1/0&&o===-1/0)&&(o=e,a=i)}));return o}function Ht(e,t,n){var r,i,o=1/0,a=1/0;if(null==t||"number"==typeof t&&"object"!=typeof e[0]&&null!=e)for(var s=0,l=(e=nt(e)?e:se(e)).length;s<l;s++)null!=(r=e[s])&&r<o&&(o=r);else t=Oe(t,n),Et(e,(function(e,n,r){((i=t(e,n,r))<a||i===1/0&&o===1/0)&&(o=e,a=i)}));return o}var Ft=/[^\ud800-\udfff]|[\ud800-\udbff][\udc00-\udfff]|[\ud800-\udfff]/g;function Yt(e){return e?L(e)?i.q.call(e):h(e)?e.match(Ft):nt(e)?Lt(e,Ce):se(e):[]}function Vt(e,t,n){if(null==t||n)return nt(e)||(e=se(e)),e[je(e.length-1)];var r=Yt(e),i=H(r);t=Math.max(Math.min(t,i),0);for(var o=i-1,a=0;a<t;a++){var s=je(a,o),l=r[a];r[a]=r[s],r[s]=l}return r.slice(0,t)}function Ut(e){return Vt(e,1/0)}function Wt(e,t,n){var r=0;return t=Oe(t,n),zt(Lt(e,(function(e,n,i){return{value:e,index:r++,criteria:t(e,n,i)}})).sort((function(e,t){var n=e.criteria,r=t.criteria;if(n!==r){if(n>r||void 0===n)return 1;if(n<r||void 0===r)return-1}return e.index-t.index})),"value")}function Gt(e,t){return function(n,r,i){var o=t?[[],[]]:{};return r=Oe(r,i),Et(n,(function(t,i){var a=r(t,i,n);e(o,t,a)})),o}}var qt=Gt((function(e,t,n){S(e,n)?e[n].push(t):e[n]=[t]})),Kt=Gt((function(e,t,n){e[n]=t})),Xt=Gt((function(e,t,n){S(e,n)?e[n]++:e[n]=1})),Jt=Gt((function(e,t,n){e[n?0:1].push(t)}),!0);function Qt(e){return null==e?0:nt(e)?e.length:Y(e).length}function Zt(e,t,n){return t in n}var $t=o((function(e,t){var n={},r=t[0];if(null==e)return n;M(r)?(t.length>1&&(r=Le(r,t[1])),t=X(e)):(r=Zt,t=rt(t,!1,!1),e=Object(e));for(var i=0,o=t.length;i<o;i++){var a=t[i],s=e[a];r(s,a,e)&&(n[a]=s)}return n})),en=o((function(e,t){var n,r=t[0];return M(r)?(r=dt(r),t.length>1&&(n=t[1])):(t=Lt(rt(t,!1,!1),String),r=function(e,n){return!jt(t,n)}),$t(e,r,n)}));function tn(e,t,n){return i.q.call(e,0,Math.max(0,e.length-(null==t||n?1:t)))}function nn(e,t,n){return null==e||e.length<1?null==t||n?void 0:[]:null==t||n?e[0]:tn(e,e.length-t)}function rn(e,t,n){return i.q.call(e,null==t||n?1:t)}function on(e,t,n){return null==e||e.length<1?null==t||n?void 0:[]:null==t||n?e[e.length-1]:rn(e,Math.max(0,e.length-t))}function an(e){return It(e,Boolean)}function sn(e,t){return rt(e,t,!1)}var ln=o((function(e,t){return t=rt(t,!0,!0),It(e,(function(e){return!jt(t,e)}))})),cn=o((function(e,t){return ln(e,t)}));function un(e,t,n,r){c(t)||(r=n,n=t,t=!1),null!=n&&(n=Oe(n,r));for(var i=[],o=[],a=0,s=H(e);a<s;a++){var l=e[a],u=n?n(l,a,e):l;t&&!n?(a&&o===u||i.push(l),o=u):n?jt(o,u)||(o.push(u),i.push(l)):jt(i,l)||i.push(l)}return i}var dn=o((function(e){return un(rt(e,!0,!0))}));function hn(e){for(var t=[],n=arguments.length,r=0,i=H(e);r<i;r++){var o=e[r];if(!jt(t,o)){var a;for(a=1;a<n&&jt(arguments[a],o);a++);a===n&&t.push(o)}}return t}function pn(e){for(var t=e&&Bt(e,H).length||0,n=Array(t),r=0;r<t;r++)n[r]=zt(e,r);return n}var fn=o(pn);function mn(e,t){for(var n={},r=0,i=H(e);r<i;r++)t?n[e[r]]=t[r]:n[e[r][0]]=e[r][1];return n}function gn(e,t,n){null==t&&(t=e||0,e=0),n||(n=t<e?-1:1);for(var r=Math.max(Math.ceil((t-e)/n),0),i=Array(r),o=0;o<r;o++,e+=n)i[o]=e;return i}function vn(e,t){if(null==t||t<1)return[];for(var n=[],r=0,o=e.length;r<o;)n.push(i.q.call(e,r,r+=t));return n}function yn(e,t){return e._chain?W(t).chain():t}function _n(e){return Et(ue(e),(function(t){var n=W[t]=e[t];W.prototype[t]=function(){var e=[this._wrapped];return i.o.apply(e,arguments),yn(this,n.apply(W,e))}})),W}Et(["pop","push","reverse","shift","sort","splice","unshift"],(function(e){var t=i.a[e];W.prototype[e]=function(){var n=this._wrapped;return null!=n&&(t.apply(n,arguments),"shift"!==e&&"splice"!==e||0!==n.length||delete n[0]),yn(this,n)}})),Et(["concat","join","slice"],(function(e){var t=i.a[e];W.prototype[e]=function(){var e=this._wrapped;return null!=e&&(e=t.apply(e,arguments)),yn(this,e)}}));var bn=W,Mn=_n(r);Mn._=Mn;var wn=Mn},function(e,t,n){"use strict";n.d(t,"d",(function(){return i})),n.d(t,"c",(function(){return o})),n.d(t,"a",(function(){return a})),n.d(t,"b",(function(){return s})),n.d(t,"e",(function(){return l})),n.d(t,"g",(function(){return c})),n.d(t,"f",(function(){return u})),n.d(t,"l",(function(){return d})),n.d(t,"o",(function(){return h})),n.d(t,"n",(function(){return p})),n.d(t,"m",(function(){return f})),n.d(t,"p",(function(){return m})),n.d(t,"x",(function(){return g})),n.d(t,"v",(function(){return v})),n.d(t,"t",(function(){return y})),n.d(t,"w",(function(){return _})),n.d(t,"u",(function(){return b})),n.d(t,"y",(function(){return M})),n.d(t,"s",(function(){return w})),n.d(t,"A",(function(){return A})),n.d(t,"B",(function(){return C})),n.d(t,"z",(function(){return x})),n.d(t,"D",(function(){return E})),n.d(t,"C",(function(){return L})),n.d(t,"J",(function(){return S})),n.d(t,"E",(function(){return T})),n.d(t,"F",(function(){return O})),n.d(t,"G",(function(){return I})),n.d(t,"H",(function(){return k})),n.d(t,"I",(function(){return D})),n.d(t,"K",(function(){return N})),n.d(t,"L",(function(){return j})),n.d(t,"M",(function(){return P})),n.d(t,"P",(function(){return z})),n.d(t,"O",(function(){return R})),n.d(t,"N",(function(){return B})),n.d(t,"q",(function(){return H})),n.d(t,"r",(function(){return F})),n.d(t,"Q",(function(){return Y})),n.d(t,"R",(function(){return V})),n.d(t,"T",(function(){return U})),n.d(t,"i",(function(){return W})),n.d(t,"h",(function(){return G})),n.d(t,"k",(function(){return q})),n.d(t,"j",(function(){return K})),n.d(t,"S",(function(){return X}));var r="[Blueprint]",i=r+" clamp: max cannot be less than min",o=r+" <Alert> cancelButtonText and onCancel should be set together.",a=r+" <Alert> canEscapeKeyCancel enabled without onCancel or onClose handler.",s=r+" <Alert> canOutsideClickCancel enabled without onCancel or onClose handler.",l=r+" <CollapsibleList> children must be <MenuItem>s",c=r+" @ContextMenuTarget-decorated class should implement renderContextMenu.",u=r+' "@ContextMenuTarget-decorated components must return a single JSX.Element or an empty render.',d=r+" <Hotkeys> only accepts <Hotkey> children.",h=r+" @HotkeysTarget-decorated class should implement renderHotkeys.",p=r+' "@HotkeysTarget-decorated components must return a single JSX.Element or an empty render.',f=r+" <HotkeysTarget2> was configured with local hotkeys, but you did not use the generated event handlers to bind their event handlers. Try using a render function as the child of this component.",m=r+" <InputGroup> leftElement and leftIcon prop are mutually exclusive, with leftElement taking priority.",g=r+" <NumericInput> requires min to be no greater than max if both are defined.",v=r+" <NumericInput> requires minorStepSize to be no greater than stepSize.",y=r+" <NumericInput> requires stepSize to be no greater than majorStepSize.",_=r+" <NumericInput> requires minorStepSize to be strictly greater than zero.",b=r+" <NumericInput> requires majorStepSize to be strictly greater than zero.",M=r+" <NumericInput> requires stepSize to be strictly greater than zero.",w=r+" <NumericInput> controlled value prop does not adhere to stepSize, min, and/or max constraints.",A=r+" <PanelStack> requires exactly one of initialPanel and stack prop",C=r+" <PanelStack> requires at least one panel in the stack",x=r+" <OverflowList> does not support changing observeParents after mounting.",E=r+" <Popover> requires target prop or at least one child element.",L=r+" <Popover hasBackdrop={true}> requires interactionKind={PopoverInteractionKind.CLICK}.",S=r+" <Popover> supports one or two children; additional children are ignored. First child is the target, second child is the content. You may instead supply these two as props.",T=r+" <Popover> with two children ignores content prop; use either prop or children.",O=r+" <Popover> with children ignores target prop; use either prop or children.",I=r+" Disabling <Popover> with empty/whitespace content...",k=r+" <Popover usePortal={false}> ignores hasBackdrop",D=r+" <Popover> supports either placement or position prop, not both.",N=r+" <Popover> onInteraction is ignored when uncontrolled.",j=r+" <Portal> context blueprintPortalClassName must be string",P=r+" <RadioGroup> children and options prop are mutually exclusive, with options taking priority.",z=r+" <Slider> stepSize must be greater than zero.",R=r+" <Slider> labelStepSize must be greater than zero.",B=r+" <RangeSlider> value prop must be an array of two non-null numbers.",H=r+" <MultiSlider> children must be <SliderHandle>s or <SliderTrackStop>s",F=r+" <MultiSlider> labelStepSize and labelValues prop are mutually exclusive, with labelStepSize taking priority.",Y=r+" <Spinner> Classes.SMALL/LARGE are ignored if size prop is set.",V=r+" Toaster.create() is not supported inside React lifecycle methods in React 16. See usage example on the docs site.",U=r+" Toaster.create() ignores inline prop as it always creates a new element.",W=r+" <Dialog> iconName is ignored if title is omitted.",G=r+" <Dialog> isCloseButtonShown prop is ignored if title is omitted.",q=r+" <Drawer> vertical is ignored if position is defined",K=r+" <Drawer> all angle positions are casted into pure position (TOP, BOTTOM, LEFT or RIGHT)",X=r+" <Toaster> maxToasts is set to an invalid number, must be greater than 0"},function(e,t,n){"use strict";n.r(t),function(e){n.d(t,"ACTIVE",(function(){return h})),n.d(t,"ALIGN_LEFT",(function(){return p})),n.d(t,"ALIGN_RIGHT",(function(){return f})),n.d(t,"DARK",(function(){return m})),n.d(t,"DISABLED",(function(){return g})),n.d(t,"FILL",(function(){return v})),n.d(t,"FIXED",(function(){return y})),n.d(t,"FIXED_TOP",(function(){return _})),n.d(t,"INLINE",(function(){return b})),n.d(t,"INTERACTIVE",(function(){return M})),n.d(t,"LARGE",(function(){return w})),n.d(t,"LOADING",(function(){return A})),n.d(t,"MINIMAL",(function(){return C})),n.d(t,"OUTLINED",(function(){return x})),n.d(t,"MULTILINE",(function(){return E})),n.d(t,"ROUND",(function(){return L})),n.d(t,"SMALL",(function(){return S})),n.d(t,"VERTICAL",(function(){return T})),n.d(t,"POSITION_TOP",(function(){return O})),n.d(t,"POSITION_BOTTOM",(function(){return I})),n.d(t,"POSITION_LEFT",(function(){return k})),n.d(t,"POSITION_RIGHT",(function(){return D})),n.d(t,"ELEVATION_0",(function(){return N})),n.d(t,"ELEVATION_1",(function(){return j})),n.d(t,"ELEVATION_2",(function(){return P})),n.d(t,"ELEVATION_3",(function(){return z})),n.d(t,"ELEVATION_4",(function(){return R})),n.d(t,"INTENT_PRIMARY",(function(){return B})),n.d(t,"INTENT_SUCCESS",(function(){return H})),n.d(t,"INTENT_WARNING",(function(){return F})),n.d(t,"INTENT_DANGER",(function(){return Y})),n.d(t,"FOCUS_DISABLED",(function(){return V})),n.d(t,"UI_TEXT",(function(){return U})),n.d(t,"RUNNING_TEXT",(function(){return W})),n.d(t,"MONOSPACE_TEXT",(function(){return G})),n.d(t,"TEXT_LARGE",(function(){return q})),n.d(t,"TEXT_SMALL",(function(){return K})),n.d(t,"TEXT_MUTED",(function(){return X})),n.d(t,"TEXT_DISABLED",(function(){return J})),n.d(t,"TEXT_OVERFLOW_ELLIPSIS",(function(){return Q})),n.d(t,"BLOCKQUOTE",(function(){return Z})),n.d(t,"CODE",(function(){return $})),n.d(t,"CODE_BLOCK",(function(){return ee})),n.d(t,"HEADING",(function(){return te})),n.d(t,"LIST",(function(){return ne})),n.d(t,"LIST_UNSTYLED",(function(){return re})),n.d(t,"RTL",(function(){return ie})),n.d(t,"FIXED_POSITIONING_CONTAINING_BLOCK",(function(){return oe})),n.d(t,"ALERT",(function(){return ae})),n.d(t,"ALERT_BODY",(function(){return se})),n.d(t,"ALERT_CONTENTS",(function(){return le})),n.d(t,"ALERT_FOOTER",(function(){return ce})),n.d(t,"BREADCRUMB",(function(){return ue})),n.d(t,"BREADCRUMB_CURRENT",(function(){return de})),n.d(t,"BREADCRUMBS",(function(){return he})),n.d(t,"BREADCRUMBS_COLLAPSED",(function(){return pe})),n.d(t,"BUTTON",(function(){return fe})),n.d(t,"BUTTON_GROUP",(function(){return me})),n.d(t,"BUTTON_SPINNER",(function(){return ge})),n.d(t,"BUTTON_TEXT",(function(){return ve})),n.d(t,"CALLOUT",(function(){return ye})),n.d(t,"CALLOUT_ICON",(function(){return _e})),n.d(t,"CARD",(function(){return be})),n.d(t,"COLLAPSE",(function(){return Me})),n.d(t,"COLLAPSE_BODY",(function(){return we})),n.d(t,"COLLAPSIBLE_LIST",(function(){return Ae})),n.d(t,"CONTEXT_MENU",(function(){return Ce})),n.d(t,"CONTEXT_MENU_POPOVER_TARGET",(function(){return xe})),n.d(t,"CONTROL_GROUP",(function(){return Ee})),n.d(t,"DIALOG",(function(){return Le})),n.d(t,"DIALOG_CONTAINER",(function(){return Se})),n.d(t,"DIALOG_BODY",(function(){return Te})),n.d(t,"DIALOG_CLOSE_BUTTON",(function(){return Oe})),n.d(t,"DIALOG_FOOTER",(function(){return Ie})),n.d(t,"DIALOG_FOOTER_ACTIONS",(function(){return ke})),n.d(t,"DIALOG_HEADER",(function(){return De})),n.d(t,"DIALOG_STEP",(function(){return Ne})),n.d(t,"DIALOG_STEP_CONTAINER",(function(){return je})),n.d(t,"DIALOG_STEP_TITLE",(function(){return Pe})),n.d(t,"DIALOG_STEP_ICON",(function(){return ze})),n.d(t,"DIALOG_STEP_VIEWED",(function(){return Re})),n.d(t,"DIVIDER",(function(){return Be})),n.d(t,"DRAWER",(function(){return He})),n.d(t,"DRAWER_BODY",(function(){return Fe})),n.d(t,"DRAWER_FOOTER",(function(){return Ye})),n.d(t,"DRAWER_HEADER",(function(){return Ve})),n.d(t,"EDITABLE_TEXT",(function(){return Ue})),n.d(t,"EDITABLE_TEXT_CONTENT",(function(){return We})),n.d(t,"EDITABLE_TEXT_EDITING",(function(){return Ge})),n.d(t,"EDITABLE_TEXT_INPUT",(function(){return qe})),n.d(t,"EDITABLE_TEXT_PLACEHOLDER",(function(){return Ke})),n.d(t,"FLEX_EXPANDER",(function(){return Xe})),n.d(t,"HTML_SELECT",(function(){return Je})),n.d(t,"SELECT",(function(){return Qe})),n.d(t,"HTML_TABLE",(function(){return Ze})),n.d(t,"HTML_TABLE_BORDERED",(function(){return $e})),n.d(t,"HTML_TABLE_CONDENSED",(function(){return et})),n.d(t,"HTML_TABLE_STRIPED",(function(){return tt})),n.d(t,"INPUT",(function(){return nt})),n.d(t,"INPUT_GHOST",(function(){return rt})),n.d(t,"INPUT_GROUP",(function(){return it})),n.d(t,"INPUT_LEFT_CONTAINER",(function(){return ot})),n.d(t,"INPUT_ACTION",(function(){return at})),n.d(t,"CONTROL",(function(){return st})),n.d(t,"CONTROL_INDICATOR",(function(){return lt})),n.d(t,"CONTROL_INDICATOR_CHILD",(function(){return ct})),n.d(t,"CHECKBOX",(function(){return ut})),n.d(t,"RADIO",(function(){return dt})),n.d(t,"SWITCH",(function(){return ht})),n.d(t,"SWITCH_INNER_TEXT",(function(){return pt})),n.d(t,"FILE_INPUT",(function(){return ft})),n.d(t,"FILE_INPUT_HAS_SELECTION",(function(){return mt})),n.d(t,"FILE_UPLOAD_INPUT",(function(){return gt})),n.d(t,"FILE_UPLOAD_INPUT_CUSTOM_TEXT",(function(){return vt})),n.d(t,"KEY",(function(){return yt})),n.d(t,"KEY_COMBO",(function(){return _t})),n.d(t,"MODIFIER_KEY",(function(){return bt})),n.d(t,"HOTKEY",(function(){return Mt})),n.d(t,"HOTKEY_LABEL",(function(){return wt})),n.d(t,"HOTKEY_COLUMN",(function(){return At})),n.d(t,"HOTKEY_DIALOG",(function(){return Ct})),n.d(t,"LABEL",(function(){return xt})),n.d(t,"FORM_GROUP",(function(){return Et})),n.d(t,"FORM_CONTENT",(function(){return Lt})),n.d(t,"FORM_HELPER_TEXT",(function(){return St})),n.d(t,"FORM_GROUP_SUB_LABEL",(function(){return Tt})),n.d(t,"MENU",(function(){return Ot})),n.d(t,"MENU_ITEM",(function(){return It})),n.d(t,"MENU_ITEM_LABEL",(function(){return kt})),n.d(t,"MENU_SUBMENU",(function(){return Dt})),n.d(t,"MENU_DIVIDER",(function(){return Nt})),n.d(t,"MENU_HEADER",(function(){return jt})),n.d(t,"MULTISTEP_DIALOG",(function(){return Pt})),n.d(t,"MULTISTEP_DIALOG_PANELS",(function(){return zt})),n.d(t,"MULTISTEP_DIALOG_LEFT_PANEL",(function(){return Rt})),n.d(t,"MULTISTEP_DIALOG_RIGHT_PANEL",(function(){return Bt})),n.d(t,"MULTISTEP_DIALOG_FOOTER",(function(){return Ht})),n.d(t,"NAVBAR",(function(){return Ft})),n.d(t,"NAVBAR_GROUP",(function(){return Yt})),n.d(t,"NAVBAR_HEADING",(function(){return Vt})),n.d(t,"NAVBAR_DIVIDER",(function(){return Ut})),n.d(t,"NON_IDEAL_STATE",(function(){return Wt})),n.d(t,"NON_IDEAL_STATE_VISUAL",(function(){return Gt})),n.d(t,"NUMERIC_INPUT",(function(){return qt})),n.d(t,"OVERFLOW_LIST",(function(){return Kt})),n.d(t,"OVERFLOW_LIST_SPACER",(function(){return Xt})),n.d(t,"OVERLAY",(function(){return Jt})),n.d(t,"OVERLAY_BACKDROP",(function(){return Qt})),n.d(t,"OVERLAY_CONTAINER",(function(){return Zt})),n.d(t,"OVERLAY_CONTENT",(function(){return $t})),n.d(t,"OVERLAY_INLINE",(function(){return en})),n.d(t,"OVERLAY_OPEN",(function(){return tn})),n.d(t,"OVERLAY_SCROLL_CONTAINER",(function(){return nn})),n.d(t,"OVERLAY_START_FOCUS_TRAP",(function(){return rn})),n.d(t,"OVERLAY_END_FOCUS_TRAP",(function(){return on})),n.d(t,"PANEL_STACK",(function(){return an})),n.d(t,"PANEL_STACK_HEADER",(function(){return sn})),n.d(t,"PANEL_STACK_HEADER_BACK",(function(){return ln})),n.d(t,"PANEL_STACK_VIEW",(function(){return cn})),n.d(t,"PANEL_STACK2",(function(){return un})),n.d(t,"PANEL_STACK2_HEADER",(function(){return dn})),n.d(t,"PANEL_STACK2_HEADER_BACK",(function(){return hn})),n.d(t,"PANEL_STACK2_VIEW",(function(){return pn})),n.d(t,"POPOVER",(function(){return fn})),n.d(t,"POPOVER_ARROW",(function(){return mn})),n.d(t,"POPOVER_BACKDROP",(function(){return gn})),n.d(t,"POPOVER_CAPTURING_DISMISS",(function(){return vn})),n.d(t,"POPOVER_CONTENT",(function(){return yn})),n.d(t,"POPOVER_CONTENT_SIZING",(function(){return _n})),n.d(t,"POPOVER_DISMISS",(function(){return bn})),n.d(t,"POPOVER_DISMISS_OVERRIDE",(function(){return Mn})),n.d(t,"POPOVER_OPEN",(function(){return wn})),n.d(t,"POPOVER_OUT_OF_BOUNDARIES",(function(){return An})),n.d(t,"POPOVER_TARGET",(function(){return Cn})),n.d(t,"POPOVER_WRAPPER",(function(){return xn})),n.d(t,"TRANSITION_CONTAINER",(function(){return En})),n.d(t,"PROGRESS_BAR",(function(){return Ln})),n.d(t,"PROGRESS_METER",(function(){return Sn})),n.d(t,"PROGRESS_NO_STRIPES",(function(){return Tn})),n.d(t,"PROGRESS_NO_ANIMATION",(function(){return On})),n.d(t,"PORTAL",(function(){return In})),n.d(t,"SKELETON",(function(){return kn})),n.d(t,"SLIDER",(function(){return Dn})),n.d(t,"SLIDER_AXIS",(function(){return Nn})),n.d(t,"SLIDER_HANDLE",(function(){return jn})),n.d(t,"SLIDER_LABEL",(function(){return Pn})),n.d(t,"SLIDER_TRACK",(function(){return zn})),n.d(t,"SLIDER_PROGRESS",(function(){return Rn})),n.d(t,"START",(function(){return Bn})),n.d(t,"END",(function(){return Hn})),n.d(t,"SPINNER",(function(){return Fn})),n.d(t,"SPINNER_ANIMATION",(function(){return Yn})),n.d(t,"SPINNER_HEAD",(function(){return Vn})),n.d(t,"SPINNER_NO_SPIN",(function(){return Un})),n.d(t,"SPINNER_TRACK",(function(){return Wn})),n.d(t,"TAB",(function(){return Gn})),n.d(t,"TAB_INDICATOR",(function(){return qn})),n.d(t,"TAB_INDICATOR_WRAPPER",(function(){return Kn})),n.d(t,"TAB_LIST",(function(){return Xn})),n.d(t,"TAB_PANEL",(function(){return Jn})),n.d(t,"TABS",(function(){return Qn})),n.d(t,"TAG",(function(){return Zn})),n.d(t,"TAG_REMOVE",(function(){return $n})),n.d(t,"TAG_INPUT",(function(){return er})),n.d(t,"TAG_INPUT_ICON",(function(){return tr})),n.d(t,"TAG_INPUT_VALUES",(function(){return nr})),n.d(t,"TOAST",(function(){return rr})),n.d(t,"TOAST_CONTAINER",(function(){return ir})),n.d(t,"TOAST_MESSAGE",(function(){return or})),n.d(t,"TOOLTIP",(function(){return ar})),n.d(t,"TOOLTIP_INDICATOR",(function(){return sr})),n.d(t,"TREE",(function(){return lr})),n.d(t,"TREE_NODE",(function(){return cr})),n.d(t,"TREE_NODE_CARET",(function(){return ur})),n.d(t,"TREE_NODE_CARET_CLOSED",(function(){return dr})),n.d(t,"TREE_NODE_CARET_NONE",(function(){return hr})),n.d(t,"TREE_NODE_CARET_OPEN",(function(){return pr})),n.d(t,"TREE_NODE_CONTENT",(function(){return fr})),n.d(t,"TREE_NODE_EXPANDED",(function(){return mr})),n.d(t,"TREE_NODE_ICON",(function(){return gr})),n.d(t,"TREE_NODE_LABEL",(function(){return vr})),n.d(t,"TREE_NODE_LIST",(function(){return yr})),n.d(t,"TREE_NODE_SECONDARY_LABEL",(function(){return _r})),n.d(t,"TREE_NODE_SELECTED",(function(){return br})),n.d(t,"TREE_ROOT",(function(){return Mr})),n.d(t,"ICON",(function(){return wr})),n.d(t,"ICON_STANDARD",(function(){return Ar})),n.d(t,"ICON_LARGE",(function(){return Cr})),n.d(t,"getClassNamespace",(function(){return xr})),n.d(t,"alignmentClass",(function(){return Er})),n.d(t,"elevationClass",(function(){return Lr})),n.d(t,"iconClass",(function(){return Sr})),n.d(t,"intentClass",(function(){return Tr})),n.d(t,"positionClass",(function(){return Or}));var r,i,o,a,s=n(113),l=n(79),c=n(80),u=n(33),d="bp3";void 0!==e&&(d=null!==(a=null!==(i=null===(r=e.env)||void 0===r?void 0:r.BLUEPRINT_NAMESPACE)&&void 0!==i?i:null===(o=e.env)||void 0===o?void 0:o.REACT_APP_BLUEPRINT_NAMESPACE)&&void 0!==a?a:d);var h=d+"-active",p=d+"-align-left",f=d+"-align-right",m=d+"-dark",g=d+"-disabled",v=d+"-fill",y=d+"-fixed",_=d+"-fixed-top",b=d+"-inline",M=d+"-interactive",w=d+"-large",A=d+"-loading",C=d+"-minimal",x=d+"-outlined",E=d+"-multiline",L=d+"-round",S=d+"-small",T=d+"-vertical",O=Or(u.a.TOP),I=Or(u.a.BOTTOM),k=Or(u.a.LEFT),D=Or(u.a.RIGHT),N=Lr(l.a.ZERO),j=Lr(l.a.ONE),P=Lr(l.a.TWO),z=Lr(l.a.THREE),R=Lr(l.a.FOUR),B=Tr(c.a.PRIMARY),H=Tr(c.a.SUCCESS),F=Tr(c.a.WARNING),Y=Tr(c.a.DANGER),V=d+"-focus-disabled",U=d+"-ui-text",W=d+"-running-text",G=d+"-monospace-text",q=d+"-text-large",K=d+"-text-small",X=d+"-text-muted",J=d+"-text-disabled",Q=d+"-text-overflow-ellipsis",Z=d+"-blockquote",$=d+"-code",ee=d+"-code-block",te=d+"-heading",ne=d+"-list",re=d+"-list-unstyled",ie=d+"-rtl",oe=d+"-fixed-positioning-containing-block",ae=d+"-alert",se=ae+"-body",le=ae+"-contents",ce=ae+"-footer",ue=d+"-breadcrumb",de=ue+"-current",he=ue+"s",pe=ue+"s-collapsed",fe=d+"-button",me=fe+"-group",ge=fe+"-spinner",ve=fe+"-text",ye=d+"-callout",_e=ye+"-icon",be=d+"-card",Me=d+"-collapse",we=Me+"-body",Ae=d+"-collapse-list",Ce=d+"-context-menu",xe=Ce+"-popover-target",Ee=d+"-control-group",Le=d+"-dialog",Se=Le+"-container",Te=Le+"-body",Oe=Le+"-close-button",Ie=Le+"-footer",ke=Le+"-footer-actions",De=Le+"-header",Ne=d+"-dialog-step",je=Ne+"-container",Pe=Ne+"-title",ze=Ne+"-icon",Re=Ne+"-viewed",Be=d+"-divider",He=d+"-drawer",Fe=He+"-body",Ye=He+"-footer",Ve=He+"-header",Ue=d+"-editable-text",We=Ue+"-content",Ge=Ue+"-editing",qe=Ue+"-input",Ke=Ue+"-placeholder",Xe=d+"-flex-expander",Je=d+"-html-select",Qe=d+"-select",Ze=d+"-html-table",$e=Ze+"-bordered",et=Ze+"-condensed",tt=Ze+"-striped",nt=d+"-input",rt=nt+"-ghost",it=nt+"-group",ot=nt+"-left-container",at=nt+"-action",st=d+"-control",lt=st+"-indicator",ct=lt+"-child",ut=d+"-checkbox",dt=d+"-radio",ht=d+"-switch",pt=ht+"-inner-text",ft=d+"-file-input",mt=d+"-file-input-has-selection",gt=d+"-file-upload-input",vt=d+"-file-upload-input-custom-text",yt=d+"-key",_t=yt+"-combo",bt=d+"-modifier-key",Mt=d+"-hotkey",wt=Mt+"-label",At=Mt+"-column",Ct=Mt+"-dialog",xt=d+"-label",Et=d+"-form-group",Lt=d+"-form-content",St=d+"-form-helper-text",Tt=d+"-form-group-sub-label",Ot=d+"-menu",It=Ot+"-item",kt=It+"-label",Dt=d+"-submenu",Nt=Ot+"-divider",jt=Ot+"-header",Pt=d+"-multistep-dialog",zt=Pt+"-panels",Rt=Pt+"-left-panel",Bt=Pt+"-right-panel",Ht=Pt+"-footer",Ft=d+"-navbar",Yt=Ft+"-group",Vt=Ft+"-heading",Ut=Ft+"-divider",Wt=d+"-non-ideal-state",Gt=Wt+"-visual",qt=d+"-numeric-input",Kt=d+"-overflow-list",Xt=Kt+"-spacer",Jt=d+"-overlay",Qt=Jt+"-backdrop",Zt=Jt+"-container",$t=Jt+"-content",en=Jt+"-inline",tn=Jt+"-open",nn=Jt+"-scroll-container",rn=Jt+"-start-focus-trap",on=Jt+"-end-focus-trap",an=d+"-panel-stack",sn=an+"-header",ln=an+"-header-back",cn=an+"-view",un=d+"-panel-stack2",dn=an+"-header",hn=an+"-header-back",pn=an+"-view",fn=d+"-popover",mn=fn+"-arrow",gn=fn+"-backdrop",vn=fn+"-capturing-dismiss",yn=fn+"-content",_n=yn+"-sizing",bn=fn+"-dismiss",Mn=bn+"-override",wn=fn+"-open",An=fn+"-out-of-boundaries",Cn=fn+"-target",xn=fn+"-wrapper",En=d+"-transition-container",Ln=d+"-progress-bar",Sn=d+"-progress-meter",Tn=d+"-no-stripes",On=d+"-no-animation",In=d+"-portal",kn=d+"-skeleton",Dn=d+"-slider",Nn=Dn+"-axis",jn=Dn+"-handle",Pn=Dn+"-label",zn=Dn+"-track",Rn=Dn+"-progress",Bn=d+"-start",Hn=d+"-end",Fn=d+"-spinner",Yn=Fn+"-animation",Vn=Fn+"-head",Un=d+"-no-spin",Wn=Fn+"-track",Gn=d+"-tab",qn=Gn+"-indicator",Kn=qn+"-wrapper",Xn=Gn+"-list",Jn=Gn+"-panel",Qn=Gn+"s",Zn=d+"-tag",$n=Zn+"-remove",er=d+"-tag-input",tr=er+"-icon",nr=er+"-values",rr=d+"-toast",ir=rr+"-container",or=rr+"-message",ar=d+"-tooltip",sr=ar+"-indicator",lr=d+"-tree",cr=d+"-tree-node",ur=cr+"-caret",dr=ur+"-closed",hr=ur+"-none",pr=ur+"-open",fr=cr+"-content",mr=cr+"-expanded",gr=cr+"-icon",vr=cr+"-label",yr=cr+"-list",_r=cr+"-secondary-label",br=cr+"-selected",Mr=d+"-tree-root",wr=d+"-icon",Ar=wr+"-standard",Cr=wr+"-large";function xr(){return d}function Er(e){switch(e){case s.a.LEFT:return p;case s.a.RIGHT:return f;default:return}}function Lr(e){if(void 0!==e)return d+"-elevation-"+e}function Sr(e){if(null!=e)return 0===e.indexOf(d+"-icon-")?e:d+"-icon-"+e}function Tr(e){if(null!=e&&e!==c.a.NONE)return d+"-intent-"+e.toLowerCase()}function Or(e){if(void 0!==e)return d+"-position-"+e}}.call(this,n(61))},function(e,t,n){"use strict";n.d(t,"a",(function(){return r})),n.d(t,"b",(function(){return i})),n.d(t,"c",(function(){return o})),n.d(t,"d",(function(){return a})),n.d(t,"e",(function(){return s})),n.d(t,"f",(function(){return l})),n.d(t,"g",(function(){return c})),n.d(t,"i",(function(){return u})),n.d(t,"j",(function(){return d})),n.d(t,"k",(function(){return h})),n.d(t,"l",(function(){return p})),n.d(t,"h",(function(){return f}));const r=1,i=2,o=4,a=8,s=32,l=64,c=128,u=31,d=63,h=127,p=255,f=2147483647},function(e,t,n){"use strict";(function(e){n.d(t,"e",(function(){return r})),n.d(t,"p",(function(){return i})),n.d(t,"a",(function(){return o})),n.d(t,"c",(function(){return a})),n.d(t,"d",(function(){return s})),n.d(t,"o",(function(){return l})),n.d(t,"q",(function(){return c})),n.d(t,"t",(function(){return u})),n.d(t,"i",(function(){return d})),n.d(t,"r",(function(){return h})),n.d(t,"s",(function(){return p})),n.d(t,"k",(function(){return f})),n.d(t,"m",(function(){return m})),n.d(t,"j",(function(){return g})),n.d(t,"l",(function(){return v})),n.d(t,"g",(function(){return y})),n.d(t,"f",(function(){return _})),n.d(t,"h",(function(){return b})),n.d(t,"n",(function(){return M})),n.d(t,"b",(function(){return w}));var r="1.13.2",i="object"==typeof self&&self.self===self&&self||"object"==typeof e&&e.global===e&&e||Function("return this")()||{},o=Array.prototype,a=Object.prototype,s="undefined"!=typeof Symbol?Symbol.prototype:null,l=o.push,c=o.slice,u=a.toString,d=a.hasOwnProperty,h="undefined"!=typeof ArrayBuffer,p="undefined"!=typeof DataView,f=Array.isArray,m=Object.keys,g=Object.create,v=h&&ArrayBuffer.isView,y=isNaN,_=isFinite,b=!{toString:null}.propertyIsEnumerable("toString"),M=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"],w=Math.pow(2,53)-1}).call(this,n(55))},function(e,t,n){"use strict";var r,i,o,a,s;n.r(t),n.d(t,"ClipboardExt",(function(){return r})),n.d(t,"ElementExt",(function(){return i})),n.d(t,"Platform",(function(){return o})),n.d(t,"Selector",(function(){return a})),function(e){e.copyText=function(e){var t=document.body,n=function(r){r.preventDefault(),r.stopPropagation(),r.clipboardData.setData("text",e),t.removeEventListener("copy",n,!0)};t.addEventListener("copy",n,!0),document.execCommand("copy")}}(r||(r={})),function(e){e.boxSizing=function(e){var t=window.getComputedStyle(e),n=parseFloat(t.borderTopWidth)||0,r=parseFloat(t.borderLeftWidth)||0,i=parseFloat(t.borderRightWidth)||0,o=parseFloat(t.borderBottomWidth)||0,a=parseFloat(t.paddingTop)||0,s=parseFloat(t.paddingLeft)||0,l=parseFloat(t.paddingRight)||0,c=parseFloat(t.paddingBottom)||0;return{borderTop:n,borderLeft:r,borderRight:i,borderBottom:o,paddingTop:a,paddingLeft:s,paddingRight:l,paddingBottom:c,horizontalSum:r+s+l+i,verticalSum:n+a+c+o}},e.sizeLimits=function(e){var t=window.getComputedStyle(e),n=parseFloat(t.minWidth)||0,r=parseFloat(t.minHeight)||0,i=parseFloat(t.maxWidth)||1/0,o=parseFloat(t.maxHeight)||1/0;return{minWidth:n,minHeight:r,maxWidth:i=Math.max(n,i),maxHeight:o=Math.max(r,o)}},e.hitTest=function(e,t,n){var r=e.getBoundingClientRect();return t>=r.left&&t<r.right&&n>=r.top&&n<r.bottom},e.scrollIntoViewIfNeeded=function(e,t){var n=e.getBoundingClientRect(),r=t.getBoundingClientRect();r.top<=n.top&&r.bottom>=n.bottom||(r.top<n.top&&r.height<=n.height||r.bottom>n.bottom&&r.height>=n.height?e.scrollTop-=n.top-r.top:(r.top<n.top&&r.height>n.height||r.bottom>n.bottom&&r.height<n.height)&&(e.scrollTop-=n.bottom-r.bottom))}}(i||(i={})),function(e){e.IS_MAC=!!navigator.platform.match(/Mac/i),e.IS_WIN=!!navigator.platform.match(/Win/i),e.IS_IE=/Trident/.test(navigator.userAgent),e.IS_EDGE=/Edge/.test(navigator.userAgent),e.accelKey=function(t){return e.IS_MAC?t.metaKey:t.ctrlKey}}(o||(o={})),function(e){e.calculateSpecificity=function(e){if(e in s.specificityCache)return s.specificityCache[e];var t=s.calculateSingle(e);return s.specificityCache[e]=t},e.isValid=function(e){if(e in s.validityCache)return s.validityCache[e];var t=!0;try{s.testElem.querySelector(e)}catch(e){t=!1}return s.validityCache[e]=t},e.matches=function(e,t){return s.protoMatchFunc.call(e,t)}}(a||(a={})),function(e){var t;e.specificityCache=Object.create(null),e.validityCache=Object.create(null),e.testElem=document.createElement("div"),e.protoMatchFunc=(t=Element.prototype).matches||t.matchesSelector||t.mozMatchesSelector||t.msMatchesSelector||t.oMatchesSelector||t.webkitMatchesSelector||function(e){var t=this.ownerDocument?this.ownerDocument.querySelectorAll(e):[];return-1!==Array.prototype.indexOf.call(t,this)},e.calculateSingle=function(e){var t=0,u=0,d=0;function h(t){var n=e.match(t);return null!==n&&(e=e.slice(n[0].length),!0)}for(e=(e=e.split(",",1)[0]).replace(c," $1 ");e.length>0;)if(h(n))t++;else if(h(r))u++;else if(h(i))u++;else if(h(a))d++;else if(h(s))u++;else if(h(o))d++;else if(!h(l))return 0;return(t=Math.min(t,255))<<16|(u=Math.min(u,255))<<8|(d=Math.min(d,255))};var n=/^#[^\s\+>~#\.\[:]+/,r=/^\.[^\s\+>~#\.\[:]+/,i=/^\[[^\]]+\]/,o=/^[^\s\+>~#\.\[:]+/,a=/^(::[^\s\+>~#\.\[:]+|:first-line|:first-letter|:before|:after)/,s=/^:[^\s\+>~#\.\[:]+/,l=/^[\s\+>~\*]+/,c=/:not\(([^\)]+)\)/g}(s||(s={}))},function(e,t,n){"use strict";function r(e){return e.replace("-","_")}n.d(t,"b",(function(){return o})),n.d(t,"a",(function(){return l}));class i{constructor(e){e=e||{},this._defaults={domain:"messages",locale:document.documentElement.getAttribute("lang")||"en",pluralFunc:function(e){return{nplurals:2,plural:1!=e?1:0}},contextDelimiter:String.fromCharCode(4),stringsPrefix:""},this._locale=(e.locale||this._defaults.locale).replace("_","-"),this._domain=r(e.domain||this._defaults.domain),this._contextDelimiter=e.contextDelimiter||this._defaults.contextDelimiter,this._stringsPrefix=e.stringsPrefix||this._defaults.stringsPrefix,this._pluralFuncs={},this._dictionary={},this._pluralForms={},e.messages&&(this._dictionary[this._domain]={},this._dictionary[this._domain][this._locale]=e.messages),e.pluralForms&&(this._pluralForms[this._locale]=e.pluralForms)}setContextDelimiter(e){this._contextDelimiter=e}getContextDelimiter(){return this._contextDelimiter}setLocale(e){this._locale=e.replace("_","-")}getLocale(){return this._locale}setDomain(e){this._domain=r(e)}getDomain(){return this._domain}setStringsPrefix(e){this._stringsPrefix=e}getStringsPrefix(){return this._stringsPrefix}static strfmt(e,...t){return e.replace(/%%/g,"%% ").replace(/%(\d+)/g,(function(e,n){return t[n-1]})).replace(/%% /g,"%")}loadJSON(e,t){if(!e[""]||!e[""].language||!e[""].pluralForms)throw new Error('Wrong jsonData, it must have an empty key ("") with "language" and "pluralForms" information: '+e);t=r(t);let n=e[""],i=JSON.parse(JSON.stringify(e));delete i[""],this.setMessages(t||this._defaults.domain,n.language,i,n.pluralForms)}__(e,...t){return this.gettext(e,...t)}_n(e,t,n,...r){return this.ngettext(e,t,n,...r)}_p(e,t,...n){return this.pgettext(e,t,...n)}_np(e,t,n,r,...i){return this.npgettext(e,t,n,r,...i)}gettext(e,...t){return this.dcnpgettext("","",e,"",0,...t)}ngettext(e,t,n,...r){return this.dcnpgettext("","",e,t,n,...r)}pgettext(e,t,...n){return this.dcnpgettext("",e,t,"",0,...n)}npgettext(e,t,n,r,...i){return this.dcnpgettext("",e,t,n,r,...i)}dcnpgettext(e,t,n,i,o,...a){let s;e=r(e)||this._domain;let l=t?t+this._contextDelimiter+n:n,c={pluralForm:!1},u=!1,d=this._locale,h=this.expandLocale(this._locale);for(let t in h)if(d=h[t],u=this._dictionary[e]&&this._dictionary[e][d]&&this._dictionary[e][d][l],u=i?u&&this._dictionary[e][d][l].length>1:u&&1==this._dictionary[e][d][l].length,u){c.locale=d;break}if(u?s=this._dictionary[e][d][l]:(s=[n],c.pluralFunc=this._defaults.pluralFunc),!i)return this.t(s,o,c,...a);c.pluralForm=!0;let p=u?s:[n,i];return this.t(p,o,c,...a)}expandLocale(e){let t=[e],n=e.lastIndexOf("-");for(;n>0;)e=e.slice(0,n),t.push(e),n=e.lastIndexOf("-");return t}getPluralFunc(e){if(!new RegExp("^\\s*nplurals\\s*=\\s*[0-9]+\\s*;\\s*plural\\s*=\\s*(?:\\s|[-\\?\\|&=!<>+*/%:;n0-9_()])+").test(e))throw new Error(i.strfmt('The plural form "%1" is not valid',e));return new Function("n","let plural, nplurals; "+e+" return { nplurals: nplurals, plural: (plural === true ? 1 : (plural ? plural : 0)) };")}removeContext(e){if(-1!==e.indexOf(this._contextDelimiter)){return e.split(this._contextDelimiter)[1]}return e}t(e,t,n,...r){if(!n.pluralForm)return this._stringsPrefix+i.strfmt(this.removeContext(e[0]),...r);let o;return n.pluralFunc?o=n.pluralFunc(t):(this._pluralFuncs[n.locale||""]||(this._pluralFuncs[n.locale||""]=this.getPluralFunc(this._pluralForms[n.locale||""])),o=this._pluralFuncs[n.locale||""](t)),(void 0===!o.plural||o.plural>o.nplurals||e.length<=o.plural)&&(o.plural=0),this._stringsPrefix+i.strfmt(this.removeContext(e[o.plural]),...[t].concat(r))}setMessages(e,t,n,i){e=r(e),i&&(this._pluralForms[t]=i),this._dictionary[e]||(this._dictionary[e]={}),this._dictionary[e][t]=n}}const o=new class{constructor(e){this._languageBundle=e}load(e){return this._languageBundle}locale(){return"en"}}(new class{__(e,...t){return this.gettext(e,...t)}_n(e,t,n,...r){return this.ngettext(e,t,n,...r)}_p(e,t,...n){return this.pgettext(e,t,...n)}_np(e,t,n,r,...i){return this.npgettext(e,t,n,r,...i)}gettext(e,...t){return i.strfmt(e,...t)}ngettext(e,t,n,...r){return i.strfmt(1==n?e:t,...[n].concat(r))}pgettext(e,t,...n){return i.strfmt(t,...n)}npgettext(e,t,n,r,...i){return this.ngettext(t,n,r,...i)}dcnpgettext(e,t,n,r,i,...o){return this.ngettext(n,r,i,...o)}});var a=n(97),s=n(6);n(12),n(38);new s.Token("@jupyterlab/translation:ITranslatorConnector");a.DataConnector;const l=new s.Token("@jupyterlab/translation:ITranslator")},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},s=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.XMLNode=t.TextNode=t.AbstractMmlEmptyNode=t.AbstractMmlBaseNode=t.AbstractMmlLayoutNode=t.AbstractMmlTokenNode=t.AbstractMmlNode=t.indentAttributes=t.TEXCLASSNAMES=t.TEXCLASS=void 0;var l=n(110),c=n(824);t.TEXCLASS={ORD:0,OP:1,BIN:2,REL:3,OPEN:4,CLOSE:5,PUNCT:6,INNER:7,VCENTER:8,NONE:-1},t.TEXCLASSNAMES=["ORD","OP","BIN","REL","OPEN","CLOSE","PUNCT","INNER","VCENTER"];var u=["","thinmathspace","mediummathspace","thickmathspace"],d=[[0,-1,2,3,0,0,0,1],[-1,-1,0,3,0,0,0,1],[2,2,0,0,2,0,0,2],[3,3,0,0,3,0,0,3],[0,0,0,0,0,0,0,0],[0,-1,2,3,0,0,0,1],[1,1,0,1,1,1,1,1],[1,-1,2,3,1,0,1,1]];t.indentAttributes=["indentalign","indentalignfirst","indentshift","indentshiftfirst"];var h=function(e){function n(t,n,r){void 0===n&&(n={}),void 0===r&&(r=[]);var i=e.call(this,t)||this;return i.prevClass=null,i.prevLevel=null,i.texclass=null,i.arity<0&&(i.childNodes=[t.create("inferredMrow")],i.childNodes[0].parent=i),i.setChildren(r),i.attributes=new l.Attributes(t.getNodeClass(i.kind).defaults,t.getNodeClass("math").defaults),i.attributes.setList(n),i}return i(n,e),n.prototype.copy=function(e){var t,n,r,i;void 0===e&&(e=!1);var s=this.factory.create(this.kind);if(s.properties=o({},this.properties),this.attributes){var l=this.attributes.getAllAttributes();try{for(var c=a(Object.keys(l)),u=c.next();!u.done;u=c.next()){var d=u.value;("id"!==d||e)&&s.attributes.set(d,l[d])}}catch(e){t={error:e}}finally{try{u&&!u.done&&(n=c.return)&&n.call(c)}finally{if(t)throw t.error}}}if(this.childNodes&&this.childNodes.length){var h=this.childNodes;1===h.length&&h[0].isInferred&&(h=h[0].childNodes);try{for(var p=a(h),f=p.next();!f.done;f=p.next()){var m=f.value;m?s.appendChild(m.copy()):s.childNodes.push(null)}}catch(e){r={error:e}}finally{try{f&&!f.done&&(i=p.return)&&i.call(p)}finally{if(r)throw r.error}}}return s},Object.defineProperty(n.prototype,"texClass",{get:function(){return this.texclass},set:function(e){this.texclass=e},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isToken",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isEmbellished",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isSpacelike",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"linebreakContainer",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"hasNewLine",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"arity",{get:function(){return 1/0},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isInferred",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"Parent",{get:function(){for(var e=this.parent;e&&e.notParent;)e=e.Parent;return e},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"notParent",{get:function(){return!1},enumerable:!1,configurable:!0}),n.prototype.setChildren=function(t){return this.arity<0?this.childNodes[0].setChildren(t):e.prototype.setChildren.call(this,t)},n.prototype.appendChild=function(t){var n,r,i=this;if(this.arity<0)return this.childNodes[0].appendChild(t),t;if(t.isInferred){if(this.arity===1/0)return t.childNodes.forEach((function(t){return e.prototype.appendChild.call(i,t)})),t;var o=t;(t=this.factory.create("mrow")).setChildren(o.childNodes),t.attributes=o.attributes;try{for(var s=a(o.getPropertyNames()),l=s.next();!l.done;l=s.next()){var c=l.value;t.setProperty(c,o.getProperty(c))}}catch(e){n={error:e}}finally{try{l&&!l.done&&(r=s.return)&&r.call(s)}finally{if(n)throw n.error}}}return e.prototype.appendChild.call(this,t)},n.prototype.replaceChild=function(t,n){return this.arity<0?(this.childNodes[0].replaceChild(t,n),t):e.prototype.replaceChild.call(this,t,n)},n.prototype.core=function(){return this},n.prototype.coreMO=function(){return this},n.prototype.coreIndex=function(){return 0},n.prototype.childPosition=function(){for(var e,t,n=this,r=n.parent;r&&r.notParent;)n=r,r=r.parent;if(r){var i=0;try{for(var o=a(r.childNodes),s=o.next();!s.done;s=o.next()){if(s.value===n)return i;i++}}catch(t){e={error:t}}finally{try{s&&!s.done&&(t=o.return)&&t.call(o)}finally{if(e)throw e.error}}}return null},n.prototype.setTeXclass=function(e){return this.getPrevClass(e),null!=this.texClass?this:e},n.prototype.updateTeXclass=function(e){e&&(this.prevClass=e.prevClass,this.prevLevel=e.prevLevel,e.prevClass=e.prevLevel=null,this.texClass=e.texClass)},n.prototype.getPrevClass=function(e){e&&(this.prevClass=e.texClass,this.prevLevel=e.attributes.get("scriptlevel"))},n.prototype.texSpacing=function(){var e=null!=this.prevClass?this.prevClass:t.TEXCLASS.NONE,n=this.texClass||t.TEXCLASS.ORD;if(e===t.TEXCLASS.NONE||n===t.TEXCLASS.NONE)return"";e===t.TEXCLASS.VCENTER&&(e=t.TEXCLASS.ORD),n===t.TEXCLASS.VCENTER&&(n=t.TEXCLASS.ORD);var r=d[e][n];return(this.prevLevel>0||this.attributes.get("scriptlevel")>0)&&r>=0?"":u[Math.abs(r)]},n.prototype.hasSpacingAttributes=function(){return this.isEmbellished&&this.coreMO().hasSpacingAttributes()},n.prototype.setInheritedAttributes=function(e,t,r,i){var o,l;void 0===e&&(e={}),void 0===t&&(t=!1),void 0===r&&(r=0),void 0===i&&(i=!1);var c=this.attributes.getAllDefaults();try{for(var u=a(Object.keys(e)),d=u.next();!d.done;d=u.next()){var h=d.value;if(c.hasOwnProperty(h)||n.alwaysInherit.hasOwnProperty(h)){var p=s(e[h],2),f=p[0],m=p[1];((n.noInherit[f]||{})[this.kind]||{})[h]||this.attributes.setInherited(h,m)}}}catch(e){o={error:e}}finally{try{d&&!d.done&&(l=u.return)&&l.call(u)}finally{if(o)throw o.error}}void 0===this.attributes.getExplicit("displaystyle")&&this.attributes.setInherited("displaystyle",t),void 0===this.attributes.getExplicit("scriptlevel")&&this.attributes.setInherited("scriptlevel",r),i&&this.setProperty("texprimestyle",i);var g=this.arity;if(g>=0&&g!==1/0&&(1===g&&0===this.childNodes.length||1!==g&&this.childNodes.length!==g))if(g<this.childNodes.length)this.childNodes=this.childNodes.slice(0,g);else for(;this.childNodes.length<g;)this.appendChild(this.factory.create("mrow"));this.setChildInheritedAttributes(e,t,r,i)},n.prototype.setChildInheritedAttributes=function(e,t,n,r){var i,o;try{for(var s=a(this.childNodes),l=s.next();!l.done;l=s.next()){l.value.setInheritedAttributes(e,t,n,r)}}catch(e){i={error:e}}finally{try{l&&!l.done&&(o=s.return)&&o.call(s)}finally{if(i)throw i.error}}},n.prototype.addInheritedAttributes=function(e,t){var n,r,i=o({},e);try{for(var s=a(Object.keys(t)),l=s.next();!l.done;l=s.next()){var c=l.value;"displaystyle"!==c&&"scriptlevel"!==c&&"style"!==c&&(i[c]=[this.kind,t[c]])}}catch(e){n={error:e}}finally{try{l&&!l.done&&(r=s.return)&&r.call(s)}finally{if(n)throw n.error}}return i},n.prototype.inheritAttributesFrom=function(e){var t=e.attributes,n=t.get("displaystyle"),r=t.get("scriptlevel"),i=t.isSet("mathsize")?{mathsize:["math",t.get("mathsize")]}:{},o=e.getProperty("texprimestyle")||!1;this.setInheritedAttributes(i,n,r,o)},n.prototype.verifyTree=function(e){if(void 0===e&&(e=null),null!==e){this.verifyAttributes(e);var t=this.arity;e.checkArity&&t>=0&&t!==1/0&&(1===t&&0===this.childNodes.length||1!==t&&this.childNodes.length!==t)&&this.mError('Wrong number of children for "'+this.kind+'" node',e,!0),this.verifyChildren(e)}},n.prototype.verifyAttributes=function(e){var t,n;if(e.checkAttributes){var r=this.attributes,i=[];try{for(var o=a(r.getExplicitNames()),s=o.next();!s.done;s=o.next()){var l=s.value;"data-"===l.substr(0,5)||void 0!==r.getDefault(l)||l.match(/^(?:class|style|id|(?:xlink:)?href)$/)||i.push(l)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}i.length&&this.mError("Unknown attributes for "+this.kind+" node: "+i.join(", "),e)}},n.prototype.verifyChildren=function(e){var t,n;try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){i.value.verifyTree(e)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}},n.prototype.mError=function(e,t,n){if(void 0===n&&(n=!1),this.parent&&this.parent.isKind("merror"))return null;var r=this.factory.create("merror");if(t.fullErrors||n){var i=this.factory.create("mtext"),o=this.factory.create("text");o.setText(t.fullErrors?e:this.kind),i.appendChild(o),r.appendChild(i),this.parent.replaceChild(r,this)}else this.parent.replaceChild(r,this),r.appendChild(this);return r},n.defaults={mathbackground:l.INHERIT,mathcolor:l.INHERIT,mathsize:l.INHERIT,dir:l.INHERIT},n.noInherit={mstyle:{mpadded:{width:!0,height:!0,depth:!0,lspace:!0,voffset:!0},mtable:{width:!0,height:!0,depth:!0,align:!0}},maligngroup:{mrow:{groupalign:!0},mtable:{groupalign:!0}}},n.alwaysInherit={scriptminsize:!0,scriptsizemultiplier:!0},n.verifyDefaults={checkArity:!0,checkAttributes:!1,fullErrors:!1,fixMmultiscripts:!0,fixMtables:!0},n}(c.AbstractNode);t.AbstractMmlNode=h;var p=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"isToken",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.getText=function(){var e,t,n="";try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){var o=i.value;o instanceof v&&(n+=o.getText())}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}return n},t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i,o;try{for(var s=a(this.childNodes),l=s.next();!l.done;l=s.next()){var c=l.value;c instanceof h&&c.setInheritedAttributes(e,t,n,r)}}catch(e){i={error:e}}finally{try{l&&!l.done&&(o=s.return)&&o.call(s)}finally{if(i)throw i.error}}},t.prototype.walkTree=function(e,t){var n,r;e(this,t);try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){var s=o.value;s instanceof h&&s.walkTree(e,t)}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return t},t.defaults=o(o({},h.defaults),{mathvariant:"normal",mathsize:l.INHERIT}),t}(h);t.AbstractMmlTokenNode=p;var f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return this.childNodes[0].isSpacelike},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isEmbellished",{get:function(){return this.childNodes[0].isEmbellished},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),t.prototype.core=function(){return this.childNodes[0]},t.prototype.coreMO=function(){return this.childNodes[0].coreMO()},t.prototype.setTeXclass=function(e){return e=this.childNodes[0].setTeXclass(e),this.updateTeXclass(this.childNodes[0]),e},t.defaults=h.defaults,t}(h);t.AbstractMmlLayoutNode=f;var m=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return i(n,e),Object.defineProperty(n.prototype,"isEmbellished",{get:function(){return this.childNodes[0].isEmbellished},enumerable:!1,configurable:!0}),n.prototype.core=function(){return this.childNodes[0]},n.prototype.coreMO=function(){return this.childNodes[0].coreMO()},n.prototype.setTeXclass=function(e){var n,r;this.getPrevClass(e),this.texClass=t.TEXCLASS.ORD;var i=this.childNodes[0];i?this.isEmbellished||i.isKind("mi")?(e=i.setTeXclass(e),this.updateTeXclass(this.core())):(i.setTeXclass(null),e=this):e=this;try{for(var o=a(this.childNodes.slice(1)),s=o.next();!s.done;s=o.next()){var l=s.value;l&&l.setTeXclass(null)}}catch(e){n={error:e}}finally{try{s&&!s.done&&(r=o.return)&&r.call(o)}finally{if(n)throw n.error}}return e},n.defaults=h.defaults,n}(h);t.AbstractMmlBaseNode=m;var g=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return i(n,e),Object.defineProperty(n.prototype,"isToken",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isEmbellished",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isSpacelike",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"linebreakContainer",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"hasNewLine",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"arity",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"isInferred",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"notParent",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"Parent",{get:function(){return this.parent},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"texClass",{get:function(){return t.TEXCLASS.NONE},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"prevClass",{get:function(){return t.TEXCLASS.NONE},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"prevLevel",{get:function(){return 0},enumerable:!1,configurable:!0}),n.prototype.hasSpacingAttributes=function(){return!1},Object.defineProperty(n.prototype,"attributes",{get:function(){return null},enumerable:!1,configurable:!0}),n.prototype.core=function(){return this},n.prototype.coreMO=function(){return this},n.prototype.coreIndex=function(){return 0},n.prototype.childPosition=function(){return 0},n.prototype.setTeXclass=function(e){return e},n.prototype.texSpacing=function(){return""},n.prototype.setInheritedAttributes=function(e,t,n,r){},n.prototype.inheritAttributesFrom=function(e){},n.prototype.verifyTree=function(e){},n.prototype.mError=function(e,t,n){void 0===n&&(n=!1)},n}(c.AbstractEmptyNode);t.AbstractMmlEmptyNode=g;var v=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.text="",t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"text"},enumerable:!1,configurable:!0}),t.prototype.getText=function(){return this.text},t.prototype.setText=function(e){return this.text=e,this},t.prototype.copy=function(){return this.factory.create(this.kind).setText(this.getText())},t.prototype.toString=function(){return this.text},t}(g);t.TextNode=v;var y=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.xml=null,t.adaptor=null,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"XML"},enumerable:!1,configurable:!0}),t.prototype.getXML=function(){return this.xml},t.prototype.setXML=function(e,t){return void 0===t&&(t=null),this.xml=e,this.adaptor=t,this},t.prototype.getSerializedXML=function(){return this.adaptor.serializeXML(this.xml)},t.prototype.copy=function(){return this.factory.create(this.kind).setXML(this.adaptor.clone(this.xml))},t.prototype.toString=function(){return"XML data"},t}(g);t.XMLNode=y},function(e,t,n){"use strict";n.r(t),n.d(t,"VirtualDOM",(function(){return o})),n.d(t,"VirtualElement",(function(){return l})),n.d(t,"VirtualElementPass",(function(){return c})),n.d(t,"VirtualText",(function(){return s})),n.d(t,"h",(function(){return u})),n.d(t,"hpass",(function(){return d}));var r=n(2),i=function(e,t){return(i=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)};
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var o,a,s=function(e){this.type="text",this.content=e},l=function(e,t,n,r){this.type="element",this.tag=e,this.attrs=t,this.children=n,this.renderer=r},c=function(e){function t(t,n,r){return e.call(this,t,n,[],r||void 0)||this}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}i(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}(t,e),t}(l);function u(e){for(var t,n={},r=[],i=1,o=arguments.length;i<o;++i){var a=arguments[i];"string"==typeof a?r.push(new s(a)):a instanceof s||a instanceof l?r.push(a):a instanceof Array?c(r,a):1!==i&&2!==i||!a||"object"!=typeof a||("render"in a?t=a:n=a)}return new l(e,n,r,t);function c(e,t){for(var n=0,r=t;n<r.length;n++){var i=r[n];"string"==typeof i?e.push(new s(i)):(i instanceof s||i instanceof l)&&e.push(i)}}}function d(e){var t={},n=null;if(2===arguments.length){var r=arguments[1];"render"in r?n=r:t=r}else if(3===arguments.length)t=arguments[1],n=arguments[2];else if(arguments.length>3)throw new Error("hpass() should be called with 1, 2, or 3 arguments");return new c(e,t,n)}!function(e){e.a=e.bind(void 0,"a"),e.abbr=e.bind(void 0,"abbr"),e.address=e.bind(void 0,"address"),e.area=e.bind(void 0,"area"),e.article=e.bind(void 0,"article"),e.aside=e.bind(void 0,"aside"),e.audio=e.bind(void 0,"audio"),e.b=e.bind(void 0,"b"),e.bdi=e.bind(void 0,"bdi"),e.bdo=e.bind(void 0,"bdo"),e.blockquote=e.bind(void 0,"blockquote"),e.br=e.bind(void 0,"br"),e.button=e.bind(void 0,"button"),e.canvas=e.bind(void 0,"canvas"),e.caption=e.bind(void 0,"caption"),e.cite=e.bind(void 0,"cite"),e.code=e.bind(void 0,"code"),e.col=e.bind(void 0,"col"),e.colgroup=e.bind(void 0,"colgroup"),e.data=e.bind(void 0,"data"),e.datalist=e.bind(void 0,"datalist"),e.dd=e.bind(void 0,"dd"),e.del=e.bind(void 0,"del"),e.dfn=e.bind(void 0,"dfn"),e.div=e.bind(void 0,"div"),e.dl=e.bind(void 0,"dl"),e.dt=e.bind(void 0,"dt"),e.em=e.bind(void 0,"em"),e.embed=e.bind(void 0,"embed"),e.fieldset=e.bind(void 0,"fieldset"),e.figcaption=e.bind(void 0,"figcaption"),e.figure=e.bind(void 0,"figure"),e.footer=e.bind(void 0,"footer"),e.form=e.bind(void 0,"form"),e.h1=e.bind(void 0,"h1"),e.h2=e.bind(void 0,"h2"),e.h3=e.bind(void 0,"h3"),e.h4=e.bind(void 0,"h4"),e.h5=e.bind(void 0,"h5"),e.h6=e.bind(void 0,"h6"),e.header=e.bind(void 0,"header"),e.hr=e.bind(void 0,"hr"),e.i=e.bind(void 0,"i"),e.iframe=e.bind(void 0,"iframe"),e.img=e.bind(void 0,"img"),e.input=e.bind(void 0,"input"),e.ins=e.bind(void 0,"ins"),e.kbd=e.bind(void 0,"kbd"),e.label=e.bind(void 0,"label"),e.legend=e.bind(void 0,"legend"),e.li=e.bind(void 0,"li"),e.main=e.bind(void 0,"main"),e.map=e.bind(void 0,"map"),e.mark=e.bind(void 0,"mark"),e.meter=e.bind(void 0,"meter"),e.nav=e.bind(void 0,"nav"),e.noscript=e.bind(void 0,"noscript"),e.object=e.bind(void 0,"object"),e.ol=e.bind(void 0,"ol"),e.optgroup=e.bind(void 0,"optgroup"),e.option=e.bind(void 0,"option"),e.output=e.bind(void 0,"output"),e.p=e.bind(void 0,"p"),e.param=e.bind(void 0,"param"),e.pre=e.bind(void 0,"pre"),e.progress=e.bind(void 0,"progress"),e.q=e.bind(void 0,"q"),e.rp=e.bind(void 0,"rp"),e.rt=e.bind(void 0,"rt"),e.ruby=e.bind(void 0,"ruby"),e.s=e.bind(void 0,"s"),e.samp=e.bind(void 0,"samp"),e.section=e.bind(void 0,"section"),e.select=e.bind(void 0,"select"),e.small=e.bind(void 0,"small"),e.source=e.bind(void 0,"source"),e.span=e.bind(void 0,"span"),e.strong=e.bind(void 0,"strong"),e.sub=e.bind(void 0,"sub"),e.summary=e.bind(void 0,"summary"),e.sup=e.bind(void 0,"sup"),e.table=e.bind(void 0,"table"),e.tbody=e.bind(void 0,"tbody"),e.td=e.bind(void 0,"td"),e.textarea=e.bind(void 0,"textarea"),e.tfoot=e.bind(void 0,"tfoot"),e.th=e.bind(void 0,"th"),e.thead=e.bind(void 0,"thead"),e.time=e.bind(void 0,"time"),e.title=e.bind(void 0,"title"),e.tr=e.bind(void 0,"tr"),e.track=e.bind(void 0,"track"),e.u=e.bind(void 0,"u"),e.ul=e.bind(void 0,"ul"),e.var_=e.bind(void 0,"var"),e.video=e.bind(void 0,"video"),e.wbr=e.bind(void 0,"wbr")}(u||(u={})),function(e){e.realize=function(e){return a.createDOMNode(e)},e.render=function(e,t){var n=a.hostMap.get(t)||[],r=a.asContentArray(e);a.hostMap.set(t,r),a.updateContent(t,n,r)}}(o||(o={})),function(e){function t(e){var n=arguments[1]||null,r=arguments[2]||null;if(n)n.insertBefore(t(e),r);else{if("text"===e.type)return document.createTextNode(e.content);if(i(n=document.createElement(e.tag),e.attrs),e.renderer)return e.renderer.render(n,{attrs:e.attrs,children:e.children}),n;for(var o=0,a=e.children.length;o<a;++o)t(e.children[o],n)}return n}e.hostMap=new WeakMap,e.asContentArray=function(e){return e?e instanceof Array?e:[e]:[]},e.createDOMNode=t,e.updateContent=function e(n,i,a){if(i!==a){for(var s=function(e,t){for(var n=e.firstChild,r=Object.create(null),i=0,o=t;i<o.length;i++){var a=o[i];"element"===a.type&&a.attrs.key&&(r[a.attrs.key]={vNode:a,element:n}),n=n.nextSibling}return r}(n,i),l=i.slice(),c=n.firstChild,u=a.length,d=0;d<u;++d)if(d>=l.length)t(a[d],n);else{var h=l[d],p=a[d];if(h!==p)if("text"!==h.type||"text"!==p.type)if("text"!==h.type&&"text"!==p.type)if(!h.renderer==!p.renderer){var f=p.attrs.key;if(f&&f in s){var m=s[f];m.vNode!==h&&(r.ArrayExt.move(l,l.indexOf(m.vNode,d+1),d),n.insertBefore(m.element,c),h=m.vNode,c=m.element)}if(h!==p){var g=h.attrs.key;g&&g!==f?(r.ArrayExt.insert(l,d,p),t(p,n,c)):h.tag===p.tag?(o(c,h.attrs,p.attrs),p.renderer?p.renderer.render(c,{attrs:p.attrs,children:p.children}):e(c,h.children,p.children),c=c.nextSibling):(r.ArrayExt.insert(l,d,p),t(p,n,c))}else c=c.nextSibling}else r.ArrayExt.insert(l,d,p),t(p,n,c);else r.ArrayExt.insert(l,d,p),t(p,n,c);else c.textContent=p.content,c=c.nextSibling;else c=c.nextSibling}!function e(t,n,r,i){for(var o=n.length-1;o>=r;--o){var a=n[o],s=i?t.lastChild:t.childNodes[o];"text"===a.type||(a.renderer&&a.renderer.unrender?a.renderer.unrender(s,{attrs:a.attrs,children:a.children}):e(s,a.children,0,!1)),i&&t.removeChild(s)}}(n,l,u,!0)}};var n={key:!0,className:!0,htmlFor:!0,dataset:!0,style:!0};function i(e,t){for(var r in t)r in n||("on"===r.substr(0,2)?e[r]=t[r]:e.setAttribute(r,t[r]));void 0!==t.className&&e.setAttribute("class",t.className),void 0!==t.htmlFor&&e.setAttribute("for",t.htmlFor),t.dataset&&function(e,t){for(var n in t)e.setAttribute("data-"+n,t[n])}(e,t.dataset),t.style&&function(e,t){var n,r=e.style;for(n in t)r[n]=t[n]}(e,t.style)}function o(e,t,r){if(t!==r){var i;for(i in t)i in n||i in r||("on"===i.substr(0,2)?e[i]=null:e.removeAttribute(i));for(i in r)i in n||t[i]===r[i]||("on"===i.substr(0,2)?e[i]=r[i]:e.setAttribute(i,r[i]));t.className!==r.className&&(void 0!==r.className?e.setAttribute("class",r.className):e.removeAttribute("class")),t.htmlFor!==r.htmlFor&&(void 0!==r.htmlFor?e.setAttribute("for",r.htmlFor):e.removeAttribute("for")),t.dataset!==r.dataset&&function(e,t,n){for(var r in t)r in n||e.removeAttribute("data-"+r);for(var i in n)t[i]!==n[i]&&e.setAttribute("data-"+i,n[i])}(e,t.dataset||{},r.dataset||{}),t.style!==r.style&&function(e,t,n){var r,i=e.style;for(r in t)r in n||(i[r]="");for(r in n)t[r]!==n[r]&&(i[r]=n[r])}(e,t.style||{},r.style||{})}}}(a||(a={}))},function(e,t,n){"use strict";n.d(t,"d",(function(){return r})),n.d(t,"a",(function(){return i})),n.d(t,"i",(function(){return o})),n.d(t,"f",(function(){return a})),n.d(t,"b",(function(){return s})),n.d(t,"h",(function(){return l})),n.d(t,"g",(function(){return c})),n.d(t,"c",(function(){return u})),n.d(t,"e",(function(){return d}));const r=Math.floor,i=(Math.ceil,Math.abs),o=(Math.imul,Math.round),a=Math.log10,s=(Math.log2,Math.log,Math.sqrt,(e,t)=>e+t),l=(e,t)=>e<t?e:t,c=(e,t)=>e>t?e:t,u=(Number.isNaN,Math.pow,e=>Math.pow(10,e)),d=(Math.sign,e=>0!==e?e<0:1/e<0)},function(e,t){e.exports=function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e},e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){"use strict";n.r(t),n.d(t,"DisposableDelegate",(function(){return s})),n.d(t,"DisposableSet",(function(){return c})),n.d(t,"ObservableDisposableDelegate",(function(){return l})),n.d(t,"ObservableDisposableSet",(function(){return u}));var r=n(2),i=n(4),o=function(e,t){return(o=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)};function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}o(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}var s=function(){function e(e){this._fn=e}return Object.defineProperty(e.prototype,"isDisposed",{get:function(){return!this._fn},enumerable:!0,configurable:!0}),e.prototype.dispose=function(){if(this._fn){var e=this._fn;this._fn=null,e()}},e}(),l=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._disposed=new i.Signal(t),t}return a(t,e),Object.defineProperty(t.prototype,"disposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._disposed.emit(void 0),i.Signal.clearData(this))},t}(s),c=function(){function e(){this._isDisposed=!1,this._items=new Set}return Object.defineProperty(e.prototype,"isDisposed",{get:function(){return this._isDisposed},enumerable:!0,configurable:!0}),e.prototype.dispose=function(){this._isDisposed||(this._isDisposed=!0,this._items.forEach((function(e){e.dispose()})),this._items.clear())},e.prototype.contains=function(e){return this._items.has(e)},e.prototype.add=function(e){this._items.add(e)},e.prototype.remove=function(e){this._items.delete(e)},e.prototype.clear=function(){this._items.clear()},e}();!function(e){e.from=function(t){var n=new e;return Object(r.each)(t,(function(e){n.add(e)})),n}}(c||(c={}));var u=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._disposed=new i.Signal(t),t}return a(t,e),Object.defineProperty(t.prototype,"disposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._disposed.emit(void 0),i.Signal.clearData(this))},t}(c);!function(e){e.from=function(t){var n=new e;return Object(r.each)(t,(function(e){n.add(e)})),n}}(u||(u={}))},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.EnvironmentMap=t.CommandMap=t.MacroMap=t.DelimiterMap=t.CharacterMap=t.AbstractParseMap=t.RegExpMap=t.AbstractSymbolMap=void 0;var l=n(96),c=n(136),u=function(){function e(e,t){this._name=e,this._parser=t,c.MapHandler.register(this)}return Object.defineProperty(e.prototype,"name",{get:function(){return this._name},enumerable:!1,configurable:!0}),e.prototype.parserFor=function(e){return this.contains(e)?this.parser:null},e.prototype.parse=function(e){var t=o(e,2),n=t[0],r=t[1],i=this.parserFor(r),a=this.lookup(r);return i&&a?i(n,a)||!0:null},Object.defineProperty(e.prototype,"parser",{get:function(){return this._parser},set:function(e){this._parser=e},enumerable:!1,configurable:!0}),e}();t.AbstractSymbolMap=u;var d=function(e){function t(t,n,r){var i=e.call(this,t,n)||this;return i._regExp=r,i}return i(t,e),t.prototype.contains=function(e){return this._regExp.test(e)},t.prototype.lookup=function(e){return this.contains(e)?e:null},t}(u);t.RegExpMap=d;var h=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.map=new Map,t}return i(t,e),t.prototype.lookup=function(e){return this.map.get(e)},t.prototype.contains=function(e){return this.map.has(e)},t.prototype.add=function(e,t){this.map.set(e,t)},t.prototype.remove=function(e){this.map.delete(e)},t}(u);t.AbstractParseMap=h;var p=function(e){function t(t,n,r){var i,s,c=e.call(this,t,n)||this;try{for(var u=a(Object.keys(r)),d=u.next();!d.done;d=u.next()){var h=d.value,p=r[h],f=o("string"==typeof p?[p,null]:p,2),m=f[0],g=f[1],v=new l.Symbol(h,m,g);c.add(h,v)}}catch(e){i={error:e}}finally{try{d&&!d.done&&(s=u.return)&&s.call(u)}finally{if(i)throw i.error}}return c}return i(t,e),t}(h);t.CharacterMap=p;var f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.parse=function(t){var n=o(t,2),r=n[0],i=n[1];return e.prototype.parse.call(this,[r,"\\"+i])},t}(p);t.DelimiterMap=f;var m=function(e){function t(t,n,r){var i,s,c=e.call(this,t,null)||this;try{for(var u=a(Object.keys(n)),d=u.next();!d.done;d=u.next()){var h=d.value,p=n[h],f=o("string"==typeof p?[p]:p),m=f[0],g=f.slice(1),v=new l.Macro(h,r[m],g);c.add(h,v)}}catch(e){i={error:e}}finally{try{d&&!d.done&&(s=u.return)&&s.call(u)}finally{if(i)throw i.error}}return c}return i(t,e),t.prototype.parserFor=function(e){var t=this.lookup(e);return t?t.func:null},t.prototype.parse=function(e){var t=o(e,2),n=t[0],r=t[1],i=this.lookup(r),a=this.parserFor(r);return i&&a?a.apply(void 0,s([n,i.symbol],o(i.args)))||!0:null},t}(h);t.MacroMap=m;var g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.parse=function(e){var t=o(e,2),n=t[0],r=t[1],i=this.lookup(r),a=this.parserFor(r);if(!i||!a)return null;if(!a)return null;var l=n.currentCS;n.currentCS="\\"+r;var c=a.apply(void 0,s([n,"\\"+i.symbol],o(i.args)));return n.currentCS=l,c||!0},t}(m);t.CommandMap=g;var v=function(e){function t(t,n,r,i){var o=e.call(this,t,r,i)||this;return o.parser=n,o}return i(t,e),t.prototype.parse=function(e){var t=o(e,2),n=t[0],r=t[1],i=this.lookup(r),a=this.parserFor(r);return i&&a?(this.parser(n,i.symbol,a,i.args),!0):null},t}(m);t.EnvironmentMap=v},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.ParserConfiguration=t.ConfigurationHandler=t.Configuration=void 0;var o,a=n(47),s=n(136),l=n(133),c=n(108),u=n(72),d=function(){function e(e,t,n,r,i,o,a,s,l,c,u,d,h){void 0===t&&(t={}),void 0===n&&(n={}),void 0===r&&(r={}),void 0===i&&(i={}),void 0===o&&(o={}),void 0===a&&(a={}),void 0===s&&(s=[]),void 0===l&&(l=[]),void 0===c&&(c=null),void 0===u&&(u=null),this.name=e,this.handler=t,this.fallback=n,this.items=r,this.tags=i,this.options=o,this.nodes=a,this.preprocessors=s,this.postprocessors=l,this.initMethod=c,this.configMethod=u,this.priority=d,this.parser=h,this.handler=Object.assign({character:[],delimiter:[],macro:[],environment:[]},t)}return e.makeProcessor=function(e,t){return Array.isArray(e)?e:[e,t]},e._create=function(t,n){var r=this;void 0===n&&(n={});var i=n.priority||c.PrioritizedList.DEFAULTPRIORITY,o=n.init?this.makeProcessor(n.init,i):null,a=n.config?this.makeProcessor(n.config,i):null,s=(n.preprocessors||[]).map((function(e){return r.makeProcessor(e,i)})),l=(n.postprocessors||[]).map((function(e){return r.makeProcessor(e,i)})),u=n.parser||"tex";return new e(t,n.handler||{},n.fallback||{},n.items||{},n.tags||{},n.options||{},n.nodes||{},s,l,o,a,i,u)},e.create=function(t,n){void 0===n&&(n={});var r=e._create(t,n);return o.set(t,r),r},e.local=function(t){return void 0===t&&(t={}),e._create("",t)},Object.defineProperty(e.prototype,"init",{get:function(){return this.initMethod?this.initMethod[0]:null},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"config",{get:function(){return this.configMethod?this.configMethod[0]:null},enumerable:!1,configurable:!0}),e}();t.Configuration=d,function(e){var t=new Map;e.set=function(e,n){t.set(e,n)},e.get=function(e){return t.get(e)},e.keys=function(){return t.keys()}}(o=t.ConfigurationHandler||(t.ConfigurationHandler={}));var h=function(){function e(e,t){var n,i,o,a;void 0===t&&(t=["tex"]),this.initMethod=new l.FunctionList,this.configMethod=new l.FunctionList,this.configurations=new c.PrioritizedList,this.parsers=[],this.handlers=new s.SubHandlers,this.items={},this.tags={},this.options={},this.nodes={},this.parsers=t;try{for(var u=r(e.slice().reverse()),d=u.next();!d.done;d=u.next()){var h=d.value;this.addPackage(h)}}catch(e){n={error:e}}finally{try{d&&!d.done&&(i=u.return)&&i.call(u)}finally{if(n)throw n.error}}try{for(var p=r(this.configurations),f=p.next();!f.done;f=p.next()){var m=f.value,g=m.item,v=m.priority;this.append(g,v)}}catch(e){o={error:e}}finally{try{f&&!f.done&&(a=p.return)&&a.call(p)}finally{if(o)throw o.error}}}return e.prototype.init=function(){this.initMethod.execute(this)},e.prototype.config=function(e){var t,n;this.configMethod.execute(this,e);try{for(var i=r(this.configurations),o=i.next();!o.done;o=i.next()){var a=o.value;this.addFilters(e,a.item)}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},e.prototype.addPackage=function(e){var t="string"==typeof e?e:e[0],n=this.getPackage(t);n&&this.configurations.add(n,"string"==typeof e?n.priority:e[1])},e.prototype.add=function(e,t,n){var i,o;void 0===n&&(n={});var s=this.getPackage(e);this.append(s),this.configurations.add(s,s.priority),this.init();var l=t.parseOptions;l.nodeFactory.setCreators(s.nodes);try{for(var c=r(Object.keys(s.items)),d=c.next();!d.done;d=c.next()){var h=d.value;l.itemFactory.setNodeClass(h,s.items[h])}}catch(e){i={error:e}}finally{try{d&&!d.done&&(o=c.return)&&o.call(c)}finally{if(i)throw i.error}}u.TagsFactory.addTags(s.tags),a.defaultOptions(l.options,s.options),a.userOptions(l.options,n),this.addFilters(t,s),s.config&&s.config(this,t)},e.prototype.getPackage=function(e){var t=o.get(e);if(t&&this.parsers.indexOf(t.parser)<0)throw Error("Package "+e+" doesn't target the proper parser");return t},e.prototype.append=function(e,t){t=t||e.priority,e.initMethod&&this.initMethod.add(e.initMethod[0],e.initMethod[1]),e.configMethod&&this.configMethod.add(e.configMethod[0],e.configMethod[1]),this.handlers.add(e.handler,e.fallback,t),Object.assign(this.items,e.items),Object.assign(this.tags,e.tags),a.defaultOptions(this.options,e.options),Object.assign(this.nodes,e.nodes)},e.prototype.addFilters=function(e,t){var n,o,a,s;try{for(var l=r(t.preprocessors),c=l.next();!c.done;c=l.next()){var u=i(c.value,2),d=u[0],h=u[1];e.preFilters.add(d,h)}}catch(e){n={error:e}}finally{try{c&&!c.done&&(o=l.return)&&o.call(l)}finally{if(n)throw n.error}}try{for(var p=r(t.postprocessors),f=p.next();!f.done;f=p.next()){var m=i(f.value,2),g=m[0];h=m[1];e.postFilters.add(g,h)}}catch(e){a={error:e}}finally{try{f&&!f.done&&(s=p.return)&&s.call(p)}finally{if(a)throw a.error}}},e}();t.ParserConfiguration=h},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(713);t.TypeStyle=r.TypeStyle;var i=n(716);t.types=i;var o=n(386);t.extend=o.extend,t.classes=o.classes,t.media=o.media;var a=new r.TypeStyle({autoGenerateTag:!0});t.setStylesTarget=a.setStylesTarget,t.cssRaw=a.cssRaw,t.cssRule=a.cssRule,t.forceRenderStyles=a.forceRenderStyles,t.fontFace=a.fontFace,t.getStyles=a.getStyles,t.keyframes=a.keyframes,t.reinit=a.reinit,t.style=a.style,t.stylesheet=a.stylesheet,t.createTypeStyle=function(e){var t=new r.TypeStyle({autoGenerateTag:!1});return e&&t.setStylesTarget(e),t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=function(){function e(t,n){for(var r=[],i=2;i<arguments.length;i++)r[i-2]=arguments[i];this.id=t,this.message=e.processString(n,r)}return e.processString=function(t,n){for(var r=t.split(e.pattern),i=1,o=r.length;i<o;i+=2){var a=r[i].charAt(0);if(a>="0"&&a<="9")r[i]=n[parseInt(r[i],10)-1],"number"==typeof r[i]&&(r[i]=r[i].toString());else if("{"===a){if((a=r[i].substr(1))>="0"&&a<="9")r[i]=n[parseInt(r[i].substr(1,r[i].length-2),10)-1],"number"==typeof r[i]&&(r[i]=r[i].toString());else r[i].match(/^\{([a-z]+):%(\d+)\|(.*)\}$/)&&(r[i]="%"+r[i])}null==r[i]&&(r[i]="???")}return r.join("")},e.pattern=/%(\d+|\{\d+\}|\{[a-z]+:\%\d+(?:\|(?:%\{\d+\}|%.|[^\}])*)+\}|.)/g,e}();t.default=r},function(e,t,n){"use strict";n.d(t,"b",(function(){return m})),n.d(t,"c",(function(){return g})),n.d(t,"a",(function(){return v}));var r,i=n(586),o=n(13),a=n(54),s=n(2),l=n(6),c=n(8),u=n(3),d=n(0),h=n(77),p=n(59),f=n(139);function m(e={}){return new v(e).launch()}function g(e,t,n=[v.okButton({label:"Dismiss"})]){console.warn("Showing error:",t);const i="string"==typeof t?t:t.message,o=e+"----"+i,a=r.errorMessagePromiseCache.get(o);if(a)return a;{const t=m({title:e,body:i,buttons:n}).then(()=>{r.errorMessagePromiseCache.delete(o)},e=>{throw r.errorMessagePromiseCache.delete(o),e});return r.errorMessagePromiseCache.set(o,t),t}}class v extends u.Widget{constructor(e={}){super(),this._focusNodeSelector="",this.addClass("jp-Dialog");const t=r.handleOptions(e),n=t.renderer;this._host=t.host,this._defaultButton=t.defaultButton,this._buttons=t.buttons,this._hasClose=t.hasClose,this._buttonNodes=Object(s.toArray)(Object(s.map)(this._buttons,e=>n.createButtonNode(e))),this._lastMouseDownInDialog=!1;const i=this.layout=new u.PanelLayout,o=new u.Panel;o.addClass("jp-Dialog-content"),"string"==typeof e.body&&o.addClass("jp-Dialog-content-small"),i.addWidget(o),this._body=t.body;const a=n.createHeader(t.title,()=>this.reject(),e),l=n.createBody(t.body),c=n.createFooter(this._buttonNodes);o.addWidget(a),o.addWidget(l),o.addWidget(c),this._primary=this._buttonNodes[this._defaultButton],this._focusNodeSelector=e.focusNodeSelector,v.tracker.add(this)}dispose(){const e=this._promise;e&&(this._promise=null,e.reject(void 0),s.ArrayExt.removeFirstOf(r.launchQueue,e.promise)),super.dispose()}launch(){if(this._promise)return this._promise.promise;const e=this._promise=new l.PromiseDelegate,t=Promise.all(r.launchQueue);return r.launchQueue.push(this._promise.promise),t.then(()=>this._promise?(u.Widget.attach(this,this._host),e.promise):Promise.resolve({button:v.cancelButton(),value:null}))}resolve(e){this._promise&&(void 0===e&&(e=this._defaultButton),this._resolve(this._buttons[e]))}reject(){this._promise&&this._resolve(v.cancelButton())}handleEvent(e){switch(e.type){case"keydown":this._evtKeydown(e);break;case"mousedown":this._evtMouseDown(e);break;case"click":this._evtClick(e);break;case"focus":this._evtFocus(e);break;case"contextmenu":e.preventDefault(),e.stopPropagation()}}onAfterAttach(e){const t=this.node;if(t.addEventListener("keydown",this,!0),t.addEventListener("contextmenu",this,!0),t.addEventListener("click",this,!0),document.addEventListener("mousedown",this,!0),document.addEventListener("focus",this,!0),this._first=r.findFirstFocusable(this.node),this._original=document.activeElement,this._focusNodeSelector){const e=this.node.querySelector(".jp-Dialog-body"),t=null==e?void 0:e.querySelector(this._focusNodeSelector);t&&(this._primary=t)}this._primary.focus()}onAfterDetach(e){const t=this.node;t.removeEventListener("keydown",this,!0),t.removeEventListener("contextmenu",this,!0),t.removeEventListener("click",this,!0),document.removeEventListener("focus",this,!0),document.removeEventListener("mousedown",this,!0),this._original.focus()}onCloseRequest(e){this._promise&&this.reject(),super.onCloseRequest(e)}_evtClick(e){if(!this.node.getElementsByClassName("jp-Dialog-content")[0].contains(e.target))return e.stopPropagation(),e.preventDefault(),void(this._hasClose&&!this._lastMouseDownInDialog&&this.reject());for(const t of this._buttonNodes)if(t.contains(e.target)){const e=this._buttonNodes.indexOf(t);this.resolve(e)}}_evtKeydown(e){switch(e.keyCode){case 27:e.stopPropagation(),e.preventDefault(),this._hasClose&&this.reject();break;case 37:{const t=document.activeElement;if(t instanceof HTMLButtonElement){let n=this._buttonNodes.indexOf(t)-1;n<0&&(n=this._buttonNodes.length-1);const r=this._buttonNodes[n];e.stopPropagation(),e.preventDefault(),r.focus()}break}case 39:{const t=document.activeElement;if(t instanceof HTMLButtonElement){let n=this._buttonNodes.indexOf(t)+1;n==this._buttons.length&&(n=0);const r=this._buttonNodes[n];e.stopPropagation(),e.preventDefault(),r.focus()}break}case 9:{const t=this._buttonNodes[this._buttons.length-1];document.activeElement!==t||e.shiftKey||(e.stopPropagation(),e.preventDefault(),this._first.focus());break}case 13:{e.stopPropagation(),e.preventDefault();const t=document.activeElement;let n;t instanceof HTMLButtonElement&&(n=this._buttonNodes.indexOf(t)),this.resolve(n);break}}}_evtFocus(e){const t=e.target;this.node.contains(t)||(e.stopPropagation(),this._buttonNodes[this._defaultButton].focus())}_evtMouseDown(e){const t=this.node.getElementsByClassName("jp-Dialog-content")[0],n=e.target;this._lastMouseDownInDialog=t.contains(n)}_resolve(e){const t=this._promise;if(!t)return void this.dispose();this._promise=null,s.ArrayExt.removeFirstOf(r.launchQueue,t.promise);const n=this._body;let i=null;e.accept&&n instanceof u.Widget&&"function"==typeof n.getValue&&(i=n.getValue()),this.dispose(),t.resolve({button:e,value:i})}}!function(e){function t(e){e.accept=!1!==e.accept;const t=e.accept?"OK":"Cancel";return{label:e.label||t,iconClass:e.iconClass||"",iconLabel:e.iconLabel||"",caption:e.caption||"",className:e.className||"",accept:e.accept,actions:e.actions||[],displayType:e.displayType||"default"}}e.createButton=t,e.cancelButton=function(e={}){return e.accept=!1,t(e)},e.okButton=function(e={}){return e.accept=!0,t(e)},e.warnButton=function(e={}){return e.displayType="warn",t(e)},e.flush=function(){e.tracker.forEach(e=>{e.dispose()})};class n{createHeader(e,t=(()=>{}),n={}){let r;const s=e=>{0===e.button&&(e.preventDefault(),t())},l=e=>{const{key:n}=e;"Enter"!==n&&" "!==n||t()};return r="string"==typeof e?p.a.create(d.createElement(d.Fragment,null,e,n.hasClose&&d.createElement(i.a,{className:"jp-Dialog-close-button",onMouseDown:s,onKeyDown:l,title:"Cancel",minimal:!0},d.createElement(o.a.resolveReact,{icon:a.h,iconClass:"jp-Icon",className:"jp-ToolbarButtonComponent-icon",tag:"span"})))):p.a.create(e),r.addClass("jp-Dialog-header"),h.a.styleNode(r.node),r}createBody(e){let t;return"string"==typeof e?(t=new u.Widget({node:document.createElement("span")}),t.node.textContent=e):e instanceof u.Widget?t=e:(t=p.a.create(e),c.c.sendMessage(t,u.Widget.Msg.UpdateRequest)),t.addClass("jp-Dialog-body"),h.a.styleNode(t.node),t}createFooter(e){const t=new u.Widget;return t.addClass("jp-Dialog-footer"),Object(s.each)(e,e=>{t.node.appendChild(e)}),h.a.styleNode(t.node),t}createButtonNode(e){const t=document.createElement("button");return t.className=this.createItemClass(e),t.appendChild(this.renderIcon(e)),t.appendChild(this.renderLabel(e)),t}createItemClass(e){let t="jp-Dialog-button";e.accept?t+=" jp-mod-accept":t+=" jp-mod-reject","warn"===e.displayType&&(t+=" jp-mod-warn");const n=e.className;return n&&(t+=" "+n),t}renderIcon(e){const t=document.createElement("div");return t.className=this.createIconClass(e),t.appendChild(document.createTextNode(e.iconLabel)),t}createIconClass(e){const t="jp-Dialog-buttonIcon",n=e.iconClass;return n?`${t} ${n}`:t}renderLabel(e){const t=document.createElement("div");return t.className="jp-Dialog-buttonLabel",t.title=e.caption,t.appendChild(document.createTextNode(e.label)),t}}e.Renderer=n,e.defaultRenderer=new n,e.tracker=new f.a({namespace:"@jupyterlab/apputils:Dialog"})}(v||(v={})),function(e){e.launchQueue=[],e.errorMessagePromiseCache=new Map,e.handleOptions=function(e={}){var t,n,r,i,o,a,s,l;const c=null!==(t=e.buttons)&&void 0!==t?t:[v.cancelButton(),v.okButton()];return{title:null!==(n=e.title)&&void 0!==n?n:"",body:null!==(r=e.body)&&void 0!==r?r:"",host:null!==(i=e.host)&&void 0!==i?i:document.body,buttons:c,defaultButton:null!==(o=e.defaultButton)&&void 0!==o?o:c.length-1,renderer:null!==(a=e.renderer)&&void 0!==a?a:v.defaultRenderer,focusNodeSelector:null!==(s=e.focusNodeSelector)&&void 0!==s?s:"",hasClose:null===(l=e.hasClose)||void 0===l||l}},e.findFirstFocusable=function(e){const t=["input","select","a[href]","textarea","button","[tabindex]"].join(",");return e.querySelectorAll(t)[0]}}(r||(r={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return r})),n.d(t,"c",(function(){return i})),n.d(t,"d",(function(){return o})),n.d(t,"b",(function(){return a}));var r={BOTTOM:"bottom",BOTTOM_LEFT:"bottom-left",BOTTOM_RIGHT:"bottom-right",LEFT:"left",LEFT_BOTTOM:"left-bottom",LEFT_TOP:"left-top",RIGHT:"right",RIGHT_BOTTOM:"right-bottom",RIGHT_TOP:"right-top",TOP:"top",TOP_LEFT:"top-left",TOP_RIGHT:"top-right"};function i(e){return e===r.TOP||e===r.TOP_LEFT||e===r.TOP_RIGHT||e===r.BOTTOM||e===r.BOTTOM_LEFT||e===r.BOTTOM_RIGHT}function o(e){return e===r.LEFT||e===r.LEFT_TOP||e===r.LEFT_BOTTOM||e===r.RIGHT||e===r.RIGHT_TOP||e===r.RIGHT_BOTTOM}function a(e){return e===r.TOP||e===r.TOP_LEFT||e===r.TOP_RIGHT?r.TOP:e===r.BOTTOM||e===r.BOTTOM_LEFT||e===r.BOTTOM_RIGHT?r.BOTTOM:e===r.LEFT||e===r.LEFT_TOP||e===r.LEFT_BOTTOM?r.LEFT:r.RIGHT}},function(e,t,n){"use strict";!function e(){if("undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE){0;try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(e){console.error(e)}}}(),e.exports=n(690)},function(e,t,n){"use strict";n.d(t,"c",(function(){return r})),n.d(t,"b",(function(){return i})),n.d(t,"e",(function(){return o})),n.d(t,"d",(function(){return a})),n.d(t,"a",(function(){return s}));const r=()=>new Map,i=e=>{const t=r();return e.forEach((e,n)=>{t.set(n,e)}),t},o=(e,t,n)=>{let r=e.get(t);return void 0===r&&e.set(t,r=n()),r},a=(e,t)=>{const n=[];for(const[r,i]of e)n.push(t(i,r));return n},s=(e,t)=>{for(const[n,r]of e)if(t(r,n))return!0;return!1}},function(e,t,n){"use strict";n.d(t,"a",(function(){return bt})),n.d(t,"b",(function(){return ee})),n.d(t,"c",(function(){return wt})),n.d(t,"d",(function(){return Pt})),n.d(t,"e",(function(){return qe})),n.d(t,"f",(function(){return we})),n.d(t,"g",(function(){return Me})),n.d(t,"h",(function(){return ve})),n.d(t,"i",(function(){return be}));var r=n(78),i=n(66),o=n(25),a=n(35),s=n(10);n(11);"undefined"==typeof window||void 0!==window.performance&&window.performance;const l="undefined"==typeof crypto?null:crypto,c=null!==l?e=>{const t=new ArrayBuffer(e),n=new Uint8Array(t);return l.getRandomValues(n),t}:e=>{const t=new ArrayBuffer(e),n=new Uint8Array(t);for(let t=0;t<e;t++)n[t]=Math.ceil(4294967295*Math.random()>>>0);return t},u=(Math.random,()=>new Uint32Array(c(4))[0]),d=[1e7]+-1e3+-4e3+-8e3+-1e11,h=()=>d.replace(/[018]/g,e=>(e^u()&15>>e/4).toString(16));var p=n(53);const f=e=>new Promise(e);n(85);const m=e=>new Error(e),g=()=>{throw m("Method unimplemented")},v=()=>{throw m("Unexpected case")};var y=n(19),_=n(52),b=n(86),M=n(88);const w=Symbol;class A{constructor(e,t){this.left=e,this.right=t}}const C=(e,t)=>new A(e,t),x="undefined"!=typeof document?document:{},E=("undefined"!=typeof DOMParser&&new DOMParser,e=>a.d(e,(e,t)=>`${t}:${e};`).join(""));x.ELEMENT_NODE,x.TEXT_NODE,x.CDATA_SECTION_NODE,x.COMMENT_NODE,x.DOCUMENT_NODE,x.DOCUMENT_TYPE_NODE,x.DOCUMENT_FRAGMENT_NODE,JSON.stringify,JSON.parse;n(69);const L=w(),S=w(),T=w(),O=w(),I=w(),k=w(),D=w(),N=w(),j=w(),P={[L]:C("font-weight","bold"),[S]:C("font-weight","normal"),[T]:C("color","blue"),[I]:C("color","green"),[O]:C("color","grey"),[k]:C("color","red"),[D]:C("color","purple"),[N]:C("color","orange"),[j]:C("color","black")},z={[L]:"[1m",[S]:"[2m",[T]:"[34m",[I]:"[32m",[O]:"[37m",[k]:"[31m",[D]:"[35m",[N]:"[38;5;208m",[j]:"[0m"},R=M.c?e=>{const t=[],n=[];let r=0;for(;r<e.length;r++){const n=e[r],i=z[n];if(void 0!==i)t.push(i);else{if(n.constructor!==String&&n.constructor!==Number)break;t.push(n)}}for(r>0&&(t.push("[0m"),n.push(t.join("")));r<e.length;r++){const t=e[r];t instanceof Symbol||n.push(t)}return n}:e=>{const t=[],n=[],r=a.c();let i=[],o=0;for(;o<e.length;o++){const i=e[o],a=P[i];if(void 0!==a)r.set(a.left,a.right);else{if(i.constructor!==String&&i.constructor!==Number)break;{const e=E(r);o>0||e.length>0?(t.push("%c"+i),n.push(e)):t.push(i)}}}for(o>0&&(i=n,i.unshift(t.join("")));o<e.length;o++){const t=e[o];t instanceof Symbol||i.push(t)}return i},B=(...e)=>{console.log(...R(e)),H.forEach(t=>t.print(e))},H=new Set;p.a();const F=e=>({[Symbol.iterator](){return this},next:e}),Y=(e,t)=>F(()=>{const{done:n,value:r}=e.next();return{done:n,value:n?void 0:t(r)}});var V=n(87);r.a;class U{constructor(e,t){this.clock=e,this.len=t}}class W{constructor(){this.clients=new Map}}const G=(e,t,n)=>t.clients.forEach((t,r)=>{const i=e.doc.store.clients.get(r);for(let r=0;r<t.length;r++){const o=t[r];Pe(e,i,o.clock,o.len,n)}}),q=(e,t)=>{const n=e.clients.get(t.client);return void 0!==n&&null!==((e,t)=>{let n=0,r=e.length-1;for(;n<=r;){const i=o.d((n+r)/2),a=e[i],s=a.clock;if(s<=t){if(t<s+a.len)return i;n=i+1}else r=i-1}return null})(n,t.clock)},K=e=>{e.clients.forEach(e=>{let t,n;for(e.sort((e,t)=>e.clock-t.clock),t=1,n=1;t<e.length;t++){const r=e[n-1],i=e[t];r.clock+r.len>=i.clock?r.len=o.g(r.len,i.clock+i.len-r.clock):(n<t&&(e[n]=i),n++)}e.length=n})},X=e=>{const t=new W;for(let n=0;n<e.length;n++)e[n].clients.forEach((r,o)=>{if(!t.clients.has(o)){const a=r.slice();for(let t=n+1;t<e.length;t++)i.a(a,e[t].clients.get(o)||[]);t.clients.set(o,a)}});return K(t),t},J=(e,t,n,r)=>{a.e(e.clients,t,()=>[]).push(new U(n,r))},Q=()=>new W,Z=(e,t)=>{s.m(e.restEncoder,t.clients.size),t.clients.forEach((t,n)=>{e.resetDsCurVal(),s.m(e.restEncoder,n);const r=t.length;s.m(e.restEncoder,r);for(let n=0;n<r;n++){const r=t[n];e.writeDsClock(r.clock),e.writeDsLen(r.len)}})},$=u;class ee extends r.a{constructor({guid:e=h(),collectionid:t=null,gc:n=!0,gcFilter:r=(()=>!0),meta:i=null,autoLoad:o=!1,shouldLoad:a=!0}={}){super(),this.gc=n,this.gcFilter=r,this.clientID=$(),this.guid=e,this.collectionid=t,this.share=new Map,this.store=new Le,this._transaction=null,this._transactionCleanups=[],this.subdocs=new Set,this._item=null,this.shouldLoad=a,this.autoLoad=o,this.meta=i,this.isLoaded=!1,this.whenLoaded=f(e=>{this.on("load",()=>{this.isLoaded=!0,e(this)})})}load(){const e=this._item;null===e||this.shouldLoad||Ue(e.parent.doc,e=>{e.subdocsLoaded.add(this)},null,!0),this.shouldLoad=!0}getSubdocs(){return this.subdocs}getSubdocGuids(){return new Set(Array.from(this.subdocs).map(e=>e.guid))}transact(e,t=null){Ue(this,e,t)}get(e,t=nt){const n=a.e(this.share,e,()=>{const e=new t;return e._integrate(this,null),e}),r=n.constructor;if(t!==nt&&r!==t){if(r===nt){const r=new t;r._map=n._map,n._map.forEach(e=>{for(;null!==e;e=e.left)e.parent=r}),r._start=n._start;for(let e=r._start;null!==e;e=e.right)e.parent=r;return r._length=n._length,this.share.set(e,r),r._integrate(this,null),r}throw new Error(`Type with the name ${e} has already been defined with a different constructor`)}return n}getArray(e=""){return this.get(e,bt)}getText(e=""){return this.get(e,Pt)}getMap(e=""){return this.get(e,wt)}getXmlFragment(e=""){return this.get(e,Rt)}toJSON(){const e={};return this.share.forEach((t,n)=>{e[n]=t.toJSON()}),e}destroy(){i.c(this.subdocs).forEach(e=>e.destroy());const e=this._item;if(null!==e){this._item=null;const t=e.content;t.doc=new ee({guid:this.guid,...t.opts,shouldLoad:!1}),t.doc._item=e,Ue(e.parent.doc,n=>{const r=t.doc;e.deleted||n.subdocsAdded.add(r),n.subdocsRemoved.add(this)},null,!0)}this.emit("destroyed",[!0]),this.emit("destroy",[this]),super.destroy()}on(e,t){super.on(e,t)}off(e,t){super.off(e,t)}}class te{constructor(){this.restEncoder=s.e()}toUint8Array(){return s.f(this.restEncoder)}resetDsCurVal(){}writeDsClock(e){s.m(this.restEncoder,e)}writeDsLen(e){s.m(this.restEncoder,e)}}class ne extends te{writeLeftID(e){s.m(this.restEncoder,e.client),s.m(this.restEncoder,e.clock)}writeRightID(e){s.m(this.restEncoder,e.client),s.m(this.restEncoder,e.clock)}writeClient(e){s.m(this.restEncoder,e)}writeInfo(e){s.i(this.restEncoder,e)}writeString(e){s.l(this.restEncoder,e)}writeParentInfo(e){s.m(this.restEncoder,e?1:0)}writeTypeRef(e){s.m(this.restEncoder,e)}writeLen(e){s.m(this.restEncoder,e)}writeAny(e){s.g(this.restEncoder,e)}writeBuf(e){s.n(this.restEncoder,e)}writeJSON(e){s.l(this.restEncoder,JSON.stringify(e))}writeKey(e){s.l(this.restEncoder,e)}}class re{constructor(){this.restEncoder=s.e(),this.dsCurrVal=0}toUint8Array(){return s.f(this.restEncoder)}resetDsCurVal(){this.dsCurrVal=0}writeDsClock(e){const t=e-this.dsCurrVal;this.dsCurrVal=e,s.m(this.restEncoder,t)}writeDsLen(e){0===e&&v(),s.m(this.restEncoder,e-1),this.dsCurrVal+=e}}class ie extends re{constructor(){super(),this.keyMap=new Map,this.keyClock=0,this.keyClockEncoder=new s.a,this.clientEncoder=new s.d,this.leftClockEncoder=new s.a,this.rightClockEncoder=new s.a,this.infoEncoder=new s.b(s.i),this.stringEncoder=new s.c,this.parentInfoEncoder=new s.b(s.i),this.typeRefEncoder=new s.d,this.lenEncoder=new s.d}toUint8Array(){const e=s.e();return s.m(e,0),s.n(e,this.keyClockEncoder.toUint8Array()),s.n(e,this.clientEncoder.toUint8Array()),s.n(e,this.leftClockEncoder.toUint8Array()),s.n(e,this.rightClockEncoder.toUint8Array()),s.n(e,s.f(this.infoEncoder)),s.n(e,this.stringEncoder.toUint8Array()),s.n(e,s.f(this.parentInfoEncoder)),s.n(e,this.typeRefEncoder.toUint8Array()),s.n(e,this.lenEncoder.toUint8Array()),s.j(e,s.f(this.restEncoder)),s.f(e)}writeLeftID(e){this.clientEncoder.write(e.client),this.leftClockEncoder.write(e.clock)}writeRightID(e){this.clientEncoder.write(e.client),this.rightClockEncoder.write(e.clock)}writeClient(e){this.clientEncoder.write(e)}writeInfo(e){this.infoEncoder.write(e)}writeString(e){this.stringEncoder.write(e)}writeParentInfo(e){this.parentInfoEncoder.write(e?1:0)}writeTypeRef(e){this.typeRefEncoder.write(e)}writeLen(e){this.lenEncoder.write(e)}writeAny(e){s.g(this.restEncoder,e)}writeBuf(e){s.n(this.restEncoder,e)}writeJSON(e){s.g(this.restEncoder,e)}writeKey(e){void 0===this.keyMap.get(e)?(this.keyClockEncoder.write(this.keyClock++),this.stringEncoder.write(e)):this.keyClockEncoder.write(this.keyClock++)}}const oe=(e,t,n)=>{const r=new Map;n.forEach((e,n)=>{Te(t,n)>e&&r.set(n,e)}),Se(t).forEach((e,t)=>{n.has(t)||r.set(t,0)}),s.m(e.restEncoder,r.size),Array.from(r.entries()).sort((e,t)=>t[0]-e[0]).forEach(([n,r])=>{((e,t,n,r)=>{r=o.g(r,t[0].id.clock);const i=Ie(t,r);s.m(e.restEncoder,t.length-i),e.writeClient(n),s.m(e.restEncoder,r);const a=t[i];a.write(e,r-a.id.clock);for(let n=i+1;n<t.length;n++)t[n].write(e,0)})(e,t.clients.get(n),n,r)})};class ae{constructor(){this.l=[]}}const se=()=>new ae,le=(e,t)=>e.l.push(t),ce=(e,t)=>{const n=e.l,r=n.length;e.l=n.filter(e=>t!==e),r===e.l.length&&console.error("[yjs] Tried to remove event handler that doesn't exist.")},ue=(e,t,n)=>_.a(e.l,[t,n]);class de{constructor(e,t){this.client=e,this.clock=t}}const he=(e,t)=>e===t||null!==e&&null!==t&&e.client===t.client&&e.clock===t.clock,pe=(e,t)=>new de(e,t),fe=e=>{for(const[t,n]of e.doc.share.entries())if(n===e)return t;throw v()},me=(e,t)=>{for(;null!==t;){if(t.parent===e)return!0;t=t.parent._item}return!1};class ge{constructor(e,t,n,r=0){this.type=e,this.tname=t,this.item=n,this.assoc=r}}const ve=e=>new ge(null==e.type?null:pe(e.type.client,e.type.clock),e.tname||null,null==e.item?null:pe(e.item.client,e.item.clock),null==e.assoc?0:e.assoc);class ye{constructor(e,t,n=0){this.type=e,this.index=t,this.assoc=n}}const _e=(e,t,n)=>{let r=null,i=null;return null===e._item?i=fe(e):r=pe(e._item.id.client,e._item.id.clock),new ge(r,i,t,n)},be=(e,t,n=0)=>{let r=e._start;if(n<0){if(0===t)return _e(e,null,n);t--}for(;null!==r;){if(!r.deleted&&r.countable){if(r.length>t)return _e(e,pe(r.id.client,r.id.clock+t),n);t-=r.length}if(null===r.right&&n<0)return _e(e,r.lastId,n);r=r.right}return _e(e,null,n)},Me=(e,t)=>{const n=t.store,r=e.item,i=e.type,o=e.tname,a=e.assoc;let s=null,l=0;if(null!==r){if(Te(n,r.client)<=r.clock)return null;const e=rn(n,r),t=e.item;if(!(t instanceof ln))return null;if(s=t.parent,null===s._item||!s._item.deleted){l=t.deleted||!t.countable?0:e.diff+(a>=0?0:1);let n=t.left;for(;null!==n;)!n.deleted&&n.countable&&(l+=n.length),n=n.left}}else{if(null!==o)s=t.get(o);else{if(null===i)throw v();{if(Te(n,i.client)<=i.clock)return null;const{item:e}=rn(n,i);if(!(e instanceof ln&&e.content instanceof nn))return null;s=e.content.type}}l=a>=0?s._length:0}return((e,t,n=0)=>new ye(e,t,n))(s,l,e.assoc)},we=(e,t)=>e===t||null!==e&&null!==t&&e.tname===t.tname&&he(e.item,t.item)&&he(e.type,t.type)&&e.assoc===t.assoc;class Ae{constructor(e,t){this.ds=e,this.sv=t}}const Ce=(e,t)=>new Ae(e,t),xe=(Ce(Q(),new Map),(e,t)=>void 0===t?!e.deleted:t.sv.has(e.id.client)&&(t.sv.get(e.id.client)||0)>e.id.clock&&!q(t.ds,e.id)),Ee=(e,t)=>{const n=a.e(e.meta,Ee,b.a),r=e.doc.store;n.has(t)||(t.sv.forEach((t,n)=>{t<Te(r,n)&&Ne(e,pe(n,t))}),G(e,t.ds,e=>{}),n.add(t))};class Le{constructor(){this.clients=new Map,this.pendingStructs=null,this.pendingDs=null}}const Se=e=>{const t=new Map;return e.clients.forEach((e,n)=>{const r=e[e.length-1];t.set(n,r.id.clock+r.length)}),t},Te=(e,t)=>{const n=e.clients.get(t);if(void 0===n)return 0;const r=n[n.length-1];return r.id.clock+r.length},Oe=(e,t)=>{let n=e.clients.get(t.id.client);if(void 0===n)n=[],e.clients.set(t.id.client,n);else{const e=n[n.length-1];if(e.id.clock+e.length!==t.id.clock)throw v()}n.push(t)},Ie=(e,t)=>{let n=0,r=e.length-1,i=e[r],a=i.id.clock;if(a===t)return r;let s=o.d(t/(a+i.length-1)*r);for(;n<=r;){if(i=e[s],a=i.id.clock,a<=t){if(t<a+i.length)return s;n=s+1}else r=s-1;s=o.d((n+r)/2)}throw v()},ke=(e,t)=>{const n=e.clients.get(t.client);return n[Ie(n,t.clock)]},De=(e,t,n)=>{const r=Ie(t,n),i=t[r];return i.id.clock<n&&i instanceof ln?(t.splice(r+1,0,an(e,i,n-i.id.clock)),r+1):r},Ne=(e,t)=>{const n=e.doc.store.clients.get(t.client);return n[De(e,n,t.clock)]},je=(e,t,n)=>{const r=t.clients.get(n.client),i=Ie(r,n.clock),o=r[i];return n.clock!==o.id.clock+o.length-1&&o.constructor!==Yt&&r.splice(i+1,0,an(e,o,n.clock-o.id.clock+1)),o},Pe=(e,t,n,r,i)=>{if(0===r)return;const o=n+r;let a,s=De(e,t,n);do{a=t[s++],o<a.id.clock+a.length&&De(e,t,o),i(a)}while(s<t.length&&t[s].id.clock<o)};class ze{constructor(e,t,n){this.doc=e,this.deleteSet=new W,this.beforeState=Se(e.store),this.afterState=new Map,this.changed=new Map,this.changedParentTypes=new Map,this._mergeStructs=[],this.origin=t,this.meta=new Map,this.local=n,this.subdocsAdded=new Set,this.subdocsRemoved=new Set,this.subdocsLoaded=new Set}}const Re=(e,t)=>!(0===t.deleteSet.clients.size&&!a.a(t.afterState,(e,n)=>t.beforeState.get(n)!==e))&&(K(t.deleteSet),((e,t)=>{oe(e,t.doc.store,t.beforeState)})(e,t),Z(e,t.deleteSet),!0),Be=(e,t,n)=>{const r=t._item;(null===r||r.id.clock<(e.beforeState.get(r.id.client)||0)&&!r.deleted)&&a.e(e.changed,t,b.a).add(n)},He=(e,t)=>{const n=e[t-1],r=e[t];n.deleted===r.deleted&&n.constructor===r.constructor&&n.mergeWith(r)&&(e.splice(t,1),r instanceof ln&&null!==r.parentSub&&r.parent._map.get(r.parentSub)===r&&r.parent._map.set(r.parentSub,n))},Fe=(e,t,n)=>{for(const[r,i]of e.clients.entries()){const e=t.clients.get(r);for(let r=i.length-1;r>=0;r--){const o=i[r],a=o.clock+o.len;for(let r=Ie(e,o.clock),i=e[r];r<e.length&&i.id.clock<a;i=e[++r]){const i=e[r];if(o.clock+o.len<=i.id.clock)break;i instanceof ln&&i.deleted&&!i.keep&&n(i)&&i.gc(t,!1)}}}},Ye=(e,t)=>{e.clients.forEach((e,n)=>{const r=t.clients.get(n);for(let t=e.length-1;t>=0;t--){const n=e[t];for(let e=o.h(r.length-1,1+Ie(r,n.clock+n.len-1)),t=r[e];e>0&&t.id.clock>=n.clock;t=r[--e])He(r,e)}})},Ve=(e,t)=>{if(t<e.length){const n=e[t],r=n.doc,i=r.store,a=n.deleteSet,s=n._mergeStructs;try{K(a),n.afterState=Se(n.doc.store),r._transaction=null,r.emit("beforeObserverCalls",[n,r]);const l=[];n.changed.forEach((e,t)=>l.push(()=>{null!==t._item&&t._item.deleted||t._callObserver(n,e)})),l.push(()=>{n.changedParentTypes.forEach((e,t)=>l.push(()=>{null!==t._item&&t._item.deleted||((e=e.filter(e=>null===e.target._item||!e.target._item.deleted)).forEach(e=>{e.currentTarget=t}),e.sort((e,t)=>e.path.length-t.path.length),ue(t._dEH,e,n))})),l.push(()=>r.emit("afterTransaction",[n,r]))}),Object(_.a)(l,[])}finally{r.gc&&Fe(a,i,r.gcFilter),Ye(a,i),n.afterState.forEach((e,t)=>{const r=n.beforeState.get(t)||0;if(r!==e){const e=i.clients.get(t),n=o.g(Ie(e,r),1);for(let t=e.length-1;t>=n;t--)He(e,t)}});for(let e=0;e<s.length;e++){const{client:t,clock:n}=s[e].id,r=i.clients.get(t),o=Ie(r,n);o+1<r.length&&He(r,o+1),o>0&&He(r,o)}if(n.local||n.afterState.get(r.clientID)===n.beforeState.get(r.clientID)||(B(N,L,"[yjs] ",S,k,"Changed the client-id because another client seems to be using it."),r.clientID=$()),r.emit("afterTransactionCleanup",[n,r]),r._observers.has("update")){const e=new ne;Re(e,n)&&r.emit("update",[e.toUint8Array(),n.origin,r,n])}if(r._observers.has("updateV2")){const e=new ie;Re(e,n)&&r.emit("updateV2",[e.toUint8Array(),n.origin,r,n])}const{subdocsAdded:l,subdocsLoaded:c,subdocsRemoved:u}=n;(l.size>0||u.size>0||c.size>0)&&(l.forEach(e=>{e.clientID=r.clientID,null==e.collectionid&&(e.collectionid=r.collectionid),r.subdocs.add(e)}),u.forEach(e=>r.subdocs.delete(e)),r.emit("subdocs",[{loaded:c,added:l,removed:u},r,n]),u.forEach(e=>e.destroy())),e.length<=t+1?(r._transactionCleanups=[],r.emit("afterAllTransactions",[r,e])):Ve(e,t+1)}}},Ue=(e,t,n=null,r=!0)=>{const i=e._transactionCleanups;let o=!1;null===e._transaction&&(o=!0,e._transaction=new ze(e,n,r),i.push(e._transaction),1===i.length&&e.emit("beforeAllTransactions",[e]),e.emit("beforeTransaction",[e._transaction,e]));try{t(e._transaction)}finally{o&&i[0]===e._transaction&&Ve(i,0)}};class We{constructor(e,t){this.insertions=t,this.deletions=e,this.meta=new Map}}const Ge=(e,t,n)=>{let r=null,i=null;const o=e.doc,a=e.scope;if(Ue(o,n=>{for(;t.length>0&&null===r;){const i=o.store,s=t.pop(),l=new Set,c=[];let u=!1;G(n,s.insertions,e=>{if(e instanceof ln){if(null!==e.redone){let{item:t,diff:r}=rn(i,e.id);r>0&&(t=Ne(n,pe(t.id.client,t.id.clock+r))),e=t}!e.deleted&&a.some(t=>me(t,e))&&c.push(e)}}),G(n,s.deletions,e=>{e instanceof ln&&a.some(t=>me(t,e))&&!q(s.insertions,e.id)&&l.add(e)}),l.forEach(e=>{u=null!==sn(n,e,l,s.insertions)||u});for(let t=c.length-1;t>=0;t--){const r=c[t];e.deleteFilter(r)&&(r.delete(n),u=!0)}r=u?s:null}n.changed.forEach((e,t)=>{e.has(null)&&t._searchMarker&&(t._searchMarker.length=0)}),i=n},e),null!=r){const t=i.changedParentTypes;e.emit("stack-item-popped",[{stackItem:r,type:n,changedParentTypes:t},e])}return r};class qe extends r.a{constructor(e,{captureTimeout:t=500,deleteFilter:n=(()=>!0),trackedOrigins:r=new Set([null])}={}){super(),this.scope=e instanceof Array?e:[e],this.deleteFilter=n,r.add(this),this.trackedOrigins=r,this.undoStack=[],this.redoStack=[],this.undoing=!1,this.redoing=!1,this.doc=this.scope[0].doc,this.lastChange=0,this.doc.on("afterTransaction",e=>{if(!(this.scope.some(t=>e.changedParentTypes.has(t))&&(this.trackedOrigins.has(e.origin)||e.origin&&this.trackedOrigins.has(e.origin.constructor))))return;const n=this.undoing,r=this.redoing,i=n?this.redoStack:this.undoStack;n?this.stopCapturing():r||(this.redoStack=[]);const o=new W;e.afterState.forEach((t,n)=>{const r=e.beforeState.get(n)||0,i=t-r;i>0&&J(o,n,r,i)});const a=p.a();let s=!1;if(a-this.lastChange<t&&i.length>0&&!n&&!r){const t=i[i.length-1];t.deletions=X([t.deletions,e.deleteSet]),t.insertions=X([t.insertions,o])}else i.push(new We(e.deleteSet,o)),s=!0;n||r||(this.lastChange=a),G(e,e.deleteSet,e=>{e instanceof ln&&this.scope.some(t=>me(t,e))&&on(e,!0)}),s&&this.emit("stack-item-added",[{stackItem:i[i.length-1],origin:e.origin,type:n?"redo":"undo",changedParentTypes:e.changedParentTypes},this])})}clear(){this.doc.transact(e=>{const t=t=>{G(e,t.deletions,e=>{e instanceof ln&&this.scope.some(t=>me(t,e))&&on(e,!1)})};this.undoStack.forEach(t),this.redoStack.forEach(t)}),this.undoStack=[],this.redoStack=[]}stopCapturing(){this.lastChange=0}undo(){let e;this.undoing=!0;try{e=Ge(this,this.undoStack,"undo")}finally{this.undoing=!1}return e}redo(){let e;this.redoing=!0;try{e=Ge(this,this.redoStack,"redo")}finally{this.redoing=!1}return e}canUndo(){return this.undoStack.length>0}canRedo(){return this.redoStack.length>0}}class Ke{constructor(e,t){this.target=e,this.currentTarget=e,this.transaction=t,this._changes=null,this._keys=null,this._delta=null}get path(){return Xe(this.currentTarget,this.target)}deletes(e){return q(this.transaction.deleteSet,e.id)}get keys(){if(null===this._keys){const e=new Map,t=this.target;this.transaction.changed.get(t).forEach(n=>{if(null!==n){const r=t._map.get(n);let o,a;if(this.adds(r)){let e=r.left;for(;null!==e&&this.adds(e);)e=e.left;if(this.deletes(r)){if(null===e||!this.deletes(e))return;o="delete",a=i.d(e.content.getContent())}else null!==e&&this.deletes(e)?(o="update",a=i.d(e.content.getContent())):(o="add",a=void 0)}else{if(!this.deletes(r))return;o="delete",a=i.d(r.content.getContent())}e.set(n,{action:o,oldValue:a})}}),this._keys=e}return this._keys}get delta(){return this.changes.delta}adds(e){return e.id.clock>=(this.transaction.beforeState.get(e.id.client)||0)}get changes(){let e=this._changes;if(null===e){const t=this.target,n=b.a(),r=b.a(),i=[];e={added:n,deleted:r,delta:i,keys:this.keys};if(this.transaction.changed.get(t).has(null)){let e=null;const o=()=>{e&&i.push(e)};for(let i=t._start;null!==i;i=i.right)i.deleted?this.deletes(i)&&!this.adds(i)&&(null!==e&&void 0!==e.delete||(o(),e={delete:0}),e.delete+=i.length,r.add(i)):this.adds(i)?(null!==e&&void 0!==e.insert||(o(),e={insert:[]}),e.insert=e.insert.concat(i.content.getContent()),n.add(i)):(null!==e&&void 0!==e.retain||(o(),e={retain:0}),e.retain+=i.length);null!==e&&void 0===e.retain&&o()}this._changes=e}return e}}const Xe=(e,t)=>{const n=[];for(;null!==t._item&&t!==e;){if(null!==t._item.parentSub)n.unshift(t._item.parentSub);else{let e=0,r=t._item.parent._start;for(;r!==t._item&&null!==r;)r.deleted||e++,r=r.right;n.unshift(e)}t=t._item.parent}return n};let Je=0;class Qe{constructor(e,t){e.marker=!0,this.p=e,this.index=t,this.timestamp=Je++}}const Ze=(e,t,n)=>{e.p.marker=!1,e.p=t,t.marker=!0,e.index=n,e.timestamp=Je++},$e=(e,t)=>{if(null===e._start||0===t||null===e._searchMarker)return null;const n=0===e._searchMarker.length?null:e._searchMarker.reduce((e,n)=>o.a(t-e.index)<o.a(t-n.index)?e:n);let r=e._start,i=0;for(null!==n&&(r=n.p,i=n.index,(e=>{e.timestamp=Je++})(n));null!==r.right&&i<t;){if(!r.deleted&&r.countable){if(t<i+r.length)break;i+=r.length}r=r.right}for(;null!==r.left&&i>t;)r=r.left,!r.deleted&&r.countable&&(i-=r.length);for(;null!==r.left&&r.left.id.client===r.id.client&&r.left.id.clock+r.left.length===r.id.clock;)r=r.left,!r.deleted&&r.countable&&(i-=r.length);return null!==n&&o.a(n.index-i)<r.parent.length/80?(Ze(n,r,i),n):((e,t,n)=>{if(e.length>=80){const r=e.reduce((e,t)=>e.timestamp<t.timestamp?e:t);return Ze(r,t,n),r}{const r=new Qe(t,n);return e.push(r),r}})(e._searchMarker,r,i)},et=(e,t,n)=>{for(let r=e.length-1;r>=0;r--){const i=e[r];if(n>0){let t=i.p;for(t.marker=!1;t&&(t.deleted||!t.countable);)t=t.left,t&&!t.deleted&&t.countable&&(i.index-=t.length);if(null===t||!0===t.marker){e.splice(r,1);continue}i.p=t,t.marker=!0}(t<i.index||n>0&&t===i.index)&&(i.index=o.g(t,i.index+n))}},tt=(e,t,n)=>{const r=e,i=t.changedParentTypes;for(;a.e(i,e,()=>[]).push(n),null!==e._item;)e=e._item.parent;ue(r._eH,n,t)};class nt{constructor(){this._item=null,this._map=new Map,this._start=null,this.doc=null,this._length=0,this._eH=se(),this._dEH=se(),this._searchMarker=null}get parent(){return this._item?this._item.parent:null}_integrate(e,t){this.doc=e,this._item=t}_copy(){throw g()}clone(){throw g()}_write(e){}get _first(){let e=this._start;for(;null!==e&&e.deleted;)e=e.right;return e}_callObserver(e,t){!e.local&&this._searchMarker&&(this._searchMarker.length=0)}observe(e){le(this._eH,e)}observeDeep(e){le(this._dEH,e)}unobserve(e){ce(this._eH,e)}unobserveDeep(e){ce(this._dEH,e)}toJSON(){}}const rt=(e,t,n)=>{t<0&&(t=e._length+t),n<0&&(n=e._length+n);let r=n-t;const i=[];let o=e._start;for(;null!==o&&r>0;){if(o.countable&&!o.deleted){const e=o.content.getContent();if(e.length<=t)t-=e.length;else{for(let n=t;n<e.length&&r>0;n++)i.push(e[n]),r--;t=0}}o=o.right}return i},it=e=>{const t=[];let n=e._start;for(;null!==n;){if(n.countable&&!n.deleted){const e=n.content.getContent();for(let n=0;n<e.length;n++)t.push(e[n])}n=n.right}return t},ot=(e,t)=>{let n=0,r=e._start;for(;null!==r;){if(r.countable&&!r.deleted){const i=r.content.getContent();for(let r=0;r<i.length;r++)t(i[r],n++,e)}r=r.right}},at=(e,t)=>{const n=[];return ot(e,(r,i)=>{n.push(t(r,i,e))}),n},st=e=>{let t=e._start,n=null,r=0;return{[Symbol.iterator](){return this},next:()=>{if(null===n){for(;null!==t&&t.deleted;)t=t.right;if(null===t)return{done:!0,value:void 0};n=t.content.getContent(),r=0,t=t.right}const e=n[r++];return n.length<=r&&(n=null),{done:!1,value:e}}}},lt=(e,t)=>{const n=$e(e,t);let r=e._start;for(null!==n&&(r=n.p,t-=n.index);null!==r;r=r.right)if(!r.deleted&&r.countable){if(t<r.length)return r.content.getContent()[t];t-=r.length}},ct=(e,t,n,r)=>{let i=n;const o=e.doc,a=o.clientID,s=o.store,l=null===n?t._start:n.right;let c=[];const u=()=>{c.length>0&&(i=new ln(pe(a,Te(s,a)),i,i&&i.lastId,l,l&&l.id,t,null,new Xt(c)),i.integrate(e,0),c=[])};r.forEach(n=>{if(null===n)c.push(n);else switch(n.constructor){case Number:case Object:case Boolean:case Array:case String:c.push(n);break;default:switch(u(),n.constructor){case Uint8Array:case ArrayBuffer:i=new ln(pe(a,Te(s,a)),i,i&&i.lastId,l,l&&l.id,t,null,new Vt(new Uint8Array(n))),i.integrate(e,0);break;case ee:i=new ln(pe(a,Te(s,a)),i,i&&i.lastId,l,l&&l.id,t,null,new Gt(n)),i.integrate(e,0);break;default:if(!(n instanceof nt))throw new Error("Unexpected content type in insert operation");i=new ln(pe(a,Te(s,a)),i,i&&i.lastId,l,l&&l.id,t,null,new nn(n)),i.integrate(e,0)}}}),u()},ut=m("Length exceeded!"),dt=(e,t,n,r)=>{if(n>t._length)throw ut;if(0===n)return t._searchMarker&&et(t._searchMarker,n,r.length),ct(e,t,null,r);const i=n,o=$e(t,n);let a=t._start;for(null!==o&&(a=o.p,0===(n-=o.index)&&(a=a.prev,n+=a&&a.countable&&!a.deleted?a.length:0));null!==a;a=a.right)if(!a.deleted&&a.countable){if(n<=a.length){n<a.length&&Ne(e,pe(a.id.client,a.id.clock+n));break}n-=a.length}return t._searchMarker&&et(t._searchMarker,i,r.length),ct(e,t,a,r)},ht=(e,t,n,r)=>{if(0===r)return;const i=n,o=r,a=$e(t,n);let s=t._start;for(null!==a&&(s=a.p,n-=a.index);null!==s&&n>0;s=s.right)!s.deleted&&s.countable&&(n<s.length&&Ne(e,pe(s.id.client,s.id.clock+n)),n-=s.length);for(;r>0&&null!==s;)s.deleted||(r<s.length&&Ne(e,pe(s.id.client,s.id.clock+r)),s.delete(e),r-=s.length),s=s.right;if(r>0)throw ut;t._searchMarker&&et(t._searchMarker,i,-o+r)},pt=(e,t,n)=>{const r=t._map.get(n);void 0!==r&&r.delete(e)},ft=(e,t,n,r)=>{const i=t._map.get(n)||null,o=e.doc,a=o.clientID;let s;if(null==r)s=new Xt([r]);else switch(r.constructor){case Number:case Object:case Boolean:case Array:case String:s=new Xt([r]);break;case Uint8Array:s=new Vt(r);break;case ee:s=new Gt(r);break;default:if(!(r instanceof nt))throw new Error("Unexpected content type");s=new nn(r)}new ln(pe(a,Te(o.store,a)),i,i&&i.lastId,null,null,t,n,s).integrate(e,0)},mt=(e,t)=>{const n=e._map.get(t);return void 0===n||n.deleted?void 0:n.content.getContent()[n.length-1]},gt=e=>{const t={};return e._map.forEach((e,n)=>{e.deleted||(t[n]=e.content.getContent()[e.length-1])}),t},vt=(e,t)=>{const n=e._map.get(t);return void 0!==n&&!n.deleted},yt=e=>{return t=e.entries(),n=e=>!e[1].deleted,F(()=>{let e;do{e=t.next()}while(!e.done&&!n(e.value));return e});var t,n};class _t extends Ke{constructor(e,t){super(e,t),this._transaction=t}}class bt extends nt{constructor(){super(),this._prelimContent=[],this._searchMarker=[]}static from(e){const t=new bt;return t.push(e),t}_integrate(e,t){super._integrate(e,t),this.insert(0,this._prelimContent),this._prelimContent=null}_copy(){return new bt}clone(){const e=new bt;return e.insert(0,this.toArray().map(e=>e instanceof nt?e.clone():e)),e}get length(){return null===this._prelimContent?this._length:this._prelimContent.length}_callObserver(e,t){super._callObserver(e,t),tt(this,e,new _t(this,e))}insert(e,t){null!==this.doc?Ue(this.doc,n=>{dt(n,this,e,t)}):this._prelimContent.splice(e,0,...t)}push(e){null!==this.doc?Ue(this.doc,t=>{((e,t,n)=>{let r=(t._searchMarker||[]).reduce((e,t)=>t.index>e.index?t:e,{index:0,p:t._start}).p;if(r)for(;r.right;)r=r.right;ct(e,t,r,n)})(t,this,e)}):this._prelimContent.push(...e)}unshift(e){this.insert(0,e)}delete(e,t=1){null!==this.doc?Ue(this.doc,n=>{ht(n,this,e,t)}):this._prelimContent.splice(e,t)}get(e){return lt(this,e)}toArray(){return it(this)}slice(e=0,t=this.length){return rt(this,e,t)}toJSON(){return this.map(e=>e instanceof nt?e.toJSON():e)}map(e){return at(this,e)}forEach(e){ot(this,e)}[Symbol.iterator](){return st(this)}_write(e){e.writeTypeRef(Qt)}}class Mt extends Ke{constructor(e,t,n){super(e,t),this.keysChanged=n}}class wt extends nt{constructor(e){super(),this._prelimContent=null,this._prelimContent=void 0===e?new Map:new Map(e)}_integrate(e,t){super._integrate(e,t),this._prelimContent.forEach((e,t)=>{this.set(t,e)}),this._prelimContent=null}_copy(){return new wt}clone(){const e=new wt;return this.forEach((t,n)=>{e.set(n,t instanceof nt?t.clone():t)}),e}_callObserver(e,t){tt(this,e,new Mt(this,e,t))}toJSON(){const e={};return this._map.forEach((t,n)=>{if(!t.deleted){const r=t.content.getContent()[t.length-1];e[n]=r instanceof nt?r.toJSON():r}}),e}get size(){return[...yt(this._map)].length}keys(){return Y(yt(this._map),e=>e[0])}values(){return Y(yt(this._map),e=>e[1].content.getContent()[e[1].length-1])}entries(){return Y(yt(this._map),e=>[e[0],e[1].content.getContent()[e[1].length-1]])}forEach(e){return this._map.forEach((t,n)=>{t.deleted||e(t.content.getContent()[t.length-1],n,this)}),{}}[Symbol.iterator](){return this.entries()}delete(e){null!==this.doc?Ue(this.doc,t=>{pt(t,this,e)}):this._prelimContent.delete(e)}set(e,t){return null!==this.doc?Ue(this.doc,n=>{ft(n,this,e,t)}):this._prelimContent.set(e,t),t}get(e){return mt(this,e)}has(e){return vt(this,e)}clear(){null!==this.doc?Ue(this.doc,e=>{this.forEach((function(t,n,r){pt(e,r,n)}))}):this._prelimContent.clear()}_write(e){e.writeTypeRef(Zt)}}const At=(e,t)=>e===t||"object"==typeof e&&"object"==typeof t&&e&&t&&V.a(e,t);class Ct{constructor(e,t,n,r){this.left=e,this.right=t,this.index=n,this.currentAttributes=r}forward(){switch(null===this.right&&v(),this.right.content.constructor){case Kt:this.right.deleted||St(this.currentAttributes,this.right.content);break;default:this.right.deleted||(this.index+=this.right.length)}this.left=this.right,this.right=this.right.right}}const xt=(e,t,n)=>{for(;null!==t.right&&n>0;){switch(t.right.content.constructor){case Kt:t.right.deleted||St(t.currentAttributes,t.right.content);break;default:t.right.deleted||(n<t.right.length&&Ne(e,pe(t.right.id.client,t.right.id.clock+n)),t.index+=t.right.length,n-=t.right.length)}t.left=t.right,t.right=t.right.right}return t},Et=(e,t,n)=>{const r=new Map,i=$e(t,n);if(i){const t=new Ct(i.p.left,i.p,i.index,r);return xt(e,t,n-i.index)}{const i=new Ct(null,t._start,0,r);return xt(e,i,n)}},Lt=(e,t,n,r)=>{for(;null!==n.right&&(!0===n.right.deleted||n.right.content.constructor===Kt&&At(r.get(n.right.content.key),n.right.content.value));)n.right.deleted||r.delete(n.right.content.key),n.forward();const i=e.doc,o=i.clientID;r.forEach((r,a)=>{const s=n.left,l=n.right,c=new ln(pe(o,Te(i.store,o)),s,s&&s.lastId,l,l&&l.id,t,null,new Kt(a,r));c.integrate(e,0),n.right=c,n.forward()})},St=(e,t)=>{const{key:n,value:r}=t;null===r?e.delete(n):e.set(n,r)},Tt=(e,t)=>{for(;null!==e.right&&(e.right.deleted||e.right.content.constructor===Kt&&At(t[e.right.content.key]||null,e.right.content.value));)e.forward()},Ot=(e,t,n,r)=>{const i=e.doc,o=i.clientID,a=new Map;for(const s in r){const l=r[s],c=n.currentAttributes.get(s)||null;if(!At(c,l)){a.set(s,c);const{left:r,right:u}=n;n.right=new ln(pe(o,Te(i.store,o)),r,r&&r.lastId,u,u&&u.id,t,null,new Kt(s,l)),n.right.integrate(e,0),n.forward()}}return a},It=(e,t,n,r,i)=>{n.currentAttributes.forEach((e,t)=>{void 0===i[t]&&(i[t]=null)});const o=e.doc,a=o.clientID;Tt(n,i);const s=Ot(e,t,n,i),l=r.constructor===String?new Jt(r):r instanceof nt?new nn(r):new qt(r);let{left:c,right:u,index:d}=n;t._searchMarker&&et(t._searchMarker,n.index,l.getLength()),u=new ln(pe(a,Te(o.store,a)),c,c&&c.lastId,u,u&&u.id,t,null,l),u.integrate(e,0),n.right=u,n.index=d,n.forward(),Lt(e,t,n,s)},kt=(e,t,n,r,i)=>{const o=e.doc,a=o.clientID;Tt(n,i);const s=Ot(e,t,n,i);for(;r>0&&null!==n.right;){if(!n.right.deleted)switch(n.right.content.constructor){case Kt:{const{key:t,value:r}=n.right.content,o=i[t];void 0!==o&&(At(o,r)?s.delete(t):s.set(t,r),n.right.delete(e));break}default:r<n.right.length&&Ne(e,pe(n.right.id.client,n.right.id.clock+r)),r-=n.right.length}n.forward()}if(r>0){let i="";for(;r>0;r--)i+="\n";n.right=new ln(pe(a,Te(o.store,a)),n.left,n.left&&n.left.lastId,n.right,n.right&&n.right.id,t,null,new Jt(i)),n.right.integrate(e,0),n.forward()}Lt(e,t,n,s)},Dt=(e,t,n,r,i)=>{let o=n;const s=a.b(i);for(;o&&(!o.countable||o.deleted);)o.deleted||o.content.constructor!==Kt||St(s,o.content),o=o.right;let l=0,c=!1;for(;t!==o;){if(n===t&&(c=!0),!t.deleted){const n=t.content;switch(n.constructor){case Kt:{const{key:o,value:a}=n;(s.get(o)||null)===a&&(r.get(o)||null)!==a||(t.delete(e),l++,c||(i.get(o)||null)!==a||(r.get(o)||null)===a||i.delete(o));break}}}t=t.right}return l},Nt=(e,t,n)=>{const r=n,i=a.b(t.currentAttributes),o=t.right;for(;n>0&&null!==t.right;){if(!1===t.right.deleted)switch(t.right.content.constructor){case nn:case qt:case Jt:n<t.right.length&&Ne(e,pe(t.right.id.client,t.right.id.clock+n)),n-=t.right.length,t.right.delete(e)}t.forward()}o&&Dt(e,o,t.right,i,t.currentAttributes);const s=(t.left||t.right).parent;return s._searchMarker&&et(s._searchMarker,t.index,-r+n),t};class jt extends Ke{constructor(e,t,n){super(e,t),this.childListChanged=!1,this.keysChanged=new Set,n.forEach(e=>{null===e?this.childListChanged=!0:this.keysChanged.add(e)})}get changes(){if(null===this._changes){const e={keys:this.keys,delta:this.delta,added:new Set,deleted:new Set};this._changes=e}return this._changes}get delta(){if(null===this._delta){const e=this.target.doc,t=[];Ue(e,e=>{const n=new Map,r=new Map;let i=this.target._start,o=null;const a={};let s="",l=0,c=0;const u=()=>{if(null!==o){let e;switch(o){case"delete":e={delete:c},c=0;break;case"insert":e={insert:s},n.size>0&&(e.attributes={},n.forEach((t,n)=>{null!==t&&(e.attributes[n]=t)})),s="";break;case"retain":if(e={retain:l},Object.keys(a).length>0){e.attributes={};for(const t in a)e.attributes[t]=a[t]}l=0}t.push(e),o=null}};for(;null!==i;){switch(i.content.constructor){case nn:case qt:this.adds(i)?this.deletes(i)||(u(),o="insert",s=i.content.getContent()[0],u()):this.deletes(i)?("delete"!==o&&(u(),o="delete"),c+=1):i.deleted||("retain"!==o&&(u(),o="retain"),l+=1);break;case Jt:this.adds(i)?this.deletes(i)||("insert"!==o&&(u(),o="insert"),s+=i.content.str):this.deletes(i)?("delete"!==o&&(u(),o="delete"),c+=i.length):i.deleted||("retain"!==o&&(u(),o="retain"),l+=i.length);break;case Kt:{const{key:t,value:s}=i.content;if(this.adds(i)){if(!this.deletes(i)){const l=n.get(t)||null;At(l,s)?null!==s&&i.delete(e):("retain"===o&&u(),At(s,r.get(t)||null)?delete a[t]:a[t]=s)}}else if(this.deletes(i)){r.set(t,s);const e=n.get(t)||null;At(e,s)||("retain"===o&&u(),a[t]=e)}else if(!i.deleted){r.set(t,s);const n=a[t];void 0!==n&&(At(n,s)?null!==n&&i.delete(e):("retain"===o&&u(),null===s?delete a[t]:a[t]=s))}i.deleted||("insert"===o&&u(),St(n,i.content));break}}i=i.right}for(u();t.length>0;){const e=t[t.length-1];if(void 0===e.retain||void 0!==e.attributes)break;t.pop()}}),this._delta=t}return this._delta}}class Pt extends nt{constructor(e){super(),this._pending=void 0!==e?[()=>this.insert(0,e)]:[],this._searchMarker=[]}get length(){return this._length}_integrate(e,t){super._integrate(e,t);try{this._pending.forEach(e=>e())}catch(e){console.error(e)}this._pending=null}_copy(){return new Pt}clone(){const e=new Pt;return e.applyDelta(this.toDelta()),e}_callObserver(e,t){super._callObserver(e,t);const n=new jt(this,e,t),r=e.doc;if(tt(this,e,n),!e.local){let t=!1;for(const[n,i]of e.afterState.entries()){const o=e.beforeState.get(n)||0;if(i!==o&&(Pe(e,r.store.clients.get(n),o,i,e=>{e.deleted||e.content.constructor!==Kt||(t=!0)}),t))break}t||G(e,e.deleteSet,e=>{e instanceof Yt||t||e.parent===this&&e.content.constructor===Kt&&(t=!0)}),Ue(r,e=>{t?(e=>{let t=0;Ue(e.doc,n=>{let r=e._start,i=e._start,o=a.c();const s=a.b(o);for(;i;){if(!1===i.deleted)switch(i.content.constructor){case Kt:St(s,i.content);break;default:t+=Dt(n,r,i,o,s),o=a.b(s),r=i}i=i.right}})})(this):G(e,e.deleteSet,t=>{t instanceof Yt||t.parent===this&&((e,t)=>{for(;t&&t.right&&(t.right.deleted||!t.right.countable);)t=t.right;const n=new Set;for(;t&&(t.deleted||!t.countable);){if(!t.deleted&&t.content.constructor===Kt){const r=t.content.key;n.has(r)?t.delete(e):n.add(r)}t=t.left}})(e,t)})})}}toString(){let e="",t=this._start;for(;null!==t;)!t.deleted&&t.countable&&t.content.constructor===Jt&&(e+=t.content.str),t=t.right;return e}toJSON(){return this.toString()}applyDelta(e,{sanitize:t=!0}={}){null!==this.doc?Ue(this.doc,n=>{const r=new Ct(null,this._start,0,new Map);for(let i=0;i<e.length;i++){const o=e[i];if(void 0!==o.insert){const a=t||"string"!=typeof o.insert||i!==e.length-1||null!==r.right||"\n"!==o.insert.slice(-1)?o.insert:o.insert.slice(0,-1);("string"!=typeof a||a.length>0)&&It(n,this,r,a,o.attributes||{})}else void 0!==o.retain?kt(n,this,r,o.retain,o.attributes||{}):void 0!==o.delete&&Nt(n,r,o.delete)}}):this._pending.push(()=>this.applyDelta(e))}toDelta(e,t,n){const r=[],i=new Map,o=this.doc;let a="",s=this._start;function l(){if(a.length>0){const e={};let t=!1;i.forEach((n,r)=>{t=!0,e[r]=n});const n={insert:a};t&&(n.attributes=e),r.push(n),a=""}}return Ue(o,o=>{for(e&&Ee(o,e),t&&Ee(o,t);null!==s;){if(xe(s,e)||void 0!==t&&xe(s,t))switch(s.content.constructor){case Jt:{const r=i.get("ychange");void 0===e||xe(s,e)?void 0===t||xe(s,t)?void 0!==r&&(l(),i.delete("ychange")):void 0!==r&&r.user===s.id.client&&"added"===r.state||(l(),i.set("ychange",n?n("added",s.id):{type:"added"})):void 0!==r&&r.user===s.id.client&&"removed"===r.state||(l(),i.set("ychange",n?n("removed",s.id):{type:"removed"})),a+=s.content.str;break}case nn:case qt:{l();const e={insert:s.content.getContent()[0]};if(i.size>0){const t={};e.attributes=t,i.forEach((e,n)=>{t[n]=e})}r.push(e);break}case Kt:xe(s,e)&&(l(),St(i,s.content))}s=s.right}l()},Ee),r}insert(e,t,n){if(t.length<=0)return;const r=this.doc;null!==r?Ue(r,r=>{const i=Et(r,this,e);n||(n={},i.currentAttributes.forEach((e,t)=>{n[t]=e})),It(r,this,i,t,n)}):this._pending.push(()=>this.insert(e,t,n))}insertEmbed(e,t,n={}){const r=this.doc;null!==r?Ue(r,r=>{const i=Et(r,this,e);It(r,this,i,t,n)}):this._pending.push(()=>this.insertEmbed(e,t,n))}delete(e,t){if(0===t)return;const n=this.doc;null!==n?Ue(n,n=>{Nt(n,Et(n,this,e),t)}):this._pending.push(()=>this.delete(e,t))}format(e,t,n){if(0===t)return;const r=this.doc;null!==r?Ue(r,r=>{const i=Et(r,this,e);null!==i.right&&kt(r,this,i,t,n)}):this._pending.push(()=>this.format(e,t,n))}removeAttribute(e){null!==this.doc?Ue(this.doc,t=>{pt(t,this,e)}):this._pending.push(()=>this.removeAttribute(e))}setAttribute(e,t){null!==this.doc?Ue(this.doc,n=>{ft(n,this,e,t)}):this._pending.push(()=>this.setAttribute(e,t))}getAttribute(e){return mt(this,e)}getAttributes(e){return gt(this)}_write(e){e.writeTypeRef($t)}}class zt{constructor(e,t=(()=>!0)){this._filter=t,this._root=e,this._currentNode=e._start,this._firstCall=!0}[Symbol.iterator](){return this}next(){let e=this._currentNode,t=e&&e.content&&e.content.type;if(null!==e&&(!this._firstCall||e.deleted||!this._filter(t)))do{if(t=e.content.type,e.deleted||t.constructor!==Bt&&t.constructor!==Rt||null===t._start)for(;null!==e;){if(null!==e.right){e=e.right;break}e=e.parent===this._root?null:e.parent._item}else e=t._start}while(null!==e&&(e.deleted||!this._filter(e.content.type)));return this._firstCall=!1,null===e?{value:void 0,done:!0}:(this._currentNode=e,{value:e.content.type,done:!1})}}class Rt extends nt{constructor(){super(),this._prelimContent=[]}get firstChild(){const e=this._first;return e?e.content.getContent()[0]:null}_integrate(e,t){super._integrate(e,t),this.insert(0,this._prelimContent),this._prelimContent=null}_copy(){return new Rt}clone(){const e=new Rt;return e.insert(0,this.toArray().map(e=>e instanceof nt?e.clone():e)),e}get length(){return null===this._prelimContent?this._length:this._prelimContent.length}createTreeWalker(e){return new zt(this,e)}querySelector(e){e=e.toUpperCase();const t=new zt(this,t=>t.nodeName&&t.nodeName.toUpperCase()===e).next();return t.done?null:t.value}querySelectorAll(e){return e=e.toUpperCase(),Array.from(new zt(this,t=>t.nodeName&&t.nodeName.toUpperCase()===e))}_callObserver(e,t){tt(this,e,new Ht(this,t,e))}toString(){return at(this,e=>e.toString()).join("")}toJSON(){return this.toString()}toDOM(e=document,t={},n){const r=e.createDocumentFragment();return void 0!==n&&n._createAssociation(r,this),ot(this,i=>{r.insertBefore(i.toDOM(e,t,n),null)}),r}insert(e,t){null!==this.doc?Ue(this.doc,n=>{dt(n,this,e,t)}):this._prelimContent.splice(e,0,...t)}insertAfter(e,t){if(null!==this.doc)Ue(this.doc,n=>{const r=e&&e instanceof nt?e._item:e;ct(n,this,r,t)});else{const n=this._prelimContent,r=null===e?0:n.findIndex(t=>t===e)+1;if(0===r&&null!==e)throw m("Reference item not found");n.splice(r,0,...t)}}delete(e,t=1){null!==this.doc?Ue(this.doc,n=>{ht(n,this,e,t)}):this._prelimContent.splice(e,t)}toArray(){return it(this)}push(e){this.insert(this.length,e)}unshift(e){this.insert(0,e)}get(e){return lt(this,e)}slice(e=0,t=this.length){return rt(this,e,t)}_write(e){e.writeTypeRef(tn)}}class Bt extends Rt{constructor(e="UNDEFINED"){super(),this.nodeName=e,this._prelimAttrs=new Map}get nextSibling(){const e=this._item?this._item.next:null;return e?e.content.type:null}get prevSibling(){const e=this._item?this._item.prev:null;return e?e.content.type:null}_integrate(e,t){super._integrate(e,t),this._prelimAttrs.forEach((e,t)=>{this.setAttribute(t,e)}),this._prelimAttrs=null}_copy(){return new Bt(this.nodeName)}clone(){const e=new Bt(this.nodeName),t=this.getAttributes();for(const n in t)e.setAttribute(n,t[n]);return e.insert(0,this.toArray().map(e=>e instanceof nt?e.clone():e)),e}toString(){const e=this.getAttributes(),t=[],n=[];for(const t in e)n.push(t);n.sort();const r=n.length;for(let i=0;i<r;i++){const r=n[i];t.push(r+'="'+e[r]+'"')}const i=this.nodeName.toLocaleLowerCase();return`<${i}${t.length>0?" "+t.join(" "):""}>${super.toString()}</${i}>`}removeAttribute(e){null!==this.doc?Ue(this.doc,t=>{pt(t,this,e)}):this._prelimAttrs.delete(e)}setAttribute(e,t){null!==this.doc?Ue(this.doc,n=>{ft(n,this,e,t)}):this._prelimAttrs.set(e,t)}getAttribute(e){return mt(this,e)}hasAttribute(e){return vt(this,e)}getAttributes(e){return gt(this)}toDOM(e=document,t={},n){const r=e.createElement(this.nodeName),i=this.getAttributes();for(const e in i)r.setAttribute(e,i[e]);return ot(this,i=>{r.appendChild(i.toDOM(e,t,n))}),void 0!==n&&n._createAssociation(r,this),r}_write(e){e.writeTypeRef(en),e.writeKey(this.nodeName)}}class Ht extends Ke{constructor(e,t,n){super(e,n),this.childListChanged=!1,this.attributesChanged=new Set,t.forEach(e=>{null===e?this.childListChanged=!0:this.attributesChanged.add(e)})}}class Ft{constructor(e,t){this.id=e,this.length=t}get deleted(){throw g()}mergeWith(e){return!1}write(e,t,n){throw g()}integrate(e,t){throw g()}}class Yt extends Ft{get deleted(){return!0}delete(){}mergeWith(e){return this.constructor===e.constructor&&(this.length+=e.length,!0)}integrate(e,t){t>0&&(this.id.clock+=t,this.length-=t),Oe(e.doc.store,this)}write(e,t){e.writeInfo(0),e.writeLen(this.length-t)}getMissing(e,t){return null}}class Vt{constructor(e){this.content=e}getLength(){return 1}getContent(){return[this.content]}isCountable(){return!0}copy(){return new Vt(this.content)}splice(e){throw g()}mergeWith(e){return!1}integrate(e,t){}delete(e){}gc(e){}write(e,t){e.writeBuf(this.content)}getRef(){return 3}}class Ut{constructor(e){this.len=e}getLength(){return this.len}getContent(){return[]}isCountable(){return!1}copy(){return new Ut(this.len)}splice(e){const t=new Ut(this.len-e);return this.len=e,t}mergeWith(e){return this.len+=e.len,!0}integrate(e,t){J(e.deleteSet,t.id.client,t.id.clock,this.len),t.markDeleted()}delete(e){}gc(e){}write(e,t){e.writeLen(this.len-t)}getRef(){return 1}}const Wt=(e,t)=>new ee({guid:e,...t,shouldLoad:t.shouldLoad||t.autoLoad||!1});class Gt{constructor(e){e._item&&console.error("This document was already integrated as a sub-document. You should create a second instance instead with the same guid."),this.doc=e;const t={};this.opts=t,e.gc||(t.gc=!1),e.autoLoad&&(t.autoLoad=!0),null!==e.meta&&(t.meta=e.meta)}getLength(){return 1}getContent(){return[this.doc]}isCountable(){return!0}copy(){return new Gt(Wt(this.doc.guid,this.opts))}splice(e){throw g()}mergeWith(e){return!1}integrate(e,t){this.doc._item=t,e.subdocsAdded.add(this.doc),this.doc.shouldLoad&&e.subdocsLoaded.add(this.doc)}delete(e){e.subdocsAdded.has(this.doc)?e.subdocsAdded.delete(this.doc):e.subdocsRemoved.add(this.doc)}gc(e){}write(e,t){e.writeString(this.doc.guid),e.writeAny(this.opts)}getRef(){return 9}}class qt{constructor(e){this.embed=e}getLength(){return 1}getContent(){return[this.embed]}isCountable(){return!0}copy(){return new qt(this.embed)}splice(e){throw g()}mergeWith(e){return!1}integrate(e,t){}delete(e){}gc(e){}write(e,t){e.writeJSON(this.embed)}getRef(){return 5}}class Kt{constructor(e,t){this.key=e,this.value=t}getLength(){return 1}getContent(){return[]}isCountable(){return!1}copy(){return new Kt(this.key,this.value)}splice(e){throw g()}mergeWith(e){return!1}integrate(e,t){t.parent._searchMarker=null}delete(e){}gc(e){}write(e,t){e.writeKey(this.key),e.writeJSON(this.value)}getRef(){return 6}}class Xt{constructor(e){this.arr=e}getLength(){return this.arr.length}getContent(){return this.arr}isCountable(){return!0}copy(){return new Xt(this.arr)}splice(e){const t=new Xt(this.arr.slice(e));return this.arr=this.arr.slice(0,e),t}mergeWith(e){return this.arr=this.arr.concat(e.arr),!0}integrate(e,t){}delete(e){}gc(e){}write(e,t){const n=this.arr.length;e.writeLen(n-t);for(let r=t;r<n;r++){const t=this.arr[r];e.writeAny(t)}}getRef(){return 8}}class Jt{constructor(e){this.str=e}getLength(){return this.str.length}getContent(){return this.str.split("")}isCountable(){return!0}copy(){return new Jt(this.str)}splice(e){const t=new Jt(this.str.slice(e));this.str=this.str.slice(0,e);const n=this.str.charCodeAt(e-1);return n>=55296&&n<=56319&&(this.str=this.str.slice(0,e-1)+"�",t.str="�"+t.str.slice(1)),t}mergeWith(e){return this.str+=e.str,!0}integrate(e,t){}delete(e){}gc(e){}write(e,t){e.writeString(0===t?this.str:this.str.slice(t))}getRef(){return 4}}const Qt=0,Zt=1,$t=2,en=3,tn=4;class nn{constructor(e){this.type=e}getLength(){return 1}getContent(){return[this.type]}isCountable(){return!0}copy(){return new nn(this.type._copy())}splice(e){throw g()}mergeWith(e){return!1}integrate(e,t){this.type._integrate(e.doc,t)}delete(e){let t=this.type._start;for(;null!==t;)t.deleted?e._mergeStructs.push(t):t.delete(e),t=t.right;this.type._map.forEach(t=>{t.deleted?e._mergeStructs.push(t):t.delete(e)}),e.changed.delete(this.type)}gc(e){let t=this.type._start;for(;null!==t;)t.gc(e,!0),t=t.right;this.type._start=null,this.type._map.forEach(t=>{for(;null!==t;)t.gc(e,!0),t=t.left}),this.type._map=new Map}write(e,t){this.type._write(e)}getRef(){return 7}}const rn=(e,t)=>{let n,r=t,i=0;do{i>0&&(r=pe(r.client,r.clock+i)),n=ke(e,r),i=r.clock-n.id.clock,r=n.redone}while(null!==r&&n instanceof ln);return{item:n,diff:i}},on=(e,t)=>{for(;null!==e&&e.keep!==t;)e.keep=t,e=e.parent._item},an=(e,t,n)=>{const{client:r,clock:i}=t.id,o=new ln(pe(r,i+n),t,pe(r,i+n-1),t.right,t.rightOrigin,t.parent,t.parentSub,t.content.splice(n));return t.deleted&&o.markDeleted(),t.keep&&(o.keep=!0),null!==t.redone&&(o.redone=pe(t.redone.client,t.redone.clock+n)),t.right=o,null!==o.right&&(o.right.left=o),e._mergeStructs.push(o),null!==o.parentSub&&null===o.right&&o.parent._map.set(o.parentSub,o),t.length=n,o},sn=(e,t,n,r)=>{const i=e.doc,o=i.store,a=i.clientID,s=t.redone;if(null!==s)return Ne(e,s);let l,c=t.parent._item,u=null;if(null!==c&&!0===c.deleted){if(null===c.redone&&(!n.has(c)||null===sn(e,c,n,r)))return null;for(;null!==c.redone;)c=Ne(e,c.redone)}const d=null===c?t.parent:c.content.type;if(null===t.parentSub){for(u=t.left,l=t;null!==u;){let t=u;for(;null!==t&&t.parent._item!==c;)t=null===t.redone?null:Ne(e,t.redone);if(null!==t&&t.parent._item===c){u=t;break}u=u.left}for(;null!==l;){let t=l;for(;null!==t&&t.parent._item!==c;)t=null===t.redone?null:Ne(e,t.redone);if(null!==t&&t.parent._item===c){l=t;break}l=l.right}}else if(l=null,t.right){for(u=t;null!==u&&null!==u.right&&q(r,u.right.id);)u=u.right;for(;null!==u&&null!==u.redone;)u=Ne(e,u.redone);if(null===u||u.parent._item!==c)return null;if(u&&null!==u.right)return null}else u=d._map.get(t.parentSub)||null;const h=Te(o,a),p=pe(a,h),f=new ln(p,u,u&&u.lastId,l,l&&l.id,d,t.parentSub,t.content.copy());return t.redone=p,on(f,!0),f.integrate(e,0),f};class ln extends Ft{constructor(e,t,n,r,i,o,a,s){super(e,s.getLength()),this.origin=n,this.left=t,this.right=r,this.rightOrigin=i,this.parent=o,this.parentSub=a,this.redone=null,this.content=s,this.info=this.content.isCountable()?y.b:0}set marker(e){(this.info&y.d)>0!==e&&(this.info^=y.d)}get marker(){return(this.info&y.d)>0}get keep(){return(this.info&y.a)>0}set keep(e){this.keep!==e&&(this.info^=y.a)}get countable(){return(this.info&y.b)>0}get deleted(){return(this.info&y.c)>0}set deleted(e){this.deleted!==e&&(this.info^=y.c)}markDeleted(){this.info|=y.c}getMissing(e,t){if(this.origin&&this.origin.client!==this.id.client&&this.origin.clock>=Te(t,this.origin.client))return this.origin.client;if(this.rightOrigin&&this.rightOrigin.client!==this.id.client&&this.rightOrigin.clock>=Te(t,this.rightOrigin.client))return this.rightOrigin.client;if(this.parent&&this.parent.constructor===de&&this.id.client!==this.parent.client&&this.parent.clock>=Te(t,this.parent.client))return this.parent.client;if(this.origin&&(this.left=je(e,t,this.origin),this.origin=this.left.lastId),this.rightOrigin&&(this.right=Ne(e,this.rightOrigin),this.rightOrigin=this.right.id),(this.left&&this.left.constructor===Yt||this.right&&this.right.constructor===Yt)&&(this.parent=null),this.parent){if(this.parent.constructor===de){const e=ke(t,this.parent);e.constructor===Yt?this.parent=null:this.parent=e.content.type}}else this.left&&this.left.constructor===ln&&(this.parent=this.left.parent,this.parentSub=this.left.parentSub),this.right&&this.right.constructor===ln&&(this.parent=this.right.parent,this.parentSub=this.right.parentSub);return null}integrate(e,t){if(t>0&&(this.id.clock+=t,this.left=je(e,e.doc.store,pe(this.id.client,this.id.clock-1)),this.origin=this.left.lastId,this.content=this.content.splice(t),this.length-=t),this.parent){if(!this.left&&(!this.right||null!==this.right.left)||this.left&&this.left.right!==this.right){let t,n=this.left;if(null!==n)t=n.right;else if(null!==this.parentSub)for(t=this.parent._map.get(this.parentSub)||null;null!==t&&null!==t.left;)t=t.left;else t=this.parent._start;const r=new Set,i=new Set;for(;null!==t&&t!==this.right;){if(i.add(t),r.add(t),he(this.origin,t.origin)){if(t.id.client<this.id.client)n=t,r.clear();else if(he(this.rightOrigin,t.rightOrigin))break}else{if(null===t.origin||!i.has(ke(e.doc.store,t.origin)))break;r.has(ke(e.doc.store,t.origin))||(n=t,r.clear())}t=t.right}this.left=n}if(null!==this.left){const e=this.left.right;this.right=e,this.left.right=this}else{let e;if(null!==this.parentSub)for(e=this.parent._map.get(this.parentSub)||null;null!==e&&null!==e.left;)e=e.left;else e=this.parent._start,this.parent._start=this;this.right=e}null!==this.right?this.right.left=this:null!==this.parentSub&&(this.parent._map.set(this.parentSub,this),null!==this.left&&this.left.delete(e)),null===this.parentSub&&this.countable&&!this.deleted&&(this.parent._length+=this.length),Oe(e.doc.store,this),this.content.integrate(e,this),Be(e,this.parent,this.parentSub),(null!==this.parent._item&&this.parent._item.deleted||null!==this.parentSub&&null!==this.right)&&this.delete(e)}else new Yt(this.id,this.length).integrate(e,0)}get next(){let e=this.right;for(;null!==e&&e.deleted;)e=e.right;return e}get prev(){let e=this.left;for(;null!==e&&e.deleted;)e=e.left;return e}get lastId(){return 1===this.length?this.id:pe(this.id.client,this.id.clock+this.length-1)}mergeWith(e){if(this.constructor===e.constructor&&he(e.origin,this.lastId)&&this.right===e&&he(this.rightOrigin,e.rightOrigin)&&this.id.client===e.id.client&&this.id.clock+this.length===e.id.clock&&this.deleted===e.deleted&&null===this.redone&&null===e.redone&&this.content.constructor===e.content.constructor&&this.content.mergeWith(e.content)){const t=this.parent._searchMarker;return t&&t.forEach(t=>{t.p===e&&(t.p=this,!this.deleted&&this.countable&&(t.index-=this.length))}),e.keep&&(this.keep=!0),this.right=e.right,null!==this.right&&(this.right.left=this),this.length+=e.length,!0}return!1}delete(e){if(!this.deleted){const t=this.parent;this.countable&&null===this.parentSub&&(t._length-=this.length),this.markDeleted(),J(e.deleteSet,this.id.client,this.id.clock,this.length),Be(e,t,this.parentSub),this.content.delete(e)}}gc(e,t){if(!this.deleted)throw v();this.content.gc(e),t?((e,t,n)=>{const r=e.clients.get(t.id.client);r[Ie(r,t.id.clock)]=n})(e,this,new Yt(this.id,this.length)):this.content=new Ut(this.length)}write(e,t){const n=t>0?pe(this.id.client,this.id.clock+t-1):this.origin,r=this.rightOrigin,i=this.parentSub,o=this.content.getRef()&y.i|(null===n?0:y.g)|(null===r?0:y.f)|(null===i?0:y.e);if(e.writeInfo(o),null!==n&&e.writeLeftID(n),null!==r&&e.writeRightID(r),null===n&&null===r){const t=this.parent;if(void 0!==t._item){const n=t._item;if(null===n){const n=fe(t);e.writeParentInfo(!0),e.writeString(n)}else e.writeParentInfo(!1),e.writeLeftID(n.id)}else t.constructor===String?(e.writeParentInfo(!0),e.writeString(t)):t.constructor===de?(e.writeParentInfo(!1),e.writeLeftID(t)):v();null!==i&&e.writeString(i)}this.content.write(e,t)}}const cn="undefined"!=typeof window?window:"undefined"!=typeof global?global:{};!0===cn["__ $YJS$ __"]&&console.warn("Yjs was already imported. Importing different versions of Yjs often leads to issues."),cn["__ $YJS$ __"]=!0},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0});var o,a=n(23),s=n(39),l=n(49),c=n(31),u=n(135);!function(e){var t={em:function(e){return e},ex:function(e){return.43*e},pt:function(e){return e/10},pc:function(e){return 1.2*e},px:function(e){return 7.2*e/72},in:function(e){return 7.2*e},cm:function(e){return 7.2*e/2.54},mm:function(e){return 7.2*e/25.4},mu:function(e){return e/18}},n="([-+]?([.,]\\d+|\\d+([.,]\\d*)?))",o="(pt|em|ex|mu|px|mm|cm|in|pc)",d=RegExp("^\\s*"+n+"\\s*"+o+"\\s*$"),h=RegExp("^\\s*"+n+"\\s*"+o+" ?");function p(e,n){void 0===n&&(n=!1);var i=e.match(n?h:d);return i?function(e){var n=r(e,3),i=n[0],o=n[1],a=n[2];if("mu"!==o)return[i,o,a];return[f(t[o](parseFloat(i||"1"))).slice(0,-2),"em",a]}([i[1].replace(/,/,"."),i[4],i[0].length]):[null,null,0]}function f(e){return Math.abs(e)<6e-4?"0em":e.toFixed(3).replace(/\.?0+$/,"")+"em"}function m(e,t,n){"{"!==t&&"}"!==t||(t="\\"+t);var r="{\\bigg"+n+" "+t+"}",i="{\\big"+n+" "+t+"}";return new l.default("\\mathchoice"+r+i+i+i,{},e).mml()}function g(e,t,n){t=t.replace(/^\s+/,u.entities.nbsp).replace(/\s+$/,u.entities.nbsp);var r=e.create("text",t);return e.create("node","mtext",[],n,r)}function v(e,t,n){if(n.match(/^[a-z]/i)&&t.match(/(^|[^\\])(\\\\)*\\[a-z]+$/i)&&(t+=" "),t.length+n.length>e.configuration.options.maxBuffer)throw new c.default("MaxBufferSize","MathJax internal buffer size exceeded; is there a recursive macro call?");return t+n}function y(e,t){for(;t>0;)e=e.trim().slice(1,-1),t--;return e.trim()}function _(e,t){for(var n=e.length,r=0,i="",o=0,a=0,s=!0,l=!1;o<n;){var u=e[o++];switch(u){case" ":break;case"{":s?a++:(l=!1,a>r&&(a=r)),r++;break;case"}":r&&r--,(s||l)&&(a--,l=!0),s=!1;break;default:if(!r&&-1!==t.indexOf(u))return[l?"true":y(i,a),u,e.slice(o)];s=!1,l=!1}i+=u}if(r)throw new c.default("ExtraOpenMissingClose","Extra open brace or missing close brace");return[l?"true":y(i,a),"",e.slice(o)]}e.matchDimen=p,e.dimen2em=function(e){var n=r(p(e),2),i=n[0],o=n[1],a=parseFloat(i||"1"),s=t[o];return s?s(a):0},e.Em=f,e.cols=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return e.map((function(e){return f(e)})).join(" ")},e.fenced=function(e,t,n,r,i,o){void 0===i&&(i=""),void 0===o&&(o="");var c,u=e.nodeFactory,d=u.create("node","mrow",[],{open:t,close:r,texClass:a.TEXCLASS.INNER});if(i)c=new l.default("\\"+i+"l"+t,e.parser.stack.env,e).mml();else{var h=u.create("text",t);c=u.create("node","mo",[],{fence:!0,stretchy:!0,symmetric:!0,texClass:a.TEXCLASS.OPEN},h)}if(s.default.appendChildren(d,[c,n]),i)c=new l.default("\\"+i+"r"+r,e.parser.stack.env,e).mml();else{var p=u.create("text",r);c=u.create("node","mo",[],{fence:!0,stretchy:!0,symmetric:!0,texClass:a.TEXCLASS.CLOSE},p)}return o&&c.attributes.set("mathcolor",o),s.default.appendChildren(d,[c]),d},e.fixedFence=function(e,t,n,r){var i=e.nodeFactory.create("node","mrow",[],{open:t,close:r,texClass:a.TEXCLASS.ORD});return t&&s.default.appendChildren(i,[m(e,t,"l")]),s.default.isType(n,"mrow")?s.default.appendChildren(i,s.default.getChildren(n)):s.default.appendChildren(i,[n]),r&&s.default.appendChildren(i,[m(e,r,"r")]),i},e.mathPalette=m,e.fixInitialMO=function(e,t){for(var n=0,r=t.length;n<r;n++){var i=t[n];if(i&&!s.default.isType(i,"mspace")&&(!s.default.isType(i,"TeXAtom")||s.default.getChildren(i)[0]&&s.default.getChildren(s.default.getChildren(i)[0]).length)){if(s.default.isEmbellished(i)||s.default.isType(i,"TeXAtom")&&s.default.getTexClass(i)===a.TEXCLASS.REL){var o=e.nodeFactory.create("node","mi");t.unshift(o)}break}}},e.internalMath=function(e,t,n,r){if(e.configuration.options.internalMath)return e.configuration.options.internalMath(e,t,n,r);var i,o,a=r||e.stack.env.font,s=a?{mathvariant:a}:{},u=[],d=0,h=0,p="",f=0;if(t.match(/\\?[${}\\]|\\\(|\\(eq)?ref\s*\{/)){for(;d<t.length;)if("$"===(i=t.charAt(d++)))"$"===p&&0===f?(o=e.create("node","TeXAtom",[new l.default(t.slice(h,d-1),{},e.configuration).mml()]),u.push(o),p="",h=d):""===p&&(h<d-1&&u.push(g(e,t.slice(h,d-1),s)),p="$",h=d);else if("{"===i&&""!==p)f++;else if("}"===i)if("}"===p&&0===f){var m=new l.default(t.slice(h,d),{},e.configuration).mml();o=e.create("node","TeXAtom",[m],s),u.push(o),p="",h=d}else""!==p&&f&&f--;else if("\\"===i)if(""===p&&t.substr(d).match(/^(eq)?ref\s*\{/)){var v=RegExp["$&"].length;h<d-1&&u.push(g(e,t.slice(h,d-1),s)),p="}",h=d-1,d+=v}else"("===(i=t.charAt(d++))&&""===p?(h<d-2&&u.push(g(e,t.slice(h,d-2),s)),p=")",h=d):")"===i&&")"===p&&0===f?(o=e.create("node","TeXAtom",[new l.default(t.slice(h,d-2),{},e.configuration).mml()]),u.push(o),p="",h=d):i.match(/[${}\\]/)&&""===p&&(d--,t=t.substr(0,d-1)+t.substr(d));if(""!==p)throw new c.default("MathNotTerminated","Math not terminated in text box")}return h<t.length&&u.push(g(e,t.slice(h),s)),null!=n?u=[e.create("node","mstyle",u,{displaystyle:!1,scriptlevel:n})]:u.length>1&&(u=[e.create("node","mrow",u)]),u},e.internalText=g,e.underOver=function(t,n,r,i,o){if(e.checkMovableLimits(n),s.default.isType(n,"munderover")&&s.default.isEmbellished(n)){s.default.setProperties(s.default.getCoreMO(n),{lspace:0,rspace:0});var l=t.create("node","mo",[],{rspace:0});n=t.create("node","mrow",[l,n])}var c=t.create("node","munderover",[n]);s.default.setChild(c,"over"===i?c.over:c.under,r);var u=c;return o&&(u=t.create("node","TeXAtom",[c],{texClass:a.TEXCLASS.OP,movesupsub:!0})),s.default.setProperty(u,"subsupOK",!0),u},e.checkMovableLimits=function(e){var t=s.default.isType(e,"mo")?s.default.getForm(e):null;(s.default.getProperty(e,"movablelimits")||t&&t[3]&&t[3].movablelimits)&&s.default.setProperties(e,{movablelimits:!1})},e.trimSpaces=function(e){if("string"!=typeof e)return e;var t=e.trim();return t.match(/\\$/)&&e.match(/ $/)&&(t+=" "),t},e.setArrayAlign=function(t,n){return"t"===(n=e.trimSpaces(n||""))?t.arraydef.align="baseline 1":"b"===n?t.arraydef.align="baseline -1":"c"===n?t.arraydef.align="axis":n&&(t.arraydef.align=n),t},e.substituteArgs=function(e,t,n){for(var r="",i="",o=0;o<n.length;){var a=n.charAt(o++);if("\\"===a)r+=a+n.charAt(o++);else if("#"===a)if("#"===(a=n.charAt(o++)))r+=a;else{if(!a.match(/[1-9]/)||parseInt(a,10)>t.length)throw new c.default("IllegalMacroParam","Illegal macro parameter reference");i=v(e,v(e,i,r),t[parseInt(a,10)-1]),r=""}else r+=a}return v(e,i,r)},e.addArgs=v,e.checkMaxMacros=function(e,t){if(void 0===t&&(t=!0),!(++e.macroCount<=e.configuration.options.maxMacros))throw t?new c.default("MaxMacroSub1","MathJax maximum macro substitution count exceeded; is here a recursive macro call?"):new c.default("MaxMacroSub2","MathJax maximum substitution count exceeded; is there a recursive latex environment?")},e.checkEqnEnv=function(e){if(e.stack.global.eqnenv)throw new c.default("ErroneousNestingEq","Erroneous nesting of equation structures");e.stack.global.eqnenv=!0},e.copyNode=function(e,t){var n=e.copy(),r=t.configuration;return n.walkTree((function(e){var t,n;r.addNode(e.kind,e);var o=(e.getProperty("in-lists")||"").split(/,/);try{for(var a=i(o),s=a.next();!s.done;s=a.next()){var l=s.value;r.addNode(l,e)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}})),n},e.MmlFilterAttribute=function(e,t,n){return n},e.getFontDef=function(e){var t=e.stack.env.font;return t?{mathvariant:t}:{}},e.keyvalOptions=function(e,t,n){var o,a;void 0===t&&(t=null),void 0===n&&(n=!1);var s=function(e){var t,n,i,o,a,s={},l=e;for(;l;)t=r(_(l,["=",","]),3),o=t[0],i=t[1],l=t[2],"="===i?(n=r(_(l,[","]),3),a=n[0],i=n[1],l=n[2],a="false"===a||"true"===a?JSON.parse(a):a,s[o]=a):o&&(s[o]=!0);return s}(e);if(t)try{for(var l=i(Object.keys(s)),u=l.next();!u.done;u=l.next()){var d=u.value;if(!t.hasOwnProperty(d)){if(n)throw new c.default("InvalidOption","Invalid option: %1",d);delete s[d]}}}catch(e){o={error:e}}finally{try{u&&!u.done&&(a=l.return)&&a.call(l)}finally{if(o)throw o.error}}return s}}(o||(o={})),t.default=o},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),i(n(607),t),i(n(346),t),i(n(347),t),i(n(154),t),i(n(632),t),i(n(56),t),i(n(350),t),i(n(351),t),i(n(352),t),i(n(353),t),i(n(349),t)},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0});var a,s=n(23),l=n(134);!function(e){var t=new Map([["autoOP",!0],["fnOP",!0],["movesupsub",!0],["subsupOK",!0],["texprimestyle",!0],["useHeight",!0],["variantForm",!0],["withDelims",!0],["mathaccent",!0],["open",!0],["close",!0]]);function n(e,n){var i,o;try{for(var a=r(Object.keys(n)),s=a.next();!s.done;s=a.next()){var l=s.value,c=n[l];"texClass"===l?(e.texClass=c,e.setProperty(l,c)):"movablelimits"===l?(e.setProperty("movablelimits",c),(e.isKind("mo")||e.isKind("mstyle"))&&e.attributes.set("movablelimits",c)):"inferred"===l||(t.has(l)?e.setProperty(l,c):e.attributes.set(l,c))}}catch(e){i={error:e}}finally{try{s&&!s.done&&(o=a.return)&&o.call(a)}finally{if(i)throw i.error}}}function a(e,t,n){e.childNodes[t]=n,n&&(n.parent=e)}function c(e,t){return e.isKind(t)}e.createEntity=function(e){return String.fromCodePoint(parseInt(e,16))},e.getChildren=function(e){return e.childNodes},e.getText=function(e){return e.getText()},e.appendChildren=function(e,t){var n,i;try{for(var o=r(t),a=o.next();!a.done;a=o.next()){var s=a.value;e.appendChild(s)}}catch(e){n={error:e}}finally{try{a&&!a.done&&(i=o.return)&&i.call(o)}finally{if(n)throw n.error}}},e.setAttribute=function(e,t,n){e.attributes.set(t,n)},e.setProperty=function(e,t,n){e.setProperty(t,n)},e.setProperties=n,e.getProperty=function(e,t){return e.getProperty(t)},e.getAttribute=function(e,t){return e.attributes.get(t)},e.removeProperties=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];e.removeProperty.apply(e,o([],i(t)))},e.getChildAt=function(e,t){return e.childNodes[t]},e.setChild=a,e.copyChildren=function(e,t){for(var n=e.childNodes,r=0;r<n.length;r++)a(t,r,n[r])},e.copyAttributes=function(e,t){t.attributes=e.attributes,n(t,e.getAllProperties())},e.isType=c,e.isEmbellished=function(e){return e.isEmbellished},e.getTexClass=function(e){return e.texClass},e.getCoreMO=function(e){return e.coreMO()},e.isNode=function(e){return e instanceof s.AbstractMmlNode||e instanceof s.AbstractMmlEmptyNode},e.isInferred=function(e){return e.isInferred},e.getForm=function(e){var t,n;if(!c(e,"mo"))return null;var i=e,o=i.getForms();try{for(var a=r(o),s=a.next();!s.done;s=a.next()){var u=s.value,d=l.MmlMo.OPTABLE[u][i.getText()];if(d)return d}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}return null}}(a||(a={})),t.default=a},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},s=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLWrapper=t.SPACE=t.FONTSIZE=void 0;var l=n(58),c=n(833),u=n(74);t.FONTSIZE={"70.7%":"s","70%":"s","50%":"ss","60%":"Tn","85%":"sm","120%":"lg","144%":"Lg","173%":"LG","207%":"hg","249%":"HG"},t.SPACE=((i={})[l.em(2/18)]="1",i[l.em(3/18)]="2",i[l.em(4/18)]="3",i[l.em(5/18)]="4",i[l.em(6/18)]="5",i);var d=function(e){function n(){var t=null!==e&&e.apply(this,arguments)||this;return t.chtml=null,t}return o(n,e),n.prototype.toCHTML=function(e){var t,n,r=this.standardCHTMLnode(e);try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){o.value.toCHTML(r)}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},n.prototype.standardCHTMLnode=function(e){this.markUsed();var t=this.createCHTMLnode(e);return this.handleStyles(),this.handleVariant(),this.handleScale(),this.handleColor(),this.handleSpace(),this.handleAttributes(),this.handlePWidth(),t},n.prototype.markUsed=function(){this.jax.wrapperUsage.add(this.kind)},n.prototype.createCHTMLnode=function(e){var t=this.node.attributes.get("href");return t&&(e=this.adaptor.append(e,this.html("a",{href:t}))),this.chtml=this.adaptor.append(e,this.html("mjx-"+this.node.kind)),this.chtml},n.prototype.handleStyles=function(){if(this.styles){var e=this.styles.cssText;if(e){this.adaptor.setAttribute(this.chtml,"style",e);var t=this.styles.get("font-family");t&&this.adaptor.setStyle(this.chtml,"font-family","MJXZERO, "+t)}}},n.prototype.handleVariant=function(){this.node.isToken&&"-explicitFont"!==this.variant&&this.adaptor.setAttribute(this.chtml,"class",(this.font.getVariant(this.variant)||this.font.getVariant("normal")).classes)},n.prototype.handleScale=function(){this.setScale(this.chtml,this.bbox.rscale)},n.prototype.setScale=function(e,n){var r=Math.abs(n-1)<.001?1:n;if(e&&1!==r){var i=this.percent(r);t.FONTSIZE[i]?this.adaptor.setAttribute(e,"size",t.FONTSIZE[i]):this.adaptor.setStyle(e,"fontSize",i)}return e},n.prototype.handleSpace=function(){var e,n;try{for(var r=a([[this.bbox.L,"space","marginLeft"],[this.bbox.R,"rspace","marginRight"]]),i=r.next();!i.done;i=r.next()){var o=i.value,l=s(o,3),c=l[0],u=l[1],d=l[2];if(c){var h=this.em(c);t.SPACE[h]?this.adaptor.setAttribute(this.chtml,u,t.SPACE[h]):this.adaptor.setStyle(this.chtml,d,h)}}}catch(t){e={error:t}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(e)throw e.error}}},n.prototype.handleColor=function(){var e=this.node.attributes,t=e.getExplicit("mathcolor"),n=e.getExplicit("color"),r=e.getExplicit("mathbackground"),i=e.getExplicit("background");(t||n)&&this.adaptor.setStyle(this.chtml,"color",t||n),(r||i)&&this.adaptor.setStyle(this.chtml,"backgroundColor",r||i)},n.prototype.handleAttributes=function(){var e,t,r,i,o=this.node.attributes,s=o.getAllDefaults(),l=n.skipAttributes;try{for(var c=a(o.getExplicitNames()),u=c.next();!u.done;u=c.next()){var d=u.value;!1!==l[d]&&(d in s||l[d]||this.adaptor.hasAttribute(this.chtml,d))||this.adaptor.setAttribute(this.chtml,d,o.getExplicit(d))}}catch(t){e={error:t}}finally{try{u&&!u.done&&(t=c.return)&&t.call(c)}finally{if(e)throw e.error}}if(o.get("class")){var h=o.get("class").trim().split(/ +/);try{for(var p=a(h),f=p.next();!f.done;f=p.next()){var m=f.value;this.adaptor.addClass(this.chtml,m)}}catch(e){r={error:e}}finally{try{f&&!f.done&&(i=p.return)&&i.call(p)}finally{if(r)throw r.error}}}},n.prototype.handlePWidth=function(){this.bbox.pwidth&&(this.bbox.pwidth===u.BBox.fullWidth?this.adaptor.setAttribute(this.chtml,"width","full"):this.adaptor.setStyle(this.chtml,"width",this.bbox.pwidth))},n.prototype.setIndent=function(e,t,n){var r=this.adaptor;if("center"===t||"left"===t){var i=this.getBBox().L;r.setStyle(e,"margin-left",this.em(n+i))}if("center"===t||"right"===t){var o=this.getBBox().R;r.setStyle(e,"margin-right",this.em(-n+o))}},n.prototype.drawBBox=function(){var e=this.getBBox(),t=e.w,n=e.h,r=e.d,i=e.R,o=this.html("mjx-box",{style:{opacity:.25,"margin-left":this.em(-t-i)}},[this.html("mjx-box",{style:{height:this.em(n),width:this.em(t),"background-color":"red"}}),this.html("mjx-box",{style:{height:this.em(r),width:this.em(t),"margin-left":this.em(-t),"vertical-align":this.em(-r),"background-color":"green"}})]),a=this.chtml||this.parent.chtml,s=this.adaptor.getAttribute(a,"size");s&&this.adaptor.setAttribute(o,"size",s);var l=this.adaptor.getStyle(a,"fontSize");l&&this.adaptor.setStyle(o,"fontSize",l),this.adaptor.append(this.adaptor.parent(a),o),this.adaptor.setStyle(a,"backgroundColor","#FFEE00")},n.prototype.html=function(e,t,n){return void 0===t&&(t={}),void 0===n&&(n=[]),this.jax.html(e,t,n)},n.prototype.text=function(e){return this.jax.text(e)},n.prototype.char=function(e){return this.font.charSelector(e).substr(1)},n.kind="unknown",n.autoStyle=!0,n}(c.CommonWrapper);t.CHTMLWrapper=d},function(e,t,n){var r;
/*!
 * jQuery JavaScript Library v3.6.0
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright OpenJS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2021-03-02T17:08Z
 */!function(t,n){"use strict";"object"==typeof e.exports?e.exports=t.document?n(t,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return n(e)}:n(t)}("undefined"!=typeof window?window:this,(function(n,i){"use strict";var o=[],a=Object.getPrototypeOf,s=o.slice,l=o.flat?function(e){return o.flat.call(e)}:function(e){return o.concat.apply([],e)},c=o.push,u=o.indexOf,d={},h=d.toString,p=d.hasOwnProperty,f=p.toString,m=f.call(Object),g={},v=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType&&"function"!=typeof e.item},y=function(e){return null!=e&&e===e.window},_=n.document,b={type:!0,src:!0,nonce:!0,noModule:!0};function M(e,t,n){var r,i,o=(n=n||_).createElement("script");if(o.text=e,t)for(r in b)(i=t[r]||t.getAttribute&&t.getAttribute(r))&&o.setAttribute(r,i);n.head.appendChild(o).parentNode.removeChild(o)}function w(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?d[h.call(e)]||"object":typeof e}var A=function(e,t){return new A.fn.init(e,t)};function C(e){var t=!!e&&"length"in e&&e.length,n=w(e);return!v(e)&&!y(e)&&("array"===n||0===t||"number"==typeof t&&t>0&&t-1 in e)}A.fn=A.prototype={jquery:"3.6.0",constructor:A,length:0,toArray:function(){return s.call(this)},get:function(e){return null==e?s.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=A.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return A.each(this,e)},map:function(e){return this.pushStack(A.map(this,(function(t,n){return e.call(t,n,t)})))},slice:function(){return this.pushStack(s.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},even:function(){return this.pushStack(A.grep(this,(function(e,t){return(t+1)%2})))},odd:function(){return this.pushStack(A.grep(this,(function(e,t){return t%2})))},eq:function(e){var t=this.length,n=+e+(e<0?t:0);return this.pushStack(n>=0&&n<t?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:c,sort:o.sort,splice:o.splice},A.extend=A.fn.extend=function(){var e,t,n,r,i,o,a=arguments[0]||{},s=1,l=arguments.length,c=!1;for("boolean"==typeof a&&(c=a,a=arguments[s]||{},s++),"object"==typeof a||v(a)||(a={}),s===l&&(a=this,s--);s<l;s++)if(null!=(e=arguments[s]))for(t in e)r=e[t],"__proto__"!==t&&a!==r&&(c&&r&&(A.isPlainObject(r)||(i=Array.isArray(r)))?(n=a[t],o=i&&!Array.isArray(n)?[]:i||A.isPlainObject(n)?n:{},i=!1,a[t]=A.extend(c,o,r)):void 0!==r&&(a[t]=r));return a},A.extend({expando:"jQuery"+("3.6.0"+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,n;return!(!e||"[object Object]"!==h.call(e))&&(!(t=a(e))||"function"==typeof(n=p.call(t,"constructor")&&t.constructor)&&f.call(n)===m)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t,n){M(e,{nonce:t&&t.nonce},n)},each:function(e,t){var n,r=0;if(C(e))for(n=e.length;r<n&&!1!==t.call(e[r],r,e[r]);r++);else for(r in e)if(!1===t.call(e[r],r,e[r]))break;return e},makeArray:function(e,t){var n=t||[];return null!=e&&(C(Object(e))?A.merge(n,"string"==typeof e?[e]:e):c.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:u.call(t,e,n)},merge:function(e,t){for(var n=+t.length,r=0,i=e.length;r<n;r++)e[i++]=t[r];return e.length=i,e},grep:function(e,t,n){for(var r=[],i=0,o=e.length,a=!n;i<o;i++)!t(e[i],i)!==a&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=0,a=[];if(C(e))for(r=e.length;o<r;o++)null!=(i=t(e[o],o,n))&&a.push(i);else for(o in e)null!=(i=t(e[o],o,n))&&a.push(i);return l(a)},guid:1,support:g}),"function"==typeof Symbol&&(A.fn[Symbol.iterator]=o[Symbol.iterator]),A.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),(function(e,t){d["[object "+t+"]"]=t.toLowerCase()}));var x=
/*!
 * Sizzle CSS Selector Engine v2.3.6
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://js.foundation/
 *
 * Date: 2021-02-16
 */
function(e){var t,n,r,i,o,a,s,l,c,u,d,h,p,f,m,g,v,y,_,b="sizzle"+1*new Date,M=e.document,w=0,A=0,C=le(),x=le(),E=le(),L=le(),S=function(e,t){return e===t&&(d=!0),0},T={}.hasOwnProperty,O=[],I=O.pop,k=O.push,D=O.push,N=O.slice,j=function(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1},P="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",z="[\\x20\\t\\r\\n\\f]",R="(?:\\\\[\\da-fA-F]{1,6}"+z+"?|\\\\[^\\r\\n\\f]|[\\w-]|[^\0-\\x7f])+",B="\\["+z+"*("+R+")(?:"+z+"*([*^$|!~]?=)"+z+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+R+"))|)"+z+"*\\]",H=":("+R+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+B+")*)|.*)\\)|)",F=new RegExp(z+"+","g"),Y=new RegExp("^"+z+"+|((?:^|[^\\\\])(?:\\\\.)*)"+z+"+$","g"),V=new RegExp("^"+z+"*,"+z+"*"),U=new RegExp("^"+z+"*([>+~]|"+z+")"+z+"*"),W=new RegExp(z+"|>"),G=new RegExp(H),q=new RegExp("^"+R+"$"),K={ID:new RegExp("^#("+R+")"),CLASS:new RegExp("^\\.("+R+")"),TAG:new RegExp("^("+R+"|[*])"),ATTR:new RegExp("^"+B),PSEUDO:new RegExp("^"+H),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+z+"*(even|odd|(([+-]|)(\\d*)n|)"+z+"*(?:([+-]|)"+z+"*(\\d+)|))"+z+"*\\)|)","i"),bool:new RegExp("^(?:"+P+")$","i"),needsContext:new RegExp("^"+z+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+z+"*((?:-\\d)?\\d*)"+z+"*\\)|)(?=[^-]|$)","i")},X=/HTML$/i,J=/^(?:input|select|textarea|button)$/i,Q=/^h\d$/i,Z=/^[^{]+\{\s*\[native \w/,$=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ee=/[+~]/,te=new RegExp("\\\\[\\da-fA-F]{1,6}"+z+"?|\\\\([^\\r\\n\\f])","g"),ne=function(e,t){var n="0x"+e.slice(1)-65536;return t||(n<0?String.fromCharCode(n+65536):String.fromCharCode(n>>10|55296,1023&n|56320))},re=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ie=function(e,t){return t?"\0"===e?"�":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e},oe=function(){h()},ae=be((function(e){return!0===e.disabled&&"fieldset"===e.nodeName.toLowerCase()}),{dir:"parentNode",next:"legend"});try{D.apply(O=N.call(M.childNodes),M.childNodes),O[M.childNodes.length].nodeType}catch(e){D={apply:O.length?function(e,t){k.apply(e,N.call(t))}:function(e,t){for(var n=e.length,r=0;e[n++]=t[r++];);e.length=n-1}}}function se(e,t,r,i){var o,s,c,u,d,f,v,y=t&&t.ownerDocument,M=t?t.nodeType:9;if(r=r||[],"string"!=typeof e||!e||1!==M&&9!==M&&11!==M)return r;if(!i&&(h(t),t=t||p,m)){if(11!==M&&(d=$.exec(e)))if(o=d[1]){if(9===M){if(!(c=t.getElementById(o)))return r;if(c.id===o)return r.push(c),r}else if(y&&(c=y.getElementById(o))&&_(t,c)&&c.id===o)return r.push(c),r}else{if(d[2])return D.apply(r,t.getElementsByTagName(e)),r;if((o=d[3])&&n.getElementsByClassName&&t.getElementsByClassName)return D.apply(r,t.getElementsByClassName(o)),r}if(n.qsa&&!L[e+" "]&&(!g||!g.test(e))&&(1!==M||"object"!==t.nodeName.toLowerCase())){if(v=e,y=t,1===M&&(W.test(e)||U.test(e))){for((y=ee.test(e)&&ve(t.parentNode)||t)===t&&n.scope||((u=t.getAttribute("id"))?u=u.replace(re,ie):t.setAttribute("id",u=b)),s=(f=a(e)).length;s--;)f[s]=(u?"#"+u:":scope")+" "+_e(f[s]);v=f.join(",")}try{return D.apply(r,y.querySelectorAll(v)),r}catch(t){L(e,!0)}finally{u===b&&t.removeAttribute("id")}}}return l(e.replace(Y,"$1"),t,r,i)}function le(){var e=[];return function t(n,i){return e.push(n+" ")>r.cacheLength&&delete t[e.shift()],t[n+" "]=i}}function ce(e){return e[b]=!0,e}function ue(e){var t=p.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function de(e,t){for(var n=e.split("|"),i=n.length;i--;)r.attrHandle[n[i]]=t}function he(e,t){var n=t&&e,r=n&&1===e.nodeType&&1===t.nodeType&&e.sourceIndex-t.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===t)return-1;return e?1:-1}function pe(e){return function(t){return"input"===t.nodeName.toLowerCase()&&t.type===e}}function fe(e){return function(t){var n=t.nodeName.toLowerCase();return("input"===n||"button"===n)&&t.type===e}}function me(e){return function(t){return"form"in t?t.parentNode&&!1===t.disabled?"label"in t?"label"in t.parentNode?t.parentNode.disabled===e:t.disabled===e:t.isDisabled===e||t.isDisabled!==!e&&ae(t)===e:t.disabled===e:"label"in t&&t.disabled===e}}function ge(e){return ce((function(t){return t=+t,ce((function(n,r){for(var i,o=e([],n.length,t),a=o.length;a--;)n[i=o[a]]&&(n[i]=!(r[i]=n[i]))}))}))}function ve(e){return e&&void 0!==e.getElementsByTagName&&e}for(t in n=se.support={},o=se.isXML=function(e){var t=e&&e.namespaceURI,n=e&&(e.ownerDocument||e).documentElement;return!X.test(t||n&&n.nodeName||"HTML")},h=se.setDocument=function(e){var t,i,a=e?e.ownerDocument||e:M;return a!=p&&9===a.nodeType&&a.documentElement?(f=(p=a).documentElement,m=!o(p),M!=p&&(i=p.defaultView)&&i.top!==i&&(i.addEventListener?i.addEventListener("unload",oe,!1):i.attachEvent&&i.attachEvent("onunload",oe)),n.scope=ue((function(e){return f.appendChild(e).appendChild(p.createElement("div")),void 0!==e.querySelectorAll&&!e.querySelectorAll(":scope fieldset div").length})),n.attributes=ue((function(e){return e.className="i",!e.getAttribute("className")})),n.getElementsByTagName=ue((function(e){return e.appendChild(p.createComment("")),!e.getElementsByTagName("*").length})),n.getElementsByClassName=Z.test(p.getElementsByClassName),n.getById=ue((function(e){return f.appendChild(e).id=b,!p.getElementsByName||!p.getElementsByName(b).length})),n.getById?(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){return e.getAttribute("id")===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&m){var n=t.getElementById(e);return n?[n]:[]}}):(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){var n=void 0!==e.getAttributeNode&&e.getAttributeNode("id");return n&&n.value===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&m){var n,r,i,o=t.getElementById(e);if(o){if((n=o.getAttributeNode("id"))&&n.value===e)return[o];for(i=t.getElementsByName(e),r=0;o=i[r++];)if((n=o.getAttributeNode("id"))&&n.value===e)return[o]}return[]}}),r.find.TAG=n.getElementsByTagName?function(e,t){return void 0!==t.getElementsByTagName?t.getElementsByTagName(e):n.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,r=[],i=0,o=t.getElementsByTagName(e);if("*"===e){for(;n=o[i++];)1===n.nodeType&&r.push(n);return r}return o},r.find.CLASS=n.getElementsByClassName&&function(e,t){if(void 0!==t.getElementsByClassName&&m)return t.getElementsByClassName(e)},v=[],g=[],(n.qsa=Z.test(p.querySelectorAll))&&(ue((function(e){var t;f.appendChild(e).innerHTML="<a id='"+b+"'></a><select id='"+b+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&g.push("[*^$]="+z+"*(?:''|\"\")"),e.querySelectorAll("[selected]").length||g.push("\\["+z+"*(?:value|"+P+")"),e.querySelectorAll("[id~="+b+"-]").length||g.push("~="),(t=p.createElement("input")).setAttribute("name",""),e.appendChild(t),e.querySelectorAll("[name='']").length||g.push("\\["+z+"*name"+z+"*="+z+"*(?:''|\"\")"),e.querySelectorAll(":checked").length||g.push(":checked"),e.querySelectorAll("a#"+b+"+*").length||g.push(".#.+[+~]"),e.querySelectorAll("\\\f"),g.push("[\\r\\n\\f]")})),ue((function(e){e.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var t=p.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&g.push("name"+z+"*[*^$|!~]?="),2!==e.querySelectorAll(":enabled").length&&g.push(":enabled",":disabled"),f.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&g.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),g.push(",.*:")}))),(n.matchesSelector=Z.test(y=f.matches||f.webkitMatchesSelector||f.mozMatchesSelector||f.oMatchesSelector||f.msMatchesSelector))&&ue((function(e){n.disconnectedMatch=y.call(e,"*"),y.call(e,"[s!='']:x"),v.push("!=",H)})),g=g.length&&new RegExp(g.join("|")),v=v.length&&new RegExp(v.join("|")),t=Z.test(f.compareDocumentPosition),_=t||Z.test(f.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):e.compareDocumentPosition&&16&e.compareDocumentPosition(r)))}:function(e,t){if(t)for(;t=t.parentNode;)if(t===e)return!0;return!1},S=t?function(e,t){if(e===t)return d=!0,0;var r=!e.compareDocumentPosition-!t.compareDocumentPosition;return r||(1&(r=(e.ownerDocument||e)==(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!n.sortDetached&&t.compareDocumentPosition(e)===r?e==p||e.ownerDocument==M&&_(M,e)?-1:t==p||t.ownerDocument==M&&_(M,t)?1:u?j(u,e)-j(u,t):0:4&r?-1:1)}:function(e,t){if(e===t)return d=!0,0;var n,r=0,i=e.parentNode,o=t.parentNode,a=[e],s=[t];if(!i||!o)return e==p?-1:t==p?1:i?-1:o?1:u?j(u,e)-j(u,t):0;if(i===o)return he(e,t);for(n=e;n=n.parentNode;)a.unshift(n);for(n=t;n=n.parentNode;)s.unshift(n);for(;a[r]===s[r];)r++;return r?he(a[r],s[r]):a[r]==M?-1:s[r]==M?1:0},p):p},se.matches=function(e,t){return se(e,null,null,t)},se.matchesSelector=function(e,t){if(h(e),n.matchesSelector&&m&&!L[t+" "]&&(!v||!v.test(t))&&(!g||!g.test(t)))try{var r=y.call(e,t);if(r||n.disconnectedMatch||e.document&&11!==e.document.nodeType)return r}catch(e){L(t,!0)}return se(t,p,null,[e]).length>0},se.contains=function(e,t){return(e.ownerDocument||e)!=p&&h(e),_(e,t)},se.attr=function(e,t){(e.ownerDocument||e)!=p&&h(e);var i=r.attrHandle[t.toLowerCase()],o=i&&T.call(r.attrHandle,t.toLowerCase())?i(e,t,!m):void 0;return void 0!==o?o:n.attributes||!m?e.getAttribute(t):(o=e.getAttributeNode(t))&&o.specified?o.value:null},se.escape=function(e){return(e+"").replace(re,ie)},se.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},se.uniqueSort=function(e){var t,r=[],i=0,o=0;if(d=!n.detectDuplicates,u=!n.sortStable&&e.slice(0),e.sort(S),d){for(;t=e[o++];)t===e[o]&&(i=r.push(o));for(;i--;)e.splice(r[i],1)}return u=null,e},i=se.getText=function(e){var t,n="",r=0,o=e.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=i(e)}else if(3===o||4===o)return e.nodeValue}else for(;t=e[r++];)n+=i(t);return n},(r=se.selectors={cacheLength:50,createPseudo:ce,match:K,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(te,ne),e[3]=(e[3]||e[4]||e[5]||"").replace(te,ne),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||se.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&se.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return K.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&G.test(n)&&(t=a(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(te,ne).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=C[e+" "];return t||(t=new RegExp("(^|"+z+")"+e+"("+z+"|$)"))&&C(e,(function(e){return t.test("string"==typeof e.className&&e.className||void 0!==e.getAttribute&&e.getAttribute("class")||"")}))},ATTR:function(e,t,n){return function(r){var i=se.attr(r,e);return null==i?"!="===t:!t||(i+="","="===t?i===n:"!="===t?i!==n:"^="===t?n&&0===i.indexOf(n):"*="===t?n&&i.indexOf(n)>-1:"$="===t?n&&i.slice(-n.length)===n:"~="===t?(" "+i.replace(F," ")+" ").indexOf(n)>-1:"|="===t&&(i===n||i.slice(0,n.length+1)===n+"-"))}},CHILD:function(e,t,n,r,i){var o="nth"!==e.slice(0,3),a="last"!==e.slice(-4),s="of-type"===t;return 1===r&&0===i?function(e){return!!e.parentNode}:function(t,n,l){var c,u,d,h,p,f,m=o!==a?"nextSibling":"previousSibling",g=t.parentNode,v=s&&t.nodeName.toLowerCase(),y=!l&&!s,_=!1;if(g){if(o){for(;m;){for(h=t;h=h[m];)if(s?h.nodeName.toLowerCase()===v:1===h.nodeType)return!1;f=m="only"===e&&!f&&"nextSibling"}return!0}if(f=[a?g.firstChild:g.lastChild],a&&y){for(_=(p=(c=(u=(d=(h=g)[b]||(h[b]={}))[h.uniqueID]||(d[h.uniqueID]={}))[e]||[])[0]===w&&c[1])&&c[2],h=p&&g.childNodes[p];h=++p&&h&&h[m]||(_=p=0)||f.pop();)if(1===h.nodeType&&++_&&h===t){u[e]=[w,p,_];break}}else if(y&&(_=p=(c=(u=(d=(h=t)[b]||(h[b]={}))[h.uniqueID]||(d[h.uniqueID]={}))[e]||[])[0]===w&&c[1]),!1===_)for(;(h=++p&&h&&h[m]||(_=p=0)||f.pop())&&((s?h.nodeName.toLowerCase()!==v:1!==h.nodeType)||!++_||(y&&((u=(d=h[b]||(h[b]={}))[h.uniqueID]||(d[h.uniqueID]={}))[e]=[w,_]),h!==t)););return(_-=i)===r||_%r==0&&_/r>=0}}},PSEUDO:function(e,t){var n,i=r.pseudos[e]||r.setFilters[e.toLowerCase()]||se.error("unsupported pseudo: "+e);return i[b]?i(t):i.length>1?(n=[e,e,"",t],r.setFilters.hasOwnProperty(e.toLowerCase())?ce((function(e,n){for(var r,o=i(e,t),a=o.length;a--;)e[r=j(e,o[a])]=!(n[r]=o[a])})):function(e){return i(e,0,n)}):i}},pseudos:{not:ce((function(e){var t=[],n=[],r=s(e.replace(Y,"$1"));return r[b]?ce((function(e,t,n,i){for(var o,a=r(e,null,i,[]),s=e.length;s--;)(o=a[s])&&(e[s]=!(t[s]=o))})):function(e,i,o){return t[0]=e,r(t,null,o,n),t[0]=null,!n.pop()}})),has:ce((function(e){return function(t){return se(e,t).length>0}})),contains:ce((function(e){return e=e.replace(te,ne),function(t){return(t.textContent||i(t)).indexOf(e)>-1}})),lang:ce((function(e){return q.test(e||"")||se.error("unsupported lang: "+e),e=e.replace(te,ne).toLowerCase(),function(t){var n;do{if(n=m?t.lang:t.getAttribute("xml:lang")||t.getAttribute("lang"))return(n=n.toLowerCase())===e||0===n.indexOf(e+"-")}while((t=t.parentNode)&&1===t.nodeType);return!1}})),target:function(t){var n=e.location&&e.location.hash;return n&&n.slice(1)===t.id},root:function(e){return e===f},focus:function(e){return e===p.activeElement&&(!p.hasFocus||p.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:me(!1),disabled:me(!0),checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!r.pseudos.empty(e)},header:function(e){return Q.test(e.nodeName)},input:function(e){return J.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:ge((function(){return[0]})),last:ge((function(e,t){return[t-1]})),eq:ge((function(e,t,n){return[n<0?n+t:n]})),even:ge((function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e})),odd:ge((function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e})),lt:ge((function(e,t,n){for(var r=n<0?n+t:n>t?t:n;--r>=0;)e.push(r);return e})),gt:ge((function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e}))}}).pseudos.nth=r.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})r.pseudos[t]=pe(t);for(t in{submit:!0,reset:!0})r.pseudos[t]=fe(t);function ye(){}function _e(e){for(var t=0,n=e.length,r="";t<n;t++)r+=e[t].value;return r}function be(e,t,n){var r=t.dir,i=t.next,o=i||r,a=n&&"parentNode"===o,s=A++;return t.first?function(t,n,i){for(;t=t[r];)if(1===t.nodeType||a)return e(t,n,i);return!1}:function(t,n,l){var c,u,d,h=[w,s];if(l){for(;t=t[r];)if((1===t.nodeType||a)&&e(t,n,l))return!0}else for(;t=t[r];)if(1===t.nodeType||a)if(u=(d=t[b]||(t[b]={}))[t.uniqueID]||(d[t.uniqueID]={}),i&&i===t.nodeName.toLowerCase())t=t[r]||t;else{if((c=u[o])&&c[0]===w&&c[1]===s)return h[2]=c[2];if(u[o]=h,h[2]=e(t,n,l))return!0}return!1}}function Me(e){return e.length>1?function(t,n,r){for(var i=e.length;i--;)if(!e[i](t,n,r))return!1;return!0}:e[0]}function we(e,t,n,r,i){for(var o,a=[],s=0,l=e.length,c=null!=t;s<l;s++)(o=e[s])&&(n&&!n(o,r,i)||(a.push(o),c&&t.push(s)));return a}function Ae(e,t,n,r,i,o){return r&&!r[b]&&(r=Ae(r)),i&&!i[b]&&(i=Ae(i,o)),ce((function(o,a,s,l){var c,u,d,h=[],p=[],f=a.length,m=o||function(e,t,n){for(var r=0,i=t.length;r<i;r++)se(e,t[r],n);return n}(t||"*",s.nodeType?[s]:s,[]),g=!e||!o&&t?m:we(m,h,e,s,l),v=n?i||(o?e:f||r)?[]:a:g;if(n&&n(g,v,s,l),r)for(c=we(v,p),r(c,[],s,l),u=c.length;u--;)(d=c[u])&&(v[p[u]]=!(g[p[u]]=d));if(o){if(i||e){if(i){for(c=[],u=v.length;u--;)(d=v[u])&&c.push(g[u]=d);i(null,v=[],c,l)}for(u=v.length;u--;)(d=v[u])&&(c=i?j(o,d):h[u])>-1&&(o[c]=!(a[c]=d))}}else v=we(v===a?v.splice(f,v.length):v),i?i(null,a,v,l):D.apply(a,v)}))}function Ce(e){for(var t,n,i,o=e.length,a=r.relative[e[0].type],s=a||r.relative[" "],l=a?1:0,u=be((function(e){return e===t}),s,!0),d=be((function(e){return j(t,e)>-1}),s,!0),h=[function(e,n,r){var i=!a&&(r||n!==c)||((t=n).nodeType?u(e,n,r):d(e,n,r));return t=null,i}];l<o;l++)if(n=r.relative[e[l].type])h=[be(Me(h),n)];else{if((n=r.filter[e[l].type].apply(null,e[l].matches))[b]){for(i=++l;i<o&&!r.relative[e[i].type];i++);return Ae(l>1&&Me(h),l>1&&_e(e.slice(0,l-1).concat({value:" "===e[l-2].type?"*":""})).replace(Y,"$1"),n,l<i&&Ce(e.slice(l,i)),i<o&&Ce(e=e.slice(i)),i<o&&_e(e))}h.push(n)}return Me(h)}return ye.prototype=r.filters=r.pseudos,r.setFilters=new ye,a=se.tokenize=function(e,t){var n,i,o,a,s,l,c,u=x[e+" "];if(u)return t?0:u.slice(0);for(s=e,l=[],c=r.preFilter;s;){for(a in n&&!(i=V.exec(s))||(i&&(s=s.slice(i[0].length)||s),l.push(o=[])),n=!1,(i=U.exec(s))&&(n=i.shift(),o.push({value:n,type:i[0].replace(Y," ")}),s=s.slice(n.length)),r.filter)!(i=K[a].exec(s))||c[a]&&!(i=c[a](i))||(n=i.shift(),o.push({value:n,type:a,matches:i}),s=s.slice(n.length));if(!n)break}return t?s.length:s?se.error(e):x(e,l).slice(0)},s=se.compile=function(e,t){var n,i=[],o=[],s=E[e+" "];if(!s){for(t||(t=a(e)),n=t.length;n--;)(s=Ce(t[n]))[b]?i.push(s):o.push(s);(s=E(e,function(e,t){var n=t.length>0,i=e.length>0,o=function(o,a,s,l,u){var d,f,g,v=0,y="0",_=o&&[],b=[],M=c,A=o||i&&r.find.TAG("*",u),C=w+=null==M?1:Math.random()||.1,x=A.length;for(u&&(c=a==p||a||u);y!==x&&null!=(d=A[y]);y++){if(i&&d){for(f=0,a||d.ownerDocument==p||(h(d),s=!m);g=e[f++];)if(g(d,a||p,s)){l.push(d);break}u&&(w=C)}n&&((d=!g&&d)&&v--,o&&_.push(d))}if(v+=y,n&&y!==v){for(f=0;g=t[f++];)g(_,b,a,s);if(o){if(v>0)for(;y--;)_[y]||b[y]||(b[y]=I.call(l));b=we(b)}D.apply(l,b),u&&!o&&b.length>0&&v+t.length>1&&se.uniqueSort(l)}return u&&(w=C,c=M),_};return n?ce(o):o}(o,i))).selector=e}return s},l=se.select=function(e,t,n,i){var o,l,c,u,d,h="function"==typeof e&&e,p=!i&&a(e=h.selector||e);if(n=n||[],1===p.length){if((l=p[0]=p[0].slice(0)).length>2&&"ID"===(c=l[0]).type&&9===t.nodeType&&m&&r.relative[l[1].type]){if(!(t=(r.find.ID(c.matches[0].replace(te,ne),t)||[])[0]))return n;h&&(t=t.parentNode),e=e.slice(l.shift().value.length)}for(o=K.needsContext.test(e)?0:l.length;o--&&(c=l[o],!r.relative[u=c.type]);)if((d=r.find[u])&&(i=d(c.matches[0].replace(te,ne),ee.test(l[0].type)&&ve(t.parentNode)||t))){if(l.splice(o,1),!(e=i.length&&_e(l)))return D.apply(n,i),n;break}}return(h||s(e,p))(i,t,!m,n,!t||ee.test(e)&&ve(t.parentNode)||t),n},n.sortStable=b.split("").sort(S).join("")===b,n.detectDuplicates=!!d,h(),n.sortDetached=ue((function(e){return 1&e.compareDocumentPosition(p.createElement("fieldset"))})),ue((function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")}))||de("type|href|height|width",(function(e,t,n){if(!n)return e.getAttribute(t,"type"===t.toLowerCase()?1:2)})),n.attributes&&ue((function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")}))||de("value",(function(e,t,n){if(!n&&"input"===e.nodeName.toLowerCase())return e.defaultValue})),ue((function(e){return null==e.getAttribute("disabled")}))||de(P,(function(e,t,n){var r;if(!n)return!0===e[t]?t.toLowerCase():(r=e.getAttributeNode(t))&&r.specified?r.value:null})),se}(n);A.find=x,A.expr=x.selectors,A.expr[":"]=A.expr.pseudos,A.uniqueSort=A.unique=x.uniqueSort,A.text=x.getText,A.isXMLDoc=x.isXML,A.contains=x.contains,A.escapeSelector=x.escape;var E=function(e,t,n){for(var r=[],i=void 0!==n;(e=e[t])&&9!==e.nodeType;)if(1===e.nodeType){if(i&&A(e).is(n))break;r.push(e)}return r},L=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},S=A.expr.match.needsContext;function T(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}var O=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function I(e,t,n){return v(t)?A.grep(e,(function(e,r){return!!t.call(e,r,e)!==n})):t.nodeType?A.grep(e,(function(e){return e===t!==n})):"string"!=typeof t?A.grep(e,(function(e){return u.call(t,e)>-1!==n})):A.filter(t,e,n)}A.filter=function(e,t,n){var r=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===r.nodeType?A.find.matchesSelector(r,e)?[r]:[]:A.find.matches(e,A.grep(t,(function(e){return 1===e.nodeType})))},A.fn.extend({find:function(e){var t,n,r=this.length,i=this;if("string"!=typeof e)return this.pushStack(A(e).filter((function(){for(t=0;t<r;t++)if(A.contains(i[t],this))return!0})));for(n=this.pushStack([]),t=0;t<r;t++)A.find(e,i[t],n);return r>1?A.uniqueSort(n):n},filter:function(e){return this.pushStack(I(this,e||[],!1))},not:function(e){return this.pushStack(I(this,e||[],!0))},is:function(e){return!!I(this,"string"==typeof e&&S.test(e)?A(e):e||[],!1).length}});var k,D=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(A.fn.init=function(e,t,n){var r,i;if(!e)return this;if(n=n||k,"string"==typeof e){if(!(r="<"===e[0]&&">"===e[e.length-1]&&e.length>=3?[null,e,null]:D.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1]){if(t=t instanceof A?t[0]:t,A.merge(this,A.parseHTML(r[1],t&&t.nodeType?t.ownerDocument||t:_,!0)),O.test(r[1])&&A.isPlainObject(t))for(r in t)v(this[r])?this[r](t[r]):this.attr(r,t[r]);return this}return(i=_.getElementById(r[2]))&&(this[0]=i,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):v(e)?void 0!==n.ready?n.ready(e):e(A):A.makeArray(e,this)}).prototype=A.fn,k=A(_);var N=/^(?:parents|prev(?:Until|All))/,j={children:!0,contents:!0,next:!0,prev:!0};function P(e,t){for(;(e=e[t])&&1!==e.nodeType;);return e}A.fn.extend({has:function(e){var t=A(e,this),n=t.length;return this.filter((function(){for(var e=0;e<n;e++)if(A.contains(this,t[e]))return!0}))},closest:function(e,t){var n,r=0,i=this.length,o=[],a="string"!=typeof e&&A(e);if(!S.test(e))for(;r<i;r++)for(n=this[r];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&A.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(o.length>1?A.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?u.call(A(e),this[0]):u.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(A.uniqueSort(A.merge(this.get(),A(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),A.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return E(e,"parentNode")},parentsUntil:function(e,t,n){return E(e,"parentNode",n)},next:function(e){return P(e,"nextSibling")},prev:function(e){return P(e,"previousSibling")},nextAll:function(e){return E(e,"nextSibling")},prevAll:function(e){return E(e,"previousSibling")},nextUntil:function(e,t,n){return E(e,"nextSibling",n)},prevUntil:function(e,t,n){return E(e,"previousSibling",n)},siblings:function(e){return L((e.parentNode||{}).firstChild,e)},children:function(e){return L(e.firstChild)},contents:function(e){return null!=e.contentDocument&&a(e.contentDocument)?e.contentDocument:(T(e,"template")&&(e=e.content||e),A.merge([],e.childNodes))}},(function(e,t){A.fn[e]=function(n,r){var i=A.map(this,t,n);return"Until"!==e.slice(-5)&&(r=n),r&&"string"==typeof r&&(i=A.filter(r,i)),this.length>1&&(j[e]||A.uniqueSort(i),N.test(e)&&i.reverse()),this.pushStack(i)}}));var z=/[^\x20\t\r\n\f]+/g;function R(e){return e}function B(e){throw e}function H(e,t,n,r){var i;try{e&&v(i=e.promise)?i.call(e).done(t).fail(n):e&&v(i=e.then)?i.call(e,t,n):t.apply(void 0,[e].slice(r))}catch(e){n.apply(void 0,[e])}}A.Callbacks=function(e){e="string"==typeof e?function(e){var t={};return A.each(e.match(z)||[],(function(e,n){t[n]=!0})),t}(e):A.extend({},e);var t,n,r,i,o=[],a=[],s=-1,l=function(){for(i=i||e.once,r=t=!0;a.length;s=-1)for(n=a.shift();++s<o.length;)!1===o[s].apply(n[0],n[1])&&e.stopOnFalse&&(s=o.length,n=!1);e.memory||(n=!1),t=!1,i&&(o=n?[]:"")},c={add:function(){return o&&(n&&!t&&(s=o.length-1,a.push(n)),function t(n){A.each(n,(function(n,r){v(r)?e.unique&&c.has(r)||o.push(r):r&&r.length&&"string"!==w(r)&&t(r)}))}(arguments),n&&!t&&l()),this},remove:function(){return A.each(arguments,(function(e,t){for(var n;(n=A.inArray(t,o,n))>-1;)o.splice(n,1),n<=s&&s--})),this},has:function(e){return e?A.inArray(e,o)>-1:o.length>0},empty:function(){return o&&(o=[]),this},disable:function(){return i=a=[],o=n="",this},disabled:function(){return!o},lock:function(){return i=a=[],n||t||(o=n=""),this},locked:function(){return!!i},fireWith:function(e,n){return i||(n=[e,(n=n||[]).slice?n.slice():n],a.push(n),t||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!r}};return c},A.extend({Deferred:function(e){var t=[["notify","progress",A.Callbacks("memory"),A.Callbacks("memory"),2],["resolve","done",A.Callbacks("once memory"),A.Callbacks("once memory"),0,"resolved"],["reject","fail",A.Callbacks("once memory"),A.Callbacks("once memory"),1,"rejected"]],r="pending",i={state:function(){return r},always:function(){return o.done(arguments).fail(arguments),this},catch:function(e){return i.then(null,e)},pipe:function(){var e=arguments;return A.Deferred((function(n){A.each(t,(function(t,r){var i=v(e[r[4]])&&e[r[4]];o[r[1]]((function(){var e=i&&i.apply(this,arguments);e&&v(e.promise)?e.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,i?[e]:arguments)}))})),e=null})).promise()},then:function(e,r,i){var o=0;function a(e,t,r,i){return function(){var s=this,l=arguments,c=function(){var n,c;if(!(e<o)){if((n=r.apply(s,l))===t.promise())throw new TypeError("Thenable self-resolution");c=n&&("object"==typeof n||"function"==typeof n)&&n.then,v(c)?i?c.call(n,a(o,t,R,i),a(o,t,B,i)):(o++,c.call(n,a(o,t,R,i),a(o,t,B,i),a(o,t,R,t.notifyWith))):(r!==R&&(s=void 0,l=[n]),(i||t.resolveWith)(s,l))}},u=i?c:function(){try{c()}catch(n){A.Deferred.exceptionHook&&A.Deferred.exceptionHook(n,u.stackTrace),e+1>=o&&(r!==B&&(s=void 0,l=[n]),t.rejectWith(s,l))}};e?u():(A.Deferred.getStackHook&&(u.stackTrace=A.Deferred.getStackHook()),n.setTimeout(u))}}return A.Deferred((function(n){t[0][3].add(a(0,n,v(i)?i:R,n.notifyWith)),t[1][3].add(a(0,n,v(e)?e:R)),t[2][3].add(a(0,n,v(r)?r:B))})).promise()},promise:function(e){return null!=e?A.extend(e,i):i}},o={};return A.each(t,(function(e,n){var a=n[2],s=n[5];i[n[1]]=a.add,s&&a.add((function(){r=s}),t[3-e][2].disable,t[3-e][3].disable,t[0][2].lock,t[0][3].lock),a.add(n[3].fire),o[n[0]]=function(){return o[n[0]+"With"](this===o?void 0:this,arguments),this},o[n[0]+"With"]=a.fireWith})),i.promise(o),e&&e.call(o,o),o},when:function(e){var t=arguments.length,n=t,r=Array(n),i=s.call(arguments),o=A.Deferred(),a=function(e){return function(n){r[e]=this,i[e]=arguments.length>1?s.call(arguments):n,--t||o.resolveWith(r,i)}};if(t<=1&&(H(e,o.done(a(n)).resolve,o.reject,!t),"pending"===o.state()||v(i[n]&&i[n].then)))return o.then();for(;n--;)H(i[n],a(n),o.reject);return o.promise()}});var F=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;A.Deferred.exceptionHook=function(e,t){n.console&&n.console.warn&&e&&F.test(e.name)&&n.console.warn("jQuery.Deferred exception: "+e.message,e.stack,t)},A.readyException=function(e){n.setTimeout((function(){throw e}))};var Y=A.Deferred();function V(){_.removeEventListener("DOMContentLoaded",V),n.removeEventListener("load",V),A.ready()}A.fn.ready=function(e){return Y.then(e).catch((function(e){A.readyException(e)})),this},A.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--A.readyWait:A.isReady)||(A.isReady=!0,!0!==e&&--A.readyWait>0||Y.resolveWith(_,[A]))}}),A.ready.then=Y.then,"complete"===_.readyState||"loading"!==_.readyState&&!_.documentElement.doScroll?n.setTimeout(A.ready):(_.addEventListener("DOMContentLoaded",V),n.addEventListener("load",V));var U=function(e,t,n,r,i,o,a){var s=0,l=e.length,c=null==n;if("object"===w(n))for(s in i=!0,n)U(e,t,s,n[s],!0,o,a);else if(void 0!==r&&(i=!0,v(r)||(a=!0),c&&(a?(t.call(e,r),t=null):(c=t,t=function(e,t,n){return c.call(A(e),n)})),t))for(;s<l;s++)t(e[s],n,a?r:r.call(e[s],s,t(e[s],n)));return i?e:c?t.call(e):l?t(e[0],n):o},W=/^-ms-/,G=/-([a-z])/g;function q(e,t){return t.toUpperCase()}function K(e){return e.replace(W,"ms-").replace(G,q)}var X=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function J(){this.expando=A.expando+J.uid++}J.uid=1,J.prototype={cache:function(e){var t=e[this.expando];return t||(t={},X(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var r,i=this.cache(e);if("string"==typeof t)i[K(t)]=n;else for(r in t)i[K(r)]=t[r];return i},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][K(t)]},access:function(e,t,n){return void 0===t||t&&"string"==typeof t&&void 0===n?this.get(e,t):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,r=e[this.expando];if(void 0!==r){if(void 0!==t){n=(t=Array.isArray(t)?t.map(K):(t=K(t))in r?[t]:t.match(z)||[]).length;for(;n--;)delete r[t[n]]}(void 0===t||A.isEmptyObject(r))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!A.isEmptyObject(t)}};var Q=new J,Z=new J,$=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,ee=/[A-Z]/g;function te(e,t,n){var r;if(void 0===n&&1===e.nodeType)if(r="data-"+t.replace(ee,"-$&").toLowerCase(),"string"==typeof(n=e.getAttribute(r))){try{n=function(e){return"true"===e||"false"!==e&&("null"===e?null:e===+e+""?+e:$.test(e)?JSON.parse(e):e)}(n)}catch(e){}Z.set(e,t,n)}else n=void 0;return n}A.extend({hasData:function(e){return Z.hasData(e)||Q.hasData(e)},data:function(e,t,n){return Z.access(e,t,n)},removeData:function(e,t){Z.remove(e,t)},_data:function(e,t,n){return Q.access(e,t,n)},_removeData:function(e,t){Q.remove(e,t)}}),A.fn.extend({data:function(e,t){var n,r,i,o=this[0],a=o&&o.attributes;if(void 0===e){if(this.length&&(i=Z.get(o),1===o.nodeType&&!Q.get(o,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&0===(r=a[n].name).indexOf("data-")&&(r=K(r.slice(5)),te(o,r,i[r]));Q.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof e?this.each((function(){Z.set(this,e)})):U(this,(function(t){var n;if(o&&void 0===t)return void 0!==(n=Z.get(o,e))||void 0!==(n=te(o,e))?n:void 0;this.each((function(){Z.set(this,e,t)}))}),null,t,arguments.length>1,null,!0)},removeData:function(e){return this.each((function(){Z.remove(this,e)}))}}),A.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=Q.get(e,t),n&&(!r||Array.isArray(n)?r=Q.access(e,t,A.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=A.queue(e,t),r=n.length,i=n.shift(),o=A._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,(function(){A.dequeue(e,t)}),o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return Q.get(e,n)||Q.access(e,n,{empty:A.Callbacks("once memory").add((function(){Q.remove(e,[t+"queue",n])}))})}}),A.fn.extend({queue:function(e,t){var n=2;return"string"!=typeof e&&(t=e,e="fx",n--),arguments.length<n?A.queue(this[0],e):void 0===t?this:this.each((function(){var n=A.queue(this,e,t);A._queueHooks(this,e),"fx"===e&&"inprogress"!==n[0]&&A.dequeue(this,e)}))},dequeue:function(e){return this.each((function(){A.dequeue(this,e)}))},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=A.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";a--;)(n=Q.get(o[a],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(t)}});var ne=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,re=new RegExp("^(?:([+-])=|)("+ne+")([a-z%]*)$","i"),ie=["Top","Right","Bottom","Left"],oe=_.documentElement,ae=function(e){return A.contains(e.ownerDocument,e)},se={composed:!0};oe.getRootNode&&(ae=function(e){return A.contains(e.ownerDocument,e)||e.getRootNode(se)===e.ownerDocument});var le=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&ae(e)&&"none"===A.css(e,"display")};function ce(e,t,n,r){var i,o,a=20,s=r?function(){return r.cur()}:function(){return A.css(e,t,"")},l=s(),c=n&&n[3]||(A.cssNumber[t]?"":"px"),u=e.nodeType&&(A.cssNumber[t]||"px"!==c&&+l)&&re.exec(A.css(e,t));if(u&&u[3]!==c){for(l/=2,c=c||u[3],u=+l||1;a--;)A.style(e,t,u+c),(1-o)*(1-(o=s()/l||.5))<=0&&(a=0),u/=o;u*=2,A.style(e,t,u+c),n=n||[]}return n&&(u=+u||+l||0,i=n[1]?u+(n[1]+1)*n[2]:+n[2],r&&(r.unit=c,r.start=u,r.end=i)),i}var ue={};function de(e){var t,n=e.ownerDocument,r=e.nodeName,i=ue[r];return i||(t=n.body.appendChild(n.createElement(r)),i=A.css(t,"display"),t.parentNode.removeChild(t),"none"===i&&(i="block"),ue[r]=i,i)}function he(e,t){for(var n,r,i=[],o=0,a=e.length;o<a;o++)(r=e[o]).style&&(n=r.style.display,t?("none"===n&&(i[o]=Q.get(r,"display")||null,i[o]||(r.style.display="")),""===r.style.display&&le(r)&&(i[o]=de(r))):"none"!==n&&(i[o]="none",Q.set(r,"display",n)));for(o=0;o<a;o++)null!=i[o]&&(e[o].style.display=i[o]);return e}A.fn.extend({show:function(){return he(this,!0)},hide:function(){return he(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each((function(){le(this)?A(this).show():A(this).hide()}))}});var pe,fe,me=/^(?:checkbox|radio)$/i,ge=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,ve=/^$|^module$|\/(?:java|ecma)script/i;pe=_.createDocumentFragment().appendChild(_.createElement("div")),(fe=_.createElement("input")).setAttribute("type","radio"),fe.setAttribute("checked","checked"),fe.setAttribute("name","t"),pe.appendChild(fe),g.checkClone=pe.cloneNode(!0).cloneNode(!0).lastChild.checked,pe.innerHTML="<textarea>x</textarea>",g.noCloneChecked=!!pe.cloneNode(!0).lastChild.defaultValue,pe.innerHTML="<option></option>",g.option=!!pe.lastChild;var ye={thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function _e(e,t){var n;return n=void 0!==e.getElementsByTagName?e.getElementsByTagName(t||"*"):void 0!==e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&T(e,t)?A.merge([e],n):n}function be(e,t){for(var n=0,r=e.length;n<r;n++)Q.set(e[n],"globalEval",!t||Q.get(t[n],"globalEval"))}ye.tbody=ye.tfoot=ye.colgroup=ye.caption=ye.thead,ye.th=ye.td,g.option||(ye.optgroup=ye.option=[1,"<select multiple='multiple'>","</select>"]);var Me=/<|&#?\w+;/;function we(e,t,n,r,i){for(var o,a,s,l,c,u,d=t.createDocumentFragment(),h=[],p=0,f=e.length;p<f;p++)if((o=e[p])||0===o)if("object"===w(o))A.merge(h,o.nodeType?[o]:o);else if(Me.test(o)){for(a=a||d.appendChild(t.createElement("div")),s=(ge.exec(o)||["",""])[1].toLowerCase(),l=ye[s]||ye._default,a.innerHTML=l[1]+A.htmlPrefilter(o)+l[2],u=l[0];u--;)a=a.lastChild;A.merge(h,a.childNodes),(a=d.firstChild).textContent=""}else h.push(t.createTextNode(o));for(d.textContent="",p=0;o=h[p++];)if(r&&A.inArray(o,r)>-1)i&&i.push(o);else if(c=ae(o),a=_e(d.appendChild(o),"script"),c&&be(a),n)for(u=0;o=a[u++];)ve.test(o.type||"")&&n.push(o);return d}var Ae=/^([^.]*)(?:\.(.+)|)/;function Ce(){return!0}function xe(){return!1}function Ee(e,t){return e===function(){try{return _.activeElement}catch(e){}}()==("focus"===t)}function Le(e,t,n,r,i,o){var a,s;if("object"==typeof t){for(s in"string"!=typeof n&&(r=r||n,n=void 0),t)Le(e,s,n,r,t[s],o);return e}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=xe;else if(!i)return e;return 1===o&&(a=i,(i=function(e){return A().off(e),a.apply(this,arguments)}).guid=a.guid||(a.guid=A.guid++)),e.each((function(){A.event.add(this,t,i,r,n)}))}function Se(e,t,n){n?(Q.set(e,t,!1),A.event.add(e,t,{namespace:!1,handler:function(e){var r,i,o=Q.get(this,t);if(1&e.isTrigger&&this[t]){if(o.length)(A.event.special[t]||{}).delegateType&&e.stopPropagation();else if(o=s.call(arguments),Q.set(this,t,o),r=n(this,t),this[t](),o!==(i=Q.get(this,t))||r?Q.set(this,t,!1):i={},o!==i)return e.stopImmediatePropagation(),e.preventDefault(),i&&i.value}else o.length&&(Q.set(this,t,{value:A.event.trigger(A.extend(o[0],A.Event.prototype),o.slice(1),this)}),e.stopImmediatePropagation())}})):void 0===Q.get(e,t)&&A.event.add(e,t,Ce)}A.event={global:{},add:function(e,t,n,r,i){var o,a,s,l,c,u,d,h,p,f,m,g=Q.get(e);if(X(e))for(n.handler&&(n=(o=n).handler,i=o.selector),i&&A.find.matchesSelector(oe,i),n.guid||(n.guid=A.guid++),(l=g.events)||(l=g.events=Object.create(null)),(a=g.handle)||(a=g.handle=function(t){return void 0!==A&&A.event.triggered!==t.type?A.event.dispatch.apply(e,arguments):void 0}),c=(t=(t||"").match(z)||[""]).length;c--;)p=m=(s=Ae.exec(t[c])||[])[1],f=(s[2]||"").split(".").sort(),p&&(d=A.event.special[p]||{},p=(i?d.delegateType:d.bindType)||p,d=A.event.special[p]||{},u=A.extend({type:p,origType:m,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&A.expr.match.needsContext.test(i),namespace:f.join(".")},o),(h=l[p])||((h=l[p]=[]).delegateCount=0,d.setup&&!1!==d.setup.call(e,r,f,a)||e.addEventListener&&e.addEventListener(p,a)),d.add&&(d.add.call(e,u),u.handler.guid||(u.handler.guid=n.guid)),i?h.splice(h.delegateCount++,0,u):h.push(u),A.event.global[p]=!0)},remove:function(e,t,n,r,i){var o,a,s,l,c,u,d,h,p,f,m,g=Q.hasData(e)&&Q.get(e);if(g&&(l=g.events)){for(c=(t=(t||"").match(z)||[""]).length;c--;)if(p=m=(s=Ae.exec(t[c])||[])[1],f=(s[2]||"").split(".").sort(),p){for(d=A.event.special[p]||{},h=l[p=(r?d.delegateType:d.bindType)||p]||[],s=s[2]&&new RegExp("(^|\\.)"+f.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=h.length;o--;)u=h[o],!i&&m!==u.origType||n&&n.guid!==u.guid||s&&!s.test(u.namespace)||r&&r!==u.selector&&("**"!==r||!u.selector)||(h.splice(o,1),u.selector&&h.delegateCount--,d.remove&&d.remove.call(e,u));a&&!h.length&&(d.teardown&&!1!==d.teardown.call(e,f,g.handle)||A.removeEvent(e,p,g.handle),delete l[p])}else for(p in l)A.event.remove(e,p+t[c],n,r,!0);A.isEmptyObject(l)&&Q.remove(e,"handle events")}},dispatch:function(e){var t,n,r,i,o,a,s=new Array(arguments.length),l=A.event.fix(e),c=(Q.get(this,"events")||Object.create(null))[l.type]||[],u=A.event.special[l.type]||{};for(s[0]=l,t=1;t<arguments.length;t++)s[t]=arguments[t];if(l.delegateTarget=this,!u.preDispatch||!1!==u.preDispatch.call(this,l)){for(a=A.event.handlers.call(this,l,c),t=0;(i=a[t++])&&!l.isPropagationStopped();)for(l.currentTarget=i.elem,n=0;(o=i.handlers[n++])&&!l.isImmediatePropagationStopped();)l.rnamespace&&!1!==o.namespace&&!l.rnamespace.test(o.namespace)||(l.handleObj=o,l.data=o.data,void 0!==(r=((A.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,s))&&!1===(l.result=r)&&(l.preventDefault(),l.stopPropagation()));return u.postDispatch&&u.postDispatch.call(this,l),l.result}},handlers:function(e,t){var n,r,i,o,a,s=[],l=t.delegateCount,c=e.target;if(l&&c.nodeType&&!("click"===e.type&&e.button>=1))for(;c!==this;c=c.parentNode||this)if(1===c.nodeType&&("click"!==e.type||!0!==c.disabled)){for(o=[],a={},n=0;n<l;n++)void 0===a[i=(r=t[n]).selector+" "]&&(a[i]=r.needsContext?A(i,this).index(c)>-1:A.find(i,this,null,[c]).length),a[i]&&o.push(r);o.length&&s.push({elem:c,handlers:o})}return c=this,l<t.length&&s.push({elem:c,handlers:t.slice(l)}),s},addProp:function(e,t){Object.defineProperty(A.Event.prototype,e,{enumerable:!0,configurable:!0,get:v(t)?function(){if(this.originalEvent)return t(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[e]},set:function(t){Object.defineProperty(this,e,{enumerable:!0,configurable:!0,writable:!0,value:t})}})},fix:function(e){return e[A.expando]?e:new A.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return me.test(t.type)&&t.click&&T(t,"input")&&Se(t,"click",Ce),!1},trigger:function(e){var t=this||e;return me.test(t.type)&&t.click&&T(t,"input")&&Se(t,"click"),!0},_default:function(e){var t=e.target;return me.test(t.type)&&t.click&&T(t,"input")&&Q.get(t,"click")||T(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},A.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},A.Event=function(e,t){if(!(this instanceof A.Event))return new A.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?Ce:xe,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&A.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[A.expando]=!0},A.Event.prototype={constructor:A.Event,isDefaultPrevented:xe,isPropagationStopped:xe,isImmediatePropagationStopped:xe,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=Ce,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=Ce,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=Ce,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},A.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:!0},A.event.addProp),A.each({focus:"focusin",blur:"focusout"},(function(e,t){A.event.special[e]={setup:function(){return Se(this,e,Ee),!1},trigger:function(){return Se(this,e),!0},_default:function(){return!0},delegateType:t}})),A.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},(function(e,t){A.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,o=e.handleObj;return i&&(i===r||A.contains(r,i))||(e.type=o.origType,n=o.handler.apply(this,arguments),e.type=t),n}}})),A.fn.extend({on:function(e,t,n,r){return Le(this,e,t,n,r)},one:function(e,t,n,r){return Le(this,e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,A(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=xe),this.each((function(){A.event.remove(this,e,n,t)}))}});var Te=/<script|<style|<link/i,Oe=/checked\s*(?:[^=]|=\s*.checked.)/i,Ie=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function ke(e,t){return T(e,"table")&&T(11!==t.nodeType?t:t.firstChild,"tr")&&A(e).children("tbody")[0]||e}function De(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function Ne(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function je(e,t){var n,r,i,o,a,s;if(1===t.nodeType){if(Q.hasData(e)&&(s=Q.get(e).events))for(i in Q.remove(t,"handle events"),s)for(n=0,r=s[i].length;n<r;n++)A.event.add(t,i,s[i][n]);Z.hasData(e)&&(o=Z.access(e),a=A.extend({},o),Z.set(t,a))}}function Pe(e,t){var n=t.nodeName.toLowerCase();"input"===n&&me.test(e.type)?t.checked=e.checked:"input"!==n&&"textarea"!==n||(t.defaultValue=e.defaultValue)}function ze(e,t,n,r){t=l(t);var i,o,a,s,c,u,d=0,h=e.length,p=h-1,f=t[0],m=v(f);if(m||h>1&&"string"==typeof f&&!g.checkClone&&Oe.test(f))return e.each((function(i){var o=e.eq(i);m&&(t[0]=f.call(this,i,o.html())),ze(o,t,n,r)}));if(h&&(o=(i=we(t,e[0].ownerDocument,!1,e,r)).firstChild,1===i.childNodes.length&&(i=o),o||r)){for(s=(a=A.map(_e(i,"script"),De)).length;d<h;d++)c=i,d!==p&&(c=A.clone(c,!0,!0),s&&A.merge(a,_e(c,"script"))),n.call(e[d],c,d);if(s)for(u=a[a.length-1].ownerDocument,A.map(a,Ne),d=0;d<s;d++)c=a[d],ve.test(c.type||"")&&!Q.access(c,"globalEval")&&A.contains(u,c)&&(c.src&&"module"!==(c.type||"").toLowerCase()?A._evalUrl&&!c.noModule&&A._evalUrl(c.src,{nonce:c.nonce||c.getAttribute("nonce")},u):M(c.textContent.replace(Ie,""),c,u))}return e}function Re(e,t,n){for(var r,i=t?A.filter(t,e):e,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||A.cleanData(_e(r)),r.parentNode&&(n&&ae(r)&&be(_e(r,"script")),r.parentNode.removeChild(r));return e}A.extend({htmlPrefilter:function(e){return e},clone:function(e,t,n){var r,i,o,a,s=e.cloneNode(!0),l=ae(e);if(!(g.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||A.isXMLDoc(e)))for(a=_e(s),r=0,i=(o=_e(e)).length;r<i;r++)Pe(o[r],a[r]);if(t)if(n)for(o=o||_e(e),a=a||_e(s),r=0,i=o.length;r<i;r++)je(o[r],a[r]);else je(e,s);return(a=_e(s,"script")).length>0&&be(a,!l&&_e(e,"script")),s},cleanData:function(e){for(var t,n,r,i=A.event.special,o=0;void 0!==(n=e[o]);o++)if(X(n)){if(t=n[Q.expando]){if(t.events)for(r in t.events)i[r]?A.event.remove(n,r):A.removeEvent(n,r,t.handle);n[Q.expando]=void 0}n[Z.expando]&&(n[Z.expando]=void 0)}}}),A.fn.extend({detach:function(e){return Re(this,e,!0)},remove:function(e){return Re(this,e)},text:function(e){return U(this,(function(e){return void 0===e?A.text(this):this.empty().each((function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)}))}),null,e,arguments.length)},append:function(){return ze(this,arguments,(function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||ke(this,e).appendChild(e)}))},prepend:function(){return ze(this,arguments,(function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=ke(this,e);t.insertBefore(e,t.firstChild)}}))},before:function(){return ze(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this)}))},after:function(){return ze(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)}))},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(A.cleanData(_e(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map((function(){return A.clone(this,e,t)}))},html:function(e){return U(this,(function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!Te.test(e)&&!ye[(ge.exec(e)||["",""])[1].toLowerCase()]){e=A.htmlPrefilter(e);try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(A.cleanData(_e(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)}),null,e,arguments.length)},replaceWith:function(){var e=[];return ze(this,arguments,(function(t){var n=this.parentNode;A.inArray(this,e)<0&&(A.cleanData(_e(this)),n&&n.replaceChild(t,this))}),e)}}),A.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},(function(e,t){A.fn[e]=function(e){for(var n,r=[],i=A(e),o=i.length-1,a=0;a<=o;a++)n=a===o?this:this.clone(!0),A(i[a])[t](n),c.apply(r,n.get());return this.pushStack(r)}}));var Be=new RegExp("^("+ne+")(?!px)[a-z%]+$","i"),He=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=n),t.getComputedStyle(e)},Fe=function(e,t,n){var r,i,o={};for(i in t)o[i]=e.style[i],e.style[i]=t[i];for(i in r=n.call(e),t)e.style[i]=o[i];return r},Ye=new RegExp(ie.join("|"),"i");function Ve(e,t,n){var r,i,o,a,s=e.style;return(n=n||He(e))&&(""!==(a=n.getPropertyValue(t)||n[t])||ae(e)||(a=A.style(e,t)),!g.pixelBoxStyles()&&Be.test(a)&&Ye.test(t)&&(r=s.width,i=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=i,s.maxWidth=o)),void 0!==a?a+"":a}function Ue(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function e(){if(u){c.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",u.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",oe.appendChild(c).appendChild(u);var e=n.getComputedStyle(u);r="1%"!==e.top,l=12===t(e.marginLeft),u.style.right="60%",a=36===t(e.right),i=36===t(e.width),u.style.position="absolute",o=12===t(u.offsetWidth/3),oe.removeChild(c),u=null}}function t(e){return Math.round(parseFloat(e))}var r,i,o,a,s,l,c=_.createElement("div"),u=_.createElement("div");u.style&&(u.style.backgroundClip="content-box",u.cloneNode(!0).style.backgroundClip="",g.clearCloneStyle="content-box"===u.style.backgroundClip,A.extend(g,{boxSizingReliable:function(){return e(),i},pixelBoxStyles:function(){return e(),a},pixelPosition:function(){return e(),r},reliableMarginLeft:function(){return e(),l},scrollboxSize:function(){return e(),o},reliableTrDimensions:function(){var e,t,r,i;return null==s&&(e=_.createElement("table"),t=_.createElement("tr"),r=_.createElement("div"),e.style.cssText="position:absolute;left:-11111px;border-collapse:separate",t.style.cssText="border:1px solid",t.style.height="1px",r.style.height="9px",r.style.display="block",oe.appendChild(e).appendChild(t).appendChild(r),i=n.getComputedStyle(t),s=parseInt(i.height,10)+parseInt(i.borderTopWidth,10)+parseInt(i.borderBottomWidth,10)===t.offsetHeight,oe.removeChild(e)),s}}))}();var We=["Webkit","Moz","ms"],Ge=_.createElement("div").style,qe={};function Ke(e){var t=A.cssProps[e]||qe[e];return t||(e in Ge?e:qe[e]=function(e){for(var t=e[0].toUpperCase()+e.slice(1),n=We.length;n--;)if((e=We[n]+t)in Ge)return e}(e)||e)}var Xe=/^(none|table(?!-c[ea]).+)/,Je=/^--/,Qe={position:"absolute",visibility:"hidden",display:"block"},Ze={letterSpacing:"0",fontWeight:"400"};function $e(e,t,n){var r=re.exec(t);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):t}function et(e,t,n,r,i,o){var a="width"===t?1:0,s=0,l=0;if(n===(r?"border":"content"))return 0;for(;a<4;a+=2)"margin"===n&&(l+=A.css(e,n+ie[a],!0,i)),r?("content"===n&&(l-=A.css(e,"padding"+ie[a],!0,i)),"margin"!==n&&(l-=A.css(e,"border"+ie[a]+"Width",!0,i))):(l+=A.css(e,"padding"+ie[a],!0,i),"padding"!==n?l+=A.css(e,"border"+ie[a]+"Width",!0,i):s+=A.css(e,"border"+ie[a]+"Width",!0,i));return!r&&o>=0&&(l+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-o-l-s-.5))||0),l}function tt(e,t,n){var r=He(e),i=(!g.boxSizingReliable()||n)&&"border-box"===A.css(e,"boxSizing",!1,r),o=i,a=Ve(e,t,r),s="offset"+t[0].toUpperCase()+t.slice(1);if(Be.test(a)){if(!n)return a;a="auto"}return(!g.boxSizingReliable()&&i||!g.reliableTrDimensions()&&T(e,"tr")||"auto"===a||!parseFloat(a)&&"inline"===A.css(e,"display",!1,r))&&e.getClientRects().length&&(i="border-box"===A.css(e,"boxSizing",!1,r),(o=s in e)&&(a=e[s])),(a=parseFloat(a)||0)+et(e,t,n||(i?"border":"content"),o,r,a)+"px"}function nt(e,t,n,r,i){return new nt.prototype.init(e,t,n,r,i)}A.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=Ve(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,a,s=K(t),l=Je.test(t),c=e.style;if(l||(t=Ke(s)),a=A.cssHooks[t]||A.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(e,!1,r))?i:c[t];"string"===(o=typeof n)&&(i=re.exec(n))&&i[1]&&(n=ce(e,t,i),o="number"),null!=n&&n==n&&("number"!==o||l||(n+=i&&i[3]||(A.cssNumber[s]?"":"px")),g.clearCloneStyle||""!==n||0!==t.indexOf("background")||(c[t]="inherit"),a&&"set"in a&&void 0===(n=a.set(e,n,r))||(l?c.setProperty(t,n):c[t]=n))}},css:function(e,t,n,r){var i,o,a,s=K(t);return Je.test(t)||(t=Ke(s)),(a=A.cssHooks[t]||A.cssHooks[s])&&"get"in a&&(i=a.get(e,!0,n)),void 0===i&&(i=Ve(e,t,r)),"normal"===i&&t in Ze&&(i=Ze[t]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),A.each(["height","width"],(function(e,t){A.cssHooks[t]={get:function(e,n,r){if(n)return!Xe.test(A.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?tt(e,t,r):Fe(e,Qe,(function(){return tt(e,t,r)}))},set:function(e,n,r){var i,o=He(e),a=!g.scrollboxSize()&&"absolute"===o.position,s=(a||r)&&"border-box"===A.css(e,"boxSizing",!1,o),l=r?et(e,t,r,s,o):0;return s&&a&&(l-=Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-parseFloat(o[t])-et(e,t,"border",!1,o)-.5)),l&&(i=re.exec(n))&&"px"!==(i[3]||"px")&&(e.style[t]=n,n=A.css(e,t)),$e(0,n,l)}}})),A.cssHooks.marginLeft=Ue(g.reliableMarginLeft,(function(e,t){if(t)return(parseFloat(Ve(e,"marginLeft"))||e.getBoundingClientRect().left-Fe(e,{marginLeft:0},(function(){return e.getBoundingClientRect().left})))+"px"})),A.each({margin:"",padding:"",border:"Width"},(function(e,t){A.cssHooks[e+t]={expand:function(n){for(var r=0,i={},o="string"==typeof n?n.split(" "):[n];r<4;r++)i[e+ie[r]+t]=o[r]||o[r-2]||o[0];return i}},"margin"!==e&&(A.cssHooks[e+t].set=$e)})),A.fn.extend({css:function(e,t){return U(this,(function(e,t,n){var r,i,o={},a=0;if(Array.isArray(t)){for(r=He(e),i=t.length;a<i;a++)o[t[a]]=A.css(e,t[a],!1,r);return o}return void 0!==n?A.style(e,t,n):A.css(e,t)}),e,t,arguments.length>1)}}),A.Tween=nt,nt.prototype={constructor:nt,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||A.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(A.cssNumber[n]?"":"px")},cur:function(){var e=nt.propHooks[this.prop];return e&&e.get?e.get(this):nt.propHooks._default.get(this)},run:function(e){var t,n=nt.propHooks[this.prop];return this.options.duration?this.pos=t=A.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):nt.propHooks._default.set(this),this}},nt.prototype.init.prototype=nt.prototype,nt.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=A.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){A.fx.step[e.prop]?A.fx.step[e.prop](e):1!==e.elem.nodeType||!A.cssHooks[e.prop]&&null==e.elem.style[Ke(e.prop)]?e.elem[e.prop]=e.now:A.style(e.elem,e.prop,e.now+e.unit)}}},nt.propHooks.scrollTop=nt.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},A.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},A.fx=nt.prototype.init,A.fx.step={};var rt,it,ot=/^(?:toggle|show|hide)$/,at=/queueHooks$/;function st(){it&&(!1===_.hidden&&n.requestAnimationFrame?n.requestAnimationFrame(st):n.setTimeout(st,A.fx.interval),A.fx.tick())}function lt(){return n.setTimeout((function(){rt=void 0})),rt=Date.now()}function ct(e,t){var n,r=0,i={height:e};for(t=t?1:0;r<4;r+=2-t)i["margin"+(n=ie[r])]=i["padding"+n]=e;return t&&(i.opacity=i.width=e),i}function ut(e,t,n){for(var r,i=(dt.tweeners[t]||[]).concat(dt.tweeners["*"]),o=0,a=i.length;o<a;o++)if(r=i[o].call(n,t,e))return r}function dt(e,t,n){var r,i,o=0,a=dt.prefilters.length,s=A.Deferred().always((function(){delete l.elem})),l=function(){if(i)return!1;for(var t=rt||lt(),n=Math.max(0,c.startTime+c.duration-t),r=1-(n/c.duration||0),o=0,a=c.tweens.length;o<a;o++)c.tweens[o].run(r);return s.notifyWith(e,[c,r,n]),r<1&&a?n:(a||s.notifyWith(e,[c,1,0]),s.resolveWith(e,[c]),!1)},c=s.promise({elem:e,props:A.extend({},t),opts:A.extend(!0,{specialEasing:{},easing:A.easing._default},n),originalProperties:t,originalOptions:n,startTime:rt||lt(),duration:n.duration,tweens:[],createTween:function(t,n){var r=A.Tween(e,c.opts,t,n,c.opts.specialEasing[t]||c.opts.easing);return c.tweens.push(r),r},stop:function(t){var n=0,r=t?c.tweens.length:0;if(i)return this;for(i=!0;n<r;n++)c.tweens[n].run(1);return t?(s.notifyWith(e,[c,1,0]),s.resolveWith(e,[c,t])):s.rejectWith(e,[c,t]),this}}),u=c.props;for(!function(e,t){var n,r,i,o,a;for(n in e)if(i=t[r=K(n)],o=e[n],Array.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(a=A.cssHooks[r])&&"expand"in a)for(n in o=a.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(u,c.opts.specialEasing);o<a;o++)if(r=dt.prefilters[o].call(c,e,u,c.opts))return v(r.stop)&&(A._queueHooks(c.elem,c.opts.queue).stop=r.stop.bind(r)),r;return A.map(u,ut,c),v(c.opts.start)&&c.opts.start.call(e,c),c.progress(c.opts.progress).done(c.opts.done,c.opts.complete).fail(c.opts.fail).always(c.opts.always),A.fx.timer(A.extend(l,{elem:e,anim:c,queue:c.opts.queue})),c}A.Animation=A.extend(dt,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return ce(n.elem,e,re.exec(t),n),n}]},tweener:function(e,t){v(e)?(t=e,e=["*"]):e=e.match(z);for(var n,r=0,i=e.length;r<i;r++)n=e[r],dt.tweeners[n]=dt.tweeners[n]||[],dt.tweeners[n].unshift(t)},prefilters:[function(e,t,n){var r,i,o,a,s,l,c,u,d="width"in t||"height"in t,h=this,p={},f=e.style,m=e.nodeType&&le(e),g=Q.get(e,"fxshow");for(r in n.queue||(null==(a=A._queueHooks(e,"fx")).unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,h.always((function(){h.always((function(){a.unqueued--,A.queue(e,"fx").length||a.empty.fire()}))}))),t)if(i=t[r],ot.test(i)){if(delete t[r],o=o||"toggle"===i,i===(m?"hide":"show")){if("show"!==i||!g||void 0===g[r])continue;m=!0}p[r]=g&&g[r]||A.style(e,r)}if((l=!A.isEmptyObject(t))||!A.isEmptyObject(p))for(r in d&&1===e.nodeType&&(n.overflow=[f.overflow,f.overflowX,f.overflowY],null==(c=g&&g.display)&&(c=Q.get(e,"display")),"none"===(u=A.css(e,"display"))&&(c?u=c:(he([e],!0),c=e.style.display||c,u=A.css(e,"display"),he([e]))),("inline"===u||"inline-block"===u&&null!=c)&&"none"===A.css(e,"float")&&(l||(h.done((function(){f.display=c})),null==c&&(u=f.display,c="none"===u?"":u)),f.display="inline-block")),n.overflow&&(f.overflow="hidden",h.always((function(){f.overflow=n.overflow[0],f.overflowX=n.overflow[1],f.overflowY=n.overflow[2]}))),l=!1,p)l||(g?"hidden"in g&&(m=g.hidden):g=Q.access(e,"fxshow",{display:c}),o&&(g.hidden=!m),m&&he([e],!0),h.done((function(){for(r in m||he([e]),Q.remove(e,"fxshow"),p)A.style(e,r,p[r])}))),l=ut(m?g[r]:0,r,h),r in g||(g[r]=l.start,m&&(l.end=l.start,l.start=0))}],prefilter:function(e,t){t?dt.prefilters.unshift(e):dt.prefilters.push(e)}}),A.speed=function(e,t,n){var r=e&&"object"==typeof e?A.extend({},e):{complete:n||!n&&t||v(e)&&e,duration:e,easing:n&&t||t&&!v(t)&&t};return A.fx.off?r.duration=0:"number"!=typeof r.duration&&(r.duration in A.fx.speeds?r.duration=A.fx.speeds[r.duration]:r.duration=A.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){v(r.old)&&r.old.call(this),r.queue&&A.dequeue(this,r.queue)},r},A.fn.extend({fadeTo:function(e,t,n,r){return this.filter(le).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=A.isEmptyObject(e),o=A.speed(t,n,r),a=function(){var t=dt(this,A.extend({},e),o);(i||Q.get(this,"finish"))&&t.stop(!0)};return a.finish=a,i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(e,t,n){var r=function(e){var t=e.stop;delete e.stop,t(n)};return"string"!=typeof e&&(n=t,t=e,e=void 0),t&&this.queue(e||"fx",[]),this.each((function(){var t=!0,i=null!=e&&e+"queueHooks",o=A.timers,a=Q.get(this);if(i)a[i]&&a[i].stop&&r(a[i]);else for(i in a)a[i]&&a[i].stop&&at.test(i)&&r(a[i]);for(i=o.length;i--;)o[i].elem!==this||null!=e&&o[i].queue!==e||(o[i].anim.stop(n),t=!1,o.splice(i,1));!t&&n||A.dequeue(this,e)}))},finish:function(e){return!1!==e&&(e=e||"fx"),this.each((function(){var t,n=Q.get(this),r=n[e+"queue"],i=n[e+"queueHooks"],o=A.timers,a=r?r.length:0;for(n.finish=!0,A.queue(this,e,[]),i&&i.stop&&i.stop.call(this,!0),t=o.length;t--;)o[t].elem===this&&o[t].queue===e&&(o[t].anim.stop(!0),o.splice(t,1));for(t=0;t<a;t++)r[t]&&r[t].finish&&r[t].finish.call(this);delete n.finish}))}}),A.each(["toggle","show","hide"],(function(e,t){var n=A.fn[t];A.fn[t]=function(e,r,i){return null==e||"boolean"==typeof e?n.apply(this,arguments):this.animate(ct(t,!0),e,r,i)}})),A.each({slideDown:ct("show"),slideUp:ct("hide"),slideToggle:ct("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},(function(e,t){A.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}})),A.timers=[],A.fx.tick=function(){var e,t=0,n=A.timers;for(rt=Date.now();t<n.length;t++)(e=n[t])()||n[t]!==e||n.splice(t--,1);n.length||A.fx.stop(),rt=void 0},A.fx.timer=function(e){A.timers.push(e),A.fx.start()},A.fx.interval=13,A.fx.start=function(){it||(it=!0,st())},A.fx.stop=function(){it=null},A.fx.speeds={slow:600,fast:200,_default:400},A.fn.delay=function(e,t){return e=A.fx&&A.fx.speeds[e]||e,t=t||"fx",this.queue(t,(function(t,r){var i=n.setTimeout(t,e);r.stop=function(){n.clearTimeout(i)}}))},function(){var e=_.createElement("input"),t=_.createElement("select").appendChild(_.createElement("option"));e.type="checkbox",g.checkOn=""!==e.value,g.optSelected=t.selected,(e=_.createElement("input")).value="t",e.type="radio",g.radioValue="t"===e.value}();var ht,pt=A.expr.attrHandle;A.fn.extend({attr:function(e,t){return U(this,A.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each((function(){A.removeAttr(this,e)}))}}),A.extend({attr:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return void 0===e.getAttribute?A.prop(e,t,n):(1===o&&A.isXMLDoc(e)||(i=A.attrHooks[t.toLowerCase()]||(A.expr.match.bool.test(t)?ht:void 0)),void 0!==n?null===n?void A.removeAttr(e,t):i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:(e.setAttribute(t,n+""),n):i&&"get"in i&&null!==(r=i.get(e,t))?r:null==(r=A.find.attr(e,t))?void 0:r)},attrHooks:{type:{set:function(e,t){if(!g.radioValue&&"radio"===t&&T(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,r=0,i=t&&t.match(z);if(i&&1===e.nodeType)for(;n=i[r++];)e.removeAttribute(n)}}),ht={set:function(e,t,n){return!1===t?A.removeAttr(e,n):e.setAttribute(n,n),n}},A.each(A.expr.match.bool.source.match(/\w+/g),(function(e,t){var n=pt[t]||A.find.attr;pt[t]=function(e,t,r){var i,o,a=t.toLowerCase();return r||(o=pt[a],pt[a]=i,i=null!=n(e,t,r)?a:null,pt[a]=o),i}}));var ft=/^(?:input|select|textarea|button)$/i,mt=/^(?:a|area)$/i;function gt(e){return(e.match(z)||[]).join(" ")}function vt(e){return e.getAttribute&&e.getAttribute("class")||""}function yt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(z)||[]}A.fn.extend({prop:function(e,t){return U(this,A.prop,e,t,arguments.length>1)},removeProp:function(e){return this.each((function(){delete this[A.propFix[e]||e]}))}}),A.extend({prop:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&A.isXMLDoc(e)||(t=A.propFix[t]||t,i=A.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=A.find.attr(e,"tabindex");return t?parseInt(t,10):ft.test(e.nodeName)||mt.test(e.nodeName)&&e.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),g.optSelected||(A.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),A.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],(function(){A.propFix[this.toLowerCase()]=this})),A.fn.extend({addClass:function(e){var t,n,r,i,o,a,s,l=0;if(v(e))return this.each((function(t){A(this).addClass(e.call(this,t,vt(this)))}));if((t=yt(e)).length)for(;n=this[l++];)if(i=vt(n),r=1===n.nodeType&&" "+gt(i)+" "){for(a=0;o=t[a++];)r.indexOf(" "+o+" ")<0&&(r+=o+" ");i!==(s=gt(r))&&n.setAttribute("class",s)}return this},removeClass:function(e){var t,n,r,i,o,a,s,l=0;if(v(e))return this.each((function(t){A(this).removeClass(e.call(this,t,vt(this)))}));if(!arguments.length)return this.attr("class","");if((t=yt(e)).length)for(;n=this[l++];)if(i=vt(n),r=1===n.nodeType&&" "+gt(i)+" "){for(a=0;o=t[a++];)for(;r.indexOf(" "+o+" ")>-1;)r=r.replace(" "+o+" "," ");i!==(s=gt(r))&&n.setAttribute("class",s)}return this},toggleClass:function(e,t){var n=typeof e,r="string"===n||Array.isArray(e);return"boolean"==typeof t&&r?t?this.addClass(e):this.removeClass(e):v(e)?this.each((function(n){A(this).toggleClass(e.call(this,n,vt(this),t),t)})):this.each((function(){var t,i,o,a;if(r)for(i=0,o=A(this),a=yt(e);t=a[i++];)o.hasClass(t)?o.removeClass(t):o.addClass(t);else void 0!==e&&"boolean"!==n||((t=vt(this))&&Q.set(this,"__className__",t),this.setAttribute&&this.setAttribute("class",t||!1===e?"":Q.get(this,"__className__")||""))}))},hasClass:function(e){var t,n,r=0;for(t=" "+e+" ";n=this[r++];)if(1===n.nodeType&&(" "+gt(vt(n))+" ").indexOf(t)>-1)return!0;return!1}});var _t=/\r/g;A.fn.extend({val:function(e){var t,n,r,i=this[0];return arguments.length?(r=v(e),this.each((function(n){var i;1===this.nodeType&&(null==(i=r?e.call(this,n,A(this).val()):e)?i="":"number"==typeof i?i+="":Array.isArray(i)&&(i=A.map(i,(function(e){return null==e?"":e+""}))),(t=A.valHooks[this.type]||A.valHooks[this.nodeName.toLowerCase()])&&"set"in t&&void 0!==t.set(this,i,"value")||(this.value=i))}))):i?(t=A.valHooks[i.type]||A.valHooks[i.nodeName.toLowerCase()])&&"get"in t&&void 0!==(n=t.get(i,"value"))?n:"string"==typeof(n=i.value)?n.replace(_t,""):null==n?"":n:void 0}}),A.extend({valHooks:{option:{get:function(e){var t=A.find.attr(e,"value");return null!=t?t:gt(A.text(e))}},select:{get:function(e){var t,n,r,i=e.options,o=e.selectedIndex,a="select-one"===e.type,s=a?null:[],l=a?o+1:i.length;for(r=o<0?l:a?o:0;r<l;r++)if(((n=i[r]).selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!T(n.parentNode,"optgroup"))){if(t=A(n).val(),a)return t;s.push(t)}return s},set:function(e,t){for(var n,r,i=e.options,o=A.makeArray(t),a=i.length;a--;)((r=i[a]).selected=A.inArray(A.valHooks.option.get(r),o)>-1)&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),A.each(["radio","checkbox"],(function(){A.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=A.inArray(A(e).val(),t)>-1}},g.checkOn||(A.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})})),g.focusin="onfocusin"in n;var bt=/^(?:focusinfocus|focusoutblur)$/,Mt=function(e){e.stopPropagation()};A.extend(A.event,{trigger:function(e,t,r,i){var o,a,s,l,c,u,d,h,f=[r||_],m=p.call(e,"type")?e.type:e,g=p.call(e,"namespace")?e.namespace.split("."):[];if(a=h=s=r=r||_,3!==r.nodeType&&8!==r.nodeType&&!bt.test(m+A.event.triggered)&&(m.indexOf(".")>-1&&(g=m.split("."),m=g.shift(),g.sort()),c=m.indexOf(":")<0&&"on"+m,(e=e[A.expando]?e:new A.Event(m,"object"==typeof e&&e)).isTrigger=i?2:3,e.namespace=g.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+g.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=r),t=null==t?[e]:A.makeArray(t,[e]),d=A.event.special[m]||{},i||!d.trigger||!1!==d.trigger.apply(r,t))){if(!i&&!d.noBubble&&!y(r)){for(l=d.delegateType||m,bt.test(l+m)||(a=a.parentNode);a;a=a.parentNode)f.push(a),s=a;s===(r.ownerDocument||_)&&f.push(s.defaultView||s.parentWindow||n)}for(o=0;(a=f[o++])&&!e.isPropagationStopped();)h=a,e.type=o>1?l:d.bindType||m,(u=(Q.get(a,"events")||Object.create(null))[e.type]&&Q.get(a,"handle"))&&u.apply(a,t),(u=c&&a[c])&&u.apply&&X(a)&&(e.result=u.apply(a,t),!1===e.result&&e.preventDefault());return e.type=m,i||e.isDefaultPrevented()||d._default&&!1!==d._default.apply(f.pop(),t)||!X(r)||c&&v(r[m])&&!y(r)&&((s=r[c])&&(r[c]=null),A.event.triggered=m,e.isPropagationStopped()&&h.addEventListener(m,Mt),r[m](),e.isPropagationStopped()&&h.removeEventListener(m,Mt),A.event.triggered=void 0,s&&(r[c]=s)),e.result}},simulate:function(e,t,n){var r=A.extend(new A.Event,n,{type:e,isSimulated:!0});A.event.trigger(r,null,t)}}),A.fn.extend({trigger:function(e,t){return this.each((function(){A.event.trigger(e,t,this)}))},triggerHandler:function(e,t){var n=this[0];if(n)return A.event.trigger(e,t,n,!0)}}),g.focusin||A.each({focus:"focusin",blur:"focusout"},(function(e,t){var n=function(e){A.event.simulate(t,e.target,A.event.fix(e))};A.event.special[t]={setup:function(){var r=this.ownerDocument||this.document||this,i=Q.access(r,t);i||r.addEventListener(e,n,!0),Q.access(r,t,(i||0)+1)},teardown:function(){var r=this.ownerDocument||this.document||this,i=Q.access(r,t)-1;i?Q.access(r,t,i):(r.removeEventListener(e,n,!0),Q.remove(r,t))}}}));var wt=n.location,At={guid:Date.now()},Ct=/\?/;A.parseXML=function(e){var t,r;if(!e||"string"!=typeof e)return null;try{t=(new n.DOMParser).parseFromString(e,"text/xml")}catch(e){}return r=t&&t.getElementsByTagName("parsererror")[0],t&&!r||A.error("Invalid XML: "+(r?A.map(r.childNodes,(function(e){return e.textContent})).join("\n"):e)),t};var xt=/\[\]$/,Et=/\r?\n/g,Lt=/^(?:submit|button|image|reset|file)$/i,St=/^(?:input|select|textarea|keygen)/i;function Tt(e,t,n,r){var i;if(Array.isArray(t))A.each(t,(function(t,i){n||xt.test(e)?r(e,i):Tt(e+"["+("object"==typeof i&&null!=i?t:"")+"]",i,n,r)}));else if(n||"object"!==w(t))r(e,t);else for(i in t)Tt(e+"["+i+"]",t[i],n,r)}A.param=function(e,t){var n,r=[],i=function(e,t){var n=v(t)?t():t;r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==n?"":n)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!A.isPlainObject(e))A.each(e,(function(){i(this.name,this.value)}));else for(n in e)Tt(n,e[n],t,i);return r.join("&")},A.fn.extend({serialize:function(){return A.param(this.serializeArray())},serializeArray:function(){return this.map((function(){var e=A.prop(this,"elements");return e?A.makeArray(e):this})).filter((function(){var e=this.type;return this.name&&!A(this).is(":disabled")&&St.test(this.nodeName)&&!Lt.test(e)&&(this.checked||!me.test(e))})).map((function(e,t){var n=A(this).val();return null==n?null:Array.isArray(n)?A.map(n,(function(e){return{name:t.name,value:e.replace(Et,"\r\n")}})):{name:t.name,value:n.replace(Et,"\r\n")}})).get()}});var Ot=/%20/g,It=/#.*$/,kt=/([?&])_=[^&]*/,Dt=/^(.*?):[ \t]*([^\r\n]*)$/gm,Nt=/^(?:GET|HEAD)$/,jt=/^\/\//,Pt={},zt={},Rt="*/".concat("*"),Bt=_.createElement("a");function Ht(e){return function(t,n){"string"!=typeof t&&(n=t,t="*");var r,i=0,o=t.toLowerCase().match(z)||[];if(v(n))for(;r=o[i++];)"+"===r[0]?(r=r.slice(1)||"*",(e[r]=e[r]||[]).unshift(n)):(e[r]=e[r]||[]).push(n)}}function Ft(e,t,n,r){var i={},o=e===zt;function a(s){var l;return i[s]=!0,A.each(e[s]||[],(function(e,s){var c=s(t,n,r);return"string"!=typeof c||o||i[c]?o?!(l=c):void 0:(t.dataTypes.unshift(c),a(c),!1)})),l}return a(t.dataTypes[0])||!i["*"]&&a("*")}function Yt(e,t){var n,r,i=A.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);return r&&A.extend(!0,e,r),e}Bt.href=wt.href,A.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:wt.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(wt.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Rt,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":A.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?Yt(Yt(e,A.ajaxSettings),t):Yt(A.ajaxSettings,e)},ajaxPrefilter:Ht(Pt),ajaxTransport:Ht(zt),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var r,i,o,a,s,l,c,u,d,h,p=A.ajaxSetup({},t),f=p.context||p,m=p.context&&(f.nodeType||f.jquery)?A(f):A.event,g=A.Deferred(),v=A.Callbacks("once memory"),y=p.statusCode||{},b={},M={},w="canceled",C={readyState:0,getResponseHeader:function(e){var t;if(c){if(!a)for(a={};t=Dt.exec(o);)a[t[1].toLowerCase()+" "]=(a[t[1].toLowerCase()+" "]||[]).concat(t[2]);t=a[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return c?o:null},setRequestHeader:function(e,t){return null==c&&(e=M[e.toLowerCase()]=M[e.toLowerCase()]||e,b[e]=t),this},overrideMimeType:function(e){return null==c&&(p.mimeType=e),this},statusCode:function(e){var t;if(e)if(c)C.always(e[C.status]);else for(t in e)y[t]=[y[t],e[t]];return this},abort:function(e){var t=e||w;return r&&r.abort(t),x(0,t),this}};if(g.promise(C),p.url=((e||p.url||wt.href)+"").replace(jt,wt.protocol+"//"),p.type=t.method||t.type||p.method||p.type,p.dataTypes=(p.dataType||"*").toLowerCase().match(z)||[""],null==p.crossDomain){l=_.createElement("a");try{l.href=p.url,l.href=l.href,p.crossDomain=Bt.protocol+"//"+Bt.host!=l.protocol+"//"+l.host}catch(e){p.crossDomain=!0}}if(p.data&&p.processData&&"string"!=typeof p.data&&(p.data=A.param(p.data,p.traditional)),Ft(Pt,p,t,C),c)return C;for(d in(u=A.event&&p.global)&&0==A.active++&&A.event.trigger("ajaxStart"),p.type=p.type.toUpperCase(),p.hasContent=!Nt.test(p.type),i=p.url.replace(It,""),p.hasContent?p.data&&p.processData&&0===(p.contentType||"").indexOf("application/x-www-form-urlencoded")&&(p.data=p.data.replace(Ot,"+")):(h=p.url.slice(i.length),p.data&&(p.processData||"string"==typeof p.data)&&(i+=(Ct.test(i)?"&":"?")+p.data,delete p.data),!1===p.cache&&(i=i.replace(kt,"$1"),h=(Ct.test(i)?"&":"?")+"_="+At.guid+++h),p.url=i+h),p.ifModified&&(A.lastModified[i]&&C.setRequestHeader("If-Modified-Since",A.lastModified[i]),A.etag[i]&&C.setRequestHeader("If-None-Match",A.etag[i])),(p.data&&p.hasContent&&!1!==p.contentType||t.contentType)&&C.setRequestHeader("Content-Type",p.contentType),C.setRequestHeader("Accept",p.dataTypes[0]&&p.accepts[p.dataTypes[0]]?p.accepts[p.dataTypes[0]]+("*"!==p.dataTypes[0]?", "+Rt+"; q=0.01":""):p.accepts["*"]),p.headers)C.setRequestHeader(d,p.headers[d]);if(p.beforeSend&&(!1===p.beforeSend.call(f,C,p)||c))return C.abort();if(w="abort",v.add(p.complete),C.done(p.success),C.fail(p.error),r=Ft(zt,p,t,C)){if(C.readyState=1,u&&m.trigger("ajaxSend",[C,p]),c)return C;p.async&&p.timeout>0&&(s=n.setTimeout((function(){C.abort("timeout")}),p.timeout));try{c=!1,r.send(b,x)}catch(e){if(c)throw e;x(-1,e)}}else x(-1,"No Transport");function x(e,t,a,l){var d,h,_,b,M,w=t;c||(c=!0,s&&n.clearTimeout(s),r=void 0,o=l||"",C.readyState=e>0?4:0,d=e>=200&&e<300||304===e,a&&(b=function(e,t,n){for(var r,i,o,a,s=e.contents,l=e.dataTypes;"*"===l[0];)l.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("Content-Type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){l.unshift(i);break}if(l[0]in n)o=l[0];else{for(i in n){if(!l[0]||e.converters[i+" "+l[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==l[0]&&l.unshift(o),n[o]}(p,C,a)),!d&&A.inArray("script",p.dataTypes)>-1&&A.inArray("json",p.dataTypes)<0&&(p.converters["text script"]=function(){}),b=function(e,t,n,r){var i,o,a,s,l,c={},u=e.dataTypes.slice();if(u[1])for(a in e.converters)c[a.toLowerCase()]=e.converters[a];for(o=u.shift();o;)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!l&&r&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),l=o,o=u.shift())if("*"===o)o=l;else if("*"!==l&&l!==o){if(!(a=c[l+" "+o]||c["* "+o]))for(i in c)if((s=i.split(" "))[1]===o&&(a=c[l+" "+s[0]]||c["* "+s[0]])){!0===a?a=c[i]:!0!==c[i]&&(o=s[0],u.unshift(s[1]));break}if(!0!==a)if(a&&e.throws)t=a(t);else try{t=a(t)}catch(e){return{state:"parsererror",error:a?e:"No conversion from "+l+" to "+o}}}return{state:"success",data:t}}(p,b,C,d),d?(p.ifModified&&((M=C.getResponseHeader("Last-Modified"))&&(A.lastModified[i]=M),(M=C.getResponseHeader("etag"))&&(A.etag[i]=M)),204===e||"HEAD"===p.type?w="nocontent":304===e?w="notmodified":(w=b.state,h=b.data,d=!(_=b.error))):(_=w,!e&&w||(w="error",e<0&&(e=0))),C.status=e,C.statusText=(t||w)+"",d?g.resolveWith(f,[h,w,C]):g.rejectWith(f,[C,w,_]),C.statusCode(y),y=void 0,u&&m.trigger(d?"ajaxSuccess":"ajaxError",[C,p,d?h:_]),v.fireWith(f,[C,w]),u&&(m.trigger("ajaxComplete",[C,p]),--A.active||A.event.trigger("ajaxStop")))}return C},getJSON:function(e,t,n){return A.get(e,t,n,"json")},getScript:function(e,t){return A.get(e,void 0,t,"script")}}),A.each(["get","post"],(function(e,t){A[t]=function(e,n,r,i){return v(n)&&(i=i||r,r=n,n=void 0),A.ajax(A.extend({url:e,type:t,dataType:i,data:n,success:r},A.isPlainObject(e)&&e))}})),A.ajaxPrefilter((function(e){var t;for(t in e.headers)"content-type"===t.toLowerCase()&&(e.contentType=e.headers[t]||"")})),A._evalUrl=function(e,t,n){return A.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){A.globalEval(e,t,n)}})},A.fn.extend({wrapAll:function(e){var t;return this[0]&&(v(e)&&(e=e.call(this[0])),t=A(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map((function(){for(var e=this;e.firstElementChild;)e=e.firstElementChild;return e})).append(this)),this},wrapInner:function(e){return v(e)?this.each((function(t){A(this).wrapInner(e.call(this,t))})):this.each((function(){var t=A(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)}))},wrap:function(e){var t=v(e);return this.each((function(n){A(this).wrapAll(t?e.call(this,n):e)}))},unwrap:function(e){return this.parent(e).not("body").each((function(){A(this).replaceWith(this.childNodes)})),this}}),A.expr.pseudos.hidden=function(e){return!A.expr.pseudos.visible(e)},A.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},A.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(e){}};var Vt={0:200,1223:204},Ut=A.ajaxSettings.xhr();g.cors=!!Ut&&"withCredentials"in Ut,g.ajax=Ut=!!Ut,A.ajaxTransport((function(e){var t,r;if(g.cors||Ut&&!e.crossDomain)return{send:function(i,o){var a,s=e.xhr();if(s.open(e.type,e.url,e.async,e.username,e.password),e.xhrFields)for(a in e.xhrFields)s[a]=e.xhrFields[a];for(a in e.mimeType&&s.overrideMimeType&&s.overrideMimeType(e.mimeType),e.crossDomain||i["X-Requested-With"]||(i["X-Requested-With"]="XMLHttpRequest"),i)s.setRequestHeader(a,i[a]);t=function(e){return function(){t&&(t=r=s.onload=s.onerror=s.onabort=s.ontimeout=s.onreadystatechange=null,"abort"===e?s.abort():"error"===e?"number"!=typeof s.status?o(0,"error"):o(s.status,s.statusText):o(Vt[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=t(),r=s.onerror=s.ontimeout=t("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout((function(){t&&r()}))},t=t("abort");try{s.send(e.hasContent&&e.data||null)}catch(e){if(t)throw e}},abort:function(){t&&t()}}})),A.ajaxPrefilter((function(e){e.crossDomain&&(e.contents.script=!1)})),A.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return A.globalEval(e),e}}}),A.ajaxPrefilter("script",(function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")})),A.ajaxTransport("script",(function(e){var t,n;if(e.crossDomain||e.scriptAttrs)return{send:function(r,i){t=A("<script>").attr(e.scriptAttrs||{}).prop({charset:e.scriptCharset,src:e.url}).on("load error",n=function(e){t.remove(),n=null,e&&i("error"===e.type?404:200,e.type)}),_.head.appendChild(t[0])},abort:function(){n&&n()}}}));var Wt,Gt=[],qt=/(=)\?(?=&|$)|\?\?/;A.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Gt.pop()||A.expando+"_"+At.guid++;return this[e]=!0,e}}),A.ajaxPrefilter("json jsonp",(function(e,t,r){var i,o,a,s=!1!==e.jsonp&&(qt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&qt.test(e.data)&&"data");if(s||"jsonp"===e.dataTypes[0])return i=e.jsonpCallback=v(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,s?e[s]=e[s].replace(qt,"$1"+i):!1!==e.jsonp&&(e.url+=(Ct.test(e.url)?"&":"?")+e.jsonp+"="+i),e.converters["script json"]=function(){return a||A.error(i+" was not called"),a[0]},e.dataTypes[0]="json",o=n[i],n[i]=function(){a=arguments},r.always((function(){void 0===o?A(n).removeProp(i):n[i]=o,e[i]&&(e.jsonpCallback=t.jsonpCallback,Gt.push(i)),a&&v(o)&&o(a[0]),a=o=void 0})),"script"})),g.createHTMLDocument=((Wt=_.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Wt.childNodes.length),A.parseHTML=function(e,t,n){return"string"!=typeof e?[]:("boolean"==typeof t&&(n=t,t=!1),t||(g.createHTMLDocument?((r=(t=_.implementation.createHTMLDocument("")).createElement("base")).href=_.location.href,t.head.appendChild(r)):t=_),o=!n&&[],(i=O.exec(e))?[t.createElement(i[1])]:(i=we([e],t,o),o&&o.length&&A(o).remove(),A.merge([],i.childNodes)));var r,i,o},A.fn.load=function(e,t,n){var r,i,o,a=this,s=e.indexOf(" ");return s>-1&&(r=gt(e.slice(s)),e=e.slice(0,s)),v(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),a.length>0&&A.ajax({url:e,type:i||"GET",dataType:"html",data:t}).done((function(e){o=arguments,a.html(r?A("<div>").append(A.parseHTML(e)).find(r):e)})).always(n&&function(e,t){a.each((function(){n.apply(this,o||[e.responseText,t,e])}))}),this},A.expr.pseudos.animated=function(e){return A.grep(A.timers,(function(t){return e===t.elem})).length},A.offset={setOffset:function(e,t,n){var r,i,o,a,s,l,c=A.css(e,"position"),u=A(e),d={};"static"===c&&(e.style.position="relative"),s=u.offset(),o=A.css(e,"top"),l=A.css(e,"left"),("absolute"===c||"fixed"===c)&&(o+l).indexOf("auto")>-1?(a=(r=u.position()).top,i=r.left):(a=parseFloat(o)||0,i=parseFloat(l)||0),v(t)&&(t=t.call(e,n,A.extend({},s))),null!=t.top&&(d.top=t.top-s.top+a),null!=t.left&&(d.left=t.left-s.left+i),"using"in t?t.using.call(e,d):u.css(d)}},A.fn.extend({offset:function(e){if(arguments.length)return void 0===e?this:this.each((function(t){A.offset.setOffset(this,e,t)}));var t,n,r=this[0];return r?r.getClientRects().length?(t=r.getBoundingClientRect(),n=r.ownerDocument.defaultView,{top:t.top+n.pageYOffset,left:t.left+n.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,n,r=this[0],i={top:0,left:0};if("fixed"===A.css(r,"position"))t=r.getBoundingClientRect();else{for(t=this.offset(),n=r.ownerDocument,e=r.offsetParent||n.documentElement;e&&(e===n.body||e===n.documentElement)&&"static"===A.css(e,"position");)e=e.parentNode;e&&e!==r&&1===e.nodeType&&((i=A(e).offset()).top+=A.css(e,"borderTopWidth",!0),i.left+=A.css(e,"borderLeftWidth",!0))}return{top:t.top-i.top-A.css(r,"marginTop",!0),left:t.left-i.left-A.css(r,"marginLeft",!0)}}},offsetParent:function(){return this.map((function(){for(var e=this.offsetParent;e&&"static"===A.css(e,"position");)e=e.offsetParent;return e||oe}))}}),A.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},(function(e,t){var n="pageYOffset"===t;A.fn[e]=function(r){return U(this,(function(e,r,i){var o;if(y(e)?o=e:9===e.nodeType&&(o=e.defaultView),void 0===i)return o?o[t]:e[r];o?o.scrollTo(n?o.pageXOffset:i,n?i:o.pageYOffset):e[r]=i}),e,r,arguments.length)}})),A.each(["top","left"],(function(e,t){A.cssHooks[t]=Ue(g.pixelPosition,(function(e,n){if(n)return n=Ve(e,t),Be.test(n)?A(e).position()[t]+"px":n}))})),A.each({Height:"height",Width:"width"},(function(e,t){A.each({padding:"inner"+e,content:t,"":"outer"+e},(function(n,r){A.fn[r]=function(i,o){var a=arguments.length&&(n||"boolean"!=typeof i),s=n||(!0===i||!0===o?"margin":"border");return U(this,(function(t,n,i){var o;return y(t)?0===r.indexOf("outer")?t["inner"+e]:t.document.documentElement["client"+e]:9===t.nodeType?(o=t.documentElement,Math.max(t.body["scroll"+e],o["scroll"+e],t.body["offset"+e],o["offset"+e],o["client"+e])):void 0===i?A.css(t,n,s):A.style(t,n,i,s)}),t,a?i:void 0,a)}}))})),A.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],(function(e,t){A.fn[t]=function(e){return this.on(t,e)}})),A.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)},hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),A.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),(function(e,t){A.fn[t]=function(e,n){return arguments.length>0?this.on(t,null,e,n):this.trigger(t)}}));var Kt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;A.proxy=function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),v(e))return r=s.call(arguments,2),(i=function(){return e.apply(t||this,r.concat(s.call(arguments)))}).guid=e.guid=e.guid||A.guid++,i},A.holdReady=function(e){e?A.readyWait++:A.ready(!0)},A.isArray=Array.isArray,A.parseJSON=JSON.parse,A.nodeName=T,A.isFunction=v,A.isWindow=y,A.camelCase=K,A.type=w,A.now=Date.now,A.isNumeric=function(e){var t=A.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},A.trim=function(e){return null==e?"":(e+"").replace(Kt,"")},void 0===(r=function(){return A}.apply(t,[]))||(e.exports=r);var Xt=n.jQuery,Jt=n.$;return A.noConflict=function(e){return n.$===A&&(n.$=Jt),e&&n.jQuery===A&&(n.jQuery=Xt),A},void 0===i&&(n.jQuery=n.$=A),A}))},function(e,t,n){"use strict";e.exports=function(e,t){return t||(t={}),"string"!=typeof(e=e&&e.__esModule?e.default:e)?e:(/^['"].*['"]$/.test(e)&&(e=e.slice(1,-1)),t.hash&&(e+=t.hash),/["'() \t\n]/.test(e)||t.needQuotes?'"'.concat(e.replace(/"/g,'\\"').replace(/\n/g,"\\n"),'"'):e)}},function(e,t,n){"use strict";n.r(t),n.d(t,"AttachedProperty",(function(){return i}));var r,i=function(){function e(e){this._pid=r.nextPID(),this.name=e.name,this._create=e.create,this._coerce=e.coerce||null,this._compare=e.compare||null,this._changed=e.changed||null}return e.prototype.get=function(e){var t=r.ensureMap(e);return this._pid in t?t[this._pid]:t[this._pid]=this._createValue(e)},e.prototype.set=function(e,t){var n,i=r.ensureMap(e);n=this._pid in i?i[this._pid]:i[this._pid]=this._createValue(e);var o=this._coerceValue(e,t);this._maybeNotify(e,n,i[this._pid]=o)},e.prototype.coerce=function(e){var t,n=r.ensureMap(e);t=this._pid in n?n[this._pid]:n[this._pid]=this._createValue(e);var i=this._coerceValue(e,t);this._maybeNotify(e,t,n[this._pid]=i)},e.prototype._createValue=function(e){return(0,this._create)(e)},e.prototype._coerceValue=function(e,t){var n=this._coerce;return n?n(e,t):t},e.prototype._compareValue=function(e,t){var n=this._compare;return n?n(e,t):e===t},e.prototype._maybeNotify=function(e,t,n){var r=this._changed;r&&!this._compareValue(t,n)&&r(e,t,n)},e}();!function(e){e.clearData=function(e){r.ownerData.delete(e)}}(i||(i={})),function(e){var t;e.ownerData=new WeakMap,e.nextPID=(t=0,function(){return"pid-"+(""+Math.random()).slice(2)+"-"+t++}),e.ensureMap=function(t){var n=e.ownerData.get(t);return n||(n=Object.create(null),e.ownerData.set(t,n),n)}}(r||(r={}))},function(e,t){e.exports=function(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e},e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){"use strict";n.d(t,"a",(function(){return o})),n.d(t,"b",(function(){return a}));var r=n(12);function i(e){return e.map(e=>e&&"object"==typeof e?Object.keys(e).map(t=>!!e[t]&&t):"string"==typeof e?e.split(/\s+/):[]).reduce((e,t)=>e.concat(t),[]).filter(e=>!!e)}function o(...e){return i(e).join(" ")}function a(e,{ignore:t=[]}={}){return e.getAttributeNames().reduce((n,i)=>("style"===i||t.includes(i)||(i.startsWith("data")?n[i]=e.getAttribute(i):n[r.Text.camelCase(i)]=e.getAttribute(i)),n),{})}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),s=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||a(t,e,n)},l=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},c=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.AddCSS=t.CHTMLFontData=void 0;var u=n(111),d=n(449),h=n(58);s(n(111),t);var p=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.charUsage=new d.Usage,t.delimUsage=new d.Usage,t}return i(t,e),t.charOptions=function(t,n){return e.charOptions.call(this,t,n)},t.prototype.adaptiveCSS=function(e){this.options.adaptiveCSS=e},t.prototype.clearCache=function(){this.options.adaptiveCSS&&(this.charUsage.clear(),this.delimUsage.clear())},t.prototype.createVariant=function(t,n,r){void 0===n&&(n=null),void 0===r&&(r=null),e.prototype.createVariant.call(this,t,n,r);var i=this.constructor;this.variant[t].classes=i.defaultVariantClasses[t],this.variant[t].letter=i.defaultVariantLetters[t]},t.prototype.defineChars=function(n,r){var i,o;e.prototype.defineChars.call(this,n,r);var a=this.variant[n].letter;try{for(var s=l(Object.keys(r)),c=s.next();!c.done;c=s.next()){var u=c.value,d=t.charOptions(r,parseInt(u));void 0===d.f&&(d.f=a)}}catch(e){i={error:e}}finally{try{c&&!c.done&&(o=s.return)&&o.call(s)}finally{if(i)throw i.error}}},Object.defineProperty(t.prototype,"styles",{get:function(){var e=this.constructor,t=o({},e.defaultStyles);return this.addFontURLs(t,e.defaultFonts,this.options.fontURL),this.updateStyles(t),t},enumerable:!1,configurable:!0}),t.prototype.updateStyles=function(e){var t,n,r,i;try{for(var o=l(this.delimUsage.update()),a=o.next();!a.done;a=o.next()){var s=a.value;this.addDelimiterStyles(e,s,this.delimiters[s])}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}try{for(var u=l(this.charUsage.update()),d=u.next();!d.done;d=u.next()){var h=c(d.value,2),p=h[0],f=(s=h[1],this.variant[p]);this.addCharStyles(e,f.letter,s,f.chars[s])}}catch(e){r={error:e}}finally{try{d&&!d.done&&(i=u.return)&&i.call(u)}finally{if(r)throw r.error}}return e},t.prototype.addFontURLs=function(e,t,n){var r,i;try{for(var a=l(Object.keys(t)),s=a.next();!s.done;s=a.next()){var c=s.value,u=o({},t[c]);u.src=u.src.replace(/%%URL%%/,n),e[c]=u}}catch(e){r={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(r)throw r.error}}},t.prototype.addDelimiterStyles=function(e,t,n){var r=this.charSelector(t);n.c&&n.c!==t&&(e[".mjx-stretched mjx-c"+(r=this.charSelector(n.c))+"::before"]={content:this.charContent(n.c)}),n.stretch&&(1===n.dir?this.addDelimiterVStyles(e,r,n):this.addDelimiterHStyles(e,r,n))},t.prototype.addDelimiterVStyles=function(e,t,n){var r=n.HDW,i=c(n.stretch,4),o=i[0],a=i[1],s=i[2],l=i[3],u=this.addDelimiterVPart(e,t,"beg",o,r);this.addDelimiterVPart(e,t,"ext",a,r);var d=this.addDelimiterVPart(e,t,"end",s,r),h={};if(l){var p=this.addDelimiterVPart(e,t,"mid",l,r);h.height="50%",e["mjx-stretchy-v"+t+" > mjx-mid"]={"margin-top":this.em(-p/2),"margin-bottom":this.em(-p/2)}}u&&(h["border-top-width"]=this.em0(u-.03)),d&&(h["border-bottom-width"]=this.em0(d-.03),e["mjx-stretchy-v"+t+" > mjx-end"]={"margin-top":this.em(-d)}),Object.keys(h).length&&(e["mjx-stretchy-v"+t+" > mjx-ext"]=h)},t.prototype.addDelimiterVPart=function(e,t,n,r,i){if(!r)return 0;var o=this.getDelimiterData(r),a=(i[2]-o[2])/2,s={content:this.charContent(r)};return"ext"!==n?s.padding=this.padding(o,a):(s.width=this.em0(i[2]),a&&(s["padding-left"]=this.em0(a))),e["mjx-stretchy-v"+t+" mjx-"+n+" mjx-c::before"]=s,o[0]+o[1]},t.prototype.addDelimiterHStyles=function(e,t,n){var r=c(n.stretch,4),i=r[0],o=r[1],a=r[2],s=r[3],l=n.HDW;this.addDelimiterHPart(e,t,"beg",i,l),this.addDelimiterHPart(e,t,"ext",o,l),this.addDelimiterHPart(e,t,"end",a,l),s&&(this.addDelimiterHPart(e,t,"mid",s,l),e["mjx-stretchy-h"+t+" > mjx-ext"]={width:"50%"})},t.prototype.addDelimiterHPart=function(e,t,n,r,i){if(r){var o=this.getDelimiterData(r)[3],a={content:o&&o.c?'"'+o.c+'"':this.charContent(r)};a.padding=this.padding(i,0,-i[2]),e["mjx-stretchy-h"+t+" mjx-"+n+" mjx-c::before"]=a}},t.prototype.addCharStyles=function(e,t,n,r){var i=r[3],o=void 0!==i.f?i.f:t;e["mjx-c"+this.charSelector(n)+(o?".TEX-"+o:"")+"::before"]={padding:this.padding(r,0,i.ic||0),content:null!=i.c?'"'+i.c+'"':this.charContent(n)}},t.prototype.getDelimiterData=function(e){return this.getChar("-smallop",e)},t.prototype.em=function(e){return h.em(e)},t.prototype.em0=function(e){return h.em(Math.max(0,e))},t.prototype.padding=function(e,t,n){var r=c(e,3),i=r[0],o=r[1];return void 0===t&&(t=0),void 0===n&&(n=0),[i,r[2]+n,o,t].map(this.em0).join(" ")},t.prototype.charContent=function(e){return'"'+(e>=32&&e<=126&&34!==e&&39!==e&&92!==e?String.fromCharCode(e):"\\"+e.toString(16).toUpperCase())+'"'},t.prototype.charSelector=function(e){return".mjx-c"+e.toString(16).toUpperCase()},t.OPTIONS=o(o({},u.FontData.OPTIONS),{fontURL:"js/output/chtml/fonts/tex-woff-v2"}),t.defaultVariantClasses={},t.defaultVariantLetters={},t.defaultStyles={"mjx-c::before":{display:"block",width:0}},t.defaultFonts={"@font-face /* 0 */":{"font-family":"MJXZERO",src:'url("%%URL%%/MathJax_Zero.woff") format("woff")'}},t}(u.FontData);t.CHTMLFontData=p,t.AddCSS=function(e,t){var n,r;try{for(var i=l(Object.keys(t)),o=i.next();!o.done;o=i.next()){var a=o.value,s=parseInt(a);Object.assign(u.FontData.charOptions(e,s),t[s])}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return e}},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.lookup=t.separateOptions=t.selectOptionsFromKeys=t.selectOptions=t.userOptions=t.defaultOptions=t.insert=t.copy=t.keys=t.makeArray=t.expandable=t.Expandable=t.OPTIONS=t.REMOVE=t.APPEND=t.isObject=void 0;var a={}.constructor;function s(e){return"object"==typeof e&&null!==e&&(e.constructor===a||e.constructor===l)}t.isObject=s,t.APPEND="[+]",t.REMOVE="[-]",t.OPTIONS={invalidOption:"warn",optionError:function(e,n){if("fatal"===t.OPTIONS.invalidOption)throw new Error(e);console.warn("MathJax: "+e)}};var l=function(){};function c(e){return Object.assign(Object.create(l.prototype),e)}function u(e){return e?Object.keys(e).concat(Object.getOwnPropertySymbols(e)):[]}function d(e){var t,n,i={};try{for(var o=r(u(e)),a=o.next();!a.done;a=o.next()){var p=a.value,f=Object.getOwnPropertyDescriptor(e,p),m=f.value;Array.isArray(m)?f.value=h([],m,!1):s(m)&&(f.value=d(m)),f.enumerable&&(i[p]=f)}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}return Object.defineProperties(e.constructor===l?c({}):{},i)}function h(e,n,a){var c,p;void 0===a&&(a=!0);var f=function(r){if(a&&void 0===e[r]&&e.constructor!==l)return"symbol"==typeof r&&(r=r.toString()),t.OPTIONS.optionError('Invalid option "'+r+'" (no default value).',r),"continue";var c=n[r],p=e[r];if(!s(c)||null===p||"object"!=typeof p&&"function"!=typeof p)Array.isArray(c)?(e[r]=[],h(e[r],c,!1)):s(c)?e[r]=d(c):e[r]=c;else{var f=u(c);Array.isArray(p)&&(1===f.length&&(f[0]===t.APPEND||f[0]===t.REMOVE)&&Array.isArray(c[f[0]])||2===f.length&&f.sort().join(",")===t.APPEND+","+t.REMOVE&&Array.isArray(c[t.APPEND])&&Array.isArray(c[t.REMOVE]))?(c[t.REMOVE]&&(p=e[r]=p.filter((function(e){return c[t.REMOVE].indexOf(e)<0}))),c[t.APPEND]&&(e[r]=o(o([],i(p)),i(c[t.APPEND])))):h(p,c,a)}};try{for(var m=r(u(n)),g=m.next();!g.done;g=m.next()){f(g.value)}}catch(e){c={error:e}}finally{try{g&&!g.done&&(p=m.return)&&p.call(m)}finally{if(c)throw c.error}}return e}function p(e){for(var t,n,i=[],o=1;o<arguments.length;o++)i[o-1]=arguments[o];var a={};try{for(var s=r(i),l=s.next();!l.done;l=s.next()){var c=l.value;e.hasOwnProperty(c)&&(a[c]=e[c])}}catch(e){t={error:e}}finally{try{l&&!l.done&&(n=s.return)&&n.call(s)}finally{if(t)throw t.error}}return a}t.Expandable=l,t.expandable=c,t.makeArray=function(e){return Array.isArray(e)?e:[e]},t.keys=u,t.copy=d,t.insert=h,t.defaultOptions=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return t.forEach((function(t){return h(e,t,!1)})),e},t.userOptions=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return t.forEach((function(t){return h(e,t,!0)})),e},t.selectOptions=p,t.selectOptionsFromKeys=function(e,t){return p.apply(void 0,o([e],i(Object.keys(t))))},t.separateOptions=function(e){for(var t,n,i,o,a=[],s=1;s<arguments.length;s++)a[s-1]=arguments[s];var l=[];try{for(var c=r(a),u=c.next();!u.done;u=c.next()){var d=u.value,h={},p={};try{for(var f=(i=void 0,r(Object.keys(e||{}))),m=f.next();!m.done;m=f.next()){var g=m.value;(void 0===d[g]?p:h)[g]=e[g]}}catch(e){i={error:e}}finally{try{m&&!m.done&&(o=f.return)&&o.call(f)}finally{if(i)throw i.error}}l.push(h),e=p}}catch(e){t={error:e}}finally{try{u&&!u.done&&(n=c.return)&&n.call(c)}finally{if(t)throw t.error}}return l.unshift(e),l},t.lookup=function(e,t,n){return void 0===n&&(n=null),t.hasOwnProperty(e)?t[e]:n}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r="1.5.0"},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0});var a=n(37),s=n(418),l=n(31),c=n(23),u=function(){function e(e,t,n){var i,o;this._string=e,this.configuration=n,this.macroCount=0,this.i=0,this.currentCS="";var a,l=t.hasOwnProperty("isInner"),c=t.isInner;if(delete t.isInner,t){a={};try{for(var u=r(Object.keys(t)),d=u.next();!d.done;d=u.next()){var h=d.value;a[h]=t[h]}}catch(e){i={error:e}}finally{try{d&&!d.done&&(o=u.return)&&o.call(u)}finally{if(i)throw i.error}}}this.configuration.pushParser(this),this.stack=new s.default(this.itemFactory,a,!l||c),this.Parse(),this.Push(this.itemFactory.create("stop"))}return Object.defineProperty(e.prototype,"options",{get:function(){return this.configuration.options},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"itemFactory",{get:function(){return this.configuration.itemFactory},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"tags",{get:function(){return this.configuration.tags},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"string",{get:function(){return this._string},set:function(e){this._string=e},enumerable:!1,configurable:!0}),e.prototype.parse=function(e,t){return this.configuration.handlers.get(e).parse(t)},e.prototype.lookup=function(e,t){return this.configuration.handlers.get(e).lookup(t)},e.prototype.contains=function(e,t){return this.configuration.handlers.get(e).contains(t)},e.prototype.toString=function(){var e,t,n="";try{for(var i=r(Array.from(this.configuration.handlers.keys())),o=i.next();!o.done;o=i.next()){var a=o.value;n+=a+": "+this.configuration.handlers.get(a)+"\n"}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return n},e.prototype.Parse=function(){for(var e;this.i<this.string.length;)e=this.getCodePoint(),this.i+=e.length,this.parse("character",[this,e])},e.prototype.Push=function(e){e instanceof c.AbstractMmlNode&&e.isInferred?this.PushAll(e.childNodes):this.stack.Push(e)},e.prototype.PushAll=function(e){var t,n;try{for(var i=r(e),o=i.next();!o.done;o=i.next()){var a=o.value;this.stack.Push(a)}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},e.prototype.mml=function(){if(!this.stack.Top().isKind("mml"))return null;var e=this.stack.Top().First;return this.configuration.popParser(),e},e.prototype.convertDelimiter=function(e){var t=this.lookup("delimiter",e);return t?t.char:null},e.prototype.getCodePoint=function(){var e=this.string.codePointAt(this.i);return void 0===e?"":String.fromCodePoint(e)},e.prototype.nextIsSpace=function(){return!!this.string.charAt(this.i).match(/\s/)},e.prototype.GetNext=function(){for(;this.nextIsSpace();)this.i++;return this.getCodePoint()},e.prototype.GetCS=function(){var e=this.string.slice(this.i).match(/^(([a-z]+) ?|[\uD800-\uDBFF].|.)/i);return e?(this.i+=e[0].length,e[2]||e[1]):(this.i++," ")},e.prototype.GetArgument=function(e,t){switch(this.GetNext()){case"":if(!t)throw new l.default("MissingArgFor","Missing argument for %1",this.currentCS);return null;case"}":if(!t)throw new l.default("ExtraCloseMissingOpen","Extra close brace or missing open brace");return null;case"\\":return this.i++,"\\"+this.GetCS();case"{":for(var n=++this.i,r=1;this.i<this.string.length;)switch(this.string.charAt(this.i++)){case"\\":this.i++;break;case"{":r++;break;case"}":if(0==--r)return this.string.slice(n,this.i-1)}throw new l.default("MissingCloseBrace","Missing close brace")}var i=this.getCodePoint();return this.i+=i.length,i},e.prototype.GetBrackets=function(e,t){if("["!==this.GetNext())return t;for(var n=++this.i,r=0;this.i<this.string.length;)switch(this.string.charAt(this.i++)){case"{":r++;break;case"\\":this.i++;break;case"}":if(r--<=0)throw new l.default("ExtraCloseLooking","Extra close brace while looking for %1","']'");break;case"]":if(0===r)return this.string.slice(n,this.i-1)}throw new l.default("MissingCloseBracket","Could not find closing ']' for argument to %1",this.currentCS)},e.prototype.GetDelimiter=function(e,t){var n=this.GetNext();if(this.i+=n.length,this.i<=this.string.length&&("\\"===n?n+=this.GetCS():"{"===n&&t&&(this.i--,n=this.GetArgument(e).trim()),this.contains("delimiter",n)))return this.convertDelimiter(n);throw new l.default("MissingOrUnrecognizedDelim","Missing or unrecognized delimiter for %1",this.currentCS)},e.prototype.GetDimen=function(e){if("{"===this.GetNext()){var t=this.GetArgument(e),n=i(a.default.matchDimen(t),2),r=n[0],o=n[1];if(r)return r+o}else{t=this.string.slice(this.i);var s=i(a.default.matchDimen(t,!0),3),c=(r=s[0],o=s[1],s[2]);if(r)return this.i+=c,r+o}throw new l.default("MissingDimOrUnits","Missing dimension or its units for %1",this.currentCS)},e.prototype.GetUpTo=function(e,t){for(;this.nextIsSpace();)this.i++;for(var n=this.i,r=0;this.i<this.string.length;){var i=this.i,o=this.GetNext();switch(this.i+=o.length,o){case"\\":o+=this.GetCS();break;case"{":r++;break;case"}":if(0===r)throw new l.default("ExtraCloseLooking","Extra close brace while looking for %1",t);r--}if(0===r&&o===t)return this.string.slice(n,i)}throw new l.default("TokenNotFoundForCommand","Could not find %1 for %2",t,this.currentCS)},e.prototype.ParseArg=function(t){return new e(this.GetArgument(t),this.stack.env,this.configuration).mml()},e.prototype.ParseUpTo=function(t,n){return new e(this.GetUpTo(t,n),this.stack.env,this.configuration).mml()},e.prototype.GetDelimiterArg=function(e){var t=a.default.trimSpaces(this.GetArgument(e));if(""===t)return null;if(this.contains("delimiter",t))return t;throw new l.default("MissingOrUnrecognizedDelim","Missing or unrecognized delimiter for %1",this.currentCS)},e.prototype.GetStar=function(){var e="*"===this.GetNext();return e&&this.i++,e},e.prototype.create=function(e){for(var t,n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];return(t=this.configuration.nodeFactory).create.apply(t,o([e],i(n)))},e}();t.default=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TexConstant=void 0,function(e){e.Variant={NORMAL:"normal",BOLD:"bold",ITALIC:"italic",BOLDITALIC:"bold-italic",DOUBLESTRUCK:"double-struck",FRAKTUR:"fraktur",BOLDFRAKTUR:"bold-fraktur",SCRIPT:"script",BOLDSCRIPT:"bold-script",SANSSERIF:"sans-serif",BOLDSANSSERIF:"bold-sans-serif",SANSSERIFITALIC:"sans-serif-italic",SANSSERIFBOLDITALIC:"sans-serif-bold-italic",MONOSPACE:"monospace",INITIAL:"inital",TAILED:"tailed",LOOPED:"looped",STRETCHED:"stretched",CALLIGRAPHIC:"-tex-calligraphic",BOLDCALLIGRAPHIC:"-tex-bold-calligraphic",OLDSTYLE:"-tex-oldstyle",BOLDOLDSTYLE:"-tex-bold-oldstyle",MATHITALIC:"-tex-mathit"},e.Form={PREFIX:"prefix",INFIX:"infix",POSTFIX:"postfix"},e.LineBreak={AUTO:"auto",NEWLINE:"newline",NOBREAK:"nobreak",GOODBREAK:"goodbreak",BADBREAK:"badbreak"},e.LineBreakStyle={BEFORE:"before",AFTER:"after",DUPLICATE:"duplicate",INFIXLINBREAKSTYLE:"infixlinebreakstyle"},e.IndentAlign={LEFT:"left",CENTER:"center",RIGHT:"right",AUTO:"auto",ID:"id",INDENTALIGN:"indentalign"},e.IndentShift={INDENTSHIFT:"indentshift"},e.LineThickness={THIN:"thin",MEDIUM:"medium",THICK:"thick"},e.Notation={LONGDIV:"longdiv",ACTUARIAL:"actuarial",PHASORANGLE:"phasorangle",RADICAL:"radical",BOX:"box",ROUNDEDBOX:"roundedbox",CIRCLE:"circle",LEFT:"left",RIGHT:"right",TOP:"top",BOTTOM:"bottom",UPDIAGONALSTRIKE:"updiagonalstrike",DOWNDIAGONALSTRIKE:"downdiagonalstrike",VERTICALSTRIKE:"verticalstrike",HORIZONTALSTRIKE:"horizontalstrike",NORTHEASTARROW:"northeastarrow",MADRUWB:"madruwb",UPDIAGONALARROW:"updiagonalarrow"},e.Align={TOP:"top",BOTTOM:"bottom",CENTER:"center",BASELINE:"baseline",AXIS:"axis",LEFT:"left",RIGHT:"right"},e.Lines={NONE:"none",SOLID:"solid",DASHED:"dashed"},e.Side={LEFT:"left",RIGHT:"right",LEFTOVERLAP:"leftoverlap",RIGHTOVERLAP:"rightoverlap"},e.Width={AUTO:"auto",FIT:"fit"},e.Actiontype={TOGGLE:"toggle",STATUSLINE:"statusline",TOOLTIP:"tooltip",INPUT:"input"},e.Overflow={LINBREAK:"linebreak",SCROLL:"scroll",ELIDE:"elide",TRUNCATE:"truncate",SCALE:"scale"},e.Unit={EM:"em",EX:"ex",PX:"px",IN:"in",CM:"cm",MM:"mm",PT:"pt",PC:"pc"}}(t.TexConstant||(t.TexConstant={}))},function(e,t,n){"use strict";n.r(t),n.d(t,"Clipboard",(function(){return r})),n.d(t,"Collapse",(function(){return c})),n.d(t,"CommandLinker",(function(){return u.a})),n.d(t,"ICommandPalette",(function(){return d})),n.d(t,"ModalCommandPalette",(function(){return h})),n.d(t,"showDialog",(function(){return f.b})),n.d(t,"showErrorMessage",(function(){return f.c})),n.d(t,"Dialog",(function(){return f.a})),n.d(t,"DOMUtils",(function(){return m.a})),n.d(t,"HoverBox",(function(){return g.a})),n.d(t,"IFrame",(function(){return v})),n.d(t,"InputDialog",(function(){return _})),n.d(t,"MainAreaWidget",(function(){return S.a})),n.d(t,"MenuFactory",(function(){return L})),n.d(t,"Printing",(function(){return k.a})),n.d(t,"Sanitizer",(function(){return D.a})),n.d(t,"defaultSanitizer",(function(){return D.b})),n.d(t,"SessionContext",(function(){return N.a})),n.d(t,"sessionContextDialogs",(function(){return N.b})),n.d(t,"Spinner",(function(){return j.a})),n.d(t,"ISplashScreen",(function(){return P})),n.d(t,"Styling",(function(){return y.a})),n.d(t,"ThemeManager",(function(){return H})),n.d(t,"ISessionContextDialogs",(function(){return Y})),n.d(t,"IThemeManager",(function(){return V})),n.d(t,"ISanitizer",(function(){return U})),n.d(t,"Toolbar",(function(){return W.d})),n.d(t,"ReactiveToolbar",(function(){return W.c})),n.d(t,"ToolbarButtonComponent",(function(){return W.f})),n.d(t,"addToolbarButtonClass",(function(){return W.h})),n.d(t,"ToolbarButton",(function(){return W.e})),n.d(t,"CommandToolbarButtonComponent",(function(){return W.b})),n.d(t,"addCommandToolbarButtonClass",(function(){return W.g})),n.d(t,"CommandToolbarButton",(function(){return W.a})),n.d(t,"ReactWidget",(function(){return G.a})),n.d(t,"VDomRenderer",(function(){return G.d})),n.d(t,"UseSignal",(function(){return G.b})),n.d(t,"VDomModel",(function(){return G.c})),n.d(t,"WidgetTracker",(function(){return q.a})),n.d(t,"IWindowResolver",(function(){return K})),n.d(t,"WindowResolver",(function(){return X}));var r,i,o=n(6);!function(e){function t(e,t="copy"){let n=window.getSelection();const r=[];for(let e=0,t=(null==n?void 0:n.rangeCount)||0;e<t;++e)r[e]=n.getRangeAt(e).cloneRange();const i=document.createRange();if(i.selectNodeContents(e),n&&(n.removeAllRanges(),n.addRange(i)),document.execCommand(t),n=window.getSelection(),n){n.removeAllRanges();for(let e=0,t=r.length;e<t;++e)n.addRange(r[e])}}e.getInstance=function(){return i.instance},e.setInstance=function(e){i.instance=e},e.copyToSystem=function(e){const n=document.body,r=t=>{const i=t.clipboardData||window.clipboardData;"string"==typeof e?i.setData("text",e):e.types().map(t=>{i.setData(t,e.getData(t))}),t.preventDefault(),n.removeEventListener("copy",r)};n.addEventListener("copy",r),t(n)},e.generateEvent=t}(r||(r={})),(i||(i={})).instance=new o.MimeData;var a=n(54),s=n(4),l=n(3);class c extends l.Widget{constructor(e){super(e),this._collapseChanged=new s.Signal(this);const{widget:t,collapsed:n=!0}=e;this.addClass("jp-Collapse"),this._header=new l.Widget,this._header.addClass("jp-Collapse-header"),this._content=new l.Panel,this._content.addClass("jp-Collapse-contents");const r=new l.PanelLayout;this.layout=r,r.addWidget(this._header),r.addWidget(this._content),this.widget=t,this.collapsed=n}get widget(){return this._widget}set widget(e){const t=this._widget;t&&(t.title.changed.disconnect(this._onTitleChanged,this),t.parent=null),this._widget=e,e.title.changed.connect(this._onTitleChanged,this),this._onTitleChanged(e.title),this._content.addWidget(e)}get collapsed(){return this._collapsed}set collapsed(e){e!==this._collapsed&&(e?this._collapse():this._uncollapse())}get collapseChanged(){return this._collapseChanged}toggle(){this.collapsed=!this.collapsed}dispose(){this.isDisposed||(this._header=null,this._widget=null,this._content=null,super.dispose())}handleEvent(e){switch(e.type){case"click":this._evtClick(e)}}onAfterAttach(e){this._header.node.addEventListener("click",this)}onBeforeDetach(e){this._header.node.removeEventListener("click",this)}_collapse(){this._collapsed=!0,this._content&&this._content.hide(),this._setHeader(),this._collapseChanged.emit(void 0)}_uncollapse(){this._collapsed=!1,this._content&&this._content.show(),this._setHeader(),this._collapseChanged.emit(void 0)}_evtClick(e){this.toggle()}_onTitleChanged(e){this._setHeader()}_setHeader(){(this._collapsed?a.d:a.b).element({container:this._header.node,label:this._widget.title.label,elementPosition:"right",height:"28px"})}}var u=n(414);const d=new o.Token("@jupyterlab/apputils:ICommandPalette");class h extends l.Panel{constructor(e){super(),this.addClass("jp-ModalCommandPalette"),this.id="modal-command-palette",this.palette=e.commandPalette,this._commandPalette.commands.commandExecuted.connect(()=>{this.isAttached&&this.isVisible&&this.hideAndReset()}),this.node.tabIndex=0}get palette(){return this._commandPalette}set palette(e){this._commandPalette=e,this.searchIconGroup||this._commandPalette.inputNode.insertAdjacentElement("afterend",this.createSearchIconGroup()),this.addWidget(e),this.hideAndReset()}attach(){l.Widget.attach(this,document.body)}detach(){l.Widget.detach(this)}hideAndReset(){this.hide(),this._commandPalette.inputNode.value="",this._commandPalette.refresh()}handleEvent(e){switch(e.type){case"keydown":this._evtKeydown(e);break;case"blur":this.node.contains(e.target)&&!this.node.contains(e.relatedTarget)&&(e.stopPropagation(),this.hideAndReset());break;case"contextmenu":e.preventDefault(),e.stopPropagation()}}get searchIconGroup(){return this._commandPalette.node.getElementsByClassName("jp-SearchIconGroup")[0]}createSearchIconGroup(){const e=document.createElement("div");return e.classList.add("jp-SearchIconGroup"),a.x.render(e),e}onAfterAttach(e){this.node.addEventListener("keydown",this,!0),this.node.addEventListener("contextmenu",this,!0)}onAfterDetach(e){this.node.removeEventListener("keydown",this,!0),this.node.removeEventListener("contextmenu",this,!0)}onBeforeHide(e){document.removeEventListener("blur",this,!0)}onAfterShow(e){document.addEventListener("blur",this,!0)}onActivateRequest(e){this.isAttached&&(this.show(),this._commandPalette.activate())}_evtKeydown(e){switch(e.keyCode){case 27:e.stopPropagation(),e.preventDefault(),this.hideAndReset()}}}var p,f=n(32),m=n(114),g=n(401);class v extends l.Widget{constructor(e={}){super({node:p.createNode()}),this._sandbox=[],this.addClass("jp-IFrame"),this.sandbox=e.sandbox||[],this.referrerPolicy=e.referrerPolicy||"no-referrer"}get referrerPolicy(){return this._referrerPolicy}set referrerPolicy(e){if(this._referrerPolicy===e)return;this._referrerPolicy=e;this.node.querySelector("iframe").setAttribute("referrerpolicy",e)}get sandbox(){return this._sandbox.slice()}set sandbox(e){this._sandbox=e.slice();const t=this.node.querySelector("iframe"),n=e.length?e.join(" "):"";t.setAttribute("sandbox",n)}get url(){return this.node.querySelector("iframe").getAttribute("src")||""}set url(e){this.node.querySelector("iframe").setAttribute("src",e)}}!function(e){e.createNode=function(){const e=document.createElement("div"),t=document.createElement("iframe");return t.setAttribute("sandbox",""),t.style.height="100%",t.style.width="100%",e.appendChild(t),e}}(p||(p={}));var y=n(77);var _,b;(b=_||(_={})).getBoolean=function(e){return Object(f.b)(Object.assign(Object.assign({},e),{body:new w(e),buttons:[f.a.cancelButton({label:e.cancelLabel}),f.a.okButton({label:e.okLabel})],focusNodeSelector:"input"}))},b.getNumber=function(e){return Object(f.b)(Object.assign(Object.assign({},e),{body:new A(e),buttons:[f.a.cancelButton({label:e.cancelLabel}),f.a.okButton({label:e.okLabel})],focusNodeSelector:"input"}))},b.getItem=function(e){return Object(f.b)(Object.assign(Object.assign({},e),{body:new E(e),buttons:[f.a.cancelButton({label:e.cancelLabel}),f.a.okButton({label:e.okLabel})],focusNodeSelector:e.editable?"input":"select"}))},b.getText=function(e){return Object(f.b)(Object.assign(Object.assign({},e),{body:new C(e),buttons:[f.a.cancelButton({label:e.cancelLabel}),f.a.okButton({label:e.okLabel})],focusNodeSelector:"input"}))},b.getPassword=function(e){return Object(f.b)(Object.assign(Object.assign({},e),{body:new x(e),buttons:[f.a.cancelButton({label:e.cancelLabel}),f.a.okButton({label:e.okLabel})],focusNodeSelector:"input"}))};class M extends l.Widget{constructor(e){if(super(),this.addClass("jp-Input-Dialog"),this._input=document.createElement("input"),this._input.classList.add("jp-mod-styled"),this._input.id="jp-dialog-input-id",void 0!==e){const t=document.createElement("label");t.textContent=e,t.htmlFor=this._input.id,this.node.appendChild(t)}this.node.appendChild(this._input)}}class w extends M{constructor(e){super(e.label),this.addClass("jp-Input-Boolean-Dialog"),this._input.type="checkbox",this._input.checked=!!e.value}getValue(){return this._input.checked}}class A extends M{constructor(e){super(e.label),this._input.type="number",this._input.value=e.value?e.value.toString():"0"}getValue(){return this._input.value?Number(this._input.value):Number.NaN}}class C extends M{constructor(e){super(e.label),this._input.type="text",this._input.value=e.text?e.text:"",e.placeholder&&(this._input.placeholder=e.placeholder)}getValue(){return this._input.value}}class x extends M{constructor(e){super(e.label),this._input.type="password",this._input.value=e.text?e.text:"",e.placeholder&&(this._input.placeholder=e.placeholder)}getValue(){return this._input.value}}class E extends M{constructor(e){super(e.label),this._editable=e.editable||!1;let t,n=e.current||0;if("number"==typeof n&&(t=Math.max(0,Math.min(n,e.items.length-1)),n=""),this._list=document.createElement("select"),e.items.forEach((e,r)=>{const i=document.createElement("option");r===t&&(i.selected=!0,n=e),i.value=e,i.textContent=e,this._list.appendChild(i)}),e.editable){const t=document.createElement("datalist");t.id="input-dialog-items",t.appendChild(this._list),this._input.type="list",this._input.value=n,this._input.setAttribute("list",t.id),e.placeholder&&(this._input.placeholder=e.placeholder),this.node.appendChild(t)}else this._input.remove(),this.node.appendChild(y.a.wrapSelect(this._list))}getValue(){return this._editable?this._input.value:this._list.value}}var L,S=n(415),T=n(12),O=n(13),I=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};!function(e){function t(e,t){var r,i;const o=t(e);return o.id=e.id,o.title.label||(o.title.label=null!==(r=e.label)&&void 0!==r?r:T.Text.titleCase(o.id.trim())),e.icon&&(o.title.icon=O.a.resolve({icon:e.icon})),void 0!==e.mnemonic&&(o.title.mnemonic=e.mnemonic),null===(i=e.items)||void 0===i||i.filter(e=>!e.disabled).sort((e,t)=>{var n,r;return(null!==(n=e.rank)&&void 0!==n?n:1/0)-(null!==(r=t.rank)&&void 0!==r?r:1/0)}).map(e=>{n(e,o,t)}),o}function n(e,n,r){const{submenu:i}=e,o=I(e,["submenu"]);n.addItem(Object.assign(Object.assign({},o),{submenu:i?t(i,r):null}))}e.createMenus=function(e,n){return e.filter(e=>!e.disabled).sort((e,t)=>{var n,r;return(null!==(n=e.rank)&&void 0!==n?n:1/0)-(null!==(r=t.rank)&&void 0!==r?r:1/0)}).map(e=>t(e,n))},e.addContextItem=function(e,n,r){const{submenu:i}=e,o=I(e,["submenu"]);n.addItem(Object.assign(Object.assign({},o),{submenu:i?t(i,r):null}))},e.updateMenus=function(e,r,i){const a=[];return r.forEach(r=>{const s=e.find(e=>e.id===r.id);s?function e(t,r,i){var a;t.disabled?r.dispose():null===(a=t.items)||void 0===a||a.forEach(t=>{var a,s;const l=null==r?void 0:r.items.find((e,n)=>{var r,i;return e.type===t.type&&e.command===t.command&&(null===(r=e.submenu)||void 0===r?void 0:r.id)===(null===(i=t.submenu)||void 0===i?void 0:i.id)});if(l&&"separator"!==t.type)if(t.disabled)r.removeItem(l);else switch(null!==(a=t.type)&&void 0!==a?a:"command"){case"command":t.command&&(o.JSONExt.deepEqual(l.args,null!==(s=t.args)&&void 0!==s?s:{})||n(t,r,i));break;case"submenu":t.submenu&&e(t.submenu,l.submenu,i)}else n(t,r,i)})}(r,s,i):r.disabled||a.push(t(r,i))}),e.push(...a),a}}(L||(L={}));var k=n(116),D=n(354),N=n(115),j=n(140);const P=new o.Token("@jupyterlab/apputils:ISplashScreen");var z=n(22),R=n(2),B=n(27);class H{constructor(e){this._current=null,this._links=[],this._overrides={},this._overrideProps={},this._outstanding=null,this._pending=0,this._requests={},this._themes={},this._themeChanged=new s.Signal(this);const{host:t,key:n,splash:r,url:i}=e;this.translator=e.translator||z.b,this._trans=this.translator.load("jupyterlab");const o=e.settings;this._base=i,this._host=t,this._splash=r||null,o.load(n).then(e=>{this._settings=e,this._initOverrideProps(),this._settings.changed.connect(this._loadSettings,this),this._loadSettings()})}get theme(){return this._current}get themes(){return Object.keys(this._themes)}get themeChanged(){return this._themeChanged}getCSS(e){var t;return null!==(t=this._overrides[e])&&void 0!==t?t:getComputedStyle(document.documentElement).getPropertyValue("--jp-"+e)}loadCSS(e){const t=this._base,n=T.URLExt.isLocal(e)?T.URLExt.join(t,e):e,r=this._links;return new Promise((e,t)=>{const i=document.createElement("link");i.setAttribute("rel","stylesheet"),i.setAttribute("type","text/css"),i.setAttribute("href",n),i.addEventListener("load",()=>{e(void 0)}),i.addEventListener("error",()=>{t("Stylesheet failed to load: "+n)}),document.body.appendChild(i),r.push(i),this.loadCSSOverrides()})}loadCSSOverrides(){var e;const t=null!==(e=this._settings.user.overrides)&&void 0!==e?e:{};Object.keys(Object.assign(Object.assign({},this._overrides),t)).forEach(e=>{const n=t[e];n&&this.validateCSS(e,n)?document.documentElement.style.setProperty("--jp-"+e,n):(delete t[e],document.documentElement.style.removeProperty("--jp-"+e))}),this._overrides=t}validateCSS(e,t){const n=this._overrideProps[e];return n?!!CSS.supports(n,t)||(console.warn(`CSS validation failed: invalid value.\nkey: '${e}', val: '${t}', prop: '${n}'`),!1):(console.warn(`CSS validation failed: could not find property corresponding to key.\nkey: '${e}', val: '${t}'`),!1)}register(e){const{name:t}=e,n=this._themes;if(n[t])throw new Error("Theme already registered for "+t);return n[t]=e,new B.DisposableDelegate(()=>{delete n[t]})}setCSSOverride(e,t){return this._settings.set("overrides",Object.assign(Object.assign({},this._overrides),{[e]:t}))}setTheme(e){return this._settings.set("theme",e)}isLight(e){return this._themes[e].isLight}incrFontSize(e){return this._incrFontSize(e,!0)}decrFontSize(e){return this._incrFontSize(e,!1)}themeScrollbars(e){return!!this._settings.composite["theme-scrollbars"]&&!!this._themes[e].themeScrollbars}isToggledThemeScrollbars(){return!!this._settings.composite["theme-scrollbars"]}toggleThemeScrollbars(){return this._settings.set("theme-scrollbars",!this._settings.composite["theme-scrollbars"])}getDisplayName(e){var t,n;return null!==(n=null===(t=this._themes[e])||void 0===t?void 0:t.displayName)&&void 0!==n?n:e}_incrFontSize(e,t=!0){var n;const r=(null!==(n=this.getCSS(e))&&void 0!==n?n:"13px").split(/([a-zA-Z]+)/),i=(t?1:-1)*("em"===r[1]?.1:1);return this.setCSSOverride(e,`${Number(r[0])+i}${r[1]}`)}_initOverrideProps(){const e=this._settings.schema.definitions.cssOverrides.properties;Object.keys(e).forEach(t=>{this._overrideProps[t]=e[t].description})}_loadSettings(){const e=this._outstanding,t=this._pending,n=this._requests;t&&(window.clearTimeout(t),this._pending=0);const r=this._settings,i=this._themes,o=r.composite.theme;if(e)return e.then(()=>{this._loadSettings()}).catch(()=>{this._loadSettings()}),void(this._outstanding=null);if(n[o]=n[o]?n[o]+1:1,i[o])return this._outstanding=this._loadTheme(o),void delete n[o];if(n[o]>20){const e=r.default("theme");return delete n[o],i[e]?(console.warn(`Could not load theme ${o}, using default ${e}.`),void(this._outstanding=this._loadTheme(e))):void this._onError(this._trans.__("Neither theme %1 nor default %2 loaded.",o,e))}this._pending=window.setTimeout(()=>{this._loadSettings()},75)}_loadTheme(e){const t=this._current,n=this._links,r=this._themes,i=this._splash?this._splash.show(r[e].isLight):new B.DisposableDelegate(()=>{});n.forEach(e=>{e.parentElement&&e.parentElement.removeChild(e)}),n.length=0;const o=t?r[t].unload():Promise.resolve();return Promise.all([o,r[e].load()]).then(()=>{this._current=e,this._themeChanged.emit({name:"theme",oldValue:t,newValue:e}),this._host.hide(),requestAnimationFrame(()=>{this._host.show(),F.fitAll(this._host),i.dispose()})}).catch(e=>{this._onError(e),i.dispose()})}_onError(e){Object(f.b)({title:this._trans.__("Error Loading Theme"),body:String(e),buttons:[f.a.okButton({label:this._trans.__("OK")})]})}}var F;!function(e){e.fitAll=function e(t){Object(R.each)(t.children(),e),t.fit()}}(F||(F={}));const Y=new o.Token("@jupyterlab/apputils:ISessionContextDialogs"),V=new o.Token("@jupyterlab/apputils:IThemeManager"),U=new o.Token("@jupyterlab/apputils:ISanitizer");var W=n(141),G=n(59),q=n(139);const K=new o.Token("@jupyterlab/apputils:IWindowResolver");class X{get name(){return this._name}resolve(e){return J.resolve(e).then(e=>{this._name=e})}}var J;!function(e){const t="@jupyterlab/statedb:StateDB",n=t+":beacon",r=Math.floor(200+300*Math.random()),i=t+":window";let a=null,s=null;const l=new o.PromiseDelegate,c={};let u=null,d=!1;function h(e){if(null===e)return;const{localStorage:t}=window;t.setItem(i,`${e}-${(new Date).getTime()}`)}function p(){d=!0,a=null,l.reject(`Window name candidate "${s}" already exists`)}e.resolve=function(e){if(d)return l.promise;if(s=e,s in c)return p(),l.promise;const{localStorage:t,setTimeout:i}=window;return i(()=>{if(!d){if(!s||s in c)return p();d=!0,a=null,l.resolve(u=s),h(u)}},r),a=`${Math.random()}-${(new Date).getTime()}`,t.setItem(n,a),l.promise},window.addEventListener("storage",e=>{const{key:t,newValue:r}=e;if(null===r)return;if(t===n&&r!==a&&null!==s)return void h(d?u:s);if(d||t!==i)return;const o=r.replace(/\-\d+$/,"");c[o]=null,s&&!(s in c)||p()})}(J||(J={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return o})),n.d(t,"e",(function(){return a})),n.d(t,"d",(function(){return s})),n.d(t,"c",(function(){return l})),n.d(t,"b",(function(){return c}));var r=n(66),i=n(87);const o=(e,t,n=0)=>{try{for(;n<e.length;n++)e[n](...t)}finally{n<e.length&&o(e,t,n+1)}},a=()=>{},s=(e,t)=>e===t,l=(e,t)=>e===t||null!=e&&null!=t&&e.constructor===t.constructor&&(e instanceof Array&&r.b(e,t)||"object"==typeof e&&i.a(e,t)),c=(e,t)=>{if(null==e||null==t)return s(e,t);if(e.constructor!==t.constructor)return!1;if(e===t)return!0;switch(e.constructor){case ArrayBuffer:e=new Uint8Array(e),t=new Uint8Array(t);case Uint8Array:if(e.byteLength!==t.byteLength)return!1;for(let n=0;n<e.length;n++)if(e[n]!==t[n])return!1;break;case Set:if(e.size!==t.size)return!1;for(const n of e)if(!t.has(n))return!1;break;case Map:if(e.size!==t.size)return!1;for(const n of e.keys())if(!t.has(n)||!c(e.get(n),t.get(n)))return!1;break;case Object:if(i.c(e)!==i.c(t))return!1;for(const n in e)if(!i.b(e,n)||!c(e[n],t[n]))return!1;break;case Array:if(e.length!==t.length)return!1;for(let n=0;n<e.length;n++)if(!c(e[n],t[n]))return!1;break;default:return!1}return!0}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));n(25);const r=Date.now},function(e,t,n){"use strict";n.d(t,"a",(function(){return en})),n.d(t,"b",(function(){return tn})),n.d(t,"c",(function(){return nn})),n.d(t,"d",(function(){return rn})),n.d(t,"e",(function(){return on})),n.d(t,"f",(function(){return an})),n.d(t,"g",(function(){return sn})),n.d(t,"h",(function(){return ln})),n.d(t,"i",(function(){return cn})),n.d(t,"j",(function(){return un})),n.d(t,"k",(function(){return dn})),n.d(t,"l",(function(){return hn})),n.d(t,"m",(function(){return pn})),n.d(t,"n",(function(){return fn})),n.d(t,"o",(function(){return mn})),n.d(t,"p",(function(){return gn})),n.d(t,"q",(function(){return vn})),n.d(t,"r",(function(){return yn})),n.d(t,"s",(function(){return _n})),n.d(t,"t",(function(){return bn})),n.d(t,"u",(function(){return Mn})),n.d(t,"v",(function(){return wn})),n.d(t,"w",(function(){return An})),n.d(t,"x",(function(){return Cn})),n.d(t,"y",(function(){return xn})),n.d(t,"z",(function(){return En})),n.d(t,"A",(function(){return Ln})),n.d(t,"B",(function(){return Sn}));var r=n(13),i=n(497),o=n.n(i),a=n(498),s=n.n(a),l=n(499),c=n.n(l),u=n(500),d=n.n(u),h=n(501),p=n.n(h),f=n(502),m=n.n(f),g=n(503),v=n.n(g),y=n(504),_=n.n(y),b=n(505),M=n.n(b),w=n(506),A=n.n(w),C=n(507),x=n.n(C),E=n(508),L=n.n(E),S=n(509),T=n.n(S),O=n(510),I=n.n(O),k=n(511),D=n.n(k),N=n(512),j=n.n(N),P=n(513),z=n.n(P),R=n(514),B=n.n(R),H=n(515),F=n.n(H),Y=n(516),V=n.n(Y),U=n(517),W=n.n(U),G=n(518),q=n.n(G),K=n(519),X=n.n(K),J=n(520),Q=n.n(J),Z=n(521),$=n.n(Z),ee=n(522),te=n.n(ee),ne=n(523),re=n.n(ne),ie=n(524),oe=n.n(ie),ae=n(525),se=n.n(ae),le=n(526),ce=n.n(le),ue=n(527),de=n.n(ue),he=n(528),pe=n.n(he),fe=n(529),me=n.n(fe),ge=n(530),ve=n.n(ge),ye=n(531),_e=n.n(ye),be=n(532),Me=n.n(be),we=n(533),Ae=n.n(we),Ce=n(534),xe=n.n(Ce),Ee=n(535),Le=n.n(Ee),Se=n(536),Te=n.n(Se),Oe=n(537),Ie=n.n(Oe),ke=n(538),De=n.n(ke),Ne=n(539),je=n.n(Ne),Pe=n(540),ze=n.n(Pe),Re=n(541),Be=n.n(Re),He=n(542),Fe=n.n(He),Ye=n(543),Ve=n.n(Ye),Ue=n(544),We=n.n(Ue),Ge=n(545),qe=n.n(Ge),Ke=n(546),Xe=n.n(Ke),Je=n(547),Qe=n.n(Je),Ze=n(548),$e=n.n(Ze),et=n(549),tt=n.n(et),nt=n(550),rt=n.n(nt),it=n(551),ot=n.n(it),at=n(552),st=n.n(at),lt=n(553),ct=n.n(lt),ut=n(554),dt=n.n(ut),ht=n(555),pt=n.n(ht),ft=n(145),mt=n.n(ft),gt=n(556),vt=n.n(gt),yt=n(557),_t=n.n(yt),bt=n(558),Mt=n.n(bt),wt=n(559),At=n.n(wt),Ct=n(560),xt=n.n(Ct),Et=n(561),Lt=n.n(Et),St=n(562),Tt=n.n(St),Ot=n(563),It=n.n(Ot),kt=n(564),Dt=n.n(kt),Nt=n(565),jt=n.n(Nt),Pt=n(566),zt=n.n(Pt),Rt=n(567),Bt=n.n(Rt),Ht=n(568),Ft=n.n(Ht),Yt=n(569),Vt=n.n(Yt),Ut=n(570),Wt=n.n(Ut),Gt=n(571),qt=n.n(Gt),Kt=n(572),Xt=n.n(Kt),Jt=n(573),Qt=n.n(Jt),Zt=n(574),$t=n.n(Zt);new r.a({name:"ui-components:add",svgstr:o.a}),new r.a({name:"ui-components:bug-dot",svgstr:s.a}),new r.a({name:"ui-components:bug",svgstr:c.a}),new r.a({name:"ui-components:build",svgstr:d.a});const en=new r.a({name:"ui-components:caret-down-empty",svgstr:p.a}),tn=(new r.a({name:"ui-components:caret-down-empty-thin",svgstr:m.a}),new r.a({name:"ui-components:caret-down",svgstr:v.a})),nn=(new r.a({name:"ui-components:caret-left",svgstr:_.a}),new r.a({name:"ui-components:caret-right",svgstr:M.a})),rn=(new r.a({name:"ui-components:caret-up-empty-thin",svgstr:A.a}),new r.a({name:"ui-components:caret-up",svgstr:x.a})),on=(new r.a({name:"ui-components:case-sensitive",svgstr:L.a}),new r.a({name:"ui-components:check",svgstr:T.a})),an=new r.a({name:"ui-components:circle-empty",svgstr:I.a}),sn=new r.a({name:"ui-components:circle",svgstr:D.a}),ln=(new r.a({name:"ui-components:clear",svgstr:j.a}),new r.a({name:"ui-components:close",svgstr:z.a})),cn=(new r.a({name:"ui-components:code",svgstr:B.a}),new r.a({name:"ui-components:console",svgstr:F.a}),new r.a({name:"ui-components:copy",svgstr:V.a}),new r.a({name:"ui-components:copyright",svgstr:W.a}),new r.a({name:"ui-components:cut",svgstr:q.a}),new r.a({name:"ui-components:download",svgstr:X.a}),new r.a({name:"ui-components:edit",svgstr:Q.a}),new r.a({name:"ui-components:ellipses",svgstr:$.a})),un=(new r.a({name:"ui-components:extension",svgstr:te.a}),new r.a({name:"ui-components:fast-forward",svgstr:re.a}),new r.a({name:"ui-components:file",svgstr:oe.a})),dn=(new r.a({name:"ui-components:file-upload",svgstr:se.a}),new r.a({name:"ui-components:filter-list",svgstr:ce.a}),new r.a({name:"ui-components:folder",svgstr:de.a})),hn=(new r.a({name:"ui-components:html5",svgstr:pe.a}),new r.a({name:"ui-components:image",svgstr:me.a})),pn=(new r.a({name:"ui-components:inspector",svgstr:ve.a}),new r.a({name:"ui-components:json",svgstr:_e.a})),fn=new r.a({name:"ui-components:julia",svgstr:Me.a}),mn=(new r.a({name:"ui-components:jupyter-favicon",svgstr:Ae.a}),new r.a({name:"ui-components:jupyter",svgstr:xe.a}),new r.a({name:"ui-components:jupyterlab-wordmark",svgstr:Le.a}),new r.a({name:"ui-components:kernel",svgstr:Te.a})),gn=(new r.a({name:"ui-components:keyboard",svgstr:Ie.a}),new r.a({name:"ui-components:launcher",svgstr:De.a}),new r.a({name:"ui-components:line-form",svgstr:je.a})),vn=(new r.a({name:"ui-components:link",svgstr:ze.a}),new r.a({name:"ui-components:list",svgstr:Be.a}),new r.a({name:"ui-components:listings-info",svgstr:Fe.a}),new r.a({name:"ui-components:markdown",svgstr:Ve.a})),yn=(new r.a({name:"ui-components:new-folder",svgstr:We.a}),new r.a({name:"ui-components:not-trusted",svgstr:qe.a}),new r.a({name:"ui-components:notebook",svgstr:Xe.a})),_n=(new r.a({name:"ui-components:numbering",svgstr:Qe.a}),new r.a({name:"ui-components:offline-bolt",svgstr:$e.a})),bn=(new r.a({name:"ui-components:palette",svgstr:tt.a}),new r.a({name:"ui-components:paste",svgstr:rt.a}),new r.a({name:"ui-components:pdf",svgstr:ot.a})),Mn=new r.a({name:"ui-components:python",svgstr:st.a}),wn=new r.a({name:"ui-components:r-kernel",svgstr:ct.a}),An=(new r.a({name:"ui-components:react",svgstr:dt.a}),new r.a({name:"ui-components:redo",svgstr:pt.a}),new r.a({name:"ui-components:refresh",svgstr:mt.a})),Cn=(new r.a({name:"ui-components:regex",svgstr:vt.a}),new r.a({name:"ui-components:run",svgstr:_t.a}),new r.a({name:"ui-components:running",svgstr:Mt.a}),new r.a({name:"ui-components:save",svgstr:At.a}),new r.a({name:"ui-components:search",svgstr:xt.a})),xn=(new r.a({name:"ui-components:settings",svgstr:Lt.a}),new r.a({name:"ui-components:spreadsheet",svgstr:Tt.a})),En=new r.a({name:"ui-components:stop",svgstr:It.a}),Ln=(new r.a({name:"ui-components:tab",svgstr:Dt.a}),new r.a({name:"ui-components:table-rows",svgstr:jt.a}),new r.a({name:"ui-components:tag",svgstr:zt.a}),new r.a({name:"ui-components:terminal",svgstr:Bt.a})),Sn=(new r.a({name:"ui-components:text-editor",svgstr:Ft.a}),new r.a({name:"ui-components:toc",svgstr:Vt.a}),new r.a({name:"ui-components:tree-view",svgstr:Wt.a}),new r.a({name:"ui-components:trusted",svgstr:qt.a}),new r.a({name:"ui-components:undo",svgstr:Xt.a}),new r.a({name:"ui-components:vega",svgstr:Qt.a}),new r.a({name:"ui-components:yaml",svgstr:$t.a}))},function(e,t){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"==typeof window&&(n=window)}e.exports=n},function(e,t,n){"use strict";(function(e,r){var i,o,a;Object.defineProperty(t,"__esModule",{value:!0}),t.ServerConnection=void 0;const s=n(12);let l,c,u,d;if("undefined"==typeof window){const t=n(623);l=null!==(i=e.fetch)&&void 0!==i?i:t,u=null!==(o=e.Request)&&void 0!==o?o:t.Request,c=null!==(a=e.Headers)&&void 0!==a?a:t.Headers,d=n(624)}else l=fetch,u=Request,c=Headers,d=WebSocket;var h,p;!function(e){e.makeSettings=function(e){return p.makeSettings(e)},e.makeRequest=function(e,t,n){return p.handleRequest(e,t,n)};class t extends Error{constructor(e,t=`Invalid response: ${e.status} ${e.statusText}`,n=""){super(t),this.response=e,this.traceback=n}static async create(e){try{const n=await e.json();return n.traceback&&console.error(n.traceback),n.message?new t(e,n.message):new t(e)}catch(n){return console.debug(n),new t(e)}}}e.ResponseError=t;class n extends TypeError{constructor(e){super(e.message),this.stack=e.stack}}e.NetworkError=n}(h=t.ServerConnection||(t.ServerConnection={})),function(e){e.makeSettings=function(e={}){const t=s.PageConfig.getBaseUrl(),n=s.PageConfig.getWsUrl(),i=s.URLExt.normalize(e.baseUrl)||t;let o=e.wsUrl;return o||i!==t||(o=n),o||0!==i.indexOf("http")||(o="ws"+i.slice(4)),o=null!=o?o:n,Object.assign(Object.assign({init:{cache:"no-store",credentials:"same-origin"},fetch:l,Headers:c,Request:u,WebSocket:d,token:s.PageConfig.getToken(),appUrl:s.PageConfig.getOption("appUrl"),appendToken:"undefined"==typeof window||void 0!==r.env.JEST_WORKER_ID||s.URLExt.getHostName(t)!==s.URLExt.getHostName(o)},e),{baseUrl:i,wsUrl:o})},e.handleRequest=function(e,t,n){var r;if(0!==e.indexOf(n.baseUrl))throw new Error("Can only be used for notebook server requests");"no-store"===(null!==(r=t.cache)&&void 0!==r?r:n.init.cache)&&(e+=(/\?/.test(e)?"&":"?")+(new Date).getTime());const i=new n.Request(e,Object.assign(Object.assign({},n.init),t));let o=!1;if(n.token&&(o=!0,i.headers.append("Authorization","token "+n.token)),"undefined"!=typeof document&&(null===document||void 0===document?void 0:document.cookie)){const e=function(e){const t=document.cookie.match("\\b"+e+"=([^;]*)\\b");return null==t?void 0:t[1]}("_xsrf");void 0!==e&&(o=!0,i.headers.append("X-XSRFToken",e))}return!i.headers.has("Content-Type")&&o&&i.headers.set("Content-Type","application/json"),n.fetch.call(null,i).catch(e=>{throw new h.NetworkError(e)})}}(p||(p={}))}).call(this,n(55),n(61))},function(e,t,n){"use strict";var r=this&&this.__assign||function(){return(r=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0});var o=n(68),a=n(39),s=n(31),l=n(49),c=n(50),u=n(37),d=n(23),h=n(72),p=n(58),f=n(135),m=n(47),g={},v={fontfamily:1,fontsize:1,fontweight:1,fontstyle:1,color:1,background:1,id:1,class:1,href:1,style:1};function y(e,t){var n=e.stack.env,r=n.inRoot;n.inRoot=!0;var i=new l.default(t,n,e.configuration),o=i.mml(),a=i.stack.global;if(a.leftRoot||a.upRoot){var s={};a.leftRoot&&(s.width=a.leftRoot),a.upRoot&&(s.voffset=a.upRoot,s.height=a.upRoot),o=e.create("node","mpadded",[o],s)}return n.inRoot=r,o}g.Open=function(e,t){e.Push(e.itemFactory.create("open"))},g.Close=function(e,t){e.Push(e.itemFactory.create("close"))},g.Tilde=function(e,t){e.Push(e.create("token","mtext",{},f.entities.nbsp))},g.Space=function(e,t){},g.Superscript=function(e,t){var n,r,o;e.GetNext().match(/\d/)&&(e.string=e.string.substr(0,e.i+1)+" "+e.string.substr(e.i+1));var l=e.stack.Top();l.isKind("prime")?(o=(n=i(l.Peek(2),2))[0],r=n[1],e.stack.Pop()):(o=e.stack.Prev())||(o=e.create("token","mi",{},""));var c=a.default.getProperty(o,"movesupsub"),u=a.default.isType(o,"msubsup")?o.sup:o.over;if(a.default.isType(o,"msubsup")&&!a.default.isType(o,"msup")&&a.default.getChildAt(o,o.sup)||a.default.isType(o,"munderover")&&!a.default.isType(o,"mover")&&a.default.getChildAt(o,o.over)&&!a.default.getProperty(o,"subsupOK"))throw new s.default("DoubleExponent","Double exponent: use braces to clarify");a.default.isType(o,"msubsup")&&!a.default.isType(o,"msup")||(c?((!a.default.isType(o,"munderover")||a.default.isType(o,"mover")||a.default.getChildAt(o,o.over))&&(o=e.create("node","munderover",[o],{movesupsub:!0})),u=o.over):u=(o=e.create("node","msubsup",[o])).sup),e.Push(e.itemFactory.create("subsup",o).setProperties({position:u,primes:r,movesupsub:c}))},g.Subscript=function(e,t){var n,r,o;e.GetNext().match(/\d/)&&(e.string=e.string.substr(0,e.i+1)+" "+e.string.substr(e.i+1));var l=e.stack.Top();l.isKind("prime")?(o=(n=i(l.Peek(2),2))[0],r=n[1],e.stack.Pop()):(o=e.stack.Prev())||(o=e.create("token","mi",{},""));var c=a.default.getProperty(o,"movesupsub"),u=a.default.isType(o,"msubsup")?o.sub:o.under;if(a.default.isType(o,"msubsup")&&!a.default.isType(o,"msup")&&a.default.getChildAt(o,o.sub)||a.default.isType(o,"munderover")&&!a.default.isType(o,"mover")&&a.default.getChildAt(o,o.under)&&!a.default.getProperty(o,"subsupOK"))throw new s.default("DoubleSubscripts","Double subscripts: use braces to clarify");a.default.isType(o,"msubsup")&&!a.default.isType(o,"msup")||(c?((!a.default.isType(o,"munderover")||a.default.isType(o,"mover")||a.default.getChildAt(o,o.under))&&(o=e.create("node","munderover",[o],{movesupsub:!0})),u=o.under):u=(o=e.create("node","msubsup",[o])).sub),e.Push(e.itemFactory.create("subsup",o).setProperties({position:u,primes:r,movesupsub:c}))},g.Prime=function(e,t){var n=e.stack.Prev();if(n||(n=e.create("node","mi")),a.default.isType(n,"msubsup")&&!a.default.isType(n,"msup")&&a.default.getChildAt(n,n.sup))throw new s.default("DoubleExponentPrime","Prime causes double exponent: use braces to clarify");var r="";e.i--;do{r+=f.entities.prime,e.i++,t=e.GetNext()}while("'"===t||t===f.entities.rsquo);r=["","′","″","‴","⁗"][r.length]||r;var i=e.create("token","mo",{variantForm:!0},r);e.Push(e.itemFactory.create("prime",n,i))},g.Comment=function(e,t){for(;e.i<e.string.length&&"\n"!==e.string.charAt(e.i);)e.i++},g.Hash=function(e,t){throw new s.default("CantUseHash1","You can't use 'macro parameter character #' in math mode")},g.MathFont=function(e,t,n){var i=e.GetArgument(t),o=new l.default(i,r(r({},e.stack.env),{font:n,multiLetterIdentifiers:!0}),e.configuration).mml();e.Push(e.create("node","TeXAtom",[o]))},g.SetFont=function(e,t,n){e.stack.env.font=n},g.SetStyle=function(e,t,n,r,i){e.stack.env.style=n,e.stack.env.level=i,e.Push(e.itemFactory.create("style").setProperty("styles",{displaystyle:r,scriptlevel:i}))},g.SetSize=function(e,t,n){e.stack.env.size=n,e.Push(e.itemFactory.create("style").setProperty("styles",{mathsize:p.em(n)}))},g.Spacer=function(e,t,n){var r=e.create("node","mspace",[],{width:p.em(n)}),i=e.create("node","mstyle",[r],{scriptlevel:0});e.Push(i)},g.LeftRight=function(e,t){var n=t.substr(1);e.Push(e.itemFactory.create(n,e.GetDelimiter(t),e.stack.env.color))},g.NamedFn=function(e,t,n){n||(n=t.substr(1));var r=e.create("token","mi",{texClass:d.TEXCLASS.OP},n);e.Push(e.itemFactory.create("fn",r))},g.NamedOp=function(e,t,n){n||(n=t.substr(1)),n=n.replace(/&thinsp;/," ");var r=e.create("token","mo",{movablelimits:!0,movesupsub:!0,form:c.TexConstant.Form.PREFIX,texClass:d.TEXCLASS.OP},n);e.Push(r)},g.Limits=function(e,t,n){var r=e.stack.Prev(!0);if(!r||a.default.getTexClass(a.default.getCoreMO(r))!==d.TEXCLASS.OP&&null==a.default.getProperty(r,"movesupsub"))throw new s.default("MisplacedLimits","%1 is allowed only on operators",e.currentCS);var i,o=e.stack.Top();a.default.isType(r,"munderover")&&!n?(i=e.create("node","msubsup"),a.default.copyChildren(r,i),r=o.Last=i):a.default.isType(r,"msubsup")&&n&&(i=e.create("node","munderover"),a.default.copyChildren(r,i),r=o.Last=i),a.default.setProperty(r,"movesupsub",!!n),a.default.setProperties(a.default.getCoreMO(r),{movablelimits:!1}),(a.default.getAttribute(r,"movablelimits")||a.default.getProperty(r,"movablelimits"))&&a.default.setProperties(r,{movablelimits:!1})},g.Over=function(e,t,n,r){var i=e.itemFactory.create("over").setProperty("name",e.currentCS);n||r?(i.setProperty("open",n),i.setProperty("close",r)):t.match(/withdelims$/)&&(i.setProperty("open",e.GetDelimiter(t)),i.setProperty("close",e.GetDelimiter(t))),t.match(/^\\above/)?i.setProperty("thickness",e.GetDimen(t)):(t.match(/^\\atop/)||n||r)&&i.setProperty("thickness",0),e.Push(i)},g.Frac=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t),i=e.create("node","mfrac",[n,r]);e.Push(i)},g.Sqrt=function(e,t){var n=e.GetBrackets(t),r=e.GetArgument(t);"\\frac"===r&&(r+="{"+e.GetArgument(r)+"}{"+e.GetArgument(r)+"}");var i=new l.default(r,e.stack.env,e.configuration).mml();i=n?e.create("node","mroot",[i,y(e,n)]):e.create("node","msqrt",[i]),e.Push(i)},g.Root=function(e,t){var n=e.GetUpTo(t,"\\of"),r=e.ParseArg(t),i=e.create("node","mroot",[r,y(e,n)]);e.Push(i)},g.MoveRoot=function(e,t,n){if(!e.stack.env.inRoot)throw new s.default("MisplacedMoveRoot","%1 can appear only within a root",e.currentCS);if(e.stack.global[n])throw new s.default("MultipleMoveRoot","Multiple use of %1",e.currentCS);var r=e.GetArgument(t);if(!r.match(/-?[0-9]+/))throw new s.default("IntegerArg","The argument to %1 must be an integer",e.currentCS);"-"!==(r=parseInt(r,10)/15+"em").substr(0,1)&&(r="+"+r),e.stack.global[n]=r},g.Accent=function(e,t,n,i){var o=e.ParseArg(t),s=r(r({},u.default.getFontDef(e)),{accent:!0,mathaccent:!0}),l=a.default.createEntity(n),c=e.create("token","mo",s,l);a.default.setAttribute(c,"stretchy",!!i);var d=a.default.isEmbellished(o)?a.default.getCoreMO(o):o;a.default.isType(d,"mo")&&a.default.setProperties(d,{movablelimits:!1});var h=e.create("node","munderover");a.default.setChild(h,0,o),a.default.setChild(h,1,null),a.default.setChild(h,2,c);var p=e.create("node","TeXAtom",[h]);e.Push(p)},g.UnderOver=function(e,t,n,r){var i=a.default.createEntity(n),o=e.create("token","mo",{stretchy:!0,accent:!0},i),s="o"===t.charAt(1)?"over":"under",l=e.ParseArg(t);e.Push(u.default.underOver(e,l,o,s,r))},g.Overset=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t);u.default.checkMovableLimits(r);var i=e.create("node","mover",[r,n]);e.Push(i)},g.Underset=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t);u.default.checkMovableLimits(r);var i=e.create("node","munder",[r,n]);e.Push(i)},g.Overunderset=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t),i=e.ParseArg(t);u.default.checkMovableLimits(i);var o=e.create("node","munderover",[i,r,n]);e.Push(o)},g.TeXAtom=function(e,t,n){var r,i,o,a={texClass:n};if(n===d.TEXCLASS.OP){a.movesupsub=a.movablelimits=!0;var s=e.GetArgument(t),u=s.match(/^\s*\\rm\s+([a-zA-Z0-9 ]+)$/);u?(a.mathvariant=c.TexConstant.Variant.NORMAL,i=e.create("token","mi",a,u[1])):(o=new l.default(s,e.stack.env,e.configuration).mml(),i=e.create("node","TeXAtom",[o],a)),r=e.itemFactory.create("fn",i)}else o=e.ParseArg(t),r=e.create("node","TeXAtom",[o],a);e.Push(r)},g.MmlToken=function(e,t){var n,r=e.GetArgument(t),i=e.GetBrackets(t,"").replace(/^\s+/,""),o=e.GetArgument(t),l={};try{n=e.create("node",r)}catch(e){n=null}if(!n||!n.isToken)throw new s.default("NotMathMLToken","%1 is not a token element",r);for(;""!==i;){var c=i.match(/^([a-z]+)\s*=\s*('[^']*'|"[^"]*"|[^ ,]*)\s*,?\s*/i);if(!c)throw new s.default("InvalidMathMLAttr","Invalid MathML attribute: %1",i);if(!n.attributes.hasDefault(c[1])&&!v[c[1]])throw new s.default("UnknownAttrForElement","%1 is not a recognized attribute for %2",c[1],r);var d=u.default.MmlFilterAttribute(e,c[1],c[2].replace(/^(['"])(.*)\1$/,"$2"));d&&("true"===d.toLowerCase()?d=!0:"false"===d.toLowerCase()&&(d=!1),l[c[1]]=d),i=i.substr(c[0].length)}var h=e.create("text",o);n.appendChild(h),a.default.setProperties(n,l),e.Push(n)},g.Strut=function(e,t){var n=e.create("node","mrow"),r=e.create("node","mpadded",[n],{height:"8.6pt",depth:"3pt",width:0});e.Push(r)},g.Phantom=function(e,t,n,r){var i=e.create("node","mphantom",[e.ParseArg(t)]);(n||r)&&(i=e.create("node","mpadded",[i]),r&&(a.default.setAttribute(i,"height",0),a.default.setAttribute(i,"depth",0)),n&&a.default.setAttribute(i,"width",0));var o=e.create("node","TeXAtom",[i]);e.Push(o)},g.Smash=function(e,t){var n=u.default.trimSpaces(e.GetBrackets(t,"")),r=e.create("node","mpadded",[e.ParseArg(t)]);switch(n){case"b":a.default.setAttribute(r,"depth",0);break;case"t":a.default.setAttribute(r,"height",0);break;default:a.default.setAttribute(r,"height",0),a.default.setAttribute(r,"depth",0)}var i=e.create("node","TeXAtom",[r]);e.Push(i)},g.Lap=function(e,t){var n=e.create("node","mpadded",[e.ParseArg(t)],{width:0});"\\llap"===t&&a.default.setAttribute(n,"lspace","-1width");var r=e.create("node","TeXAtom",[n]);e.Push(r)},g.RaiseLower=function(e,t){var n=e.GetDimen(t),r=e.itemFactory.create("position").setProperties({name:e.currentCS,move:"vertical"});"-"===n.charAt(0)&&(n=n.slice(1),t="raise"===t.substr(1)?"\\lower":"\\raise"),"\\lower"===t?(r.setProperty("dh","-"+n),r.setProperty("dd","+"+n)):(r.setProperty("dh","+"+n),r.setProperty("dd","-"+n)),e.Push(r)},g.MoveLeftRight=function(e,t){var n=e.GetDimen(t),r="-"===n.charAt(0)?n.slice(1):"-"+n;if("\\moveleft"===t){var i=n;n=r,r=i}e.Push(e.itemFactory.create("position").setProperties({name:e.currentCS,move:"horizontal",left:e.create("node","mspace",[],{width:n}),right:e.create("node","mspace",[],{width:r})}))},g.Hskip=function(e,t){var n=e.create("node","mspace",[],{width:e.GetDimen(t)});e.Push(n)},g.Nonscript=function(e,t){e.Push(e.itemFactory.create("nonscript"))},g.Rule=function(e,t,n){var r={width:e.GetDimen(t),height:e.GetDimen(t),depth:e.GetDimen(t)};"blank"!==n&&(r.mathbackground=e.stack.env.color||"black");var i=e.create("node","mspace",[],r);e.Push(i)},g.rule=function(e,t){var n=e.GetBrackets(t),r=e.GetDimen(t),i=e.GetDimen(t),o=e.create("node","mspace",[],{width:r,height:i,mathbackground:e.stack.env.color||"black"});n&&(o=e.create("node","mpadded",[o],{voffset:n}),n.match(/^\-/)?(a.default.setAttribute(o,"height",n),a.default.setAttribute(o,"depth","+"+n.substr(1))):a.default.setAttribute(o,"height","+"+n)),e.Push(o)},g.MakeBig=function(e,t,n,r){var i=String(r*=1.2/.85).replace(/(\.\d\d\d).+/,"$1")+"em",o=e.GetDelimiter(t,!0),a=e.create("token","mo",{minsize:i,maxsize:i,fence:!0,stretchy:!0,symmetric:!0},o),s=e.create("node","TeXAtom",[a],{texClass:n});e.Push(s)},g.BuildRel=function(e,t){var n=e.ParseUpTo(t,"\\over"),r=e.ParseArg(t),i=e.create("node","munderover");a.default.setChild(i,0,r),a.default.setChild(i,1,null),a.default.setChild(i,2,n);var o=e.create("node","TeXAtom",[i],{texClass:d.TEXCLASS.REL});e.Push(o)},g.HBox=function(e,t,n,r){e.PushAll(u.default.internalMath(e,e.GetArgument(t),n,r))},g.FBox=function(e,t){var n=u.default.internalMath(e,e.GetArgument(t)),r=e.create("node","menclose",n,{notation:"box"});e.Push(r)},g.FrameBox=function(e,t){var n=e.GetBrackets(t),r=e.GetBrackets(t)||"c",i=u.default.internalMath(e,e.GetArgument(t));n&&(i=[e.create("node","mpadded",i,{width:n,"data-align":m.lookup(r,{l:"left",r:"right"},"center")})]);var o=e.create("node","TeXAtom",[e.create("node","menclose",i,{notation:"box"})],{texClass:d.TEXCLASS.ORD});e.Push(o)},g.Not=function(e,t){e.Push(e.itemFactory.create("not"))},g.Dots=function(e,t){var n=a.default.createEntity("2026"),r=a.default.createEntity("22EF"),i=e.create("token","mo",{stretchy:!1},n),o=e.create("token","mo",{stretchy:!1},r);e.Push(e.itemFactory.create("dots").setProperties({ldots:i,cdots:o}))},g.Matrix=function(e,t,n,r,i,o,a,l,c,u){var d=e.GetNext();if(""===d)throw new s.default("MissingArgFor","Missing argument for %1",e.currentCS);"{"===d?e.i++:(e.string=d+"}"+e.string.slice(e.i+1),e.i=0);var h=e.itemFactory.create("array").setProperty("requireClose",!0);h.arraydef={rowspacing:a||"4pt",columnspacing:o||"1em"},c&&h.setProperty("isCases",!0),u&&(h.setProperty("isNumbered",!0),h.arraydef.side=u),(n||r)&&(h.setProperty("open",n),h.setProperty("close",r)),"D"===l&&(h.arraydef.displaystyle=!0),null!=i&&(h.arraydef.columnalign=i),e.Push(h)},g.Entry=function(e,t){e.Push(e.itemFactory.create("cell").setProperties({isEntry:!0,name:t}));var n=e.stack.Top(),r=n.getProperty("casesEnv");if(n.getProperty("isCases")||r){for(var i=e.string,o=0,a=-1,l=e.i,c=i.length,d=r?new RegExp("^\\\\end\\s*\\{"+r.replace(/\*/,"\\*")+"\\}"):null;l<c;){var h=i.charAt(l);if("{"===h)o++,l++;else if("}"===h)0===o?c=0:(0===--o&&a<0&&(a=l-e.i),l++);else{if("&"===h&&0===o)throw new s.default("ExtraAlignTab","Extra alignment tab in \\cases text");if("\\"===h){var p=i.substr(l);p.match(/^((\\cr)[^a-zA-Z]|\\\\)/)||d&&p.match(d)?c=0:l+=2}else l++}}var f=i.substr(e.i,l-e.i);if(!f.match(/^\s*\\text[^a-zA-Z]/)||a!==f.replace(/\s+$/,"").length-1){var m=u.default.internalMath(e,u.default.trimSpaces(f),0);e.PushAll(m),e.i=l}}},g.Cr=function(e,t){e.Push(e.itemFactory.create("cell").setProperties({isCR:!0,name:t}))},g.CrLaTeX=function(e,t,n){var r;if(void 0===n&&(n=!1),!n&&("*"===e.string.charAt(e.i)&&e.i++,"["===e.string.charAt(e.i))){var a=e.GetBrackets(t,""),l=i(u.default.matchDimen(a),2),d=l[0],h=l[1];if(a&&!d)throw new s.default("BracketMustBeDimension","Bracket argument to %1 must be a dimension",e.currentCS);r=d+h}e.Push(e.itemFactory.create("cell").setProperties({isCR:!0,name:t,linebreak:!0}));var p,f=e.stack.Top();f instanceof o.ArrayItem?r&&f.addRowSpacing(r):(r&&(p=e.create("node","mspace",[],{depth:r}),e.Push(p)),p=e.create("node","mspace",[],{linebreak:c.TexConstant.LineBreak.NEWLINE}),e.Push(p))},g.HLine=function(e,t,n){null==n&&(n="solid");var r=e.stack.Top();if(!(r instanceof o.ArrayItem)||r.Size())throw new s.default("Misplaced","Misplaced %1",e.currentCS);if(r.table.length){for(var i=r.arraydef.rowlines?r.arraydef.rowlines.split(/ /):[];i.length<r.table.length;)i.push("none");i[r.table.length-1]=n,r.arraydef.rowlines=i.join(" ")}else r.frame.push("top")},g.HFill=function(e,t){var n=e.stack.Top();if(!(n instanceof o.ArrayItem))throw new s.default("UnsupportedHFill","Unsupported use of %1",e.currentCS);n.hfill.push(n.Size())},g.BeginEnd=function(e,t){var n=e.GetArgument(t);if(n.match(/\\/i))throw new s.default("InvalidEnv","Invalid environment name '%1'",n);var r=e.configuration.handlers.get("environment").lookup(n);if(r&&"\\end"===t){if(!r.args[0]){var i=e.itemFactory.create("end").setProperty("name",n);return void e.Push(i)}e.stack.env.closing=n}u.default.checkMaxMacros(e,!1),e.parse("environment",[e,n])},g.Array=function(e,t,n,r,i,o,a,s,l){i||(i=e.GetArgument("\\begin{"+t.getName()+"}"));var c=("c"+i).replace(/[^clr|:]/g,"").replace(/[^|:]([|:])+/g,"$1");i=(i=i.replace(/[^clr]/g,"").split("").join(" ")).replace(/l/g,"left").replace(/r/g,"right").replace(/c/g,"center");var u=e.itemFactory.create("array");return u.arraydef={columnalign:i,columnspacing:o||"1em",rowspacing:a||"4pt"},c.match(/[|:]/)&&(c.charAt(0).match(/[|:]/)&&(u.frame.push("left"),u.dashed=":"===c.charAt(0)),c.charAt(c.length-1).match(/[|:]/)&&u.frame.push("right"),c=c.substr(1,c.length-2),u.arraydef.columnlines=c.split("").join(" ").replace(/[^|: ]/g,"none").replace(/\|/g,"solid").replace(/:/g,"dashed")),n&&u.setProperty("open",e.convertDelimiter(n)),r&&u.setProperty("close",e.convertDelimiter(r)),"'"===(s||"").charAt(1)&&(u.arraydef["data-cramped"]=!0,s=s.charAt(0)),"D"===s?u.arraydef.displaystyle=!0:s&&(u.arraydef.displaystyle=!1),"S"===s&&(u.arraydef.scriptlevel=1),l&&(u.arraydef.useHeight=!1),e.Push(t),u},g.AlignedArray=function(e,t){var n=e.GetBrackets("\\begin{"+t.getName()+"}"),r=g.Array(e,t);return u.default.setArrayAlign(r,n)},g.Equation=function(e,t,n){return e.Push(t),u.default.checkEqnEnv(e),e.itemFactory.create("equation",n).setProperty("name",t.getName())},g.EqnArray=function(e,t,n,r,i,o){e.Push(t),r&&u.default.checkEqnEnv(e),i=(i=i.replace(/[^clr]/g,"").split("").join(" ")).replace(/l/g,"left").replace(/r/g,"right").replace(/c/g,"center");var a=e.itemFactory.create("eqnarray",t.getName(),n,r,e.stack.global);return a.arraydef={displaystyle:!0,columnalign:i,columnspacing:o||"1em",rowspacing:"3pt",side:e.options.tagSide,minlabelspacing:e.options.tagIndent},a},g.HandleNoTag=function(e,t){e.tags.notag()},g.HandleLabel=function(e,t){var n=e.GetArgument(t);if(""!==n&&!e.tags.refUpdate){if(e.tags.label)throw new s.default("MultipleCommand","Multiple %1",e.currentCS);if(e.tags.label=n,(e.tags.allLabels[n]||e.tags.labels[n])&&!e.options.ignoreDuplicateLabels)throw new s.default("MultipleLabel","Label '%1' multiply defined",n);e.tags.labels[n]=new h.Label}},g.HandleRef=function(e,t,n){var r=e.GetArgument(t),i=e.tags.allLabels[r]||e.tags.labels[r];i||(e.tags.refUpdate||(e.tags.redo=!0),i=new h.Label);var o=i.tag;n&&(o=e.tags.formatTag(o));var a=e.create("node","mrow",u.default.internalMath(e,o),{href:e.tags.formatUrl(i.id,e.options.baseURL),class:"MathJax_ref"});e.Push(a)},g.Macro=function(e,t,n,r,i){if(r){var o=[];if(null!=i){var a=e.GetBrackets(t);o.push(null==a?i:a)}for(var s=o.length;s<r;s++)o.push(e.GetArgument(t));n=u.default.substituteArgs(e,o,n)}e.string=u.default.addArgs(e,n,e.string.slice(e.i)),e.i=0,u.default.checkMaxMacros(e)},g.MathChoice=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t),i=e.ParseArg(t),o=e.ParseArg(t);e.Push(e.create("node","MathChoice",[n,r,i,o]))},t.default=g},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.px=t.emRounded=t.em=t.percent=t.length2em=t.MATHSPACE=t.RELUNITS=t.UNITS=t.BIGDIMEN=void 0,t.BIGDIMEN=1e6,t.UNITS={px:1,in:96,cm:96/2.54,mm:96/25.4},t.RELUNITS={em:1,ex:.431,pt:.1,pc:1.2,mu:1/18},t.MATHSPACE={veryverythinmathspace:1/18,verythinmathspace:2/18,thinmathspace:3/18,mediummathspace:4/18,thickmathspace:5/18,verythickmathspace:6/18,veryverythickmathspace:7/18,negativeveryverythinmathspace:-1/18,negativeverythinmathspace:-2/18,negativethinmathspace:-3/18,negativemediummathspace:-4/18,negativethickmathspace:-5/18,negativeverythickmathspace:-6/18,negativeveryverythickmathspace:-7/18,thin:.04,medium:.06,thick:.1,normal:1,big:2,small:1/Math.sqrt(2),infinity:t.BIGDIMEN},t.length2em=function(e,n,r,i){if(void 0===n&&(n=0),void 0===r&&(r=1),void 0===i&&(i=16),"string"!=typeof e&&(e=String(e)),""===e||null==e)return n;if(t.MATHSPACE[e])return t.MATHSPACE[e];var o=e.match(/^\s*([-+]?(?:\.\d+|\d+(?:\.\d*)?))?(pt|em|ex|mu|px|pc|in|mm|cm|%)?/);if(!o)return n;var a=parseFloat(o[1]||"1"),s=o[2];return t.UNITS.hasOwnProperty(s)?a*t.UNITS[s]/i/r:t.RELUNITS.hasOwnProperty(s)?a*t.RELUNITS[s]:"%"===s?a/100*n:a*n},t.percent=function(e){return(100*e).toFixed(1).replace(/\.?0+$/,"")+"%"},t.em=function(e){return Math.abs(e)<.001?"0":e.toFixed(3).replace(/\.?0+$/,"")+"em"},t.emRounded=function(e,t){return void 0===t&&(t=16),e=(Math.round(e*t)+.05)/t,Math.abs(e)<.001?"0em":e.toFixed(3).replace(/\.?0+$/,"")+"em"},t.px=function(e,n,r){return void 0===n&&(n=-t.BIGDIMEN),void 0===r&&(r=16),e*=r,n&&e<n&&(e=n),Math.abs(e)<.1?"0":e.toFixed(1).replace(/\.0$/,"")+"px"}},function(e,t,n){"use strict";n.d(t,"a",(function(){return l})),n.d(t,"d",(function(){return c})),n.d(t,"b",(function(){return u})),n.d(t,"c",(function(){return d}));var r=n(8),i=n(4),o=n(3),a=n(0),s=n(34);class l extends o.Widget{static create(e){return new class extends l{render(){return e}}}onUpdateRequest(e){this.renderPromise=this.renderDOM()}onAfterAttach(e){r.c.sendMessage(this,o.Widget.Msg.UpdateRequest)}onBeforeDetach(e){s.unmountComponentAtNode(this.node)}renderDOM(){return new Promise(e=>{const t=this.render();(Array.isArray(t)||t)&&s.render(t,this.node,e)})}}class c extends l{constructor(e){super(),this._modelChanged=new i.Signal(this),this.model=null!=e?e:null}get modelChanged(){return this._modelChanged}set model(e){this._model!==e&&(this._model&&this._model.stateChanged.disconnect(this.update,this),this._model=e,e&&e.stateChanged.connect(this.update,this),this.update(),this._modelChanged.emit(void 0))}get model(){return this._model}dispose(){this.isDisposed||(this._model=null,super.dispose())}}class u extends a.Component{constructor(e){super(e),this.slot=(e,t)=>{this.props.shouldUpdate&&!this.props.shouldUpdate(e,t)||this.setState({value:[e,t]})},this.state={value:[this.props.initialSender,this.props.initialArgs]}}componentDidMount(){this.props.signal.connect(this.slot)}componentWillUnmount(){this.props.signal.disconnect(this.slot)}render(){return this.props.children(...this.state.value)}}class d{constructor(){this.stateChanged=new i.Signal(this),this._isDisposed=!1}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,i.Signal.clearData(this))}}},,function(e,t){var n,r,i=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function a(){throw new Error("clearTimeout has not been defined")}function s(e){if(n===setTimeout)return setTimeout(e,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(e,0);try{return n(e,0)}catch(t){try{return n.call(null,e,0)}catch(t){return n.call(this,e,0)}}}!function(){try{n="function"==typeof setTimeout?setTimeout:o}catch(e){n=o}try{r="function"==typeof clearTimeout?clearTimeout:a}catch(e){r=a}}();var l,c=[],u=!1,d=-1;function h(){u&&l&&(u=!1,l.length?c=l.concat(c):d=-1,c.length&&p())}function p(){if(!u){var e=s(h);u=!0;for(var t=c.length;t;){for(l=c,c=[];++d<t;)l&&l[d].run();d=-1,t=c.length}l=null,u=!1,function(e){if(r===clearTimeout)return clearTimeout(e);if((r===a||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(e);try{r(e)}catch(t){try{return r.call(null,e)}catch(t){return r.call(this,e)}}}(e)}}function f(e,t){this.fun=e,this.array=t}function m(){}i.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)t[n-1]=arguments[n];c.push(new f(e,t)),1!==c.length||u||s(p)},f.prototype.run=function(){this.fun.apply(null,this.array)},i.title="browser",i.browser=!0,i.env={},i.argv=[],i.version="",i.versions={},i.on=m,i.addListener=m,i.once=m,i.off=m,i.removeListener=m,i.removeAllListeners=m,i.emit=m,i.prependListener=m,i.prependOnceListener=m,i.listeners=function(e){return[]},i.binding=function(e){throw new Error("process.binding is not supported")},i.cwd=function(){return"/"},i.chdir=function(e){throw new Error("process.chdir is not supported")},i.umask=function(){return 0}},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.split=t.isPercent=t.unicodeString=t.unicodeChars=t.quotePattern=t.sortLength=void 0,t.sortLength=function(e,t){return e.length!==t.length?t.length-e.length:e===t?0:e<t?-1:1},t.quotePattern=function(e){return e.replace(/([\^$(){}+*?\-|\[\]\:\\])/g,"\\$1")},t.unicodeChars=function(e){return Array.from(e).map((function(e){return e.codePointAt(0)}))},t.unicodeString=function(e){return String.fromCodePoint.apply(String,i([],r(e)))},t.isPercent=function(e){return!!e.match(/%\s*$/)},t.split=function(e){return e.trim().split(/\s+/)}},function(e,t,n){"use strict";var r=s(n(722)),i=s(n(727)),o=s(n(390)),a=s(n(388));function s(e){return e&&e.__esModule?e:{default:e}}e.exports={Transition:a.default,TransitionGroup:o.default,ReplaceTransition:i.default,CSSTransition:r.default}},function(e,t,n){"use strict";n.r(t),function(e,r){n.d(t,"Debouncer",(function(){return g})),n.d(t,"Poll",(function(){return f})),n.d(t,"RateLimiter",(function(){return m})),n.d(t,"Throttler",(function(){return v}));var i=n(6),o=n(4),a=function(e,t){return(a=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)};function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}a(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}var l=function(){return(l=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function c(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{l(r.next(e))}catch(e){o(e)}}function s(e){try{l(r.throw(e))}catch(e){o(e)}}function l(e){var t;e.done?i(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,s)}l((r=r.apply(e,t||[])).next())}))}function u(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}var d,h="function"==typeof requestAnimationFrame?requestAnimationFrame:e,p="function"==typeof cancelAnimationFrame?cancelAnimationFrame:r,f=function(){function e(e){var t=this;this._disposed=new o.Signal(this),this._tick=new i.PromiseDelegate,this._ticked=new o.Signal(this),this._timeout=-1,this._factory=e.factory,this._standby=e.standby||d.DEFAULT_STANDBY,this._state=l(l({},d.DEFAULT_STATE),{timestamp:(new Date).getTime()});var n=e.frequency||{},r=Math.max(n.interval||0,n.max||0,d.DEFAULT_FREQUENCY.max);this.frequency=l(l(l({},d.DEFAULT_FREQUENCY),n),{max:r}),this.name=e.name||d.DEFAULT_NAME,"auto"in e&&!e.auto||h((function(){t.start()}))}return Object.defineProperty(e.prototype,"disposed",{get:function(){return this._disposed},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"frequency",{get:function(){return this._frequency},set:function(t){if(!this.isDisposed&&!i.JSONExt.deepEqual(t,this.frequency||{})){var n=t.backoff,r=t.interval,o=t.max;if(r=Math.round(r),o=Math.round(o),"number"==typeof n&&n<1)throw new Error("Poll backoff growth factor must be at least 1");if((r<0||r>o)&&r!==e.NEVER)throw new Error("Poll interval must be between 0 and max");if(o>e.MAX_INTERVAL&&o!==e.NEVER)throw new Error("Max interval must be less than "+e.MAX_INTERVAL);this._frequency={backoff:n,interval:r,max:o}}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"isDisposed",{get:function(){return"disposed"===this.state.phase},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"standby",{get:function(){return this._standby},set:function(e){this.isDisposed||this.standby===e||(this._standby=e)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"state",{get:function(){return this._state},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"tick",{get:function(){return this._tick.promise},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"ticked",{get:function(){return this._ticked},enumerable:!0,configurable:!0}),e.prototype.dispose=function(){this.isDisposed||(this._state=l(l({},d.DISPOSED_STATE),{timestamp:(new Date).getTime()}),this._tick.promise.catch((function(e){})),this._tick.reject(new Error("Poll ("+this.name+") is disposed.")),this._disposed.emit(void 0),o.Signal.clearData(this))},e.prototype.refresh=function(){return this.schedule({cancel:function(e){return"refreshed"===e.phase},interval:e.IMMEDIATE,phase:"refreshed"})},e.prototype.schedule=function(t){return void 0===t&&(t={}),c(this,void 0,void 0,(function(){var n,r,o,a,s,c=this;return u(this,(function(u){switch(u.label){case 0:return this.isDisposed||t.cancel&&t.cancel(this.state)?[2]:(n=this.state,r=this._tick,o=new i.PromiseDelegate,a=l({interval:this.frequency.interval,payload:null,phase:"standby",timestamp:(new Date).getTime()},t),this._state=a,this._tick=o,n.interval===e.IMMEDIATE?p(this._timeout):clearTimeout(this._timeout),this._ticked.emit(this.state),r.resolve(this),[4,r.promise]);case 1:return u.sent(),s=function(){c.isDisposed||c.tick!==o.promise||c._execute()},this._timeout=a.interval===e.IMMEDIATE?h(s):a.interval===e.NEVER?-1:setTimeout(s,a.interval),[2]}}))}))},e.prototype.start=function(){return this.schedule({cancel:function(e){var t=e.phase;return"constructed"!==t&&"standby"!==t&&"stopped"!==t},interval:e.IMMEDIATE,phase:"started"})},e.prototype.stop=function(){return this.schedule({cancel:function(e){return"stopped"===e.phase},interval:e.NEVER,phase:"stopped"})},e.prototype._execute=function(){var e=this,t="function"==typeof this.standby?this.standby():this.standby;if(t="never"!==t&&("when-hidden"===t?!("undefined"==typeof document||!document||!document.hidden):t))this.schedule();else{var n=this.tick;this._factory(this.state).then((function(t){e.isDisposed||e.tick!==n||e.schedule({payload:t,phase:"rejected"===e.state.phase?"reconnected":"resolved"})})).catch((function(t){e.isDisposed||e.tick!==n||e.schedule({interval:d.sleep(e.frequency,e.state),payload:t,phase:"rejected"})}))}},e}();!function(e){e.IMMEDIATE=0,e.MAX_INTERVAL=2147483647,e.NEVER=1/0}(f||(f={})),function(e){e.DEFAULT_BACKOFF=3,e.DEFAULT_FREQUENCY={backoff:!0,interval:1e3,max:3e4},e.DEFAULT_NAME="unknown",e.DEFAULT_STANDBY="when-hidden",e.DEFAULT_STATE={interval:f.NEVER,payload:null,phase:"constructed",timestamp:new Date(0).getTime()},e.DISPOSED_STATE={interval:f.NEVER,payload:null,phase:"disposed",timestamp:new Date(0).getTime()},e.sleep=function(t,n){var r=t.backoff,i=t.interval,o=t.max;if(i===f.NEVER)return i;var a=!0===r?e.DEFAULT_BACKOFF:!1===r?1:r,s=function(e,t){return e=Math.ceil(e),t=Math.floor(t),Math.floor(Math.random()*(t-e+1))+e}(i,n.interval*a);return Math.min(o,s)}}(d||(d={}));var m=function(){function e(e,t){var n=this;void 0===t&&(t=500),this.payload=null,this.limit=t,this.poll=new f({auto:!1,factory:function(){return c(n,void 0,void 0,(function(){return u(this,(function(t){switch(t.label){case 0:return[4,e()];case 1:return[2,t.sent()]}}))}))},frequency:{backoff:!1,interval:f.NEVER,max:f.NEVER},standby:"never"}),this.payload=new i.PromiseDelegate,this.poll.ticked.connect((function(e,t){var r=n.payload;return"resolved"===t.phase?(n.payload=new i.PromiseDelegate,void r.resolve(t.payload)):"rejected"===t.phase||"stopped"===t.phase?(n.payload=new i.PromiseDelegate,r.promise.catch((function(e){})),void r.reject(t.payload)):void 0}),this)}return Object.defineProperty(e.prototype,"isDisposed",{get:function(){return null===this.payload},enumerable:!0,configurable:!0}),e.prototype.dispose=function(){this.isDisposed||(this.payload=null,this.poll.dispose())},e.prototype.stop=function(){return c(this,void 0,void 0,(function(){return u(this,(function(e){return[2,this.poll.stop()]}))}))},e}(),g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return s(t,e),t.prototype.invoke=function(){return this.poll.schedule({interval:this.limit,phase:"invoked"}),this.payload.promise},t}(m),v=function(e){function t(t,n){var r=e.call(this,t,"number"==typeof n?n:n&&n.limit)||this,i="leading";return"number"!=typeof n&&(i="edge"in(n=n||{})?n.edge:i),r._interval="trailing"===i?r.limit:f.IMMEDIATE,r}return s(t,e),t.prototype.invoke=function(){return"invoked"!==this.poll.state.phase&&this.poll.schedule({interval:this._interval,phase:"invoked"}),this.payload.promise},t}(m)}.call(this,n(90).setImmediate,n(90).clearImmediate)},function(e,t,n){"use strict";n.r(t),n.d(t,"CommandRegistry",(function(){return u}));var r,i=n(2),o=n(6),a=n(27),s=n(21),l=n(100),c=n(4),u=function(){function e(){this._timerID=0,this._replaying=!1,this._keystrokes=[],this._keydownEvents=[],this._keyBindings=[],this._exactKeyMatch=null,this._commands=Object.create(null),this._commandChanged=new c.Signal(this),this._commandExecuted=new c.Signal(this),this._keyBindingChanged=new c.Signal(this)}return Object.defineProperty(e.prototype,"commandChanged",{get:function(){return this._commandChanged},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"commandExecuted",{get:function(){return this._commandExecuted},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"keyBindingChanged",{get:function(){return this._keyBindingChanged},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"keyBindings",{get:function(){return this._keyBindings},enumerable:!0,configurable:!0}),e.prototype.listCommands=function(){return Object.keys(this._commands)},e.prototype.hasCommand=function(e){return e in this._commands},e.prototype.addCommand=function(e,t){var n=this;if(e in this._commands)throw new Error("Command '"+e+"' already registered.");return this._commands[e]=r.createCommand(t),this._commandChanged.emit({id:e,type:"added"}),new a.DisposableDelegate((function(){delete n._commands[e],n._commandChanged.emit({id:e,type:"removed"})}))},e.prototype.notifyCommandChanged=function(e){if(void 0!==e&&!(e in this._commands))throw new Error("Command '"+e+"' is not registered.");this._commandChanged.emit({id:e,type:e?"changed":"many-changed"})},e.prototype.label=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.label.call(void 0,t):""},e.prototype.mnemonic=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.mnemonic.call(void 0,t):-1},e.prototype.icon=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.icon.call(void 0,t):""},e.prototype.iconClass=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.iconClass.call(void 0,t):""},e.prototype.iconLabel=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.iconLabel.call(void 0,t):""},e.prototype.caption=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.caption.call(void 0,t):""},e.prototype.usage=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.usage.call(void 0,t):""},e.prototype.className=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.className.call(void 0,t):""},e.prototype.dataset=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return n?n.dataset.call(void 0,t):{}},e.prototype.isEnabled=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return!!n&&n.isEnabled.call(void 0,t)},e.prototype.isToggled=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return!!n&&n.isToggled.call(void 0,t)},e.prototype.isToggleable=function(e,t){var n=this._commands[e];return!!n&&n.isToggleable},e.prototype.isVisible=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n=this._commands[e];return!!n&&n.isVisible.call(void 0,t)},e.prototype.execute=function(e,t){void 0===t&&(t=o.JSONExt.emptyObject);var n,r=this._commands[e];if(!r)return Promise.reject(new Error("Command '"+e+"' not registered."));try{n=r.execute.call(void 0,t)}catch(e){n=Promise.reject(e)}var i=Promise.resolve(n);return this._commandExecuted.emit({id:e,args:t,result:i}),i},e.prototype.addKeyBinding=function(e){var t=this,n=r.createKeyBinding(e);return this._keyBindings.push(n),this._keyBindingChanged.emit({binding:n,type:"added"}),new a.DisposableDelegate((function(){i.ArrayExt.removeFirstOf(t._keyBindings,n),t._keyBindingChanged.emit({binding:n,type:"removed"})}))},e.prototype.processKeydownEvent=function(t){if(!this._replaying&&!e.isModifierKeyPressed(t)){var n=e.keystrokeForKeydownEvent(t);if(!n)return this._replayKeydownEvents(),void this._clearPendingState();this._keystrokes.push(n);var i=r.matchKeyBinding(this._keyBindings,this._keystrokes,t),o=i.exact,a=i.partial;if(!o&&!a)return this._replayKeydownEvents(),void this._clearPendingState();if(t.preventDefault(),t.stopPropagation(),o&&!a)return this._executeKeyBinding(o),void this._clearPendingState();o&&(this._exactKeyMatch=o),this._keydownEvents.push(t),this._startTimer()}},e.prototype._startTimer=function(){var e=this;this._clearTimer(),this._timerID=window.setTimeout((function(){e._onPendingTimeout()}),r.CHORD_TIMEOUT)},e.prototype._clearTimer=function(){0!==this._timerID&&(clearTimeout(this._timerID),this._timerID=0)},e.prototype._replayKeydownEvents=function(){0!==this._keydownEvents.length&&(this._replaying=!0,this._keydownEvents.forEach(r.replayKeyEvent),this._replaying=!1)},e.prototype._executeKeyBinding=function(e){var t=e.command,n=e.args;if(this.hasCommand(t)&&this.isEnabled(t,n))this.execute(t,n);else{var r=this.hasCommand(t)?"enabled":"registered",i="Cannot execute key binding '"+e.keys.join(", ")+"':",o="command '"+t+"' is not "+r+".";console.warn(i+" "+o)}},e.prototype._clearPendingState=function(){this._clearTimer(),this._exactKeyMatch=null,this._keystrokes.length=0,this._keydownEvents.length=0},e.prototype._onPendingTimeout=function(){this._timerID=0,this._exactKeyMatch?this._executeKeyBinding(this._exactKeyMatch):this._replayKeydownEvents(),this._clearPendingState()},e}();!function(e){function t(e){for(var t="",n=!1,r=!1,i=!1,o=!1,a=0,l=e.split(/\s+/);a<l.length;a++){var c=l[a];"Accel"===c?s.Platform.IS_MAC?r=!0:i=!0:"Alt"===c?n=!0:"Cmd"===c?r=!0:"Ctrl"===c?i=!0:"Shift"===c?o=!0:c.length>0&&(t=c)}return{cmd:r,ctrl:i,alt:n,shift:o,key:t}}function n(e){var n="",r=t(e);return r.ctrl&&(n+="Ctrl "),r.alt&&(n+="Alt "),r.shift&&(n+="Shift "),r.cmd&&s.Platform.IS_MAC&&(n+="Cmd "),n+r.key}e.parseKeystroke=t,e.normalizeKeystroke=n,e.normalizeKeys=function(e){return(s.Platform.IS_WIN?e.winKeys||e.keys:s.Platform.IS_MAC?e.macKeys||e.keys:e.linuxKeys||e.keys).map(n)},e.formatKeystroke=function(e){var n=[],i=s.Platform.IS_MAC?" ":"+",o=t(e);return o.ctrl&&n.push("Ctrl"),o.alt&&n.push("Alt"),o.shift&&n.push("Shift"),s.Platform.IS_MAC&&o.cmd&&n.push("Cmd"),n.push(o.key),n.map(r.formatKey).join(i)},e.isModifierKeyPressed=function(e){var t=Object(l.a)(),n=t.keyForKeydownEvent(e);return t.isModifierKey(n)},e.keystrokeForKeydownEvent=function(e){var t=Object(l.a)(),n=t.keyForKeydownEvent(e);if(!n||t.isModifierKey(n))return"";var r=[];return e.ctrlKey&&r.push("Ctrl"),e.altKey&&r.push("Alt"),e.shiftKey&&r.push("Shift"),e.metaKey&&s.Platform.IS_MAC&&r.push("Cmd"),r.push(n),r.join(" ")}}(u||(u={})),function(e){e.CHORD_TIMEOUT=1e3,e.createCommand=function(e){var t,n;return e.icon&&"string"!=typeof e.icon?(n=h(e.iconClass,r),t=h(e.icon,d)):t=n=h(e.iconClass||e.icon,r),{execute:e.execute,label:h(e.label,r),mnemonic:h(e.mnemonic,i),icon:t,iconClass:n,iconLabel:h(e.iconLabel,r),caption:h(e.caption,r),usage:h(e.usage,r),className:h(e.className,r),dataset:h(e.dataset,c),isEnabled:e.isEnabled||a,isToggled:e.isToggled||l,isToggleable:e.isToggleable||!!e.isToggled,isVisible:e.isVisible||a}},e.createKeyBinding=function(e){return{keys:u.normalizeKeys(e),selector:p(e),command:e.command,args:e.args||o.JSONExt.emptyObject}},e.matchKeyBinding=function(e,t,n){for(var r=null,i=!1,o=1/0,a=0,l=0,c=e.length;l<c;++l){var u=e[l],d=f(u.keys,t);if(0!==d)if(2!==d){var h=m(u.selector,n);if(!(-1===h||h>o)){var p=s.Selector.calculateSpecificity(u.selector);(!r||h<o||p>=a)&&(r=u,o=h,a=p)}}else i||-1===m(u.selector,n)||(i=!0)}return{exact:r,partial:i}},e.replayKeyEvent=function(e){e.target.dispatchEvent(function(e){var t=document.createEvent("Event"),n=e.bubbles||!0,r=e.cancelable||!0;return t.initEvent(e.type||"keydown",n,r),t.key=e.key||"",t.keyCode=e.keyCode||0,t.which=e.keyCode||0,t.ctrlKey=e.ctrlKey||!1,t.altKey=e.altKey||!1,t.shiftKey=e.shiftKey||!1,t.metaKey=e.metaKey||!1,t.view=e.view||window,t}(e))},e.formatKey=function(e){return s.Platform.IS_MAC?t.hasOwnProperty(e)?t[e]:e:n.hasOwnProperty(e)?n[e]:e};var t={Backspace:"⌫",Tab:"⇥",Enter:"↩",Shift:"⇧",Ctrl:"⌃",Alt:"⌥",Escape:"⎋",PageUp:"⇞",PageDown:"⇟",End:"↘",Home:"↖",ArrowLeft:"←",ArrowUp:"↑",ArrowRight:"→",ArrowDown:"↓",Delete:"⌦",Cmd:"⌘"},n={Escape:"Esc",PageUp:"Page Up",PageDown:"Page Down",ArrowLeft:"Left",ArrowUp:"Up",ArrowRight:"Right",ArrowDown:"Down",Delete:"Del"},r=function(){return""},i=function(){return-1},a=function(){return!0},l=function(){return!1},c=function(){return{}},d=function(){};function h(e,t){return void 0===e?t:"function"==typeof e?e:function(){return e}}function p(e){if(-1!==e.selector.indexOf(","))throw new Error("Selector cannot contain commas: "+e.selector);if(!s.Selector.isValid(e.selector))throw new Error("Invalid selector: "+e.selector);return e.selector}function f(e,t){if(e.length<t.length)return 0;for(var n=0,r=t.length;n<r;++n)if(e[n]!==t[n])return 0;return e.length>t.length?2:1}function m(e,t){for(var n=t.target,r=t.currentTarget,i=0;null!==n;n=n.parentElement,++i){if(n.hasAttribute("data-lm-suppress-shortcuts"))return-1;if(n.hasAttribute("data-p-suppress-shortcuts"))return-1;if(s.Selector.matches(n,e))return i;if(n===r)return-1}return-1}}(r||(r={}))},function(e,t,n){"use strict";n.d(t,"d",(function(){return r})),n.d(t,"a",(function(){return i})),n.d(t,"c",(function(){return o})),n.d(t,"b",(function(){return a}));const r=e=>e[e.length-1],i=(e,t)=>{for(let n=0;n<t.length;n++)e.push(t[n])},o=Array.from,a=(e,t)=>{return e.length===t.length&&(n=(e,n)=>e===t[n],e.every(n));var n}},function(e,t,n){var r=n(404),i="object"==typeof self&&self&&self.Object===Object&&self,o=r||i||Function("return this")();e.exports=o},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.EquationItem=t.EqnArrayItem=t.ArrayItem=t.DotsItem=t.NonscriptItem=t.NotItem=t.FnItem=t.MmlItem=t.CellItem=t.PositionItem=t.StyleItem=t.EndItem=t.BeginItem=t.RightItem=t.Middle=t.LeftItem=t.OverItem=t.SubsupItem=t.PrimeItem=t.CloseItem=t.OpenItem=t.StopItem=t.StartItem=void 0;var s=n(136),l=n(135),c=n(23),u=n(31),d=n(37),h=n(39),p=n(95),f=function(e){function t(t,n){var r=e.call(this,t)||this;return r.global=n,r}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"start"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("stop")){var n=this.toMml();return this.global.isInner||(n=this.factory.configuration.tags.finalize(n,this.env)),[[this.factory.create("mml",n)],!0]}return e.prototype.checkItem.call(this,t)},t}(p.BaseItem);t.StartItem=f;var m=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"stop"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.StopItem=m;var g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"open"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("close")){var n=this.toMml(),r=this.create("node","TeXAtom",[n]);return[[this.factory.create("mml",r)],!0]}return e.prototype.checkItem.call(this,t)},t.errors=Object.assign(Object.create(p.BaseItem.errors),{stop:["ExtraOpenMissingClose","Extra open brace or missing close brace"]}),t}(p.BaseItem);t.OpenItem=g;var v=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"close"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.CloseItem=v;var y=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"prime"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(e){var t=o(this.Peek(2),2),n=t[0],r=t[1];return!h.default.isType(n,"msubsup")||h.default.isType(n,"msup")?[[this.create("node","msup",[n,r]),e],!0]:(h.default.setChild(n,n.sup,r),[[n,e],!0])},t}(p.BaseItem);t.PrimeItem=y;var _=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"subsup"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("open")||t.isKind("left"))return p.BaseItem.success;var n=this.First,r=this.getProperty("position");if(t.isKind("mml")){if(this.getProperty("primes"))if(2!==r)h.default.setChild(n,2,this.getProperty("primes"));else{h.default.setProperty(this.getProperty("primes"),"variantForm",!0);var i=this.create("node","mrow",[this.getProperty("primes"),t.First]);t.First=i}return h.default.setChild(n,r,t.First),null!=this.getProperty("movesupsub")&&h.default.setProperty(n,"movesupsub",this.getProperty("movesupsub")),[[this.factory.create("mml",n)],!0]}if(e.prototype.checkItem.call(this,t)[1]){var s=this.getErrors(["","sub","sup"][r]);throw new(u.default.bind.apply(u.default,a([void 0,s[0],s[1]],o(s.splice(2)))))}return null},t.errors=Object.assign(Object.create(p.BaseItem.errors),{stop:["MissingScript","Missing superscript or subscript argument"],sup:["MissingOpenForSup","Missing open brace for superscript"],sub:["MissingOpenForSub","Missing open brace for subscript"]}),t}(p.BaseItem);t.SubsupItem=_;var b=function(e){function t(t){var n=e.call(this,t)||this;return n.setProperty("name","\\over"),n}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"over"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("over"))throw new u.default("AmbiguousUseOf","Ambiguous use of %1",t.getName());if(t.isClose){var n=this.create("node","mfrac",[this.getProperty("num"),this.toMml(!1)]);return null!=this.getProperty("thickness")&&h.default.setAttribute(n,"linethickness",this.getProperty("thickness")),(this.getProperty("open")||this.getProperty("close"))&&(h.default.setProperty(n,"withDelims",!0),n=d.default.fixedFence(this.factory.configuration,this.getProperty("open"),n,this.getProperty("close"))),[[this.factory.create("mml",n),t],!0]}return e.prototype.checkItem.call(this,t)},t.prototype.toString=function(){return"over["+this.getProperty("num")+" / "+this.nodes.join("; ")+"]"},t}(p.BaseItem);t.OverItem=b;var M=function(e){function t(t,n){var r=e.call(this,t)||this;return r.setProperty("delim",n),r}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"left"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("right"))return[[this.factory.create("mml",d.default.fenced(this.factory.configuration,this.getProperty("delim"),this.toMml(),t.getProperty("delim"),"",t.getProperty("color")))],!0];if(t.isKind("middle")){var n={stretchy:!0};return t.getProperty("color")&&(n.mathcolor=t.getProperty("color")),this.Push(this.create("node","TeXAtom",[],{texClass:c.TEXCLASS.CLOSE}),this.create("token","mo",n,t.getProperty("delim")),this.create("node","TeXAtom",[],{texClass:c.TEXCLASS.OPEN})),this.env={},[[this],!0]}return e.prototype.checkItem.call(this,t)},t.errors=Object.assign(Object.create(p.BaseItem.errors),{stop:["ExtraLeftMissingRight","Extra \\left or missing \\right"]}),t}(p.BaseItem);t.LeftItem=M;var w=function(e){function t(t,n,r){var i=e.call(this,t)||this;return i.setProperty("delim",n),r&&i.setProperty("color",r),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"middle"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.Middle=w;var A=function(e){function t(t,n,r){var i=e.call(this,t)||this;return i.setProperty("delim",n),r&&i.setProperty("color",r),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"right"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.RightItem=A;var C=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"begin"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("end")){if(t.getName()!==this.getName())throw new u.default("EnvBadEnd","\\begin{%1} ended with \\end{%2}",this.getName(),t.getName());return this.getProperty("end")?p.BaseItem.fail:[[this.factory.create("mml",this.toMml())],!0]}if(t.isKind("stop"))throw new u.default("EnvMissingEnd","Missing \\end{%1}",this.getName());return e.prototype.checkItem.call(this,t)},t}(p.BaseItem);t.BeginItem=C;var x=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"end"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.EndItem=x;var E=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"style"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(!t.isClose)return e.prototype.checkItem.call(this,t);var n=this.create("node","mstyle",this.nodes,this.getProperty("styles"));return[[this.factory.create("mml",n),t],!0]},t}(p.BaseItem);t.StyleItem=E;var L=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"position"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isClose)throw new u.default("MissingBoxFor","Missing box for %1",this.getName());if(t.isFinal){var n=t.toMml();switch(this.getProperty("move")){case"vertical":return n=this.create("node","mpadded",[n],{height:this.getProperty("dh"),depth:this.getProperty("dd"),voffset:this.getProperty("dh")}),[[this.factory.create("mml",n)],!0];case"horizontal":return[[this.factory.create("mml",this.getProperty("left")),t,this.factory.create("mml",this.getProperty("right"))],!0]}}return e.prototype.checkItem.call(this,t)},t}(p.BaseItem);t.PositionItem=L;var S=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"cell"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!0},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.CellItem=S;var T=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"isFinal",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"kind",{get:function(){return"mml"},enumerable:!1,configurable:!0}),t}(p.BaseItem);t.MmlItem=T;var O=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"fn"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){var n=this.First;if(n){if(t.isOpen)return p.BaseItem.success;if(!t.isKind("fn")){var r=t.First;if(!t.isKind("mml")||!r)return[[n,t],!0];if(h.default.isType(r,"mstyle")&&r.childNodes.length&&h.default.isType(r.childNodes[0].childNodes[0],"mspace")||h.default.isType(r,"mspace"))return[[n,t],!0];h.default.isEmbellished(r)&&(r=h.default.getCoreMO(r));var i=h.default.getForm(r);if(null!=i&&[0,0,1,1,0,1,1,0,0,0][i[2]])return[[n,t],!0]}var o=this.create("token","mo",{texClass:c.TEXCLASS.NONE},l.entities.ApplyFunction);return[[n,o,t],!0]}return e.prototype.checkItem.apply(this,arguments)},t}(p.BaseItem);t.FnItem=O;var I=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.remap=s.MapHandler.getMap("not_remap"),t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"not"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(e){var t,n,r;if(e.isKind("open")||e.isKind("left"))return p.BaseItem.success;if(e.isKind("mml")&&(h.default.isType(e.First,"mo")||h.default.isType(e.First,"mi")||h.default.isType(e.First,"mtext"))&&(t=e.First,1===(n=h.default.getText(t)).length&&!h.default.getProperty(t,"movesupsub")&&1===h.default.getChildren(t).length))return this.remap.contains(n)?(r=this.create("text",this.remap.lookup(n).char),h.default.setChild(t,0,r)):(r=this.create("text","̸"),h.default.appendChildren(t,[r])),[[e],!0];r=this.create("text","⧸");var i=this.create("node","mtext",[],{},r),o=this.create("node","mpadded",[i],{width:0});return[[t=this.create("node","TeXAtom",[o],{texClass:c.TEXCLASS.REL}),e],!0]},t}(p.BaseItem);t.NotItem=I;var k=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"nonscript"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(e){if(e.isKind("mml")&&1===e.Size()){var t=e.First;if(t.isKind("mstyle")&&t.notParent&&(t=h.default.getChildren(h.default.getChildren(t)[0])[0]),t.isKind("mspace")){if(t!==e.First){var n=this.create("node","mrow",[e.Pop()]);e.Push(n)}this.factory.configuration.addNode("nonscript",e.First)}}return[[e],!0]},t}(p.BaseItem);t.NonscriptItem=k;var D=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"dots"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(e){if(e.isKind("open")||e.isKind("left"))return p.BaseItem.success;var t=this.getProperty("ldots"),n=e.First;if(e.isKind("mml")&&h.default.isEmbellished(n)){var r=h.default.getTexClass(h.default.getCoreMO(n));r!==c.TEXCLASS.BIN&&r!==c.TEXCLASS.REL||(t=this.getProperty("cdots"))}return[[t,e],!0]},t}(p.BaseItem);t.DotsItem=D;var N=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.table=[],t.row=[],t.frame=[],t.hfill=[],t.arraydef={},t.dashed=!1,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"array"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"copyEnv",{get:function(){return!1},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isClose&&!t.isKind("over")){if(t.getProperty("isEntry"))return this.EndEntry(),this.clearEnv(),p.BaseItem.fail;if(t.getProperty("isCR"))return this.EndEntry(),this.EndRow(),this.clearEnv(),p.BaseItem.fail;this.EndTable(),this.clearEnv();var n=this.factory.create("mml",this.createMml());if(this.getProperty("requireClose")){if(t.isKind("close"))return[[n],!0];throw new u.default("MissingCloseBrace","Missing close brace")}return[[n,t],!0]}return e.prototype.checkItem.call(this,t)},t.prototype.createMml=function(){var e=this.arraydef.scriptlevel;delete this.arraydef.scriptlevel;var t=this.create("node","mtable",this.table,this.arraydef);return e&&t.setProperty("scriptlevel",e),4===this.frame.length?h.default.setAttribute(t,"frame",this.dashed?"dashed":"solid"):this.frame.length&&(this.arraydef.rowlines&&(this.arraydef.rowlines=this.arraydef.rowlines.replace(/none( none)+$/,"none")),h.default.setAttribute(t,"frame",""),t=this.create("node","menclose",[t],{notation:this.frame.join(" ")}),"none"===(this.arraydef.columnlines||"none")&&"none"===(this.arraydef.rowlines||"none")||h.default.setAttribute(t,"data-padding",0)),(this.getProperty("open")||this.getProperty("close"))&&(t=d.default.fenced(this.factory.configuration,this.getProperty("open"),t,this.getProperty("close"))),t},t.prototype.EndEntry=function(){var e=this.create("node","mtd",this.nodes);this.hfill.length&&(0===this.hfill[0]&&h.default.setAttribute(e,"columnalign","right"),this.hfill[this.hfill.length-1]===this.Size()&&h.default.setAttribute(e,"columnalign",h.default.getAttribute(e,"columnalign")?"center":"left")),this.row.push(e),this.Clear(),this.hfill=[]},t.prototype.EndRow=function(){var e;this.getProperty("isNumbered")&&3===this.row.length?(this.row.unshift(this.row.pop()),e=this.create("node","mlabeledtr",this.row)):e=this.create("node","mtr",this.row),this.table.push(e),this.row=[]},t.prototype.EndTable=function(){(this.Size()||this.row.length)&&(this.EndEntry(),this.EndRow()),this.checkLines()},t.prototype.checkLines=function(){if(this.arraydef.rowlines){var e=this.arraydef.rowlines.split(/ /);e.length===this.table.length?(this.frame.push("bottom"),e.pop(),this.arraydef.rowlines=e.join(" ")):e.length<this.table.length-1&&(this.arraydef.rowlines+=" none")}if(this.getProperty("rowspacing")){for(var t=this.arraydef.rowspacing.split(/ /);t.length<this.table.length;)t.push(this.getProperty("rowspacing")+"em");this.arraydef.rowspacing=t.join(" ")}},t.prototype.addRowSpacing=function(e){if(this.arraydef.rowspacing){var t=this.arraydef.rowspacing.split(/ /);if(!this.getProperty("rowspacing")){var n=d.default.dimen2em(t[0]);this.setProperty("rowspacing",n)}for(var r=this.getProperty("rowspacing");t.length<this.table.length;)t.push(d.default.Em(r));t[this.table.length-1]=d.default.Em(Math.max(0,r+d.default.dimen2em(e))),this.arraydef.rowspacing=t.join(" ")}},t}(p.BaseItem);t.ArrayItem=N;var j=function(e){function t(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var i=e.call(this,t)||this;return i.maxrow=0,i.factory.configuration.tags.start(n[0],n[2],n[1]),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"eqnarray"},enumerable:!1,configurable:!0}),t.prototype.EndEntry=function(){this.row.length&&d.default.fixInitialMO(this.factory.configuration,this.nodes);var e=this.create("node","mtd",this.nodes);this.row.push(e),this.Clear()},t.prototype.EndRow=function(){this.row.length>this.maxrow&&(this.maxrow=this.row.length);var e="mtr",t=this.factory.configuration.tags.getTag();t&&(this.row=[t].concat(this.row),e="mlabeledtr"),this.factory.configuration.tags.clearTag();var n=this.create("node",e,this.row);this.table.push(n),this.row=[]},t.prototype.EndTable=function(){e.prototype.EndTable.call(this),this.factory.configuration.tags.end(),this.extendArray("columnalign",this.maxrow),this.extendArray("columnwidth",this.maxrow),this.extendArray("columnspacing",this.maxrow-1)},t.prototype.extendArray=function(e,t){if(this.arraydef[e]){var n=this.arraydef[e].split(/ /),r=a([],o(n));if(r.length>1){for(;r.length<t;)r.push.apply(r,a([],o(n)));this.arraydef[e]=r.slice(0,t).join(" ")}}},t}(N);t.EqnArrayItem=j;var P=function(e){function t(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var i=e.call(this,t)||this;return i.factory.configuration.tags.start("equation",!0,n[0]),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"equation"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("end")){var n=this.toMml(),r=this.factory.configuration.tags.getTag();return this.factory.configuration.tags.end(),[[r?this.factory.configuration.tags.enTag(n,r):n,t],!0]}if(t.isKind("stop"))throw new u.default("EnvMissingEnd","Missing \\end{%1}",this.getName());return e.prototype.checkItem.call(this,t)},t}(p.BaseItem);t.EquationItem=P},function(e,t,n){"use strict";n.d(t,"b",(function(){return o})),n.d(t,"a",(function(){return s}));let r=[];const i=()=>{for(let e=0;e<r.length;e++)r[e]();r=[]},o=e=>{r.push(e),1===r.length&&setTimeout(i,0)},a=e=>class{constructor(e){this._=e}destroy(){e(this._)}},s=(a(clearTimeout),a(clearInterval),a(e=>"undefined"!=typeof requestAnimationFrame&&cancelAnimationFrame(e)),a(e=>"undefined"!=typeof cancelIdleCallback&&cancelIdleCallback(e)),e=>{let t=-1;return n=>{clearTimeout(t),n&&(t=setTimeout(n,e))}})},function(e,t,n){"use strict";n.d(t,"a",(function(){return w})),n.d(t,"d",(function(){return A})),n.d(t,"b",(function(){return C})),n.d(t,"e",(function(){return x})),n.d(t,"f",(function(){return E})),n.d(t,"g",(function(){return L})),n.d(t,"c",(function(){return S}));var r=n(22),i=n(3),o=n(101),a=n(12),s=n(2),l=n(575),c=n.n(l),u=n(200),d=n.n(u);const h=/(\$\$?|\\(?:begin|end)\{[a-z]*\*?\}|\\[{}$]|[{}]|(?:\n\s*)+|@@\d+@@|\\\\(?:\(|\)|\[|\]))/i;function p(e,t,n,r,i){let o=i.slice(e,t+1).join("").replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;");for(navigator&&"Microsoft Internet Explorer"===navigator.appName&&(o=o.replace(/(%[^\n]*)\n/g,"$1<br/>\n"));t>e;)i[t]="",t--;return i[e]="@@"+r.length+"@@",n&&(o=n(o)),r.push(o),i}var f,m=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};function g(e){let{host:t,source:n,trusted:i,sanitizer:o,resolver:a,linkHandler:s,shouldTypeset:l,latexTypesetter:c,translator:u}=e;u=u||r.b;const d=null==u?void 0:u.load("jupyterlab");let h,p=n;if(!n)return t.textContent="",Promise.resolve(void 0);if(i||(p=""+n,n=o.sanitize(n)),t.innerHTML=n,t.getElementsByTagName("script").length>0)if(i)f.evalInnerHTMLScriptTags(t);else{const e=document.createElement("div"),n=document.createElement("pre");n.textContent=d.__("This HTML output contains inline scripts. Are you sure that you want to run arbitrary Javascript within your JupyterLab session?");const r=document.createElement("button");r.textContent=d.__("Run"),r.onclick=e=>{t.innerHTML=p,f.evalInnerHTMLScriptTags(t),t.firstChild&&t.removeChild(t.firstChild)},e.appendChild(n),e.appendChild(r),t.insertBefore(e,t.firstChild)}return f.handleDefaults(t,a),h=a?f.handleUrls(t,a,s):Promise.resolve(void 0),h.then(()=>{l&&c&&c.typeset(t)})}async function v(e){const{host:t,source:n}=e,r=m(e,["host","source"]);if(!n)return void(t.textContent="");const i=function(e){const t=[];let n,r=null,i=null,o=null,a=0;e.includes("`")||e.includes("~~~")?(e=e.replace(/~/g,"~T").replace(/^(?<fence>`{3,}|(~T){3,})[^`\n]*\n([\s\S]*?)^\k<fence>`*$/gm,e=>e.replace(/\$/g,"~D")).replace(/(^|[^\\])(`+)([^\n]*?[^`\n])\2(?!`)/gm,e=>e.replace(/\$/g,"~D")),n=e=>e.replace(/~([TD])/g,(e,t)=>"T"===t?"~":"$")):n=e=>e;let s=e.replace(/\r\n?/g,"\n").split(h);for(let e=1,l=s.length;e<l;e+=2){const l=s[e];"@"===l.charAt(0)?(s[e]="@@"+t.length+"@@",t.push(l)):null!==r?l===i?a?o=e:(s=p(r,e,n,t,s),r=null,i=null,o=null):l.match(/\n.*\n/)?(null!==o&&(e=o,s=p(r,e,n,t,s)),r=null,i=null,o=null,a=0):"{"===l?a++:"}"===l&&a&&a--:"$"===l||"$$"===l?(r=e,i=l,a=0):"\\\\("===l||"\\\\["===l?(r=e,i="("===l.slice(-1)?"\\\\)":"\\\\]",a=0):"begin"===l.substr(1,5)&&(r=e,i="\\end"+l.substr(6),a=0)}return null!==r&&null!==o&&(s=p(r,o,n,t,s),r=null,i=null,o=null),{text:n(s.join("")),math:t}}(n);let o=await f.renderMarked(i.text);var a,s;a=o,s=i.math,o=a.replace(/@@(\d+)@@/g,(e,t)=>{let n=s[t];return"\\\\("===n.substr(0,3)&&"\\\\)"===n.substr(n.length-3)?n="\\("+n.substring(3,n.length-3)+"\\)":"\\\\["===n.substr(0,3)&&"\\\\]"===n.substr(n.length-3)&&(n="\\["+n.substring(3,n.length-3)+"\\]"),n}),await g(Object.assign({host:t,source:o},r)),f.headerAnchors(t)}function y(e,t){var n,r;const i=e.cloneNode();i.textContent=null===(n=e.textContent)||void 0===n?void 0:n.substr(0,t);const o=e.cloneNode();return o.textContent=null===(r=e.textContent)||void 0===r?void 0:r.substr(t),{pre:i,post:o}}function _(e){var t,n;const{host:r,sanitizer:i,source:o}=e,a=i.sanitize(f.ansiSpan(o),{allowedTags:["span"]}),s=document.createElement("pre");s.innerHTML=a;const l=s.textContent;if(l){const e=function(e){const t=new RegExp('(?:[a-zA-Z][a-zA-Z0-9+.-]{2,}:\\/\\/|data:|www\\.)[^\\s\\u0000-\\u0020\\u007f-\\u009f"]{2,}[^\\s\\u0000-\\u0020\\u007f-\\u009f"\'(){}\\[\\],:;.!?]',"ug"),n=[];let r,i=0;for(;null!=(r=t.exec(e));){r.index!==i&&n.push(document.createTextNode(e.slice(i,r.index)));let t=r[0];const o=t.slice(-1),a=-1!==[">","<"].indexOf(o)?t.length-1:t.length,s=document.createElement("a");t=t.slice(0,a),s.href=t.startsWith("www.")?"https://"+t:t,s.rel="noopener",s.target="_blank",s.appendChild(document.createTextNode(t.slice(0,a))),n.push(s),i=r.index+a}return i!==e.length&&n.push(document.createTextNode(e.slice(i,e.length))),n}(l);let r=!1;const i=[],o=Array.from(s.childNodes);for(;o.length&&e.length;){let a=o.shift(),s=e.shift();if(void 0===a){i.push(s);break}if(void 0===s){i.push(a);break}let l=null===(t=a.textContent)||void 0===t?void 0:t.length,c=null===(n=s.textContent)||void 0===n?void 0:n.length;if(l&&c)if(l>c){let{pre:e,post:t}=y(a,c);o.unshift(t),a=e}else if(c>l){let{pre:t,post:n}=y(s,l);e.unshift(n),s=t}const u=i[i.length-1];if(r&&s.href===u.href)u.appendChild(a);else{s.nodeType!==Node.TEXT_NODE?(s.textContent="",s.appendChild(a),i.push(s),r=!0):(i.push(a),r=!1)}}s.innerHTML="";for(const e of i)s.appendChild(e)}return r.appendChild(s),Promise.resolve(void 0)}!function(e){async function t(e,t,n){const r=e.getAttribute(t)||"",i=n.isLocal?n.isLocal(r):a.URLExt.isLocal(r);if(r&&i)try{const i=await n.resolveUrl(r);let o=await n.getDownloadUrl(i);"data:"!==a.URLExt.parse(o).protocol&&(o+=(/\?/.test(o)?"&":"?")+(new Date).getTime()),e.setAttribute(t,o)}catch(n){throw e.setAttribute(t,""),n}}function n(e,t,n){let r=e.getAttribute("href")||"";const i=t.isLocal?t.isLocal(r):a.URLExt.isLocal(r);if(!r||!i)return Promise.resolve(void 0);const o=e.hash;if(o){if(o===r)return e.target="_self",Promise.resolve(void 0);r=r.replace(o,"")}return t.resolveUrl(r).then(r=>{const i=decodeURIComponent(r);return n&&n.handleLink(e,i,o),t.getDownloadUrl(r)}).then(t=>{e.href=t+o}).catch(t=>{e.href=""})}e.evalInnerHTMLScriptTags=function(e){const t=Object(s.toArray)(e.getElementsByTagName("script"));for(const e of t){if(!e.parentNode)continue;const t=document.createElement("script"),n=e.attributes;for(let e=0,r=n.length;e<r;++e){const{name:r,value:i}=n[e];t.setAttribute(r,i)}t.textContent=e.textContent,e.parentNode.replaceChild(t,e)}},e.renderMarked=function(e){return function(){if(r)return;r=!0,d.a.setOptions({gfm:!0,sanitize:!1,langPrefix:`cm-s-${o.a.defaultConfig.theme} language-`,highlight:(e,t,n)=>{const r=(e,t)=>(n&&n(e,t),t);return t?(o.b.ensure(t).then(n=>{const i=document.createElement("div");if(!n)return console.error("No CodeMirror mode: "+t),r(null,e);try{return o.b.run(e,n.mime,i),r(null,i.innerHTML)}catch(n){return console.error(`Failed to highlight ${t} code`,n),r(n,e)}}).catch(n=>(console.error("No CodeMirror mode: "+t),console.error("Require CodeMirror mode error: "+n),r(null,e))),e):r(null,e)}})}(),new Promise((t,n)=>{d()(e,(e,r)=>{e?n(e):t(r)})})},e.handleDefaults=function(e,t){const n=e.getElementsByTagName("a");for(let e=0;e<n.length;e++){const r=n[e];if(!(r instanceof HTMLAnchorElement))continue;const i=r.href,o=t&&t.isLocal?t.isLocal(i):a.URLExt.isLocal(i);r.target||(r.target=o?"_self":"_blank"),o||(r.rel="noopener")}const r=e.getElementsByTagName("img");for(let e=0;e<r.length;e++)r[e].alt||(r[e].alt="Image")},e.handleUrls=function(e,r,i){const o=[],a=e.querySelectorAll("*[src]");for(let e=0;e<a.length;e++)o.push(t(a[e],"src",r));const s=e.getElementsByTagName("a");for(let e=0;e<s.length;e++)o.push(n(s[e],r,i));const l=e.getElementsByTagName("link");for(let e=0;e<l.length;e++)o.push(t(l[e],"href",r));return Promise.all(o).then(()=>{})},e.headerAnchors=function(e){var t;const n=["h1","h2","h3","h4","h5","h6"];for(const r of n){const n=e.getElementsByTagName(r);for(let e=0;e<n.length;e++){const r=n[e];r.id=(null!==(t=r.textContent)&&void 0!==t?t:"").replace(/ /g,"-");const i=document.createElement("a");i.target="_self",i.textContent="¶",i.href="#"+r.id,i.classList.add("jp-InternalAnchorLink"),r.appendChild(i)}}};let r=!1;const i=["ansi-black","ansi-red","ansi-green","ansi-yellow","ansi-blue","ansi-magenta","ansi-cyan","ansi-white","ansi-black-intense","ansi-red-intense","ansi-green-intense","ansi-yellow-intense","ansi-blue-intense","ansi-magenta-intense","ansi-cyan-intense","ansi-white-intense"];function l(e,t,n,r,o,a,s){if(e){const l=[],c=[];r&&"number"==typeof t&&0<=t&&t<8&&(t+=8),a&&([t,n]=[n,t]),"number"==typeof t?l.push(i[t]+"-fg"):t.length?c.push(`color: rgb(${t})`):a&&l.push("ansi-default-inverse-fg"),"number"==typeof n?l.push(i[n]+"-bg"):n.length?c.push(`background-color: rgb(${n})`):a&&l.push("ansi-default-inverse-bg"),r&&l.push("ansi-bold"),o&&l.push("ansi-underline"),l.length||c.length?(s.push("<span"),l.length&&s.push(` class="${l.join(" ")}"`),c.length&&s.push(` style="${c.join("; ")}"`),s.push(">"),s.push(e),s.push("</span>")):s.push(e)}}function u(e){let t,n,r;const i=e.shift();if(2===i&&e.length>=3){if(t=e.shift(),n=e.shift(),r=e.shift(),[t,n,r].some(e=>e<0||255<e))throw new RangeError("Invalid range for RGB colors")}else{if(!(5===i&&e.length>=1))throw new RangeError("Invalid extended color specification");{const i=e.shift();if(i<0)throw new RangeError("Color index must be >= 0");if(i<16)return i;if(i<232)t=Math.floor((i-16)/36),t=t>0?55+40*t:0,n=Math.floor((i-16)%36/6),n=n>0?55+40*n:0,r=(i-16)%6,r=r>0?55+40*r:0;else{if(!(i<256))throw new RangeError("Color index must be < 256");t=n=r=10*(i-232)+8}}}return[t,n,r]}e.ansiSpan=function(e){const t=/\x1b\[(.*?)([@-~])/g;let n,r=[],i=[],o=!1,a=!1,s=!1;const d=[],h=[];let p=0;for(e=c()(e),e+="[m";n=t.exec(e);){if("m"===n[2]){const e=n[1].split(";");for(let t=0;t<e.length;t++){const n=e[t];if(""===n)h.push(0);else{if(-1===n.search(/^\d+$/)){h.length=0;break}h.push(parseInt(n,10))}}}for(l(e.substring(p,n.index),r,i,o,a,s,d),p=t.lastIndex;h.length;){const e=h.shift();switch(e){case 0:r=i=[],o=!1,a=!1,s=!1;break;case 1:case 5:o=!0;break;case 4:a=!0;break;case 7:s=!0;break;case 21:case 22:o=!1;break;case 24:a=!1;break;case 27:s=!1;break;case 30:case 31:case 32:case 33:case 34:case 35:case 36:case 37:r=e-30;break;case 38:try{r=u(h)}catch(e){h.length=0}break;case 39:r=[];break;case 40:case 41:case 42:case 43:case 44:case 45:case 46:case 47:i=e-40;break;case 48:try{i=u(h)}catch(e){h.length=0}break;case 49:i=[];break;case 90:case 91:case 92:case 93:case 94:case 95:case 96:case 97:r=e-90+8;break;case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:i=e-100+8}}}return d.join("")}}(f||(f={}));class b extends i.Widget{constructor(e){super(),this.mimeType=e.mimeType,this.sanitizer=e.sanitizer,this.resolver=e.resolver,this.linkHandler=e.linkHandler,this.translator=e.translator||r.b,this.latexTypesetter=e.latexTypesetter,this.node.dataset.mimeType=this.mimeType}async renderModel(e){for(;this.node.firstChild;)this.node.removeChild(this.node.firstChild);this.toggleClass("jp-mod-trusted",e.trusted),await this.render(e);const{fragment:t}=e.metadata;t&&this.setFragment(t)}setFragment(e){}}class M extends b{constructor(e){super(e),this.addClass("jp-RenderedHTMLCommon")}setFragment(e){let t;try{t=this.node.querySelector(e.startsWith("#")?"#"+CSS.escape(e.slice(1)):e)}catch(e){console.warn("Unable to set URI fragment identifier.",e)}t&&t.scrollIntoView()}}class w extends M{constructor(e){super(e),this.addClass("jp-RenderedHTML")}render(e){return g({host:this.node,source:String(e.data[this.mimeType]),trusted:e.trusted,resolver:this.resolver,sanitizer:this.sanitizer,linkHandler:this.linkHandler,shouldTypeset:this.isAttached,latexTypesetter:this.latexTypesetter,translator:this.translator})}onAfterAttach(e){this.latexTypesetter&&this.latexTypesetter.typeset(this.node)}}class A extends b{constructor(e){super(e),this.addClass("jp-RenderedLatex")}render(e){return function(e){const{host:t,source:n,shouldTypeset:r,latexTypesetter:i}=e;return t.textContent=n,r&&i&&i.typeset(t),Promise.resolve(void 0)}({host:this.node,source:String(e.data[this.mimeType]),shouldTypeset:this.isAttached,latexTypesetter:this.latexTypesetter})}onAfterAttach(e){this.latexTypesetter&&this.latexTypesetter.typeset(this.node)}}class C extends b{constructor(e){super(e),this.addClass("jp-RenderedImage")}render(e){const t=e.metadata[this.mimeType];return function(e){const{host:t,mimeType:n,source:r,width:i,height:o,needsBackground:a,unconfined:s}=e;t.textContent="";const l=document.createElement("img");return l.src=`data:${n};base64,${r}`,"number"==typeof o&&(l.height=o),"number"==typeof i&&(l.width=i),"light"===a?l.classList.add("jp-needs-light-background"):"dark"===a&&l.classList.add("jp-needs-dark-background"),!0===s&&l.classList.add("jp-mod-unconfined"),t.appendChild(l),Promise.resolve(void 0)}({host:this.node,mimeType:this.mimeType,source:String(e.data[this.mimeType]),width:t&&t.width,height:t&&t.height,needsBackground:e.metadata.needs_background,unconfined:t&&t.unconfined})}}class x extends M{constructor(e){super(e),this.addClass("jp-RenderedMarkdown")}render(e){return v({host:this.node,source:String(e.data[this.mimeType]),trusted:e.trusted,resolver:this.resolver,sanitizer:this.sanitizer,linkHandler:this.linkHandler,shouldTypeset:this.isAttached,latexTypesetter:this.latexTypesetter,translator:this.translator})}onAfterAttach(e){this.latexTypesetter&&this.latexTypesetter.typeset(this.node)}}class E extends b{constructor(e){super(e),this.addClass("jp-RenderedSVG")}render(e){const t=e.metadata[this.mimeType];return function(e){let{host:t,source:n,trusted:r,unconfined:i}=e;if(!n)return t.textContent="",Promise.resolve(void 0);if(!r)return t.textContent="Cannot display an untrusted SVG. Maybe you need to run the cell?",Promise.resolve(void 0);n.search("<svg[^>]+xmlns=[^>]+svg")<0&&(n=n.replace("<svg",'<svg xmlns="http://www.w3.org/2000/svg"'));const o=new Image;return o.src="data:image/svg+xml,"+encodeURIComponent(n),t.appendChild(o),!0===i&&t.classList.add("jp-mod-unconfined"),Promise.resolve()}({host:this.node,source:String(e.data[this.mimeType]),trusted:e.trusted,unconfined:t&&t.unconfined,translator:this.translator})}onAfterAttach(e){this.latexTypesetter&&this.latexTypesetter.typeset(this.node)}}class L extends b{constructor(e){super(e),this.addClass("jp-RenderedText")}render(e){return _({host:this.node,sanitizer:this.sanitizer,source:String(e.data[this.mimeType]),translator:this.translator})}}class S extends b{constructor(e){super(e),this.addClass("jp-RenderedJavaScript")}render(e){const t=this.translator.load("jupyterlab");return _({host:this.node,sanitizer:this.sanitizer,source:t.__("JavaScript output is disabled in JupyterLab"),translator:this.translator})}}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.DomHandler=void 0;var o=n(102),a=n(359);i(n(359),t);var s=/\s+/g,l={normalizeWhitespace:!1,withStartIndices:!1,withEndIndices:!1,xmlMode:!1},c=function(){function e(e,t,n){this.dom=[],this.root=new a.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null,"function"==typeof t&&(n=t,t=l),"object"==typeof e&&(t=e,e=void 0),this.callback=null!=e?e:null,this.options=null!=t?t:l,this.elementCB=null!=n?n:null}return e.prototype.onparserinit=function(e){this.parser=e},e.prototype.onreset=function(){this.dom=[],this.root=new a.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null},e.prototype.onend=function(){this.done||(this.done=!0,this.parser=null,this.handleCallback(null))},e.prototype.onerror=function(e){this.handleCallback(e)},e.prototype.onclosetag=function(){this.lastNode=null;var e=this.tagStack.pop();this.options.withEndIndices&&(e.endIndex=this.parser.endIndex),this.elementCB&&this.elementCB(e)},e.prototype.onopentag=function(e,t){var n=this.options.xmlMode?o.ElementType.Tag:void 0,r=new a.Element(e,t,void 0,n);this.addNode(r),this.tagStack.push(r)},e.prototype.ontext=function(e){var t=this.options.normalizeWhitespace,n=this.lastNode;if(n&&n.type===o.ElementType.Text)t?n.data=(n.data+e).replace(s," "):n.data+=e,this.options.withEndIndices&&(n.endIndex=this.parser.endIndex);else{t&&(e=e.replace(s," "));var r=new a.Text(e);this.addNode(r),this.lastNode=r}},e.prototype.oncomment=function(e){if(this.lastNode&&this.lastNode.type===o.ElementType.Comment)this.lastNode.data+=e;else{var t=new a.Comment(e);this.addNode(t),this.lastNode=t}},e.prototype.oncommentend=function(){this.lastNode=null},e.prototype.oncdatastart=function(){var e=new a.Text(""),t=new a.NodeWithChildren(o.ElementType.CDATA,[e]);this.addNode(t),e.parent=t,this.lastNode=e},e.prototype.oncdataend=function(){this.lastNode=null},e.prototype.onprocessinginstruction=function(e,t){var n=new a.ProcessingInstruction(e,t);this.addNode(n)},e.prototype.handleCallback=function(e){if("function"==typeof this.callback)this.callback(e,this.dom);else if(e)throw e},e.prototype.addNode=function(e){var t=this.tagStack[this.tagStack.length-1],n=t.children[t.children.length-1];this.options.withStartIndices&&(e.startIndex=this.parser.startIndex),this.options.withEndIndices&&(e.endIndex=this.parser.endIndex),t.children.push(e),n&&(e.prev=n,n.next=e),e.parent=t,this.lastNode=null},e}();t.DomHandler=c,t.default=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.TagsFactory=t.AllTags=t.NoTags=t.AbstractTags=t.TagInfo=t.Label=void 0;var a=n(49),s=function(e,t){void 0===e&&(e="???"),void 0===t&&(t=""),this.tag=e,this.id=t};t.Label=s;var l=function(e,t,n,r,i,o,a,s){void 0===e&&(e=""),void 0===t&&(t=!1),void 0===n&&(n=!1),void 0===r&&(r=null),void 0===i&&(i=""),void 0===o&&(o=""),void 0===a&&(a=!1),void 0===s&&(s=""),this.env=e,this.taggable=t,this.defaultTags=n,this.tag=r,this.tagId=i,this.tagFormat=o,this.noTag=a,this.labelId=s};t.TagInfo=l;var c=function(){function e(){this.counter=0,this.allCounter=0,this.configuration=null,this.ids={},this.allIds={},this.labels={},this.allLabels={},this.redo=!1,this.refUpdate=!1,this.currentTag=new l,this.history=[],this.stack=[],this.enTag=function(e,t){var n=this.configuration.nodeFactory,r=n.create("node","mtd",[e]),i=n.create("node","mlabeledtr",[t,r]);return n.create("node","mtable",[i],{side:this.configuration.options.tagSide,minlabelspacing:this.configuration.options.tagIndent,displaystyle:!0})}}return e.prototype.start=function(e,t,n){this.currentTag&&this.stack.push(this.currentTag),this.currentTag=new l(e,t,n)},Object.defineProperty(e.prototype,"env",{get:function(){return this.currentTag.env},enumerable:!1,configurable:!0}),e.prototype.end=function(){this.history.push(this.currentTag),this.currentTag=this.stack.pop()},e.prototype.tag=function(e,t){this.currentTag.tag=e,this.currentTag.tagFormat=t?e:this.formatTag(e),this.currentTag.noTag=!1},e.prototype.notag=function(){this.tag("",!0),this.currentTag.noTag=!0},Object.defineProperty(e.prototype,"noTag",{get:function(){return this.currentTag.noTag},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"label",{get:function(){return this.currentTag.labelId},set:function(e){this.currentTag.labelId=e},enumerable:!1,configurable:!0}),e.prototype.formatUrl=function(e,t){return t+"#"+encodeURIComponent(e)},e.prototype.formatTag=function(e){return"("+e+")"},e.prototype.formatId=function(e){return"mjx-eqn:"+e.replace(/\s/g,"_")},e.prototype.formatNumber=function(e){return e.toString()},e.prototype.autoTag=function(){null==this.currentTag.tag&&(this.counter++,this.tag(this.formatNumber(this.counter),!1))},e.prototype.clearTag=function(){this.label="",this.tag(null,!0),this.currentTag.tagId=""},e.prototype.getTag=function(e){if(void 0===e&&(e=!1),e)return this.autoTag(),this.makeTag();var t=this.currentTag;return t.taggable&&!t.noTag&&(t.defaultTags&&this.autoTag(),t.tag)?this.makeTag():null},e.prototype.resetTag=function(){this.history=[],this.redo=!1,this.refUpdate=!1,this.clearTag()},e.prototype.reset=function(e){void 0===e&&(e=0),this.resetTag(),this.counter=this.allCounter=e,this.allLabels={},this.allIds={}},e.prototype.startEquation=function(e){this.history=[],this.stack=[],this.clearTag(),this.currentTag=new l("",void 0,void 0),this.labels={},this.ids={},this.counter=this.allCounter,this.redo=!1;var t=e.inputData.recompile;t&&(this.refUpdate=!0,this.counter=t.counter)},e.prototype.finishEquation=function(e){this.redo&&(e.inputData.recompile={state:e.state(),counter:this.allCounter}),this.refUpdate||(this.allCounter=this.counter),Object.assign(this.allIds,this.ids),Object.assign(this.allLabels,this.labels)},e.prototype.finalize=function(e,t){if(!t.display||this.currentTag.env||null==this.currentTag.tag)return e;var n=this.makeTag();return this.enTag(e,n)},e.prototype.makeId=function(){this.currentTag.tagId=this.formatId(this.configuration.options.useLabelIds&&this.label||this.currentTag.tag)},e.prototype.makeTag=function(){this.makeId(),this.label&&(this.labels[this.label]=new s(this.currentTag.tag,this.currentTag.tagId));var e=new a.default("\\text{"+this.currentTag.tagFormat+"}",{},this.configuration).mml();return this.configuration.nodeFactory.create("node","mtd",[e],{id:this.currentTag.tagId})},e}();t.AbstractTags=c;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.autoTag=function(){},t.prototype.getTag=function(){return this.currentTag.tag?e.prototype.getTag.call(this):null},t}(c);t.NoTags=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.finalize=function(e,t){if(!t.display||this.history.find((function(e){return e.taggable})))return e;var n=this.getTag(!0);return this.enTag(e,n)},t}(c);t.AllTags=d,function(e){var t=new Map([["none",u],["all",d]]),n="none";e.OPTIONS={tags:n,tagSide:"right",tagIndent:"0.8em",useLabelIds:!0,ignoreDuplicateLabels:!1},e.add=function(e,n){t.set(e,n)},e.addTags=function(t){var n,r;try{for(var i=o(Object.keys(t)),a=i.next();!a.done;a=i.next()){var s=a.value;e.add(s,t[s])}}catch(e){n={error:e}}finally{try{a&&!a.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}},e.create=function(e){var r=t.get(e)||t.get(n);if(!r)throw Error("Unknown tags class");return new r},e.setDefault=function(e){n=e},e.getDefault=function(){return e.create(n)}}(t.TagsFactory||(t.TagsFactory={}))},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0});var o,a=n(39),s=n(50),l=n(37);!function(e){e.variable=function(e,t){var n=l.default.getFontDef(e);e.stack.env.multiLetterIdentifiers&&""!==e.stack.env.font&&(t=e.string.substr(e.i-1).match(/^[a-z]+/i)[0],e.i+=t.length-1,n.mathvariant===s.TexConstant.Variant.NORMAL&&(n.autoOP=!1));var r=e.create("token","mi",n,t);e.Push(r)},e.digit=function(e,t){var n,r=e.configuration.options.digits,i=e.string.slice(e.i-1).match(r),o=l.default.getFontDef(e);i?(n=e.create("token","mn",o,i[0].replace(/[{}]/g,"")),e.i+=i[0].length-1):n=e.create("token","mo",o,t),e.Push(n)},e.controlSequence=function(e,t){var n=e.GetCS();e.parse("macro",[e,n])},e.mathchar0mi=function(e,t){var n=t.attributes||{mathvariant:s.TexConstant.Variant.ITALIC},r=e.create("token","mi",n,t.char);e.Push(r)},e.mathchar0mo=function(e,t){var n=t.attributes||{};n.stretchy=!1;var r=e.create("token","mo",n,t.char);a.default.setProperty(r,"fixStretchy",!0),e.configuration.addNode("fixStretchy",r),e.Push(r)},e.mathchar7=function(e,t){var n=t.attributes||{mathvariant:s.TexConstant.Variant.NORMAL};e.stack.env.font&&(n.mathvariant=e.stack.env.font);var r=e.create("token","mi",n,t.char);e.Push(r)},e.delimiter=function(e,t){var n=t.attributes||{};n=Object.assign({fence:!1,stretchy:!1},n);var r=e.create("token","mo",n,t.char);e.Push(r)},e.environment=function(e,t,n,o){var a=o[0],s=e.itemFactory.create("begin").setProperties({name:t,end:a});s=n.apply(void 0,i([e,s],r(o.slice(1)))),e.Push(s)}}(o||(o={})),t.default=o},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.BBox=t.BBoxStyleAdjust=void 0;var r=n(58);t.BBoxStyleAdjust=[["borderTopWidth","h"],["borderRightWidth","w"],["borderBottomWidth","d"],["borderLeftWidth","w",0],["paddingTop","h"],["paddingRight","w"],["paddingBottom","d"],["paddingLeft","w",0]];var i=function(){function e(e){void 0===e&&(e={w:0,h:-r.BIGDIMEN,d:-r.BIGDIMEN}),this.w=e.w||0,this.h="h"in e?e.h:-r.BIGDIMEN,this.d="d"in e?e.d:-r.BIGDIMEN,this.L=this.R=this.ic=this.sk=this.dx=0,this.scale=this.rscale=1,this.pwidth=""}return e.zero=function(){return new e({h:0,d:0,w:0})},e.empty=function(){return new e},e.prototype.empty=function(){return this.w=0,this.h=this.d=-r.BIGDIMEN,this},e.prototype.clean=function(){this.w===-r.BIGDIMEN&&(this.w=0),this.h===-r.BIGDIMEN&&(this.h=0),this.d===-r.BIGDIMEN&&(this.d=0)},e.prototype.rescale=function(e){this.w*=e,this.h*=e,this.d*=e},e.prototype.combine=function(e,t,n){void 0===t&&(t=0),void 0===n&&(n=0);var r=e.rscale,i=t+r*(e.w+e.L+e.R),o=n+r*e.h,a=r*e.d-n;i>this.w&&(this.w=i),o>this.h&&(this.h=o),a>this.d&&(this.d=a)},e.prototype.append=function(e){var t=e.rscale;this.w+=t*(e.w+e.L+e.R),t*e.h>this.h&&(this.h=t*e.h),t*e.d>this.d&&(this.d=t*e.d)},e.prototype.updateFrom=function(e){this.h=e.h,this.d=e.d,this.w=e.w,e.pwidth&&(this.pwidth=e.pwidth)},e.fullWidth="100%",e}();t.BBox=i},function(e,t,n){"use strict";function r(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=e&&("undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"]);if(null==n)return;var r,i,o=[],a=!0,s=!1;try{for(n=n.call(e);!(a=(r=n.next()).done)&&(o.push(r.value),!t||o.length!==t);a=!0);}catch(e){s=!0,i=e}finally{try{a||null==n.return||n.return()}finally{if(s)throw i}}return o}(e,t)||function(e,t){if(!e)return;if("string"==typeof e)return i(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return i(e,t)}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function i(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}e.exports=function(e){var t=r(e,4),n=t[1],i=t[3];if(!i)return n;if("function"==typeof btoa){var o=btoa(unescape(encodeURIComponent(JSON.stringify(i)))),a="sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(o),s="/*# ".concat(a," */"),l=i.sources.map((function(e){return"/*# sourceURL=".concat(i.sourceRoot||"").concat(e," */")}));return[n].concat(l).concat([s]).join("\n")}return[n].join("\n")}},function(e,t,n){"use strict";e.exports=function(e){var t=[];return t.toString=function(){return this.map((function(t){var n=e(t);return t[2]?"@media ".concat(t[2]," {").concat(n,"}"):n})).join("")},t.i=function(e,n,r){"string"==typeof e&&(e=[[null,e,""]]);var i={};if(r)for(var o=0;o<this.length;o++){var a=this[o][0];null!=a&&(i[a]=!0)}for(var s=0;s<e.length;s++){var l=[].concat(e[s]);r&&i[l[0]]||(n&&(l[2]?l[2]="".concat(n," and ").concat(l[2]):l[2]=n),t.push(l))}},t}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r,i,o=n(54);!function(e){function t(e,t,r=""){e.localName===t&&e.classList.add("jp-mod-styled"),"select"===e.localName&&n(e);const i=e.getElementsByTagName(t);for(let e=0;e<i.length;e++){const o=i[e];o.classList.add("jp-mod-styled"),r&&o.classList.add(r),"select"===t&&n(o)}}function n(e){const t=document.createElement("div");return t.classList.add("jp-select-wrapper"),e.addEventListener("focus",i.onFocus),e.addEventListener("blur",i.onFocus),e.classList.add("jp-mod-styled"),e.parentElement&&e.parentElement.replaceChild(t,e),t.appendChild(e),t.appendChild(o.a.element({tag:"span",stylesheet:"select",right:"8px",top:"5px",width:"18px"})),t}e.styleNode=function(e,n=""){t(e,"select",n),t(e,"textarea",n),t(e,"input",n),t(e,"button",n)},e.styleNodeByTag=t,e.wrapSelect=n}(r||(r={})),function(e){e.onFocus=function(e){const t=e.target.parentElement;t&&("focus"===e.type?t.classList.add("jp-mod-focused"):t.classList.remove("jp-mod-focused"))}}(i||(i={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r=n(35),i=n(86),o=n(66);class a{constructor(){this._observers=r.c()}on(e,t){r.e(this._observers,e,i.a).add(t)}once(e,t){const n=(...r)=>{this.off(e,n),t(...r)};this.on(e,n)}off(e,t){const n=this._observers.get(e);void 0!==n&&(n.delete(t),0===n.size&&this._observers.delete(e))}emit(e,t){return o.c((this._observers.get(e)||r.c()).values()).forEach(e=>e(...t))}destroy(){this._observers=r.c()}}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r={ZERO:0,ONE:1,TWO:2,THREE:3,FOUR:4}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r={NONE:"none",PRIMARY:"primary",SUCCESS:"success",WARNING:"warning",DANGER:"danger"}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.LegacyColors=t.Colors=void 0;var r=n(707);Object.defineProperty(t,"Colors",{enumerable:!0,get:function(){return r.Colors}});var i=n(708);Object.defineProperty(t,"LegacyColors",{enumerable:!0,get:function(){return i.LegacyColors}})},,function(e,t,n){"use strict";let r,i,o,{isClean:a,my:s}=n(159),l=n(123),c=n(127),u=n(124);class d extends u{push(e){return e.parent=this,this.proxyOf.nodes.push(e),this}each(e){if(!this.proxyOf.nodes)return;let t,n,r=this.getIterator();for(;this.indexes[r]<this.proxyOf.nodes.length&&(t=this.indexes[r],n=e(this.proxyOf.nodes[t],t),!1!==n);)this.indexes[r]+=1;return delete this.indexes[r],n}walk(e){return this.each((t,n)=>{let r;try{r=e(t,n)}catch(e){throw t.addToError(e)}return!1!==r&&t.walk&&(r=t.walk(e)),r})}walkDecls(e,t){return t?e instanceof RegExp?this.walk((n,r)=>{if("decl"===n.type&&e.test(n.prop))return t(n,r)}):this.walk((n,r)=>{if("decl"===n.type&&n.prop===e)return t(n,r)}):(t=e,this.walk((e,n)=>{if("decl"===e.type)return t(e,n)}))}walkRules(e,t){return t?e instanceof RegExp?this.walk((n,r)=>{if("rule"===n.type&&e.test(n.selector))return t(n,r)}):this.walk((n,r)=>{if("rule"===n.type&&n.selector===e)return t(n,r)}):(t=e,this.walk((e,n)=>{if("rule"===e.type)return t(e,n)}))}walkAtRules(e,t){return t?e instanceof RegExp?this.walk((n,r)=>{if("atrule"===n.type&&e.test(n.name))return t(n,r)}):this.walk((n,r)=>{if("atrule"===n.type&&n.name===e)return t(n,r)}):(t=e,this.walk((e,n)=>{if("atrule"===e.type)return t(e,n)}))}walkComments(e){return this.walk((t,n)=>{if("comment"===t.type)return e(t,n)})}append(...e){for(let t of e){let e=this.normalize(t,this.last);for(let t of e)this.proxyOf.nodes.push(t)}return this.markDirty(),this}prepend(...e){e=e.reverse();for(let t of e){let e=this.normalize(t,this.first,"prepend").reverse();for(let t of e)this.proxyOf.nodes.unshift(t);for(let t in this.indexes)this.indexes[t]=this.indexes[t]+e.length}return this.markDirty(),this}cleanRaws(e){if(super.cleanRaws(e),this.nodes)for(let t of this.nodes)t.cleanRaws(e)}insertBefore(e,t){let n,r=0===(e=this.index(e))&&"prepend",i=this.normalize(t,this.proxyOf.nodes[e],r).reverse();for(let t of i)this.proxyOf.nodes.splice(e,0,t);for(let t in this.indexes)n=this.indexes[t],e<=n&&(this.indexes[t]=n+i.length);return this.markDirty(),this}insertAfter(e,t){e=this.index(e);let n,r=this.normalize(t,this.proxyOf.nodes[e]).reverse();for(let t of r)this.proxyOf.nodes.splice(e+1,0,t);for(let t in this.indexes)n=this.indexes[t],e<n&&(this.indexes[t]=n+r.length);return this.markDirty(),this}removeChild(e){let t;e=this.index(e),this.proxyOf.nodes[e].parent=void 0,this.proxyOf.nodes.splice(e,1);for(let n in this.indexes)t=this.indexes[n],t>=e&&(this.indexes[n]=t-1);return this.markDirty(),this}removeAll(){for(let e of this.proxyOf.nodes)e.parent=void 0;return this.proxyOf.nodes=[],this.markDirty(),this}replaceValues(e,t,n){return n||(n=t,t={}),this.walkDecls(r=>{t.props&&!t.props.includes(r.prop)||t.fast&&!r.value.includes(t.fast)||(r.value=r.value.replace(e,n))}),this.markDirty(),this}every(e){return this.nodes.every(e)}some(e){return this.nodes.some(e)}index(e){return"number"==typeof e?e:(e.proxyOf&&(e=e.proxyOf),this.proxyOf.nodes.indexOf(e))}get first(){if(this.proxyOf.nodes)return this.proxyOf.nodes[0]}get last(){if(this.proxyOf.nodes)return this.proxyOf.nodes[this.proxyOf.nodes.length-1]}normalize(e,t){if("string"==typeof e)e=function e(t){return t.map(t=>(t.nodes&&(t.nodes=e(t.nodes)),delete t.source,t))}(r(e).nodes);else if(Array.isArray(e)){e=e.slice(0);for(let t of e)t.parent&&t.parent.removeChild(t,"ignore")}else if("root"===e.type&&"document"!==this.type){e=e.nodes.slice(0);for(let t of e)t.parent&&t.parent.removeChild(t,"ignore")}else if(e.type)e=[e];else if(e.prop){if(void 0===e.value)throw new Error("Value field is missed in node creation");"string"!=typeof e.value&&(e.value=String(e.value)),e=[new l(e)]}else if(e.selector)e=[new i(e)];else if(e.name)e=[new o(e)];else{if(!e.text)throw new Error("Unknown node type in node creation");e=[new c(e)]}return e.map(e=>(e[s]||d.rebuild(e),(e=e.proxyOf).parent&&e.parent.removeChild(e),e[a]&&function e(t){if(t[a]=!1,t.proxyOf.nodes)for(let n of t.proxyOf.nodes)e(n)}(e),void 0===e.raws.before&&t&&void 0!==t.raws.before&&(e.raws.before=t.raws.before.replace(/\S/g,"")),e.parent=this,e))}getProxyProcessor(){return{set:(e,t,n)=>(e[t]===n||(e[t]=n,"name"!==t&&"params"!==t&&"selector"!==t||e.markDirty()),!0),get:(e,t)=>"proxyOf"===t?e:e[t]?"each"===t||"string"==typeof t&&t.startsWith("walk")?(...n)=>e[t](...n.map(e=>"function"==typeof e?(t,n)=>e(t.toProxy(),n):e)):"every"===t||"some"===t?n=>e[t]((e,...t)=>n(e.toProxy(),...t)):"root"===t?()=>e.root().toProxy():"nodes"===t?e.nodes.map(e=>e.toProxy()):"first"===t||"last"===t?e[t].toProxy():e[t]:e[t]}}getIterator(){this.lastEach||(this.lastEach=0),this.indexes||(this.indexes={}),this.lastEach+=1;let e=this.lastEach;return this.indexes[e]=0,e}}d.registerParse=e=>{r=e},d.registerRule=e=>{i=e},d.registerAtRule=e=>{o=e},e.exports=d,d.default=d,d.rebuild=e=>{"atrule"===e.type?Object.setPrototypeOf(e,o.prototype):"rule"===e.type?Object.setPrototypeOf(e,i.prototype):"decl"===e.type?Object.setPrototypeOf(e,l.prototype):"comment"===e.type&&Object.setPrototypeOf(e,c.prototype),e[s]=!0,e.nodes&&e.nodes.forEach(e=>{d.rebuild(e)})}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.removeNonHTMLProps=t.DISPLAYNAME_PREFIX=void 0;var r=n(1);t.DISPLAYNAME_PREFIX="Blueprint3";var i=["active","alignText","asyncControl","containerRef","current","elementRef","fill","icon","inputRef","intent","inline","large","loading","leftElement","leftIcon","minimal","onRemove","outlined","panel","panelClassName","popoverProps","rightElement","rightIcon","round","small","text"];t.removeNonHTMLProps=function(e,t,n){return void 0===t&&(t=i),void 0===n&&(n=!1),n&&(t=t.concat(i)),t.reduce((function(e,t){return-1!==t.indexOf("-")||e.hasOwnProperty(t)&&delete e[t],e}),r.__assign({},e))}},function(e,t,n){"use strict";(function(e){n.d(t,"b",(function(){return a})),n.d(t,"a",(function(){return s}));var r=n(117),i=n(88);n(10),n(11);const o=e=>new Uint8Array(e),a=(e,t,n)=>new Uint8Array(e,t,n),s=(i.b,i.b,e=>{const t=o(e.byteLength);return t.set(e),t})}).call(this,n(160).Buffer)},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));const r=()=>new Set},function(e,t,n){"use strict";n.d(t,"c",(function(){return i})),n.d(t,"b",(function(){return o})),n.d(t,"a",(function(){return a}));Object.assign;const r=Object.keys,i=e=>r(e).length,o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),a=(e,t)=>e===t||i(e)===i(t)&&((e,t)=>{for(const n in e)if(!t(e[n],n))return!1;return!0})(e,(e,n)=>(void 0!==e||o(t,n))&&t[n]===e)},function(e,t,n){"use strict";(function(e){n.d(t,"c",(function(){return s})),n.d(t,"b",(function(){return l})),n.d(t,"a",(function(){return h}));var r=n(35),i=n(117),o=n(196),a=n(488);const s=void 0!==e&&e.release&&/node|io\.js/.test(e.release.name),l="undefined"!=typeof window&&!s;"undefined"!=typeof navigator&&/Mac/.test(navigator.platform);let c;const u=[],d=()=>{if(void 0===c)if(s){c=r.c();const t=e.argv;let n=null;for(let e=0;e<t.length;e++){const r=t[e];"-"===r[0]?(null!==n&&c.set(n,""),n=r):null!==n?(c.set(n,r),n=null):u.push(r)}null!==n&&c.set(n,"")}else"object"==typeof location?(c=r.c(),(location.search||"?").slice(1).split("&").forEach(e=>{if(0!==e.length){const[t,n]=e.split("=");c.set("--"+i.a(t,"-"),n),c.set("-"+i.a(t,"-"),n)}})):c=r.c();return c},h=t=>s?o.a(e.env[t.toUpperCase()]):o.a(a.a.getItem(t));(e=>d().has(e))("--"+(p="production"))||h(p);var p}).call(this,n(61))},function(e,t){function n(){return e.exports=n=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},e.exports.__esModule=!0,e.exports.default=e.exports,n.apply(this,arguments)}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){(function(e){var r=void 0!==e&&e||"undefined"!=typeof self&&self||window,i=Function.prototype.apply;function o(e,t){this._id=e,this._clearFn=t}t.setTimeout=function(){return new o(i.call(setTimeout,r,arguments),clearTimeout)},t.setInterval=function(){return new o(i.call(setInterval,r,arguments),clearInterval)},t.clearTimeout=t.clearInterval=function(e){e&&e.close()},o.prototype.unref=o.prototype.ref=function(){},o.prototype.close=function(){this._clearFn.call(r,this._id)},t.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},t.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},t._unrefActive=t.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout((function(){e._onTimeout&&e._onTimeout()}),t))},n(609),t.setImmediate="undefined"!=typeof self&&self.setImmediate||void 0!==e&&e.setImmediate||this&&this.setImmediate,t.clearImmediate="undefined"!=typeof self&&self.clearImmediate||void 0!==e&&e.clearImmediate||this&&this.clearImmediate}).call(this,n(55))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Utils=t.Keys=t.Classes=t.Colors=void 0;var r=n(1);r.__exportStar(n(694),t),r.__exportStar(n(702),t),r.__exportStar(n(703),t),r.__exportStar(n(704),t),r.__exportStar(n(382),t),r.__exportStar(n(705),t);var i=n(706);Object.defineProperty(t,"Colors",{enumerable:!0,get:function(){return i.Colors}}),r.__exportStar(n(709),t),r.__exportStar(n(383),t),r.__exportStar(n(128),t),r.__exportStar(n(384),t),r.__exportStar(n(84),t),r.__exportStar(n(170),t);var o=r.__importStar(n(381));t.Classes=o;var a=r.__importStar(n(710));t.Keys=a;var s=r.__importStar(n(92));t.Utils=s},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getRef=t.setRef=t.isDarkTheme=void 0;var r=n(1);r.__exportStar(n(695),t),r.__exportStar(n(696),t),r.__exportStar(n(171),t),r.__exportStar(n(697),t),r.__exportStar(n(698),t),r.__exportStar(n(699),t);var i=n(700);Object.defineProperty(t,"isDarkTheme",{enumerable:!0,get:function(){return i.isDarkTheme}});var o=n(170);Object.defineProperty(t,"setRef",{enumerable:!0,get:function(){return o.setRef}}),Object.defineProperty(t,"getRef",{enumerable:!0,get:function(){return o.getRef}})},function(e,t,n){e.exports=n(719)()},function(e,t,n){var r=n(760),i=n(765);e.exports=function(e,t){var n=i(e,t);return r(n)?n:void 0}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.BaseItem=t.MmlStack=void 0;var l=n(31),c=function(){function e(e){this._nodes=e}return Object.defineProperty(e.prototype,"nodes",{get:function(){return this._nodes},enumerable:!1,configurable:!0}),e.prototype.Push=function(){for(var e,t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];(e=this._nodes).push.apply(e,a([],o(t)))},e.prototype.Pop=function(){return this._nodes.pop()},Object.defineProperty(e.prototype,"First",{get:function(){return this._nodes[this.Size()-1]},set:function(e){this._nodes[this.Size()-1]=e},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"Last",{get:function(){return this._nodes[0]},set:function(e){this._nodes[0]=e},enumerable:!1,configurable:!0}),e.prototype.Peek=function(e){return null==e&&(e=1),this._nodes.slice(this.Size()-e)},e.prototype.Size=function(){return this._nodes.length},e.prototype.Clear=function(){this._nodes=[]},e.prototype.toMml=function(e,t){return void 0===e&&(e=!0),1!==this._nodes.length||t?this.create("node",e?"inferredMrow":"mrow",this._nodes,{}):this.First},e.prototype.create=function(e){for(var t,n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];return(t=this.factory.configuration.nodeFactory).create.apply(t,a([e],o(n)))},e}();t.MmlStack=c;var u=function(e){function t(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var i=e.call(this,n)||this;return i.factory=t,i.global={},i._properties={},i.isOpen&&(i._env={}),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"base"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"env",{get:function(){return this._env},set:function(e){this._env=e},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"copyEnv",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.getProperty=function(e){return this._properties[e]},t.prototype.setProperty=function(e,t){return this._properties[e]=t,this},Object.defineProperty(t.prototype,"isOpen",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isClose",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isFinal",{get:function(){return!1},enumerable:!1,configurable:!0}),t.prototype.isKind=function(e){return e===this.kind},t.prototype.checkItem=function(e){if(e.isKind("over")&&this.isOpen&&(e.setProperty("num",this.toMml(!1)),this.Clear()),e.isKind("cell")&&this.isOpen){if(e.getProperty("linebreak"))return t.fail;throw new l.default("Misplaced","Misplaced %1",e.getName())}if(e.isClose&&this.getErrors(e.kind)){var n=o(this.getErrors(e.kind),2),r=n[0],i=n[1];throw new l.default(r,i,e.getName())}return e.isFinal?(this.Push(e.First),t.fail):t.success},t.prototype.clearEnv=function(){var e,t;try{for(var n=s(Object.keys(this.env)),r=n.next();!r.done;r=n.next()){var i=r.value;delete this.env[i]}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}},t.prototype.setProperties=function(e){return Object.assign(this._properties,e),this},t.prototype.getName=function(){return this.getProperty("name")},t.prototype.toString=function(){return this.kind+"["+this.nodes.join("; ")+"]"},t.prototype.getErrors=function(e){return(this.constructor.errors||{})[e]||t.errors[e]},t.fail=[null,!1],t.success=[null,!0],t.errors={end:["MissingBeginExtraEnd","Missing \\begin{%1} or extra \\end{%1}"],close:["ExtraCloseMissingOpen","Extra close brace or missing open brace"],right:["MissingLeftExtraRight","Missing \\left or extra \\right"],middle:["ExtraMiddle","Extra \\middle"]},t}(c);t.BaseItem=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Macro=t.Symbol=void 0;var r=function(){function e(e,t,n){this._symbol=e,this._char=t,this._attributes=n}return Object.defineProperty(e.prototype,"symbol",{get:function(){return this._symbol},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"char",{get:function(){return this._char},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"attributes",{get:function(){return this._attributes},enumerable:!1,configurable:!0}),e}();t.Symbol=r;var i=function(){function e(e,t,n){void 0===n&&(n=[]),this._symbol=e,this._func=t,this._args=n}return Object.defineProperty(e.prototype,"symbol",{get:function(){return this._symbol},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"func",{get:function(){return this._func},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"args",{get:function(){return this._args},enumerable:!1,configurable:!0}),e}();t.Macro=i},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),i(n(638),t),i(n(639),t),i(n(640),t),i(n(641),t),i(n(642),t)},function(e,t,n){"use strict";var r,i=function(){return void 0===r&&(r=Boolean(window&&document&&document.all&&!window.atob)),r},o=function(){var e={};return function(t){if(void 0===e[t]){var n=document.querySelector(t);if(window.HTMLIFrameElement&&n instanceof window.HTMLIFrameElement)try{n=n.contentDocument.head}catch(e){n=null}e[t]=n}return e[t]}}(),a=[];function s(e){for(var t=-1,n=0;n<a.length;n++)if(a[n].identifier===e){t=n;break}return t}function l(e,t){for(var n={},r=[],i=0;i<e.length;i++){var o=e[i],l=t.base?o[0]+t.base:o[0],c=n[l]||0,u="".concat(l," ").concat(c);n[l]=c+1;var d=s(u),h={css:o[1],media:o[2],sourceMap:o[3]};-1!==d?(a[d].references++,a[d].updater(h)):a.push({identifier:u,updater:g(h,t),references:1}),r.push(u)}return r}function c(e){var t=document.createElement("style"),r=e.attributes||{};if(void 0===r.nonce){var i=n.nc;i&&(r.nonce=i)}if(Object.keys(r).forEach((function(e){t.setAttribute(e,r[e])})),"function"==typeof e.insert)e.insert(t);else{var a=o(e.insert||"head");if(!a)throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");a.appendChild(t)}return t}var u,d=(u=[],function(e,t){return u[e]=t,u.filter(Boolean).join("\n")});function h(e,t,n,r){var i=n?"":r.media?"@media ".concat(r.media," {").concat(r.css,"}"):r.css;if(e.styleSheet)e.styleSheet.cssText=d(t,i);else{var o=document.createTextNode(i),a=e.childNodes;a[t]&&e.removeChild(a[t]),a.length?e.insertBefore(o,a[t]):e.appendChild(o)}}function p(e,t,n){var r=n.css,i=n.media,o=n.sourceMap;if(i?e.setAttribute("media",i):e.removeAttribute("media"),o&&"undefined"!=typeof btoa&&(r+="\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(o))))," */")),e.styleSheet)e.styleSheet.cssText=r;else{for(;e.firstChild;)e.removeChild(e.firstChild);e.appendChild(document.createTextNode(r))}}var f=null,m=0;function g(e,t){var n,r,i;if(t.singleton){var o=m++;n=f||(f=c(t)),r=h.bind(null,n,o,!1),i=h.bind(null,n,o,!0)}else n=c(t),r=p.bind(null,n,t),i=function(){!function(e){if(null===e.parentNode)return!1;e.parentNode.removeChild(e)}(n)};return r(e),function(t){if(t){if(t.css===e.css&&t.media===e.media&&t.sourceMap===e.sourceMap)return;r(e=t)}else i()}}e.exports=function(e,t){(t=t||{}).singleton||"boolean"==typeof t.singleton||(t.singleton=i());var n=l(e=e||[],t);return function(e){if(e=e||[],"[object Array]"===Object.prototype.toString.call(e)){for(var r=0;r<n.length;r++){var i=s(n[r]);a[i].references--}for(var o=l(e,t),c=0;c<n.length;c++){var u=s(n[c]);0===a[u].references&&(a[u].updater(),a.splice(u,1))}n=o}}}},function(e,t,n){var r=n(717);e.exports=function(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,r(e,t)},e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){"use strict";function r(){return o.keyboardLayout}n.d(t,"a",(function(){return r}));var i=function(){function e(t,n,r){void 0===r&&(r=[]),this.name=t,this._codes=n,this._keys=e.extractKeys(n),this._modifierKeys=e.convertToKeySet(r)}return e.prototype.keys=function(){return Object.keys(this._keys)},e.prototype.isValidKey=function(e){return e in this._keys},e.prototype.isModifierKey=function(e){return e in this._modifierKeys},e.prototype.keyForKeydownEvent=function(e){return this._codes[e.keyCode]||""},e}();!function(e){e.extractKeys=function(e){var t=Object.create(null);for(var n in e)t[e[n]]=!0;return t},e.convertToKeySet=function(e){for(var t=Object(null),n=0,r=e.length;n<r;++n)t[e[n]]=!0;return t}}(i||(i={}));var o,a=new i("en-us",{8:"Backspace",9:"Tab",13:"Enter",16:"Shift",17:"Ctrl",18:"Alt",19:"Pause",27:"Escape",32:"Space",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",48:"0",49:"1",50:"2",51:"3",52:"4",53:"5",54:"6",55:"7",56:"8",57:"9",59:";",61:"=",65:"A",66:"B",67:"C",68:"D",69:"E",70:"F",71:"G",72:"H",73:"I",74:"J",75:"K",76:"L",77:"M",78:"N",79:"O",80:"P",81:"Q",82:"R",83:"S",84:"T",85:"U",86:"V",87:"W",88:"X",89:"Y",90:"Z",91:"Meta",93:"ContextMenu",96:"0",97:"1",98:"2",99:"3",100:"4",101:"5",102:"6",103:"7",104:"8",105:"9",106:"*",107:"+",109:"-",110:".",111:"/",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",173:"-",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'",224:"Meta"},["Shift","Ctrl","Alt","Meta"]);!function(e){e.keyboardLayout=a}(o||(o={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return L})),n.d(t,"b",(function(){return C}));var r=n(22),i=n(32),o=n(1012),a=n(2),s=n(6),l=n(27),c=n(64),u=n(4),d=n(14),h=n.n(d);n(670),n(671),n(672),n(376),n(673),n(674),n(377),n(675),n(676),n(677),n(678),n(587),n(679),n(680),n(681),n(168),n(682),n(683),n(684),n(685),n(686),n(687);var p=n(25),f=n(36),m=n(52),g=n(69),v=n(78);const y=(e,t)=>{let n=0,r=0;for(;n<e.length&&n<t.length&&e[n]===t[n];)n++;if(n!==e.length||n!==t.length)for(;r+n<e.length&&r+n<t.length&&e[e.length-r-1]===t[t.length-r-1];)r++;return{index:n,remove:e.length-n-r,insert:t.slice(n,t.length-r)}},_=e=>{const t=document.createElement("span");t.setAttribute("style","user-select: none;");const n=document.createElement("span");n.insertBefore(document.createTextNode(""),null);const r=document.createElement("span");return r.setAttribute("class","y-line-selection"),r.setAttribute("style",`display: inline-block; position: absolute; left: 4px; right: 4px; top: 0; bottom: 0; background-color: ${e}70`),t.insertBefore(r,null),t.insertBefore(n,null),t},b=(e,t,n,r,i,o)=>{const a=o.getStates().get(i),s=r.get(i);if(void 0!==s&&(s.caret&&s.caret.clear(),s.sel.forEach(e=>e.clear()),r.delete(i)),void 0===a)return;const l=a.user||{};null==l.color&&(l.color="#ffa500"),null==l.name&&(l.name="User: "+i);const c=a.cursor;if(null==c||null==c.anchor||null==c.head)return;const u=f.g(JSON.parse(c.anchor),e),d=f.g(JSON.parse(c.head),e);if(null!==u&&null!==d&&u.type===n&&d.type===n){const e=t.posFromIndex(d.index),n=t.posFromIndex(u.index);let o,p;d.index<u.index?(o=e,p=n):(o=n,p=e);const f=((e,t)=>{const n=document.createElement("span");n.classList.add("remote-caret"),n.setAttribute("style","border-color: "+t);const r=document.createElement("div");return r.setAttribute("style","background-color: "+t),r.insertBefore(document.createTextNode(e),null),n.insertBefore(r,null),setTimeout(()=>{n.classList.add("hide-name")},2e3),n})(l.name,l.color);s&&m.c(a.cursor.anchor,s.awCursor.anchor)&&m.c(a.cursor.head,s.awCursor.head)&&f.classList.add("hide-name");const g=[];if(d.index!==u.index){for(o.line!==p.line&&0!==o.ch&&(g.push(t.markText(o,new h.a.Pos(o.line+1,0),{css:`background-color: ${l.color}70;`,inclusiveRight:!1,inclusiveLeft:!1})),o=new h.a.Pos(o.line+1,0));o.line!==p.line;)g.push(t.setBookmark(new h.a.Pos(o.line,0),{widget:_(l.color)})),o=new h.a.Pos(o.line+1,0);g.push(t.markText(o,p,{css:`background-color: ${l.color}70;`,inclusiveRight:!1,inclusiveLeft:!1}))}const v=g.length>0&&p===e&&0===e.ch?null:t.setBookmark(e,{widget:f,insertLeft:!0});r.set(i,{caret:v,sel:g,awCursor:c})}};class M extends v.a{constructor(e,t,n=null,{yUndoManager:r=null}={}){super();const i=e.doc,o=t.getDoc();if(this.doc=i,this.type=e,this.cm=t,this.cmDoc=o,this.awareness=n||null,this.yUndoManager=r,this._onStackItemAdded=({stackItem:t,changedParentTypes:n})=>{n.has(e)&&this._beforeChangeSelection&&t.meta.set(this,this._beforeChangeSelection)},this._onStackItemPopped=({stackItem:e})=>{const n=e.meta.get(this);if(n){const e=f.g(n.anchor,i).index,r=f.g(n.head,i).index;t.setSelection(t.posFromIndex(e),t.posFromIndex(r)),this._beforeChange()}},r){r.trackedOrigins.add(this);const e=e=>{e.endOperation(),r.undo(),e.startOperation()},n=e=>{e.endOperation(),r.redo(),e.startOperation()};t.addKeyMap({"Ctrl-Z":e,"Shift-Ctrl-Z":n,"Ctrl-Y":n,"Cmd-Z":e,"Shift-Cmd-Z":n,"Cmd-Y":n}),r.on("stack-item-added",this._onStackItemAdded),r.on("stack-item-popped",this._onStackItemPopped)}this._mux=(()=>{let e=!0;return(t,n)=>{if(e){e=!1;try{t()}finally{e=!0}}else void 0!==n&&n()}})(),o.setValue(e.toString()),this._typeObserver=e=>((e,t)=>{e._mux(()=>{const n=e.cmDoc,r=n.getEditor();let i=r.indexFromPos(r.getCursor("anchor")),o=r.indexFromPos(r.getCursor("head"));const a=o<i;if(a){const e=o;o=i,i=e}const s=()=>{const e=t.delta;let r=0;for(let a=0;a<t.delta.length;a++){const t=e[a];if(t.retain)r+=t.retain;else if(t.insert){(r<i||i<o&&r===i)&&(i+=t.insert.length),r<o&&(o+=t.insert.length);const e=n.posFromIndex(r);n.replaceRange(t.insert,e,e,"y-codemirror"),r+=t.insert.length}else if(t.delete){r<i&&(i=p.g(i-t.delete,r)),r<o&&(o=p.g(o-t.delete,r));const e=n.posFromIndex(r),a=n.posFromIndex(r+t.delete);n.replaceRange("",e,a,"y-codemirror")}}};if(r?r.operation(s):s(),a){const e=o;o=i,i=e}r.setSelection(r.posFromIndex(i),r.posFromIndex(o),{scroll:!1})})})(this,e),this._targetObserver=(e,t)=>{e.getDoc()===o&&((e,t)=>{e._mux(()=>{e.doc.transact(()=>{const n=e.yUndoManager&&t.some(e=>"paste"===e.origin);if(n&&e.yUndoManager.stopCapturing(),t.length>1){const t=y(e.type.toString(),e.cmDoc.getValue());e.type.delete(t.index,t.remove),e.type.insert(t.index,t.insert)}else{const n=t[0],r=e.cmDoc.indexFromPos(n.from),i=n.removed.map(e=>e.length).reduce(p.b)+n.removed.length-1;i>0&&e.type.delete(r,i),n.text.length>0&&e.type.insert(r,n.text.join("\n"))}n&&e.yUndoManager.stopCapturing()},e)}),e._pendingCursorEvent&&(e._pendingCursorEvent=!1,e.emit("cursorActivity",[e]))})(this,t)},this._cursors=new Map,this._changedCursors=new Set,this._debounceCursorEvent=g.a(10),this._awarenessListener=r=>{if(t.getDoc()!==o)return;const a=e=>{e!==i.clientID&&this._changedCursors.add(e)};r.added.forEach(a),r.removed.forEach(a),r.updated.forEach(a),this._changedCursors.size>0&&this._debounceCursorEvent(()=>{this._changedCursors.forEach(r=>{b(i,t,e,this._cursors,r,n)}),this._changedCursors.clear()})},this._pendingCursorEvent=!1,this._cursorListener=()=>{t.getDoc()===o&&(this._pendingCursorEvent=!0,setTimeout(()=>{this._pendingCursorEvent&&(this._pendingCursorEvent=!1,this.emit("cursorActivity",[t]))},0))},this.on("cursorActivity",()=>{((e,t,n,r)=>{const i=r.getLocalState();if(!t.hasFocus()||null==i||!t.display.wrapper.ownerDocument.hasFocus())return;const o=f.i(n,t.indexFromPos(t.getCursor("anchor"))),a=f.i(n,t.indexFromPos(t.getCursor("head")));let s=null,l=null;null!=i.cursor&&(s=f.h(JSON.parse(i.cursor.anchor)),l=f.h(JSON.parse(i.cursor.head))),null!=i.cursor&&f.f(s,o)&&f.f(l,a)||r.setLocalStateField("cursor",{anchor:JSON.stringify(o),head:JSON.stringify(a)})})(0,t,e,n)}),this._blurListeer=()=>n.setLocalStateField("cursor",null),e.observe(this._typeObserver),t.on("changes",this._targetObserver),this._beforeChangeSelection=null,this._beforeChange=()=>{this._mux(()=>{const n=f.i(e,t.indexFromPos(t.getCursor("anchor"))),r=f.i(e,t.indexFromPos(t.getCursor("head")));this._beforeChangeSelection={anchor:n,head:r}})},t.on("beforeChange",this._beforeChange),n&&(t.on("swapDoc",this._blurListeer),n.on("change",this._awarenessListener),t.on("cursorActivity",this._cursorListener),t.on("blur",this._blurListeer),t.on("focus",this._cursorListener))}destroy(){this.type.unobserve(this._typeObserver),this.cm.off("swapDoc",this._blurListeer),this.cm.off("changes",this._targetObserver),this.cm.off("beforeChange",this._beforeChange),this.cm.off("cursorActivity",this._cursorListener),this.cm.off("focus",this._cursorListener),this.cm.off("blur",this._blurListeer),this.awareness&&this.awareness.off("change",this._awarenessListener),this.yUndoManager&&(this.yUndoManager.off("stack-item-added",this._onStackItemAdded),this.yUndoManager.off("stack-item-popped",this._onStackItemPopped),this.yUndoManager.trackedOrigins.delete(this)),this.type=null,this.cm=null,this.cmDoc=null,super.destroy()}}var w;!function(e){e.defaultMimeType="text/plain"}(w||(w={}));var A=n(12);n(688),n(590),n(588),n(204),n(594),n(595),n(206),n(169),n(596),n(597),n(598),n(592);h.a.defineMode("ipython",(e,t)=>{const n={};for(const e in t)t.hasOwnProperty(e)&&(n[e]=t[e]);return n.name="python",n.singleOperators=new RegExp("^[\\+\\-\\*/%&|@\\^~<>!\\?]"),n.identifiers=new RegExp("^[_A-Za-z¡-][_A-Za-z0-9¡-]*"),h.a.getMode(e,n)},"python"),h.a.defineMIME("text/x-ipython","ipython"),h.a.modeInfo.push({ext:[],mime:"text/x-ipython",mode:"ipython",name:"ipython"});var C,x;n(591),n(599),n(593);h.a.defineMode("ipythongfm",(e,t)=>{const n=h.a.getMode(e,{name:"gfm",tokenTypeOverrides:{list3:"string-2"}}),r=h.a.getMode(e,{name:"stex",inMathMode:!0});return h.a.multiplexingMode(n,{open:"<code>",close:"</code>",mode:n,parseDelimiters:!0},{open:"<pre>",close:"</pre>",mode:n,parseDelimiters:!0},{open:"```",close:"```",mode:n,parseDelimiters:!0},{open:"`",close:"`",mode:n,parseDelimiters:!0},{open:"$$",close:"$$",mode:r,delimStyle:"delimit"},{open:/\$(?=.*\$)/,close:"$",mode:r,delimStyle:"delimit"},{open:"\\(",close:"\\)",mode:r,delimStyle:"delimit"},{open:"\\[",close:"\\]",mode:r,delimStyle:"delimit"})},"gfm"),h.a.defineMIME("text/x-ipythongfm","ipythongfm"),h.a.modeInfo.push({ext:[],mime:"text/x-ipythongfm",mode:"ipythongfm",name:"ipythongfm"}),function(e){const t=[{loader:async e=>h.a.modes.hasOwnProperty(e.mode),rank:0},{loader:function(e){return new Promise((t,r)=>{Promise.all([n.e(1),n.e(2)]).then((function(){var r=[n(1122)(`./${e.mode}/${e.mode}.js`)];(function(){t(!0)}).apply(null,r)})).catch(n.oe)})},rank:99}];function r(e){var t;const n="string"==typeof e?e:e.mode||e.name,r="string"!=typeof e?e.mime:n,o="string"!=typeof e&&null!==(t=e.ext)&&void 0!==t?t:[];return h.a.findModeByName(n||"")||h.a.findModeByMIME(r||"")||i(o)||h.a.findModeByMIME(w.defaultMimeType)||h.a.findModeByMIME("text/plain")}function i(e){if("string"==typeof e)return h.a.findModeByExtension(e);for(let t=0;t<e.length;t++){const n=h.a.findModeByExtension(e[t]);if(n)return n}return null}e.getModeInfo=function(){return h.a.modeInfo},e.run=function(e,t,n){h.a.runMode(e,t,n)},e.ensure=async function(e){const n=r(e);for(const e of t)if(await e.loader(n))return n;return null},e.addSpecLoader=function(e,n){const r={loader:e,rank:n},i=a.ArrayExt.upperBound(t,r,x.itemCmp);a.ArrayExt.insert(t,i,r)},e.findBest=r,e.findByMIME=function(e){return h.a.findModeByMIME(e)},e.findByName=function(e){return h.a.findModeByName(e)},e.findByFileName=function(e){const t=A.PathExt.basename(e);return h.a.findModeByFileName(t)},e.findByExtension=i}(C||(C={})),(x||(x={})).itemCmp=function(e,t){return e.rank-t.rank};var E=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};class L{constructor(e){var t;this.edgeRequested=new u.Signal(this),this.selectionMarkers={},this._keydownHandlers=new Array,this._changeGuard=!1,this._uuid="",this._needsRefresh=!1,this._isDisposed=!1,this._lastChange=null;const n=this.host=e.host;this.translator=e.translator||r.b,this._trans=this.translator.load("jupyterlab"),n.classList.add("jp-CodeMirrorEditor"),n.classList.add("jp-Editor"),n.addEventListener("focus",this,!0),n.addEventListener("blur",this,!0),n.addEventListener("scroll",this,!0),this._uuid=e.uuid||s.UUID.uuid4();const i=e.selectionStyle||{};this._selectionStyle=Object.assign(Object.assign({},o.a.defaultSelectionStyle),i);const l=this._model=e.model,d=e.config||{},p=this._config=Object.assign(Object.assign({},L.defaultConfig),d),f=this._editor=T.createEditor(n,p);this._initializeEditorBinding(),this.model.sharedModelSwitched.connect(this._initializeEditorBinding,this);f.getDoc();this._onMimeTypeChanged(),this._onCursorActivity(),this._poll=new c.Poll({factory:async()=>{this._checkSync()},frequency:{interval:3e3,backoff:!1},standby:()=>!this._lastChange||"when-hidden"}),l.mimeTypeChanged.connect(this._onMimeTypeChanged,this),l.selections.changed.connect(this._onSelectionsChanged,this),h.a.on(f,"keydown",(e,t)=>{-1===a.ArrayExt.findFirstIndex(this._keydownHandlers,e=>!0===e(this,t)&&(t.preventDefault(),!0))&&this.onKeydown(t)}),null===(t=this._yeditorBinding)||void 0===t||t.on("cursorActivity",()=>this._onCursorActivity()),h.a.on(f.getDoc(),"change",(e,t)=>{"setValue"===t.origin&&this.hasFocus()&&this.refresh(),this._lastChange=t}),f.on("paste",(e,t)=>{var n;null===(n=this._config.handlePaste)||void 0===n||n||(t.codemirrorIgnore=!0)}),f.getWrapperElement().addEventListener("paste",()=>{this.hasFocus()&&this.refresh()})}_initializeEditorBinding(){var e;null===(e=this._yeditorBinding)||void 0===e||e.destroy();const t=this.model.sharedModel,n=t.undoManager?{yUndoManager:t.undoManager}:{},r=t.awareness;this._yeditorBinding=new M(t.ysource,this.editor,r,n)}get uuid(){return this._uuid}set uuid(e){this._uuid=e}get selectionStyle(){return this._selectionStyle}set selectionStyle(e){this._selectionStyle=e}get editor(){return this._editor}get doc(){return this._editor.getDoc()}get lineCount(){return this.doc.lineCount()}get model(){return this._model}get lineHeight(){return this._editor.defaultTextHeight()}get charWidth(){return this._editor.defaultCharWidth()}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,this.host.removeEventListener("focus",this,!0),this.host.removeEventListener("blur",this,!0),this.host.removeEventListener("scroll",this,!0),this._yeditorBinding&&this._yeditorBinding.destroy(),this._keydownHandlers.length=0,this._poll.dispose(),u.Signal.clearData(this))}getOption(e){return this._config[e]}setOption(e,t){this._config[e]!==t&&(this._config[e]=t,T.setOption(this.editor,e,t,this._config))}setOptions(e){const t=this._editor;t.startOperation();for(let n in e)t.operation(()=>{this.setOption(n,e[n])});t.endOperation()}getLine(e){return this.doc.getLine(e)}getOffsetAt(e){return this.doc.indexFromPos({ch:e.column,line:e.line})}getPositionAt(e){const{ch:t,line:n}=this.doc.posFromIndex(e);return{line:n,column:t}}undo(){this.model.sharedModel.undo()}redo(){this.model.sharedModel.redo()}clearHistory(){var e,t;null===(t=null===(e=this._yeditorBinding)||void 0===e?void 0:e.yUndoManager)||void 0===t||t.clear()}focus(){this._editor.focus()}hasFocus(){return this._editor.getWrapperElement().contains(document.activeElement)}blur(){this._editor.getInputField().blur()}refresh(){this._editor.refresh(),this._needsRefresh=!1}resizeToFit(){this.hasFocus()?this.refresh():this._needsRefresh=!0,this._clearHover()}addOverlay(e,t){this._editor.addOverlay(e,t)}removeOverlay(e){this._editor.removeOverlay(e)}getSearchCursor(e,t,n){return this._editor.getDoc().getSearchCursor(e,t,n)}getCursor(e){return this._editor.getDoc().getCursor(e)}get state(){return this._editor.state}operation(e){return this._editor.operation(e)}firstLine(){return this._editor.getDoc().firstLine()}lastLine(){return this._editor.getDoc().lastLine()}scrollIntoView(e,t){this._editor.scrollIntoView(e,t)}scrollIntoViewCentered(e){var t,n;const r=this._editor.charCoords(e,"local").top,i=this._editor.getWrapperElement().offsetHeight;null===(n=(t=this.host).scrollIntoView)||void 0===n||n.call(t,{behavior:"auto",block:"center",inline:"center"}),this._editor.scrollTo(null,r-i/2)}cursorCoords(e,t){return this._editor.cursorCoords(e,t)}getRange(e,t,n){return this._editor.getDoc().getRange(e,t,n)}addKeydownHandler(e){return this._keydownHandlers.push(e),new l.DisposableDelegate(()=>{a.ArrayExt.removeAllWhere(this._keydownHandlers,t=>t===e)})}setSize(e){e?this._editor.setSize(e.width,e.height):this._editor.setSize(null,null),this._needsRefresh=!1}revealPosition(e){const t=this._toCodeMirrorPosition(e);this._editor.scrollIntoView(t)}revealSelection(e){const t={from:this._toCodeMirrorPosition(e.start),to:this._toCodeMirrorPosition(e.end)};this._editor.scrollIntoView(t)}getCoordinateForPosition(e){const t=this._toCodeMirrorPosition(e);return this.editor.charCoords(t,"page")}getPositionForCoordinate(e){return this._toPosition(this.editor.coordsChar(e))||null}getCursorPosition(){const e=this.doc.getCursor();return this._toPosition(e)}setCursorPosition(e,t){const n=this._toCodeMirrorPosition(e);this.doc.setCursor(n,void 0,t),this.editor.hasFocus()||this.model.selections.set(this.uuid,this.getSelections())}getSelection(){return this.getSelections()[0]}setSelection(e){this.setSelections([e])}getSelections(){const e=this.doc.listSelections();if(e.length>0)return e.map(e=>this._toSelection(e));const t=this.doc.getCursor();return[this._toSelection({anchor:t,head:t})]}setSelections(e){const t=this._toCodeMirrorSelections(e);this.doc.setSelections(t,0)}replaceSelection(e){this.doc.replaceSelection(e)}getTokens(){let e=[];for(let t=0;t<this.lineCount;++t){const n=this.editor.getLineTokens(t).map(e=>({offset:this.getOffsetAt({column:e.start,line:t}),value:e.string,type:e.type||""}));e=e.concat(n)}return e}getTokenForPosition(e){var t;const n=this._toCodeMirrorPosition(e),r=this.editor.getTokenAt(n);return{offset:this.getOffsetAt({column:r.start,line:n.line}),value:r.string,type:null!==(t=r.type)&&void 0!==t?t:void 0}}newIndentedLine(){this.execCommand("newlineAndIndent")}execCommand(e){this._editor.execCommand(e)}onKeydown(e){const t=this.getCursorPosition(),{line:n,column:r}=t;if(0===n&&0===r&&38===e.keyCode)return e.shiftKey||this.edgeRequested.emit("top"),!1;if(0===n&&38===e.keyCode)return e.shiftKey||this.edgeRequested.emit("topLine"),!1;const i=this.lineCount-1,o=this.getLine(i).length;return n===i&&r===o&&40===e.keyCode&&(e.shiftKey||this.edgeRequested.emit("bottom"),!1)}_toCodeMirrorSelections(e){if(e.length>0)return e.map(e=>this._toCodeMirrorSelection(e));const t={line:0,ch:0};return[{anchor:t,head:t}]}_onMimeTypeChanged(){const e=this._model.mimeType,t=this._editor.getOption("extraKeys")||{};"text/plain"!==e&&"text/x-ipythongfm"!==e?t.Backspace="delSpaceToPrevTabStop":delete t.Backspace,this.setOption("extraKeys",t),C.ensure(e).then(e=>{var t;this.setOption("mode",null!==(t=null==e?void 0:e.mime)&&void 0!==t?t:"null")})}_onSelectionsChanged(e,t){const n=t.key;n!==this.uuid&&(this._cleanSelections(n),"remove"!==t.type&&t.newValue&&this._markSelections(n,t.newValue))}_cleanSelections(e){const t=this.selectionMarkers[e];t&&t.forEach(e=>{e.clear()}),delete this.selectionMarkers[e]}_markSelections(e,t){const n=[];let r;e===this._hoverId&&this._clearHover(),this._model.modelDB.collaborators&&(r=this._model.modelDB.collaborators.get(e)),t.forEach(e=>{if(s.JSONExt.deepEqual(e.start,e.end)){if(r){const t=this._getCaret(r);n.push(this.doc.setBookmark(this._toCodeMirrorPosition(e.end),{widget:t}))}}else{const t=e.start.line<e.end.line||e.start.line===e.end.line&&e.start.column<=e.end.column,i=this._toCodeMirrorPosition(t?e.start:e.end),o=this._toCodeMirrorPosition(t?e.end:e.start);let a;a=r?this._toTextMarkerOptions(Object.assign(Object.assign({},e.style),{color:r.color})):this._toTextMarkerOptions(e.style),n.push(this.doc.markText(i,o,a))}}),this.selectionMarkers[e]=n}_onCursorActivity(){if(this._editor.hasFocus()){const e=this.getSelections();this.model.selections.set(this.uuid,e)}}_toSelection(e){return{uuid:this.uuid,start:this._toPosition(e.anchor),end:this._toPosition(e.head),style:this.selectionStyle}}_toTextMarkerOptions(e){const t=`background-color: rgba( ${parseInt(e.color.slice(1,3),16)}, ${parseInt(e.color.slice(3,5),16)}, ${parseInt(e.color.slice(5,7),16)}, 0.15)`;return{className:e.className,title:e.displayName,css:t}}_toCodeMirrorSelection(e){return{anchor:this._toCodeMirrorPosition(e.start),head:this._toCodeMirrorPosition(e.end)}}_toPosition(e){return{line:e.line,column:e.ch}}_toCodeMirrorPosition(e){return{line:e.line,ch:e.column}}_onValueChanged(e,t){if(this._changeGuard)return;this._changeGuard=!0;const n=this.doc;switch(t.type){case"insert":{const e=n.posFromIndex(t.start);n.replaceRange(t.value,e,e,"+input");break}case"remove":{const e=n.posFromIndex(t.start),r=n.posFromIndex(t.end);n.replaceRange("",e,r,"+input");break}case"set":n.setValue(t.value)}this._changeGuard=!1}_beforeDocChanged(e,t){if(this._changeGuard)return;this._changeGuard=!0;const n=this._model.value,r=e.indexFromPos(t.from),i=e.indexFromPos(t.to),o=t.text.join("\n");i!==r&&n.remove(r,i),o&&n.insert(r,o),this._changeGuard=!1}handleEvent(e){switch(e.type){case"focus":this._evtFocus(e);break;case"blur":this._evtBlur(e);break;case"scroll":this._evtScroll()}}_evtFocus(e){this._needsRefresh&&this.refresh(),this.host.classList.add("jp-mod-focused"),this._onCursorActivity()}_evtBlur(e){this.host.classList.remove("jp-mod-focused")}_evtScroll(){this._clearHover()}_clearHover(){this._caretHover&&(window.clearTimeout(this._hoverTimeout),document.body.removeChild(this._caretHover),this._caretHover=null)}_getCaret(e){const t=e?e.displayName:"Anonymous",n=e?e.color:this._selectionStyle.color,r=document.createElement("span");return r.className="jp-CollaboratorCursor",r.style.borderBottomColor=n,r.onmouseenter=()=>{this._clearHover(),this._hoverId=e.sessionId;const i=r.getBoundingClientRect(),o=document.createElement("div");o.className="jp-CollaboratorCursor-hover",o.style.left=String(i.left)+"px",o.style.top=String(i.bottom)+"px",o.textContent=t,o.style.backgroundColor=n,o.onmouseenter=()=>{window.clearTimeout(this._hoverTimeout)},o.onmouseleave=()=>{this._hoverTimeout=window.setTimeout(()=>{this._clearHover()},1e3)},this._caretHover=o,document.body.appendChild(o)},r.onmouseleave=()=>{this._hoverTimeout=window.setTimeout(()=>{this._clearHover()},1e3)},r}_checkSync(){const e=this._lastChange;if(!e)return;this._lastChange=null;const t=this._editor,n=t.getDoc();n.getValue()!==this._model.value.text&&(Object(i.b)({title:this._trans.__("Code Editor out of Sync"),body:this._trans.__("Please open your browser JavaScript console for bug report instructions")}),console.warn('If you are able and willing to publicly share the text or code in your editor, you can help us debug the "Code Editor out of Sync" message by pasting the following to the public issue at https://github.com/jupyterlab/jupyterlab/issues/2951. Please note that the data below includes the text/code in your editor.'),console.warn(JSON.stringify({model:this._model.value.text,view:n.getValue(),selections:this.getSelections(),cursor:this.getCursorPosition(),lineSep:t.getOption("lineSeparator"),mode:t.getOption("mode"),change:e})))}}var S,T;(S=L||(L={})).defaultConfig=Object.assign(Object.assign({},o.a.defaultConfig),{mode:"null",theme:"jupyter",smartIndent:!0,electricChars:!0,keyMap:"default",extraKeys:null,gutters:[],fixedGutter:!0,showCursorWhenSelecting:!1,coverGutterNextToScrollbar:!1,dragDrop:!0,lineSeparator:null,scrollbarStyle:"native",lineWiseCopyCut:!0,scrollPastEnd:!1,styleActiveLine:!1,styleSelectedText:!0,selectionPointer:!1,rulers:[],foldGutter:!1,handlePaste:!0}),S.addCommand=function(e,t){h.a.commands[e]=t},function(e){function t(e,t){return e.line===t.line&&e.ch===t.ch}function n(e){const t={"CodeMirror-linenumbers":"lineNumbers","CodeMirror-foldgutter":"codeFolding"};return Object.keys(t).filter(n=>e[t[n]])}e.createEditor=function(e,t){const{autoClosingBrackets:n,fontFamily:r,fontSize:i,insertSpaces:o,lineHeight:a,lineWrap:s,wordWrapColumn:l,tabSize:c,readOnly:u}=t,d=E(t,["autoClosingBrackets","fontFamily","fontSize","insertSpaces","lineHeight","lineWrap","wordWrapColumn","tabSize","readOnly"]),p=Object.assign({autoCloseBrackets:!!n&&{},indentUnit:c,indentWithTabs:!o,lineWrapping:"off"!==s,readOnly:u},d);return h()(t=>{if(r&&(t.style.fontFamily=r),i&&(t.style.fontSize=i+"px"),a&&(t.style.lineHeight=a.toString()),u&&t.classList.add("jp-mod-readOnly"),"wordWrapColumn"===s){t.querySelector(".CodeMirror-lines").style.width=l+"ch"}if("bounded"===s){t.querySelector(".CodeMirror-lines").style.maxWidth=l+"ch"}e.appendChild(t)},p)},e.indentMoreOrinsertTab=function(e){const n=e.getDoc(),r=n.getCursor("from");if(!t(r,n.getCursor("to")))return void h.a.commands.indentMore(e);const i=n.getLine(r.line).slice(0,r.ch);/^\s*$/.test(i)?h.a.commands.indentMore(e):e.getOption("indentWithTabs")?h.a.commands.insertTab(e):h.a.commands.insertSoftTab(e)},e.delSpaceToPrevTabStop=function(e){var n;const r=e.getDoc(),i=null!==(n=e.getOption("indentUnit"))&&void 0!==n?n:2,o=r.listSelections();for(let n=o.length-1;n>=0;n--){const a=o[n].head,s=o[n].anchor;if(!t(a,s))r.replaceRange("",s,a);else{if(null!==r.getLine(a.line).substring(0,a.ch).match(/^\ +$/)){const e=(Math.ceil(a.ch/i)-1)*i,t=h.a.Pos(a.line,e);r.replaceRange("",t,a)}else{const t=e.findPosH(a,-1,"char",!1);r.replaceRange("",t,a)}}}},e.posEq=t,e.setOption=function(e,t,r,i){const o=e.getWrapperElement();switch(t){case"cursorBlinkRate":e.setOption(t,r);break;case"lineWrap":{const t="off"!==r,n=o.querySelector(".CodeMirror-lines"),a="bounded"===r?i.wordWrapColumn+"ch":null,s="wordWrapColumn"===r?i.wordWrapColumn+"ch":null;n.style.setProperty("max-width",a),n.style.setProperty("width",s),e.setOption("lineWrapping",t);break}case"wordWrapColumn":{const{lineWrap:e}=i;if("wordWrapColumn"===e||"bounded"===e){const t="wordWrapColumn"===e?"width":"maxWidth";o.querySelector(".CodeMirror-lines").style[t]=r+"ch"}break}case"tabSize":e.setOption("indentUnit",r);break;case"insertSpaces":e.setOption("indentWithTabs",!r);break;case"autoClosingBrackets":e.setOption("autoCloseBrackets",r);break;case"rulers":{const t=r;e.setOption("rulers",t.map(e=>({column:e,className:"jp-CodeMirror-ruler"})));break}case"readOnly":o.classList.toggle("jp-mod-readOnly",r),e.setOption(t,r);break;case"fontFamily":o.style.fontFamily=r;break;case"fontSize":o.style.setProperty("font-size",r?r+"px":null);break;case"lineHeight":o.style.lineHeight=r?r.toString():null;break;case"gutters":e.setOption(t,n(i));break;case"lineNumbers":e.setOption(t,r),e.setOption("gutters",n(i));break;case"codeFolding":e.setOption("foldGutter",r),e.setOption("gutters",n(i));break;case"showTrailingSpace":default:e.setOption(t,r)}}}(T||(T={})),L.addCommand("delSpaceToPrevTabStop",T.delSpaceToPrevTabStop),L.addCommand("indentMoreOrinsertTab",T.indentMoreOrinsertTab);var O=n(59),I=n(0),k=n.n(I),D=n(30);const N={display:"flex",alignItems:"center"},j={flexDirection:"row"};var P=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};const z=Object(D.style)(N,j);function R(e){const{spacing:t,children:n,className:r}=e,i=P(e,["spacing","children","className"]),o=I.Children.count(n);return I.createElement("div",Object.assign({className:Object(D.classes)(z,r)},i),I.Children.map(n,(e,n)=>0===n?I.createElement("div",{style:{marginRight:t+"px"}},e):n===o-1?I.createElement("div",{style:{marginLeft:t+"px"}},e):I.createElement("div",{style:{margin:`0px ${t}px`}},e)))}var B=n(401),H=n(3),F="var(--jp-layout-color3)",Y="var(--jp-brand-color1)",V="var(--jp-layout-color2)",U="var(--jp-statusbar-height)",W="var(--jp-ui-font-color1)",G="white",q="2px",K="6px",X="10px",J="nowrap",Q="ellipsis";const Z={fontSize:"var(--jp-ui-font-size1)",fontFamily:"var(--jp-ui-font-family)"},$=Object(D.style)(Z,{lineHeight:"24px",color:W}),ee={paddingLeft:K,paddingRight:K},te={$nest:{"&:hover":{backgroundColor:F}}},ne={backgroundColor:Y,$nest:{["."+$]:{color:G}}},re=(Object(D.style)({background:V,minHeight:U,justifyContent:"space-between",paddingLeft:X,paddingRight:X},N),Object(D.style)(N),Object(D.style)(j),Object(D.style)({flexDirection:"row-reverse"}),Object(D.style)({maxHeight:U,marginLeft:q,marginRight:q,height:U,whiteSpace:J,textOverflow:Q,color:W},ee),Object(D.style)(ne)),ie=Object(D.style)(te),oe=Object(D.style)({boxShadow:"0px 4px 4px rgba(0, 0, 0, 0.25)"});function ae(e){const t=new se(e);return t.launch(),t}class se extends H.Widget{constructor(e){super(),this._body=e.body,this._body.addClass(oe),this._anchor=e.anchor,this._align=e.align;(this.layout=new H.PanelLayout).addWidget(e.body),this._body.node.addEventListener("resize",()=>{this.update()})}launch(){this._setGeometry(),H.Widget.attach(this,document.body),this.update(),this._anchor.addClass(re),this._anchor.removeClass(ie)}onUpdateRequest(e){this._setGeometry(),super.onUpdateRequest(e)}onAfterAttach(e){document.addEventListener("click",this,!1),this.node.addEventListener("keydown",this,!1),window.addEventListener("resize",this,!1)}onAfterDetach(e){document.removeEventListener("click",this,!1),this.node.removeEventListener("keydown",this,!1),window.removeEventListener("resize",this,!1)}onResize(){this.update()}dispose(){super.dispose(),this._anchor.removeClass(re),this._anchor.addClass(ie)}handleEvent(e){switch(e.type){case"keydown":this._evtKeydown(e);break;case"click":this._evtClick(e);break;case"resize":this.onResize()}}_evtClick(e){!e.target||this._body.node.contains(e.target)||this._anchor.node.contains(e.target)||this.dispose()}_evtKeydown(e){switch(e.keyCode){case 27:e.stopPropagation(),e.preventDefault(),this.dispose()}}_setGeometry(){let e=0;const t=this._anchor.node.getBoundingClientRect(),n=this._body.node.getBoundingClientRect();"right"===this._align&&(e=-(n.width-t.width));const r=window.getComputedStyle(this._body.node);B.a.setGeometry({anchor:t,host:document.body,maxHeight:500,minHeight:20,node:this._body.node,offset:{horizontal:e},privilege:"forceAbove",style:r})}}Object(D.style)({background:"black",height:"10px",width:"100px",border:"1px solid black",borderRadius:"3px",marginLeft:"4px",overflow:"hidden"}),Object(D.style)({background:"var(--jp-brand-color2)",height:"10px"});var le=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};function ce(e){const{title:t,source:n,className:r}=e,i=le(e,["title","source","className"]);return I.createElement("span",Object.assign({className:Object(D.classes)($,r),title:t},i),n)}function ue(e){const t=(e.translator||r.b).load("jupyterlab");let n="";return e.status&&(n=" | "+e.status),k.a.createElement(ce,{onClick:e.handleClick,source:`${e.kernelName}${n}`,title:t.__("Change kernel for %1",e.activityName)})}class de extends O.d{constructor(e,t){super(new de.Model(t)),this.translator=t||r.b,this._handleClick=e.onClick,this.addClass(ie)}render(){return null===this.model?null:k.a.createElement(ue,{status:this.model.status,kernelName:this.model.kernelName,activityName:this.model.activityName,handleClick:this._handleClick,translator:this.translator})}}!function(e){class t extends O.c{constructor(e){super(),this._onKernelStatusChanged=()=>{var e;this._kernelStatus=null===(e=this._sessionContext)||void 0===e?void 0:e.kernelDisplayStatus,this.stateChanged.emit(void 0)},this._onKernelChanged=(e,t)=>{var n;const r=this._getAllState();this._kernelStatus=null===(n=this._sessionContext)||void 0===n?void 0:n.kernelDisplayStatus,this._kernelName=e.kernelDisplayName,this._triggerChange(r,this._getAllState())},this._activityName="activity",this._kernelStatus="",this._sessionContext=null,e=e||r.b,this._trans=e.load("jupyterlab"),this._kernelName=this._trans.__("No Kernel!"),this._statusNames={unknown:this._trans.__("Unknown"),starting:this._trans.__("Starting"),idle:this._trans.__("Idle"),busy:this._trans.__("Busy"),terminating:this._trans.__("Terminating"),restarting:this._trans.__("Restarting"),autorestarting:this._trans.__("Autorestarting"),dead:this._trans.__("Dead"),connected:this._trans.__("Connected"),connecting:this._trans.__("Connecting"),disconnected:this._trans.__("Disconnected"),initializing:this._trans.__("Initializing"),"":""}}get kernelName(){return this._kernelName}get status(){return this._kernelStatus?this._statusNames[this._kernelStatus]:void 0}get activityName(){return this._activityName}set activityName(e){this._activityName!==e&&(this._activityName=e,this.stateChanged.emit(void 0))}get sessionContext(){return this._sessionContext}set sessionContext(e){var t,n,r;null===(t=this._sessionContext)||void 0===t||t.statusChanged.disconnect(this._onKernelStatusChanged),null===(n=this._sessionContext)||void 0===n||n.kernelChanged.disconnect(this._onKernelChanged);const i=this._getAllState();this._sessionContext=e,this._kernelStatus=null==e?void 0:e.kernelDisplayStatus,this._kernelName=null!==(r=null==e?void 0:e.kernelDisplayName)&&void 0!==r?r:this._trans.__("No Kernel"),null==e||e.statusChanged.connect(this._onKernelStatusChanged,this),null==e||e.connectionStatusChanged.connect(this._onKernelStatusChanged,this),null==e||e.kernelChanged.connect(this._onKernelChanged,this),this._triggerChange(i,this._getAllState())}_getAllState(){return[this._kernelName,this._kernelStatus,this._activityName]}_triggerChange(e,t){s.JSONExt.deepEqual(e,t)&&this.stateChanged.emit(void 0)}}e.Model=t}(de||(de={}));var he=n(54);Object(D.style)({boxShadow:"0px 4px 4px rgba(0, 0, 0, 0.25)"});const pe=Object(D.style)({padding:"4px 12px",backgroundColor:"var(--jp-layout-color2)",boxShadow:"var(--jp-toolbar-box-shadow)",zIndex:2,fontSize:"var(--jp-ui-font-size1)"}),fe=Object(D.style)({fontSize:"var(--jp-ui-font-size0)",lineHeight:"var(--jp-ui-font-size1)",marginTop:"4px",color:"var(--jp-ui-font-color0)"}),me={border:"none",borderRadius:"0px",position:"absolute",backgroundSize:"16px",backgroundRepeat:"no-repeat",backgroundPosition:"center",outline:"none",top:"0px",right:"0px"},ge=Object(D.style)(me,{top:"4px",right:"8px",height:"24px",padding:"0px 12px",width:"12px"}),ve=Object(D.style)(me,{backgroundColor:"var(--jp-brand-color1)",height:"100%",width:"100%",boxSizing:"border-box",padding:"4px 6px"}),ye=Object(D.style)(me,{backgroundColor:"transparent",height:"100%",width:"100%",boxSizing:"border-box"}),_e=Object(D.style)({overflow:"hidden",padding:"0px 8px",border:"1px solid var(--jp-border-color0)",backgroundColor:"var(--jp-input-active-background)",height:"22px"}),be=Object(D.style)({border:"var(--jp-border-width) solid var(--md-blue-500)",boxShadow:"inset 0 0 4px var(--md-blue-300)"}),Me=Object(D.style)({background:"transparent",width:"200px",height:"100%",border:"none",outline:"none",color:"var(--jp-ui-font-color0)",lineHeight:"28px"});class we extends k.a.Component{constructor(e){super(e),this._handleChange=e=>{this.setState({value:e.currentTarget.value})},this._handleSubmit=e=>{e.preventDefault();const t=parseInt(this._textInput.value,10);return!isNaN(t)&&isFinite(t)&&1<=t&&t<=this.props.maxLine&&this.props.handleSubmit(t),!1},this._handleFocus=()=>{this.setState({hasFocus:!0})},this._handleBlur=()=>{this.setState({hasFocus:!1})},this._textInput=null,this.translator=e.translator||r.b,this._trans=this.translator.load("jupyterlab"),this.state={value:"",hasFocus:!1}}componentDidMount(){this._textInput.focus()}render(){return k.a.createElement("div",{className:pe},k.a.createElement("form",{name:"lineColumnForm",onSubmit:this._handleSubmit,noValidate:!0},k.a.createElement("div",{className:Object(D.classes)(_e,"lm-lineForm-wrapper",this.state.hasFocus?be:void 0)},k.a.createElement("input",{type:"text",className:Me,onChange:this._handleChange,onFocus:this._handleFocus,onBlur:this._handleBlur,value:this.state.value,ref:e=>{this._textInput=e}}),k.a.createElement("div",{className:ge},k.a.createElement(he.p.react,{className:ve,elementPosition:"center"}),k.a.createElement("input",{type:"submit",className:ye,value:""}))),k.a.createElement("label",{className:fe},this._trans.__("Go to line number between 1 and %1",this.props.maxLine))))}}function Ae(e){const t=(e.translator||r.b).load("jupyterlab");return k.a.createElement(ce,{onClick:e.handleClick,source:t.__("Ln %1, Col %2",e.line,e.column),title:t.__("Go to line number…")})}class Ce extends O.d{constructor(e){super(new Ce.Model),this._popup=null,this.addClass(ie),this.translator=e||r.b}render(){return null===this.model?null:k.a.createElement(Ae,{line:this.model.line,column:this.model.column,translator:this.translator,handleClick:()=>this._handleClick()})}_handleClick(){this._popup&&this._popup.dispose();const e=O.a.create(k.a.createElement(we,{handleSubmit:e=>this._handleSubmit(e),currentLine:this.model.line,maxLine:this.model.editor.lineCount,translator:this.translator}));this._popup=ae({body:e,anchor:this,align:"right"})}_handleSubmit(e){this.model.editor.setCursorPosition({line:e-1,column:0}),this._popup.dispose(),this.model.editor.focus()}}!function(e){class t extends O.c{constructor(){super(...arguments),this._onSelectionChanged=()=>{const e=this._getAllState(),t=this.editor.getCursorPosition();this._line=t.line+1,this._column=t.column+1,this._triggerChange(e,this._getAllState())},this._line=1,this._column=1,this._editor=null}get editor(){return this._editor}set editor(e){const t=this._editor;t&&t.model.selections.changed.disconnect(this._onSelectionChanged);const n=this._getAllState();if(this._editor=e,this._editor){this._editor.model.selections.changed.connect(this._onSelectionChanged);const e=this._editor.getCursorPosition();this._column=e.column+1,this._line=e.line+1}else this._column=1,this._line=1;this._triggerChange(n,this._getAllState())}get line(){return this._line}get column(){return this._column}_getAllState(){return[this._line,this._column]}_triggerChange(e,t){e[0]===t[0]&&e[1]===t[1]||this.stateChanged.emit(void 0)}}e.Model=t}(Ce||(Ce={}));function xe(e){return k.a.createElement(R,{spacing:4,onClick:e.handleClick},k.a.createElement(R,{spacing:4},k.a.createElement(ce,{source:e.terminals}),k.a.createElement(he.A.react,{left:"1px",top:"3px",stylesheet:"statusBar"})),k.a.createElement(R,{spacing:4},k.a.createElement(ce,{source:e.sessions}),k.a.createElement(he.o.react,{top:"2px",stylesheet:"statusBar"})))}class Ee extends O.d{constructor(e){super(new Ee.Model),this._serviceManager=e.serviceManager,this._handleClick=e.onClick,this.translator=e.translator||r.b,this._trans=this.translator.load("jupyterload"),this._serviceManager.sessions.runningChanged.connect(this._onSessionsRunningChanged,this),this._serviceManager.terminals.runningChanged.connect(this._onTerminalsRunningChanged,this),this.addClass(ie)}render(){return this.model?(this.title.caption=this._trans.__("%1 Terminals, %2 Kernel sessions",this.model.terminals,this.model.sessions),k.a.createElement(xe,{sessions:this.model.sessions,terminals:this.model.terminals,handleClick:this._handleClick})):null}dispose(){super.dispose(),this._serviceManager.sessions.runningChanged.disconnect(this._onSessionsRunningChanged,this),this._serviceManager.terminals.runningChanged.disconnect(this._onTerminalsRunningChanged,this)}_onSessionsRunningChanged(e,t){this.model.sessions=t.length}_onTerminalsRunningChanged(e,t){this.model.terminals=t.length}}!function(e){class t extends O.c{constructor(){super(...arguments),this._terminals=0,this._sessions=0}get sessions(){return this._sessions}set sessions(e){const t=this._sessions;this._sessions=e,t!==this._sessions&&this.stateChanged.emit(void 0)}get terminals(){return this._terminals}set terminals(e){const t=this._terminals;this._terminals=e,t!==this._terminals&&this.stateChanged.emit(void 0)}}e.Model=t}(Ee||(Ee={}));H.Widget;var Le;!function(e){e.statusItemDefaults={align:"left",rank:0,isActive:()=>!0,activeStateChanged:void 0}}(Le||(Le={}));new s.Token("@jupyterlab/statusbar:IStatusBar");function Se(e){return k.a.createElement(ce,{source:e.mode,onClick:e.handleClick})}class Te extends O.d{constructor(e){super(new Te.Model),this._handleClick=()=>{const e=new H.Menu({commands:this._commands});this._popup&&this._popup.dispose(),C.getModeInfo().sort((e,t)=>{const n=e.name||"",r=t.name||"";return n.localeCompare(r)}).forEach(t=>{if(0===t.mode.indexOf("brainf"))return;const n={insertSpaces:!0,name:t.name};e.addItem({command:"codemirror:change-mode",args:n})}),this._popup=ae({body:e,anchor:this,align:"left"})},this._popup=null,this._commands=e.commands,this.translator=e.translator||r.b;const t=this.translator.load("jupyterlab");this.addClass(ie),this.title.caption=t.__("Change text editor syntax highlighting")}render(){return this.model?k.a.createElement(Se,{mode:this.model.mode,handleClick:this._handleClick}):null}}!function(e){class t extends O.c{constructor(){super(...arguments),this._onMIMETypeChange=(e,t)=>{const n=this._mode,r=C.findByMIME(t.newValue);this._mode=r.name||r.mode,this._triggerChange(n,this._mode)},this._mode="",this._editor=null}get mode(){return this._mode}get editor(){return this._editor}set editor(e){const t=this._editor;null!==t&&t.model.mimeTypeChanged.disconnect(this._onMIMETypeChange);const n=this._mode;if(this._editor=e,null===this._editor)this._mode="";else{const e=C.findByMIME(this._editor.model.mimeType);this._mode=e.name||e.mode,this._editor.model.mimeTypeChanged.connect(this._onMIMETypeChange)}this._triggerChange(n,this._mode)}_triggerChange(e,t){e!==t&&this.stateChanged.emit(void 0)}}e.Model=t}(Te||(Te={}));new s.Token("@jupyterlab/codemirror:ICodeMirror"),new class{constructor(e={},t){this.newInlineEditor=e=>(e.host.dataset.type="inline",new L(Object.assign(Object.assign({},e),{config:Object.assign(Object.assign({},this.inlineCodeMirrorConfig),e.config||{}),translator:this.translator}))),this.newDocumentEditor=e=>(e.host.dataset.type="document",new L(Object.assign(Object.assign({},e),{config:Object.assign(Object.assign({},this.documentCodeMirrorConfig),e.config||{}),translator:this.translator}))),this.translator=t||r.b,this.inlineCodeMirrorConfig=Object.assign(Object.assign(Object.assign({},L.defaultConfig),{extraKeys:{"Cmd-Right":"goLineRight",End:"goLineRight","Cmd-Left":"goLineLeft",Tab:"indentMoreOrinsertTab","Shift-Tab":"indentLess","Cmd-/":e=>e.toggleComment({indent:!0}),"Ctrl-/":e=>e.toggleComment({indent:!0}),"Ctrl-G":"find","Cmd-G":"find"}}),e),this.documentCodeMirrorConfig=Object.assign(Object.assign(Object.assign({},L.defaultConfig),{extraKeys:{Tab:"indentMoreOrinsertTab","Shift-Tab":"indentLess","Cmd-/":e=>e.toggleComment({indent:!0}),"Ctrl-/":e=>e.toggleComment({indent:!0}),"Shift-Enter":()=>{}},lineNumbers:!0,scrollPastEnd:!0}),e)}},new class{getMimeTypeByLanguage(e){const t=e.file_extension||"";return C.findBest(e.codemirror_mode||{mimetype:e.mimetype,name:e.name,ext:[t.split(".").slice(-1)[0]]}).mime}getMimeTypeByFilePath(e){const t=A.PathExt.extname(e);if(".ipy"===t)return"text/x-python";if(".md"===t)return"text/x-ipythongfm";return(C.findByFileName(e)||C.findBest("")).mime}}},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.Doctype=t.CDATA=t.Tag=t.Style=t.Script=t.Comment=t.Directive=t.Text=t.Root=t.isTag=t.ElementType=void 0,function(e){e.Root="root",e.Text="text",e.Directive="directive",e.Comment="comment",e.Script="script",e.Style="style",e.Tag="tag",e.CDATA="cdata",e.Doctype="doctype"}(r=t.ElementType||(t.ElementType={})),t.isTag=function(e){return e.type===r.Tag||e.type===r.Script||e.type===r.Style},t.Root=r.Root,t.Text=r.Text,t.Directive=r.Directive,t.Comment=r.Comment,t.Script=r.Script,t.Style=r.Style,t.Tag=r.Tag,t.CDATA=r.CDATA,t.Doctype=r.Doctype},function(e,t,n){"use strict";let r,i,o=n(83);class a extends o{constructor(e){super(e),this.type="root",this.nodes||(this.nodes=[])}removeChild(e,t){let n=this.index(e);return!t&&0===n&&this.nodes.length>1&&(this.nodes[1].raws.before=this.nodes[n].raws.before),super.removeChild(e)}normalize(e,t,n){let r=super.normalize(e);if(t)if("prepend"===n)this.nodes.length>1?t.raws.before=this.nodes[1].raws.before:delete t.raws.before;else if(this.first!==t)for(let e of r)e.raws.before=t.raws.before;return r}toResult(e={}){return new r(new i,this,e).stringify()}}a.registerLazyResult=e=>{r=e},a.registerProcessor=e=>{i=e},e.exports=a,a.default=a},function(e,t,n){"use strict";var r=n(391),i="function"==typeof Symbol&&"symbol"==typeof Symbol("foo"),o=Object.prototype.toString,a=Array.prototype.concat,s=Object.defineProperty,l=s&&function(){var e={};try{for(var t in s(e,"x",{enumerable:!1,value:e}),e)return!1;return e.x===e}catch(e){return!1}}(),c=function(e,t,n,r){var i;(!(t in e)||"function"==typeof(i=r)&&"[object Function]"===o.call(i)&&r())&&(l?s(e,t,{configurable:!0,enumerable:!1,value:n,writable:!0}):e[t]=n)},u=function(e,t){var n=arguments.length>2?arguments[2]:{},o=r(t);i&&(o=a.call(o,Object.getOwnPropertySymbols(t)));for(var s=0;s<o.length;s+=1)c(e,o[s],t[o[s]],n[o[s]])};u.supportsDescriptors=!!l,e.exports=u},function(e,t,n){var r=n(178),i=n(761),o=n(762),a=r?r.toStringTag:void 0;e.exports=function(e){return null==e?void 0===e?"[object Undefined]":"[object Null]":a&&a in Object(e)?i(e):o(e)}},function(e,t){e.exports=function(e){return null!=e&&"object"==typeof e}},function(e,t,n){var r,i,o;!function(a){"use strict";i=[n(41)],void 0===(o="function"==typeof(r=function(e){return e.ui=e.ui||{},e.ui.version="1.13.1"})?r.apply(t,i):r)||(e.exports=o)}()},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.PrioritizedList=void 0;var r=function(){function e(){this.items=[],this.items=[]}return e.prototype[Symbol.iterator]=function(){var e=0,t=this.items;return{next:function(){return{value:t[e++],done:e>t.length}}}},e.prototype.add=function(t,n){void 0===n&&(n=e.DEFAULTPRIORITY);var r=this.items.length;do{r--}while(r>=0&&n<this.items[r].priority);return this.items.splice(r+1,0,{item:t,priority:n}),t},e.prototype.remove=function(e){var t=this.items.length;do{t--}while(t>=0&&this.items[t].item!==e);t>=0&&this.items.splice(t,1)},e.DEFAULTPRIORITY=5,e}();t.PrioritizedList=r},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.newState=t.STATE=t.AbstractMathItem=t.protoItem=void 0,t.protoItem=function(e,t,n,r,i,o,a){return void 0===a&&(a=null),{open:e,math:t,close:n,n:r,start:{n:i},end:{n:o},display:a}};var r=function(){function e(e,n,r,i,o){void 0===r&&(r=!0),void 0===i&&(i={i:0,n:0,delim:""}),void 0===o&&(o={i:0,n:0,delim:""}),this.root=null,this.typesetRoot=null,this.metrics={},this.inputData={},this.outputData={},this._state=t.STATE.UNPROCESSED,this.math=e,this.inputJax=n,this.display=r,this.start=i,this.end=o,this.root=null,this.typesetRoot=null,this.metrics={},this.inputData={},this.outputData={}}return Object.defineProperty(e.prototype,"isEscaped",{get:function(){return null===this.display},enumerable:!1,configurable:!0}),e.prototype.render=function(e){e.renderActions.renderMath(this,e)},e.prototype.rerender=function(e,n){void 0===n&&(n=t.STATE.RERENDER),this.state()>=n&&this.state(n-1),e.renderActions.renderMath(this,e,n)},e.prototype.convert=function(e,n){void 0===n&&(n=t.STATE.LAST),e.renderActions.renderConvert(this,e,n)},e.prototype.compile=function(e){this.state()<t.STATE.COMPILED&&(this.root=this.inputJax.compile(this,e),this.state(t.STATE.COMPILED))},e.prototype.typeset=function(e){this.state()<t.STATE.TYPESET&&(this.typesetRoot=e.outputJax[this.isEscaped?"escaped":"typeset"](this,e),this.state(t.STATE.TYPESET))},e.prototype.updateDocument=function(e){},e.prototype.removeFromDocument=function(e){void 0===e&&(e=!1)},e.prototype.setMetrics=function(e,t,n,r,i){this.metrics={em:e,ex:t,containerWidth:n,lineWidth:r,scale:i}},e.prototype.state=function(e,n){return void 0===e&&(e=null),void 0===n&&(n=!1),null!=e&&(e<t.STATE.INSERTED&&this._state>=t.STATE.INSERTED&&this.removeFromDocument(n),e<t.STATE.TYPESET&&this._state>=t.STATE.TYPESET&&(this.outputData={}),e<t.STATE.COMPILED&&this._state>=t.STATE.COMPILED&&(this.inputData={}),this._state=e),this._state},e.prototype.reset=function(e){void 0===e&&(e=!1),this.state(t.STATE.UNPROCESSED,e)},e}();t.AbstractMathItem=r,t.STATE={UNPROCESSED:0,FINDMATH:10,COMPILED:20,CONVERT:100,METRICS:110,RERENDER:125,TYPESET:150,INSERTED:200,LAST:1e4},t.newState=function(e,n){if(e in t.STATE)throw Error("State "+e+" already exists");t.STATE[e]=n}},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.Attributes=t.INHERIT=void 0,t.INHERIT="_inherit_";var i=function(){function e(e,t){this.global=t,this.defaults=Object.create(t),this.inherited=Object.create(this.defaults),this.attributes=Object.create(this.inherited),Object.assign(this.defaults,e)}return e.prototype.set=function(e,t){this.attributes[e]=t},e.prototype.setList=function(e){Object.assign(this.attributes,e)},e.prototype.get=function(e){var n=this.attributes[e];return n===t.INHERIT&&(n=this.global[e]),n},e.prototype.getExplicit=function(e){if(this.attributes.hasOwnProperty(e))return this.attributes[e]},e.prototype.getList=function(){for(var e,t,n=[],i=0;i<arguments.length;i++)n[i]=arguments[i];var o={};try{for(var a=r(n),s=a.next();!s.done;s=a.next()){var l=s.value;o[l]=this.get(l)}}catch(t){e={error:t}}finally{try{s&&!s.done&&(t=a.return)&&t.call(a)}finally{if(e)throw e.error}}return o},e.prototype.setInherited=function(e,t){this.inherited[e]=t},e.prototype.getInherited=function(e){return this.inherited[e]},e.prototype.getDefault=function(e){return this.defaults[e]},e.prototype.isSet=function(e){return this.attributes.hasOwnProperty(e)||this.inherited.hasOwnProperty(e)},e.prototype.hasDefault=function(e){return e in this.defaults},e.prototype.getExplicitNames=function(){return Object.keys(this.attributes)},e.prototype.getInheritedNames=function(){return Object.keys(this.inherited)},e.prototype.getDefaultNames=function(){return Object.keys(this.defaults)},e.prototype.getGlobalNames=function(){return Object.keys(this.global)},e.prototype.getAllAttributes=function(){return this.attributes},e.prototype.getAllInherited=function(){return this.inherited},e.prototype.getAllDefaults=function(){return this.defaults},e.prototype.getAllGlobals=function(){return this.global},e}();t.Attributes=i},function(e,t,n){"use strict";var r=this&&this.__assign||function(){return(r=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.FontData=t.NOSTRETCH=t.H=t.V=void 0;var s=n(47);t.V=1,t.H=2,t.NOSTRETCH={dir:0};var l=function(){function e(e){var t,n,l,c;void 0===e&&(e=null),this.variant={},this.delimiters={},this.cssFontMap={},this.remapChars={},this.skewIcFactor=.75;var u=this.constructor;this.options=s.userOptions(s.defaultOptions({},u.OPTIONS),e),this.params=r({},u.defaultParams),this.sizeVariants=o([],i(u.defaultSizeVariants)),this.stretchVariants=o([],i(u.defaultStretchVariants)),this.cssFontMap=r({},u.defaultCssFonts);try{for(var d=a(Object.keys(this.cssFontMap)),h=d.next();!h.done;h=d.next()){var p=h.value;"unknown"===this.cssFontMap[p][0]&&(this.cssFontMap[p][0]=this.options.unknownFamily)}}catch(e){t={error:e}}finally{try{h&&!h.done&&(n=d.return)&&n.call(d)}finally{if(t)throw t.error}}this.cssFamilyPrefix=u.defaultCssFamilyPrefix,this.createVariants(u.defaultVariants),this.defineDelimiters(u.defaultDelimiters);try{for(var f=a(Object.keys(u.defaultChars)),m=f.next();!m.done;m=f.next()){var g=m.value;this.defineChars(g,u.defaultChars[g])}}catch(e){l={error:e}}finally{try{m&&!m.done&&(c=f.return)&&c.call(f)}finally{if(l)throw l.error}}this.defineRemap("accent",u.defaultAccentMap),this.defineRemap("mo",u.defaultMoMap),this.defineRemap("mn",u.defaultMnMap)}return e.charOptions=function(e,t){var n=e[t];return 3===n.length&&(n[3]={}),n[3]},Object.defineProperty(e.prototype,"styles",{get:function(){return this._styles},set:function(e){this._styles=e},enumerable:!1,configurable:!0}),e.prototype.createVariant=function(e,t,n){void 0===t&&(t=null),void 0===n&&(n=null);var r={linked:[],chars:t?Object.create(this.variant[t].chars):{}};n&&this.variant[n]&&(Object.assign(r.chars,this.variant[n].chars),this.variant[n].linked.push(r.chars),r.chars=Object.create(r.chars)),this.remapSmpChars(r.chars,e),this.variant[e]=r},e.prototype.remapSmpChars=function(e,t){var n,r,o,s,l=this.constructor;if(l.VariantSmp[t]){var c=l.SmpRemap,u=[null,null,l.SmpRemapGreekU,l.SmpRemapGreekL];try{for(var d=a(l.SmpRanges),h=d.next();!h.done;h=d.next()){var p=i(h.value,3),f=p[0],m=p[1],g=p[2],v=l.VariantSmp[t][f];if(v){for(var y=m;y<=g;y++)if(930!==y){var _=v+y-m;e[y]=this.smpChar(c[_]||_)}if(u[f])try{for(var b=(o=void 0,a(Object.keys(u[f]).map((function(e){return parseInt(e)})))),M=b.next();!M.done;M=b.next()){e[y=M.value]=this.smpChar(v+u[f][y])}}catch(e){o={error:e}}finally{try{M&&!M.done&&(s=b.return)&&s.call(b)}finally{if(o)throw o.error}}}}}catch(e){n={error:e}}finally{try{h&&!h.done&&(r=d.return)&&r.call(d)}finally{if(n)throw n.error}}}"bold"===t&&(e[988]=this.smpChar(120778),e[989]=this.smpChar(120779))},e.prototype.smpChar=function(e){return[,,,{smp:e}]},e.prototype.createVariants=function(e){var t,n;try{for(var r=a(e),i=r.next();!i.done;i=r.next()){var o=i.value;this.createVariant(o[0],o[1],o[2])}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}},e.prototype.defineChars=function(e,t){var n,r,i=this.variant[e];Object.assign(i.chars,t);try{for(var o=a(i.linked),s=o.next();!s.done;s=o.next()){var l=s.value;Object.assign(l,t)}}catch(e){n={error:e}}finally{try{s&&!s.done&&(r=o.return)&&r.call(o)}finally{if(n)throw n.error}}},e.prototype.defineDelimiters=function(e){Object.assign(this.delimiters,e)},e.prototype.defineRemap=function(e,t){this.remapChars.hasOwnProperty(e)||(this.remapChars[e]={}),Object.assign(this.remapChars[e],t)},e.prototype.getDelimiter=function(e){return this.delimiters[e]},e.prototype.getSizeVariant=function(e,t){return this.delimiters[e].variants&&(t=this.delimiters[e].variants[t]),this.sizeVariants[t]},e.prototype.getStretchVariant=function(e,t){return this.stretchVariants[this.delimiters[e].stretchv?this.delimiters[e].stretchv[t]:0]},e.prototype.getChar=function(e,t){return this.variant[e].chars[t]},e.prototype.getVariant=function(e){return this.variant[e]},e.prototype.getCssFont=function(e){return this.cssFontMap[e]||["serif",!1,!1]},e.prototype.getFamily=function(e){return this.cssFamilyPrefix?this.cssFamilyPrefix+", "+e:e},e.prototype.getRemappedChar=function(e,t){return(this.remapChars[e]||{})[t]},e.OPTIONS={unknownFamily:"serif"},e.defaultVariants=[["normal"],["bold","normal"],["italic","normal"],["bold-italic","italic","bold"],["double-struck","bold"],["fraktur","normal"],["bold-fraktur","bold","fraktur"],["script","italic"],["bold-script","bold-italic","script"],["sans-serif","normal"],["bold-sans-serif","bold","sans-serif"],["sans-serif-italic","italic","sans-serif"],["sans-serif-bold-italic","bold-italic","bold-sans-serif"],["monospace","normal"]],e.defaultCssFonts={normal:["unknown",!1,!1],bold:["unknown",!1,!0],italic:["unknown",!0,!1],"bold-italic":["unknown",!0,!0],"double-struck":["unknown",!1,!0],fraktur:["unknown",!1,!1],"bold-fraktur":["unknown",!1,!0],script:["cursive",!1,!1],"bold-script":["cursive",!1,!0],"sans-serif":["sans-serif",!1,!1],"bold-sans-serif":["sans-serif",!1,!0],"sans-serif-italic":["sans-serif",!0,!1],"sans-serif-bold-italic":["sans-serif",!0,!0],monospace:["monospace",!1,!1]},e.defaultCssFamilyPrefix="",e.VariantSmp={bold:[119808,119834,120488,120514,120782],italic:[119860,119886,120546,120572],"bold-italic":[119912,119938,120604,120630],script:[119964,119990],"bold-script":[120016,120042],fraktur:[120068,120094],"double-struck":[120120,120146,,,120792],"bold-fraktur":[120172,120198],"sans-serif":[120224,120250,,,120802],"bold-sans-serif":[120276,120302,120662,120688,120812],"sans-serif-italic":[120328,120354],"sans-serif-bold-italic":[120380,120406,120720,120746],monospace:[120432,120458,,,120822]},e.SmpRanges=[[0,65,90],[1,97,122],[2,913,937],[3,945,969],[4,48,57]],e.SmpRemap={119893:8462,119965:8492,119968:8496,119969:8497,119971:8459,119972:8464,119975:8466,119976:8499,119981:8475,119994:8495,119996:8458,120004:8500,120070:8493,120075:8460,120076:8465,120085:8476,120093:8488,120122:8450,120127:8461,120133:8469,120135:8473,120136:8474,120137:8477,120145:8484},e.SmpRemapGreekU={8711:25,1012:17},e.SmpRemapGreekL={977:27,981:29,982:31,1008:28,1009:30,1013:26,8706:25},e.defaultAccentMap={768:"ˋ",769:"ˊ",770:"ˆ",771:"˜",772:"ˉ",774:"˘",775:"˙",776:"¨",778:"˚",780:"ˇ",8594:"⃗",8242:"'",8243:"''",8244:"'''",8245:"`",8246:"``",8247:"```",8279:"''''",8400:"↼",8401:"⇀",8406:"←",8417:"↔",8432:"*",8411:"...",8412:"....",8428:"⇁",8429:"↽",8430:"←",8431:"→"},e.defaultMoMap={45:"−"},e.defaultMnMap={45:"−"},e.defaultParams={x_height:.442,quad:1,num1:.676,num2:.394,num3:.444,denom1:.686,denom2:.345,sup1:.413,sup2:.363,sup3:.289,sub1:.15,sub2:.247,sup_drop:.386,sub_drop:.05,delim1:2.39,delim2:1,axis_height:.25,rule_thickness:.06,big_op_spacing1:.111,big_op_spacing2:.167,big_op_spacing3:.2,big_op_spacing4:.6,big_op_spacing5:.1,surd_height:.075,scriptspace:.05,nulldelimiterspace:.12,delimiterfactor:901,delimitershortfall:.3,min_rule_thickness:1.25,separation_factor:1.75,extra_ic:.033},e.defaultDelimiters={},e.defaultChars={},e.defaultSizeVariants=[],e.defaultStretchVariants=[],e}();t.FontData=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.NEW_OPS=t.AmsMethods=void 0;var r=n(37),i=n(39),o=n(50),a=n(49),s=n(31),l=n(96),c=n(57),u=n(23);t.AmsMethods={},t.AmsMethods.AmsEqnArray=function(e,t,n,i,o,a,s){var l=e.GetBrackets("\\begin{"+t.getName()+"}"),u=c.default.EqnArray(e,t,n,i,o,a,s);return r.default.setArrayAlign(u,l)},t.AmsMethods.AlignAt=function(e,n,i,o){var a,l,c=n.getName(),u="",d=[];if(o||(l=e.GetBrackets("\\begin{"+c+"}")),(a=e.GetArgument("\\begin{"+c+"}")).match(/[^0-9]/))throw new s.default("PositiveIntegerArg","Argument to %1 must me a positive integer","\\begin{"+c+"}");for(var h=parseInt(a,10);h>0;)u+="rl",d.push("0em 0em"),h--;var p=d.join(" ");if(o)return t.AmsMethods.EqnArray(e,n,i,o,u,p);var f=t.AmsMethods.EqnArray(e,n,i,o,u,p);return r.default.setArrayAlign(f,l)},t.AmsMethods.Multline=function(e,t,n){e.Push(t),r.default.checkEqnEnv(e);var i=e.itemFactory.create("multline",n,e.stack);return i.arraydef={displaystyle:!0,rowspacing:".5em",columnspacing:"100%",width:e.options.ams.multlineWidth,side:e.options.tagSide,minlabelspacing:e.options.tagIndent,framespacing:e.options.ams.multlineIndent+" 0",frame:"","data-width-includes-label":!0},i},t.AmsMethods.XalignAt=function(e,n,r,i){var o=e.GetArgument("\\begin{"+n.getName()+"}");if(o.match(/[^0-9]/))throw new s.default("PositiveIntegerArg","Argument to %1 must me a positive integer","\\begin{"+n.getName()+"}");var a=i?"crl":"rlc",l=i?"fit auto auto":"auto auto fit",c=t.AmsMethods.FlalignArray(e,n,r,i,!1,a,l,!0);return c.setProperty("xalignat",2*parseInt(o)),c},t.AmsMethods.FlalignArray=function(e,t,n,i,o,a,s,l){void 0===l&&(l=!1),e.Push(t),r.default.checkEqnEnv(e),a=a.split("").join(" ").replace(/r/g,"right").replace(/l/g,"left").replace(/c/g,"center");var c=e.itemFactory.create("flalign",t.getName(),n,i,o,e.stack);return c.arraydef={width:"100%",displaystyle:!0,columnalign:a,columnspacing:"0em",columnwidth:s,rowspacing:"3pt",side:e.options.tagSide,minlabelspacing:l?"0":e.options.tagIndent,"data-width-includes-label":!0},c.setProperty("zeroWidthLabel",l),c},t.NEW_OPS="ams-declare-ops",t.AmsMethods.HandleDeclareOp=function(e,n){var i=e.GetStar()?"":"\\nolimits\\SkipLimits",o=r.default.trimSpaces(e.GetArgument(n));"\\"===o.charAt(0)&&(o=o.substr(1));var a=e.GetArgument(n);a.match(/\\text/)||(a=a.replace(/\*/g,"\\text{*}").replace(/-/g,"\\text{-}")),e.configuration.handlers.retrieve(t.NEW_OPS).add(o,new l.Macro(o,t.AmsMethods.Macro,["\\mathop{\\rm "+a+"}"+i]))},t.AmsMethods.HandleOperatorName=function(e,t){var n=e.GetStar()?"":"\\nolimits\\SkipLimits",i=r.default.trimSpaces(e.GetArgument(t));i.match(/\\text/)||(i=i.replace(/\*/g,"\\text{*}").replace(/-/g,"\\text{-}")),e.string="\\mathop{\\rm "+i+"}"+n+" "+e.string.slice(e.i),e.i=0},t.AmsMethods.SkipLimits=function(e,t){var n=e.GetNext(),r=e.i;"\\"===n&&++e.i&&"limits"!==e.GetCS()&&(e.i=r)},t.AmsMethods.MultiIntegral=function(e,t,n){var r=e.GetNext();if("\\"===r){var i=e.i;r=e.GetArgument(t),e.i=i,"\\limits"===r&&(n="\\idotsint"===t?"\\!\\!\\mathop{\\,\\,"+n+"}":"\\!\\!\\!\\mathop{\\,\\,\\,"+n+"}")}e.string=n+" "+e.string.slice(e.i),e.i=0},t.AmsMethods.xArrow=function(e,t,n,o,s){var l={width:"+"+r.default.Em((o+s)/18),lspace:r.default.Em(o/18)},c=e.GetBrackets(t),d=e.ParseArg(t),h=e.create("node","mspace",[],{depth:".25em"}),p=e.create("token","mo",{stretchy:!0,texClass:u.TEXCLASS.REL},String.fromCodePoint(n));p=e.create("node","mstyle",[p],{scriptlevel:0});var f=e.create("node","munderover",[p]),m=e.create("node","mpadded",[d,h],l);if(i.default.setAttribute(m,"voffset","-.2em"),i.default.setAttribute(m,"height","-.2em"),i.default.setChild(f,f.over,m),c){var g=new a.default(c,e.stack.env,e.configuration).mml(),v=e.create("node","mspace",[],{height:".75em"});m=e.create("node","mpadded",[g,v],l),i.default.setAttribute(m,"voffset",".15em"),i.default.setAttribute(m,"depth","-.15em"),i.default.setChild(f,f.under,m)}i.default.setProperty(f,"subsupOK",!0),e.Push(f)},t.AmsMethods.HandleShove=function(e,t,n){var r=e.stack.Top();if("multline"!==r.kind)throw new s.default("CommandOnlyAllowedInEnv","%1 only allowed in %2 environment",e.currentCS,"multline");if(r.Size())throw new s.default("CommandAtTheBeginingOfLine","%1 must come at the beginning of the line",e.currentCS);r.setProperty("shove",n)},t.AmsMethods.CFrac=function(e,t){var n=r.default.trimSpaces(e.GetBrackets(t,"")),l=e.GetArgument(t),c=e.GetArgument(t),u={l:o.TexConstant.Align.LEFT,r:o.TexConstant.Align.RIGHT,"":""},d=new a.default("\\strut\\textstyle{"+l+"}",e.stack.env,e.configuration).mml(),h=new a.default("\\strut\\textstyle{"+c+"}",e.stack.env,e.configuration).mml(),p=e.create("node","mfrac",[d,h]);if(null==(n=u[n]))throw new s.default("IllegalAlign","Illegal alignment specified in %1",e.currentCS);n&&i.default.setProperties(p,{numalign:n,denomalign:n}),e.Push(p)},t.AmsMethods.Genfrac=function(e,t,n,o,a,l){null==n&&(n=e.GetDelimiterArg(t)),null==o&&(o=e.GetDelimiterArg(t)),null==a&&(a=e.GetArgument(t)),null==l&&(l=r.default.trimSpaces(e.GetArgument(t)));var c=e.ParseArg(t),u=e.ParseArg(t),d=e.create("node","mfrac",[c,u]);if(""!==a&&i.default.setAttribute(d,"linethickness",a),(n||o)&&(i.default.setProperty(d,"withDelims",!0),d=r.default.fixedFence(e.configuration,n,d,o)),""!==l){var h=parseInt(l,10),p=["D","T","S","SS"][h];if(null==p)throw new s.default("BadMathStyleFor","Bad math style for %1",e.currentCS);d=e.create("node","mstyle",[d]),"D"===p?i.default.setProperties(d,{displaystyle:!0,scriptlevel:0}):i.default.setProperties(d,{displaystyle:!1,scriptlevel:h-1})}e.Push(d)},t.AmsMethods.HandleTag=function(e,t){if(!e.tags.currentTag.taggable&&e.tags.env)throw new s.default("CommandNotAllowedInEnv","%1 not allowed in %2 environment",e.currentCS,e.tags.env);if(e.tags.currentTag.tag)throw new s.default("MultipleCommand","Multiple %1",e.currentCS);var n=e.GetStar(),i=r.default.trimSpaces(e.GetArgument(t));e.tags.tag(i,n)},t.AmsMethods.HandleNoTag=c.default.HandleNoTag,t.AmsMethods.HandleRef=c.default.HandleRef,t.AmsMethods.Macro=c.default.Macro,t.AmsMethods.Accent=c.default.Accent,t.AmsMethods.Tilde=c.default.Tilde,t.AmsMethods.Array=c.default.Array,t.AmsMethods.Spacer=c.default.Spacer,t.AmsMethods.NamedOp=c.default.NamedOp,t.AmsMethods.EqnArray=c.default.EqnArray,t.AmsMethods.Equation=c.default.Equation},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r={CENTER:"center",LEFT:"left",RIGHT:"right"}},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r,i=n(2),o=n(6),a=n(21);!function(e){e.hitTestNodes=function(e,t,n){return i.ArrayExt.findFirstIndex(e,e=>a.ElementExt.hitTest(e,t,n))},e.findElement=function(e,t){return e.querySelector("."+t)},e.findElements=function(e,t){return e.getElementsByClassName(t)},e.createDomID=function(){return"id-"+o.UUID.uuid4()}}(r||(r={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return d})),n.d(t,"b",(function(){return h}));var r=n(12),i=n(22),o=n(2),a=n(6),s=n(4),l=n(3),c=n(0),u=n(32);class d{constructor(e){var t,n,r,o;this._path="",this._name="",this._type="",this._prevKernelName="",this._isDisposed=!1,this._disposed=new s.Signal(this),this._session=null,this._ready=new a.PromiseDelegate,this._initializing=!1,this._initStarted=new a.PromiseDelegate,this._initPromise=new a.PromiseDelegate,this._isReady=!1,this._isTerminating=!1,this._isRestarting=!1,this._kernelChanged=new s.Signal(this),this._sessionChanged=new s.Signal(this),this._statusChanged=new s.Signal(this),this._connectionStatusChanged=new s.Signal(this),this._pendingInput=!1,this._iopubMessage=new s.Signal(this),this._unhandledMessage=new s.Signal(this),this._propertyChanged=new s.Signal(this),this._dialog=null,this._busyDisposable=null,this._pendingKernelName="",this._pendingSessionRequest="",this.sessionManager=e.sessionManager,this.specsManager=e.specsManager,this.translator=e.translator||i.b,this._trans=this.translator.load("jupyterlab"),this._path=null!==(t=e.path)&&void 0!==t?t:a.UUID.uuid4(),this._type=null!==(n=e.type)&&void 0!==n?n:"",this._name=null!==(r=e.name)&&void 0!==r?r:"",this._setBusy=e.setBusy,this._kernelPreference=null!==(o=e.kernelPreference)&&void 0!==o?o:{}}get session(){var e;return null!==(e=this._session)&&void 0!==e?e:null}get path(){return this._path}get type(){return this._type}get name(){return this._name}get kernelChanged(){return this._kernelChanged}get sessionChanged(){return this._sessionChanged}get statusChanged(){return this._statusChanged}get pendingInput(){return this._pendingInput}get connectionStatusChanged(){return this._connectionStatusChanged}get iopubMessage(){return this._iopubMessage}get unhandledMessage(){return this._unhandledMessage}get propertyChanged(){return this._propertyChanged}get kernelPreference(){return this._kernelPreference}set kernelPreference(e){this._kernelPreference=e}get isReady(){return this._isReady}get ready(){return this._ready.promise}get isTerminating(){return this._isTerminating}get isRestarting(){return this._isRestarting}get hasNoKernel(){return this.kernelDisplayName===this.noKernelName}get kernelDisplayName(){var e,t,n,r,i,o,a,s,l,c;const u=null===(e=this.session)||void 0===e?void 0:e.kernel;if(this._pendingKernelName===this.noKernelName)return this.noKernelName;if(!u&&!this.isReady&&!1!==this.kernelPreference.canStart&&!1!==this.kernelPreference.shouldStart){let e=this._pendingKernelName||d.getDefaultKernel({specs:this.specsManager.specs,sessions:this.sessionManager.running(),preference:this.kernelPreference})||"";return e?(e=null!==(r=null===(n=null===(t=this.specsManager.specs)||void 0===t?void 0:t.kernelspecs[e])||void 0===n?void 0:n.display_name)&&void 0!==r?r:e,e):this.noKernelName}return this._pendingKernelName?null!==(a=null===(o=null===(i=this.specsManager.specs)||void 0===i?void 0:i.kernelspecs[this._pendingKernelName])||void 0===o?void 0:o.display_name)&&void 0!==a?a:this._pendingKernelName:u?null!==(c=null===(l=null===(s=this.specsManager.specs)||void 0===s?void 0:s.kernelspecs[u.name])||void 0===l?void 0:l.display_name)&&void 0!==c?c:u.name:this.noKernelName}get kernelDisplayStatus(){var e,t;const n=null===(e=this.session)||void 0===e?void 0:e.kernel;return this._isTerminating?"terminating":this._isRestarting?"restarting":this._pendingKernelName===this.noKernelName?"idle":!n&&this._pendingKernelName?"initializing":n||this.isReady||!1===this.kernelPreference.canStart||!1===this.kernelPreference.shouldStart?null!==(t="connected"===(null==n?void 0:n.connectionStatus)?null==n?void 0:n.status:null==n?void 0:n.connectionStatus)&&void 0!==t?t:"unknown":"initializing"}get prevKernelName(){return this._prevKernelName}get isDisposed(){return this._isDisposed}get disposed(){return this._disposed}get noKernelName(){return this._trans.__("No Kernel")}dispose(){this._isDisposed||(this._isDisposed=!0,this._disposed.emit(),this._session&&(this.kernelPreference.shutdownOnDispose&&this.sessionManager.shutdown(this._session.id).catch(e=>{console.error("Kernel not shut down "+e)}),this._session.dispose(),this._session=null),this._dialog&&this._dialog.dispose(),this._busyDisposable&&(this._busyDisposable.dispose(),this._busyDisposable=null),s.Signal.clearData(this))}async restartKernel(){var e,t,n,r,i,o;const a=(null===(e=this.session)||void 0===e?void 0:e.kernel)||null;this._isRestarting=!0,this._isReady=!1,this._statusChanged.emit("restarting"),await(null===(n=null===(t=this.session)||void 0===t?void 0:t.kernel)||void 0===n?void 0:n.restart()),this._isRestarting=!1,this._isReady=!0,this._statusChanged.emit((null===(i=null===(r=this.session)||void 0===r?void 0:r.kernel)||void 0===i?void 0:i.status)||"unknown"),this._kernelChanged.emit({name:"kernel",oldValue:a,newValue:(null===(o=this.session)||void 0===o?void 0:o.kernel)||null})}async changeKernel(e={}){if(this.isDisposed)throw new Error("Disposed");return await this._initStarted.promise,this._changeKernel(e)}async shutdown(){if(!this.isDisposed&&this._initializing)return await this._initStarted.promise,this._pendingSessionRequest="",this._pendingKernelName=this.noKernelName,this._shutdownSession()}async initialize(){if(this._initializing)return this._initPromise.promise;this._initializing=!0;const e=await this._initialize();return e||(this._isReady=!0,this._ready.resolve(void 0)),this._pendingSessionRequest||this._initStarted.resolve(void 0),this._initPromise.resolve(e),e}async _initialize(){const e=this.sessionManager;await e.ready,await e.refreshRunning();const t=Object(o.find)(e.running(),e=>e.path===this._path);if(t)try{const n=e.connectTo({model:t});this._handleNewSession(n)}catch(e){return this._handleSessionError(e),Promise.reject(e)}return await this._startIfNecessary()}async _shutdownSession(){const e=this._session;this._isTerminating=!0,this._isReady=!1,this._statusChanged.emit("terminating"),await(null==e?void 0:e.shutdown()),this._isTerminating=!1,null==e||e.dispose(),this._session=null;const t=(null==e?void 0:e.kernel)||null;this._statusChanged.emit("unknown"),this._kernelChanged.emit({name:"kernel",oldValue:t,newValue:null}),this._sessionChanged.emit({name:"session",oldValue:e,newValue:null})}async _startIfNecessary(){var e;const t=this.kernelPreference;if(this.isDisposed||(null===(e=this.session)||void 0===e?void 0:e.kernel)||!1===t.shouldStart||!1===t.canStart)return!1;let n;if(t.id)n={id:t.id};else{const e=d.getDefaultKernel({specs:this.specsManager.specs,sessions:this.sessionManager.running(),preference:t});e&&(n={name:e})}if(n)try{return await this._changeKernel(n),!1}catch(e){}return!0}async _changeKernel(e={},t=!1){e.name&&(this._pendingKernelName=e.name),this._session&&!this._isTerminating?await this._shutdownSession():this._session||this._kernelChanged.emit({name:"kernel",oldValue:null,newValue:null}),this._pendingSessionRequest||this._initStarted.resolve(void 0);const n=r.PathExt.dirname(this._path),i=this._pendingSessionRequest=r.PathExt.join(n,a.UUID.uuid4());try{this._statusChanged.emit("starting");const t=await this.sessionManager.startNew({path:i,type:this._type,name:this._name,kernel:e});return this._pendingSessionRequest!==t.path?(await t.shutdown(),t.dispose(),null):(await t.setPath(this._path),await t.setName(this._name),this._session&&!this._isTerminating&&await this._shutdownSession(),this._handleNewSession(t))}catch(e){throw this._handleSessionError(e),e}}_handleNewSession(e){var t,n,r;if(this.isDisposed)throw Error("Disposed");return this._isReady||(this._isReady=!0,this._ready.resolve(void 0)),this._session&&this._session.dispose(),this._session=e,this._pendingKernelName="",e&&(this._prevKernelName=null!==(n=null===(t=e.kernel)||void 0===t?void 0:t.name)&&void 0!==n?n:"",e.disposed.connect(this._onSessionDisposed,this),e.propertyChanged.connect(this._onPropertyChanged,this),e.kernelChanged.connect(this._onKernelChanged,this),e.statusChanged.connect(this._onStatusChanged,this),e.connectionStatusChanged.connect(this._onConnectionStatusChanged,this),e.pendingInput.connect(this._onPendingInput,this),e.iopubMessage.connect(this._onIopubMessage,this),e.unhandledMessage.connect(this._onUnhandledMessage,this),e.path!==this._path&&this._onPropertyChanged(e,"path"),e.name!==this._name&&this._onPropertyChanged(e,"name"),e.type!==this._type&&this._onPropertyChanged(e,"type")),this._sessionChanged.emit({name:"session",oldValue:null,newValue:e}),this._kernelChanged.emit({oldValue:null,newValue:(null==e?void 0:e.kernel)||null,name:"kernel"}),this._statusChanged.emit((null===(r=null==e?void 0:e.kernel)||void 0===r?void 0:r.status)||"unknown"),(null==e?void 0:e.kernel)||null}async _handleSessionError(e){this._handleNewSession(null);let t="",n="";try{t=e.traceback,n=e.message}catch(e){}const r=c.createElement("div",null,n&&c.createElement("pre",null,n),t&&c.createElement("details",{className:"jp-mod-wide"},c.createElement("pre",null,t))),i=this._dialog=new u.a({title:this._trans.__("Error Starting Kernel"),body:r,buttons:[u.a.okButton()]});await i.launch(),this._dialog=null}_onSessionDisposed(){if(this._session){const e=this._session;this._session=null;const t=this._session;this._sessionChanged.emit({name:"session",oldValue:e,newValue:t})}}_onPropertyChanged(e,t){switch(t){case"path":this._path=e.path;break;case"name":this._name=e.name;break;case"type":this._type=e.type;break;default:throw new Error("unrecognized property "+t)}this._propertyChanged.emit(t)}_onKernelChanged(e,t){this._kernelChanged.emit(t)}_onStatusChanged(e,t){this._setBusy&&("busy"===t?this._busyDisposable||(this._busyDisposable=this._setBusy()):this._busyDisposable&&(this._busyDisposable.dispose(),this._busyDisposable=null)),this._statusChanged.emit(t)}_onConnectionStatusChanged(e,t){this._connectionStatusChanged.emit(t)}_onPendingInput(e,t){this._pendingInput=t}_onIopubMessage(e,t){"shutdown_reply"===t.header.msg_type&&this.session.kernel.removeInputGuard(),this._iopubMessage.emit(t)}_onUnhandledMessage(e,t){this._unhandledMessage.emit(t)}}!function(e){e.getDefaultKernel=function(e){return p.getDefaultKernel(e)}}(d||(d={}));const h={async selectKernel(e,t){if(e.isDisposed)return Promise.resolve();const n=(t=t||i.b).load("jupyterlab");let r=n.__("Cancel");e.hasNoKernel&&(r=e.kernelDisplayName);const o=[u.a.cancelButton({label:r}),u.a.okButton({label:n.__("Select")})],a=new u.a({title:n.__("Select Kernel"),body:new p.KernelSelector(e,t),buttons:o}),s=await a.launch();if(e.isDisposed||!s.button.accept)return;const l=s.value;if(null===l&&!e.hasNoKernel)return e.shutdown();l&&await e.changeKernel(l)},async restart(e,t){var n;const r=(t=t||i.b).load("jupyterlab");if(await e.initialize(),e.isDisposed)throw new Error("session already disposed");const o=null===(n=e.session)||void 0===n?void 0:n.kernel;if(!o&&e.prevKernelName)return await e.changeKernel({name:e.prevKernelName}),!0;if(!o)throw new Error("No kernel to restart");const a=u.a.warnButton({label:"Restart"}),s=await Object(u.b)({title:r.__("Restart Kernel?"),body:r.__("Do you want to restart the current kernel? All variables will be lost."),buttons:[u.a.cancelButton(),a]});return!o.isDisposed&&(!!s.button.accept&&(await e.restartKernel(),!0))}};var p;!function(e){class t extends l.Widget{constructor(e,t){super({node:n(e,t)})}getValue(){const e=this.node.querySelector("select");return JSON.parse(e.value)}}function n(e,t){const n=(t=t||i.b).load("jupyterlab"),r=document.createElement("div"),o=document.createElement("label");o.textContent=`${n.__("Select kernel for:")} "${e.name}"`,r.appendChild(o);const s=function(e){return{specs:e.specsManager.specs,sessions:e.sessionManager.running(),preference:e.kernelPreference}}(e),l=document.createElement("select");return a(l,s,t,e.hasNoKernel?null:e.kernelDisplayName),r.appendChild(l),r}function a(e,t,n,r=null){for(;e.firstChild;)e.removeChild(e.firstChild);const{preference:a,sessions:l,specs:d}=t,{name:h,id:p,language:f,canStart:m,shouldStart:g}=a,v=(n=n||i.b).load("jupyterlab");if(!d||!1===m)return e.appendChild(c(n)),e.value="null",void(e.disabled=!0);e.disabled=!1;const y=Object.create(null),_=Object.create(null);for(const e in d.kernelspecs){const t=d.kernelspecs[e];y[e]=t.display_name,_[e]=t.language}const b=[];if(h&&h in d.kernelspecs&&b.push(h),f)for(const e in d.kernelspecs)h!==e&&_[e]===f&&b.push(e);b.length||b.push(d.default);const M=document.createElement("optgroup");M.label=v.__("Start Preferred Kernel"),b.sort((e,t)=>y[e].localeCompare(y[t]));for(const e of b)M.appendChild(s(e,y[e]));M.firstChild&&e.appendChild(M),e.appendChild(c());const w=document.createElement("optgroup");w.label=v.__("Start Other Kernel");const A=[];for(const e in d.kernelspecs)-1===b.indexOf(e)&&A.push(e);A.sort((e,t)=>y[e].localeCompare(y[t]));for(const e of A)w.appendChild(s(e,y[e]));if(A.length&&e.appendChild(w),!1===g)e.value="null";else{let t=0;r&&(t=[...e.options].findIndex(e=>e.text===r),t=Math.max(t,0)),e.selectedIndex=t}if(!l)return;const C=[],x=[];Object(o.each)(l,e=>{var t;f&&e.kernel&&_[e.kernel.name]===f&&e.kernel.id!==p?C.push(e):(null===(t=e.kernel)||void 0===t?void 0:t.id)!==p&&x.push(e)});const E=document.createElement("optgroup");E.label=v.__("Use Kernel from Preferred Session"),e.appendChild(E),C.length&&(C.sort((e,t)=>e.path.localeCompare(t.path)),Object(o.each)(C,e=>{const t=e.kernel?y[e.kernel.name]:"";E.appendChild(u(e,t,n))}));const L=document.createElement("optgroup");L.label=v.__("Use Kernel from Other Session"),e.appendChild(L),x.length&&(x.sort((e,t)=>e.path.localeCompare(t.path)),Object(o.each)(x,e=>{const t=e.kernel?y[e.kernel.name]||e.kernel.name:"";L.appendChild(u(e,t,n))}))}function s(e,t){const n=document.createElement("option");return n.text=t,n.value=JSON.stringify({name:e}),n}function c(e){const t=(e=e||i.b).load("jupyterlab"),n=document.createElement("optgroup");n.label=t.__("Use No Kernel");const r=document.createElement("option");return r.text=t.__("No Kernel"),r.value="null",n.appendChild(r),n}function u(e,t,n){var o,a;const s=(n=n||i.b).load("jupyterlab"),l=document.createElement("option"),c=e.name||r.PathExt.basename(e.path);return l.text=c,l.value=JSON.stringify({id:null===(o=e.kernel)||void 0===o?void 0:o.id}),l.title=`${s.__("Path:")} ${e.path}\n${s.__("Name:")} ${c}\n${s.__("Kernel Name:")} ${t}\n${s.__("Kernel Id:")} ${null===(a=e.kernel)||void 0===a?void 0:a.id}`,l}e.KernelSelector=t,e.getDefaultKernel=function(e){var t;const{specs:n,preference:r}=e,{name:i,language:o,shouldStart:a,canStart:s,autoStartDefault:l}=r;if(!n||!1===a||!1===s)return null;const c=l?n.default:null;if(!i&&!o)return c;for(const e in n.kernelspecs)if(e===i)return i;if(!o)return c;const u=[];for(const e in n.kernelspecs){o===(null===(t=n.kernelspecs[e])||void 0===t?void 0:t.language)&&u.push(e)}if(1===u.length){const e=u[0];return console.warn("No exact match found for "+e+", using kernel "+e+" that matches language="+o),e}return c},e.populateKernelSelect=a}(p||(p={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r,i=n(38);!function(e){function t(t){return!("object"!=typeof t||!t)&&e.symbol in t}async function n(e){const t="string"==typeof e,n=function(){const e=window.document.createElement("iframe");e.setAttribute("sandbox","allow-modals allow-same-origin");return e.setAttribute("style","visibility:hidden;width:0;height:0;position:absolute;z-index:-9999;bottom:0;"),e.setAttribute("width","0"),e.setAttribute("height","0"),e}(),i=window.document.body;i.appendChild(n),t?(n.srcdoc=e,await r(n)):(n.src="about:blank",await r(n),function(e,t){e.contentDocument.body.appendChild(t.cloneNode(!0)),e.contentDocument.close()}(n,e));const o=new Promise(e=>{const t=()=>{document.removeEventListener("mousemove",t,!0),document.removeEventListener("mousedown",t,!0),document.removeEventListener("keydown",t,!0),e()};document.addEventListener("mousemove",t,!0),document.addEventListener("mousedown",t,!0),document.addEventListener("keydown",t,!0)});var a;(a=n.contentWindow).document.execCommand("print",!1)||a.print(),await o,i.removeChild(n)}function r(e){return new Promise(t=>{e.onload=()=>t()})}e.symbol=Symbol("printable"),e.isPrintable=t,e.getPrintFunction=function(n){return t(n)?n[e.symbol]():null},e.printWidget=function(e){return n(e.node)},e.printURL=async function(e){const t=i.ServerConnection.makeSettings();return n(await(await i.ServerConnection.makeRequest(e,{},t)).text())}}(r||(r={}))},function(e,t,n){"use strict";n.d(t,"b",(function(){return r})),n.d(t,"a",(function(){return a}));const r=String.fromCharCode,i=(String.fromCodePoint,/^\s*/g),o=/([A-Z])/g,a=(e,t)=>(e=>e.replace(i,""))(e.replace(o,e=>`${t}${(e=>e.toLowerCase())(e)}`));"undefined"!=typeof TextEncoder&&new TextEncoder;let s="undefined"==typeof TextDecoder?null:new TextDecoder("utf-8",{fatal:!0,ignoreBOM:!0});s&&1===s.decode(new Uint8Array).length&&(s=null)},function(e,t,n){const r=n(646),i=n(655),{isPlainObject:o}=n(656),a=n(657),s=n(658),{parse:l}=n(659),c=["img","audio","video","picture","svg","object","map","iframe","embed"],u=["script","style"];function d(e,t){e&&Object.keys(e).forEach((function(n){t(e[n],n)}))}function h(e,t){return{}.hasOwnProperty.call(e,t)}function p(e,t){const n=[];return d(e,(function(e){t(e)&&n.push(e)})),n}e.exports=m;const f=/^[^\0\t\n\f\r /<=>]+$/;function m(e,t,n){if(null==e)return"";let v="",y="";function _(e,t){const n=this;this.tag=e,this.attribs=t||{},this.tagPosition=v.length,this.text="",this.mediaChildren=[],this.updateParentNodeText=function(){if(S.length){S[S.length-1].text+=n.text}},this.updateParentNodeMediaChildren=function(){if(S.length&&c.includes(this.tag)){S[S.length-1].mediaChildren.push(this.tag)}}}(t=Object.assign({},m.defaults,t)).parser=Object.assign({},g,t.parser),u.forEach((function(e){t.allowedTags&&t.allowedTags.indexOf(e)>-1&&!t.allowVulnerableTags&&console.warn(`\n\n⚠️ Your \`allowedTags\` option includes, \`${e}\`, which is inherently\nvulnerable to XSS attacks. Please remove it from \`allowedTags\`.\nOr, to disable this warning, add the \`allowVulnerableTags\` option\nand ensure you are accounting for this risk.\n\n`)}));const b=t.nonTextTags||["script","style","textarea","option"];let M,w;t.allowedAttributes&&(M={},w={},d(t.allowedAttributes,(function(e,t){M[t]=[];const n=[];e.forEach((function(e){"string"==typeof e&&e.indexOf("*")>=0?n.push(i(e).replace(/\\\*/g,".*")):M[t].push(e)})),n.length&&(w[t]=new RegExp("^("+n.join("|")+")$"))})));const A={},C={};d(t.allowedClasses,(function(e,t){M&&(h(M,t)||(M[t]=[]),M[t].push("class")),A[t]=[];const n=[];e.forEach((function(e){"string"==typeof e&&e.indexOf("*")>=0?n.push(i(e).replace(/\\\*/g,".*")):A[t].push(e)})),n.length&&(C[t]=new RegExp("^("+n.join("|")+")$"))}));const x={};let E,L,S,T,O,I,k;d(t.transformTags,(function(e,t){let n;"function"==typeof e?n=e:"string"==typeof e&&(n=m.simpleTransform(e)),"*"===t?E=n:x[t]=n}));let D=!1;j();const N=new r.Parser({onopentag:function(e,n){if(t.enforceHtmlBoundary&&"html"===e&&j(),I)return void k++;const r=new _(e,n);S.push(r);let i=!1;const c=!!r.text;let u;if(h(x,e)&&(u=x[e](e,n),r.attribs=n=u.attribs,void 0!==u.text&&(r.innerText=u.text),e!==u.tagName&&(r.name=e=u.tagName,O[L]=u.tagName)),E&&(u=E(e,n),r.attribs=n=u.attribs,e!==u.tagName&&(r.name=e=u.tagName,O[L]=u.tagName)),(t.allowedTags&&-1===t.allowedTags.indexOf(e)||"recursiveEscape"===t.disallowedTagsMode&&!function(e){for(const t in e)if(h(e,t))return!1;return!0}(T)||null!=t.nestingLimit&&L>=t.nestingLimit)&&(i=!0,T[L]=!0,"discard"===t.disallowedTagsMode&&-1!==b.indexOf(e)&&(I=!0,k=1),T[L]=!0),L++,i){if("discard"===t.disallowedTagsMode)return;y=v,v=""}v+="<"+e,"script"===e&&(t.allowedScriptHostnames||t.allowedScriptDomains)&&(r.innerText=""),(!M||h(M,e)||M["*"])&&d(n,(function(n,i){if(!f.test(i))return void delete r.attribs[i];let c,u=!1;if(!M||h(M,e)&&-1!==M[e].indexOf(i)||M["*"]&&-1!==M["*"].indexOf(i)||h(w,e)&&w[e].test(i)||w["*"]&&w["*"].test(i))u=!0;else if(M&&M[e])for(const t of M[e])if(o(t)&&t.name&&t.name===i){u=!0;let e="";if(!0===t.multiple){const r=n.split(" ");for(const n of r)-1!==t.values.indexOf(n)&&(""===e?e=n:e+=" "+n)}else t.values.indexOf(n)>=0&&(e=n);n=e}if(u){if(-1!==t.allowedSchemesAppliedToAttributes.indexOf(i)&&z(e,n))return void delete r.attribs[i];if("script"===e&&"src"===i){let e=!0;try{const r=new URL(n);if(t.allowedScriptHostnames||t.allowedScriptDomains){const n=(t.allowedScriptHostnames||[]).find((function(e){return e===r.hostname})),i=(t.allowedScriptDomains||[]).find((function(e){return r.hostname===e||r.hostname.endsWith("."+e)}));e=n||i}}catch(t){e=!1}if(!e)return void delete r.attribs[i]}if("iframe"===e&&"src"===i){let e=!0;try{if((n=n.replace(/^(\w+:)?\s*[\\/]\s*[\\/]/,"$1//")).startsWith("relative:"))throw new Error("relative: exploit attempt");let r="relative://relative-site";for(let e=0;e<100;e++)r+="/"+e;const i=new URL(n,r);if(i&&"relative-site"===i.hostname&&"relative:"===i.protocol)e=h(t,"allowIframeRelativeUrls")?t.allowIframeRelativeUrls:!t.allowedIframeHostnames&&!t.allowedIframeDomains;else if(t.allowedIframeHostnames||t.allowedIframeDomains){const n=(t.allowedIframeHostnames||[]).find((function(e){return e===i.hostname})),r=(t.allowedIframeDomains||[]).find((function(e){return i.hostname===e||i.hostname.endsWith("."+e)}));e=n||r}}catch(t){e=!1}if(!e)return void delete r.attribs[i]}if("srcset"===i)try{if(c=s(n),c.forEach((function(e){z("srcset",e.url)&&(e.evil=!0)})),c=p(c,(function(e){return!e.evil})),!c.length)return void delete r.attribs[i];n=p(c,(function(e){return!e.evil})).map((function(e){if(!e.url)throw new Error("URL missing");return e.url+(e.w?` ${e.w}w`:"")+(e.h?` ${e.h}h`:"")+(e.d?` ${e.d}x`:"")})).join(", "),r.attribs[i]=n}catch(e){return void delete r.attribs[i]}if("class"===i){const t=A[e],o=A["*"],s=[C[e],C["*"]].filter((function(e){return e}));if(!(n=R(n,t&&o?a(t,o):t||o,s)).length)return void delete r.attribs[i]}if("style"===i)try{const o=l(e+" {"+n+"}");if(0===(n=function(e){return e.nodes[0].nodes.reduce((function(e,t){return e.push(t.prop+":"+t.value),e}),[]).join(";")}(function(e,t){if(!t)return e;const n=e.nodes[0];let r;r=t[n.selector]&&t["*"]?a(t[n.selector],t["*"]):t[n.selector]||t["*"];r&&(e.nodes[0].nodes=n.nodes.reduce(function(e){return function(t,n){if(h(e,n.prop)){e[n.prop].some((function(e){return e.test(n.value)}))&&t.push(n)}return t}}(r),[]));return e}(o,t.allowedStyles))).length)return void delete r.attribs[i]}catch(e){return void delete r.attribs[i]}v+=" "+i,n&&n.length&&(v+='="'+P(n,!0)+'"')}else delete r.attribs[i]})),-1!==t.selfClosing.indexOf(e)?v+=" />":(v+=">",!r.innerText||c||t.textFilter||(v+=P(r.innerText),D=!0)),i&&(v=y+P(v),y="")},ontext:function(e){if(I)return;const n=S[S.length-1];let r;if(n&&(r=n.tag,e=void 0!==n.innerText?n.innerText:e),"discard"!==t.disallowedTagsMode||"script"!==r&&"style"!==r){const n=P(e,!1);t.textFilter&&!D?v+=t.textFilter(n,r):D||(v+=n)}else v+=e;if(S.length){S[S.length-1].text+=e}},onclosetag:function(e){if(I){if(k--,k)return;I=!1}const n=S.pop();if(!n)return;I=!!t.enforceHtmlBoundary&&"html"===e,L--;const r=T[L];if(r){if(delete T[L],"discard"===t.disallowedTagsMode)return void n.updateParentNodeText();y=v,v=""}O[L]&&(e=O[L],delete O[L]),t.exclusiveFilter&&t.exclusiveFilter(n)?v=v.substr(0,n.tagPosition):(n.updateParentNodeMediaChildren(),n.updateParentNodeText(),-1===t.selfClosing.indexOf(e)?(v+="</"+e+">",r&&(v=y+P(v),y="")):r&&(v=y,y=""))}},t.parser);return N.write(e),N.end(),v;function j(){v="",L=0,S=[],T={},O={},I=!1,k=0}function P(e,n){return"string"!=typeof e&&(e+=""),t.parser.decodeEntities&&(e=e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;"),n&&(e=e.replace(/"/g,"&quot;"))),e=e.replace(/&(?![a-zA-Z0-9#]{1,20};)/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;"),n&&(e=e.replace(/"/g,"&quot;")),e}function z(e,n){const r=(n=(n=n.replace(/[\x00-\x20]+/g,"")).replace(/<!--.*?-->/g,"")).match(/^([a-zA-Z][a-zA-Z0-9.\-+]*):/);if(!r)return!!n.match(/^[/\\]{2}/)&&!t.allowProtocolRelative;const i=r[1].toLowerCase();return h(t.allowedSchemesByTag,e)?-1===t.allowedSchemesByTag[e].indexOf(i):!t.allowedSchemes||-1===t.allowedSchemes.indexOf(i)}function R(e,t,n){return t?(e=e.split(/\s+/)).filter((function(e){return-1!==t.indexOf(e)||n.some((function(t){return t.test(e)}))})).join(" "):e}}const g={decodeEntities:!0};m.defaults={allowedTags:["address","article","aside","footer","header","h1","h2","h3","h4","h5","h6","hgroup","main","nav","section","blockquote","dd","div","dl","dt","figcaption","figure","hr","li","main","ol","p","pre","ul","a","abbr","b","bdi","bdo","br","cite","code","data","dfn","em","i","kbd","mark","q","rb","rp","rt","rtc","ruby","s","samp","small","span","strong","sub","sup","time","u","var","wbr","caption","col","colgroup","table","tbody","td","tfoot","th","thead","tr"],disallowedTagsMode:"discard",allowedAttributes:{a:["href","name","target"],img:["src"]},selfClosing:["img","br","hr","area","base","basefont","input","link","meta"],allowedSchemes:["http","https","ftp","mailto","tel"],allowedSchemesByTag:{},allowedSchemesAppliedToAttributes:["href","src","cite"],allowProtocolRelative:!0,enforceHtmlBoundary:!1},m.simpleTransform=function(e,t,n){return n=void 0===n||n,t=t||{},function(r,i){let o;if(n)for(o in t)i[o]=t[o];else i=t;return{tagName:e,attribs:i}}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.validateProperty=void 0,t.validateProperty=function(e,t,n,r=[]){if(!e.hasOwnProperty(t))throw Error(`Missing property '${t}'`);const i=e[t];if(void 0!==n){let e=!0;switch(n){case"array":e=Array.isArray(i);break;case"object":e=void 0!==i;break;default:e=typeof i===n}if(!e)throw new Error(`Property '${t}' is not of type '${n}'`);if(r.length>0){let e=!0;switch(n){case"string":case"number":case"boolean":e=r.includes(i);break;default:e=r.findIndex(e=>e===i)>=0}if(!e)throw new Error(`Property '${t}' is not one of the valid values ${JSON.stringify(r)}`)}}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.isInputReplyMsg=t.isInputRequestMsg=t.isDebugReplyMsg=t.isDebugRequestMsg=t.isExecuteReplyMsg=t.isInfoRequestMsg=t.isCommMsgMsg=t.isCommCloseMsg=t.isCommOpenMsg=t.isDebugEventMsg=t.isClearOutputMsg=t.isStatusMsg=t.isErrorMsg=t.isExecuteResultMsg=t.isExecuteInputMsg=t.isUpdateDisplayDataMsg=t.isDisplayDataMsg=t.isStreamMsg=t.createMessage=void 0;const r=n(6);t.createMessage=function(e){var t,n,i,o,a;return{buffers:null!==(t=e.buffers)&&void 0!==t?t:[],channel:e.channel,content:e.content,header:{date:(new Date).toISOString(),msg_id:null!==(n=e.msgId)&&void 0!==n?n:r.UUID.uuid4(),msg_type:e.msgType,session:e.session,username:null!==(i=e.username)&&void 0!==i?i:"",version:"5.2"},metadata:null!==(o=e.metadata)&&void 0!==o?o:{},parent_header:null!==(a=e.parentHeader)&&void 0!==a?a:{}}},t.isStreamMsg=function(e){return"stream"===e.header.msg_type},t.isDisplayDataMsg=function(e){return"display_data"===e.header.msg_type},t.isUpdateDisplayDataMsg=function(e){return"update_display_data"===e.header.msg_type},t.isExecuteInputMsg=function(e){return"execute_input"===e.header.msg_type},t.isExecuteResultMsg=function(e){return"execute_result"===e.header.msg_type},t.isErrorMsg=function(e){return"error"===e.header.msg_type},t.isStatusMsg=function(e){return"status"===e.header.msg_type},t.isClearOutputMsg=function(e){return"clear_output"===e.header.msg_type},t.isDebugEventMsg=function(e){return"debug_event"===e.header.msg_type},t.isCommOpenMsg=function(e){return"comm_open"===e.header.msg_type},t.isCommCloseMsg=function(e){return"comm_close"===e.header.msg_type},t.isCommMsgMsg=function(e){return"comm_msg"===e.header.msg_type},t.isInfoRequestMsg=function(e){return"kernel_info_request"===e.header.msg_type},t.isExecuteReplyMsg=function(e){return"execute_reply"===e.header.msg_type},t.isDebugRequestMsg=function(e){return"debug_request"===e.header.msg_type},t.isDebugReplyMsg=function(e){return"debug_reply"===e.header.msg_type},t.isInputRequestMsg=function(e){return"input_request"===e.header.msg_type},t.isInputReplyMsg=function(e){return"input_reply"===e.header.msg_type}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.BaseManager=void 0;const r=n(4),i=n(56);t.BaseManager=class{constructor(e){var t;this._isDisposed=!1,this._disposed=new r.Signal(this),this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:i.ServerConnection.makeSettings()}get disposed(){return this._disposed}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._disposed.emit(void 0),r.Signal.clearData(this))}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.shutdownTerminal=t.listRunning=t.startNew=t.isAvailable=t.TERMINAL_SERVICE_URL=void 0;const r=n(12),i=n(56);function o(){return"true"===String(r.PageConfig.getOption("terminalsAvailable")).toLowerCase()}var a;t.TERMINAL_SERVICE_URL="api/terminals",t.isAvailable=o,t.startNew=async function(e=i.ServerConnection.makeSettings()){a.errorIfNotAvailable();const n=r.URLExt.join(e.baseUrl,t.TERMINAL_SERVICE_URL),o=await i.ServerConnection.makeRequest(n,{method:"POST"},e);if(200!==o.status){throw await i.ServerConnection.ResponseError.create(o)}return await o.json()},t.listRunning=async function(e=i.ServerConnection.makeSettings()){a.errorIfNotAvailable();const n=r.URLExt.join(e.baseUrl,t.TERMINAL_SERVICE_URL),o=await i.ServerConnection.makeRequest(n,{},e);if(200!==o.status){throw await i.ServerConnection.ResponseError.create(o)}const s=await o.json();if(!Array.isArray(s))throw new Error("Invalid terminal list");return s},t.shutdownTerminal=async function(e,n=i.ServerConnection.makeSettings()){var o;a.errorIfNotAvailable();const s=r.URLExt.join(n.baseUrl,t.TERMINAL_SERVICE_URL,e),l=await i.ServerConnection.makeRequest(s,{method:"DELETE"},n);if(404===l.status){const t=null!==(o=(await l.json()).message)&&void 0!==o?o:`The terminal session "${e}"" does not exist on the server`;console.warn(t)}else if(204!==l.status){throw await i.ServerConnection.ResponseError.create(l)}},function(e){e.errorIfNotAvailable=function(){if(!o())throw new Error("Terminals Unavailable")}}(a||(a={}))},function(e,t,n){"use strict";let r=n(124);class i extends r{constructor(e){e&&void 0!==e.value&&"string"!=typeof e.value&&(e={...e,value:String(e.value)}),super(e),this.type="decl"}get variable(){return this.prop.startsWith("--")||"$"===this.prop[0]}}e.exports=i,i.default=i},function(e,t,n){"use strict";let{isClean:r,my:i}=n(159),o=n(158),a=n(368),s=n(125);class l{constructor(e={}){this.raws={},this[r]=!1,this[i]=!0;for(let t in e)if("nodes"===t){this.nodes=[];for(let n of e[t])"function"==typeof n.clone?this.append(n.clone()):this.append(n)}else this[t]=e[t]}error(e,t={}){if(this.source){let{start:n,end:r}=this.rangeBy(t);return this.source.input.error(e,{line:n.line,column:n.column},{line:r.line,column:r.column},t)}return new o(e)}warn(e,t,n){let r={node:this};for(let e in n)r[e]=n[e];return e.warn(t,r)}remove(){return this.parent&&this.parent.removeChild(this),this.parent=void 0,this}toString(e=s){e.stringify&&(e=e.stringify);let t="";return e(this,e=>{t+=e}),t}assign(e={}){for(let t in e)this[t]=e[t];return this}clone(e={}){let t=function e(t,n){let r=new t.constructor;for(let i in t){if(!Object.prototype.hasOwnProperty.call(t,i))continue;if("proxyCache"===i)continue;let o=t[i],a=typeof o;"parent"===i&&"object"===a?n&&(r[i]=n):"source"===i?r[i]=o:Array.isArray(o)?r[i]=o.map(t=>e(t,r)):("object"===a&&null!==o&&(o=e(o)),r[i]=o)}return r}(this);for(let n in e)t[n]=e[n];return t}cloneBefore(e={}){let t=this.clone(e);return this.parent.insertBefore(this,t),t}cloneAfter(e={}){let t=this.clone(e);return this.parent.insertAfter(this,t),t}replaceWith(...e){if(this.parent){let t=this,n=!1;for(let r of e)r===this?n=!0:n?(this.parent.insertAfter(t,r),t=r):this.parent.insertBefore(t,r);n||this.remove()}return this}next(){if(!this.parent)return;let e=this.parent.index(this);return this.parent.nodes[e+1]}prev(){if(!this.parent)return;let e=this.parent.index(this);return this.parent.nodes[e-1]}before(e){return this.parent.insertBefore(this,e),this}after(e){return this.parent.insertAfter(this,e),this}root(){let e=this;for(;e.parent&&"document"!==e.parent.type;)e=e.parent;return e}raw(e,t){return(new a).raw(this,e,t)}cleanRaws(e){delete this.raws.before,delete this.raws.after,e||delete this.raws.between}toJSON(e,t){let n={},r=null==t;t=t||new Map;let i=0;for(let e in this){if(!Object.prototype.hasOwnProperty.call(this,e))continue;if("parent"===e||"proxyCache"===e)continue;let r=this[e];if(Array.isArray(r))n[e]=r.map(e=>"object"==typeof e&&e.toJSON?e.toJSON(null,t):e);else if("object"==typeof r&&r.toJSON)n[e]=r.toJSON(null,t);else if("source"===e){let o=t.get(r.input);null==o&&(o=i,t.set(r.input,i),i++),n[e]={inputId:o,start:r.start,end:r.end}}else n[e]=r}return r&&(n.inputs=[...t.keys()].map(e=>e.toJSON())),n}positionInside(e){let t=this.toString(),n=this.source.start.column,r=this.source.start.line;for(let i=0;i<e;i++)"\n"===t[i]?(n=1,r+=1):n+=1;return{line:r,column:n}}positionBy(e){let t=this.source.start;if(e.index)t=this.positionInside(e.index);else if(e.word){let n=this.toString().indexOf(e.word);-1!==n&&(t=this.positionInside(n))}return t}rangeBy(e){let t={line:this.source.start.line,column:this.source.start.column},n=this.source.end?{line:this.source.end.line,column:this.source.end.column+1}:{line:t.line,column:t.column+1};if(e.word){let r=this.toString().indexOf(e.word);-1!==r&&(t=this.positionInside(r),n=this.positionInside(r+e.word.length))}else e.start?t={line:e.start.line,column:e.start.column}:e.index&&(t=this.positionInside(e.index)),e.end?n={line:e.end.line,column:e.end.column}:e.endIndex?n=this.positionInside(e.endIndex):e.index&&(n=this.positionInside(e.index+1));return(n.line<t.line||n.line===t.line&&n.column<=t.column)&&(n={line:t.line,column:t.column+1}),{start:t,end:n}}getProxyProcessor(){return{set:(e,t,n)=>(e[t]===n||(e[t]=n,"prop"!==t&&"value"!==t&&"name"!==t&&"params"!==t&&"important"!==t&&"text"!==t||e.markDirty()),!0),get:(e,t)=>"proxyOf"===t?e:"root"===t?()=>e.root().toProxy():e[t]}}toProxy(){return this.proxyCache||(this.proxyCache=new Proxy(this,this.getProxyProcessor())),this.proxyCache}addToError(e){if(e.postcssNode=this,e.stack&&this.source&&/\n\s{4}at /.test(e.stack)){let t=this.source;e.stack=e.stack.replace(/\n\s{4}at /,`$&${t.input.from}:${t.start.line}:${t.start.column}$&`)}return e}markDirty(){if(this[r]){this[r]=!1;let e=this;for(;e=e.parent;)e[r]=!1}}get proxyOf(){return this}}e.exports=l,l.default=l},function(e,t,n){"use strict";let r=n(368);function i(e,t){new r(t).stringify(e)}e.exports=i,i.default=i},function(e,t,n){"use strict";let{SourceMapConsumer:r,SourceMapGenerator:i}=n(161),{fileURLToPath:o,pathToFileURL:a}=n(371),{resolve:s,isAbsolute:l}=n(162),{nanoid:c}=n(663),u=n(367),d=n(158),h=n(372),p=Symbol("fromOffsetCache"),f=Boolean(r&&i),m=Boolean(s&&l);class g{constructor(e,t={}){if(null==e||"object"==typeof e&&!e.toString)throw new Error(`PostCSS received ${e} instead of CSS string`);if(this.css=e.toString(),"\ufeff"===this.css[0]||""===this.css[0]?(this.hasBOM=!0,this.css=this.css.slice(1)):this.hasBOM=!1,t.from&&(!m||/^\w+:\/\//.test(t.from)||l(t.from)?this.file=t.from:this.file=s(t.from)),m&&f){let e=new h(this.css,t);if(e.text){this.map=e;let t=e.consumer().file;!this.file&&t&&(this.file=this.mapResolve(t))}}this.file||(this.id="<input css "+c(6)+">"),this.map&&(this.map.file=this.from)}fromOffset(e){let t,n;if(this[p])n=this[p];else{let e=this.css.split("\n");n=new Array(e.length);let t=0;for(let r=0,i=e.length;r<i;r++)n[r]=t,t+=e[r].length+1;this[p]=n}t=n[n.length-1];let r=0;if(e>=t)r=n.length-1;else{let t,i=n.length-2;for(;r<i;)if(t=r+(i-r>>1),e<n[t])i=t-1;else{if(!(e>=n[t+1])){r=t;break}r=t+1}}return{line:r+1,col:e-n[r]+1}}error(e,t,n,r={}){let i,o,s;if(t&&"object"==typeof t){let e=t,r=n;if("number"==typeof t.offset){let r=this.fromOffset(e.offset);t=r.line,n=r.col}else t=e.line,n=e.column;if("number"==typeof r.offset){let e=this.fromOffset(r.offset);o=e.line,s=e.col}else o=r.line,s=r.column}else if(!n){let e=this.fromOffset(t);t=e.line,n=e.col}let l=this.origin(t,n,o,s);return i=l?new d(e,void 0===l.endLine?l.line:{line:l.line,column:l.column},void 0===l.endLine?l.column:{line:l.endLine,column:l.endColumn},l.source,l.file,r.plugin):new d(e,void 0===o?t:{line:t,column:n},void 0===o?n:{line:o,column:s},this.css,this.file,r.plugin),i.input={line:t,column:n,endLine:o,endColumn:s,source:this.css},this.file&&(a&&(i.input.url=a(this.file).toString()),i.input.file=this.file),i}origin(e,t,n,r){if(!this.map)return!1;let i,s,c=this.map.consumer(),u=c.originalPositionFor({line:e,column:t});if(!u.source)return!1;"number"==typeof n&&(i=c.originalPositionFor({line:n,column:r})),s=l(u.source)?a(u.source):new URL(u.source,this.map.consumer().sourceRoot||a(this.map.mapFile));let d={url:s.toString(),line:u.line,column:u.column,endLine:i&&i.line,endColumn:i&&i.column};if("file:"===s.protocol){if(!o)throw new Error("file: protocol is not available in this PostCSS build");d.file=o(s)}let h=c.sourceContentFor(u.source);return h&&(d.source=h),d}mapResolve(e){return/^\w+:\/\//.test(e)?e:s(this.map.consumer().sourceRoot||this.map.root||".",e)}get from(){return this.file||this.id}toJSON(){let e={};for(let t of["hasBOM","css","file","id"])null!=this[t]&&(e[t]=this[t]);return this.map&&(e.map={...this.map},e.map.consumerCache&&(e.map.consumerCache=void 0)),e}}e.exports=g,g.default=g,u&&u.registerInput&&u.registerInput(g)},function(e,t,n){"use strict";let r=n(124);class i extends r{constructor(e){super(e),this.type="comment"}}e.exports=i,i.default=i},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Intent=void 0,t.Intent={NONE:"none",PRIMARY:"primary",SUCCESS:"success",WARNING:"warning",DANGER:"danger"}},function(e,t,n){var r=n(750),i=n(751),o=n(752),a=n(753),s=n(754);function l(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}l.prototype.clear=r,l.prototype.delete=i,l.prototype.get=o,l.prototype.has=a,l.prototype.set=s,e.exports=l},function(e,t,n){var r=n(402);e.exports=function(e,t){for(var n=e.length;n--;)if(r(e[n][0],t))return n;return-1}},function(e,t,n){var r=n(94)(Object,"create");e.exports=r},function(e,t,n){var r=n(774);e.exports=function(e,t){var n=e.__data__;return r(t)?n["string"==typeof t?"string":"hash"]:n.map}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.FunctionList=void 0;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.execute=function(){for(var e,t,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];try{for(var i=o(this),l=i.next();!l.done;l=i.next()){var c=l.value,u=c.item.apply(c,s([],a(n)));if(!1===u)return!1}}catch(t){e={error:t}}finally{try{l&&!l.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return!0},t.prototype.asyncExecute=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var n=-1,r=this.items;return new Promise((function(t,i){!function o(){for(var l;++n<r.length;){var c=(l=r[n]).item.apply(l,s([],a(e)));if(c instanceof Promise)return void c.then(o).catch((function(e){return i(e)}));if(!1===c)return void t(!1)}t(!0)}()}))},t}(n(108).PrioritizedList);t.FunctionList=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMo=void 0;var l=n(23),c=n(417),u=n(62),d=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._texClass=null,t.lspace=5/18,t.rspace=5/18,t}return i(t,e),Object.defineProperty(t.prototype,"texClass",{get:function(){if(null===this._texClass){var e=this.getText(),t=a(this.handleExplicitForm(this.getForms()),3),n=t[0],r=t[1],i=t[2],o=this.constructor.OPTABLE,s=o[n][e]||o[r][e]||o[i][e];return s?s[2]:l.TEXCLASS.REL}return this._texClass},set:function(e){this._texClass=e},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"kind",{get:function(){return"mo"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isEmbellished",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"hasNewLine",{get:function(){return"newline"===this.attributes.get("linebreak")},enumerable:!1,configurable:!0}),t.prototype.coreParent=function(){for(var e=this,t=this,n=this.factory.getNodeClass("math");t&&t.isEmbellished&&t.coreMO()===this&&!(t instanceof n);)e=t,t=t.parent;return e},t.prototype.coreText=function(e){if(!e)return"";if(e.isEmbellished)return e.coreMO().getText();for(;((e.isKind("mrow")||e.isKind("TeXAtom")||e.isKind("mstyle")||e.isKind("mphantom"))&&1===e.childNodes.length||e.isKind("munderover"))&&e.childNodes[0];)e=e.childNodes[0];return e.isToken?e.getText():""},t.prototype.hasSpacingAttributes=function(){return this.attributes.isSet("lspace")||this.attributes.isSet("rspace")},Object.defineProperty(t.prototype,"isAccent",{get:function(){var e=!1,t=this.coreParent().parent;if(t){var n=t.isKind("mover")?t.childNodes[t.over].coreMO()?"accent":"":t.isKind("munder")?t.childNodes[t.under].coreMO()?"accentunder":"":t.isKind("munderover")?this===t.childNodes[t.over].coreMO()?"accent":this===t.childNodes[t.under].coreMO()?"accentunder":"":"";if(n)e=void 0!==t.attributes.getExplicit(n)?e:this.attributes.get("accent")}return e},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){var t=this.attributes.getList("form","fence"),n=t.form,r=t.fence;return void 0===this.getProperty("texClass")&&(this.attributes.isSet("lspace")||this.attributes.isSet("rspace"))?null:(r&&this.texClass===l.TEXCLASS.REL&&("prefix"===n&&(this.texClass=l.TEXCLASS.OPEN),"postfix"===n&&(this.texClass=l.TEXCLASS.CLOSE)),this.adjustTeXclass(e))},t.prototype.adjustTeXclass=function(e){var t=this.texClass,n=this.prevClass;if(t===l.TEXCLASS.NONE)return e;if(e?(!e.getProperty("autoOP")||t!==l.TEXCLASS.BIN&&t!==l.TEXCLASS.REL||(n=e.texClass=l.TEXCLASS.ORD),n=this.prevClass=e.texClass||l.TEXCLASS.ORD,this.prevLevel=this.attributes.getInherited("scriptlevel")):n=this.prevClass=l.TEXCLASS.NONE,t!==l.TEXCLASS.BIN||n!==l.TEXCLASS.NONE&&n!==l.TEXCLASS.BIN&&n!==l.TEXCLASS.OP&&n!==l.TEXCLASS.REL&&n!==l.TEXCLASS.OPEN&&n!==l.TEXCLASS.PUNCT)if(n!==l.TEXCLASS.BIN||t!==l.TEXCLASS.REL&&t!==l.TEXCLASS.CLOSE&&t!==l.TEXCLASS.PUNCT){if(t===l.TEXCLASS.BIN){for(var r=this,i=this.parent;i&&i.parent&&i.isEmbellished&&(1===i.childNodes.length||!i.isKind("mrow")&&i.core()===r);)r=i,i=i.parent;i.childNodes[i.childNodes.length-1]===r&&(this.texClass=l.TEXCLASS.ORD)}}else e.texClass=this.prevClass=l.TEXCLASS.ORD;else this.texClass=l.TEXCLASS.ORD;return this},t.prototype.setInheritedAttributes=function(t,n,r,i){void 0===t&&(t={}),void 0===n&&(n=!1),void 0===r&&(r=0),void 0===i&&(i=!1),e.prototype.setInheritedAttributes.call(this,t,n,r,i);var o=this.getText();this.checkOperatorTable(o),this.checkPseudoScripts(o),this.checkPrimes(o),this.checkMathAccent(o)},t.prototype.checkOperatorTable=function(e){var t,n,r=a(this.handleExplicitForm(this.getForms()),3),i=r[0],o=r[1],l=r[2];this.attributes.setInherited("form",i);var u=this.constructor.OPTABLE,d=u[i][e]||u[o][e]||u[l][e];if(d){void 0===this.getProperty("texClass")&&(this.texClass=d[2]);try{for(var h=s(Object.keys(d[3]||{})),p=h.next();!p.done;p=h.next()){var f=p.value;this.attributes.setInherited(f,d[3][f])}}catch(e){t={error:e}}finally{try{p&&!p.done&&(n=h.return)&&n.call(h)}finally{if(t)throw t.error}}this.lspace=(d[0]+1)/18,this.rspace=(d[1]+1)/18}else{var m=c.getRange(e);if(m){void 0===this.getProperty("texClass")&&(this.texClass=m[2]);var g=this.constructor.MMLSPACING[m[2]];this.lspace=(g[0]+1)/18,this.rspace=(g[1]+1)/18}}},t.prototype.getForms=function(){for(var e=this,t=this.parent,n=this.Parent;n&&n.isEmbellished;)e=t,t=n.parent,n=n.Parent;if(t&&t.isKind("mrow")&&1!==t.nonSpaceLength()){if(t.firstNonSpace()===e)return["prefix","infix","postfix"];if(t.lastNonSpace()===e)return["postfix","infix","prefix"]}return["infix","prefix","postfix"]},t.prototype.handleExplicitForm=function(e){if(this.attributes.isSet("form")){var t=this.attributes.get("form");e=[t].concat(e.filter((function(e){return e!==t})))}return e},t.prototype.checkPseudoScripts=function(e){var t=this.constructor.pseudoScripts;if(e.match(t)){var n=this.coreParent().Parent,r=!n||!(n.isKind("msubsup")&&!n.isKind("msub"));this.setProperty("pseudoscript",r),r&&(this.attributes.setInherited("lspace",0),this.attributes.setInherited("rspace",0))}},t.prototype.checkPrimes=function(e){var t=this.constructor.primes;if(e.match(t)){var n=this.constructor.remapPrimes,r=u.unicodeString(u.unicodeChars(e).map((function(e){return n[e]})));this.setProperty("primes",r)}},t.prototype.checkMathAccent=function(e){var t=this.Parent;if(void 0===this.getProperty("mathaccent")&&t&&t.isKind("munderover")){var n=t.childNodes[0];if(!n.isEmbellished||n.coreMO()!==this){var r=this.constructor.mathaccents;e.match(r)&&this.setProperty("mathaccent",!0)}}},t.defaults=o(o({},l.AbstractMmlTokenNode.defaults),{form:"infix",fence:!1,separator:!1,lspace:"thickmathspace",rspace:"thickmathspace",stretchy:!1,symmetric:!1,maxsize:"infinity",minsize:"0em",largeop:!1,movablelimits:!1,accent:!1,linebreak:"auto",lineleading:"1ex",linebreakstyle:"before",indentalign:"auto",indentshift:"0",indenttarget:"",indentalignfirst:"indentalign",indentshiftfirst:"indentshift",indentalignlast:"indentalign",indentshiftlast:"indentshift"}),t.MMLSPACING=c.MMLSPACING,t.OPTABLE=c.OPTABLE,t.pseudoScripts=new RegExp(["^[\"'*`","ª","°","²-´","¹","º","‘-‟","′-‷⁗","⁰ⁱ","⁴-ⁿ","₀-₎","]+$"].join("")),t.primes=new RegExp(["^[\"'`","‘-‟","]+$"].join("")),t.remapPrimes={34:8243,39:8242,96:8245,8216:8245,8217:8242,8218:8242,8219:8245,8220:8246,8221:8243,8222:8243,8223:8246},t.mathaccents=new RegExp(["^[","´́ˊ","`̀ˋ","¨̈","~̃˜","¯̄ˉ","˘̆","ˇ̌","^̂ˆ","→⃗","˙̇","˚̊","⃛","⃜","]$"].join("")),t}(l.AbstractMmlTokenNode);t.MmlMo=d},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.numeric=t.translate=t.remove=t.add=t.entities=t.options=void 0;var r=n(180),i=n(825);t.options={loadMissingEntities:!0},t.entities={ApplyFunction:"⁡",Backslash:"∖",Because:"∵",Breve:"˘",Cap:"⋒",CenterDot:"·",CircleDot:"⊙",CircleMinus:"⊖",CirclePlus:"⊕",CircleTimes:"⊗",Congruent:"≡",ContourIntegral:"∮",Coproduct:"∐",Cross:"⨯",Cup:"⋓",CupCap:"≍",Dagger:"‡",Del:"∇",Delta:"Δ",Diamond:"⋄",DifferentialD:"ⅆ",DotEqual:"≐",DoubleDot:"¨",DoubleRightTee:"⊨",DoubleVerticalBar:"∥",DownArrow:"↓",DownLeftVector:"↽",DownRightVector:"⇁",DownTee:"⊤",Downarrow:"⇓",Element:"∈",EqualTilde:"≂",Equilibrium:"⇌",Exists:"∃",ExponentialE:"ⅇ",FilledVerySmallSquare:"▪",ForAll:"∀",Gamma:"Γ",Gg:"⋙",GreaterEqual:"≥",GreaterEqualLess:"⋛",GreaterFullEqual:"≧",GreaterLess:"≷",GreaterSlantEqual:"⩾",GreaterTilde:"≳",Hacek:"ˇ",Hat:"^",HumpDownHump:"≎",HumpEqual:"≏",Im:"ℑ",ImaginaryI:"ⅈ",Integral:"∫",Intersection:"⋂",InvisibleComma:"⁣",InvisibleTimes:"⁢",Lambda:"Λ",Larr:"↞",LeftAngleBracket:"⟨",LeftArrow:"←",LeftArrowRightArrow:"⇆",LeftCeiling:"⌈",LeftDownVector:"⇃",LeftFloor:"⌊",LeftRightArrow:"↔",LeftTee:"⊣",LeftTriangle:"⊲",LeftTriangleEqual:"⊴",LeftUpVector:"↿",LeftVector:"↼",Leftarrow:"⇐",Leftrightarrow:"⇔",LessEqualGreater:"⋚",LessFullEqual:"≦",LessGreater:"≶",LessSlantEqual:"⩽",LessTilde:"≲",Ll:"⋘",Lleftarrow:"⇚",LongLeftArrow:"⟵",LongLeftRightArrow:"⟷",LongRightArrow:"⟶",Longleftarrow:"⟸",Longleftrightarrow:"⟺",Longrightarrow:"⟹",Lsh:"↰",MinusPlus:"∓",NestedGreaterGreater:"≫",NestedLessLess:"≪",NotDoubleVerticalBar:"∦",NotElement:"∉",NotEqual:"≠",NotExists:"∄",NotGreater:"≯",NotGreaterEqual:"≱",NotLeftTriangle:"⋪",NotLeftTriangleEqual:"⋬",NotLess:"≮",NotLessEqual:"≰",NotPrecedes:"⊀",NotPrecedesSlantEqual:"⋠",NotRightTriangle:"⋫",NotRightTriangleEqual:"⋭",NotSubsetEqual:"⊈",NotSucceeds:"⊁",NotSucceedsSlantEqual:"⋡",NotSupersetEqual:"⊉",NotTilde:"≁",NotVerticalBar:"∤",Omega:"Ω",OverBar:"‾",OverBrace:"⏞",PartialD:"∂",Phi:"Φ",Pi:"Π",PlusMinus:"±",Precedes:"≺",PrecedesEqual:"⪯",PrecedesSlantEqual:"≼",PrecedesTilde:"≾",Product:"∏",Proportional:"∝",Psi:"Ψ",Rarr:"↠",Re:"ℜ",ReverseEquilibrium:"⇋",RightAngleBracket:"⟩",RightArrow:"→",RightArrowLeftArrow:"⇄",RightCeiling:"⌉",RightDownVector:"⇂",RightFloor:"⌋",RightTee:"⊢",RightTeeArrow:"↦",RightTriangle:"⊳",RightTriangleEqual:"⊵",RightUpVector:"↾",RightVector:"⇀",Rightarrow:"⇒",Rrightarrow:"⇛",Rsh:"↱",Sigma:"Σ",SmallCircle:"∘",Sqrt:"√",Square:"□",SquareIntersection:"⊓",SquareSubset:"⊏",SquareSubsetEqual:"⊑",SquareSuperset:"⊐",SquareSupersetEqual:"⊒",SquareUnion:"⊔",Star:"⋆",Subset:"⋐",SubsetEqual:"⊆",Succeeds:"≻",SucceedsEqual:"⪰",SucceedsSlantEqual:"≽",SucceedsTilde:"≿",SuchThat:"∋",Sum:"∑",Superset:"⊃",SupersetEqual:"⊇",Supset:"⋑",Therefore:"∴",Theta:"Θ",Tilde:"∼",TildeEqual:"≃",TildeFullEqual:"≅",TildeTilde:"≈",UnderBar:"_",UnderBrace:"⏟",Union:"⋃",UnionPlus:"⊎",UpArrow:"↑",UpDownArrow:"↕",UpTee:"⊥",Uparrow:"⇑",Updownarrow:"⇕",Upsilon:"Υ",Vdash:"⊩",Vee:"⋁",VerticalBar:"∣",VerticalTilde:"≀",Vvdash:"⊪",Wedge:"⋀",Xi:"Ξ",amp:"&",acute:"´",aleph:"ℵ",alpha:"α",amalg:"⨿",and:"∧",ang:"∠",angmsd:"∡",angsph:"∢",ape:"≊",backprime:"‵",backsim:"∽",backsimeq:"⋍",beta:"β",beth:"ℶ",between:"≬",bigcirc:"◯",bigodot:"⨀",bigoplus:"⨁",bigotimes:"⨂",bigsqcup:"⨆",bigstar:"★",bigtriangledown:"▽",bigtriangleup:"△",biguplus:"⨄",blacklozenge:"⧫",blacktriangle:"▴",blacktriangledown:"▾",blacktriangleleft:"◂",bowtie:"⋈",boxdl:"┐",boxdr:"┌",boxminus:"⊟",boxplus:"⊞",boxtimes:"⊠",boxul:"┘",boxur:"└",bsol:"\\",bull:"•",cap:"∩",check:"✓",chi:"χ",circ:"ˆ",circeq:"≗",circlearrowleft:"↺",circlearrowright:"↻",circledR:"®",circledS:"Ⓢ",circledast:"⊛",circledcirc:"⊚",circleddash:"⊝",clubs:"♣",colon:":",comp:"∁",ctdot:"⋯",cuepr:"⋞",cuesc:"⋟",cularr:"↶",cup:"∪",curarr:"↷",curlyvee:"⋎",curlywedge:"⋏",dagger:"†",daleth:"ℸ",ddarr:"⇊",deg:"°",delta:"δ",digamma:"ϝ",div:"÷",divideontimes:"⋇",dot:"˙",doteqdot:"≑",dotplus:"∔",dotsquare:"⊡",dtdot:"⋱",ecir:"≖",efDot:"≒",egs:"⪖",ell:"ℓ",els:"⪕",empty:"∅",epsi:"ε",epsiv:"ϵ",erDot:"≓",eta:"η",eth:"ð",flat:"♭",fork:"⋔",frown:"⌢",gEl:"⪌",gamma:"γ",gap:"⪆",gimel:"ℷ",gnE:"≩",gnap:"⪊",gne:"⪈",gnsim:"⋧",gt:">",gtdot:"⋗",harrw:"↭",hbar:"ℏ",hellip:"…",hookleftarrow:"↩",hookrightarrow:"↪",imath:"ı",infin:"∞",intcal:"⊺",iota:"ι",jmath:"ȷ",kappa:"κ",kappav:"ϰ",lEg:"⪋",lambda:"λ",lap:"⪅",larrlp:"↫",larrtl:"↢",lbrace:"{",lbrack:"[",le:"≤",leftleftarrows:"⇇",leftthreetimes:"⋋",lessdot:"⋖",lmoust:"⎰",lnE:"≨",lnap:"⪉",lne:"⪇",lnsim:"⋦",longmapsto:"⟼",looparrowright:"↬",lowast:"∗",loz:"◊",lt:"<",ltimes:"⋉",ltri:"◃",macr:"¯",malt:"✠",mho:"℧",mu:"μ",multimap:"⊸",nLeftarrow:"⇍",nLeftrightarrow:"⇎",nRightarrow:"⇏",nVDash:"⊯",nVdash:"⊮",natur:"♮",nearr:"↗",nharr:"↮",nlarr:"↚",not:"¬",nrarr:"↛",nu:"ν",nvDash:"⊭",nvdash:"⊬",nwarr:"↖",omega:"ω",omicron:"ο",or:"∨",osol:"⊘",period:".",phi:"φ",phiv:"ϕ",pi:"π",piv:"ϖ",prap:"⪷",precnapprox:"⪹",precneqq:"⪵",precnsim:"⋨",prime:"′",psi:"ψ",quot:'"',rarrtl:"↣",rbrace:"}",rbrack:"]",rho:"ρ",rhov:"ϱ",rightrightarrows:"⇉",rightthreetimes:"⋌",ring:"˚",rmoust:"⎱",rtimes:"⋊",rtri:"▹",scap:"⪸",scnE:"⪶",scnap:"⪺",scnsim:"⋩",sdot:"⋅",searr:"↘",sect:"§",sharp:"♯",sigma:"σ",sigmav:"ς",simne:"≆",smile:"⌣",spades:"♠",sub:"⊂",subE:"⫅",subnE:"⫋",subne:"⊊",supE:"⫆",supnE:"⫌",supne:"⊋",swarr:"↙",tau:"τ",theta:"θ",thetav:"ϑ",tilde:"˜",times:"×",triangle:"▵",triangleq:"≜",upsi:"υ",upuparrows:"⇈",veebar:"⊻",vellip:"⋮",weierp:"℘",xi:"ξ",yen:"¥",zeta:"ζ",zigrarr:"⇝",nbsp:" ",rsquo:"’",lsquo:"‘"};var o={};function a(e,n){if("#"===n.charAt(0))return s(n.slice(1));if(t.entities[n])return t.entities[n];if(t.options.loadMissingEntities){var a=n.match(/^[a-zA-Z](fr|scr|opf)$/)?RegExp.$1:n.charAt(0).toLowerCase();o[a]||(o[a]=!0,r.retryAfter(i.asyncLoad("./util/entities/"+a+".js")))}return e}function s(e){var t="x"===e.charAt(0)?parseInt(e.slice(1),16):parseInt(e);return String.fromCodePoint(t)}t.add=function(e,n){Object.assign(t.entities,e),o[n]=!0},t.remove=function(e){delete t.entities[e]},t.translate=function(e){return e.replace(/&([a-z][a-z0-9]*|#(?:[0-9]+|x[0-9a-f]+));/gi,a)},t.numeric=s},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.SubHandlers=t.SubHandler=t.MapHandler=void 0;var o,a=n(108),s=n(133);!function(e){var t=new Map;e.register=function(e){t.set(e.name,e)},e.getMap=function(e){return t.get(e)}}(o=t.MapHandler||(t.MapHandler={}));var l=function(){function e(){this._configuration=new a.PrioritizedList,this._fallback=new s.FunctionList}return e.prototype.add=function(e,t,n){var i,s;void 0===n&&(n=a.PrioritizedList.DEFAULTPRIORITY);try{for(var l=r(e.slice().reverse()),c=l.next();!c.done;c=l.next()){var u=c.value,d=o.getMap(u);if(!d)return void this.warn("Configuration "+u+" not found! Omitted.");this._configuration.add(d,n)}}catch(e){i={error:e}}finally{try{c&&!c.done&&(s=l.return)&&s.call(l)}finally{if(i)throw i.error}}t&&this._fallback.add(t,n)},e.prototype.parse=function(e){var t,n;try{for(var o=r(this._configuration),a=o.next();!a.done;a=o.next()){var s=a.value.item.parse(e);if(s)return s}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}var l=i(e,2),c=l[0],u=l[1];Array.from(this._fallback)[0].item(c,u)},e.prototype.lookup=function(e){var t=this.applicable(e);return t?t.lookup(e):null},e.prototype.contains=function(e){return!!this.applicable(e)},e.prototype.toString=function(){var e,t,n=[];try{for(var i=r(this._configuration),o=i.next();!o.done;o=i.next()){var a=o.value.item;n.push(a.name)}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return n.join(", ")},e.prototype.applicable=function(e){var t,n;try{for(var i=r(this._configuration),o=i.next();!o.done;o=i.next()){var a=o.value.item;if(a.contains(e))return a}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}return null},e.prototype.retrieve=function(e){var t,n;try{for(var i=r(this._configuration),o=i.next();!o.done;o=i.next()){var a=o.value.item;if(a.name===e)return a}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}return null},e.prototype.warn=function(e){console.log("TexParser Warning: "+e)},e}();t.SubHandler=l;var c=function(){function e(){this.map=new Map}return e.prototype.add=function(e,t,n){var i,o;void 0===n&&(n=a.PrioritizedList.DEFAULTPRIORITY);try{for(var s=r(Object.keys(e)),c=s.next();!c.done;c=s.next()){var u=c.value,d=this.get(u);d||(d=new l,this.set(u,d)),d.add(e[u],t[u],n)}}catch(e){i={error:e}}finally{try{c&&!c.done&&(o=s.return)&&o.call(s)}finally{if(i)throw i.error}}},e.prototype.set=function(e,t){this.map.set(e,t)},e.prototype.get=function(e){return this.map.get(e)},e.prototype.retrieve=function(e){var t,n;try{for(var i=r(this.map.values()),o=i.next();!o.done;o=i.next()){var a=o.value.retrieve(e);if(a)return a}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}return null},e.prototype.keys=function(){return this.map.keys()},e}();t.SubHandlers=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r,i=n(37),o=n(31),a=n(96);!function(e){function t(e,t){return e.string.substr(e.i,t.length)!==t||t.match(/\\[a-z]+$/i)&&e.string.charAt(e.i+t.length).match(/[a-z]/i)?0:(e.i+=t.length,1)}e.disassembleSymbol=function(e,t){var n=[e,t.char];if(t.attributes)for(var r in t.attributes)n.push(r),n.push(t.attributes[r]);return n},e.assembleSymbol=function(e){for(var t=e[0],n=e[1],r={},i=2;i<e.length;i+=2)r[e[i]]=e[i+1];return new a.Symbol(t,n,r)},e.GetCSname=function(e,t){if("\\"!==e.GetNext())throw new o.default("MissingCS","%1 must be followed by a control sequence",t);return i.default.trimSpaces(e.GetArgument(t)).substr(1)},e.GetCsNameArgument=function(e,t){var n=i.default.trimSpaces(e.GetArgument(t));if("\\"===n.charAt(0)&&(n=n.substr(1)),!n.match(/^(.|[a-z]+)$/i))throw new o.default("IllegalControlSequenceName","Illegal control sequence name for %1",t);return n},e.GetArgCount=function(e,t){var n=e.GetBrackets(t);if(n&&!(n=i.default.trimSpaces(n)).match(/^[0-9]+$/))throw new o.default("IllegalParamNumber","Illegal number of parameters specified in %1",t);return n},e.GetTemplate=function(e,t,n){for(var r=e.GetNext(),i=[],a=0,s=e.i;e.i<e.string.length;){if("#"===(r=e.GetNext())){if(s!==e.i&&(i[a]=e.string.substr(s,e.i-s)),!(r=e.string.charAt(++e.i)).match(/^[1-9]$/))throw new o.default("CantUseHash2","Illegal use of # in template for %1",n);if(parseInt(r)!==++a)throw new o.default("SequentialParam","Parameters for %1 must be numbered sequentially",n);s=e.i+1}else if("{"===r)return s!==e.i&&(i[a]=e.string.substr(s,e.i-s)),i.length>0?[a.toString()].concat(i):a;e.i++}throw new o.default("MissingReplacementString","Missing replacement string for definition of %1",t)},e.GetParameter=function(e,n,r){if(null==r)return e.GetArgument(n);for(var i=e.i,a=0,s=0;e.i<e.string.length;){var l=e.string.charAt(e.i);if("{"===l)e.i===i&&(s=1),e.GetArgument(n),a=e.i-i;else{if(t(e,r))return s&&(i++,a-=2),e.string.substr(i,a);if("\\"===l){e.i++,a++,s=0;var c=e.string.substr(e.i).match(/[a-z]+|./i);c&&(e.i+=c[0].length,a=e.i-i)}else e.i++,a++,s=0}}throw new o.default("RunawayArgument","Runaway argument for %1?",n)},e.MatchParam=t,e.addDelimiter=function(t,n,r,i){t.configuration.handlers.retrieve(e.NEW_DELIMITER).add(n,new a.Symbol(n,r,i))},e.addMacro=function(t,n,r,i,o){void 0===o&&(o=""),t.configuration.handlers.retrieve(e.NEW_COMMAND).add(n,new a.Macro(o||n,r,i))},e.addEnvironment=function(t,n,r,i){t.configuration.handlers.retrieve(e.NEW_ENVIRONMENT).add(n,new a.Macro(n,r,i))},e.NEW_DELIMITER="new-Delimiter",e.NEW_COMMAND="new-Command",e.NEW_ENVIRONMENT="new-Environment"}(r||(r={})),t.default=r},function(e,t,n){"use strict";n.r(t),n.d(t,"FocusStyleManager",(function(){return c})),n.d(t,"AbstractComponent",(function(){return p})),n.d(t,"AbstractComponent2",(function(){return f})),n.d(t,"AbstractPureComponent",(function(){return m})),n.d(t,"AbstractPureComponent2",(function(){return g})),n.d(t,"Alignment",(function(){return v.a})),n.d(t,"Boundary",(function(){return y})),n.d(t,"Colors",(function(){return b})),n.d(t,"Elevation",(function(){return M.a})),n.d(t,"Intent",(function(){return w.a})),n.d(t,"Position",(function(){return A.a})),n.d(t,"isPositionHorizontal",(function(){return A.c})),n.d(t,"isPositionVertical",(function(){return A.d})),n.d(t,"getPositionIgnoreAngles",(function(){return A.b})),n.d(t,"DISPLAYNAME_PREFIX",(function(){return C})),n.d(t,"removeNonHTMLProps",(function(){return E})),n.d(t,"isRefObject",(function(){return L})),n.d(t,"isRefCallback",(function(){return S})),n.d(t,"setRef",(function(){return T})),n.d(t,"combineRefs",(function(){return O})),n.d(t,"mergeRefs",(function(){return I})),n.d(t,"getRef",(function(){return k})),n.d(t,"refHandler",(function(){return D})),n.d(t,"Classes",(function(){return a})),n.d(t,"Keys",(function(){return r})),n.d(t,"Utils",(function(){return i})),n.d(t,"ContextMenu",(function(){return pi})),n.d(t,"Alert",(function(){return Xt})),n.d(t,"Breadcrumb",(function(){return Jt})),n.d(t,"Breadcrumbs",(function(){return an})),n.d(t,"Button",(function(){return kt})),n.d(t,"AnchorButton",(function(){return Dt})),n.d(t,"ButtonGroup",(function(){return sn})),n.d(t,"Callout",(function(){return ln})),n.d(t,"Card",(function(){return cn})),n.d(t,"AnimationStates",(function(){return rn})),n.d(t,"Collapse",(function(){return un})),n.d(t,"CollapsibleList",(function(){return dn})),n.d(t,"ContextMenuTarget",(function(){return hn})),n.d(t,"Dialog",(function(){return Kt})),n.d(t,"MultistepDialog",(function(){return fn})),n.d(t,"DialogStep",(function(){return pn})),n.d(t,"Divider",(function(){return vn})),n.d(t,"DrawerSize",(function(){return gn})),n.d(t,"Drawer",(function(){return yn})),n.d(t,"EditableText",(function(){return wn})),n.d(t,"ControlGroup",(function(){return xn})),n.d(t,"Switch",(function(){return Ln})),n.d(t,"Radio",(function(){return Sn})),n.d(t,"Checkbox",(function(){return Tn})),n.d(t,"FileInput",(function(){return On})),n.d(t,"FormGroup",(function(){return In})),n.d(t,"InputGroup",(function(){return Dn})),n.d(t,"NumericInput",(function(){return Yn})),n.d(t,"RadioGroup",(function(){return Wn})),n.d(t,"TextArea",(function(){return Gn})),n.d(t,"H1",(function(){return Pt})),n.d(t,"H2",(function(){return zt})),n.d(t,"H3",(function(){return Rt})),n.d(t,"H4",(function(){return Bt})),n.d(t,"H5",(function(){return Ht})),n.d(t,"H6",(function(){return Ft})),n.d(t,"Blockquote",(function(){return Yt})),n.d(t,"Code",(function(){return Vt})),n.d(t,"Pre",(function(){return Ut})),n.d(t,"Label",(function(){return Wt})),n.d(t,"OL",(function(){return Gt})),n.d(t,"UL",(function(){return qt})),n.d(t,"HTMLSelect",(function(){return qn})),n.d(t,"HTMLTable",(function(){return Kn})),n.d(t,"Hotkeys",(function(){return cr})),n.d(t,"Hotkey",(function(){return lr})),n.d(t,"KeyCombo",(function(){return sr})),n.d(t,"HotkeysTarget",(function(){return gr})),n.d(t,"comboMatches",(function(){return tr})),n.d(t,"getKeyCombo",(function(){return ir})),n.d(t,"getKeyComboString",(function(){return rr})),n.d(t,"parseKeyCombo",(function(){return nr})),n.d(t,"hideHotkeysDialog",(function(){return pr})),n.d(t,"setHotkeysDialogProps",(function(){return hr})),n.d(t,"HotkeysDialog2",(function(){return yr})),n.d(t,"HotkeysTarget2",(function(){return xr})),n.d(t,"IconSize",(function(){return Ct})),n.d(t,"Icon",(function(){return Lt})),n.d(t,"Menu",(function(){return nn})),n.d(t,"MenuDivider",(function(){return Qt})),n.d(t,"MenuItem",(function(){return $t})),n.d(t,"Navbar",(function(){return Tr})),n.d(t,"NavbarDivider",(function(){return Er})),n.d(t,"NavbarGroup",(function(){return Lr})),n.d(t,"NavbarHeading",(function(){return Sr})),n.d(t,"NonIdealState",(function(){return Or})),n.d(t,"OverflowDirection",(function(){return jt})),n.d(t,"OverflowList",(function(){return on})),n.d(t,"Overlay",(function(){return tt})),n.d(t,"Text",(function(){return Zt})),n.d(t,"PanelStack",(function(){return kr})),n.d(t,"PanelStack2",(function(){return Nr})),n.d(t,"PopoverInteractionKind",(function(){return gt})),n.d(t,"Popover",(function(){return vt})),n.d(t,"PopoverPosition",(function(){return jr})),n.d(t,"Portal",(function(){return $e})),n.d(t,"ProgressBar",(function(){return Pr})),n.d(t,"ResizeSensor",(function(){return rt})),n.d(t,"HandleType",(function(){return zr})),n.d(t,"HandleInteractionKind",(function(){return Rr})),n.d(t,"MultiSlider",(function(){return Wr})),n.d(t,"RangeSlider",(function(){return Xr})),n.d(t,"Slider",(function(){return Jr})),n.d(t,"SpinnerSize",(function(){return Et})),n.d(t,"Spinner",(function(){return Ot})),n.d(t,"Tab",(function(){return Qr})),n.d(t,"Expander",(function(){return ti})),n.d(t,"Tabs",(function(){return ri})),n.d(t,"Tag",(function(){return ai})),n.d(t,"TagInput",(function(){return si})),n.d(t,"Toast",(function(){return li})),n.d(t,"Toaster",(function(){return ci})),n.d(t,"OverlayToaster",(function(){return ui})),n.d(t,"Tooltip",(function(){return it})),n.d(t,"Tree",(function(){return hi})),n.d(t,"TreeNode",(function(){return di})),n.d(t,"HotkeysContext",(function(){return br})),n.d(t,"HotkeysProvider",(function(){return wr})),n.d(t,"useHotkeys",(function(){return Ar}));var r={};n.r(r),n.d(r,"BACKSPACE",(function(){return N})),n.d(r,"TAB",(function(){return j})),n.d(r,"ENTER",(function(){return P})),n.d(r,"SHIFT",(function(){return z})),n.d(r,"ESCAPE",(function(){return R})),n.d(r,"SPACE",(function(){return B})),n.d(r,"ARROW_LEFT",(function(){return H})),n.d(r,"ARROW_UP",(function(){return F})),n.d(r,"ARROW_RIGHT",(function(){return Y})),n.d(r,"ARROW_DOWN",(function(){return V})),n.d(r,"DELETE",(function(){return U})),n.d(r,"isKeyboardClick",(function(){return W}));var i={};n.r(i),n.d(i,"arraysEqual",(function(){return G})),n.d(i,"shallowCompareKeys",(function(){return q})),n.d(i,"deepCompareKeys",(function(){return K})),n.d(i,"getDeepUnequalKeyValues",(function(){return X})),n.d(i,"elementIsOrContains",(function(){return re})),n.d(i,"throttleEvent",(function(){return ie})),n.d(i,"throttleReactEventCallback",(function(){return oe})),n.d(i,"throttle",(function(){return ae})),n.d(i,"isFunction",(function(){return ee})),n.d(i,"safeInvoke",(function(){return te})),n.d(i,"safeInvokeOrValue",(function(){return ne})),n.d(i,"isNodeEnv",(function(){return h.e})),n.d(i,"arrayLengthCompare",(function(){return h.b})),n.d(i,"approxEqual",(function(){return h.a})),n.d(i,"clamp",(function(){return h.c})),n.d(i,"countDecimalPlaces",(function(){return h.d})),n.d(i,"uniqueId",(function(){return h.f})),n.d(i,"isReactNodeEmpty",(function(){return le})),n.d(i,"isReactChildrenElementOrElements",(function(){return ce})),n.d(i,"ensureElement",(function(){return ue})),n.d(i,"getDisplayName",(function(){return de})),n.d(i,"isElementOfType",(function(){return he})),n.d(i,"createReactRef",(function(){return pe})),n.d(i,"safeInvokeMember",(function(){return fe})),n.d(i,"isDarkTheme",(function(){return me})),n.d(i,"setRef",(function(){return T})),n.d(i,"getRef",(function(){return k}));var o={};n.r(o),n.d(o,"show",(function(){return bt})),n.d(o,"hide",(function(){return Mt})),n.d(o,"isOpen",(function(){return wt}));var a=n(18),s=function(){function e(e,t){var n=this;this.container=e,this.className=t,this.isRunning=!1,this.handleKeyDown=function(e){9===e.which&&(n.reset(),n.container.addEventListener("mousedown",n.handleMouseDown))},this.handleMouseDown=function(){n.reset(),n.container.classList.add(n.className),n.container.addEventListener("keydown",n.handleKeyDown)}}return e.prototype.isActive=function(){return this.isRunning},e.prototype.start=function(){this.container.addEventListener("mousedown",this.handleMouseDown),this.isRunning=!0},e.prototype.stop=function(){this.reset(),this.isRunning=!1},e.prototype.reset=function(){this.container.classList.remove(this.className),this.container.removeEventListener("keydown",this.handleKeyDown),this.container.removeEventListener("mousedown",this.handleMouseDown)},e}(),l="undefined"!=typeof document?new s(document.documentElement,a.FOCUS_DISABLED):{isActive:function(){return!0},start:function(){return!0},stop:function(){return!0}},c={alwaysShowFocus:function(){return l.stop()},isActive:function(){return l.isActive()},onlyShowFocusOnTabs:function(){return l.start()}},u=n(1),d=n(0),h=n(387),p=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},Object(h.e)("production")||r.validateProps(r.props),r}return Object(u.__extends)(t,e),t.prototype.componentWillReceiveProps=function(e){Object(h.e)("production")||this.validateProps(e)},t.prototype.componentWillUnmount=function(){this.clearTimeouts()},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(d.Component),f=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.requestIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},r.cancelAnimationFrames=function(){if(r.requestIds.length>0){for(var e=0,t=r.requestIds;e<t.length;e++){var n=t[e];window.cancelAnimationFrame(n)}r.requestIds=[]}},Object(h.e)("production")||r.validateProps(r.props),r}return Object(u.__extends)(t,e),t.prototype.componentDidUpdate=function(e,t,n){Object(h.e)("production")||this.validateProps(this.props)},t.prototype.componentWillUnmount=function(){this.clearTimeouts(),this.cancelAnimationFrames()},t.prototype.requestAnimationFrame=function(e){var t=window.requestAnimationFrame(e);return this.requestIds.push(t),function(){return window.cancelAnimationFrame(t)}},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(d.Component),m=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},Object(h.e)("production")||r.validateProps(r.props),r}return Object(u.__extends)(t,e),t.prototype.componentWillReceiveProps=function(e){Object(h.e)("production")||this.validateProps(e)},t.prototype.componentWillUnmount=function(){this.clearTimeouts()},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(d.PureComponent),g=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.requestIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},r.cancelAnimationFrames=function(){if(r.requestIds.length>0){for(var e=0,t=r.requestIds;e<t.length;e++){var n=t[e];window.cancelAnimationFrame(n)}r.requestIds=[]}},Object(h.e)("production")||r.validateProps(r.props),r}return Object(u.__extends)(t,e),t.prototype.componentDidUpdate=function(e,t,n){Object(h.e)("production")||this.validateProps(this.props)},t.prototype.componentWillUnmount=function(){this.clearTimeouts(),this.cancelAnimationFrames()},t.prototype.requestAnimationFrame=function(e){var t=window.requestAnimationFrame(e);return this.requestIds.push(t),function(){return window.cancelAnimationFrame(t)}},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(d.PureComponent),v=n(113),y={START:"start",END:"end"},_=n(81),b=Object(u.__assign)(Object(u.__assign)({},_.LegacyColors),{CERULEAN1:_.LegacyColors.COBALT1,CERULEAN2:_.LegacyColors.COBALT2,CERULEAN3:_.LegacyColors.COBALT3,CERULEAN4:_.LegacyColors.COBALT4,CERULEAN5:_.LegacyColors.COBALT5}),M=n(79),w=n(80),A=n(33),C="Blueprint3",x=["active","alignText","asyncControl","containerRef","current","elementRef","fill","icon","inputRef","intent","inline","large","loading","leftElement","leftIcon","minimal","onRemove","outlined","panel","panelClassName","popoverProps","rightElement","rightIcon","round","small","text"];function E(e,t,n){return void 0===t&&(t=x),void 0===n&&(n=!1),n&&(t=t.concat(x)),t.reduce((function(e,t){return-1!==t.indexOf("-")||e.hasOwnProperty(t)&&delete e[t],e}),Object(u.__assign)({},e))}function L(e){return null!=e&&"function"!=typeof e}function S(e){return"function"==typeof e}function T(e,t){L(e)?e.current=t:S(e)&&e(t)}function O(e,t){return I(e,t)}function I(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){e.forEach((function(e){T(e,t)}))}}function k(e){var t;return null===e?null:null!==(t=e.current)&&void 0!==t?t:e}function D(e,t,n){return function(r){e[t]=r,T(n,r)}}var N=8,j=9,P=13,z=16,R=27,B=32,H=37,F=38,Y=39,V=40,U=46;function W(e){return e===P||e===B}function G(e,t,n){return void 0===n&&(n=function(e,t){return e===t}),null==e&&null==t||null!=e&&null!=t&&e.length===t.length&&e.every((function(e,r){return n(e,t[r])}))}function q(e,t,n){if(null==e&&null==t)return!0;if(null==e||null==t)return!1;if(Array.isArray(e)||Array.isArray(t))return!1;if(null!=n)return J(e,t,n);var r=Object.keys(e),i=Object.keys(t);return J(e,t,{include:r})&&J(e,t,{include:i})}function K(e,t,n){if(e===t)return!0;if(null==e&&null==t)return!0;if(null==e||null==t)return!1;if(Array.isArray(e)||Array.isArray(t))return G(e,t,K);if(Z(e)||Z(t))return e===t;if(null!=n)return Q(e,t,n);if(e.constructor!==t.constructor)return!1;var r=Object.keys(e),i=Object.keys(t);return null!=r&&null!=i&&(0===r.length&&0===i.length||G(r,i)&&Q(e,t,r))}function X(e,t,n){return void 0===e&&(e={}),void 0===t&&(t={}),function(e,t,n,r){return n.filter((function(n){return!r(e,t,n)})).map((function(n){return{key:n,valueA:e[n],valueB:t[n]}}))}(e,t,null==n?function(e,t){var n=Object.keys(e),r=Object.keys(t),i=$(n.concat(r));return Object.keys(i)}(e,t):n,(function(e,t,n){return K(e,t,[n])}))}function J(e,t,n){return function(e,t,n){if(function(e){return null!=e&&null!=e.include}(n))return n.include;if(function(e){return null!=e&&null!=e.exclude}(n)){var r=Object.keys(e),i=Object.keys(t),o=$(r.concat(i));return n.exclude.forEach((function(e){return delete o[e]})),Object.keys(o)}return[]}(e,t,n).every((function(n){return e.hasOwnProperty(n)===t.hasOwnProperty(n)&&e[n]===t[n]}))}function Q(e,t,n){return n.every((function(n){return e.hasOwnProperty(n)===t.hasOwnProperty(n)&&K(e[n],t[n])}))}function Z(e){return"number"==typeof e||"string"==typeof e||"boolean"==typeof e}function $(e){return e.reduce((function(e,t){return e[t]=!0,e}),{})}function ee(e){return"function"==typeof e}function te(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(ee(e))return e.apply(void 0,t)}function ne(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return ee(e)?e.apply(void 0,t):e}function re(e,t){return e===t||e.contains(t)}function ie(e,t,n){var r=se((function(t){e.dispatchEvent(new CustomEvent(n,t))}));return e.addEventListener(t,r),r}function oe(e,t){return void 0===t&&(t={}),se(e,(function(e){t.preventDefault&&e.preventDefault()}),(function(e){return e.persist()}))}function ae(e){return se(e)}function se(e,t,n){var r=!1;return function(){for(var i=[],o=0;o<arguments.length;o++)i[o]=arguments[o];ee(t)&&t.apply(void 0,i),r||(r=!0,ee(n)&&n.apply(void 0,i),requestAnimationFrame((function(){e.apply(void 0,i),r=!1})))}}function le(e,t){return void 0===t&&(t=!1),null==e||""===e||!1===e||!t&&Array.isArray(e)&&(0===e.length||e.every((function(e){return le(e,!0)})))}function ce(e){return!le(e,!0)&&!0!==e}function ue(e,t){return void 0===t&&(t="span"),null==e||"boolean"==typeof e?void 0:"string"==typeof e?e.trim().length>0?d.createElement(t,{},e):void 0:"number"==typeof e||"symbol"==typeof e.type||Array.isArray(e)?d.createElement(t,{},e):function(e){return"object"==typeof e&&void 0!==e.type&&void 0!==e.props}(e)?e:void 0}function de(e){return e.displayName||e.name||"Unknown"}function he(e,t){return null!=e&&null!=e.type&&null!=e.type.displayName&&e.type.displayName===t.displayName}function pe(){return void 0!==d.createRef?d.createRef():{current:null}}function fe(e,t){for(var n=[],r=2;r<arguments.length;r++)n[r-2]=arguments[r];if(null!=e){var i=e[t];if(ee(i))return i.apply(void 0,n)}}function me(e){return null!=e&&e instanceof Element&&null!=e.closest("."+a.DARK)}"undefined"!=typeof window&&"undefined"!=typeof document&&n(380);var ge=n(5),ve=n.n(ge),ye=n(34),_e=n(9),be=n(89),Me=n.n(be),we=n(99),Ae=n.n(we),Ce=n(26),xe=n.n(Ce),Ee=n(44),Le=n.n(Ee),Se=n(193),Te=n.n(Se),Oe=n(198),Ie=n.n(Oe),ke=Ie()(),De=Ie()(),Ne=function(e){function t(){for(var t,n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return t=e.call.apply(e,[this].concat(r))||this,Le()(xe()(xe()(t)),"referenceNode",void 0),Le()(xe()(xe()(t)),"setReferenceNode",(function(e){e&&t.referenceNode!==e&&(t.referenceNode=e,t.forceUpdate())})),t}Ae()(t,e);var n=t.prototype;return n.componentWillUnmount=function(){this.referenceNode=null},n.render=function(){return d.createElement(ke.Provider,{value:this.referenceNode},d.createElement(De.Provider,{value:this.setReferenceNode},this.props.children))},t}(d.Component),je=function(e){return Array.isArray(e)?e[0]:e},Pe=function(e){if("function"==typeof e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return e.apply(void 0,n)}},ze=function(e,t){if("function"==typeof e)return Pe(e,t);null!=e&&(e.current=t)},Re=function(e){function t(){for(var t,n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return t=e.call.apply(e,[this].concat(r))||this,Le()(xe()(xe()(t)),"refHandler",(function(e){ze(t.props.innerRef,e),Pe(t.props.setReferenceNode,e)})),t}Ae()(t,e);var n=t.prototype;return n.componentWillUnmount=function(){ze(this.props.innerRef,null)},n.render=function(){return Te()(Boolean(this.props.setReferenceNode),"`Reference` should not be used outside of a `Manager` component."),je(this.props.children)({ref:this.refHandler})},t}(d.Component);function Be(e){return d.createElement(De.Consumer,null,(function(t){return d.createElement(Re,Me()({setReferenceNode:t},e))}))}var He=n(494),Fe=n.n(He),Ye=n(495),Ve=n.n(Ye),Ue=n(199),We={position:"absolute",top:0,left:0,opacity:0,pointerEvents:"none"},Ge={},qe=function(e){function t(){for(var t,n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return t=e.call.apply(e,[this].concat(r))||this,Le()(xe()(xe()(t)),"state",{data:void 0,placement:void 0}),Le()(xe()(xe()(t)),"popperInstance",void 0),Le()(xe()(xe()(t)),"popperNode",null),Le()(xe()(xe()(t)),"arrowNode",null),Le()(xe()(xe()(t)),"setPopperNode",(function(e){e&&t.popperNode!==e&&(ze(t.props.innerRef,e),t.popperNode=e,t.updatePopperInstance())})),Le()(xe()(xe()(t)),"setArrowNode",(function(e){t.arrowNode=e})),Le()(xe()(xe()(t)),"updateStateModifier",{enabled:!0,order:900,fn:function(e){var n=e.placement;return t.setState({data:e,placement:n}),e}}),Le()(xe()(xe()(t)),"getOptions",(function(){return{placement:t.props.placement,eventsEnabled:t.props.eventsEnabled,positionFixed:t.props.positionFixed,modifiers:Me()({},t.props.modifiers,{arrow:Me()({},t.props.modifiers&&t.props.modifiers.arrow,{enabled:!!t.arrowNode,element:t.arrowNode}),applyStyle:{enabled:!1},updateStateModifier:t.updateStateModifier})}})),Le()(xe()(xe()(t)),"getPopperStyle",(function(){return t.popperNode&&t.state.data?Me()({position:t.state.data.offsets.popper.position},t.state.data.styles):We})),Le()(xe()(xe()(t)),"getPopperPlacement",(function(){return t.state.data?t.state.placement:void 0})),Le()(xe()(xe()(t)),"getArrowStyle",(function(){return t.arrowNode&&t.state.data?t.state.data.arrowStyles:Ge})),Le()(xe()(xe()(t)),"getOutOfBoundariesState",(function(){return t.state.data?t.state.data.hide:void 0})),Le()(xe()(xe()(t)),"destroyPopperInstance",(function(){t.popperInstance&&(t.popperInstance.destroy(),t.popperInstance=null)})),Le()(xe()(xe()(t)),"updatePopperInstance",(function(){t.destroyPopperInstance();var e=xe()(xe()(t)).popperNode,n=t.props.referenceElement;n&&e&&(t.popperInstance=new Ue.a(n,e,t.getOptions()))})),Le()(xe()(xe()(t)),"scheduleUpdate",(function(){t.popperInstance&&t.popperInstance.scheduleUpdate()})),t}Ae()(t,e);var n=t.prototype;return n.componentDidUpdate=function(e,t){this.props.placement===e.placement&&this.props.referenceElement===e.referenceElement&&this.props.positionFixed===e.positionFixed&&Ve()(this.props.modifiers,e.modifiers,{strict:!0})?this.props.eventsEnabled!==e.eventsEnabled&&this.popperInstance&&(this.props.eventsEnabled?this.popperInstance.enableEventListeners():this.popperInstance.disableEventListeners()):this.updatePopperInstance(),t.placement!==this.state.placement&&this.scheduleUpdate()},n.componentWillUnmount=function(){ze(this.props.innerRef,null),this.destroyPopperInstance()},n.render=function(){return je(this.props.children)({ref:this.setPopperNode,style:this.getPopperStyle(),placement:this.getPopperPlacement(),outOfBoundaries:this.getOutOfBoundariesState(),scheduleUpdate:this.scheduleUpdate,arrowProps:{ref:this.setArrowNode,style:this.getArrowStyle()}})},t}(d.Component);Le()(qe,"defaultProps",{placement:"bottom",eventsEnabled:!0,referenceElement:void 0,positionFixed:!1});Ue.a.placements;function Ke(e){var t=e.referenceElement,n=Fe()(e,["referenceElement"]);return d.createElement(ke.Consumer,null,(function(e){return d.createElement(qe,Me()({referenceElement:void 0!==t?t:e},n))}))}var Xe=n(17),Je=n(63),Qe=!ee(ye.createPortal),Ze={blueprintPortalClassName:function(e,t){if(null!=e[t]&&"string"!=typeof e[t])return new Error(Xe.L)}},$e=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.context={},t.state={hasMounted:!1},t.portalElement=null,t}return Object(u.__extends)(t,e),t.prototype.render=function(){return Qe||"undefined"==typeof document||!this.state.hasMounted||null===this.portalElement?null:ye.createPortal(this.props.children,this.portalElement)},t.prototype.componentDidMount=function(){this.props.container&&(this.portalElement=this.createContainerElement(),this.props.container.appendChild(this.portalElement),this.setState({hasMounted:!0},this.props.onChildrenMount),Qe&&this.unstableRenderNoPortal())},t.prototype.componentDidUpdate=function(e){var t,n;null!=this.portalElement&&e.className!==this.props.className&&(t=this.portalElement.classList,null!=(n=e.className)&&""!==n&&t.remove.apply(t,n.split(" ")),et(this.portalElement.classList,this.props.className)),Qe&&this.unstableRenderNoPortal()},t.prototype.componentWillUnmount=function(){null!=this.portalElement&&(Qe&&ye.unmountComponentAtNode(this.portalElement),this.portalElement.remove())},t.prototype.createContainerElement=function(){var e=document.createElement("div");return e.classList.add(a.PORTAL),et(e.classList,this.props.className),null!=this.context&&et(e.classList,this.context.blueprintPortalClassName),e},t.prototype.unstableRenderNoPortal=function(){null!==this.portalElement&&ye.unstable_renderSubtreeIntoContainer(this,d.createElement("div",null,this.props.children),this.portalElement)},t.displayName=C+".Portal",t.contextTypes=Ze,t.defaultProps={container:"undefined"!=typeof document?document.body:void 0},t}(d.Component);function et(e,t){null!=t&&""!==t&&e.add.apply(e,t.split(" "))}var tt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.isAutoFocusing=!1,t.state={hasEverOpened:t.props.isOpen},t.containerElement=null,t.startFocusTrapElement=null,t.endFocusTrapElement=null,t.refHandlers={container:function(e){return t.containerElement=Object(ye.findDOMNode)(e)},endFocusTrap:function(e){return t.endFocusTrapElement=e},startFocusTrap:function(e){return t.startFocusTrapElement=e}},t.maybeRenderChild=function(e){if(ee(e)&&(e=e()),null==e)return null;var n="object"==typeof e?d.cloneElement(e,{className:ve()(e.props.className,a.OVERLAY_CONTENT)}):d.createElement("span",{className:a.OVERLAY_CONTENT},e),r=t.props,i=r.onOpening,o=r.onOpened,s=r.onClosing,l=r.transitionDuration,c=r.transitionName,u=Je.CSSTransition;return d.createElement(u,{classNames:c,onEntering:i,onEntered:o,onExiting:s,onExited:t.handleTransitionExited,timeout:l,addEndListener:t.handleTransitionAddEnd},n)},t.handleStartFocusTrapElementFocus=function(e){var n;t.props.enforceFocus&&!t.isAutoFocusing&&null!=e.relatedTarget&&t.containerElement.contains(e.relatedTarget)&&e.relatedTarget!==t.endFocusTrapElement&&(null===(n=t.endFocusTrapElement)||void 0===n||n.focus({preventScroll:!0}))},t.handleStartFocusTrapElementKeyDown=function(e){var n;if(t.props.enforceFocus&&e.shiftKey&&e.which===r.TAB){var i=t.getKeyboardFocusableElements().pop();null!=i?i.focus():null===(n=t.endFocusTrapElement)||void 0===n||n.focus({preventScroll:!0})}},t.handleEndFocusTrapElementFocus=function(e){var n,r;if(null!=e.relatedTarget&&t.containerElement.contains(e.relatedTarget)&&e.relatedTarget!==t.startFocusTrapElement){var i=t.getKeyboardFocusableElements().shift();t.isAutoFocusing||null==i||i===e.relatedTarget?null===(n=t.startFocusTrapElement)||void 0===n||n.focus({preventScroll:!0}):i.focus()}else{var o=t.getKeyboardFocusableElements().pop();null!=o?o.focus():null===(r=t.startFocusTrapElement)||void 0===r||r.focus({preventScroll:!0})}},t.handleTransitionExited=function(e){var n,r;t.props.shouldReturnFocusOnClose&&t.lastActiveElementBeforeOpened instanceof HTMLElement&&t.lastActiveElementBeforeOpened.focus(),null===(r=(n=t.props).onClosed)||void 0===r||r.call(n,e)},t.handleBackdropMouseDown=function(e){var n,r=t.props,i=r.backdropProps,o=r.canOutsideClickClose,a=r.enforceFocus,s=r.onClose;o&&(null==s||s(e)),a&&t.bringFocusInsideOverlay(),null===(n=null==i?void 0:i.onMouseDown)||void 0===n||n.call(i,e)},t.handleDocumentClick=function(e){var r=t.props,i=r.canOutsideClickClose,o=r.isOpen,a=r.onClose,s=e.composed?e.composedPath()[0]:e.target,l=n.openStack.indexOf(t),c=n.openStack.slice(l).some((function(e){var t=e.containerElement;return t&&t.contains(s)&&!t.isSameNode(s)}));o&&!c&&i&&(null==a||a(e))},t.handleDocumentFocus=function(e){var n=e.composed?e.composedPath()[0]:e.target;t.props.enforceFocus&&null!=t.containerElement&&n instanceof Node&&!t.containerElement.contains(n)&&(e.preventDefault(),e.stopImmediatePropagation(),t.bringFocusInsideOverlay())},t.handleKeyDown=function(e){var n=t.props,i=n.canEscapeKeyClose,o=n.onClose;e.which===r.ESCAPE&&i&&(null==o||o(e),e.preventDefault())},t.handleTransitionAddEnd=function(){},t}var n;return Object(u.__extends)(t,e),n=t,t.getDerivedStateFromProps=function(e){var t=e.isOpen;return t?{hasEverOpened:t}:null},t.prototype.render=function(){var e,t;if(this.props.lazy&&!this.state.hasEverOpened)return null;var n=this.props,r=n.autoFocus,i=n.children,o=n.className,s=n.enforceFocus,l=n.usePortal,c=n.isOpen,u=c&&null!==(t=d.Children.map(i,this.maybeRenderChild))&&void 0!==t?t:[],h=this.maybeRenderBackdrop();null!==h&&u.unshift(h),c&&(r||s)&&u.length>0&&(u.unshift(this.renderDummyElement("__start",{className:a.OVERLAY_START_FOCUS_TRAP,onFocus:this.handleStartFocusTrapElementFocus,onKeyDown:this.handleStartFocusTrapElementKeyDown,ref:this.refHandlers.startFocusTrap})),s&&u.push(this.renderDummyElement("__end",{className:a.OVERLAY_END_FOCUS_TRAP,onFocus:this.handleEndFocusTrapElementFocus,ref:this.refHandlers.endFocusTrap})));var p=ve()(a.OVERLAY,((e={})[a.OVERLAY_OPEN]=c,e[a.OVERLAY_INLINE]=!l,e),o),f=d.createElement(Je.TransitionGroup,{appear:!0,"aria-live":"polite",className:p,component:"div",onKeyDown:this.handleKeyDown,ref:this.refHandlers.container},u);return l?d.createElement($e,{className:this.props.portalClassName,container:this.props.portalContainer},f):f},t.prototype.componentDidMount=function(){this.props.isOpen&&this.overlayWillOpen()},t.prototype.componentDidUpdate=function(e){e.isOpen&&!this.props.isOpen?this.overlayWillClose():!e.isOpen&&this.props.isOpen&&this.overlayWillOpen()},t.prototype.componentWillUnmount=function(){this.overlayWillClose()},t.prototype.bringFocusInsideOverlay=function(){var e=this;return this.requestAnimationFrame((function(){var t;null!=e.containerElement&&null!=document.activeElement&&e.props.isOpen&&(!e.containerElement.contains(document.activeElement)&&(null===(t=e.startFocusTrapElement)||void 0===t||t.focus({preventScroll:!0}),e.isAutoFocusing=!1))}))},t.prototype.maybeRenderBackdrop=function(){var e=this.props,t=e.backdropClassName,n=e.backdropProps,r=e.hasBackdrop,i=e.isOpen,o=e.transitionDuration,s=e.transitionName;return r&&i?d.createElement(Je.CSSTransition,{classNames:s,key:"__backdrop",timeout:o,addEndListener:this.handleTransitionAddEnd},d.createElement("div",Object(u.__assign)({},n,{className:ve()(a.OVERLAY_BACKDROP,t,null==n?void 0:n.className),onMouseDown:this.handleBackdropMouseDown}))):null},t.prototype.renderDummyElement=function(e,t){var n=this.props,r=n.transitionDuration,i=n.transitionName;return d.createElement(Je.CSSTransition,{classNames:i,key:e,addEndListener:this.handleTransitionAddEnd,timeout:r,unmountOnExit:!0},d.createElement("div",Object(u.__assign)({tabIndex:0},t)))},t.prototype.getKeyboardFocusableElements=function(){return(null!==this.containerElement?Array.from(this.containerElement.querySelectorAll(['a[href]:not([tabindex="-1"])','button:not([disabled]):not([tabindex="-1"])','details:not([tabindex="-1"])','input:not([disabled]):not([tabindex="-1"])','select:not([disabled]):not([tabindex="-1"])','textarea:not([disabled]):not([tabindex="-1"])','[tabindex]:not([tabindex="-1"])'].join(","))):[]).filter((function(e){return!e.classList.contains(a.OVERLAY_START_FOCUS_TRAP)&&!e.classList.contains(a.OVERLAY_END_FOCUS_TRAP)}))},t.prototype.overlayWillClose=function(){document.removeEventListener("focus",this.handleDocumentFocus,!0),document.removeEventListener("mousedown",this.handleDocumentClick);var e=n.openStack,t=e.indexOf(this);if(-1!==t){if(e.splice(t,1),e.length>0){var r=n.getLastOpened();r.props.autoFocus&&r.props.enforceFocus&&(r.bringFocusInsideOverlay(),document.addEventListener("focus",r.handleDocumentFocus,!0))}0===e.filter((function(e){return e.props.usePortal&&e.props.hasBackdrop})).length&&document.body.classList.remove(a.OVERLAY_OPEN)}},t.prototype.overlayWillOpen=function(){var e=n.getLastOpened,t=n.openStack;t.length>0&&document.removeEventListener("focus",e().handleDocumentFocus,!0),t.push(this),this.props.autoFocus&&(this.isAutoFocusing=!0,this.bringFocusInsideOverlay()),this.props.enforceFocus&&document.addEventListener("focus",this.handleDocumentFocus,!0),this.props.canOutsideClickClose&&!this.props.hasBackdrop&&document.addEventListener("mousedown",this.handleDocumentClick),this.props.hasBackdrop&&this.props.usePortal&&document.body.classList.add(a.OVERLAY_OPEN),this.lastActiveElementBeforeOpened=document.activeElement},t.displayName=C+".Overlay",t.defaultProps={autoFocus:!0,backdropProps:{},canEscapeKeyClose:!0,canOutsideClickClose:!0,enforceFocus:!0,hasBackdrop:!0,isOpen:!1,lazy:!0,shouldReturnFocusOnClose:!0,transitionDuration:300,transitionName:a.OVERLAY,usePortal:!0},t.openStack=[],t.getLastOpened=function(){return n.openStack[n.openStack.length-1]},t=n=Object(u.__decorate)([_e.polyfill],t)}(g),nt=n(146),rt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.element=null,t.observer=new nt.a((function(e){var n,r;return null===(r=(n=t.props).onResize)||void 0===r?void 0:r.call(n,e)})),t}return Object(u.__extends)(t,e),t.prototype.render=function(){return d.Children.only(this.props.children)},t.prototype.componentDidMount=function(){this.observeElement()},t.prototype.componentDidUpdate=function(e){this.observeElement(this.props.observeParents!==e.observeParents)},t.prototype.componentWillUnmount=function(){this.observer.disconnect()},t.prototype.observeElement=function(e){void 0===e&&(e=!1);var t=this.getElement();if(t instanceof Element){if((t!==this.element||e)&&(this.observer.disconnect(),this.element=t,this.observer.observe(t),this.props.observeParents))for(var n=t.parentElement;null!=n;)this.observer.observe(n),n=n.parentElement}else this.observer.disconnect()},t.prototype.getElement=function(){try{return Object(ye.findDOMNode)(this)}catch(e){return null}},t.displayName=C+".ResizeSensor",t=Object(u.__decorate)([_e.polyfill],t)}(g),it=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.popover=null,t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this,n=this.props,r=n.children,i=n.intent,o=n.popoverClassName,s=Object(u.__rest)(n,["children","intent","popoverClassName"]),l=ve()(a.TOOLTIP,((e={})[a.MINIMAL]=this.props.minimal,e),a.intentClass(i),o);return d.createElement(vt,Object(u.__assign)({interactionKind:gt.HOVER_TARGET_ONLY,modifiers:{arrow:{enabled:!this.props.minimal}}},s,{autoFocus:!1,canEscapeKeyClose:!1,enforceFocus:!1,lazy:!0,popoverClassName:l,portalContainer:this.props.portalContainer,ref:function(e){return t.popover=e}}),r)},t.prototype.reposition=function(){null!=this.popover&&this.popover.reposition()},t.displayName=C+".Tooltip",t.defaultProps={hoverCloseDelay:0,hoverOpenDelay:100,minimal:!1,transitionDuration:100},t=Object(u.__decorate)([_e.polyfill],t)}(g);function ot(e){return e.split("-")[0]}function at(e){return-1!==["left","right"].indexOf(e)}function st(e){switch(e){case"top":return"bottom";case"left":return"right";case"bottom":return"top";default:return"left"}}function lt(e){switch(e.split("-")[1]){case"start":return"left";case"end":return"right";default:return"center"}}function ct(e){var t=ot(e.placement);if(null==e.arrowElement)return at(t)?st(t)+" "+lt(t):lt(t)+" "+st(t);var n=e.arrowElement.clientHeight/2,r=e.offsets.arrow;return at(t)?st(t)+" "+(r.top+n)+"px":r.left+n+"px "+st(t)}var ut=function(e){if(null==e.arrowElement)return e;var t=e.arrowElement.clientWidth,n=ot(e.placement),r=at(n),i=r?"width":"height",o=r?"left":"top",a=Math.round(t/2/Math.sqrt(2));return"top"===n||"left"===n?(e.offsets.popper[o]-=a+4,e.offsets.arrow[o]=e.offsets.popper[i]-t+a):(e.offsets.popper[o]+=a+4,e.offsets.arrow[o]=-a),e};function dt(e){if(null==e)return 0;switch(ot(e)){case"top":return-90;case"left":return 180;case"bottom":return 90;default:return 0}}var ht=function(e){var t=e.arrowProps,n=t.ref,r=t.style,i=e.placement;return d.createElement("div",{className:a.POPOVER_ARROW,ref:n,style:null==r.left||isNaN(+r.left)?{}:r},d.createElement("svg",{viewBox:"0 0 30 30",style:{transform:"rotate("+dt(i)+"deg)"}},d.createElement("path",{className:a.POPOVER_ARROW+"-border",d:"M8.11 6.302c1.015-.936 1.887-2.922 1.887-4.297v26c0-1.378-.868-3.357-1.888-4.297L.925 17.09c-1.237-1.14-1.233-3.034 0-4.17L8.11 6.302z"}),d.createElement("path",{className:a.POPOVER_ARROW+"-fill",d:"M8.787 7.036c1.22-1.125 2.21-3.376 2.21-5.03V0v30-2.005c0-1.654-.983-3.9-2.21-5.03l-7.183-6.616c-.81-.746-.802-1.96 0-2.7l7.183-6.614z"})))};function pt(e){switch(e){case A.a.TOP_LEFT:return"top-start";case A.a.TOP:return"top";case A.a.TOP_RIGHT:return"top-end";case A.a.RIGHT_TOP:return"right-start";case A.a.RIGHT:return"right";case A.a.RIGHT_BOTTOM:return"right-end";case A.a.BOTTOM_RIGHT:return"bottom-end";case A.a.BOTTOM:return"bottom";case A.a.BOTTOM_LEFT:return"bottom-start";case A.a.LEFT_BOTTOM:return"left-end";case A.a.LEFT:return"left";case A.a.LEFT_TOP:return"left-start";case"auto":case"auto-start":case"auto-end":return e;default:return function(e){throw new Error("Unexpected position: "+e)}(e)}}ht.displayName=C+".PopoverArrow";var ft,mt,gt={CLICK:"click",CLICK_TARGET_ONLY:"click-target",HOVER:"hover",HOVER_TARGET_ONLY:"hover-target"},vt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.popoverRef=pe(),t.popoverElement=null,t.targetElement=null,t.state={hasDarkParent:!1,isOpen:t.getIsOpen(t.props),transformOrigin:""},t.isMouseInTargetOrPopover=!1,t.lostFocusOnSamePage=!0,t.handlePopoverRef=D(t,"popoverElement",t.props.popoverRef),t.handleTargetRef=function(e){return t.targetElement=e},t.reposition=function(){var e;return null===(e=t.popperScheduleUpdate)||void 0===e?void 0:e.call(t)},t.renderPopover=function(e){var n,r=t.props,i=r.interactionKind,o=r.usePortal,s=t.state.transformOrigin;t.popperScheduleUpdate=e.scheduleUpdate;var l={onClick:t.handlePopoverClick};(i===gt.HOVER||!o&&i===gt.HOVER_TARGET_ONLY)&&(l.onMouseEnter=t.handleMouseEnter,l.onMouseLeave=t.handleMouseLeave);var c=ve()(a.POPOVER,((n={})[a.DARK]=t.props.inheritDarkTheme&&t.state.hasDarkParent,n[a.MINIMAL]=t.props.minimal,n[a.POPOVER_CAPTURING_DISMISS]=t.props.captureDismiss,n[a.POPOVER_OUT_OF_BOUNDARIES]=!0===e.outOfBoundaries,n),t.props.popoverClassName);return d.createElement("div",{className:a.TRANSITION_CONTAINER,ref:e.ref,style:e.style},d.createElement(rt,{onResize:t.reposition},d.createElement("div",Object(u.__assign)({className:c,style:{transformOrigin:s},ref:t.popoverRef},l),t.isArrowEnabled()&&d.createElement(ht,{arrowProps:e.arrowProps,placement:e.placement}),d.createElement("div",{className:a.POPOVER_CONTENT},t.understandChildren().content))))},t.renderTarget=function(e){var n,r,i=t.props,o=i.fill,s=i.openOnTargetFocus,l=i.targetClassName,c=i.targetProps,h=void 0===c?{}:c,p=t.state.isOpen,f=t.isControlled(),m=t.isHoverInteractionKind(),g=t.props.targetTagName;o&&(g="div");var v=m?{onBlur:t.handleTargetBlur,onFocus:t.handleTargetFocus,onMouseEnter:t.handleMouseEnter,onMouseLeave:t.handleMouseLeave}:{onClick:t.handleTargetClick};v["aria-haspopup"]="true",v.className=ve()(a.POPOVER_TARGET,((n={})[a.POPOVER_OPEN]=p,n),h.className,l),v.ref=e.ref;var y=ue(t.understandChildren().target);if(void 0===y)return null;var _=y.props.tabIndex,b=null==_&&s&&m?0:_,M=d.cloneElement(y,{className:ve()(y.props.className,(r={},r[a.ACTIVE]=p&&!f&&!m,r)),disabled:!(!p||!he(y,it))||y.props.disabled,tabIndex:b}),w=d.createElement(g,Object(u.__assign)(Object(u.__assign)({},h),v),M);return d.createElement(rt,{onResize:t.reposition},w)},t.isControlled=function(){return void 0!==t.props.isOpen},t.handleTargetFocus=function(e){var n,r;if(t.props.openOnTargetFocus&&t.isHoverInteractionKind()){if(null==e.relatedTarget&&!t.lostFocusOnSamePage)return;t.handleMouseEnter(e)}null===(r=null===(n=t.props.targetProps)||void 0===n?void 0:n.onFocus)||void 0===r||r.call(n,e)},t.handleTargetBlur=function(e){var n,r;t.props.openOnTargetFocus&&t.isHoverInteractionKind()&&(null==e.relatedTarget||t.isElementInPopover(e.relatedTarget)||t.handleMouseLeave(e)),t.lostFocusOnSamePage=null!=e.relatedTarget,null===(r=null===(n=t.props.targetProps)||void 0===n?void 0:n.onBlur)||void 0===r||r.call(n,e)},t.handleMouseEnter=function(e){var n,r;t.isMouseInTargetOrPopover=!0,t.props.usePortal||!t.isElementInPopover(e.target)||t.props.interactionKind!==gt.HOVER_TARGET_ONLY||t.props.openOnTargetFocus?t.props.disabled||t.setOpenState(!0,e,t.props.hoverOpenDelay):t.handleMouseLeave(e),null===(r=null===(n=t.props.targetProps)||void 0===n?void 0:n.onMouseEnter)||void 0===r||r.call(n,e)},t.handleMouseLeave=function(e){var n,r;t.isMouseInTargetOrPopover=!1,t.setTimeout((function(){t.isMouseInTargetOrPopover||t.setOpenState(!1,e,t.props.hoverCloseDelay)})),null===(r=null===(n=t.props.targetProps)||void 0===n?void 0:n.onMouseLeave)||void 0===r||r.call(n,e)},t.handlePopoverClick=function(e){var n=e.target,r=n.closest("."+a.POPOVER),i=r===t.popoverRef.current,o=null==r?void 0:r.classList.contains(a.POPOVER_CAPTURING_DISMISS),s=n.closest("."+a.POPOVER_DISMISS+", ."+a.POPOVER_DISMISS_OVERRIDE),l=null!=s&&s.classList.contains(a.POPOVER_DISMISS),c=null!=n.closest(":disabled, ."+a.DISABLED);!l||c||o&&!i||t.setOpenState(!1,e)},t.handleOverlayClose=function(e){if(null!==t.targetElement&&void 0!==e){var n=e.target;(!re(t.targetElement,n)||e.nativeEvent instanceof KeyboardEvent)&&t.setOpenState(!1,e)}},t.handleTargetClick=function(e){var n,r;t.props.disabled||t.isElementInPopover(e.target)||(null==t.props.isOpen?t.setState((function(e){return{isOpen:!e.isOpen}})):t.setOpenState(!t.props.isOpen,e)),null===(r=null===(n=t.props.targetProps)||void 0===n?void 0:n.onClick)||void 0===r||r.call(n,e)},t.updatePopoverState=function(e){return t.setState({transformOrigin:ct(e)}),e},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t,n=this.props,r=n.className,i=n.disabled,o=n.fill,s=n.placement,l=n.position,c=void 0===l?"auto":l,u=n.shouldReturnFocusOnClose,p=this.state.isOpen,f=this.props.wrapperTagName;o&&(f="div");var m=null==ue(this.understandChildren().content);!m||i||!1===p||h.e("production")||console.warn(Xe.G);var g=ve()(a.POPOVER_WRAPPER,r,((e={})[a.FILL]=o,e)),v=!this.isHoverInteractionKind()&&void 0,y=d.createElement(f,{className:g},d.createElement(Be,{innerRef:this.handleTargetRef},this.renderTarget),d.createElement(tt,{autoFocus:null!==(t=this.props.autoFocus)&&void 0!==t?t:v,backdropClassName:a.POPOVER_BACKDROP,backdropProps:this.props.backdropProps,canEscapeKeyClose:this.props.canEscapeKeyClose,canOutsideClickClose:this.props.interactionKind===gt.CLICK,className:this.props.portalClassName,enforceFocus:this.props.enforceFocus,hasBackdrop:this.props.hasBackdrop,isOpen:p&&!m,onClose:this.handleOverlayClose,onClosed:this.props.onClosed,onClosing:this.props.onClosing,onOpened:this.props.onOpened,onOpening:this.props.onOpening,transitionDuration:this.props.transitionDuration,transitionName:a.POPOVER,usePortal:this.props.usePortal,portalContainer:this.props.portalContainer,shouldReturnFocusOnClose:!this.isHoverInteractionKind()&&u},d.createElement(Ke,{innerRef:this.handlePopoverRef,placement:null!=s?s:pt(c),modifiers:this.getPopperModifiers()},this.renderPopover)));return d.createElement(Ne,null,y)},t.prototype.componentDidMount=function(){this.updateDarkParent()},t.prototype.componentDidUpdate=function(t,n){e.prototype.componentDidUpdate.call(this,t,n),t.popoverRef!==this.props.popoverRef&&(T(t.popoverRef,null),this.handlePopoverRef=D(this,"popoverElement",this.props.popoverRef),T(this.props.popoverRef,this.popoverElement)),this.updateDarkParent();var r=this.getIsOpen(this.props);null!=this.props.isOpen&&r!==this.state.isOpen?(this.setOpenState(r),this.setState({isOpen:r})):this.props.disabled&&this.state.isOpen&&null==this.props.isOpen&&this.setOpenState(!1)},t.prototype.validateProps=function(e){null==e.isOpen&&null!=e.onInteraction&&console.warn(Xe.K),e.hasBackdrop&&!e.usePortal&&console.warn(Xe.H),e.hasBackdrop&&e.interactionKind!==gt.CLICK&&console.error(Xe.C),void 0!==e.placement&&void 0!==e.position&&console.warn(Xe.I);var t=d.Children.count(e.children),n=void 0!==e.content,r=void 0!==e.target;0!==t||r||console.error(Xe.D),t>2&&console.warn(Xe.J),t>0&&r&&console.warn(Xe.F),2===t&&n&&console.warn(Xe.E)},t.prototype.updateDarkParent=function(){if(this.props.usePortal&&this.state.isOpen){var e=null!=this.targetElement&&null!=this.targetElement.closest("."+a.DARK);this.setState({hasDarkParent:e})}},t.prototype.understandChildren=function(){var e=this.props,t=e.children,n=e.content,r=e.target,i=d.Children.toArray(t),o=i[0],a=i[1];return{content:null==a?n:a,target:null==o?r:o}},t.prototype.getIsOpen=function(e){return!e.disabled&&(null!=e.isOpen?e.isOpen:e.defaultIsOpen)},t.prototype.getPopperModifiers=function(){var e=this.props,t=e.boundary,n=e.modifiers,r=n,i=r.flip,o=void 0===i?{}:i,a=r.preventOverflow,s=void 0===a?{}:a;return Object(u.__assign)(Object(u.__assign)({},n),{arrowOffset:{enabled:this.isArrowEnabled(),fn:ut,order:510},flip:Object(u.__assign)({boundariesElement:t},o),preventOverflow:Object(u.__assign)({boundariesElement:t},s),updatePopoverState:{enabled:!0,fn:this.updatePopoverState,order:900}})},t.prototype.setOpenState=function(e,t,n){var r,i,o,a,s,l=this;null===(r=this.cancelOpenTimeout)||void 0===r||r.call(this),void 0!==n&&n>0?this.cancelOpenTimeout=this.setTimeout((function(){return l.setOpenState(e,t)}),n):(null==this.props.isOpen?this.setState({isOpen:e}):null===(o=(i=this.props).onInteraction)||void 0===o||o.call(i,e,t),e||null===(s=(a=this.props).onClose)||void 0===s||s.call(a,t))},t.prototype.isArrowEnabled=function(){var e=this.props,t=e.minimal,n=e.modifiers;return!t&&(null==(null==n?void 0:n.arrow)||n.arrow.enabled)},t.prototype.isElementInPopover=function(e){var t;return null===(t=this.popoverElement)||void 0===t?void 0:t.contains(e)},t.prototype.isHoverInteractionKind=function(){return this.props.interactionKind===gt.HOVER||this.props.interactionKind===gt.HOVER_TARGET_ONLY},t.displayName=C+".Popover",t.defaultProps={boundary:"scrollParent",captureDismiss:!1,defaultIsOpen:!1,disabled:!1,fill:!1,hasBackdrop:!1,hoverCloseDelay:300,hoverOpenDelay:150,inheritDarkTheme:!0,interactionKind:gt.CLICK,minimal:!1,modifiers:{},openOnTargetFocus:!0,shouldReturnFocusOnClose:!1,targetTagName:"span",transitionDuration:300,usePortal:!0,wrapperTagName:"span"},t=Object(u.__decorate)([_e.polyfill],t)}(g),yt={preventOverflow:{boundariesElement:"viewport"}},_t=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={isDarkTheme:!1,isOpen:!1},t.cancelContextMenu=function(e){return e.preventDefault()},t.handleBackdropContextMenu=function(e){e.persist(),e.preventDefault(),t.setTimeout((function(){var t=document.elementFromPoint(e.clientX,e.clientY),n=(e.view,Object(u.__rest)(e,["view"]));null==t||t.dispatchEvent(new MouseEvent("contextmenu",n))}),100)},t.handlePopoverInteraction=function(e){e||t.requestAnimationFrame((function(){return t.hide()}))},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=d.createElement("div",{onContextMenu:this.cancelContextMenu},this.state.menu),n=ve()(((e={})[a.DARK]=this.state.isDarkTheme,e)),r=void 0===this.state.offset?"":this.state.offset.left+"x"+this.state.offset.top;return d.createElement("div",{className:a.CONTEXT_MENU_POPOVER_TARGET,style:this.state.offset},d.createElement(vt,Object(u.__assign)({},this.props,{backdropProps:{onContextMenu:this.handleBackdropContextMenu},content:t,enforceFocus:!1,key:r,hasBackdrop:!0,isOpen:this.state.isOpen,minimal:!0,modifiers:yt,onInteraction:this.handlePopoverInteraction,position:A.a.RIGHT_TOP,popoverClassName:n,target:d.createElement("div",null),transitionDuration:100})))},t.prototype.show=function(e,t,n,r){void 0===r&&(r=!1),this.setState({isOpen:!0,menu:e,offset:t,onClose:n,isDarkTheme:r})},t.prototype.hide=function(){var e,t;null===(t=(e=this.state).onClose)||void 0===t||t.call(e),this.setState({isOpen:!1,onClose:void 0})},t=Object(u.__decorate)([_e.polyfill],t)}(g);function bt(e,t,n,r){void 0===ft&&((ft=document.createElement("div")).classList.add(a.CONTEXT_MENU),document.body.appendChild(ft),mt=ye.render(d.createElement(_t,{onClosed:At}),ft)),mt.show(e,t,n,r)}function Mt(){null==mt||mt.hide()}function wt(){return null!=mt&&mt.state.isOpen}function At(){null!=ft&&(ye.unmountComponentAtNode(ft),ft.remove(),ft=void 0,mt=void 0)}var Ct,xt=n(173);!function(e){e[e.STANDARD=16]="STANDARD",e[e.LARGE=20]="LARGE"}(Ct||(Ct={}));var Et,Lt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props.icon;if(null==e||"boolean"==typeof e)return null;if("string"!=typeof e)return e;var t=this.props,n=t.className,r=t.color,i=t.htmlTitle,o=t.iconSize,s=t.intent,l=t.size,c=void 0===l?null!=o?o:Ct.STANDARD:l,h=t.title,p=t.tagName,f=void 0===p?"span":p,m=Object(u.__rest)(t,["className","color","htmlTitle","iconSize","intent","size","title","tagName"]),g=c>=Ct.LARGE?Ct.LARGE:Ct.STANDARD,v=this.renderSvgPaths(g,e),y=ve()(a.ICON,a.iconClass(e),a.intentClass(s),n),_="0 0 "+g+" "+g;return d.createElement(f,Object(u.__assign)(Object(u.__assign)({},m),{"aria-hidden":!h||void 0,className:y,title:i}),d.createElement("svg",{fill:r,"data-icon":e,width:c,height:c,viewBox:_},h&&d.createElement("desc",null,h),v))},t.prototype.renderSvgPaths=function(e,t){var n=(e===Ct.STANDARD?xt.a:xt.b)[t];return null==n?null:n.map((function(e,t){return d.createElement("path",{key:t,d:e,fillRule:"evenodd"})}))},t.displayName=C+".Icon",t.SIZE_STANDARD=Ct.STANDARD,t.SIZE_LARGE=Ct.LARGE,t=Object(u.__decorate)([_e.polyfill],t)}(g);!function(e){e[e.SMALL=20]="SMALL",e[e.STANDARD=50]="STANDARD",e[e.LARGE=100]="LARGE"}(Et||(Et={}));var St=45,Tt="M 50,50 m 0,-45 a 45,45 0 1 1 0,90 a 45,45 0 1 1 0,-90",Ot=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.componentDidUpdate=function(e){e.value!==this.props.value&&this.forceUpdate()},t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.intent,i=t.value,o=t.tagName,s=void 0===o?"div":o,l=this.getSize(),c=ve()(a.SPINNER,a.intentClass(r),((e={})[a.SPINNER_NO_SPIN]=null!=i,e),n),u=Math.min(16,4*Et.LARGE/l),p=280-280*(null==i?.25:Object(h.c)(i,0,1));return d.createElement(s,{className:c,role:"progressbar"},d.createElement(s,{className:a.SPINNER_ANIMATION},d.createElement("svg",{width:l,height:l,strokeWidth:u.toFixed(2),viewBox:this.getViewBox(u)},d.createElement("path",{className:a.SPINNER_TRACK,d:Tt}),d.createElement("path",{className:a.SPINNER_HEAD,d:Tt,pathLength:280,strokeDasharray:"280 280",strokeDashoffset:p}))))},t.prototype.validateProps=function(e){var t=e.className,n=void 0===t?"":t;null!=e.size&&(n.indexOf(a.SMALL)>=0||n.indexOf(a.LARGE)>=0)&&console.warn(Xe.Q)},t.prototype.getSize=function(){var e=this.props,t=e.className,n=void 0===t?"":t,r=e.size;return null==r?n.indexOf(a.SMALL)>=0?Et.SMALL:n.indexOf(a.LARGE)>=0?Et.LARGE:Et.STANDARD:Math.max(10,r)},t.prototype.getViewBox=function(e){var t=St+e/2,n=(50-t).toFixed(2),r=(2*t).toFixed(2);return n+" "+n+" "+r+" "+r},t.displayName=C+".Spinner",t.SIZE_SMALL=Et.SMALL,t.SIZE_STANDARD=Et.STANDARD,t.SIZE_LARGE=Et.LARGE,t=Object(u.__decorate)([_e.polyfill],t)}(g),It=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={isActive:!1},t.handleKeyDown=function(e){var n,i;r.isKeyboardClick(e.which)&&(e.preventDefault(),e.which!==t.currentKeyDown&&t.setState({isActive:!0})),t.currentKeyDown=e.which,null===(i=(n=t.props).onKeyDown)||void 0===i||i.call(n,e)},t.handleKeyUp=function(e){var n,i,o;r.isKeyboardClick(e.which)&&(t.setState({isActive:!1}),null===(n=t.buttonRef)||void 0===n||n.click()),t.currentKeyDown=void 0,null===(o=(i=t.props).onKeyUp)||void 0===o||o.call(i,e)},t.handleBlur=function(e){var n,r;t.state.isActive&&t.setState({isActive:!1}),null===(r=(n=t.props).onBlur)||void 0===r||r.call(n,e)},t}return Object(u.__extends)(t,e),t.prototype.getCommonButtonProps=function(){var e,t=this.props,n=t.active,r=t.alignText,i=t.fill,o=t.large,s=t.loading,l=t.outlined,c=t.minimal,u=t.small,d=t.tabIndex,h=this.props.disabled||s;return{className:ve()(a.BUTTON,((e={})[a.ACTIVE]=!h&&(n||this.state.isActive),e[a.DISABLED]=h,e[a.FILL]=i,e[a.LARGE]=o,e[a.LOADING]=s,e[a.MINIMAL]=c,e[a.OUTLINED]=l,e[a.SMALL]=u,e),a.alignmentClass(r),a.intentClass(this.props.intent),this.props.className),disabled:h,onBlur:this.handleBlur,onClick:h?void 0:this.props.onClick,onKeyDown:this.handleKeyDown,onKeyUp:this.handleKeyUp,tabIndex:h?-1:d}},t.prototype.renderChildren=function(){var e=this.props,t=e.children,n=e.icon,r=e.loading,o=e.rightIcon,s=e.text;return[r&&d.createElement(Ot,{key:"loading",className:a.BUTTON_SPINNER,size:Ct.LARGE}),d.createElement(Lt,{key:"leftIcon",icon:n}),(!i.isReactNodeEmpty(s)||!i.isReactNodeEmpty(t))&&d.createElement("span",{key:"text",className:a.BUTTON_TEXT},s,t),d.createElement(Lt,{key:"rightIcon",icon:o})]},t}(g),kt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buttonRef=null,t.handleRef=D(t,"buttonRef",t.props.elementRef),t}return Object(u.__extends)(t,e),t.prototype.render=function(){return d.createElement("button",Object(u.__assign)({type:"button",ref:this.handleRef},E(this.props),this.getCommonButtonProps()),this.renderChildren())},t.prototype.componentDidUpdate=function(e){e.elementRef!==this.props.elementRef&&(T(e.elementRef,null),this.handleRef=D(this,"buttonRef",this.props.elementRef),T(this.props.elementRef,this.buttonRef))},t.displayName=C+".Button",t}(It),Dt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buttonRef=null,t.handleRef=D(t,"buttonRef",t.props.elementRef),t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.href,n=e.tabIndex,r=void 0===n?0:n,i=this.getCommonButtonProps();return d.createElement("a",Object(u.__assign)({role:"button",ref:this.handleRef},E(this.props),i,{href:i.disabled?void 0:t,tabIndex:i.disabled?-1:r}),this.renderChildren())},t.prototype.componentDidUpdate=function(e){e.elementRef!==this.props.elementRef&&(T(e.elementRef,null),this.handleRef=D(this,"buttonRef",this.props.elementRef),T(this.props.elementRef,this.buttonRef))},t.displayName=C+".AnchorButton",t}(It);function Nt(e,t){return function(n){var r=n.className,i=n.elementRef,o=Object(u.__rest)(n,["className","elementRef"]);return d.createElement(e,Object(u.__assign)(Object(u.__assign)({},o),{className:ve()(t,r),ref:i}))}}var jt,Pt=Nt("h1",a.HEADING),zt=Nt("h2",a.HEADING),Rt=Nt("h3",a.HEADING),Bt=Nt("h4",a.HEADING),Ht=Nt("h5",a.HEADING),Ft=Nt("h6",a.HEADING),Yt=Nt("blockquote",a.BLOCKQUOTE),Vt=Nt("code",a.CODE),Ut=Nt("pre",a.CODE_BLOCK),Wt=Nt("label",a.LABEL),Gt=Nt("ol",a.LIST),qt=Nt("ul",a.LIST),Kt=function(e){function t(t){var n=e.call(this,t)||this,r=Object(h.f)("bp-dialog");return n.titleId="title-"+r,n}return Object(u.__extends)(t,e),t.prototype.render=function(){return d.createElement(tt,Object(u.__assign)({},this.props,{className:a.OVERLAY_SCROLL_CONTAINER,hasBackdrop:!0}),d.createElement("div",{className:a.DIALOG_CONTAINER},d.createElement("div",{className:ve()(a.DIALOG,this.props.className),role:"dialog","aria-labelledby":this.props["aria-labelledby"]||(this.props.title?this.titleId:void 0),"aria-describedby":this.props["aria-describedby"],style:this.props.style},this.maybeRenderHeader(),this.props.children)))},t.prototype.validateProps=function(e){null==e.title&&(null!=e.icon&&console.warn(Xe.i),null!=e.isCloseButtonShown&&console.warn(Xe.h))},t.prototype.maybeRenderCloseButton=function(){return!1!==this.props.isCloseButtonShown?d.createElement(kt,{"aria-label":"Close",className:a.DIALOG_CLOSE_BUTTON,icon:d.createElement(Lt,{icon:"small-cross",size:Ct.LARGE}),minimal:!0,onClick:this.props.onClose}):void 0},t.prototype.maybeRenderHeader=function(){var e=this.props,t=e.icon,n=e.title;if(null!=n)return d.createElement("div",{className:a.DIALOG_HEADER},d.createElement(Lt,{icon:t,size:Ct.LARGE}),d.createElement(Bt,{id:this.titleId},n),this.maybeRenderCloseButton())},t.defaultProps={canOutsideClickClose:!0,isOpen:!1},t.displayName=C+".Dialog",t=Object(u.__decorate)([_e.polyfill],t)}(g),Xt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleCancel=function(e){return t.internalHandleCallbacks(!1,e)},t.handleConfirm=function(e){return t.internalHandleCallbacks(!0,e)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.canEscapeKeyCancel,n=e.canOutsideClickCancel,r=e.children,i=e.className,o=e.icon,s=e.intent,l=e.loading,c=e.cancelButtonText,h=e.confirmButtonText,p=(e.onClose,Object(u.__rest)(e,["canEscapeKeyCancel","canOutsideClickCancel","children","className","icon","intent","loading","cancelButtonText","confirmButtonText","onClose"]));return d.createElement(Kt,Object(u.__assign)({},p,{className:ve()(a.ALERT,i),canEscapeKeyClose:t,canOutsideClickClose:n,onClose:this.handleCancel,portalContainer:this.props.portalContainer}),d.createElement("div",{className:a.ALERT_BODY},d.createElement(Lt,{icon:o,size:40,intent:s}),d.createElement("div",{className:a.ALERT_CONTENTS},r)),d.createElement("div",{className:a.ALERT_FOOTER},d.createElement(kt,{loading:l,intent:s,text:h,onClick:this.handleConfirm}),c&&d.createElement(kt,{text:c,disabled:l,onClick:this.handleCancel})))},t.prototype.validateProps=function(e){null==e.onClose&&null==e.cancelButtonText!=(null==e.onCancel)&&console.warn(Xe.c);var t=null!=e.onCancel||null!=e.onClose;e.canEscapeKeyCancel&&!t&&console.warn(Xe.a),e.canOutsideClickCancel&&!t&&console.warn(Xe.b)},t.prototype.internalHandleCallbacks=function(e,t){var n,r=this.props,i=r.onCancel,o=r.onClose,a=r.onConfirm;null===(n=e?a:i)||void 0===n||n(t),null==o||o(e,t)},t.defaultProps={canEscapeKeyCancel:!1,canOutsideClickCancel:!1,confirmButtonText:"OK",isOpen:!1,loading:!1},t.displayName=C+".Alert",t=Object(u.__decorate)([_e.polyfill],t)}(g),Jt=function(e){var t,n=ve()(a.BREADCRUMB,((t={})[a.BREADCRUMB_CURRENT]=e.current,t[a.DISABLED]=e.disabled,t),e.className),r=null!=e.icon?d.createElement(Lt,{title:e.iconTitle,icon:e.icon}):void 0;return null==e.href&&null==e.onClick?d.createElement("span",{className:n},r,e.text,e.children):d.createElement("a",{className:n,href:e.href,onClick:e.disabled?void 0:e.onClick,tabIndex:e.disabled?void 0:0,target:e.target},r,e.text,e.children)},Qt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.title;return null==n?d.createElement("li",{className:ve()(a.MENU_DIVIDER,t)}):d.createElement("li",{className:ve()(a.MENU_HEADER,t)},d.createElement(Ft,null,n))},t.displayName=C+".MenuDivider",t}(d.Component),Zt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={isContentOverflowing:!1,textContent:""},t.textRef=null,t}return Object(u.__extends)(t,e),t.prototype.componentDidMount=function(){this.update()},t.prototype.componentDidUpdate=function(){this.update()},t.prototype.render=function(){var e,t=this,n=this.props,r=n.children,i=n.className,o=n.ellipsize,s=n.tagName,l=void 0===s?"div":s,c=n.title,h=Object(u.__rest)(n,["children","className","ellipsize","tagName","title"]),p=ve()(i,((e={})[a.TEXT_OVERFLOW_ELLIPSIS]=o,e));return d.createElement(l,Object(u.__assign)(Object(u.__assign)({},h),{className:p,ref:function(e){return t.textRef=e},title:null!=c?c:this.state.isContentOverflowing?this.state.textContent:void 0}),r)},t.prototype.update=function(){var e;if(null!=(null===(e=this.textRef)||void 0===e?void 0:e.textContent)){var t={isContentOverflowing:this.props.ellipsize&&this.textRef.scrollWidth>this.textRef.clientWidth,textContent:this.textRef.textContent};this.setState(t)}},t.displayName=C+".Text",t.defaultProps={ellipsize:!1},t=Object(u.__decorate)([_e.polyfill],t)}(g),$t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t,n=this.props,r=n.active,i=n.className,o=n.children,s=n.disabled,l=n.icon,c=n.intent,h=(n.labelClassName,n.labelElement),p=n.multiline,f=(n.popoverProps,n.shouldDismissPopover),m=n.text,g=n.textClassName,v=n.tagName,y=void 0===v?"a":v,_=n.htmlTitle,b=Object(u.__rest)(n,["active","className","children","disabled","icon","intent","labelClassName","labelElement","multiline","popoverProps","shouldDismissPopover","text","textClassName","tagName","htmlTitle"]),M=null!=o,w=a.intentClass(c),A=ve()(a.MENU_ITEM,w,((e={})[a.ACTIVE]=r,e[a.INTENT_PRIMARY]=r&&null==w,e[a.DISABLED]=s,e[a.POPOVER_DISMISS]=f&&!s&&!M,e),i),C=d.createElement(y,Object(u.__assign)(Object(u.__assign)(Object(u.__assign)({tabIndex:0},b),s?tn:{}),{className:A}),d.createElement(Lt,{icon:l}),d.createElement(Zt,{className:ve()(a.FILL,g),ellipsize:!p,title:_},m),this.maybeRenderLabel(h),M?d.createElement(Lt,{title:"Open sub menu",icon:"caret-right"}):void 0),x=ve()(((t={})[a.MENU_SUBMENU]=M,t));return d.createElement("li",{className:x},this.maybeRenderPopover(C,o))},t.prototype.maybeRenderLabel=function(e){var t=this.props,n=t.label,r=t.labelClassName;return null==n&&null==e?null:d.createElement("span",{className:ve()(a.MENU_ITEM_LABEL,r)},n,e)},t.prototype.maybeRenderPopover=function(e,t){if(null==t)return e;var n=this.props,r=n.disabled,i=n.popoverProps;return d.createElement(vt,Object(u.__assign)({autoFocus:!1,captureDismiss:!1,disabled:r,enforceFocus:!1,hoverCloseDelay:0,interactionKind:gt.HOVER,modifiers:en,position:A.a.RIGHT_TOP,usePortal:!1},i,{content:d.createElement(nn,null,t),minimal:!0,popoverClassName:ve()(a.MENU_SUBMENU,null==i?void 0:i.popoverClassName),target:e}))},t.defaultProps={disabled:!1,multiline:!1,popoverProps:{},shouldDismissPopover:!0,text:""},t.displayName=C+".MenuItem",t=Object(u.__decorate)([_e.polyfill],t)}(g),en={flip:{boundariesElement:"viewport",padding:20},offset:{offset:-5},preventOverflow:{boundariesElement:"viewport",padding:20}},tn={href:void 0,onClick:void 0,onMouseDown:void 0,onMouseEnter:void 0,onMouseLeave:void 0,tabIndex:-1},nn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.children,i=t.large,o=t.ulRef,s=Object(u.__rest)(t,["className","children","large","ulRef"]),l=ve()(a.MENU,((e={})[a.LARGE]=i,e),n);return d.createElement("ul",Object(u.__assign)({},s,{className:l,ref:o}),r)},t.displayName=C+".Menu",t.Divider=Qt,t.Item=$t,t=Object(u.__decorate)([_e.polyfill],t)}(g);!function(e){e[e.NONE=0]="NONE",e[e.GROW=1]="GROW",e[e.SHRINK=2]="SHRINK"}(jt||(jt={}));var rn,on=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={direction:jt.NONE,lastOverflowCount:0,overflow:[],visible:t.props.items},t.previousWidths=new Map,t.spacer=null,t.resize=function(e){var n=e.some((function(e){var n=t.previousWidths.get(e.target)||0;return e.contentRect.width>n}));t.repartition(n),e.forEach((function(e){return t.previousWidths.set(e.target,e.contentRect.width)}))},t}return Object(u.__extends)(t,e),t.ofType=function(){return t},t.prototype.componentDidMount=function(){this.repartition(!1)},t.prototype.shouldComponentUpdate=function(e,t){return!(this.state!==t&&q(this.state,t))},t.prototype.componentDidUpdate=function(e,t){var n,r;e.observeParents!==this.props.observeParents&&console.warn(Xe.z),e.collapseFrom===this.props.collapseFrom&&e.items===this.props.items&&e.minVisibleItems===this.props.minVisibleItems&&e.overflowRenderer===this.props.overflowRenderer&&e.alwaysRenderOverflow===this.props.alwaysRenderOverflow&&e.visibleItemRenderer===this.props.visibleItemRenderer||this.setState({direction:jt.GROW,lastOverflowCount:0,overflow:[],visible:this.props.items}),q(t,this.state)||this.repartition(!1);var i=this.state,o=i.direction,a=i.overflow,s=i.lastOverflowCount;o===jt.NONE&&o!==t.direction&&a.length!==s&&(null===(r=(n=this.props).onOverflow)||void 0===r||r.call(n,a))},t.prototype.render=function(){var e=this,t=this.props,n=t.className,r=t.collapseFrom,i=t.observeParents,o=t.style,s=t.tagName,l=void 0===s?"div":s,c=t.visibleItemRenderer,u=this.maybeRenderOverflow(),h=d.createElement(l,{className:ve()(a.OVERFLOW_LIST,n),style:o},r===y.START?u:null,this.state.visible.map(c),r===y.END?u:null,d.createElement("div",{className:a.OVERFLOW_LIST_SPACER,ref:function(t){return e.spacer=t}}));return d.createElement(rt,{onResize:this.resize,observeParents:i},h)},t.prototype.maybeRenderOverflow=function(){var e=this.state.overflow;return 0!==e.length||this.props.alwaysRenderOverflow?this.props.overflowRenderer(e):null},t.prototype.repartition=function(e){var t=this;null!=this.spacer&&(e?this.setState((function(e){return{direction:jt.GROW,lastOverflowCount:e.direction===jt.NONE?e.overflow.length:e.lastOverflowCount,overflow:[],visible:t.props.items}})):this.spacer.getBoundingClientRect().width<.9?this.setState((function(e){if(e.visible.length<=t.props.minVisibleItems)return null;var n=t.props.collapseFrom===y.START,r=e.visible.slice(),i=n?r.shift():r.pop();if(void 0===i)return null;var o=n?Object(u.__spreadArrays)(e.overflow,[i]):Object(u.__spreadArrays)([i],e.overflow);return{direction:e.direction===jt.NONE?jt.SHRINK:e.direction,overflow:o,visible:r}})):this.setState({direction:jt.NONE}))},t.displayName=C+".OverflowList",t.defaultProps={alwaysRenderOverflow:!1,collapseFrom:y.START,minVisibleItems:0},t}(d.Component),an=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.renderOverflow=function(e){var n=t.props.collapseFrom,r=n===y.END?A.a.BOTTOM_RIGHT:A.a.BOTTOM_LEFT,i=e;return n===y.START&&(i=e.slice().reverse()),d.createElement("li",null,d.createElement(vt,Object(u.__assign)({position:r,disabled:0===i.length,content:d.createElement(nn,null,i.map(t.renderOverflowBreadcrumb))},t.props.popoverProps),d.createElement("span",{className:a.BREADCRUMBS_COLLAPSED})))},t.renderOverflowBreadcrumb=function(e,t){var n=null!=e.href||null!=e.onClick,r=E(e);return d.createElement($t,Object(u.__assign)({disabled:!n},r,{text:e.text,key:t}))},t.renderBreadcrumbWrapper=function(e,n){var r=t.props.items[t.props.items.length-1]===e;return d.createElement("li",{key:n},t.renderBreadcrumb(e,r))},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.collapseFrom,r=e.items,i=e.minVisibleItems,o=e.overflowListProps,s=void 0===o?{}:o;return d.createElement(on,Object(u.__assign)({collapseFrom:n,minVisibleItems:i,tagName:"ul"},s,{className:ve()(a.BREADCRUMBS,s.className,t),items:r,overflowRenderer:this.renderOverflow,visibleItemRenderer:this.renderBreadcrumbWrapper}))},t.prototype.renderBreadcrumb=function(e,t){return t&&null!=this.props.currentBreadcrumbRenderer?this.props.currentBreadcrumbRenderer(e):null!=this.props.breadcrumbRenderer?this.props.breadcrumbRenderer(e):d.createElement(Jt,Object(u.__assign)({current:t},e))},t.defaultProps={collapseFrom:y.START},t=Object(u.__decorate)([_e.polyfill],t)}(g),sn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.alignText,r=t.className,i=t.fill,o=t.minimal,s=t.large,l=t.vertical,c=Object(u.__rest)(t,["alignText","className","fill","minimal","large","vertical"]),h=ve()(a.BUTTON_GROUP,((e={})[a.FILL]=i,e[a.LARGE]=s,e[a.MINIMAL]=o,e[a.VERTICAL]=l,e),a.alignmentClass(n),r);return d.createElement("div",Object(u.__assign)({},c,{className:h}),this.props.children)},t.displayName=C+".ButtonGroup",t=Object(u.__decorate)([_e.polyfill],t)}(g),ln=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.children,i=t.icon,o=t.intent,s=t.title,l=Object(u.__rest)(t,["className","children","icon","intent","title"]),c=this.getIconName(i,o),h=ve()(a.CALLOUT,a.intentClass(o),((e={})[a.CALLOUT_ICON]=null!=c,e),n);return d.createElement("div",Object(u.__assign)({className:h},l),c&&d.createElement(Lt,{icon:c,size:Ct.LARGE}),s&&d.createElement(Bt,null,s),r)},t.prototype.getIconName=function(e,t){if(null!==e){if(void 0!==e)return e;switch(t){case w.a.DANGER:return"error";case w.a.PRIMARY:return"info-sign";case w.a.WARNING:return"warning-sign";case w.a.SUCCESS:return"tick";default:return}}},t.displayName=C+".Callout",t=Object(u.__decorate)([_e.polyfill],t)}(g),cn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.elevation,i=t.interactive,o=Object(u.__rest)(t,["className","elevation","interactive"]),s=ve()(a.CARD,((e={})[a.INTERACTIVE]=i,e),a.elevationClass(r),n);return d.createElement("div",Object(u.__assign)({className:s},o))},t.displayName=C+".Card",t.defaultProps={elevation:M.a.ZERO,interactive:!1},t=Object(u.__decorate)([_e.polyfill],t)}(g);!function(e){e[e.OPEN_START=0]="OPEN_START",e[e.OPENING=1]="OPENING",e[e.OPEN=2]="OPEN",e[e.CLOSING_START=3]="CLOSING_START",e[e.CLOSING=4]="CLOSING",e[e.CLOSED=5]="CLOSED"}(rn||(rn={}));var un=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={animationState:t.props.isOpen?rn.OPEN:rn.CLOSED,height:void 0,heightWhenOpen:void 0},t.contents=null,t.contentsRefHandler=function(e){if(t.contents=e,null!=t.contents){var n=t.contents.clientHeight;t.setState({animationState:t.props.isOpen?rn.OPEN:rn.CLOSED,height:0===n?void 0:n+"px",heightWhenOpen:0===n?void 0:n})}},t}return Object(u.__extends)(t,e),t.getDerivedStateFromProps=function(e,t){var n=e.isOpen,r=t.animationState;if(n)switch(r){case rn.OPEN:case rn.OPENING:break;default:return{animationState:rn.OPEN_START}}else switch(r){case rn.CLOSED:case rn.CLOSING:break;default:return{animationState:rn.CLOSING_START,height:t.heightWhenOpen+"px"}}return null},t.prototype.render=function(){var e=this.state.animationState!==rn.CLOSED,t=e||this.props.keepChildrenMounted,n=e&&this.state.animationState!==rn.CLOSING,r="auto"===this.state.height,i={height:e?this.state.height:void 0,overflowY:r?"visible":void 0,transition:r?"none":void 0},o={transform:n?"translateY(0)":"translateY(-"+this.state.heightWhenOpen+"px)",transition:r?"none":void 0};return d.createElement(this.props.component,{className:ve()(a.COLLAPSE,this.props.className),style:i},d.createElement("div",{className:a.COLLAPSE_BODY,ref:this.contentsRefHandler,style:o,"aria-hidden":!e&&this.props.keepChildrenMounted},t?this.props.children:null))},t.prototype.componentDidMount=function(){this.forceUpdate(),this.props.isOpen?this.setState({animationState:rn.OPEN,height:"auto"}):this.setState({animationState:rn.CLOSED,height:"0px"})},t.prototype.componentDidUpdate=function(){var e=this;if(null!=this.contents){var t=this.props.transitionDuration,n=this.state.animationState;if(n===rn.OPEN_START){var r=this.contents.clientHeight;this.setState({animationState:rn.OPENING,height:r+"px",heightWhenOpen:r}),this.setTimeout((function(){return e.onDelayedStateChange()}),t)}else if(n===rn.CLOSING_START){var i=this.contents.clientHeight;this.setTimeout((function(){return e.setState({animationState:rn.CLOSING,height:"0px",heightWhenOpen:i})})),this.setTimeout((function(){return e.onDelayedStateChange()}),t)}}},t.prototype.onDelayedStateChange=function(){switch(this.state.animationState){case rn.OPENING:this.setState({animationState:rn.OPEN,height:"auto"});break;case rn.CLOSING:this.setState({animationState:rn.CLOSED})}},t.displayName=C+".Collapse",t.defaultProps={component:"div",isOpen:!1,keepChildrenMounted:!1,transitionDuration:200},t=Object(u.__decorate)([_e.polyfill],t)}(g),dn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this,n=this.props.collapseFrom,r=d.Children.count(this.props.children),i=this.partitionChildren(),o=i[0],s=i[1],l=o.map((function(e,i){var o=n===y.START?r-1-i:i;return d.createElement("li",{className:t.props.visibleItemClassName,key:o},t.props.visibleItemRenderer(e.props,o))}));if(n===y.START&&l.reverse(),s.length>0){var c=n===y.END?A.a.BOTTOM_RIGHT:A.a.BOTTOM_LEFT;e=d.createElement("li",{className:this.props.visibleItemClassName},d.createElement(vt,Object(u.__assign)({content:d.createElement(nn,null,s),position:c},this.props.dropdownProps),this.props.dropdownTarget))}return d.createElement("ul",{className:ve()(a.COLLAPSIBLE_LIST,this.props.className)},n===y.START?e:null,l,n===y.END?e:null)},t.prototype.partitionChildren=function(){var e=d.Children.map(this.props.children,(function(e,t){if(!he(e,$t))throw new Error(Xe.e);return d.cloneElement(e,{key:"visible-"+t})}));if(null==e)return[[],[]];this.props.collapseFrom===y.START&&e.reverse();var t=this.props.visibleItemCount;return[e.slice(0,t),e.slice(t)]},t.displayName=C+".CollapsibleList",t.defaultProps={collapseFrom:y.START,visibleItemCount:3},t}(d.Component);function hn(e){var t;return ee(e.prototype.renderContextMenu)||console.warn(Xe.g),(t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var t=this,n=e.prototype.render.call(this);if(null==n)return n;if(!d.isValidElement(n))return console.warn(Xe.f),n;var r=n.props.onContextMenu;return d.cloneElement(n,{onContextMenu:function(e){if(!e.defaultPrevented){if(ee(t.renderContextMenu)){var n=t.renderContextMenu(e);if(null!=n){var i=me(ye.findDOMNode(t));e.preventDefault(),bt(n,{left:e.clientX,top:e.clientY},t.onContextMenuClose,i)}}null==r||r(e)}}})},t}(e)).displayName="ContextMenuTarget("+de(e)+")",t}var pn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props.className;return d.createElement("div",{className:a.DIALOG_STEP_CONTAINER},d.createElement("div",{className:ve()(a.DIALOG_STEP,e),role:"dialogsteplist"}))},t.displayName=C+".DialogStep",t=Object(u.__decorate)([_e.polyfill],t)}(g),fn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state=t.getInitialIndexFromProps(t.props),t.renderDialogStep=function(e,n){var r,i=n+1,o=t.state.lastViewedIndex>=n,s=t.state.selectedIndex===n;return d.createElement("div",{className:ve()(a.DIALOG_STEP_CONTAINER,(r={},r[a.ACTIVE]=s,r[a.DIALOG_STEP_VIEWED]=o,r)),key:n},d.createElement("div",{className:a.DIALOG_STEP,onClick:t.handleClickDialogStep(n)},d.createElement("div",{className:a.DIALOG_STEP_ICON},i),d.createElement("div",{className:a.DIALOG_STEP_TITLE},e.props.title)))},t.handleClickDialogStep=function(e){if(!(e>t.state.lastViewedIndex))return t.getDialogStepChangeHandler(e)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.showCloseButtonInFooter,n=e.isCloseButtonShown,r=Object(u.__rest)(e,["showCloseButtonInFooter","isCloseButtonShown"]),i=!t&&n;return d.createElement(Kt,Object(u.__assign)({isCloseButtonShown:i},r,{style:this.getDialogStyle()}),d.createElement("div",{className:a.MULTISTEP_DIALOG_PANELS},this.renderLeftPanel(),this.maybeRenderRightPanel()))},t.prototype.componentDidUpdate=function(e){!e.resetOnClose&&e.initialStepIndex===this.props.initialStepIndex||e.isOpen||!this.props.isOpen||this.setState(this.getInitialIndexFromProps(this.props))},t.prototype.getDialogStyle=function(){return Object(u.__assign)({minWidth:800,paddingBottom:0},this.props.style)},t.prototype.renderLeftPanel=function(){return d.createElement("div",{className:a.MULTISTEP_DIALOG_LEFT_PANEL},this.getDialogStepChildren().filter(mn).map(this.renderDialogStep))},t.prototype.maybeRenderRightPanel=function(){var e=this.getDialogStepChildren();if(e.length<=this.state.selectedIndex)return null;var t=e[this.state.selectedIndex].props,n=t.className,r=t.panel,i=t.panelClassName;return d.createElement("div",{className:ve()(a.MULTISTEP_DIALOG_RIGHT_PANEL,n,i)},r,this.renderFooter())},t.prototype.renderFooter=function(){var e=this.props,t=e.closeButtonProps,n=e.isCloseButtonShown,r=e.showCloseButtonInFooter,i=e.onClose,o=r&&n?d.createElement(kt,Object(u.__assign)({text:"Close",onClick:i},t)):void 0;return d.createElement("div",{className:a.MULTISTEP_DIALOG_FOOTER},o,d.createElement("div",{className:a.DIALOG_FOOTER_ACTIONS},this.renderButtons()))},t.prototype.renderButtons=function(){var e,t,n=this.state.selectedIndex,r=this.getDialogStepChildren(),i=[];if(this.state.selectedIndex>0){var o=null!==(e=r[n].props.backButtonProps)&&void 0!==e?e:this.props.backButtonProps;i.push(d.createElement(kt,Object(u.__assign)({key:"back",onClick:this.getDialogStepChangeHandler(n-1),text:"Back"},o)))}if(n===this.getDialogStepChildren().length-1)i.push(d.createElement(kt,Object(u.__assign)({intent:"primary",key:"final",text:"Submit"},this.props.finalButtonProps)));else{var a=null!==(t=r[n].props.nextButtonProps)&&void 0!==t?t:this.props.nextButtonProps;i.push(d.createElement(kt,Object(u.__assign)({intent:"primary",key:"next",onClick:this.getDialogStepChangeHandler(n+1),text:"Next"},a)))}return i},t.prototype.getDialogStepChangeHandler=function(e){var t=this;return function(n){if(void 0!==t.props.onChange){var r=t.getDialogStepChildren(),i=r[t.state.selectedIndex].props.id,o=r[e].props.id;t.props.onChange(o,i,n)}t.setState({lastViewedIndex:Math.max(t.state.lastViewedIndex,e),selectedIndex:e})}},t.prototype.getDialogStepChildren=function(e){return void 0===e&&(e=this.props),d.Children.toArray(e.children).filter(mn)},t.prototype.getInitialIndexFromProps=function(e){if(void 0!==e.initialStepIndex){var t=Math.max(0,Math.min(e.initialStepIndex,this.getDialogStepChildren(e).length-1));return{lastViewedIndex:t,selectedIndex:t}}return{lastViewedIndex:0,selectedIndex:0}},t.displayName=C+".MultistepDialog",t.defaultProps={canOutsideClickClose:!0,isOpen:!1,resetOnClose:!0,showCloseButtonInFooter:!1},t=Object(u.__decorate)([_e.polyfill],t)}(g);function mn(e){return i.isElementOfType(e,pn)}var gn,vn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.tagName,r=void 0===n?"div":n,i=Object(u.__rest)(e,["className","tagName"]),o=ve()(a.DIVIDER,t);return d.createElement(r,Object(u.__assign)(Object(u.__assign)({},i),{className:o}))},t.displayName=C+".Divider",t=Object(u.__decorate)([_e.polyfill],t)}(g);!function(e){e.SMALL="360px",e.STANDARD="50%",e.LARGE="90%"}(gn||(gn={}));var yn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t,n,r=this.props,i=r.size,o=r.style,s=r.position,l=r.vertical,c=s?Object(A.b)(s):void 0,h=ve()(a.DRAWER,((e={})[a.VERTICAL]=!c&&l,e[null!==(n=a.positionClass(c))&&void 0!==n?n:""]=!0,e),this.props.className),p=null==i?o:Object(u.__assign)(Object(u.__assign)({},o),((t={})[(c?Object(A.c)(c):l)?"height":"width"]=i,t));return d.createElement(tt,Object(u.__assign)({},this.props,{className:a.OVERLAY_CONTAINER}),d.createElement("div",{className:h,style:p},this.maybeRenderHeader(),this.props.children))},t.prototype.validateProps=function(e){null==e.title&&(null!=e.icon&&console.warn(Xe.i),null!=e.isCloseButtonShown&&console.warn(Xe.h)),null!=e.position&&(e.vertical&&console.warn(Xe.k),e.position!==Object(A.b)(e.position)&&console.warn(Xe.j))},t.prototype.maybeRenderCloseButton=function(){return!1!==this.props.isCloseButtonShown?d.createElement(kt,{"aria-label":"Close",className:a.DIALOG_CLOSE_BUTTON,icon:d.createElement(Lt,{icon:"small-cross",size:Ct.LARGE}),minimal:!0,onClick:this.props.onClose}):null},t.prototype.maybeRenderHeader=function(){var e=this.props,t=e.icon,n=e.title;return null==n?null:d.createElement("div",{className:a.DRAWER_HEADER},d.createElement(Lt,{icon:t,size:Ct.LARGE}),d.createElement(Bt,null,n),this.maybeRenderCloseButton())},t.displayName=C+".Drawer",t.defaultProps={canOutsideClickClose:!0,isOpen:!1,style:{},vertical:!1},t.SIZE_SMALL=gn.SMALL,t.SIZE_STANDARD=gn.STANDARD,t.SIZE_LARGE=gn.LARGE,t=Object(u.__decorate)([_e.polyfill],t)}(g),_n="undefined"!=typeof navigator?navigator.userAgent:"",bn={isEdge:/Edge/.test(_n),isInternetExplorer:/Trident|rv:11/.test(_n),isWebkit:/AppleWebKit/.test(_n)},Mn=function(){return bn.isInternetExplorer},wn=function(e){function t(t,n){var i=e.call(this,t,n)||this;i.inputElement=null,i.valueElement=null,i.refHandlers={content:function(e){i.valueElement=e},input:function(e){if(null!=e&&(i.inputElement=e,i.props.alwaysRenderInput||i.inputElement.focus(),null!=i.state&&i.state.isEditing)){var t=function(e){switch(e.type){case"textarea":return!0;case"text":case"search":case"tel":case"url":case"password":return!0;default:return!1}}(e);if(t){var n=e.value.length;e.setSelectionRange(i.props.selectAllOnFocus?0:n,n)}t&&i.props.selectAllOnFocus||(e.scrollLeft=e.scrollWidth)}}},i.cancelEditing=function(){var e,t,n,r,o=i.state,a=o.lastValue,s=o.value;i.setState({isEditing:!1,value:a}),s!==a&&(null===(t=(e=i.props).onChange)||void 0===t||t.call(e,a)),null===(r=(n=i.props).onCancel)||void 0===r||r.call(n,a)},i.toggleEditing=function(){var e,t;if(i.state.isEditing){var n=i.state.value;i.setState({isEditing:!1,lastValue:n}),null===(t=(e=i.props).onConfirm)||void 0===t||t.call(e,n)}else i.props.disabled||i.setState({isEditing:!0})},i.handleFocus=function(){var e=i.props,t=e.alwaysRenderInput,n=e.disabled,r=e.selectAllOnFocus;if(n||i.setState({isEditing:!0}),t&&r&&null!=i.inputElement){var o=i.inputElement.value.length;i.inputElement.setSelectionRange(0,o)}},i.handleTextChange=function(e){var t,n,r=e.target.value;null==i.props.value&&i.setState({value:r}),null===(n=(t=i.props).onChange)||void 0===n||n.call(t,r)},i.handleKeyEvent=function(e){var t=e.altKey,n=e.ctrlKey,o=e.metaKey,a=e.shiftKey,s=e.which;if(s!==r.ESCAPE){var l=t||n||o||a;s===r.ENTER&&((t||a)&&e.preventDefault(),i.props.confirmOnEnterKey&&i.props.multiline?null!=e.target&&l?(!function(e,t){var n=e.selectionEnd,r=e.selectionStart,i=e.value;if(r>=0){var o=i.substring(0,r),a=i.substring(n,i.length),s=t.length;e.value=""+o+t+a,e.selectionStart=r+s,e.selectionEnd=r+s}}(e.target,"\n"),i.handleTextChange(e)):i.toggleEditing():i.props.multiline&&!l||i.toggleEditing())}else i.cancelEditing()};var o=null==t.value?t.defaultValue:t.value;return i.state={inputHeight:0,inputWidth:0,isEditing:!0===t.isEditing&&!1===t.disabled,lastValue:o,value:o},i}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t,n,r=this.props,i=r.alwaysRenderInput,o=r.disabled,s=r.multiline,l=r.contentId,c=null!==(t=this.props.value)&&void 0!==t?t:this.state.value,h=null!=c&&""!==c,p=ve()(a.EDITABLE_TEXT,a.intentClass(this.props.intent),((e={})[a.DISABLED]=o,e[a.EDITABLE_TEXT_EDITING]=this.state.isEditing,e[a.EDITABLE_TEXT_PLACEHOLDER]=!h,e[a.MULTILINE]=s,e),this.props.className);n=s?{height:this.state.isEditing?void 0:this.state.inputHeight}:{height:this.state.inputHeight,lineHeight:null!=this.state.inputHeight?this.state.inputHeight+"px":void 0,minWidth:this.props.minWidth};var f=i||this.state.isEditing||o?void 0:0,m=i&&!this.state.isEditing,g=null!=l?{id:l}:{};return d.createElement("div",{className:p,onFocus:this.handleFocus,tabIndex:f},i||this.state.isEditing?this.renderInput(c):void 0,m?void 0:d.createElement("span",Object(u.__assign)({},g,{className:a.EDITABLE_TEXT_CONTENT,ref:this.refHandlers.content,style:n}),h?c:this.props.placeholder))},t.prototype.componentDidMount=function(){this.updateInputDimensions()},t.prototype.componentDidUpdate=function(e,t){var n,r,i={};this.props.value===e.value||null==e.value&&null==this.props.value||(i.value=this.props.value),null!=this.props.isEditing&&this.props.isEditing!==e.isEditing&&(i.isEditing=this.props.isEditing),(this.props.disabled||null==this.props.disabled&&e.disabled)&&(i.isEditing=!1),this.setState(i),this.state.isEditing&&!t.isEditing&&(null===(r=(n=this.props).onEdit)||void 0===r||r.call(n,this.state.value)),this.state.value===t.value&&this.props.alwaysRenderInput===e.alwaysRenderInput&&this.props.maxLines===e.maxLines&&this.props.minLines===e.minLines&&this.props.minWidth===e.minWidth&&this.props.multiline===e.multiline||this.updateInputDimensions()},t.prototype.renderInput=function(e){var t=this.props,n=t.disabled,r=t.maxLength,i=t.multiline,o=t.type,s=t.placeholder,l={className:a.EDITABLE_TEXT_INPUT,disabled:n,maxLength:r,onBlur:this.toggleEditing,onChange:this.handleTextChange,onKeyDown:this.handleKeyEvent,placeholder:s,value:e},c=this.state,h=c.inputHeight,p=c.inputWidth;return 0!==h&&0!==p&&(l.style={height:h,lineHeight:i||null==h?void 0:h+"px",width:i?"100%":p}),i?d.createElement("textarea",Object(u.__assign)({ref:this.refHandlers.input},l)):d.createElement("input",Object(u.__assign)({ref:this.refHandlers.input,type:o},l))},t.prototype.updateInputDimensions=function(){if(null!=this.valueElement){var e=this.props,t=e.maxLines,n=e.minLines,r=e.minWidth,i=e.multiline,o=this.valueElement,a=o.parentElement,s=o.textContent,l=this.valueElement,c=l.scrollHeight,u=l.scrollWidth,d=An(this.valueElement);i&&this.state.isEditing&&/\n$/.test(null!=s?s:"")&&(c+=d),d>0&&(c=Object(h.c)(c,n*d,t*d)),c=Math.max(c,(p=this.valueElement,(""===(f=getComputedStyle(p).fontSize)?0:parseInt(f.slice(0,-2),10))+1),An(a)),u+=Mn()?30:5,this.setState({inputHeight:c,inputWidth:Math.max(u,r)}),i&&this.state.isEditing&&this.setTimeout((function(){return a.style.height=c+"px"}))}var p,f},t.displayName=C+".EditableText",t.defaultProps={alwaysRenderInput:!1,confirmOnEnterKey:!1,defaultValue:"",disabled:!1,maxLines:1/0,minLines:1,minWidth:80,multiline:!1,placeholder:"Click to Edit",type:"text"},t=Object(u.__decorate)([_e.polyfill],t)}(g);function An(e){var t=parseInt(getComputedStyle(e).lineHeight.slice(0,-2),10);if(isNaN(t)){var n=document.createElement("span");n.innerHTML="<br>",e.appendChild(n);var r=e.offsetHeight;n.innerHTML="<br><br>";var i=e.offsetHeight;e.removeChild(n),t=i-r}return t}var Cn,xn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.children,r=t.className,i=t.fill,o=t.vertical,s=Object(u.__rest)(t,["children","className","fill","vertical"]),l=ve()(a.CONTROL_GROUP,((e={})[a.FILL]=i,e[a.VERTICAL]=o,e),r);return d.createElement("div",Object(u.__assign)({},s,{className:l}),n)},t.displayName=C+".ControlGroup",t=Object(u.__decorate)([_e.polyfill],t)}(g),En=function(e){var t,n=e.alignIndicator,r=e.children,i=e.className,o=e.indicatorChildren,s=e.inline,l=e.inputRef,c=e.label,h=e.labelElement,p=e.large,f=e.style,m=e.type,g=e.typeClassName,v=e.tagName,y=void 0===v?"label":v,_=Object(u.__rest)(e,["alignIndicator","children","className","indicatorChildren","inline","inputRef","label","labelElement","large","style","type","typeClassName","tagName"]),b=ve()(a.CONTROL,g,((t={})[a.DISABLED]=_.disabled,t[a.INLINE]=s,t[a.LARGE]=p,t),a.alignmentClass(n),i);return d.createElement(y,{className:b,style:f},d.createElement("input",Object(u.__assign)({},_,{ref:l,type:m})),d.createElement("span",{className:a.CONTROL_INDICATOR},o),c,h,r)},Ln=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.innerLabelChecked,n=e.innerLabel,r=Object(u.__rest)(e,["innerLabelChecked","innerLabel"]),i=n||t?[d.createElement("div",{key:"checked",className:a.CONTROL_INDICATOR_CHILD},d.createElement("div",{className:a.SWITCH_INNER_TEXT},t||n)),d.createElement("div",{key:"unchecked",className:a.CONTROL_INDICATOR_CHILD},d.createElement("div",{className:a.SWITCH_INNER_TEXT},n))]:null;return d.createElement(En,Object(u.__assign)({},r,{type:"checkbox",typeClassName:a.SWITCH,indicatorChildren:i}))},t.displayName=C+".Switch",t=Object(u.__decorate)([_e.polyfill],t)}(g),Sn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){return d.createElement(En,Object(u.__assign)({},this.props,{type:"radio",typeClassName:a.RADIO}))},t.displayName=C+".Radio",t=Object(u.__decorate)([_e.polyfill],t)}(g),Tn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={indeterminate:t.props.indeterminate||t.props.defaultIndeterminate||!1},t.input=null,t.handleInputRef=D(t,"input",t.props.inputRef),t.handleChange=function(e){var n,r,i=e.target.indeterminate;null==t.props.indeterminate&&t.setState({indeterminate:i}),null===(r=(n=t.props).onChange)||void 0===r||r.call(n,e)},t}return Object(u.__extends)(t,e),t.getDerivedStateFromProps=function(e){var t=e.indeterminate;return null!=t?{indeterminate:t}:null},t.prototype.render=function(){var e=this.props,t=(e.defaultIndeterminate,e.indeterminate,Object(u.__rest)(e,["defaultIndeterminate","indeterminate"]));return d.createElement(En,Object(u.__assign)({},t,{inputRef:this.handleInputRef,onChange:this.handleChange,type:"checkbox",typeClassName:a.CHECKBOX}))},t.prototype.componentDidMount=function(){this.updateIndeterminate()},t.prototype.componentDidUpdate=function(e){this.updateIndeterminate(),e.inputRef!==this.props.inputRef&&(T(e.inputRef,null),this.handleInputRef=D(this,"input",this.props.inputRef),T(this.props.inputRef,this.input))},t.prototype.updateIndeterminate=function(){null!=this.input&&(this.input.indeterminate=this.state.indeterminate)},t.displayName=C+".Checkbox",t=Object(u.__decorate)([_e.polyfill],t)}(g),On=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleInputChange=function(e){var n,r,i,o;null===(r=(n=t.props).onInputChange)||void 0===r||r.call(n,e),null===(o=null===(i=t.props.inputProps)||void 0===i?void 0:i.onChange)||void 0===o||o.call(i,e)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t,n,r=this.props,i=r.buttonText,o=r.className,s=r.disabled,l=r.fill,c=r.hasSelection,h=r.inputProps,p=r.large,f=(r.onInputChange,r.text),m=Object(u.__rest)(r,["buttonText","className","disabled","fill","hasSelection","inputProps","large","onInputChange","text"]),g=ve()(a.FILE_INPUT,((e={})[a.FILE_INPUT_HAS_SELECTION]=c,e[a.DISABLED]=s,e[a.FILL]=l,e[a.LARGE]=p,e),o),v=((t={})[a.getClassNamespace()+"-button-text"]=i,t.className=ve()(a.FILE_UPLOAD_INPUT,((n={})[a.FILE_UPLOAD_INPUT_CUSTOM_TEXT]=!!i,n)),t);return d.createElement("label",Object(u.__assign)({},m,{className:g}),d.createElement("input",Object(u.__assign)({},h,{onChange:this.handleInputChange,type:"file",disabled:s})),d.createElement("span",Object(u.__assign)({},v),f))},t.displayName=C+".FileInput",t.defaultProps={hasSelection:!1,inputProps:{},text:"Choose file..."},t=Object(u.__decorate)([_e.polyfill],t)}(g),In=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.children,n=e.contentClassName,r=e.helperText,i=e.label,o=e.labelFor,s=e.labelInfo,l=e.style,c=e.subLabel;return d.createElement("div",{className:this.getClassName(),style:l},i&&d.createElement("label",{className:a.LABEL,htmlFor:o},i," ",d.createElement("span",{className:a.TEXT_MUTED},s)),c&&d.createElement("div",{className:a.FORM_GROUP_SUB_LABEL},c),d.createElement("div",{className:ve()(a.FORM_CONTENT,n)},t,r&&d.createElement("div",{className:a.FORM_HELPER_TEXT},r)))},t.prototype.getClassName=function(){var e,t=this.props,n=t.className,r=t.disabled,i=t.inline,o=t.intent;return ve()(a.FORM_GROUP,a.intentClass(o),((e={})[a.DISABLED]=r,e[a.INLINE]=i,e),n)},t.displayName=C+".FormGroup",t=Object(u.__decorate)([_e.polyfill],t)}(g),kn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={hasPendingUpdate:!1,isComposing:!1,nextValue:t.props.value,value:t.props.value},t.handleCompositionStart=function(e){var n,r;t.setState({isComposing:!0,nextValue:t.state.value}),null===(r=(n=t.props).onCompositionStart)||void 0===r||r.call(n,e)},t.handleCompositionEnd=function(e){var n,r;t.setState({isComposing:!1}),null===(r=(n=t.props).onCompositionEnd)||void 0===r||r.call(n,e)},t.handleChange=function(e){var n,r,i=e.target.value;t.setState({nextValue:i}),null===(r=(n=t.props).onChange)||void 0===r||r.call(n,e)},t}return Object(u.__extends)(t,e),t.getDerivedStateFromProps=function(e,t){return t.isComposing||void 0===e.value?null:t.nextValue!==t.value?e.value===t.nextValue?t.hasPendingUpdate?{value:e.value,hasPendingUpdate:!1}:{value:t.nextValue}:e.value===t.value?{hasPendingUpdate:!0}:{value:e.value,nextValue:e.value,hasPendingUpdate:!1}:{value:e.value,nextValue:e.value,hasPendingUpdate:!1}},t.prototype.render=function(){var e=this.state,t=e.isComposing,n=e.hasPendingUpdate,r=e.value,i=e.nextValue,o=this.props,a=o.inputRef,s=Object(u.__rest)(o,["inputRef"]);return d.createElement("input",Object(u.__assign)({},s,{ref:a,value:t||n?i:r,onCompositionStart:this.handleCompositionStart,onCompositionEnd:this.handleCompositionEnd,onChange:this.handleChange}))},t.displayName=C+".AsyncControllableInput",t=Object(u.__decorate)([_e.polyfill],t)}(d.PureComponent),Dn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={},t.leftElement=null,t.rightElement=null,t.refHandlers={leftElement:function(e){return t.leftElement=e},rightElement:function(e){return t.rightElement=e}},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.asyncControl,r=void 0!==n&&n,i=t.className,o=t.disabled,s=t.fill,l=t.inputRef,c=t.intent,h=t.large,p=t.small,f=t.round,m=ve()(a.INPUT_GROUP,a.intentClass(c),((e={})[a.DISABLED]=o,e[a.FILL]=s,e[a.LARGE]=h,e[a.SMALL]=p,e[a.ROUND]=f,e),i),g=Object(u.__assign)(Object(u.__assign)({},this.props.style),{paddingLeft:this.state.leftElementWidth,paddingRight:this.state.rightElementWidth}),v=Object(u.__assign)(Object(u.__assign)({type:"text"},E(this.props)),{className:a.INPUT,style:g});return d.createElement("div",{className:m},this.maybeRenderLeftElement(),r?d.createElement(kn,Object(u.__assign)({},v,{inputRef:l})):d.createElement("input",Object(u.__assign)({},v,{ref:l})),this.maybeRenderRightElement())},t.prototype.componentDidMount=function(){this.updateInputWidth()},t.prototype.componentDidUpdate=function(e){var t=this.props,n=t.leftElement,r=t.rightElement;e.leftElement===n&&e.rightElement===r||this.updateInputWidth()},t.prototype.validateProps=function(e){null!=e.leftElement&&null!=e.leftIcon&&console.warn(Xe.p)},t.prototype.maybeRenderLeftElement=function(){var e=this.props,t=e.leftElement,n=e.leftIcon;return null!=t?d.createElement("span",{className:a.INPUT_LEFT_CONTAINER,ref:this.refHandlers.leftElement},t):null!=n?d.createElement(Lt,{icon:n}):void 0},t.prototype.maybeRenderRightElement=function(){var e=this.props.rightElement;if(null!=e)return d.createElement("span",{className:a.INPUT_ACTION,ref:this.refHandlers.rightElement},e)},t.prototype.updateInputWidth=function(){var e=this.state,t=e.leftElementWidth,n=e.rightElementWidth;if(null!=this.leftElement){var r=this.leftElement.clientWidth;(void 0===t||Math.abs(r-t)>2)&&this.setState({leftElementWidth:r})}else this.setState({leftElementWidth:void 0});if(null!=this.rightElement){r=this.rightElement.clientWidth;(void 0===n||Math.abs(r-n)>2)&&this.setState({rightElementWidth:r})}else this.setState({rightElementWidth:void 0})},t.displayName=C+".InputGroup",t=Object(u.__decorate)([_e.polyfill],t)}(g);function Nn(e){var t=1.9.toLocaleString(e),n=1..toLocaleString(e),r=9..toLocaleString(e),i=new RegExp(n+"(.+)"+r).exec(t);return i&&i[1]||"."}function jn(e,t){return void 0===t&&(t="en-US"),Hn(e.toLocaleString(t),t)}function Pn(e){return void 0===e&&(e=""),e.toString()}function zn(e,t){var n=""+e;if(parseFloat(n).toString()===e.toString())return e.toString();if(void 0!==t){var r=Nn(t);return Hn(n,t).split("").map((function(e){return function(e,t){var n=[0,1,2,3,4,5,6,7,8,9].map((function(e){return e.toLocaleString(t)})).indexOf(e);return-1!==n?n:e}(e,t)})).join("").replace(r,".")}return e.toString()}function Rn(e,t){return null==e.key||(!!(e.ctrlKey||e.altKey||e.metaKey)||(!(1===e.key.length)||Bn(e.key,t)))}function Bn(e,t){if(void 0!==t){var n=Nn(t).replace(".","\\."),r=[0,1,2,3,4,5,6,7,8,9].map((function(e){return e.toLocaleString(t)})).join("");return new RegExp("^[Ee"+r+"\\+\\-"+n+"]$").test(e)}return/^[Ee0-9\+\-\.]$/.test(e)}function Hn(e,t){return function(e){return e.replace(/[\uFF10-\uFF19]/g,(function(e){return String.fromCharCode(e.charCodeAt(0)-65248)}))}(e).split("").filter((function(e){return Bn(e,t)})).join("")}!function(e){e[e.DOWN=-1]="DOWN",e[e.UP=1]="UP"}(Cn||(Cn={}));var Fn=["allowNumericCharactersOnly","buttonPosition","clampValueOnBlur","className","defaultValue","majorStepSize","minorStepSize","onButtonClick","onValueChange","selectAllOnFocus","selectAllOnIncrement","stepSize"],Yn=function(e){function t(){var t,i=e.apply(this,arguments)||this;return i.state={currentImeInputInvalid:!1,shouldSelectAfterUpdate:!1,stepMaxPrecision:n.getStepMaxPrecision(i.props),value:Pn(null!==(t=i.props.value)&&void 0!==t?t:i.props.defaultValue)},i.didPasteEventJustOccur=!1,i.delta=0,i.inputElement=null,i.inputRef=D(i,"inputElement",i.props.inputRef),i.incrementButtonHandlers=i.getButtonEventHandlers(Cn.UP),i.decrementButtonHandlers=i.getButtonEventHandlers(Cn.DOWN),i.handleButtonClick=function(e,t){var n,r,o=i.updateDelta(t,e),a=i.incrementValue(o);null===(r=(n=i.props).onButtonClick)||void 0===r||r.call(n,Number(zn(a,i.props.locale)),a)},i.stopContinuousChange=function(){i.delta=0,i.clearTimeouts(),clearInterval(i.intervalId),document.removeEventListener("mouseup",i.stopContinuousChange)},i.handleContinuousChange=function(){var e,t,n,r;if(void 0!==i.props.min||void 0!==i.props.max){var o=null!==(e=i.props.min)&&void 0!==e?e:-1/0,a=null!==(t=i.props.max)&&void 0!==t?t:1/0,s=Number(zn(i.state.value,i.props.locale));if(s<=o||s>=a)return void i.stopContinuousChange()}var l=i.incrementValue(i.delta);null===(r=(n=i.props).onButtonClick)||void 0===r||r.call(n,Number(zn(l,i.props.locale)),l)},i.handleInputFocus=function(e){var t,n;i.setState({shouldSelectAfterUpdate:i.props.selectAllOnFocus}),null===(n=(t=i.props).onFocus)||void 0===n||n.call(t,e)},i.handleInputBlur=function(e){var t,n;if(i.setState({shouldSelectAfterUpdate:!1}),i.props.clampValueOnBlur){var r=e.target.value;i.handleNextValue(i.roundAndClampValue(r))}null===(n=(t=i.props).onBlur)||void 0===n||n.call(t,e)},i.handleInputKeyDown=function(e){var t,n;if(!i.props.disabled&&!i.props.readOnly){var o,a=e.keyCode;if(a===r.ARROW_UP?o=Cn.UP:a===r.ARROW_DOWN&&(o=Cn.DOWN),void 0!==o){e.preventDefault();var s=i.updateDelta(o,e);i.incrementValue(s)}null===(n=(t=i.props).onKeyDown)||void 0===n||n.call(t,e)}},i.handleCompositionEnd=function(e){i.props.allowNumericCharactersOnly&&(i.handleNextValue(Hn(e.data,i.props.locale)),i.setState({currentImeInputInvalid:!1}))},i.handleCompositionUpdate=function(e){if(i.props.allowNumericCharactersOnly){var t=e.data;0===Hn(t,i.props.locale).length&&t.length>0?i.setState({currentImeInputInvalid:!0}):i.setState({currentImeInputInvalid:!1})}},i.handleInputKeyPress=function(e){var t,n;i.props.allowNumericCharactersOnly&&!Rn(e,i.props.locale)&&e.preventDefault(),null===(n=(t=i.props).onKeyPress)||void 0===n||n.call(t,e)},i.handleInputPaste=function(e){var t,n;i.didPasteEventJustOccur=!0,null===(n=(t=i.props).onPaste)||void 0===n||n.call(t,e)},i.handleInputChange=function(e){var t=e.target.value,n=t;i.props.allowNumericCharactersOnly&&i.didPasteEventJustOccur&&(i.didPasteEventJustOccur=!1,n=Hn(t,i.props.locale)),i.handleNextValue(n),i.setState({shouldSelectAfterUpdate:!1})},i}var n;return Object(u.__extends)(t,e),n=t,t.getDerivedStateFromProps=function(e,t){var r,i,o={prevMaxProp:e.max,prevMinProp:e.min},a=e.min!==t.prevMinProp,s=e.max!==t.prevMaxProp,l=a||s,c=null!==(i=null===(r=e.value)||void 0===r?void 0:r.toString())&&void 0!==i?i:t.value,d=n.getStepMaxPrecision(e),h=c!==n.VALUE_EMPTY?n.roundAndClampValue(c,d,e.min,e.max,0,e.locale):n.VALUE_EMPTY;return l&&h!==t.value?Object(u.__assign)(Object(u.__assign)({},o),{stepMaxPrecision:d,value:h}):Object(u.__assign)(Object(u.__assign)({},o),{stepMaxPrecision:d,value:c})},t.getStepMaxPrecision=function(e){return null!=e.minorStepSize?i.countDecimalPlaces(e.minorStepSize):i.countDecimalPlaces(e.stepSize)},t.roundAndClampValue=function(e,t,r,i,o,a){if(void 0===o&&(o=0),!function(e,t){var n=zn(e,t);return null!=e&&n-parseFloat(n)+1>=0}(e,a))return n.VALUE_EMPTY;var s=zn(e,a);return jn(function(e,t,n){var r=null!=t?t:-1/0,i=null!=n?n:1/0;return Object(h.c)(e,r,i)}(function(e,t){var n=Math.pow(10,t);return Math.round(e*n)/n}(Number(s)+o,t),r,i),a)},t.prototype.render=function(){var e,t=this.props,n=t.buttonPosition,r=t.className,i=t.fill,o=t.large,s=ve()(a.NUMERIC_INPUT,((e={})[a.LARGE]=o,e),r),l=this.renderButtons();return d.createElement(xn,{className:s,fill:i},n===A.a.LEFT&&l,this.renderInput(),n===A.a.RIGHT&&l)},t.prototype.componentDidUpdate=function(t,r){var i,o,a;e.prototype.componentDidUpdate.call(this,t,r),t.inputRef!==this.props.inputRef&&(T(t.inputRef,null),this.inputRef=D(this,"inputElement",this.props.inputRef),T(this.props.inputRef,this.inputElement)),this.state.shouldSelectAfterUpdate&&(null===(i=this.inputElement)||void 0===i||i.setSelectionRange(0,this.state.value.length));var s=this.props.min!==t.min,l=this.props.max!==t.max,c=s||l,u=this.props.locale!==t.locale,d=this.state.value!==r.value;if(c&&d||u&&r.value!==n.VALUE_EMPTY){var h=zn(u?r.value:this.state.value,t.locale),p=jn(+h,this.props.locale);null===(a=(o=this.props).onValueChange)||void 0===a||a.call(o,+h,p,this.inputElement)}},t.prototype.validateProps=function(e){var t=e.majorStepSize,r=e.max,i=e.min,o=e.minorStepSize,a=e.stepSize,s=e.value;if(null!=i&&null!=r&&i>r&&console.error(Xe.x),a<=0&&console.error(Xe.y),o&&o<=0&&console.error(Xe.w),t&&t<=0&&console.error(Xe.u),o&&o>a&&console.error(Xe.v),t&&t<a&&console.error(Xe.t),null!=s){var l=n.getStepMaxPrecision(e),c=n.roundAndClampValue(s.toString(),l,i,r,0,this.props.locale),u=c!==s.toString(),d=jn(Number(zn(s,this.props.locale)),this.props.locale);u&&c!==d&&console.warn(Xe.s)}},t.prototype.renderButtons=function(){var e=this.props,t=e.intent,n=e.max,r=e.min,i=e.locale,o=zn(this.state.value,i),s=this.props.disabled||this.props.readOnly,l=void 0!==n&&""!==o&&+o>=n,c=void 0!==r&&""!==o&&+o<=r;return d.createElement(sn,{className:a.FIXED,key:"button-group",vertical:!0},d.createElement(kt,Object(u.__assign)({"aria-label":"increment",disabled:s||l,icon:"chevron-up",intent:t},this.incrementButtonHandlers)),d.createElement(kt,Object(u.__assign)({"aria-label":"decrement",disabled:s||c,icon:"chevron-down",intent:t},this.decrementButtonHandlers)))},t.prototype.renderInput=function(){var e=E(this.props,Fn,!0);return d.createElement(Dn,Object(u.__assign)({asyncControl:this.props.asyncControl,autoComplete:"off"},e,{intent:this.state.currentImeInputInvalid?w.a.DANGER:this.props.intent,inputRef:this.inputRef,large:this.props.large,leftIcon:this.props.leftIcon,onFocus:this.handleInputFocus,onBlur:this.handleInputBlur,onChange:this.handleInputChange,onCompositionEnd:this.handleCompositionEnd,onCompositionUpdate:this.handleCompositionUpdate,onKeyDown:this.handleInputKeyDown,onKeyPress:this.handleInputKeyPress,onPaste:this.handleInputPaste,rightElement:this.props.rightElement,value:this.state.value}))},t.prototype.getButtonEventHandlers=function(e){var t=this;return{onKeyDown:function(n){!t.props.disabled&&r.isKeyboardClick(n.keyCode)&&t.handleButtonClick(n,e)},onMouseDown:function(n){t.props.disabled||(t.handleButtonClick(n,e),t.startContinuousChange())}}},t.prototype.startContinuousChange=function(){var e=this;document.addEventListener("mouseup",this.stopContinuousChange),this.setTimeout((function(){e.intervalId=window.setInterval(e.handleContinuousChange,n.CONTINUOUS_CHANGE_INTERVAL)}),n.CONTINUOUS_CHANGE_DELAY)},t.prototype.handleNextValue=function(e){var t,n;null==this.props.value&&this.setState({value:e}),null===(n=(t=this.props).onValueChange)||void 0===n||n.call(t,Number(zn(e,this.props.locale)),e,this.inputElement)},t.prototype.incrementValue=function(e){var t=this.state.value===n.VALUE_EMPTY?n.VALUE_ZERO:this.state.value,r=this.roundAndClampValue(t,e);return r!==this.state.value&&(this.handleNextValue(r),this.setState({shouldSelectAfterUpdate:this.props.selectAllOnIncrement})),r},t.prototype.getIncrementDelta=function(e,t,n){var r=this.props,i=r.majorStepSize,o=r.minorStepSize,a=r.stepSize;return t&&null!=i?e*i:n&&null!=o?e*o:e*a},t.prototype.roundAndClampValue=function(e,t){return void 0===t&&(t=0),n.roundAndClampValue(e,this.state.stepMaxPrecision,this.props.min,this.props.max,t,this.props.locale)},t.prototype.updateDelta=function(e,t){return this.delta=this.getIncrementDelta(e,t.shiftKey,t.altKey),this.delta},t.displayName=C+".NumericInput",t.VALUE_EMPTY="",t.VALUE_ZERO="0",t.defaultProps={allowNumericCharactersOnly:!0,buttonPosition:A.a.RIGHT,clampValueOnBlur:!1,defaultValue:n.VALUE_EMPTY,large:!1,majorStepSize:10,minorStepSize:.1,selectAllOnFocus:!1,selectAllOnIncrement:!1,stepSize:1},t.CONTINUOUS_CHANGE_DELAY=300,t.CONTINUOUS_CHANGE_INTERVAL=100,t=n=Object(u.__decorate)([_e.polyfill],t)}(g),Vn=0;function Un(){return Wn.displayName+"-"+Vn++}for(var Wn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.autoGroupName=Un(),t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props.label;return d.createElement("div",{className:this.props.className},null==e?null:d.createElement("label",{className:a.LABEL},e),Array.isArray(this.props.options)?this.renderOptions():this.renderChildren())},t.prototype.validateProps=function(){null!=this.props.children&&null!=this.props.options&&console.warn(Xe.M)},t.prototype.renderChildren=function(){var e=this;return d.Children.map(this.props.children,(function(t){return he(t,Sn)?d.cloneElement(t,e.getRadioProps(t.props)):t}))},t.prototype.renderOptions=function(){var e,t=this;return null===(e=this.props.options)||void 0===e?void 0:e.map((function(e){return d.createElement(Sn,Object(u.__assign)({},t.getRadioProps(e),{key:e.value,labelElement:e.label||e.value}))}))},t.prototype.getRadioProps=function(e){var t=this.props.name,n=e.className,r=e.disabled,i=e.value;return{checked:i===this.props.selectedValue,className:n,disabled:r||this.props.disabled,inline:this.props.inline,name:null==t?this.autoGroupName:t,onChange:this.props.onChange,value:i}},t.displayName=C+".RadioGroup",t=Object(u.__decorate)([_e.polyfill],t)}(g),Gn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={},t.textareaElement=null,t.handleRef=D(t,"textareaElement",t.props.inputRef),t.handleChange=function(e){t.props.growVertically&&t.setState({height:e.target.scrollHeight}),null!=t.props.onChange&&t.props.onChange(e)},t}return Object(u.__extends)(t,e),t.prototype.componentDidMount=function(){var e;this.props.growVertically&&null!==this.textareaElement&&this.setState({height:null===(e=this.textareaElement)||void 0===e?void 0:e.scrollHeight})},t.prototype.componentDidUpdate=function(e){e.inputRef!==this.props.inputRef&&(T(e.inputRef,null),this.handleRef=D(this,"textareaElement",this.props.inputRef),T(this.props.inputRef,this.textareaElement))},t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.fill,i=(t.inputRef,t.intent),o=t.large,s=t.small,l=t.growVertically,c=Object(u.__rest)(t,["className","fill","inputRef","intent","large","small","growVertically"]),h=ve()(a.INPUT,a.intentClass(i),((e={})[a.FILL]=r,e[a.LARGE]=o,e[a.SMALL]=s,e),n),p=c.style,f=void 0===p?{}:p;return l&&null!=this.state.height&&(f=Object(u.__assign)(Object(u.__assign)({},f),{height:this.state.height+"px"})),d.createElement("textarea",Object(u.__assign)({},c,{className:h,onChange:this.handleChange,ref:this.handleRef,style:f}))},t.displayName=C+".TextArea",t=Object(u.__decorate)([_e.polyfill],t)}(g),qn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.disabled,i=t.elementRef,o=t.fill,s=t.iconProps,l=t.large,c=t.minimal,h=t.options,p=void 0===h?[]:h,f=Object(u.__rest)(t,["className","disabled","elementRef","fill","iconProps","large","minimal","options"]),m=ve()(a.HTML_SELECT,((e={})[a.DISABLED]=r,e[a.FILL]=o,e[a.LARGE]=l,e[a.MINIMAL]=c,e),n),g=p.map((function(e){var t="object"==typeof e?e:{value:e};return d.createElement("option",Object(u.__assign)({},t,{key:t.value,children:t.label||t.value}))}));return d.createElement("div",{className:m},d.createElement("select",Object(u.__assign)({disabled:r,ref:i},f,{multiple:!1}),g,f.children),d.createElement(Lt,Object(u.__assign)({icon:"double-caret-vertical",title:"Open dropdown"},s)))},t=Object(u.__decorate)([_e.polyfill],t)}(g),Kn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.bordered,r=t.className,i=t.condensed,o=t.elementRef,s=t.interactive,l=t.small,c=t.striped,h=Object(u.__rest)(t,["bordered","className","condensed","elementRef","interactive","small","striped"]),p=ve()(a.HTML_TABLE,((e={})[a.HTML_TABLE_BORDERED]=n,e[a.HTML_TABLE_CONDENSED]=i,e[a.HTML_TABLE_STRIPED]=c,e[a.INTERACTIVE]=s,e[a.SMALL]=l,e),r);return d.createElement("table",Object(u.__assign)({},h,{ref:o,className:p}))},t=Object(u.__decorate)([_e.polyfill],t)}(g),Xn={8:"backspace",9:"tab",13:"enter",20:"capslock",27:"esc",32:"space",33:"pageup",34:"pagedown",35:"end",36:"home",37:"left",38:"up",39:"right",40:"down",45:"ins",46:"del",48:"0",49:"1",50:"2",51:"3",52:"4",53:"5",54:"6",55:"7",56:"8",57:"9",65:"a",66:"b",67:"c",68:"d",69:"e",70:"f",71:"g",72:"h",73:"i",74:"j",75:"k",76:"l",77:"m",78:"n",79:"o",80:"p",81:"q",82:"r",83:"s",84:"t",85:"u",86:"v",87:"w",88:"x",89:"y",90:"z",106:"*",107:"+",109:"-",110:".",111:"/",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'"},Jn={16:"shift",17:"ctrl",18:"alt",91:"meta",93:"meta",224:"meta"},Qn={alt:1,ctrl:2,meta:4,shift:8},Zn={cmd:"meta",command:"meta",escape:"esc",minus:"-",mod:or()?"meta":"ctrl",option:"alt",plus:"+",return:"enter",win:"meta"},$n={"~":"`","!":"1","@":"2","#":"3",$:"4","%":"5","^":"6","&":"7","*":"8","(":"9",")":"0",_:"-","+":"=","{":"[","}":"]","|":"\\",":":";",'"':"'","<":",",">":".","?":"/"},er=1;er<=12;++er)Xn[111+er]="f"+er;for(er=0;er<=9;++er)Xn[96+er]="num"+er.toString();function tr(e,t){return e.modifiers===t.modifiers&&e.key===t.key}var nr=function(e){for(var t,n=0,r=0,i=e.replace(/\s/g,"").toLowerCase().split("+");r<i.length;r++){var o=i[r];if(""===o)throw new Error('Failed to parse key combo "'+e+'".\n                Valid key combos look like "cmd + plus", "shift+p", or "!"');null!=Zn[o]&&(o=Zn[o]),null!=Qn[o]?n+=Qn[o]:null!=$n[o]?(n+=Qn.shift,t=$n[o]):t=o.toLowerCase()}return{modifiers:n,key:t}},rr=function(e){var t=[];e.ctrlKey&&t.push("ctrl"),e.altKey&&t.push("alt"),e.shiftKey&&t.push("shift"),e.metaKey&&t.push("meta");var n=e.which;return null!=Jn[n]||(null!=Xn[n]?t.push(Xn[n]):t.push(String.fromCharCode(n).toLowerCase())),t.join(" + ")},ir=function(e){var t,n=e.which;null!=Jn[n]||(t=null!=Xn[n]?Xn[n]:String.fromCharCode(n).toLowerCase());var r=0;return e.altKey&&(r+=Qn.alt),e.ctrlKey&&(r+=Qn.ctrl),e.metaKey&&(r+=Qn.meta),e.shiftKey&&(r+=Qn.shift),{modifiers:r,key:t}};function or(e){var t=null!=e?e:"undefined"!=typeof navigator?navigator.platform:void 0;return null!=t&&/Mac|iPod|iPhone|iPad/.test(t)}var ar={alt:{icon:"key-option",iconTitle:"Alt/Option key"},cmd:{icon:"key-command",iconTitle:"Command key"},ctrl:{icon:"key-control",iconTitle:"Control key"},delete:{icon:"key-delete",iconTitle:"Delete key"},down:{icon:"arrow-down",iconTitle:"Down key"},enter:{icon:"key-enter",iconTitle:"Enter key"},left:{icon:"arrow-left",iconTitle:"Left key"},meta:{icon:"key-command",iconTitle:"Command key"},right:{icon:"arrow-right",iconTitle:"Right key"},shift:{icon:"key-shift",iconTitle:"Shift key"},up:{icon:"arrow-up",iconTitle:"Up key"}},sr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.renderKey=function(e,t){var n,r=ar[e],i="key-"+t;return d.createElement("kbd",{className:ve()(a.KEY,(n={},n[a.MODIFIER_KEY]=null!=r,n)),key:i},null!=r&&d.createElement(Lt,{icon:r.icon,title:r.iconTitle}),e)},t.renderMinimalKey=function(e,t){var n=ar[e];return null==n?e:d.createElement(Lt,{icon:n.icon,title:n.iconTitle,key:"key-"+t})},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.combo,r=e.minimal,i=function(e,t){return e.replace(/\s/g,"").split("+").map((function(e){var n=null!=Zn[e]?Zn[e]:e;return"meta"===n?or(t)?"cmd":"ctrl":n}))}(n).map((function(e){return 1===e.length?e.toUpperCase():e})).map(r?this.renderMinimalKey:this.renderKey);return d.createElement("span",{className:ve()(a.KEY_COMBO,t)},i)},t.displayName=C+".KeyCombo",t=Object(u.__decorate)([_e.polyfill],t)}(g),lr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.label,n=e.className,r=Object(u.__rest)(e,["label","className"]),i=ve()(a.HOTKEY,n);return d.createElement("div",{className:i},d.createElement("div",{className:a.HOTKEY_LABEL},t),d.createElement(sr,Object(u.__assign)({},r)))},t.prototype.validateProps=function(e){!0!==e.global&&null==e.group&&console.error("non-global <Hotkey>s must define a group")},t.displayName=C+".Hotkey",t.defaultProps={allowInInput:!1,disabled:!1,global:!1,preventDefault:!1,stopPropagation:!1},t=Object(u.__decorate)([_e.polyfill],t)}(g),cr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){if(!ce(this.props.children))return null;var e,t=d.Children.map(this.props.children,(function(e){return e.props}));t.sort((function(e,t){return e.global===t.global&&e.group&&t.group?e.group.localeCompare(t.group):e.global?-1:1}));for(var n=[],r=0,i=t;r<i.length;r++){var o=i[r],s=o.group;s!==e&&(n.push(d.createElement(Bt,{key:"group-"+n.length},s)),e=s),n.push(d.createElement(lr,Object(u.__assign)({key:n.length},o)))}var l=ve()(a.HOTKEY_COLUMN,this.props.className);return d.createElement("div",{className:l},n)},t.prototype.validateProps=function(e){ce(e.children)&&d.Children.forEach(e.children,(function(e){if(!he(e,lr))throw new Error(Xe.l)}))},t.displayName=C+".Hotkeys",t.defaultProps={tabIndex:0},t=Object(u.__decorate)([_e.polyfill],t)}(g),ur=new(function(){function e(){var e=this;this.componentProps={globalHotkeysGroup:"Global hotkeys"},this.container=null,this.hotkeysQueue=[],this.isDialogShowing=!1,this.show=function(){e.isDialogShowing=!0,e.render()},this.hide=function(){e.isDialogShowing=!1,e.render()}}return e.prototype.render=function(){null==this.container&&(this.container=this.getContainer()),ye.render(this.renderComponent(),this.container)},e.prototype.unmount=function(){null!=this.container&&(ye.unmountComponentAtNode(this.container),this.container.remove(),this.container=null)},e.prototype.enqueueHotkeysForDisplay=function(e){this.hotkeysQueue.push(e),window.clearTimeout(this.showTimeoutToken),this.showTimeoutToken=window.setTimeout(this.show,10)},e.prototype.hideAfterDelay=function(){window.clearTimeout(this.hideTimeoutToken),this.hideTimeoutToken=window.setTimeout(this.hide,10)},e.prototype.isShowing=function(){return this.isDialogShowing},e.prototype.getContainer=function(){return null==this.container&&(this.container=document.createElement("div"),this.container.classList.add(a.PORTAL),document.body.appendChild(this.container)),this.container},e.prototype.renderComponent=function(){return d.createElement(Kt,Object(u.__assign)({},this.componentProps,{className:ve()(a.HOTKEY_DIALOG,this.componentProps.className),isOpen:this.isDialogShowing,onClose:this.hide}),d.createElement("div",{className:a.DIALOG_BODY},this.renderHotkeys()))},e.prototype.renderHotkeys=function(){var e=this,t=this.emptyHotkeyQueue().map((function(t,n){var r=!0===t.global&&null==t.group?e.componentProps.globalHotkeysGroup:t.group;return d.createElement(lr,Object(u.__assign)({key:n},t,{group:r}))}));return d.createElement(cr,null,t)},e.prototype.emptyHotkeyQueue=function(){var e=this.hotkeysQueue.reduce((function(e,t){return e.concat(t)}),[]);return this.hotkeysQueue.length=0,e},e}());function dr(){return ur.isShowing()}function hr(e){for(var t in e)e.hasOwnProperty(t)&&(ur.componentProps[t]=e[t])}function pr(){ur.hide()}var fr;!function(e){e.LOCAL="local",e.GLOBAL="global"}(fr||(fr={}));var mr=function(){function e(e){var t=this;this.scope=e,this.actions=[],this.handleKeyDown=function(e){var n,r=ir(e);t.isTextInput(e)||!tr(nr("?"),r)?dr()||t.invokeNamedCallbackIfComboRecognized(r,"onKeyDown",e):dr()?ur.hideAfterDelay():(n=t.actions.map((function(e){return e.props})),ur.enqueueHotkeysForDisplay(n))},this.handleKeyUp=function(e){dr()||t.invokeNamedCallbackIfComboRecognized(ir(e),"onKeyUp",e)}}return e.prototype.count=function(){return this.actions.length},e.prototype.clear=function(){this.actions=[]},e.prototype.setHotkeys=function(e){var t=this,n=[];d.Children.forEach(e.children,(function(e){he(e,lr)&&t.isScope(e.props)&&n.push({combo:nr(e.props.combo),props:e.props})})),this.actions=n},e.prototype.invokeNamedCallbackIfComboRecognized=function(e,t,n){for(var r,i,o=this.isTextInput(n),a=0,s=this.actions;a<s.length;a++){var l=s[a];!(o&&!l.props.allowInInput||l.props.disabled)&&tr(l.combo,e)&&(l.props.preventDefault&&n.preventDefault(),l.props.stopPropagation&&(n.isPropagationStopped=!0,n.stopPropagation()),null===(i=(r=l.props)[t])||void 0===i||i.call(r,n))}},e.prototype.isScope=function(e){return(e.global?fr.GLOBAL:fr.LOCAL)===this.scope},e.prototype.isTextInput=function(e){var t=e.target;if(null==t||null==t.closest)return!1;var n=t.closest("input, textarea, [contenteditable=true]");if(null==n)return!1;if("input"===n.tagName.toLowerCase()){var r=n.type;if("checkbox"===r||"radio"===r)return!1}return!n.readOnly},e}();function gr(e){var t;return ee(e.prototype.renderHotkeys)||console.warn(Xe.o),(t=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.globalHotkeysEvents=new mr(fr.GLOBAL),t.localHotkeysEvents=new mr(fr.LOCAL),t}return Object(u.__extends)(t,e),t.prototype.componentDidMount=function(){null!=e.prototype.componentDidMount&&e.prototype.componentDidMount.call(this),document.addEventListener("keydown",this.globalHotkeysEvents.handleKeyDown),document.addEventListener("keyup",this.globalHotkeysEvents.handleKeyUp)},t.prototype.componentWillUnmount=function(){var t;null===(t=e.prototype.componentWillUnmount)||void 0===t||t.call(this),document.removeEventListener("keydown",this.globalHotkeysEvents.handleKeyDown),document.removeEventListener("keyup",this.globalHotkeysEvents.handleKeyUp),this.globalHotkeysEvents.clear(),this.localHotkeysEvents.clear()},t.prototype.render=function(){var t=this,n=e.prototype.render.call(this);if(null==n)return n;if(!d.isValidElement(n))return console.warn(Xe.n),n;if(ee(this.renderHotkeys)){var r=this.renderHotkeys();if(this.localHotkeysEvents&&this.localHotkeysEvents.setHotkeys(r.props),this.globalHotkeysEvents&&this.globalHotkeysEvents.setHotkeys(r.props),this.localHotkeysEvents.count()>0){var i=void 0===r.props.tabIndex?0:r.props.tabIndex,o=n.props,a=o.onKeyDown,s=o.onKeyUp;return d.cloneElement(n,{onKeyDown:function(e){t.localHotkeysEvents.handleKeyDown(e.nativeEvent),null==a||a(e)},onKeyUp:function(e){t.localHotkeysEvents.handleKeyUp(e.nativeEvent),null==s||s(e)},tabIndex:i})}}return n},t}(e)).displayName="HotkeysTarget("+de(e)+")",t}var vr,yr=function(e){var t=e.globalGroupName,n=void 0===t?"Global":t,r=e.hotkeys,i=Object(u.__rest)(e,["globalGroupName","hotkeys"]);return d.createElement(Kt,Object(u.__assign)({},i,{className:ve()(a.HOTKEY_DIALOG,i.className)}),d.createElement("div",{className:a.DIALOG_BODY},d.createElement(cr,null,r.map((function(e,t){return d.createElement(lr,Object(u.__assign)({key:t},e,{group:!0===e.global&&null==e.group?n:e.group}))})))))},_r={hotkeys:[],isDialogOpen:!1},br=null===(vr=d.createContext)||void 0===vr?void 0:vr.call(d,[_r,function(){return null}]),Mr=function(e,t){switch(t.type){case"ADD_HOTKEYS":for(var n=[],r=0,i=t.payload;r<i.length;r++){for(var o=i[r],a=!0,s=0,l=e.hotkeys;s<l.length;s++){var c=l[s];a&&(a=!q(o,c,{exclude:["onKeyDown","onKeyUp"]}))}a&&n.push(o)}return Object(u.__assign)(Object(u.__assign)({},e),{hotkeys:Object(u.__spreadArrays)(e.hotkeys,n)});case"REMOVE_HOTKEYS":return Object(u.__assign)(Object(u.__assign)({},e),{hotkeys:e.hotkeys.filter((function(e){return-1===t.payload.indexOf(e)}))});case"OPEN_DIALOG":return Object(u.__assign)(Object(u.__assign)({},e),{isDialogOpen:!0});case"CLOSE_DIALOG":return Object(u.__assign)(Object(u.__assign)({},e),{isDialogOpen:!1});default:return e}},wr=function(e){var t,n=e.children,r=e.dialogProps,i=e.renderDialog,o=e.value,a=null!=o,s=null!=o?o:d.useReducer(Mr,_r),l=s[0],c=s[1],h=d.useCallback((function(){return c({type:"CLOSE_DIALOG"})}),[]),p=null!==(t=null==i?void 0:i(l,{handleDialogClose:h}))&&void 0!==t?t:d.createElement(yr,Object(u.__assign)({},r,{isOpen:l.isDialogOpen,hotkeys:l.hotkeys,onClose:h}));return d.createElement(br.Provider,{value:[l,c]},n,a?void 0:p)};function Ar(e,t){void 0===t&&(t={});var n=t.document,r=void 0===n?function(){if("undefined"==typeof window)return;return window.document}():n,i=t.showDialogKeyCombo,o=void 0===i?"?":i,a=d.useMemo((function(){return e.filter((function(e){return!e.global})).map((function(e){return{combo:nr(e.combo),config:e}}))}),[e]),s=d.useMemo((function(){return e.filter((function(e){return e.global})).map((function(e){return{combo:nr(e.combo),config:e}}))}),[e]),l=d.useContext(br)[1];d.useEffect((function(){var e=Object(u.__spreadArrays)(s.map((function(e){return e.config})),a.map((function(e){return e.config})));return l({type:"ADD_HOTKEYS",payload:e}),function(){return l({type:"REMOVE_HOTKEYS",payload:e})}}),[e]);var c=function(e,t,n,r){for(var i,o,l=Cr(r),c=0,u=e?s:a;c<u.length;c++){var d=u[c],h=d.config,p=h.allowInInput,f=void 0!==p&&p,m=h.disabled,g=void 0!==m&&m,v=h.preventDefault,y=void 0!==v&&v,_=h.stopPropagation,b=void 0!==_&&_;!(l&&!f||g)&&tr(d.combo,t)&&(y&&r.preventDefault(),b&&(r.isPropagationStopped=!0,r.stopPropagation()),null===(o=(i=d.config)[n])||void 0===o||o.call(i,r))}},h=d.useCallback((function(e){var t=ir(e);!Cr(e)&&tr(nr(o),t)?l({type:"OPEN_DIALOG"}):c(!0,ir(e),"onKeyDown",e)}),[s]),p=d.useCallback((function(e){return c(!0,ir(e),"onKeyUp",e)}),[s]),f=d.useCallback((function(e){return c(!1,ir(e.nativeEvent),"onKeyDown",e.nativeEvent)}),[a]),m=d.useCallback((function(e){return c(!1,ir(e.nativeEvent),"onKeyUp",e.nativeEvent)}),[a]);return d.useEffect((function(){return r.addEventListener("keydown",h),r.addEventListener("keyup",p),function(){r.removeEventListener("keydown",h),r.removeEventListener("keyup",p)}}),[h,p]),{handleKeyDown:f,handleKeyUp:m}}function Cr(e){var t=e.target;if(null==t||null==t.closest)return!1;var n=t.closest("input, textarea, [contenteditable=true]");if(null==n)return!1;if("input"===n.tagName.toLowerCase()){var r=n.type;if("checkbox"===r||"radio"===r)return!1}return!n.readOnly}var xr=function(e){var t=e.children,n=e.hotkeys,r=e.options,i=Ar(n,r),o=i.handleKeyDown,a=i.handleKeyUp;return d.useEffect((function(){Object(h.e)("production")||"function"!=typeof t&&n.some((function(e){return!e.global}))&&console.error(Xe.m)}),[n]),"function"==typeof t?t({handleKeyDown:o,handleKeyUp:a}):t},Er=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=Object(u.__rest)(e,["className"]);return d.createElement("div",Object(u.__assign)({className:ve()(a.NAVBAR_DIVIDER,t)},n))},t.displayName=C+".NavbarDivider",t=Object(u.__decorate)([_e.polyfill],t)}(g),Lr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.align,n=e.children,r=e.className,i=Object(u.__rest)(e,["align","children","className"]),o=ve()(a.NAVBAR_GROUP,a.alignmentClass(t),r);return d.createElement("div",Object(u.__assign)({className:o},i),n)},t.displayName=C+".NavbarGroup",t.defaultProps={align:v.a.LEFT},t=Object(u.__decorate)([_e.polyfill],t)}(g),Sr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.children,n=e.className,r=Object(u.__rest)(e,["children","className"]);return d.createElement("div",Object(u.__assign)({className:ve()(a.NAVBAR_HEADING,n)},r),t)},t.displayName=C+".NavbarHeading",t=Object(u.__decorate)([_e.polyfill],t)}(g),Tr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.children,r=t.className,i=t.fixedToTop,o=Object(u.__rest)(t,["children","className","fixedToTop"]),s=ve()(a.NAVBAR,((e={})[a.FIXED_TOP]=i,e),r);return d.createElement("div",Object(u.__assign)({className:s},o),n)},t.displayName=C+".Navbar",t.Divider=Er,t.Group=Lr,t.Heading=Sr,t=Object(u.__decorate)([_e.polyfill],t)}(g),Or=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.action,n=e.children,r=e.className,i=e.description,o=e.title;return d.createElement("div",{className:ve()(a.NON_IDEAL_STATE,r)},this.maybeRenderVisual(),o&&d.createElement(Bt,null,o),i&&ue(i,"div"),t,n)},t.prototype.maybeRenderVisual=function(){var e=this.props.icon;return null==e?null:d.createElement("div",{className:a.NON_IDEAL_STATE_VISUAL},d.createElement(Lt,{icon:e,size:3*Ct.LARGE}))},t.displayName=C+".NonIdealState",t=Object(u.__decorate)([_e.polyfill],t)}(g),Ir=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleClose=function(){return t.props.onClose(t.props.panel)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.panel,n=e.onOpen;return d.createElement("div",{className:a.PANEL_STACK_VIEW},this.maybeRenderHeader(),d.createElement(t.component,Object(u.__assign)({openPanel:n,closePanel:this.handleClose},t.props)))},t.prototype.maybeRenderHeader=function(){return this.props.showHeader?d.createElement("div",{className:a.PANEL_STACK_HEADER},d.createElement("span",null,this.maybeRenderBack()),d.createElement(Zt,{className:a.HEADING,ellipsize:!0,title:this.props.panel.htmlTitle},this.props.panel.title),d.createElement("span",null)):null},t.prototype.maybeRenderBack=function(){return void 0===this.props.previousPanel?null:d.createElement(kt,{"aria-label":"Back",className:a.PANEL_STACK_HEADER_BACK,icon:"chevron-left",minimal:!0,onClick:this.handleClose,small:!0,text:this.props.previousPanel.title,title:this.props.previousPanel.htmlTitle})},t=Object(u.__decorate)([_e.polyfill],t)}(g),kr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={direction:"push",stack:null!=t.props.stack?t.props.stack.slice().reverse():void 0!==t.props.initialPanel?[t.props.initialPanel]:[]},t.renderPanel=function(e,n){var r=t.props,i=r.renderActivePanelOnly,o=r.showPanelHeader,s=void 0===o||o,l=t.state.stack,c=l.length-n,u=i?l.length:c;return d.createElement(Je.CSSTransition,{classNames:a.PANEL_STACK,key:u,timeout:400},d.createElement(Ir,{onClose:t.handlePanelClose,onOpen:t.handlePanelOpen,panel:e,previousPanel:l[n+1],showHeader:s}))},t.handlePanelClose=function(e){var n,r,i=t.state.stack;i[0]!==e||i.length<=1||(null===(r=(n=t.props).onClose)||void 0===r||r.call(n,e),null==t.props.stack&&t.setState((function(e){return{direction:"pop",stack:e.stack.slice(1)}})))},t.handlePanelOpen=function(e){var n,r;null===(r=(n=t.props).onOpen)||void 0===r||r.call(n,e),null==t.props.stack&&t.setState((function(t){return{direction:"push",stack:Object(u.__spreadArrays)([e],t.stack)}}))},t}return Object(u.__extends)(t,e),t.prototype.componentDidUpdate=function(t,n){e.prototype.componentDidUpdate.call(this,t,n),this.props.stack!==t.stack&&null!=t.stack&&this.setState({stack:this.props.stack.slice().reverse()}),(null!=this.props.stack?this.props.stack.length:0)!==(null!=t.stack?t.stack.length:0)&&null!=t.stack&&this.setState({direction:t.stack.length-this.props.stack.length<0?"push":"pop"})},t.prototype.render=function(){var e=ve()(a.PANEL_STACK,a.PANEL_STACK+"-"+this.state.direction,this.props.className);return d.createElement(Je.TransitionGroup,{className:e,component:"div"},this.renderPanels())},t.prototype.validateProps=function(e){(null==e.initialPanel&&null==e.stack||null!=e.initialPanel&&null!=e.stack)&&console.error(Xe.A),null!=e.stack&&0===e.stack.length&&console.error(Xe.B)},t.prototype.renderPanels=function(){var e=this.props.renderActivePanelOnly,t=void 0===e||e,n=this.state.stack;return 0===n.length?null:(t?[n[0]]:n).map(this.renderPanel).reverse()},t=Object(u.__decorate)([_e.polyfill],t)}(g),Dr=function(e){var t=d.useCallback((function(){return e.onClose(e.panel)}),[e.onClose,e.panel]),n=void 0===e.previousPanel?null:d.createElement(kt,{"aria-label":"Back",className:a.PANEL_STACK_HEADER_BACK,icon:"chevron-left",minimal:!0,onClick:t,small:!0,text:e.previousPanel.title,title:e.previousPanel.htmlTitle}),r=d.useMemo((function(){return function(){return e.panel.renderPanel(Object(u.__assign)({closePanel:t,openPanel:e.onOpen},e.panel.props))}}),[e.panel,e.onOpen]);return d.createElement("div",{className:a.PANEL_STACK2_VIEW},e.showHeader&&d.createElement("div",{className:a.PANEL_STACK2_HEADER},d.createElement("span",null,n),d.createElement(Zt,{className:a.HEADING,ellipsize:!0,title:e.panel.htmlTitle},e.panel.title),d.createElement("span",null)),d.createElement(r,null))};Dr.displayName=C+".PanelView2";var Nr=function(e){var t=e.renderActivePanelOnly,n=void 0===t||t,r=e.showPanelHeader,i=void 0===r||r,o=e.stack,s=d.useState("push"),l=s[0],c=s[1],h=d.useState(void 0!==e.initialPanel?[e.initialPanel]:[]),p=h[0],f=h[1],m=d.useMemo((function(){return null!=o?o.slice().reverse():p}),[p,o]),g=d.useRef(m.length);d.useEffect((function(){m.length!==g.current&&c(m.length-g.current<0?"pop":"push"),g.current=m.length}),[m]);var v=d.useCallback((function(t){var n;null===(n=e.onOpen)||void 0===n||n.call(e,t),null==e.stack&&f((function(e){return Object(u.__spreadArrays)([t],e)}))}),[e.onOpen]),y=d.useCallback((function(t){var n;m[0]!==t||m.length<=1||(null===(n=e.onClose)||void 0===n||n.call(e,t),null==e.stack&&f((function(e){return e.slice(1)})))}),[m,e.onClose]);if(0===m.length)return null;var _=(n?[m[0]]:m).map((function(e,t){var r=m.length-t,o=n?m.length:r;return d.createElement(Je.CSSTransition,{classNames:a.PANEL_STACK2,key:o,timeout:400},d.createElement(Dr,{onClose:y,onOpen:v,panel:e,previousPanel:m[t+1],showHeader:i}))})).reverse(),b=ve()(a.PANEL_STACK2,a.PANEL_STACK2+"-"+l,e.className);return d.createElement(Je.TransitionGroup,{className:b,component:"div"},_)};Nr.displayName=C+".PanelStack2";var jr=Object(u.__assign)(Object(u.__assign)({},A.a),{AUTO:"auto",AUTO_END:"auto-end",AUTO_START:"auto-start"}),Pr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.animate,r=void 0===n||n,i=t.className,o=t.intent,s=t.stripes,l=void 0===s||s,c=t.value,u=ve()(a.PROGRESS_BAR,a.intentClass(o),((e={})[a.PROGRESS_NO_ANIMATION]=!r,e[a.PROGRESS_NO_STRIPES]=!l,e),i),p=null==c?void 0:100*Object(h.c)(c,0,1),f=null==p?void 0:p+"%";return d.createElement("div",{"aria-valuemax":100,"aria-valuemin":0,"aria-valuenow":null==p?void 0:Math.round(p),className:u,role:"progressbar"},d.createElement("div",{className:a.PROGRESS_METER,style:{width:f}}))},t.displayName=C+".ProgressBar",t=Object(u.__decorate)([_e.polyfill],t)}(g),zr={FULL:"full",START:"start",END:"end"},Rr={LOCK:"lock",PUSH:"push",NONE:"none"};function Br(e){return(100*e).toFixed(2)+"%"}function Hr(e,t,n,r){for(var i=t<n?1:-1,o=t;o!==n+i;o+=i)e[o]=r}var Fr=["max","min","stepSize","tickSize","value"],Yr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={isMoving:!1},t.handleElement=null,t.refHandlers={handle:function(e){return t.handleElement=e}},t.beginHandleMovement=function(e){document.addEventListener("mousemove",t.handleHandleMovement),document.addEventListener("mouseup",t.endHandleMovement),t.setState({isMoving:!0}),t.changeValue(t.clientToValue(t.mouseEventClientOffset(e)))},t.beginHandleTouchMovement=function(e){document.addEventListener("touchmove",t.handleHandleTouchMovement),document.addEventListener("touchend",t.endHandleTouchMovement),document.addEventListener("touchcancel",t.endHandleTouchMovement),t.setState({isMoving:!0}),t.changeValue(t.clientToValue(t.touchEventClientOffset(e)))},t.getStyleProperties=function(){if(null==t.handleElement)return{};var e=t.props,n=e.min,r=void 0===n?0:n,i=e.tickSizeRatio,o=e.value,a=e.vertical,s=t.getHandleMidpointAndOffset(t.handleElement,!0).handleMidpoint,l="calc("+Br((o-r)*i)+" - "+s+"px)";return a?{bottom:l}:{left:l}},t.endHandleMovement=function(e){t.handleMoveEndedAt(t.mouseEventClientOffset(e))},t.endHandleTouchMovement=function(e){t.handleMoveEndedAt(t.touchEventClientOffset(e))},t.handleMoveEndedAt=function(e){var n,r;t.removeDocumentEventListeners(),t.setState({isMoving:!1});var i=t.changeValue(t.clientToValue(e));null===(r=(n=t.props).onRelease)||void 0===r||r.call(n,i)},t.handleHandleMovement=function(e){t.handleMovedTo(t.mouseEventClientOffset(e))},t.handleHandleTouchMovement=function(e){t.handleMovedTo(t.touchEventClientOffset(e))},t.handleMovedTo=function(e){t.state.isMoving&&!t.props.disabled&&t.changeValue(t.clientToValue(e))},t.handleKeyDown=function(e){var n=t.props,i=n.stepSize,o=n.value,a=e.which;a===r.ARROW_DOWN||a===r.ARROW_LEFT?(t.changeValue(o-i),e.preventDefault()):a!==r.ARROW_UP&&a!==r.ARROW_RIGHT||(t.changeValue(o+i),e.preventDefault())},t.handleKeyUp=function(e){var n,i;[r.ARROW_UP,r.ARROW_DOWN,r.ARROW_LEFT,r.ARROW_RIGHT].indexOf(e.which)>=0&&(null===(i=(n=t.props).onRelease)||void 0===i||i.call(n,t.props.value))},t}return Object(u.__extends)(t,e),t.prototype.componentDidMount=function(){this.forceUpdate()},t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.disabled,i=t.label,o=this.state.isMoving;return d.createElement("span",{className:ve()(a.SLIDER_HANDLE,(e={},e[a.ACTIVE]=o,e),n),onKeyDown:r?void 0:this.handleKeyDown,onKeyUp:r?void 0:this.handleKeyUp,onMouseDown:r?void 0:this.beginHandleMovement,onTouchStart:r?void 0:this.beginHandleTouchMovement,ref:this.refHandlers.handle,style:this.getStyleProperties(),tabIndex:0},null==i?null:d.createElement("span",{className:a.SLIDER_LABEL},i))},t.prototype.componentWillUnmount=function(){this.removeDocumentEventListeners()},t.prototype.clientToValue=function(e){var t=this.props,n=t.stepSize,r=t.tickSize,i=t.value,o=t.vertical;if(null==this.handleElement)return i;var a=(o?window.innerHeight-e:e)-this.getHandleElementCenterPixel(this.handleElement);return isNaN(a)?i:i+Math.round(a/(r*n))*n},t.prototype.mouseEventClientOffset=function(e){return this.props.vertical?e.clientY:e.clientX},t.prototype.touchEventClientOffset=function(e){var t=e.changedTouches[0];return this.props.vertical?t.clientY:t.clientX},t.prototype.validateProps=function(e){for(var t=0,n=Fr;t<n.length;t++){var r=n[t];if("number"!=typeof e[r])throw new Error("[Blueprint] <Handle> requires number value for "+r+" prop")}},t.prototype.changeValue=function(e,t){return void 0===t&&(t=this.props.onChange),e=this.clamp(e),isNaN(e)||this.props.value===e||null==t||t(e),e},t.prototype.clamp=function(e){return Object(h.c)(e,this.props.min,this.props.max)},t.prototype.getHandleElementCenterPixel=function(e){var t=this.getHandleMidpointAndOffset(e),n=t.handleMidpoint;return t.handleOffset+n},t.prototype.getHandleMidpointAndOffset=function(e,t){if(void 0===t&&(t=!1),null==e)return{handleMidpoint:0,handleOffset:0};var n=this.props.vertical,r=e.getBoundingClientRect(),i=n?t?"width":"height":t?"height":"width",o=n?window.innerHeight-(r.top+r[i]):r.left;return{handleMidpoint:r[i]/2,handleOffset:o}},t.prototype.removeDocumentEventListeners=function(){document.removeEventListener("mousemove",this.handleHandleMovement),document.removeEventListener("mouseup",this.endHandleMovement),document.removeEventListener("touchmove",this.handleHandleTouchMovement),document.removeEventListener("touchend",this.endHandleTouchMovement),document.removeEventListener("touchcancel",this.endHandleTouchMovement)},t.displayName=C+".SliderHandle",t=Object(u.__decorate)([_e.polyfill],t)}(g),Vr=function(){return null};Vr.displayName=C+".MultiSliderHandle";var Ur,Wr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={labelPrecision:Gr(t.props),tickSize:0,tickSizeRatio:0},t.handleElements=[],t.trackElement=null,t.addHandleRef=function(e){null!=e&&t.handleElements.push(e)},t.maybeHandleTrackClick=function(e){if(t.canHandleTrackEvent(e)){var n=t.nearestHandleForValue(t.handleElements,(function(t){return t.mouseEventClientOffset(e)}));n&&n.beginHandleMovement(e)}},t.maybeHandleTrackTouch=function(e){if(t.canHandleTrackEvent(e)){var n=t.nearestHandleForValue(t.handleElements,(function(t){return t.touchEventClientOffset(e)}));n&&n.beginHandleTouchMovement(e)}},t.canHandleTrackEvent=function(e){var n=e.target;return!t.props.disabled&&null==n.closest("."+a.SLIDER_HANDLE)},t.getHandlerForIndex=function(e,n){return function(r){null==n||n(t.getNewHandleValues(r,e))}},t.handleChange=function(e){var n,r,i=qr(t.props),o=i.map((function(e){return e.value}));G(e,o)||(null===(r=(n=t.props).onChange)||void 0===r||r.call(n,e),i.forEach((function(t,n){var r;o[n]!==e[n]&&(null===(r=t.onChange)||void 0===r||r.call(t,e[n]))})))},t.handleRelease=function(e){var n,r,i=qr(t.props);null===(r=(n=t.props).onRelease)||void 0===r||r.call(n,e),i.forEach((function(t,n){var r;null===(r=t.onRelease)||void 0===r||r.call(t,e[n])}))},t}var n;return Object(u.__extends)(t,e),n=t,t.getDerivedStateFromProps=function(e){return{labelPrecision:n.getLabelPrecision(e)}},t.getLabelPrecision=function(e){var t=e.labelPrecision,n=e.stepSize;return null==t?h.d(n):t},t.prototype.getSnapshotBeforeUpdate=function(e){var t=qr(e);return qr(this.props).length!==t.length&&(this.handleElements=[]),null},t.prototype.render=function(){var e,t=this,n=ve()(a.SLIDER,((e={})[a.DISABLED]=this.props.disabled,e[a.SLIDER+"-unlabeled"]=!1===this.props.labelRenderer,e[a.VERTICAL]=this.props.vertical,e),this.props.className);return d.createElement("div",{className:n,onMouseDown:this.maybeHandleTrackClick,onTouchStart:this.maybeHandleTrackTouch},d.createElement("div",{className:a.SLIDER_TRACK,ref:function(e){return t.trackElement=e}},this.renderTracks()),d.createElement("div",{className:a.SLIDER_AXIS},this.renderLabels()),this.renderHandles())},t.prototype.componentDidMount=function(){this.updateTickSize()},t.prototype.componentDidUpdate=function(t,n){e.prototype.componentDidUpdate.call(this,t,n),this.updateTickSize()},t.prototype.validateProps=function(e){if(e.stepSize<=0)throw new Error(Xe.P);if(void 0!==e.labelStepSize&&void 0!==e.labelValues)throw new Error(Xe.r);if(void 0!==e.labelStepSize&&e.labelStepSize<=0)throw new Error(Xe.O);var t=!1;if(d.Children.forEach(e.children,(function(e){e&&!he(e,n.Handle)&&(t=!0)})),t)throw new Error(Xe.q)},t.prototype.formatLabel=function(e,t){void 0===t&&(t=!1);var n=this.props.labelRenderer;return!1===n?void 0:ee(n)?n(e,{isHandleTooltip:t}):e.toFixed(this.state.labelPrecision)},t.prototype.renderLabels=function(){var e=this;if(!1===this.props.labelRenderer)return null;var t=this.getLabelValues(),n=this.props,r=n.max,i=n.min;return t.map((function(t,n){var o=Br((t-i)/(r-i)),s=e.props.vertical?{bottom:o}:{left:o};return d.createElement("div",{className:a.SLIDER_LABEL,key:n,style:s},e.formatLabel(t))}))},t.prototype.renderTracks=function(){var e=Kr(this.props);e.push({value:this.props.max});for(var t={value:this.props.min},n=[],r=0;r<e.length;r++){var i=e[r];n.push(this.renderTrackFill(r,t,i)),t=i}return n},t.prototype.renderTrackFill=function(e,t,n){var r=[this.getOffsetRatio(t.value),this.getOffsetRatio(n.value)].sort((function(e,t){return e-t})),i=r[0],o=r[1],s=Br(i),l=Br(1-o),c=this.props.vertical?{bottom:s,top:l,left:0}:{left:s,right:l,top:0},h=Object(u.__assign)(Object(u.__assign)({},c),t.trackStyleAfter||n.trackStyleBefore||{}),p=ve()(a.SLIDER_PROGRESS,a.intentClass(this.getTrackIntent(t,n)));return d.createElement("div",{key:"track-"+e,className:p,style:h})},t.prototype.renderHandles=function(){var e=this,t=this.props,n=t.disabled,r=t.max,i=t.min,o=t.stepSize,s=t.vertical,l=qr(this.props);return 0===l.length?null:l.map((function(t,c){var u,h=t.value,p=t.type,f=t.className;return d.createElement(Yr,{className:ve()((u={},u[a.START]=p===zr.START,u[a.END]=p===zr.END,u),f),disabled:n,key:c+"-"+l.length,label:e.formatLabel(h,!0),max:r,min:i,onChange:e.getHandlerForIndex(c,e.handleChange),onRelease:e.getHandlerForIndex(c,e.handleRelease),ref:e.addHandleRef,stepSize:o,tickSize:e.state.tickSize,tickSizeRatio:e.state.tickSizeRatio,value:h,vertical:s})}))},t.prototype.nearestHandleForValue=function(e,t){return function(e,t){if(0!==e.length){for(var n=e[0],r=t(n),i=1;i<e.length;i++){var o=e[i],a=t(o);a<r&&(n=o,r=a)}return n}}(e,(function(e){var n=t(e),r=e.clientToValue(n),i=e.props.value;return Math.abs(r-i)}))},t.prototype.getNewHandleValues=function(e,t){var n=qr(this.props).map((function(e){return e.value})),r=n.slice();r[t]=e,r.sort((function(e,t){return e-t}));var i=r.indexOf(e),o=this.findFirstLockedHandleIndex(t,i);return-1!==o?(Hr(n,t,o,n[o]),n):(Hr(r,t,i,e),r)},t.prototype.findFirstLockedHandleIndex=function(e,t){for(var n=e<t?1:-1,r=qr(this.props),i=e+n;i!==t+n;i+=n)if(r[i].interactionKind!==Rr.PUSH)return i;return-1},t.prototype.getLabelValues=function(){var e=this.props,t=e.labelStepSize,n=e.labelValues,r=e.min,i=e.max,o=[];if(void 0!==n)o=n;else for(var a=r;a<i||h.a(a,i);a+=null!=t?t:1)o.push(a);return o},t.prototype.getOffsetRatio=function(e){return h.c((e-this.props.min)*this.state.tickSizeRatio,0,1)},t.prototype.getTrackIntent=function(e,t){return this.props.showTrackFill?void 0!==e.intentAfter?e.intentAfter:void 0!==t&&void 0!==t.intentBefore?t.intentBefore:this.props.defaultTrackIntent:w.a.NONE},t.prototype.updateTickSize=function(){if(null!=this.trackElement){var e=this.props.vertical?this.trackElement.clientHeight:this.trackElement.clientWidth,t=1/(this.props.max-this.props.min),n=e*t;this.setState({tickSize:n,tickSizeRatio:t})}},t.defaultSliderProps={disabled:!1,max:10,min:0,showTrackFill:!0,stepSize:1,vertical:!1},t.defaultProps=Object(u.__assign)(Object(u.__assign)({},n.defaultSliderProps),{defaultTrackIntent:w.a.NONE}),t.displayName=C+".MultiSlider",t.Handle=Vr,t=n=Object(u.__decorate)([_e.polyfill],t)}(g);function Gr(e){var t=e.labelPrecision,n=e.stepSize,r=void 0===n?Wr.defaultSliderProps.stepSize:n;return null==t?h.d(r):t}function qr(e){return Kr(e,(function(e){return e.interactionKind!==Rr.NONE}))}function Kr(e,t){var n=e.children;void 0===t&&(t=function(){return!0});var r=d.Children.map(n,(function(e){return he(e,Wr.Handle)&&t(e.props)?e.props:null})),i=null!=r?r:[];return(i=i.filter((function(e){return null!==e}))).sort((function(e,t){return e.value-t.value})),i}!function(e){e[e.START=0]="START",e[e.END=1]="END"}(Ur||(Ur={}));var Xr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.value,n=Object(u.__rest)(e,["value"]);return d.createElement(Wr,Object(u.__assign)({},n),d.createElement(Wr.Handle,{value:t[Ur.START],type:"start",intentAfter:n.intent}),d.createElement(Wr.Handle,{value:t[Ur.END],type:"end"}))},t.prototype.validateProps=function(e){var t=e.value;if(null==t||null==t[Ur.START]||null==t[Ur.END])throw new Error(Xe.N)},t.defaultProps=Object(u.__assign)(Object(u.__assign)({},Wr.defaultSliderProps),{intent:w.a.PRIMARY,value:[0,10]}),t.displayName=C+".RangeSlider",t=Object(u.__decorate)([_e.polyfill],t)}(g),Jr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.initialValue,n=e.intent,r=e.value,i=e.onChange,o=e.onRelease,a=Object(u.__rest)(e,["initialValue","intent","value","onChange","onRelease"]);return d.createElement(Wr,Object(u.__assign)({},a),d.createElement(Wr.Handle,{value:r,intentAfter:r<t?n:void 0,intentBefore:r>=t?n:void 0,onChange:i,onRelease:o}),d.createElement(Wr.Handle,{value:t,interactionKind:"none"}))},t.defaultProps=Object(u.__assign)(Object(u.__assign)({},Wr.defaultSliderProps),{initialValue:0,intent:w.a.PRIMARY,value:0}),t.displayName=C+".Slider",t=Object(u.__decorate)([_e.polyfill],t)}(g),Qr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.panel;return d.createElement("div",{className:ve()(a.TAB_PANEL,t),role:"tablist"},n)},t.defaultProps={disabled:!1},t.displayName=C+".Tab",t=Object(u.__decorate)([_e.polyfill],t)}(g),Zr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleClick=function(e){return t.props.onClick(t.props.id,e)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.children,r=e.disabled,i=e.id,o=e.parentId,s=e.selected,l=e.title,c=Object(u.__rest)(e,["className","children","disabled","id","parentId","selected","title"]);return d.createElement("div",Object(u.__assign)({},E(c),{"aria-controls":$r(o,i),"aria-disabled":r,"aria-expanded":s,"aria-selected":s,className:ve()(a.TAB,t),"data-tab-id":i,id:ei(o,i),onClick:r?void 0:this.handleClick,role:"tab",tabIndex:r?void 0:s?0:-1}),l,n)},t.displayName=C+".TabTitle",t=Object(u.__decorate)([_e.polyfill],t)}(g);function $r(e,t){return a.TAB_PANEL+"_"+e+"_"+t}function ei(e,t){return a.TAB+"-title_"+e+"_"+t}var ti=function(){return d.createElement("div",{className:a.FLEX_EXPANDER})},ni="."+a.TAB,ri=function(e){function t(t){var n=e.call(this,t)||this;n.tablistElement=null,n.refHandlers={tablist:function(e){return n.tablistElement=e}},n.handleKeyDown=function(e){var t,r=null===(t=document.activeElement)||void 0===t?void 0:t.closest(ni);if(null!=r){var i=n.getTabElements().filter((function(e){return"false"===e.getAttribute("aria-disabled")})),o=i.indexOf(r),a=n.getKeyCodeDirection(e);if(o>=0&&void 0!==a){e.preventDefault();var s=i.length;i[(o+a+s)%s].focus()}}},n.handleKeyPress=function(e){var t=e.target.closest(ni);null!=t&&r.isKeyboardClick(e.which)&&(e.preventDefault(),t.click())},n.handleTabClick=function(e,t){var r,i;null===(i=(r=n.props).onChange)||void 0===i||i.call(r,e,n.state.selectedTabId,t),void 0===n.props.selectedTabId&&n.setState({selectedTabId:e})},n.renderTabPanel=function(e){var t=e.props,r=t.className,i=t.panel,o=t.id,s=t.panelClassName;if(void 0!==i)return d.createElement("div",{"aria-labelledby":ei(n.props.id,o),"aria-hidden":o!==n.state.selectedTabId,className:ve()(a.TAB_PANEL,r,s),id:$r(n.props.id,o),key:o,role:"tabpanel"},i)},n.renderTabTitle=function(e){if(oi(e)){var t=e.props.id;return d.createElement(Zr,Object(u.__assign)({},e.props,{parentId:n.props.id,onClick:n.handleTabClick,selected:t===n.state.selectedTabId}))}return e};var i=n.getInitialSelectedTabId();return n.state={selectedTabId:i},n}return Object(u.__extends)(t,e),t.getDerivedStateFromProps=function(e){var t=e.selectedTabId;return void 0!==t?{selectedTabId:t}:null},t.prototype.render=function(){var e,t,n=this.state,r=n.indicatorWrapperStyle,i=n.selectedTabId,o=d.Children.map(this.props.children,this.renderTabTitle),s=this.getTabChildren().filter(this.props.renderActiveTabPanelOnly?function(e){return e.props.id===i}:function(){return!0}).map(this.renderTabPanel),l=this.props.animate?d.createElement("div",{className:a.TAB_INDICATOR_WRAPPER,style:r},d.createElement("div",{className:a.TAB_INDICATOR})):null,c=ve()(a.TABS,((e={})[a.VERTICAL]=this.props.vertical,e),this.props.className),u=ve()(a.TAB_LIST,((t={})[a.LARGE]=this.props.large,t));return d.createElement("div",{className:c},d.createElement("div",{className:u,onKeyDown:this.handleKeyDown,onKeyPress:this.handleKeyPress,ref:this.refHandlers.tablist,role:"tablist"},l,o),s)},t.prototype.componentDidMount=function(){this.moveSelectionIndicator(!1)},t.prototype.componentDidUpdate=function(e,t){if(this.state.selectedTabId!==t.selectedTabId)this.moveSelectionIndicator();else if(null!=t.selectedTabId){!G(this.getTabChildrenProps(e),this.getTabChildrenProps(),q)&&this.moveSelectionIndicator()}},t.prototype.getInitialSelectedTabId=function(){var e=this.props,t=e.defaultSelectedTabId,n=e.selectedTabId;if(void 0!==n)return n;if(void 0!==t)return t;var r=this.getTabChildren();return 0===r.length?void 0:r[0].props.id},t.prototype.getKeyCodeDirection=function(e){return ii(e,r.ARROW_LEFT,r.ARROW_UP)?-1:ii(e,r.ARROW_RIGHT,r.ARROW_DOWN)?1:void 0},t.prototype.getTabChildrenProps=function(e){return void 0===e&&(e=this.props),this.getTabChildren(e).map((function(e){return e.props}))},t.prototype.getTabChildren=function(e){return void 0===e&&(e=this.props),d.Children.toArray(e.children).filter(oi)},t.prototype.getTabElements=function(e){return void 0===e&&(e=""),null==this.tablistElement?[]:Array.from(this.tablistElement.querySelectorAll(ni+e))},t.prototype.moveSelectionIndicator=function(e){if(void 0===e&&(e=!0),null!=this.tablistElement&&this.props.animate){var t=ni+'[data-tab-id="'+this.state.selectedTabId+'"]',n=this.tablistElement.querySelector(t),r={display:"none"};if(null!=n){var i=n.clientHeight,o=n.clientWidth,a=n.offsetLeft,s=n.offsetTop;r={height:i,transform:"translateX("+Math.floor(a)+"px) translateY("+Math.floor(s)+"px)",width:o},e||(r.transition="none")}this.setState({indicatorWrapperStyle:r})}},t.Expander=ti,t.Tab=Qr,t.defaultProps={animate:!0,large:!1,renderActiveTabPanelOnly:!1,vertical:!1},t.displayName=C+".Tabs",t=Object(u.__decorate)([_e.polyfill],t)}(g);function ii(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return t.indexOf(e.which)>=0}function oi(e){return he(e,Qr)}var ai=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.onRemoveClick=function(e){var n,r;null===(r=(n=t.props).onRemove)||void 0===r||r.call(n,e,t.props)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e,t=this.props,n=t.active,r=t.children,o=t.className,s=t.fill,l=t.icon,c=t.intent,h=t.interactive,p=t.large,f=t.minimal,m=t.multiline,g=t.onRemove,v=t.rightIcon,y=t.round,_=t.tabIndex,b=void 0===_?0:_,M=t.htmlTitle,w=t.elementRef,A=Object(u.__rest)(t,["active","children","className","fill","icon","intent","interactive","large","minimal","multiline","onRemove","rightIcon","round","tabIndex","htmlTitle","elementRef"]),C=i.isFunction(g),x=ve()(a.TAG,a.intentClass(c),((e={})[a.ACTIVE]=n,e[a.FILL]=s,e[a.INTERACTIVE]=h,e[a.LARGE]=p,e[a.MINIMAL]=f,e[a.ROUND]=y,e),o),E=p||x.indexOf(a.LARGE)>=0,L=C?d.createElement("button",{"aria-label":"Remove",type:"button",className:a.TAG_REMOVE,onClick:this.onRemoveClick,tabIndex:h?b:void 0},d.createElement(Lt,{icon:"small-cross",size:E?Ct.LARGE:Ct.STANDARD})):null;return d.createElement("span",Object(u.__assign)({},A,{className:x,tabIndex:h?b:void 0,ref:w}),d.createElement(Lt,{icon:l}),!le(r)&&d.createElement(Zt,{className:a.FILL,ellipsize:!m,tagName:"span",title:M},r),d.createElement(Lt,{icon:v}),L)},t.displayName=C+".Tag",t=Object(u.__decorate)([_e.polyfill],t)}(g),si=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={activeIndex:-1,inputValue:t.props.inputValue||"",isInputFocused:!1},t.inputElement=null,t.handleRef=D(t,"inputElement",t.props.inputRef),t.addTags=function(e,n){void 0===n&&(n="default");var r=t.props,o=r.inputValue,a=r.onAdd,s=r.onChange,l=r.values,c=t.getValues(e),d=!1!==(null==a?void 0:a(c,n))&&void 0===o;i.isFunction(s)&&(d=!1!==s(Object(u.__spreadArrays)(l,c))&&d),d&&t.setState({inputValue:""})},t.maybeRenderTag=function(e,n){if(!e)return null;var r=t.props,o=r.large,a=r.tagProps,s=i.isFunction(a)?a(e,n):a;return d.createElement(ai,Object(u.__assign)({active:n===t.state.activeIndex,"data-tag-index":n,key:e+"__"+n,large:o,onRemove:t.props.disabled?void 0:t.handleRemoveTag},s),e)},t.handleContainerClick=function(){var e;null===(e=t.inputElement)||void 0===e||e.focus()},t.handleContainerBlur=function(e){var n=e.currentTarget;t.requestAnimationFrame((function(){n.contains(document.activeElement)||(t.props.addOnBlur&&void 0!==t.state.inputValue&&t.state.inputValue.length>0&&t.addTags(t.state.inputValue,"blur"),t.setState({activeIndex:-1,isInputFocused:!1}))}))},t.handleInputFocus=function(e){var n,r;t.setState({isInputFocused:!0}),null===(r=null===(n=t.props.inputProps)||void 0===n?void 0:n.onFocus)||void 0===r||r.call(n,e)},t.handleInputChange=function(e){var n,r,i,o;t.setState({activeIndex:-1,inputValue:e.currentTarget.value}),null===(r=(n=t.props).onInputChange)||void 0===r||r.call(n,e),null===(o=null===(i=t.props.inputProps)||void 0===i?void 0:i.onChange)||void 0===o||o.call(i,e)},t.handleInputKeyDown=function(e){var n=e.currentTarget,i=n.selectionEnd,o=n.value,a=t.state.activeIndex,s=a;if(e.which===r.ENTER&&o.length>0)t.addTags(o,"default");else if(0===i&&t.props.values.length>0)if(e.which===r.ARROW_LEFT||e.which===r.ARROW_RIGHT){var l=t.getNextActiveIndex(e.which===r.ARROW_RIGHT?1:-1);l!==a&&(e.stopPropagation(),s=l,t.setState({activeIndex:l}))}else e.which===r.BACKSPACE?t.handleBackspaceToRemove(e):e.which===r.DELETE&&t.handleDeleteToRemove(e);t.invokeKeyPressCallback("onKeyDown",e,s)},t.handleInputKeyUp=function(e){t.invokeKeyPressCallback("onKeyUp",e,t.state.activeIndex)},t.handleInputPaste=function(e){var n=t.props.separator,r=e.clipboardData.getData("text");t.props.addOnPaste&&0!==r.length&&!1!==n&&1!==r.split(n).length&&(e.preventDefault(),t.addTags(r,"paste"))},t.handleRemoveTag=function(e){var n=+e.currentTarget.parentElement.getAttribute("data-tag-index");t.removeIndexFromValues(n)},t}return Object(u.__extends)(t,e),t.getDerivedStateFromProps=function(e,t){return e.inputValue!==t.prevInputValueProp?{inputValue:e.inputValue,prevInputValueProp:e.inputValue}:null},t.prototype.render=function(){var e,t=this.props,n=t.className,r=t.disabled,i=t.fill,o=t.inputProps,s=t.intent,l=t.large,c=t.leftIcon,h=t.placeholder,p=t.values,f=ve()(a.INPUT,a.TAG_INPUT,((e={})[a.ACTIVE]=this.state.isInputFocused,e[a.DISABLED]=r,e[a.FILL]=i,e[a.LARGE]=l,e),a.intentClass(s),n),m=f.indexOf(a.LARGE)>-1,g=p.some((function(e){return!!e})),v=null==h||g?null==o?void 0:o.placeholder:h;return d.createElement("div",{className:f,onBlur:this.handleContainerBlur,onClick:this.handleContainerClick},d.createElement(Lt,{className:a.TAG_INPUT_ICON,icon:c,size:m?Ct.LARGE:Ct.STANDARD}),d.createElement("div",{className:a.TAG_INPUT_VALUES},p.map(this.maybeRenderTag),this.props.children,d.createElement("input",Object(u.__assign)({value:this.state.inputValue},o,{onFocus:this.handleInputFocus,onChange:this.handleInputChange,onKeyDown:this.handleInputKeyDown,onKeyUp:this.handleInputKeyUp,onPaste:this.handleInputPaste,placeholder:v,ref:this.handleRef,className:ve()(a.INPUT_GHOST,null==o?void 0:o.className),disabled:r}))),this.props.rightElement)},t.prototype.componentDidUpdate=function(e){e.inputRef!==this.props.inputRef&&(T(e.inputRef,null),this.handleRef=D(this,"inputElement",this.props.inputRef),T(this.props.inputRef,this.inputElement))},t.prototype.getNextActiveIndex=function(e){var t=this.state.activeIndex;return-1===t?e<0?this.findNextIndex(this.props.values.length,-1):-1:this.findNextIndex(t,e)},t.prototype.findNextIndex=function(e,t){for(var n=this.props.values,r=e+t;r>0&&r<n.length&&!n[r];)r+=t;return i.clamp(r,0,n.length)},t.prototype.getValues=function(e){var t=this.props.separator;return(!1===t?[e]:e.split(t)).map((function(e){return e.trim()})).filter((function(e){return e.length>0}))},t.prototype.handleBackspaceToRemove=function(e){var t=this.state.activeIndex;this.setState({activeIndex:this.getNextActiveIndex(-1)}),this.isValidIndex(t)&&(e.stopPropagation(),this.removeIndexFromValues(t))},t.prototype.handleDeleteToRemove=function(e){var t=this.state.activeIndex;this.isValidIndex(t)&&(e.stopPropagation(),this.removeIndexFromValues(t))},t.prototype.removeIndexFromValues=function(e){var t=this.props,n=t.onChange,r=t.onRemove,o=t.values;null==r||r(o[e],e),i.isFunction(n)&&n(o.filter((function(t,n){return n!==e})))},t.prototype.invokeKeyPressCallback=function(e,t,n){var r,i,o,a;null===(i=(r=this.props)[e])||void 0===i||i.call(r,t,-1===n?void 0:n),null===(a=(o=this.props.inputProps)[e])||void 0===a||a.call(o,t)},t.prototype.isValidIndex=function(e){return-1!==e&&e<this.props.values.length},t.displayName=C+".TagInput",t.defaultProps={addOnBlur:!1,addOnPaste:!0,inputProps:{},separator:/[,\n\r]/,tagProps:{}},t=Object(u.__decorate)([_e.polyfill],t)}(g),li=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleActionClick=function(e){var n,r;null===(r=null===(n=t.props.action)||void 0===n?void 0:n.onClick)||void 0===r||r.call(n,e),t.triggerDismiss(!1)},t.handleCloseClick=function(){return t.triggerDismiss(!1)},t.startTimeout=function(){t.clearTimeouts(),t.props.timeout>0&&t.setTimeout((function(){return t.triggerDismiss(!0)}),t.props.timeout)},t}return Object(u.__extends)(t,e),t.prototype.render=function(){var e=this.props,t=e.className,n=e.icon,r=e.intent,i=e.message;return d.createElement("div",{className:ve()(a.TOAST,a.intentClass(r),t),onBlur:this.startTimeout,onFocus:this.clearTimeouts,onMouseEnter:this.clearTimeouts,onMouseLeave:this.startTimeout,tabIndex:0},d.createElement(Lt,{icon:n}),d.createElement("span",{className:a.TOAST_MESSAGE},i),d.createElement(sn,{minimal:!0},this.maybeRenderActionButton(),d.createElement(kt,{"aria-label":"Close",icon:"cross",onClick:this.handleCloseClick})))},t.prototype.componentDidMount=function(){this.startTimeout()},t.prototype.componentDidUpdate=function(e){e.timeout!==this.props.timeout&&(this.props.timeout>0?this.startTimeout():this.clearTimeouts())},t.prototype.componentWillUnmount=function(){this.clearTimeouts()},t.prototype.maybeRenderActionButton=function(){var e=this.props.action;return null==e?void 0:d.createElement(Dt,Object(u.__assign)({},e,{intent:void 0,onClick:this.handleActionClick}))},t.prototype.triggerDismiss=function(e){var t,n;this.clearTimeouts(),null===(n=(t=this.props).onDismiss)||void 0===n||n.call(t,e)},t.defaultProps={className:"",message:"",timeout:5e3},t.displayName=C+".Toast",t=Object(u.__decorate)([_e.polyfill],t)}(g),ci=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={toasts:[]},t.toastId=0,t.renderToast=function(e){return d.createElement(li,Object(u.__assign)({},e,{onDismiss:t.getDismissHandler(e)}))},t.getDismissHandler=function(e){return function(n){t.dismiss(e.key,n)}},t.handleClose=function(e){e.which===R&&t.clear()},t}var n;return Object(u.__extends)(t,e),n=t,t.create=function(e,t){void 0===t&&(t=document.body),null==e||null==e.usePortal||Object(h.e)("production")||console.warn(Xe.T);var r=document.createElement("div");t.appendChild(r);var i=ye.render(d.createElement(n,Object(u.__assign)({},e,{usePortal:!1})),r);if(null==i)throw new Error(Xe.R);return i},t.prototype.show=function(e,t){this.props.maxToasts&&this.dismissIfAtLimit();var n=this.createToastOptions(e,t);return void 0===t||this.isNewToastKey(t)?this.setState((function(e){return{toasts:Object(u.__spreadArrays)([n],e.toasts)}})):this.setState((function(e){return{toasts:e.toasts.map((function(e){return e.key===t?n:e}))}})),n.key},t.prototype.dismiss=function(e,t){void 0===t&&(t=!1),this.setState((function(n){return{toasts:n.toasts.filter((function(n){var r,i=n.key===e;return i&&(null===(r=n.onDismiss)||void 0===r||r.call(n,t)),!i}))}}))},t.prototype.clear=function(){this.state.toasts.forEach((function(e){var t;return null===(t=e.onDismiss)||void 0===t?void 0:t.call(e,!1)})),this.setState({toasts:[]})},t.prototype.getToasts=function(){return this.state.toasts},t.prototype.render=function(){var e=ve()(a.TOAST_CONTAINER,this.getPositionClasses(),this.props.className);return d.createElement(tt,{autoFocus:this.props.autoFocus,canEscapeKeyClose:this.props.canEscapeKeyClear,canOutsideClickClose:!1,className:e,enforceFocus:!1,hasBackdrop:!1,isOpen:this.state.toasts.length>0||null!=this.props.children,onClose:this.handleClose,shouldReturnFocusOnClose:!1,transitionDuration:350,transitionName:a.TOAST,usePortal:this.props.usePortal},this.state.toasts.map(this.renderToast,this),this.props.children)},t.prototype.validateProps=function(e){var t=e.maxToasts;if(void 0!==t&&t<1)throw new Error(Xe.S)},t.prototype.isNewToastKey=function(e){return this.state.toasts.every((function(t){return t.key!==e}))},t.prototype.dismissIfAtLimit=function(){this.state.toasts.length===this.props.maxToasts&&this.dismiss(this.state.toasts[this.state.toasts.length-1].key)},t.prototype.createToastOptions=function(e,t){return void 0===t&&(t="toast-"+this.toastId++),Object(u.__assign)(Object(u.__assign)({},e),{key:t})},t.prototype.getPositionClasses=function(){var e=this.props.position.split("-");return Object(u.__spreadArrays)(e.map((function(e){return a.TOAST_CONTAINER+"-"+e.toLowerCase()})),[a.TOAST_CONTAINER+"-"+(this.props.usePortal?"in-portal":"inline")])},t.displayName=C+".Toaster",t.defaultProps={autoFocus:!1,canEscapeKeyClear:!0,position:A.a.TOP,usePortal:!0},t=n=Object(u.__decorate)([_e.polyfill],t)}(g),ui=ci,di=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleCaretClick=function(e){var n;e.stopPropagation();var r=t.props,i=r.isExpanded,o=r.onCollapse,a=r.onExpand;null===(n=i?o:a)||void 0===n||n(t,e)},t.handleClick=function(e){var n,r;null===(r=(n=t.props).onClick)||void 0===r||r.call(n,t,e)},t.handleContentRef=function(e){var n,r;null===(r=(n=t.props).contentRef)||void 0===r||r.call(n,t,e)},t.handleContextMenu=function(e){var n,r;null===(r=(n=t.props).onContextMenu)||void 0===r||r.call(n,t,e)},t.handleDoubleClick=function(e){var n,r;null===(r=(n=t.props).onDoubleClick)||void 0===r||r.call(n,t,e)},t.handleMouseEnter=function(e){var n,r;null===(r=(n=t.props).onMouseEnter)||void 0===r||r.call(n,t,e)},t.handleMouseLeave=function(e){var n,r;null===(r=(n=t.props).onMouseLeave)||void 0===r||r.call(n,t,e)},t}return Object(u.__extends)(t,e),t.ofType=function(){return t},t.prototype.render=function(){var e,t=this.props,n=t.children,r=t.className,i=t.disabled,o=t.icon,s=t.isExpanded,l=t.isSelected,c=t.label,h=ve()(a.TREE_NODE,((e={})[a.DISABLED]=i,e[a.TREE_NODE_SELECTED]=l,e[a.TREE_NODE_EXPANDED]=s,e),r),p=ve()(a.TREE_NODE_CONTENT,a.TREE_NODE_CONTENT+"-"+this.props.depth),f=!0===i?{}:{onClick:this.handleClick,onContextMenu:this.handleContextMenu,onDoubleClick:this.handleDoubleClick,onMouseEnter:this.handleMouseEnter,onMouseLeave:this.handleMouseLeave};return d.createElement("li",{className:h},d.createElement("div",Object(u.__assign)({className:p,ref:this.handleContentRef},f),this.maybeRenderCaret(),d.createElement(Lt,{className:a.TREE_NODE_ICON,icon:o}),d.createElement("span",{className:a.TREE_NODE_LABEL},c),this.maybeRenderSecondaryLabel()),d.createElement(un,{isOpen:s},n))},t.prototype.maybeRenderCaret=function(){var e=this.props,t=e.children,n=e.isExpanded,r=e.disabled,i=e.hasCaret;if(void 0===i?d.Children.count(t)>0:i){var o=ve()(a.TREE_NODE_CARET,n?a.TREE_NODE_CARET_OPEN:a.TREE_NODE_CARET_CLOSED),s=!0===r?void 0:this.handleCaretClick;return d.createElement(Lt,{title:n?"Collapse group":"Expand group",className:o,onClick:s,icon:"chevron-right"})}return d.createElement("span",{className:a.TREE_NODE_CARET_NONE})},t.prototype.maybeRenderSecondaryLabel=function(){return null!=this.props.secondaryLabel?d.createElement("span",{className:a.TREE_NODE_SECONDARY_LABEL},this.props.secondaryLabel):void 0},t.displayName=C+".TreeNode",t}(d.Component),hi=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.nodeRefs={},t.handleNodeCollapse=function(e,n){t.handlerHelper(t.props.onNodeCollapse,e,n)},t.handleNodeClick=function(e,n){t.handlerHelper(t.props.onNodeClick,e,n)},t.handleContentRef=function(e,n){null!=n?t.nodeRefs[e.props.id]=n:delete t.nodeRefs[e.props.id]},t.handleNodeContextMenu=function(e,n){t.handlerHelper(t.props.onNodeContextMenu,e,n)},t.handleNodeDoubleClick=function(e,n){t.handlerHelper(t.props.onNodeDoubleClick,e,n)},t.handleNodeExpand=function(e,n){t.handlerHelper(t.props.onNodeExpand,e,n)},t.handleNodeMouseEnter=function(e,n){t.handlerHelper(t.props.onNodeMouseEnter,e,n)},t.handleNodeMouseLeave=function(e,n){t.handlerHelper(t.props.onNodeMouseLeave,e,n)},t}return Object(u.__extends)(t,e),t.ofType=function(){return t},t.nodeFromPath=function(e,n){return 1===e.length?n[e[0]]:t.nodeFromPath(e.slice(1),n[e[0]].childNodes)},t.prototype.render=function(){return d.createElement("div",{className:ve()(a.TREE,this.props.className)},this.renderNodes(this.props.contents,[],a.TREE_ROOT))},t.prototype.getNodeContentElement=function(e){return this.nodeRefs[e]},t.prototype.renderNodes=function(e,t,n){var r=this;if(null==e)return null;var i=e.map((function(e,n){var i=t.concat(n),o=di.ofType();return d.createElement(o,Object(u.__assign)({},e,{key:e.id,contentRef:r.handleContentRef,depth:i.length-1,onClick:r.handleNodeClick,onContextMenu:r.handleNodeContextMenu,onCollapse:r.handleNodeCollapse,onDoubleClick:r.handleNodeDoubleClick,onExpand:r.handleNodeExpand,onMouseEnter:r.handleNodeMouseEnter,onMouseLeave:r.handleNodeMouseLeave,path:i}),r.renderNodes(e.childNodes,i))}));return d.createElement("ul",{className:ve()(a.TREE_NODE_LIST,n)},i)},t.prototype.handlerHelper=function(e,n,r){ee(e)&&e(t.nodeFromPath(n.props.path,this.props.contents),n.props.path,r)},t.displayName=C+".Tree",t}(d.Component),pi=o},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r=n(97),i=n(4),o=n(3);class a{constructor(e){this._currentChanged=new i.Signal(this),this._isDisposed=!1,this._widgetAdded=new i.Signal(this),this._widgetUpdated=new i.Signal(this);const t=this._focusTracker=new o.FocusTracker,n=this._pool=new r.RestorablePool(e);this.namespace=e.namespace,t.currentChanged.connect((e,t)=>{t.newValue!==this.currentWidget&&(n.current=t.newValue)},this),n.added.connect((e,t)=>{this._widgetAdded.emit(t)},this),n.currentChanged.connect((e,r)=>{null===r&&t.currentWidget?n.current=t.currentWidget:(this.onCurrentChanged(r),this._currentChanged.emit(r))},this),n.updated.connect((e,t)=>{this._widgetUpdated.emit(t)},this)}get currentChanged(){return this._currentChanged}get currentWidget(){return this._pool.current||null}get restored(){return this._pool.restored}get size(){return this._pool.size}get widgetAdded(){return this._widgetAdded}get widgetUpdated(){return this._widgetUpdated}async add(e){this._focusTracker.add(e),await this._pool.add(e),this._focusTracker.activeWidget||(this._pool.current=e)}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,this._pool.dispose(),this._focusTracker.dispose(),i.Signal.clearData(this))}find(e){return this._pool.find(e)}forEach(e){return this._pool.forEach(e)}filter(e){return this._pool.filter(e)}inject(e){return this._pool.inject(e)}has(e){return this._pool.has(e)}async restore(e){return this._pool.restore(e)}async save(e){return this._pool.save(e)}onCurrentChanged(e){}}},function(e,t,n){"use strict";n.d(t,"a",(function(){return i}));var r=n(3);class i extends r.Widget{constructor(){super(),this.addClass("jp-Spinner"),this.node.tabIndex=-1;const e=document.createElement("div");e.className="jp-SpinnerContent",this.node.appendChild(e)}onActivateRequest(e){this.node.focus()}}},function(e,t,n){"use strict";n.d(t,"d",(function(){return y})),n.d(t,"c",(function(){return _})),n.d(t,"f",(function(){return b})),n.d(t,"h",(function(){return M})),n.d(t,"e",(function(){return w})),n.d(t,"b",(function(){return A})),n.d(t,"g",(function(){return C})),n.d(t,"a",(function(){return x}));var r=n(22),i=n(54),o=n(586),a=n(13),s=n(45),l=n(2),c=n(65),u=n(8),d=n(43),h=n(3),p=n(0),f=n(115),m=n(59),g=n(64);class v extends h.PanelLayout{constructor(){super(...arguments),this._dirty=!1}onFitRequest(e){super.onFitRequest(e),this.parent.isAttached&&(Object(l.some)(this.widgets,e=>!e.isHidden)?(this.parent.node.style.minHeight="var(--jp-private-toolbar-height)",this.parent.removeClass("jp-Toolbar-micro")):(this.parent.node.style.minHeight="",this.parent.addClass("jp-Toolbar-micro"))),this._dirty=!0,this.parent.parent&&u.c.sendMessage(this.parent.parent,h.Widget.Msg.FitRequest),this._dirty&&u.c.sendMessage(this.parent,h.Widget.Msg.UpdateRequest)}onUpdateRequest(e){super.onUpdateRequest(e),this.parent.isVisible&&(this._dirty=!1)}onChildShown(e){super.onChildShown(e),this.parent.fit()}onChildHidden(e){super.onChildHidden(e),this.parent.fit()}onBeforeAttach(e){super.onBeforeAttach(e),this.parent.fit()}attachWidget(e,t){super.attachWidget(e,t),this.parent.fit()}detachWidget(e,t){super.detachWidget(e,t),this.parent.fit()}}class y extends h.Widget{constructor(){super(),this.addClass("jp-Toolbar"),this.layout=new v}names(){const e=this.layout;return Object(l.map)(e.widgets,e=>S.nameProperty.get(e))}addItem(e,t){const n=this.layout;return this.insertItem(n.widgets.length,e,t)}insertItem(e,t,n){if(Object(l.find)(this.names(),e=>e===t))return!1;n.addClass("jp-Toolbar-item");const r=this.layout,i=Math.max(0,Math.min(e,r.widgets.length));return r.insertWidget(i,n),S.nameProperty.set(n,t),!0}insertAfter(e,t,n){return this._insertRelative(e,1,t,n)}insertBefore(e,t,n){return this._insertRelative(e,0,t,n)}_insertRelative(e,t,n,r){const i=Object(l.map)(this.names(),(e,t)=>({name:e,index:t})),o=Object(l.find)(i,t=>t.name===e);return!!o&&this.insertItem(o.index+t,n,r)}handleEvent(e){switch(e.type){case"click":this.handleClick(e)}}handleClick(e){if(e.target instanceof HTMLLabelElement){const t=e.target.getAttribute("for");if(t&&this.node.querySelector("#"+t))return}this.node.contains(document.activeElement)||this.parent&&this.parent.activate()}onAfterAttach(e){this.node.addEventListener("click",this)}onBeforeDetach(e){this.node.removeEventListener("click",this)}}class _ extends y{constructor(){super(),this.popupOpener=new L,this._widgetWidths={},this.insertItem(0,"toolbar-popup-opener",this.popupOpener),this.popupOpener.hide(),this._resizer=new g.Throttler(this._onResize.bind(this),500)}dispose(){this.isDisposed||(this._resizer&&this._resizer.dispose(),super.dispose())}insertAfter(e,t,n){return"toolbar-popup-opener"!==e&&super.insertAfter(e,t,n)}insertItem(e,t,n){if(n instanceof L)return super.insertItem(e,t,n);{const r=Math.max(0,Math.min(e,this.layout.widgets.length-1));return super.insertItem(r,t,n)}}onBeforeHide(e){this.popupOpener.hidePopup(),super.onBeforeHide(e)}onResize(e){super.onResize(e),e.width>0&&this._resizer&&this._resizer.invoke()}_onResize(){if(this.parent&&this.parent.isAttached){const e=this.node.clientWidth,t=this.popupOpener,n=30,r=2,i=this.layout;let o=t.isHidden?r:r+n,a=0;const s=[],l=i.widgets.length-1;for(;a<l;){const r=i.widgets[a];this._saveWidgetWidth(r),o+=this._getWidgetWidth(r),0===s.length&&t.isHidden&&o+n>e&&(o+=n),o>e&&s.push(r),a++}for(;s.length>0;){const e=s.pop();o-=this._getWidgetWidth(e),t.addWidget(e)}if(t.widgetCount()>0){const r=[];let i=0,a=t.widgetAt(i);const s=t.widgetCount();for(o+=this._getWidgetWidth(a),1===s&&o-n<=e&&(o-=n);o<e&&i<s&&(r.push(a),i++,a=t.widgetAt(i),a);)o+=this._getWidgetWidth(a);for(;r.length>0;){const e=r.shift();this.addItem(S.nameProperty.get(e),e)}}t.widgetCount()>0?(t.updatePopup(),t.show()):t.hide()}}_saveWidgetWidth(e){const t=S.nameProperty.get(e);this._widgetWidths[t]=e.hasClass("jp-Toolbar-spacer")?2:e.node.clientWidth}_getWidgetWidth(e){const t=S.nameProperty.get(e);return this._widgetWidths[t]}}function b(e){var t,n;return p.createElement(o.a,{className:e.className?e.className+" jp-ToolbarButtonComponent":"jp-ToolbarButtonComponent","aria-pressed":e.pressed,"aria-disabled":!1===e.enabled,disabled:!1===e.enabled,onClick:null!==(t=e.actualOnClick)&&void 0!==t&&t?t=>{var n;0===t.button&&(null===(n=e.onClick)||void 0===n||n.call(e))}:void 0,onMouseDown:null!==(n=e.actualOnClick)&&void 0!==n&&n?void 0:t=>{var n;0===t.button&&(t.preventDefault(),null===(n=e.onClick)||void 0===n||n.call(e))},onKeyDown:t=>{var n;const{key:r}=t;"Enter"!==r&&" "!==r||null===(n=e.onClick)||void 0===n||n.call(e)},title:!1===e.enabled&&e.disabledTooltip?e.disabledTooltip:e.pressed&&e.pressedTooltip?e.pressedTooltip:e.tooltip||e.iconLabel,minimal:!0},(e.icon||e.iconClass)&&p.createElement(a.a.resolveReact,{icon:e.pressed?e.pressedIcon:e.icon,iconClass:Object(s.a)(e.iconClass,"jp-Icon"),className:"jp-ToolbarButtonComponent-icon",tag:"span",stylesheet:"toolbarButton"}),e.label&&p.createElement("span",{className:"jp-ToolbarButtonComponent-label"},e.label))}function M(e){return e.addClass("jp-ToolbarButton"),e}!function(e){e.createInterruptButton=function(e,t){const n=(t=t||r.b).load("jupyterlab");return new w({icon:i.z,onClick:()=>{var t,n;null===(n=null===(t=e.session)||void 0===t?void 0:t.kernel)||void 0===n||n.interrupt()},tooltip:n.__("Interrupt the kernel")})},e.createRestartButton=function(e,t,n){const o=(n=n||r.b).load("jupyterlab");return new w({icon:i.w,onClick:()=>{(null!=t?t:f.b).restart(e,n)},tooltip:o.__("Restart the kernel")})},e.createSpacerItem=function(){return new S.Spacer},e.createKernelNameItem=function(e,t,n){const r=m.a.create(p.createElement(S.KernelNameComponent,{sessionContext:e,dialogs:null!=t?t:f.b,translator:n}));return r.addClass("jp-KernelName"),r},e.createKernelStatusItem=function(e,t){return new S.KernelStatus(e,t)}}(y||(y={}));class w extends m.a{constructor(e={}){var t,n;super(),this.props=e,M(this),this._enabled=null===(t=e.enabled)||void 0===t||t,this._pressed=this._enabled&&null!==(n=e.pressed)&&void 0!==n&&n,this._onClick=e.onClick}set pressed(e){this.enabled&&e!==this._pressed&&(this._pressed=e,this.update())}get pressed(){return this._pressed}set enabled(e){e!=this._enabled&&(this._enabled=e,this._enabled||(this._pressed=!1),this.update())}get enabled(){return this._enabled}set onClick(e){e!==this._onClick&&(this._onClick=e,this.update())}get onClick(){return this._onClick}render(){return p.createElement(b,Object.assign({},this.props,{pressed:this.pressed,enabled:this.enabled,onClick:this.onClick}))}}function A(e){return p.createElement(m.b,{signal:e.commands.commandChanged,shouldUpdate:(t,n)=>n.id===e.id&&"changed"===n.type||"many-changed"===n.type},()=>p.createElement(b,Object.assign({},S.propsFromCommand(e))))}function C(e){return e.addClass("jp-CommandToolbarButton"),e}class x extends m.a{constructor(e){super(),this.props=e,C(this)}render(){return p.createElement(A,Object.assign({},this.props))}}class E extends h.Widget{constructor(){super(),this.width=0,this.addClass("jp-Toolbar-responsive-popup"),this.layout=new h.PanelLayout,h.Widget.attach(this,document.body),this.hide()}updateWidth(e){e>0&&(this.width=e,this.node.style.width=e+"px")}alignTo(e){const{height:t,width:n,x:r,y:i}=e.node.getBoundingClientRect(),o=this.width;this.node.style.left=r+n-o+1+"px",this.node.style.top=i+t+1+"px"}insertWidget(e,t){this.layout.insertWidget(0,t)}widgetCount(){return this.layout.widgets.length}widgetAt(e){return this.layout.widgets[e]}}class L extends w{constructor(){super({icon:i.i,onClick:()=>{this.handleClick()}}),this.addClass("jp-Toolbar-responsive-opener"),this.popup=new E}addWidget(e){this.popup.insertWidget(0,e)}dispose(){this.isDisposed||(this.popup.dispose(),super.dispose())}hide(){super.hide(),this.hidePopup()}hidePopup(){this.popup.hide()}updatePopup(){this.popup.updateWidth(this.parent.node.clientWidth),this.popup.alignTo(this.parent)}widgetAt(e){return this.popup.widgetAt(e)}widgetCount(){return this.popup.widgetCount()}handleClick(){this.updatePopup(),this.popup.setHidden(!this.popup.isHidden)}}var S;!function(e){e.propsFromCommand=function(e){const{commands:t,id:n,args:r}=e,i=t.iconClass(n,r),o=t.iconLabel(n,r),a=t.icon(n,r),s=a===i?void 0:a,l=t.label(n,r);let u=t.className(n,r);t.isToggled(n,r)&&(u+=" lm-mod-toggled"),t.isVisible(n,r)||(u+=" lm-mod-hidden");let d=t.caption(n,r)||l||o;const h=t.keyBindings.find(e=>e.command===n);if(h){d=`${d} (${c.CommandRegistry.formatKeystroke(h.keys.join(" "))})`}return{className:u,icon:s,iconClass:i,tooltip:d,onClick:()=>{t.execute(n,r)},enabled:t.isEnabled(n,r),label:l}},e.nameProperty=new d.AttachedProperty({name:"name",create:()=>""}),e.noOp=function(){};class t extends h.Widget{constructor(){super(),this.addClass("jp-Toolbar-spacer")}}e.Spacer=t,e.KernelNameComponent=function(e){const t=e.translator||r.b,n=t.load("jupyterlab"),i=()=>{e.dialogs.selectKernel(e.sessionContext,t)};return p.createElement(m.b,{signal:e.sessionContext.kernelChanged,initialSender:e.sessionContext},e=>p.createElement(b,{className:"jp-Toolbar-kernelName",onClick:i,tooltip:n.__("Switch kernel"),label:null==e?void 0:e.kernelDisplayName}))};class n extends h.Widget{constructor(e,t){super(),this.translator=t||r.b,this._trans=this.translator.load("jupyterlab"),this.addClass("jp-Toolbar-kernelStatus"),this._statusNames={unknown:this._trans.__("Unknown"),starting:this._trans.__("Starting"),idle:this._trans.__("Idle"),busy:this._trans.__("Busy"),terminating:this._trans.__("Terminating"),restarting:this._trans.__("Restarting"),autorestarting:this._trans.__("Autorestarting"),dead:this._trans.__("Dead"),connected:this._trans.__("Connected"),connecting:this._trans.__("Connecting"),disconnected:this._trans.__("Disconnected"),initializing:this._trans.__("Initializing"),"":""},this._onStatusChanged(e),e.statusChanged.connect(this._onStatusChanged,this),e.connectionStatusChanged.connect(this._onStatusChanged,this)}_onStatusChanged(e){if(this.isDisposed)return;const t=e.kernelDisplayStatus,n={container:this.node,title:this._trans.__("Kernel %1",this._statusNames[t]||t),stylesheet:"toolbarButton",alignSelf:"normal",height:"24px"};a.a.remove(this.node),"busy"===t||"starting"===t||"terminating"===t||"restarting"===t||"initializing"===t?i.g.element(n):"connecting"===t||"disconnected"===t||"unknown"===t?i.s.element(n):i.f.element(n)}}e.KernelStatus=n}(S||(S={}))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.mathjax=void 0;var r=n(820),i=n(180);t.mathjax={version:"3.2.0",handlers:new r.HandlerList,document:function(e,n){return t.mathjax.handlers.document(e,n)},handleRetriesFor:i.handleRetriesFor,retryAfter:i.retryAfter,asyncLoad:null}},function(e,t,n){"use strict";t.byteLength=function(e){var t=c(e),n=t[0],r=t[1];return 3*(n+r)/4-r},t.toByteArray=function(e){var t,n,r=c(e),a=r[0],s=r[1],l=new o(function(e,t,n){return 3*(t+n)/4-n}(0,a,s)),u=0,d=s>0?a-4:a;for(n=0;n<d;n+=4)t=i[e.charCodeAt(n)]<<18|i[e.charCodeAt(n+1)]<<12|i[e.charCodeAt(n+2)]<<6|i[e.charCodeAt(n+3)],l[u++]=t>>16&255,l[u++]=t>>8&255,l[u++]=255&t;2===s&&(t=i[e.charCodeAt(n)]<<2|i[e.charCodeAt(n+1)]>>4,l[u++]=255&t);1===s&&(t=i[e.charCodeAt(n)]<<10|i[e.charCodeAt(n+1)]<<4|i[e.charCodeAt(n+2)]>>2,l[u++]=t>>8&255,l[u++]=255&t);return l},t.fromByteArray=function(e){for(var t,n=e.length,i=n%3,o=[],a=0,s=n-i;a<s;a+=16383)o.push(u(e,a,a+16383>s?s:a+16383));1===i?(t=e[n-1],o.push(r[t>>2]+r[t<<4&63]+"==")):2===i&&(t=(e[n-2]<<8)+e[n-1],o.push(r[t>>10]+r[t>>4&63]+r[t<<2&63]+"="));return o.join("")};for(var r=[],i=[],o="undefined"!=typeof Uint8Array?Uint8Array:Array,a="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",s=0,l=a.length;s<l;++s)r[s]=a[s],i[a.charCodeAt(s)]=s;function c(e){var t=e.length;if(t%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var n=e.indexOf("=");return-1===n&&(n=t),[n,n===t?0:4-n%4]}function u(e,t,n){for(var i,o,a=[],s=t;s<n;s+=3)i=(e[s]<<16&16711680)+(e[s+1]<<8&65280)+(255&e[s+2]),a.push(r[(o=i)>>18&63]+r[o>>12&63]+r[o>>6&63]+r[63&o]);return a.join("")}i["-".charCodeAt(0)]=62,i["_".charCodeAt(0)]=63},function(e,t,n){"use strict";n.d(t,"a",(function(){return o}));var r,i=n(4);class o{constructor(e={}){if(this._map=new Map,this._changed=new i.Signal(this),this._isDisposed=!1,this._itemCmp=e.itemCmp||r.itemCmp,e.values)for(const t in e.values)this._map.set(t,e.values[t])}get type(){return"Map"}get changed(){return this._changed}get isDisposed(){return this._isDisposed}get size(){return this._map.size}set(e,t){const n=this._map.get(e);if(void 0===t)throw Error("Cannot set an undefined value, use remove");const r=this._itemCmp;return void 0!==n&&r(n,t)||(this._map.set(e,t),this._changed.emit({type:n?"change":"add",key:e,oldValue:n,newValue:t})),n}get(e){return this._map.get(e)}has(e){return this._map.has(e)}keys(){const e=[];return this._map.forEach((t,n)=>{e.push(n)}),e}values(){const e=[];return this._map.forEach((t,n)=>{e.push(t)}),e}delete(e){const t=this._map.get(e);return this._map.delete(e)&&this._changed.emit({type:"remove",key:e,oldValue:t,newValue:void 0}),t}clear(){const e=this.keys();for(let t=0;t<e.length;t++)this.delete(e[t])}dispose(){this.isDisposed||(this._isDisposed=!0,i.Signal.clearData(this),this._map.clear())}}!function(e){e.itemCmp=function(e,t){return e===t}}(r||(r={}))},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTkgMTMuNWMtMi40OSAwLTQuNS0yLjAxLTQuNS00LjVTNi41MSA0LjUgOSA0LjVjMS4yNCAwIDIuMzYuNTIgMy4xNyAxLjMzTDEwIDhoNVYzbC0xLjc2IDEuNzZDMTIuMTUgMy42OCAxMC42NiAzIDkgMyA1LjY5IDMgMy4wMSA1LjY5IDMuMDEgOVM1LjY5IDE1IDkgMTVjMi45NyAwIDUuNDMtMi4xNiA1LjktNWgtMS41MmMtLjQ2IDItMi4yNCAzLjUtNC4zOCAzLjV6Ii8+CiAgICA8L2c+Cjwvc3ZnPgo="},function(e,t,n){"use strict";(function(e){var n=function(){if("undefined"!=typeof Map)return Map;function e(e,t){var n=-1;return e.some((function(e,r){return e[0]===t&&(n=r,!0)})),n}return function(){function t(){this.__entries__=[]}return Object.defineProperty(t.prototype,"size",{get:function(){return this.__entries__.length},enumerable:!0,configurable:!0}),t.prototype.get=function(t){var n=e(this.__entries__,t),r=this.__entries__[n];return r&&r[1]},t.prototype.set=function(t,n){var r=e(this.__entries__,t);~r?this.__entries__[r][1]=n:this.__entries__.push([t,n])},t.prototype.delete=function(t){var n=this.__entries__,r=e(n,t);~r&&n.splice(r,1)},t.prototype.has=function(t){return!!~e(this.__entries__,t)},t.prototype.clear=function(){this.__entries__.splice(0)},t.prototype.forEach=function(e,t){void 0===t&&(t=null);for(var n=0,r=this.__entries__;n<r.length;n++){var i=r[n];e.call(t,i[1],i[0])}},t}()}(),r="undefined"!=typeof window&&"undefined"!=typeof document&&window.document===document,i=void 0!==e&&e.Math===Math?e:"undefined"!=typeof self&&self.Math===Math?self:"undefined"!=typeof window&&window.Math===Math?window:Function("return this")(),o="function"==typeof requestAnimationFrame?requestAnimationFrame.bind(i):function(e){return setTimeout((function(){return e(Date.now())}),1e3/60)};var a=["top","right","bottom","left","width","height","size","weight"],s="undefined"!=typeof MutationObserver,l=function(){function e(){this.connected_=!1,this.mutationEventsAdded_=!1,this.mutationsObserver_=null,this.observers_=[],this.onTransitionEnd_=this.onTransitionEnd_.bind(this),this.refresh=function(e,t){var n=!1,r=!1,i=0;function a(){n&&(n=!1,e()),r&&l()}function s(){o(a)}function l(){var e=Date.now();if(n){if(e-i<2)return;r=!0}else n=!0,r=!1,setTimeout(s,t);i=e}return l}(this.refresh.bind(this),20)}return e.prototype.addObserver=function(e){~this.observers_.indexOf(e)||this.observers_.push(e),this.connected_||this.connect_()},e.prototype.removeObserver=function(e){var t=this.observers_,n=t.indexOf(e);~n&&t.splice(n,1),!t.length&&this.connected_&&this.disconnect_()},e.prototype.refresh=function(){this.updateObservers_()&&this.refresh()},e.prototype.updateObservers_=function(){var e=this.observers_.filter((function(e){return e.gatherActive(),e.hasActive()}));return e.forEach((function(e){return e.broadcastActive()})),e.length>0},e.prototype.connect_=function(){r&&!this.connected_&&(document.addEventListener("transitionend",this.onTransitionEnd_),window.addEventListener("resize",this.refresh),s?(this.mutationsObserver_=new MutationObserver(this.refresh),this.mutationsObserver_.observe(document,{attributes:!0,childList:!0,characterData:!0,subtree:!0})):(document.addEventListener("DOMSubtreeModified",this.refresh),this.mutationEventsAdded_=!0),this.connected_=!0)},e.prototype.disconnect_=function(){r&&this.connected_&&(document.removeEventListener("transitionend",this.onTransitionEnd_),window.removeEventListener("resize",this.refresh),this.mutationsObserver_&&this.mutationsObserver_.disconnect(),this.mutationEventsAdded_&&document.removeEventListener("DOMSubtreeModified",this.refresh),this.mutationsObserver_=null,this.mutationEventsAdded_=!1,this.connected_=!1)},e.prototype.onTransitionEnd_=function(e){var t=e.propertyName,n=void 0===t?"":t;a.some((function(e){return!!~n.indexOf(e)}))&&this.refresh()},e.getInstance=function(){return this.instance_||(this.instance_=new e),this.instance_},e.instance_=null,e}(),c=function(e,t){for(var n=0,r=Object.keys(t);n<r.length;n++){var i=r[n];Object.defineProperty(e,i,{value:t[i],enumerable:!1,writable:!1,configurable:!0})}return e},u=function(e){return e&&e.ownerDocument&&e.ownerDocument.defaultView||i},d=v(0,0,0,0);function h(e){return parseFloat(e)||0}function p(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return t.reduce((function(t,n){return t+h(e["border-"+n+"-width"])}),0)}function f(e){var t=e.clientWidth,n=e.clientHeight;if(!t&&!n)return d;var r=u(e).getComputedStyle(e),i=function(e){for(var t={},n=0,r=["top","right","bottom","left"];n<r.length;n++){var i=r[n],o=e["padding-"+i];t[i]=h(o)}return t}(r),o=i.left+i.right,a=i.top+i.bottom,s=h(r.width),l=h(r.height);if("border-box"===r.boxSizing&&(Math.round(s+o)!==t&&(s-=p(r,"left","right")+o),Math.round(l+a)!==n&&(l-=p(r,"top","bottom")+a)),!function(e){return e===u(e).document.documentElement}(e)){var c=Math.round(s+o)-t,f=Math.round(l+a)-n;1!==Math.abs(c)&&(s-=c),1!==Math.abs(f)&&(l-=f)}return v(i.left,i.top,s,l)}var m="undefined"!=typeof SVGGraphicsElement?function(e){return e instanceof u(e).SVGGraphicsElement}:function(e){return e instanceof u(e).SVGElement&&"function"==typeof e.getBBox};function g(e){return r?m(e)?function(e){var t=e.getBBox();return v(0,0,t.width,t.height)}(e):f(e):d}function v(e,t,n,r){return{x:e,y:t,width:n,height:r}}var y=function(){function e(e){this.broadcastWidth=0,this.broadcastHeight=0,this.contentRect_=v(0,0,0,0),this.target=e}return e.prototype.isActive=function(){var e=g(this.target);return this.contentRect_=e,e.width!==this.broadcastWidth||e.height!==this.broadcastHeight},e.prototype.broadcastRect=function(){var e=this.contentRect_;return this.broadcastWidth=e.width,this.broadcastHeight=e.height,e},e}(),_=function(e,t){var n,r,i,o,a,s,l,u=(r=(n=t).x,i=n.y,o=n.width,a=n.height,s="undefined"!=typeof DOMRectReadOnly?DOMRectReadOnly:Object,l=Object.create(s.prototype),c(l,{x:r,y:i,width:o,height:a,top:i,right:r+o,bottom:a+i,left:r}),l);c(this,{target:e,contentRect:u})},b=function(){function e(e,t,r){if(this.activeObservations_=[],this.observations_=new n,"function"!=typeof e)throw new TypeError("The callback provided as parameter 1 is not a function.");this.callback_=e,this.controller_=t,this.callbackCtx_=r}return e.prototype.observe=function(e){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if("undefined"!=typeof Element&&Element instanceof Object){if(!(e instanceof u(e).Element))throw new TypeError('parameter 1 is not of type "Element".');var t=this.observations_;t.has(e)||(t.set(e,new y(e)),this.controller_.addObserver(this),this.controller_.refresh())}},e.prototype.unobserve=function(e){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if("undefined"!=typeof Element&&Element instanceof Object){if(!(e instanceof u(e).Element))throw new TypeError('parameter 1 is not of type "Element".');var t=this.observations_;t.has(e)&&(t.delete(e),t.size||this.controller_.removeObserver(this))}},e.prototype.disconnect=function(){this.clearActive(),this.observations_.clear(),this.controller_.removeObserver(this)},e.prototype.gatherActive=function(){var e=this;this.clearActive(),this.observations_.forEach((function(t){t.isActive()&&e.activeObservations_.push(t)}))},e.prototype.broadcastActive=function(){if(this.hasActive()){var e=this.callbackCtx_,t=this.activeObservations_.map((function(e){return new _(e.target,e.broadcastRect())}));this.callback_.call(e,t,e),this.clearActive()}},e.prototype.clearActive=function(){this.activeObservations_.splice(0)},e.prototype.hasActive=function(){return this.activeObservations_.length>0},e}(),M="undefined"!=typeof WeakMap?new WeakMap:new n,w=function e(t){if(!(this instanceof e))throw new TypeError("Cannot call a class as a function.");if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");var n=l.getInstance(),r=new b(t,n,this);M.set(this,r)};["observe","unobserve","disconnect"].forEach((function(e){w.prototype[e]=function(){var t;return(t=M.get(this))[e].apply(t,arguments)}}));var A=void 0!==i.ResizeObserver?i.ResizeObserver:w;t.a=A}).call(this,n(55))},function(e,t,n){(function(r){var i,o,a;a="object"==typeof self&&self.self==self&&self||"object"==typeof r&&r.global==r&&r,i=[n(16),n(41),t],void 0===(o=function(e,t,n){a.Backbone=function(e,t,n,r){var i=e.Backbone,o=Array.prototype.slice;t.VERSION="1.2.3",t.$=r,t.noConflict=function(){return e.Backbone=i,this},t.emulateHTTP=!1,t.emulateJSON=!1;var a=function(e,t,r){n.each(t,(function(t,i){n[i]&&(e.prototype[i]=function(e,t,r){switch(e){case 1:return function(){return n[t](this[r])};case 2:return function(e){return n[t](this[r],e)};case 3:return function(e,i){return n[t](this[r],s(e,this),i)};case 4:return function(e,i,o){return n[t](this[r],s(e,this),i,o)};default:return function(){var e=o.call(arguments);return e.unshift(this[r]),n[t].apply(n,e)}}}(t,i,r))}))},s=function(e,t){return n.isFunction(e)?e:n.isObject(e)&&!t._isModel(e)?l(e):n.isString(e)?function(t){return t.get(e)}:e},l=function(e){var t=n.matches(e);return function(e){return t(e.attributes)}},c=t.Events={},u=/\s+/,d=function(e,t,r,i,o){var a,s=0;if(r&&"object"==typeof r){void 0!==i&&"context"in o&&void 0===o.context&&(o.context=i);for(a=n.keys(r);s<a.length;s++)t=d(e,t,a[s],r[a[s]],o)}else if(r&&u.test(r))for(a=r.split(u);s<a.length;s++)t=e(t,a[s],i,o);else t=e(t,r,i,o);return t};c.on=function(e,t,n){return h(this,e,t,n)};var h=function(e,t,n,r,i){return e._events=d(p,e._events||{},t,n,{context:r,ctx:e,listening:i}),i&&((e._listeners||(e._listeners={}))[i.id]=i),e};c.listenTo=function(e,t,r){if(!e)return this;var i=e._listenId||(e._listenId=n.uniqueId("l")),o=this._listeningTo||(this._listeningTo={}),a=o[i];if(!a){var s=this._listenId||(this._listenId=n.uniqueId("l"));a=o[i]={obj:e,objId:i,id:s,listeningTo:o,count:0}}return h(e,t,r,this,a),this};var p=function(e,t,n,r){if(n){var i=e[t]||(e[t]=[]),o=r.context,a=r.ctx,s=r.listening;s&&s.count++,i.push({callback:n,context:o,ctx:o||a,listening:s})}return e};c.off=function(e,t,n){return this._events?(this._events=d(f,this._events,e,t,{context:n,listeners:this._listeners}),this):this},c.stopListening=function(e,t,r){var i=this._listeningTo;if(!i)return this;for(var o=e?[e._listenId]:n.keys(i),a=0;a<o.length;a++){var s=i[o[a]];if(!s)break;s.obj.off(t,r,this)}return n.isEmpty(i)&&(this._listeningTo=void 0),this};var f=function(e,t,r,i){if(e){var o,a=0,s=i.context,l=i.listeners;if(t||r||s){for(var c=t?[t]:n.keys(e);a<c.length;a++){var u=e[t=c[a]];if(!u)break;for(var d=[],h=0;h<u.length;h++){var p=u[h];r&&r!==p.callback&&r!==p.callback._callback||s&&s!==p.context?d.push(p):(o=p.listening)&&0==--o.count&&(delete l[o.id],delete o.listeningTo[o.objId])}d.length?e[t]=d:delete e[t]}return n.size(e)?e:void 0}for(var f=n.keys(l);a<f.length;a++)delete l[(o=l[f[a]]).id],delete o.listeningTo[o.objId]}};c.once=function(e,t,r){var i=d(m,{},e,t,n.bind(this.off,this));return this.on(i,void 0,r)},c.listenToOnce=function(e,t,r){var i=d(m,{},t,r,n.bind(this.stopListening,this,e));return this.listenTo(e,i)};var m=function(e,t,r,i){if(r){var o=e[t]=n.once((function(){i(t,o),r.apply(this,arguments)}));o._callback=r}return e};c.trigger=function(e){if(!this._events)return this;for(var t=Math.max(0,arguments.length-1),n=Array(t),r=0;r<t;r++)n[r]=arguments[r+1];return d(g,this._events,e,void 0,n),this};var g=function(e,t,n,r){if(e){var i=e[t],o=e.all;i&&o&&(o=o.slice()),i&&v(i,r),o&&v(o,[t].concat(r))}return e},v=function(e,t){var n,r=-1,i=e.length,o=t[0],a=t[1],s=t[2];switch(t.length){case 0:for(;++r<i;)(n=e[r]).callback.call(n.ctx);return;case 1:for(;++r<i;)(n=e[r]).callback.call(n.ctx,o);return;case 2:for(;++r<i;)(n=e[r]).callback.call(n.ctx,o,a);return;case 3:for(;++r<i;)(n=e[r]).callback.call(n.ctx,o,a,s);return;default:for(;++r<i;)(n=e[r]).callback.apply(n.ctx,t);return}};c.bind=c.on,c.unbind=c.off,n.extend(t,c);var y=t.Model=function(e,t){var r=e||{};t||(t={}),this.cid=n.uniqueId(this.cidPrefix),this.attributes={},t.collection&&(this.collection=t.collection),t.parse&&(r=this.parse(r,t)||{}),r=n.defaults({},r,n.result(this,"defaults")),this.set(r,t),this.changed={},this.initialize.apply(this,arguments)};n.extend(y.prototype,c,{changed:null,validationError:null,idAttribute:"id",cidPrefix:"c",initialize:function(){},toJSON:function(e){return n.clone(this.attributes)},sync:function(){return t.sync.apply(this,arguments)},get:function(e){return this.attributes[e]},escape:function(e){return n.escape(this.get(e))},has:function(e){return null!=this.get(e)},matches:function(e){return!!n.iteratee(e,this)(this.attributes)},set:function(e,t,r){if(null==e)return this;var i;if("object"==typeof e?(i=e,r=t):(i={})[e]=t,r||(r={}),!this._validate(i,r))return!1;var o=r.unset,a=r.silent,s=[],l=this._changing;this._changing=!0,l||(this._previousAttributes=n.clone(this.attributes),this.changed={});var c=this.attributes,u=this.changed,d=this._previousAttributes;for(var h in i)t=i[h],n.isEqual(c[h],t)||s.push(h),n.isEqual(d[h],t)?delete u[h]:u[h]=t,o?delete c[h]:c[h]=t;if(this.id=this.get(this.idAttribute),!a){s.length&&(this._pending=r);for(var p=0;p<s.length;p++)this.trigger("change:"+s[p],this,c[s[p]],r)}if(l)return this;if(!a)for(;this._pending;)r=this._pending,this._pending=!1,this.trigger("change",this,r);return this._pending=!1,this._changing=!1,this},unset:function(e,t){return this.set(e,void 0,n.extend({},t,{unset:!0}))},clear:function(e){var t={};for(var r in this.attributes)t[r]=void 0;return this.set(t,n.extend({},e,{unset:!0}))},hasChanged:function(e){return null==e?!n.isEmpty(this.changed):n.has(this.changed,e)},changedAttributes:function(e){if(!e)return!!this.hasChanged()&&n.clone(this.changed);var t=this._changing?this._previousAttributes:this.attributes,r={};for(var i in e){var o=e[i];n.isEqual(t[i],o)||(r[i]=o)}return!!n.size(r)&&r},previous:function(e){return null!=e&&this._previousAttributes?this._previousAttributes[e]:null},previousAttributes:function(){return n.clone(this._previousAttributes)},fetch:function(e){e=n.extend({parse:!0},e);var t=this,r=e.success;return e.success=function(n){var i=e.parse?t.parse(n,e):n;if(!t.set(i,e))return!1;r&&r.call(e.context,t,n,e),t.trigger("sync",t,n,e)},z(this,e),this.sync("read",this,e)},save:function(e,t,r){var i;null==e||"object"==typeof e?(i=e,r=t):(i={})[e]=t;var o=(r=n.extend({validate:!0,parse:!0},r)).wait;if(i&&!o){if(!this.set(i,r))return!1}else if(!this._validate(i,r))return!1;var a=this,s=r.success,l=this.attributes;r.success=function(e){a.attributes=l;var t=r.parse?a.parse(e,r):e;if(o&&(t=n.extend({},i,t)),t&&!a.set(t,r))return!1;s&&s.call(r.context,a,e,r),a.trigger("sync",a,e,r)},z(this,r),i&&o&&(this.attributes=n.extend({},l,i));var c=this.isNew()?"create":r.patch?"patch":"update";"patch"!==c||r.attrs||(r.attrs=i);var u=this.sync(c,this,r);return this.attributes=l,u},destroy:function(e){e=e?n.clone(e):{};var t=this,r=e.success,i=e.wait,o=function(){t.stopListening(),t.trigger("destroy",t,t.collection,e)};e.success=function(n){i&&o(),r&&r.call(e.context,t,n,e),t.isNew()||t.trigger("sync",t,n,e)};var a=!1;return this.isNew()?n.defer(e.success):(z(this,e),a=this.sync("delete",this,e)),i||o(),a},url:function(){var e=n.result(this,"urlRoot")||n.result(this.collection,"url")||P();if(this.isNew())return e;var t=this.get(this.idAttribute);return e.replace(/[^\/]$/,"$&/")+encodeURIComponent(t)},parse:function(e,t){return e},clone:function(){return new this.constructor(this.attributes)},isNew:function(){return!this.has(this.idAttribute)},isValid:function(e){return this._validate({},n.defaults({validate:!0},e))},_validate:function(e,t){if(!t.validate||!this.validate)return!0;e=n.extend({},this.attributes,e);var r=this.validationError=this.validate(e,t)||null;return!r||(this.trigger("invalid",this,r,n.extend(t,{validationError:r})),!1)}}),a(y,{keys:1,values:1,pairs:1,invert:1,pick:0,omit:0,chain:1,isEmpty:1},"attributes");var _=t.Collection=function(e,t){t||(t={}),t.model&&(this.model=t.model),void 0!==t.comparator&&(this.comparator=t.comparator),this._reset(),this.initialize.apply(this,arguments),e&&this.reset(e,n.extend({silent:!0},t))},b={add:!0,remove:!0,merge:!0},M={add:!0,remove:!1},w=function(e,t,n){n=Math.min(Math.max(n,0),e.length);for(var r=Array(e.length-n),i=t.length,o=0;o<r.length;o++)r[o]=e[o+n];for(o=0;o<i;o++)e[o+n]=t[o];for(o=0;o<r.length;o++)e[o+i+n]=r[o]};n.extend(_.prototype,c,{model:y,initialize:function(){},toJSON:function(e){return this.map((function(t){return t.toJSON(e)}))},sync:function(){return t.sync.apply(this,arguments)},add:function(e,t){return this.set(e,n.extend({merge:!1},t,M))},remove:function(e,t){t=n.extend({},t);var r=!n.isArray(e);e=r?[e]:n.clone(e);var i=this._removeModels(e,t);return!t.silent&&i&&this.trigger("update",this,t),r?i[0]:i},set:function(e,t){if(null!=e){(t=n.defaults({},t,b)).parse&&!this._isModel(e)&&(e=this.parse(e,t));var r=!n.isArray(e);e=r?[e]:e.slice();var i=t.at;null!=i&&(i=+i),i<0&&(i+=this.length+1);for(var o,a=[],s=[],l=[],c={},u=t.add,d=t.merge,h=t.remove,p=!1,f=this.comparator&&null==i&&!1!==t.sort,m=n.isString(this.comparator)?this.comparator:null,g=0;g<e.length;g++){o=e[g];var v=this.get(o);if(v){if(d&&o!==v){var y=this._isModel(o)?o.attributes:o;t.parse&&(y=v.parse(y,t)),v.set(y,t),f&&!p&&(p=v.hasChanged(m))}c[v.cid]||(c[v.cid]=!0,a.push(v)),e[g]=v}else u&&(o=e[g]=this._prepareModel(o,t))&&(s.push(o),this._addReference(o,t),c[o.cid]=!0,a.push(o))}if(h){for(g=0;g<this.length;g++)c[(o=this.models[g]).cid]||l.push(o);l.length&&this._removeModels(l,t)}var _=!1,M=!f&&u&&h;if(a.length&&M?(_=this.length!=a.length||n.some(this.models,(function(e,t){return e!==a[t]})),this.models.length=0,w(this.models,a,0),this.length=this.models.length):s.length&&(f&&(p=!0),w(this.models,s,null==i?this.length:i),this.length=this.models.length),p&&this.sort({silent:!0}),!t.silent){for(g=0;g<s.length;g++)null!=i&&(t.index=i+g),(o=s[g]).trigger("add",o,this,t);(p||_)&&this.trigger("sort",this,t),(s.length||l.length)&&this.trigger("update",this,t)}return r?e[0]:e}},reset:function(e,t){t=t?n.clone(t):{};for(var r=0;r<this.models.length;r++)this._removeReference(this.models[r],t);return t.previousModels=this.models,this._reset(),e=this.add(e,n.extend({silent:!0},t)),t.silent||this.trigger("reset",this,t),e},push:function(e,t){return this.add(e,n.extend({at:this.length},t))},pop:function(e){var t=this.at(this.length-1);return this.remove(t,e)},unshift:function(e,t){return this.add(e,n.extend({at:0},t))},shift:function(e){var t=this.at(0);return this.remove(t,e)},slice:function(){return o.apply(this.models,arguments)},get:function(e){if(null!=e){var t=this.modelId(this._isModel(e)?e.attributes:e);return this._byId[e]||this._byId[t]||this._byId[e.cid]}},at:function(e){return e<0&&(e+=this.length),this.models[e]},where:function(e,t){return this[t?"find":"filter"](e)},findWhere:function(e){return this.where(e,!0)},sort:function(e){var t=this.comparator;if(!t)throw new Error("Cannot sort a set without a comparator");e||(e={});var r=t.length;return n.isFunction(t)&&(t=n.bind(t,this)),1===r||n.isString(t)?this.models=this.sortBy(t):this.models.sort(t),e.silent||this.trigger("sort",this,e),this},pluck:function(e){return n.invoke(this.models,"get",e)},fetch:function(e){var t=(e=n.extend({parse:!0},e)).success,r=this;return e.success=function(n){var i=e.reset?"reset":"set";r[i](n,e),t&&t.call(e.context,r,n,e),r.trigger("sync",r,n,e)},z(this,e),this.sync("read",this,e)},create:function(e,t){var r=(t=t?n.clone(t):{}).wait;if(!(e=this._prepareModel(e,t)))return!1;r||this.add(e,t);var i=this,o=t.success;return t.success=function(e,t,n){r&&i.add(e,n),o&&o.call(n.context,e,t,n)},e.save(null,t),e},parse:function(e,t){return e},clone:function(){return new this.constructor(this.models,{model:this.model,comparator:this.comparator})},modelId:function(e){return e[this.model.prototype.idAttribute||"id"]},_reset:function(){this.length=0,this.models=[],this._byId={}},_prepareModel:function(e,t){if(this._isModel(e))return e.collection||(e.collection=this),e;(t=t?n.clone(t):{}).collection=this;var r=new this.model(e,t);return r.validationError?(this.trigger("invalid",this,r.validationError,t),!1):r},_removeModels:function(e,t){for(var n=[],r=0;r<e.length;r++){var i=this.get(e[r]);if(i){var o=this.indexOf(i);this.models.splice(o,1),this.length--,t.silent||(t.index=o,i.trigger("remove",i,this,t)),n.push(i),this._removeReference(i,t)}}return!!n.length&&n},_isModel:function(e){return e instanceof y},_addReference:function(e,t){this._byId[e.cid]=e;var n=this.modelId(e.attributes);null!=n&&(this._byId[n]=e),e.on("all",this._onModelEvent,this)},_removeReference:function(e,t){delete this._byId[e.cid];var n=this.modelId(e.attributes);null!=n&&delete this._byId[n],this===e.collection&&delete e.collection,e.off("all",this._onModelEvent,this)},_onModelEvent:function(e,t,n,r){if("add"!==e&&"remove"!==e||n===this){if("destroy"===e&&this.remove(t,r),"change"===e){var i=this.modelId(t.previousAttributes()),o=this.modelId(t.attributes);i!==o&&(null!=i&&delete this._byId[i],null!=o&&(this._byId[o]=t))}this.trigger.apply(this,arguments)}}}),a(_,{forEach:3,each:3,map:3,collect:3,reduce:4,foldl:4,inject:4,reduceRight:4,foldr:4,find:3,detect:3,filter:3,select:3,reject:3,every:3,all:3,some:3,any:3,include:3,includes:3,contains:3,invoke:0,max:3,min:3,toArray:1,size:1,first:3,head:3,take:3,initial:3,rest:3,tail:3,drop:3,last:3,without:0,difference:0,indexOf:3,shuffle:1,lastIndexOf:3,isEmpty:1,chain:1,sample:3,partition:3,groupBy:3,countBy:3,sortBy:3,indexBy:3},"models");var A=t.View=function(e){this.cid=n.uniqueId("view"),n.extend(this,n.pick(e,x)),this._ensureElement(),this.initialize.apply(this,arguments)},C=/^(\S+)\s*(.*)$/,x=["model","collection","el","id","attributes","className","tagName","events"];n.extend(A.prototype,c,{tagName:"div",$:function(e){return this.$el.find(e)},initialize:function(){},render:function(){return this},remove:function(){return this._removeElement(),this.stopListening(),this},_removeElement:function(){this.$el.remove()},setElement:function(e){return this.undelegateEvents(),this._setElement(e),this.delegateEvents(),this},_setElement:function(e){this.$el=e instanceof t.$?e:t.$(e),this.el=this.$el[0]},delegateEvents:function(e){if(e||(e=n.result(this,"events")),!e)return this;for(var t in this.undelegateEvents(),e){var r=e[t];if(n.isFunction(r)||(r=this[r]),r){var i=t.match(C);this.delegate(i[1],i[2],n.bind(r,this))}}return this},delegate:function(e,t,n){return this.$el.on(e+".delegateEvents"+this.cid,t,n),this},undelegateEvents:function(){return this.$el&&this.$el.off(".delegateEvents"+this.cid),this},undelegate:function(e,t,n){return this.$el.off(e+".delegateEvents"+this.cid,t,n),this},_createElement:function(e){return document.createElement(e)},_ensureElement:function(){if(this.el)this.setElement(n.result(this,"el"));else{var e=n.extend({},n.result(this,"attributes"));this.id&&(e.id=n.result(this,"id")),this.className&&(e.class=n.result(this,"className")),this.setElement(this._createElement(n.result(this,"tagName"))),this._setAttributes(e)}},_setAttributes:function(e){this.$el.attr(e)}}),t.sync=function(e,r,i){var o=E[e];n.defaults(i||(i={}),{emulateHTTP:t.emulateHTTP,emulateJSON:t.emulateJSON});var a={type:o,dataType:"json"};if(i.url||(a.url=n.result(r,"url")||P()),null!=i.data||!r||"create"!==e&&"update"!==e&&"patch"!==e||(a.contentType="application/json",a.data=JSON.stringify(i.attrs||r.toJSON(i))),i.emulateJSON&&(a.contentType="application/x-www-form-urlencoded",a.data=a.data?{model:a.data}:{}),i.emulateHTTP&&("PUT"===o||"DELETE"===o||"PATCH"===o)){a.type="POST",i.emulateJSON&&(a.data._method=o);var s=i.beforeSend;i.beforeSend=function(e){if(e.setRequestHeader("X-HTTP-Method-Override",o),s)return s.apply(this,arguments)}}"GET"===a.type||i.emulateJSON||(a.processData=!1);var l=i.error;i.error=function(e,t,n){i.textStatus=t,i.errorThrown=n,l&&l.call(i.context,e,t,n)};var c=i.xhr=t.ajax(n.extend(a,i));return r.trigger("request",r,c,i),c};var E={create:"POST",update:"PUT",patch:"PATCH",delete:"DELETE",read:"GET"};t.ajax=function(){return t.$.ajax.apply(t.$,arguments)};var L=t.Router=function(e){e||(e={}),e.routes&&(this.routes=e.routes),this._bindRoutes(),this.initialize.apply(this,arguments)},S=/\((.*?)\)/g,T=/(\(\?)?:\w+/g,O=/\*\w+/g,I=/[\-{}\[\]+?.,\\\^$|#\s]/g;n.extend(L.prototype,c,{initialize:function(){},route:function(e,r,i){n.isRegExp(e)||(e=this._routeToRegExp(e)),n.isFunction(r)&&(i=r,r=""),i||(i=this[r]);var o=this;return t.history.route(e,(function(n){var a=o._extractParameters(e,n);!1!==o.execute(i,a,r)&&(o.trigger.apply(o,["route:"+r].concat(a)),o.trigger("route",r,a),t.history.trigger("route",o,r,a))})),this},execute:function(e,t,n){e&&e.apply(this,t)},navigate:function(e,n){return t.history.navigate(e,n),this},_bindRoutes:function(){if(this.routes){this.routes=n.result(this,"routes");for(var e,t=n.keys(this.routes);null!=(e=t.pop());)this.route(e,this.routes[e])}},_routeToRegExp:function(e){return e=e.replace(I,"\\$&").replace(S,"(?:$1)?").replace(T,(function(e,t){return t?e:"([^/?]+)"})).replace(O,"([^?]*?)"),new RegExp("^"+e+"(?:\\?([\\s\\S]*))?$")},_extractParameters:function(e,t){var r=e.exec(t).slice(1);return n.map(r,(function(e,t){return t===r.length-1?e||null:e?decodeURIComponent(e):null}))}});var k=t.History=function(){this.handlers=[],this.checkUrl=n.bind(this.checkUrl,this),"undefined"!=typeof window&&(this.location=window.location,this.history=window.history)},D=/^[#\/]|\s+$/g,N=/^\/+|\/+$/g,j=/#.*$/;k.started=!1,n.extend(k.prototype,c,{interval:50,atRoot:function(){return this.location.pathname.replace(/[^\/]$/,"$&/")===this.root&&!this.getSearch()},matchRoot:function(){return this.decodeFragment(this.location.pathname).slice(0,this.root.length-1)+"/"===this.root},decodeFragment:function(e){return decodeURI(e.replace(/%25/g,"%2525"))},getSearch:function(){var e=this.location.href.replace(/#.*/,"").match(/\?.+/);return e?e[0]:""},getHash:function(e){var t=(e||this).location.href.match(/#(.*)$/);return t?t[1]:""},getPath:function(){var e=this.decodeFragment(this.location.pathname+this.getSearch()).slice(this.root.length-1);return"/"===e.charAt(0)?e.slice(1):e},getFragment:function(e){return null==e&&(e=this._usePushState||!this._wantsHashChange?this.getPath():this.getHash()),e.replace(D,"")},start:function(e){if(k.started)throw new Error("Backbone.history has already been started");if(k.started=!0,this.options=n.extend({root:"/"},this.options,e),this.root=this.options.root,this._wantsHashChange=!1!==this.options.hashChange,this._hasHashChange="onhashchange"in window&&(void 0===document.documentMode||document.documentMode>7),this._useHashChange=this._wantsHashChange&&this._hasHashChange,this._wantsPushState=!!this.options.pushState,this._hasPushState=!(!this.history||!this.history.pushState),this._usePushState=this._wantsPushState&&this._hasPushState,this.fragment=this.getFragment(),this.root=("/"+this.root+"/").replace(N,"/"),this._wantsHashChange&&this._wantsPushState){if(!this._hasPushState&&!this.atRoot()){var t=this.root.slice(0,-1)||"/";return this.location.replace(t+"#"+this.getPath()),!0}this._hasPushState&&this.atRoot()&&this.navigate(this.getHash(),{replace:!0})}if(!this._hasHashChange&&this._wantsHashChange&&!this._usePushState){this.iframe=document.createElement("iframe"),this.iframe.src="javascript:0",this.iframe.style.display="none",this.iframe.tabIndex=-1;var r=document.body,i=r.insertBefore(this.iframe,r.firstChild).contentWindow;i.document.open(),i.document.close(),i.location.hash="#"+this.fragment}var o=window.addEventListener||function(e,t){return attachEvent("on"+e,t)};if(this._usePushState?o("popstate",this.checkUrl,!1):this._useHashChange&&!this.iframe?o("hashchange",this.checkUrl,!1):this._wantsHashChange&&(this._checkUrlInterval=setInterval(this.checkUrl,this.interval)),!this.options.silent)return this.loadUrl()},stop:function(){var e=window.removeEventListener||function(e,t){return detachEvent("on"+e,t)};this._usePushState?e("popstate",this.checkUrl,!1):this._useHashChange&&!this.iframe&&e("hashchange",this.checkUrl,!1),this.iframe&&(document.body.removeChild(this.iframe),this.iframe=null),this._checkUrlInterval&&clearInterval(this._checkUrlInterval),k.started=!1},route:function(e,t){this.handlers.unshift({route:e,callback:t})},checkUrl:function(e){var t=this.getFragment();if(t===this.fragment&&this.iframe&&(t=this.getHash(this.iframe.contentWindow)),t===this.fragment)return!1;this.iframe&&this.navigate(t),this.loadUrl()},loadUrl:function(e){return!!this.matchRoot()&&(e=this.fragment=this.getFragment(e),n.some(this.handlers,(function(t){if(t.route.test(e))return t.callback(e),!0})))},navigate:function(e,t){if(!k.started)return!1;t&&!0!==t||(t={trigger:!!t}),e=this.getFragment(e||"");var n=this.root;""!==e&&"?"!==e.charAt(0)||(n=n.slice(0,-1)||"/");var r=n+e;if(e=this.decodeFragment(e.replace(j,"")),this.fragment!==e){if(this.fragment=e,this._usePushState)this.history[t.replace?"replaceState":"pushState"]({},document.title,r);else{if(!this._wantsHashChange)return this.location.assign(r);if(this._updateHash(this.location,e,t.replace),this.iframe&&e!==this.getHash(this.iframe.contentWindow)){var i=this.iframe.contentWindow;t.replace||(i.document.open(),i.document.close()),this._updateHash(i.location,e,t.replace)}}return t.trigger?this.loadUrl(e):void 0}},_updateHash:function(e,t,n){if(n){var r=e.href.replace(/(javascript:|#).*$/,"");e.replace(r+"#"+t)}else e.hash="#"+t}}),t.history=new k,y.extend=_.extend=L.extend=A.extend=k.extend=function(e,t){var r,i=this;r=e&&n.has(e,"constructor")?e.constructor:function(){return i.apply(this,arguments)},n.extend(r,i,t);var o=function(){this.constructor=r};return o.prototype=i.prototype,r.prototype=new o,e&&n.extend(r.prototype,e),r.__super__=i.prototype,r};var P=function(){throw new Error('A "url" property or function must be specified')},z=function(e,t){var n=t.error;t.error=function(r){n&&n.call(t.context,e,r,t),e.trigger("error",e,r,t)}};return t}(a,n,e,t)}.apply(t,i))||(e.exports=o)}).call(this,n(55))},function(e,t,n){(function(n){var r;t=e.exports=h,r="object"==typeof n&&n.env&&n.env.NODE_DEBUG&&/\bsemver\b/i.test(n.env.NODE_DEBUG)?function(){var e=Array.prototype.slice.call(arguments,0);e.unshift("SEMVER"),console.log.apply(console,e)}:function(){},t.SEMVER_SPEC_VERSION="2.0.0";var i=Number.MAX_SAFE_INTEGER||9007199254740991,o=t.re=[],a=t.src=[],s=t.tokens={},l=0;function c(e){s[e]=l++}c("NUMERICIDENTIFIER"),a[s.NUMERICIDENTIFIER]="0|[1-9]\\d*",c("NUMERICIDENTIFIERLOOSE"),a[s.NUMERICIDENTIFIERLOOSE]="[0-9]+",c("NONNUMERICIDENTIFIER"),a[s.NONNUMERICIDENTIFIER]="\\d*[a-zA-Z-][a-zA-Z0-9-]*",c("MAINVERSION"),a[s.MAINVERSION]="("+a[s.NUMERICIDENTIFIER]+")\\.("+a[s.NUMERICIDENTIFIER]+")\\.("+a[s.NUMERICIDENTIFIER]+")",c("MAINVERSIONLOOSE"),a[s.MAINVERSIONLOOSE]="("+a[s.NUMERICIDENTIFIERLOOSE]+")\\.("+a[s.NUMERICIDENTIFIERLOOSE]+")\\.("+a[s.NUMERICIDENTIFIERLOOSE]+")",c("PRERELEASEIDENTIFIER"),a[s.PRERELEASEIDENTIFIER]="(?:"+a[s.NUMERICIDENTIFIER]+"|"+a[s.NONNUMERICIDENTIFIER]+")",c("PRERELEASEIDENTIFIERLOOSE"),a[s.PRERELEASEIDENTIFIERLOOSE]="(?:"+a[s.NUMERICIDENTIFIERLOOSE]+"|"+a[s.NONNUMERICIDENTIFIER]+")",c("PRERELEASE"),a[s.PRERELEASE]="(?:-("+a[s.PRERELEASEIDENTIFIER]+"(?:\\."+a[s.PRERELEASEIDENTIFIER]+")*))",c("PRERELEASELOOSE"),a[s.PRERELEASELOOSE]="(?:-?("+a[s.PRERELEASEIDENTIFIERLOOSE]+"(?:\\."+a[s.PRERELEASEIDENTIFIERLOOSE]+")*))",c("BUILDIDENTIFIER"),a[s.BUILDIDENTIFIER]="[0-9A-Za-z-]+",c("BUILD"),a[s.BUILD]="(?:\\+("+a[s.BUILDIDENTIFIER]+"(?:\\."+a[s.BUILDIDENTIFIER]+")*))",c("FULL"),c("FULLPLAIN"),a[s.FULLPLAIN]="v?"+a[s.MAINVERSION]+a[s.PRERELEASE]+"?"+a[s.BUILD]+"?",a[s.FULL]="^"+a[s.FULLPLAIN]+"$",c("LOOSEPLAIN"),a[s.LOOSEPLAIN]="[v=\\s]*"+a[s.MAINVERSIONLOOSE]+a[s.PRERELEASELOOSE]+"?"+a[s.BUILD]+"?",c("LOOSE"),a[s.LOOSE]="^"+a[s.LOOSEPLAIN]+"$",c("GTLT"),a[s.GTLT]="((?:<|>)?=?)",c("XRANGEIDENTIFIERLOOSE"),a[s.XRANGEIDENTIFIERLOOSE]=a[s.NUMERICIDENTIFIERLOOSE]+"|x|X|\\*",c("XRANGEIDENTIFIER"),a[s.XRANGEIDENTIFIER]=a[s.NUMERICIDENTIFIER]+"|x|X|\\*",c("XRANGEPLAIN"),a[s.XRANGEPLAIN]="[v=\\s]*("+a[s.XRANGEIDENTIFIER]+")(?:\\.("+a[s.XRANGEIDENTIFIER]+")(?:\\.("+a[s.XRANGEIDENTIFIER]+")(?:"+a[s.PRERELEASE]+")?"+a[s.BUILD]+"?)?)?",c("XRANGEPLAINLOOSE"),a[s.XRANGEPLAINLOOSE]="[v=\\s]*("+a[s.XRANGEIDENTIFIERLOOSE]+")(?:\\.("+a[s.XRANGEIDENTIFIERLOOSE]+")(?:\\.("+a[s.XRANGEIDENTIFIERLOOSE]+")(?:"+a[s.PRERELEASELOOSE]+")?"+a[s.BUILD]+"?)?)?",c("XRANGE"),a[s.XRANGE]="^"+a[s.GTLT]+"\\s*"+a[s.XRANGEPLAIN]+"$",c("XRANGELOOSE"),a[s.XRANGELOOSE]="^"+a[s.GTLT]+"\\s*"+a[s.XRANGEPLAINLOOSE]+"$",c("COERCE"),a[s.COERCE]="(^|[^\\d])(\\d{1,16})(?:\\.(\\d{1,16}))?(?:\\.(\\d{1,16}))?(?:$|[^\\d])",c("COERCERTL"),o[s.COERCERTL]=new RegExp(a[s.COERCE],"g"),c("LONETILDE"),a[s.LONETILDE]="(?:~>?)",c("TILDETRIM"),a[s.TILDETRIM]="(\\s*)"+a[s.LONETILDE]+"\\s+",o[s.TILDETRIM]=new RegExp(a[s.TILDETRIM],"g");c("TILDE"),a[s.TILDE]="^"+a[s.LONETILDE]+a[s.XRANGEPLAIN]+"$",c("TILDELOOSE"),a[s.TILDELOOSE]="^"+a[s.LONETILDE]+a[s.XRANGEPLAINLOOSE]+"$",c("LONECARET"),a[s.LONECARET]="(?:\\^)",c("CARETTRIM"),a[s.CARETTRIM]="(\\s*)"+a[s.LONECARET]+"\\s+",o[s.CARETTRIM]=new RegExp(a[s.CARETTRIM],"g");c("CARET"),a[s.CARET]="^"+a[s.LONECARET]+a[s.XRANGEPLAIN]+"$",c("CARETLOOSE"),a[s.CARETLOOSE]="^"+a[s.LONECARET]+a[s.XRANGEPLAINLOOSE]+"$",c("COMPARATORLOOSE"),a[s.COMPARATORLOOSE]="^"+a[s.GTLT]+"\\s*("+a[s.LOOSEPLAIN]+")$|^$",c("COMPARATOR"),a[s.COMPARATOR]="^"+a[s.GTLT]+"\\s*("+a[s.FULLPLAIN]+")$|^$",c("COMPARATORTRIM"),a[s.COMPARATORTRIM]="(\\s*)"+a[s.GTLT]+"\\s*("+a[s.LOOSEPLAIN]+"|"+a[s.XRANGEPLAIN]+")",o[s.COMPARATORTRIM]=new RegExp(a[s.COMPARATORTRIM],"g");c("HYPHENRANGE"),a[s.HYPHENRANGE]="^\\s*("+a[s.XRANGEPLAIN]+")\\s+-\\s+("+a[s.XRANGEPLAIN]+")\\s*$",c("HYPHENRANGELOOSE"),a[s.HYPHENRANGELOOSE]="^\\s*("+a[s.XRANGEPLAINLOOSE]+")\\s+-\\s+("+a[s.XRANGEPLAINLOOSE]+")\\s*$",c("STAR"),a[s.STAR]="(<|>)?=?\\s*\\*";for(var u=0;u<l;u++)r(u,a[u]),o[u]||(o[u]=new RegExp(a[u]));function d(e,t){if(t&&"object"==typeof t||(t={loose:!!t,includePrerelease:!1}),e instanceof h)return e;if("string"!=typeof e)return null;if(e.length>256)return null;if(!(t.loose?o[s.LOOSE]:o[s.FULL]).test(e))return null;try{return new h(e,t)}catch(e){return null}}function h(e,t){if(t&&"object"==typeof t||(t={loose:!!t,includePrerelease:!1}),e instanceof h){if(e.loose===t.loose)return e;e=e.version}else if("string"!=typeof e)throw new TypeError("Invalid Version: "+e);if(e.length>256)throw new TypeError("version is longer than 256 characters");if(!(this instanceof h))return new h(e,t);r("SemVer",e,t),this.options=t,this.loose=!!t.loose;var n=e.trim().match(t.loose?o[s.LOOSE]:o[s.FULL]);if(!n)throw new TypeError("Invalid Version: "+e);if(this.raw=e,this.major=+n[1],this.minor=+n[2],this.patch=+n[3],this.major>i||this.major<0)throw new TypeError("Invalid major version");if(this.minor>i||this.minor<0)throw new TypeError("Invalid minor version");if(this.patch>i||this.patch<0)throw new TypeError("Invalid patch version");n[4]?this.prerelease=n[4].split(".").map((function(e){if(/^[0-9]+$/.test(e)){var t=+e;if(t>=0&&t<i)return t}return e})):this.prerelease=[],this.build=n[5]?n[5].split("."):[],this.format()}t.parse=d,t.valid=function(e,t){var n=d(e,t);return n?n.version:null},t.clean=function(e,t){var n=d(e.trim().replace(/^[=v]+/,""),t);return n?n.version:null},t.SemVer=h,h.prototype.format=function(){return this.version=this.major+"."+this.minor+"."+this.patch,this.prerelease.length&&(this.version+="-"+this.prerelease.join(".")),this.version},h.prototype.toString=function(){return this.version},h.prototype.compare=function(e){return r("SemVer.compare",this.version,this.options,e),e instanceof h||(e=new h(e,this.options)),this.compareMain(e)||this.comparePre(e)},h.prototype.compareMain=function(e){return e instanceof h||(e=new h(e,this.options)),f(this.major,e.major)||f(this.minor,e.minor)||f(this.patch,e.patch)},h.prototype.comparePre=function(e){if(e instanceof h||(e=new h(e,this.options)),this.prerelease.length&&!e.prerelease.length)return-1;if(!this.prerelease.length&&e.prerelease.length)return 1;if(!this.prerelease.length&&!e.prerelease.length)return 0;var t=0;do{var n=this.prerelease[t],i=e.prerelease[t];if(r("prerelease compare",t,n,i),void 0===n&&void 0===i)return 0;if(void 0===i)return 1;if(void 0===n)return-1;if(n!==i)return f(n,i)}while(++t)},h.prototype.compareBuild=function(e){e instanceof h||(e=new h(e,this.options));var t=0;do{var n=this.build[t],i=e.build[t];if(r("prerelease compare",t,n,i),void 0===n&&void 0===i)return 0;if(void 0===i)return 1;if(void 0===n)return-1;if(n!==i)return f(n,i)}while(++t)},h.prototype.inc=function(e,t){switch(e){case"premajor":this.prerelease.length=0,this.patch=0,this.minor=0,this.major++,this.inc("pre",t);break;case"preminor":this.prerelease.length=0,this.patch=0,this.minor++,this.inc("pre",t);break;case"prepatch":this.prerelease.length=0,this.inc("patch",t),this.inc("pre",t);break;case"prerelease":0===this.prerelease.length&&this.inc("patch",t),this.inc("pre",t);break;case"major":0===this.minor&&0===this.patch&&0!==this.prerelease.length||this.major++,this.minor=0,this.patch=0,this.prerelease=[];break;case"minor":0===this.patch&&0!==this.prerelease.length||this.minor++,this.patch=0,this.prerelease=[];break;case"patch":0===this.prerelease.length&&this.patch++,this.prerelease=[];break;case"pre":if(0===this.prerelease.length)this.prerelease=[0];else{for(var n=this.prerelease.length;--n>=0;)"number"==typeof this.prerelease[n]&&(this.prerelease[n]++,n=-2);-1===n&&this.prerelease.push(0)}t&&(this.prerelease[0]===t?isNaN(this.prerelease[1])&&(this.prerelease=[t,0]):this.prerelease=[t,0]);break;default:throw new Error("invalid increment argument: "+e)}return this.format(),this.raw=this.version,this},t.inc=function(e,t,n,r){"string"==typeof n&&(r=n,n=void 0);try{return new h(e,n).inc(t,r).version}catch(e){return null}},t.diff=function(e,t){if(y(e,t))return null;var n=d(e),r=d(t),i="";if(n.prerelease.length||r.prerelease.length){i="pre";var o="prerelease"}for(var a in n)if(("major"===a||"minor"===a||"patch"===a)&&n[a]!==r[a])return i+a;return o},t.compareIdentifiers=f;var p=/^[0-9]+$/;function f(e,t){var n=p.test(e),r=p.test(t);return n&&r&&(e=+e,t=+t),e===t?0:n&&!r?-1:r&&!n?1:e<t?-1:1}function m(e,t,n){return new h(e,n).compare(new h(t,n))}function g(e,t,n){return m(e,t,n)>0}function v(e,t,n){return m(e,t,n)<0}function y(e,t,n){return 0===m(e,t,n)}function _(e,t,n){return 0!==m(e,t,n)}function b(e,t,n){return m(e,t,n)>=0}function M(e,t,n){return m(e,t,n)<=0}function w(e,t,n,r){switch(t){case"===":return"object"==typeof e&&(e=e.version),"object"==typeof n&&(n=n.version),e===n;case"!==":return"object"==typeof e&&(e=e.version),"object"==typeof n&&(n=n.version),e!==n;case"":case"=":case"==":return y(e,n,r);case"!=":return _(e,n,r);case">":return g(e,n,r);case">=":return b(e,n,r);case"<":return v(e,n,r);case"<=":return M(e,n,r);default:throw new TypeError("Invalid operator: "+t)}}function A(e,t){if(t&&"object"==typeof t||(t={loose:!!t,includePrerelease:!1}),e instanceof A){if(e.loose===!!t.loose)return e;e=e.value}if(!(this instanceof A))return new A(e,t);r("comparator",e,t),this.options=t,this.loose=!!t.loose,this.parse(e),this.semver===C?this.value="":this.value=this.operator+this.semver.version,r("comp",this)}t.rcompareIdentifiers=function(e,t){return f(t,e)},t.major=function(e,t){return new h(e,t).major},t.minor=function(e,t){return new h(e,t).minor},t.patch=function(e,t){return new h(e,t).patch},t.compare=m,t.compareLoose=function(e,t){return m(e,t,!0)},t.compareBuild=function(e,t,n){var r=new h(e,n),i=new h(t,n);return r.compare(i)||r.compareBuild(i)},t.rcompare=function(e,t,n){return m(t,e,n)},t.sort=function(e,n){return e.sort((function(e,r){return t.compareBuild(e,r,n)}))},t.rsort=function(e,n){return e.sort((function(e,r){return t.compareBuild(r,e,n)}))},t.gt=g,t.lt=v,t.eq=y,t.neq=_,t.gte=b,t.lte=M,t.cmp=w,t.Comparator=A;var C={};function x(e,t){if(t&&"object"==typeof t||(t={loose:!!t,includePrerelease:!1}),e instanceof x)return e.loose===!!t.loose&&e.includePrerelease===!!t.includePrerelease?e:new x(e.raw,t);if(e instanceof A)return new x(e.value,t);if(!(this instanceof x))return new x(e,t);if(this.options=t,this.loose=!!t.loose,this.includePrerelease=!!t.includePrerelease,this.raw=e,this.set=e.split(/\s*\|\|\s*/).map((function(e){return this.parseRange(e.trim())}),this).filter((function(e){return e.length})),!this.set.length)throw new TypeError("Invalid SemVer Range: "+e);this.format()}function E(e,t){for(var n=!0,r=e.slice(),i=r.pop();n&&r.length;)n=r.every((function(e){return i.intersects(e,t)})),i=r.pop();return n}function L(e){return!e||"x"===e.toLowerCase()||"*"===e}function S(e,t,n,r,i,o,a,s,l,c,u,d,h){return((t=L(n)?"":L(r)?">="+n+".0.0":L(i)?">="+n+"."+r+".0":">="+t)+" "+(s=L(l)?"":L(c)?"<"+(+l+1)+".0.0":L(u)?"<"+l+"."+(+c+1)+".0":d?"<="+l+"."+c+"."+u+"-"+d:"<="+s)).trim()}function T(e,t,n){for(var i=0;i<e.length;i++)if(!e[i].test(t))return!1;if(t.prerelease.length&&!n.includePrerelease){for(i=0;i<e.length;i++)if(r(e[i].semver),e[i].semver!==C&&e[i].semver.prerelease.length>0){var o=e[i].semver;if(o.major===t.major&&o.minor===t.minor&&o.patch===t.patch)return!0}return!1}return!0}function O(e,t,n){try{t=new x(t,n)}catch(e){return!1}return t.test(e)}function I(e,t,n,r){var i,o,a,s,l;switch(e=new h(e,r),t=new x(t,r),n){case">":i=g,o=M,a=v,s=">",l=">=";break;case"<":i=v,o=b,a=g,s="<",l="<=";break;default:throw new TypeError('Must provide a hilo val of "<" or ">"')}if(O(e,t,r))return!1;for(var c=0;c<t.set.length;++c){var u=t.set[c],d=null,p=null;if(u.forEach((function(e){e.semver===C&&(e=new A(">=0.0.0")),d=d||e,p=p||e,i(e.semver,d.semver,r)?d=e:a(e.semver,p.semver,r)&&(p=e)})),d.operator===s||d.operator===l)return!1;if((!p.operator||p.operator===s)&&o(e,p.semver))return!1;if(p.operator===l&&a(e,p.semver))return!1}return!0}A.prototype.parse=function(e){var t=this.options.loose?o[s.COMPARATORLOOSE]:o[s.COMPARATOR],n=e.match(t);if(!n)throw new TypeError("Invalid comparator: "+e);this.operator=void 0!==n[1]?n[1]:"","="===this.operator&&(this.operator=""),n[2]?this.semver=new h(n[2],this.options.loose):this.semver=C},A.prototype.toString=function(){return this.value},A.prototype.test=function(e){if(r("Comparator.test",e,this.options.loose),this.semver===C||e===C)return!0;if("string"==typeof e)try{e=new h(e,this.options)}catch(e){return!1}return w(e,this.operator,this.semver,this.options)},A.prototype.intersects=function(e,t){if(!(e instanceof A))throw new TypeError("a Comparator is required");var n;if(t&&"object"==typeof t||(t={loose:!!t,includePrerelease:!1}),""===this.operator)return""===this.value||(n=new x(e.value,t),O(this.value,n,t));if(""===e.operator)return""===e.value||(n=new x(this.value,t),O(e.semver,n,t));var r=!(">="!==this.operator&&">"!==this.operator||">="!==e.operator&&">"!==e.operator),i=!("<="!==this.operator&&"<"!==this.operator||"<="!==e.operator&&"<"!==e.operator),o=this.semver.version===e.semver.version,a=!(">="!==this.operator&&"<="!==this.operator||">="!==e.operator&&"<="!==e.operator),s=w(this.semver,"<",e.semver,t)&&(">="===this.operator||">"===this.operator)&&("<="===e.operator||"<"===e.operator),l=w(this.semver,">",e.semver,t)&&("<="===this.operator||"<"===this.operator)&&(">="===e.operator||">"===e.operator);return r||i||o&&a||s||l},t.Range=x,x.prototype.format=function(){return this.range=this.set.map((function(e){return e.join(" ").trim()})).join("||").trim(),this.range},x.prototype.toString=function(){return this.range},x.prototype.parseRange=function(e){var t=this.options.loose;e=e.trim();var n=t?o[s.HYPHENRANGELOOSE]:o[s.HYPHENRANGE];e=e.replace(n,S),r("hyphen replace",e),e=e.replace(o[s.COMPARATORTRIM],"$1$2$3"),r("comparator trim",e,o[s.COMPARATORTRIM]),e=(e=(e=e.replace(o[s.TILDETRIM],"$1~")).replace(o[s.CARETTRIM],"$1^")).split(/\s+/).join(" ");var i=t?o[s.COMPARATORLOOSE]:o[s.COMPARATOR],a=e.split(" ").map((function(e){return function(e,t){return r("comp",e,t),e=function(e,t){return e.trim().split(/\s+/).map((function(e){return function(e,t){r("caret",e,t);var n=t.loose?o[s.CARETLOOSE]:o[s.CARET];return e.replace(n,(function(t,n,i,o,a){var s;return r("caret",e,t,n,i,o,a),L(n)?s="":L(i)?s=">="+n+".0.0 <"+(+n+1)+".0.0":L(o)?s="0"===n?">="+n+"."+i+".0 <"+n+"."+(+i+1)+".0":">="+n+"."+i+".0 <"+(+n+1)+".0.0":a?(r("replaceCaret pr",a),s="0"===n?"0"===i?">="+n+"."+i+"."+o+"-"+a+" <"+n+"."+i+"."+(+o+1):">="+n+"."+i+"."+o+"-"+a+" <"+n+"."+(+i+1)+".0":">="+n+"."+i+"."+o+"-"+a+" <"+(+n+1)+".0.0"):(r("no pr"),s="0"===n?"0"===i?">="+n+"."+i+"."+o+" <"+n+"."+i+"."+(+o+1):">="+n+"."+i+"."+o+" <"+n+"."+(+i+1)+".0":">="+n+"."+i+"."+o+" <"+(+n+1)+".0.0"),r("caret return",s),s}))}(e,t)})).join(" ")}(e,t),r("caret",e),e=function(e,t){return e.trim().split(/\s+/).map((function(e){return function(e,t){var n=t.loose?o[s.TILDELOOSE]:o[s.TILDE];return e.replace(n,(function(t,n,i,o,a){var s;return r("tilde",e,t,n,i,o,a),L(n)?s="":L(i)?s=">="+n+".0.0 <"+(+n+1)+".0.0":L(o)?s=">="+n+"."+i+".0 <"+n+"."+(+i+1)+".0":a?(r("replaceTilde pr",a),s=">="+n+"."+i+"."+o+"-"+a+" <"+n+"."+(+i+1)+".0"):s=">="+n+"."+i+"."+o+" <"+n+"."+(+i+1)+".0",r("tilde return",s),s}))}(e,t)})).join(" ")}(e,t),r("tildes",e),e=function(e,t){return r("replaceXRanges",e,t),e.split(/\s+/).map((function(e){return function(e,t){e=e.trim();var n=t.loose?o[s.XRANGELOOSE]:o[s.XRANGE];return e.replace(n,(function(n,i,o,a,s,l){r("xRange",e,n,i,o,a,s,l);var c=L(o),u=c||L(a),d=u||L(s),h=d;return"="===i&&h&&(i=""),l=t.includePrerelease?"-0":"",c?n=">"===i||"<"===i?"<0.0.0-0":"*":i&&h?(u&&(a=0),s=0,">"===i?(i=">=",u?(o=+o+1,a=0,s=0):(a=+a+1,s=0)):"<="===i&&(i="<",u?o=+o+1:a=+a+1),n=i+o+"."+a+"."+s+l):u?n=">="+o+".0.0"+l+" <"+(+o+1)+".0.0"+l:d&&(n=">="+o+"."+a+".0"+l+" <"+o+"."+(+a+1)+".0"+l),r("xRange return",n),n}))}(e,t)})).join(" ")}(e,t),r("xrange",e),e=function(e,t){return r("replaceStars",e,t),e.trim().replace(o[s.STAR],"")}(e,t),r("stars",e),e}(e,this.options)}),this).join(" ").split(/\s+/);return this.options.loose&&(a=a.filter((function(e){return!!e.match(i)}))),a=a.map((function(e){return new A(e,this.options)}),this)},x.prototype.intersects=function(e,t){if(!(e instanceof x))throw new TypeError("a Range is required");return this.set.some((function(n){return E(n,t)&&e.set.some((function(e){return E(e,t)&&n.every((function(n){return e.every((function(e){return n.intersects(e,t)}))}))}))}))},t.toComparators=function(e,t){return new x(e,t).set.map((function(e){return e.map((function(e){return e.value})).join(" ").trim().split(" ")}))},x.prototype.test=function(e){if(!e)return!1;if("string"==typeof e)try{e=new h(e,this.options)}catch(e){return!1}for(var t=0;t<this.set.length;t++)if(T(this.set[t],e,this.options))return!0;return!1},t.satisfies=O,t.maxSatisfying=function(e,t,n){var r=null,i=null;try{var o=new x(t,n)}catch(e){return null}return e.forEach((function(e){o.test(e)&&(r&&-1!==i.compare(e)||(i=new h(r=e,n)))})),r},t.minSatisfying=function(e,t,n){var r=null,i=null;try{var o=new x(t,n)}catch(e){return null}return e.forEach((function(e){o.test(e)&&(r&&1!==i.compare(e)||(i=new h(r=e,n)))})),r},t.minVersion=function(e,t){e=new x(e,t);var n=new h("0.0.0");if(e.test(n))return n;if(n=new h("0.0.0-0"),e.test(n))return n;n=null;for(var r=0;r<e.set.length;++r){e.set[r].forEach((function(e){var t=new h(e.semver.version);switch(e.operator){case">":0===t.prerelease.length?t.patch++:t.prerelease.push(0),t.raw=t.format();case"":case">=":n&&!g(n,t)||(n=t);break;case"<":case"<=":break;default:throw new Error("Unexpected operation: "+e.operator)}}))}if(n&&e.test(n))return n;return null},t.validRange=function(e,t){try{return new x(e,t).range||"*"}catch(e){return null}},t.ltr=function(e,t,n){return I(e,t,"<",n)},t.gtr=function(e,t,n){return I(e,t,">",n)},t.outside=I,t.prerelease=function(e,t){var n=d(e,t);return n&&n.prerelease.length?n.prerelease:null},t.intersects=function(e,t,n){return e=new x(e,n),t=new x(t,n),e.intersects(t)},t.coerce=function(e,t){if(e instanceof h)return e;"number"==typeof e&&(e=String(e));if("string"!=typeof e)return null;var n=null;if((t=t||{}).rtl){for(var r;(r=o[s.COERCERTL].exec(e))&&(!n||n.index+n[0].length!==e.length);)n&&r.index+r[0].length===n.index+n[0].length||(n=r),o[s.COERCERTL].lastIndex=r.index+r[1].length+r[2].length;o[s.COERCERTL].lastIndex=-1}else n=e.match(o[s.COERCE]);if(null===n)return null;return d(n[2]+"."+(n[3]||"0")+"."+(n[4]||"0"),t)}}).call(this,n(61))},function(e,t,n){"use strict";n.r(t),n.d(t,"uuid",(function(){return r.uuid})),n.d(t,"WrappedError",(function(){return r.WrappedError})),n.d(t,"resolvePromisesDict",(function(){return r.resolvePromisesDict})),n.d(t,"reject",(function(){return i})),n.d(t,"typeset",(function(){return o})),n.d(t,"escape_html",(function(){return a})),n.d(t,"JUPYTER_CONTROLS_VERSION",(function(){return l.a})),n.d(t,"DirectionalLinkModel",(function(){return A})),n.d(t,"LinkModel",(function(){return C})),n.d(t,"BoolModel",(function(){return E})),n.d(t,"CheckboxModel",(function(){return L})),n.d(t,"CheckboxView",(function(){return S})),n.d(t,"ToggleButtonModel",(function(){return T})),n.d(t,"ToggleButtonView",(function(){return O})),n.d(t,"ValidModel",(function(){return I})),n.d(t,"ValidView",(function(){return k})),n.d(t,"ButtonStyleModel",(function(){return N})),n.d(t,"ButtonModel",(function(){return j})),n.d(t,"ButtonView",(function(){return P})),n.d(t,"BoxModel",(function(){return U})),n.d(t,"HBoxModel",(function(){return W})),n.d(t,"VBoxModel",(function(){return G})),n.d(t,"BoxView",(function(){return q})),n.d(t,"HBoxView",(function(){return K})),n.d(t,"VBoxView",(function(){return X})),n.d(t,"GridBoxView",(function(){return J})),n.d(t,"GridBoxModel",(function(){return Q})),n.d(t,"ImageModel",(function(){return ee})),n.d(t,"ImageView",(function(){return te})),n.d(t,"VideoModel",(function(){return ie})),n.d(t,"VideoView",(function(){return oe})),n.d(t,"AudioModel",(function(){return le})),n.d(t,"AudioView",(function(){return ce})),n.d(t,"ColorPickerModel",(function(){return de})),n.d(t,"ColorPickerView",(function(){return he})),n.d(t,"serialize_date",(function(){return ge})),n.d(t,"deserialize_date",(function(){return ve})),n.d(t,"DatePickerModel",(function(){return ye})),n.d(t,"DatePickerView",(function(){return _e})),n.d(t,"IntModel",(function(){return Ne})),n.d(t,"BoundedIntModel",(function(){return je})),n.d(t,"SliderStyleModel",(function(){return Pe})),n.d(t,"IntSliderModel",(function(){return ze})),n.d(t,"IntRangeSliderModel",(function(){return Re})),n.d(t,"BaseIntSliderView",(function(){return Be})),n.d(t,"IntRangeSliderView",(function(){return He})),n.d(t,"IntSliderView",(function(){return Fe})),n.d(t,"IntTextModel",(function(){return Ye})),n.d(t,"BoundedIntTextModel",(function(){return Ve})),n.d(t,"IntTextView",(function(){return Ue})),n.d(t,"ProgressStyleModel",(function(){return We})),n.d(t,"IntProgressModel",(function(){return Ge})),n.d(t,"ProgressView",(function(){return qe})),n.d(t,"PlayModel",(function(){return Ke})),n.d(t,"PlayView",(function(){return Xe})),n.d(t,"FloatModel",(function(){return Qe})),n.d(t,"BoundedFloatModel",(function(){return Ze})),n.d(t,"FloatSliderModel",(function(){return $e})),n.d(t,"FloatLogSliderModel",(function(){return et})),n.d(t,"FloatRangeSliderModel",(function(){return tt})),n.d(t,"FloatSliderView",(function(){return nt})),n.d(t,"FloatLogSliderView",(function(){return rt})),n.d(t,"FloatRangeSliderView",(function(){return it})),n.d(t,"FloatTextModel",(function(){return ot})),n.d(t,"BoundedFloatTextModel",(function(){return at})),n.d(t,"FloatTextView",(function(){return st})),n.d(t,"FloatProgressModel",(function(){return lt})),n.d(t,"ControllerButtonModel",(function(){return dt})),n.d(t,"ControllerButtonView",(function(){return ht})),n.d(t,"ControllerAxisModel",(function(){return pt})),n.d(t,"ControllerAxisView",(function(){return ft})),n.d(t,"ControllerModel",(function(){return mt})),n.d(t,"ControllerView",(function(){return gt})),n.d(t,"SelectionModel",(function(){return _t})),n.d(t,"DropdownModel",(function(){return bt})),n.d(t,"DropdownView",(function(){return Mt})),n.d(t,"SelectModel",(function(){return wt})),n.d(t,"SelectView",(function(){return At})),n.d(t,"RadioButtonsModel",(function(){return Ct})),n.d(t,"RadioButtonsView",(function(){return xt})),n.d(t,"ToggleButtonsStyleModel",(function(){return Et})),n.d(t,"ToggleButtonsModel",(function(){return Lt})),n.d(t,"ToggleButtonsView",(function(){return St})),n.d(t,"SelectionSliderModel",(function(){return Tt})),n.d(t,"SelectionSliderView",(function(){return Ot})),n.d(t,"MultipleSelectionModel",(function(){return It})),n.d(t,"SelectMultipleModel",(function(){return kt})),n.d(t,"SelectMultipleView",(function(){return Dt})),n.d(t,"SelectionRangeSliderModel",(function(){return Nt})),n.d(t,"SelectionRangeSliderView",(function(){return jt})),n.d(t,"SelectionContainerModel",(function(){return Gt})),n.d(t,"AccordionModel",(function(){return qt})),n.d(t,"JupyterPhosphorAccordionWidget",(function(){return Kt})),n.d(t,"AccordionView",(function(){return Xt})),n.d(t,"TabModel",(function(){return Jt})),n.d(t,"JupyterPhosphorTabPanelWidget",(function(){return Qt})),n.d(t,"TabView",(function(){return Zt})),n.d(t,"StringModel",(function(){return tn})),n.d(t,"HTMLModel",(function(){return nn})),n.d(t,"HTMLView",(function(){return rn})),n.d(t,"HTMLMathModel",(function(){return on})),n.d(t,"HTMLMathView",(function(){return an})),n.d(t,"LabelModel",(function(){return sn})),n.d(t,"LabelView",(function(){return ln})),n.d(t,"TextareaModel",(function(){return cn})),n.d(t,"TextareaView",(function(){return un})),n.d(t,"TextModel",(function(){return dn})),n.d(t,"TextView",(function(){return hn})),n.d(t,"PasswordModel",(function(){return pn})),n.d(t,"PasswordView",(function(){return fn})),n.d(t,"ComboboxModel",(function(){return mn})),n.d(t,"ComboboxView",(function(){return gn})),n.d(t,"DescriptionStyleModel",(function(){return d})),n.d(t,"DescriptionModel",(function(){return h})),n.d(t,"DescriptionView",(function(){return p})),n.d(t,"LabeledDOMWidgetModel",(function(){return f})),n.d(t,"LabeledDOMWidgetView",(function(){return m})),n.d(t,"FileUploadModel",(function(){return bn})),n.d(t,"FileUploadView",(function(){return Mn})),n.d(t,"version",(function(){return wn}));var r=n(15);function i(e,t){return function(n){var i=new r.WrappedError(e,n);return t&&console.error(i),Promise.reject(i)}}function o(e,t){void 0!==t&&(e.textContent=t),void 0!==window.MathJax&&MathJax.Hub.Queue(["Typeset",MathJax.Hub,e])}function a(e){var t=document.createElement("div");return t.textContent=e,t.innerHTML}var s,l=n(48),c=(s=function(e,t){return(s=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}s(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),u=function(){return(u=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return c(t,e),t.prototype.defaults=function(){return u(u({},e.prototype.defaults.call(this)),{_model_name:"DescriptionStyleModel",_model_module:"@jupyter-widgets/controls",_model_module_version:l.a})},t.styleProperties={description_width:{selector:".widget-label",attribute:"width",default:null}},t}(r.StyleModel),h=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return c(t,e),t.prototype.defaults=function(){return u(u({},e.prototype.defaults.call(this)),{_model_name:"DescriptionModel",_view_name:"DescriptionView",_view_module:"@jupyter-widgets/controls",_model_module:"@jupyter-widgets/controls",_view_module_version:l.a,_model_module_version:l.a,description:"",description_tooltip:null})},t}(r.DOMWidgetModel),p=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return c(t,e),t.prototype.render=function(){this.label=document.createElement("label"),this.el.appendChild(this.label),this.label.className="widget-label",this.label.style.display="none",this.listenTo(this.model,"change:description",this.updateDescription),this.listenTo(this.model,"change:description_tooltip",this.updateDescription),this.updateDescription()},t.prototype.typeset=function(e,t){this.displayed.then((function(){return o(e,t)}))},t.prototype.updateDescription=function(){var e=this.model.get("description"),t=this.model.get("description_tooltip");null===t&&(t=e),0===e.length?this.label.style.display="none":(this.label.innerHTML=e,this.typeset(this.label),this.label.style.display=""),this.label.title=t},t}(r.DOMWidgetView),f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return c(t,e),t}(h),m=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return c(t,e),t}(p),g=n(16),v=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),y=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return v(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"CoreWidgetModel",_view_module:"@jupyter-widgets/controls",_model_module:"@jupyter-widgets/controls",_view_module_version:l.a,_model_module_version:l.a})},t}(r.WidgetModel),_=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return v(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"CoreDOMWidgetModel",_view_module:"@jupyter-widgets/controls",_model_module:"@jupyter-widgets/controls",_view_module_version:l.a,_model_module_version:l.a})},t}(r.DOMWidgetModel),b=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return v(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"CoreDescriptionModel",_view_module:"@jupyter-widgets/controls",_model_module:"@jupyter-widgets/controls",_view_module_version:l.a,_model_module_version:l.a})},t}(h),M=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),w=function(){return(w=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},A=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return M(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{target:void 0,source:void 0,_model_name:"DirectionalLinkModel"})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),this.on("change",this.updateBindings,this),this.updateBindings()},t.prototype.updateValue=function(e,t,n,r){if(!this._updating){this._updating=!0;try{n&&(n.set(r,e.get(t)),n.save_changes())}finally{this._updating=!1}}},t.prototype.updateBindings=function(){var e,t,n=this;this.cleanup(),e=this.get("source")||[null,null],this.sourceModel=e[0],this.sourceAttr=e[1],t=this.get("target")||[null,null],this.targetModel=t[0],this.targetAttr=t[1],this.sourceModel&&(this.listenTo(this.sourceModel,"change:"+this.sourceAttr,(function(){n.updateValue(n.sourceModel,n.sourceAttr,n.targetModel,n.targetAttr)})),this.updateValue(this.sourceModel,this.sourceAttr,this.targetModel,this.targetAttr),this.listenToOnce(this.sourceModel,"destroy",this.cleanup)),this.targetModel&&this.listenToOnce(this.targetModel,"destroy",this.cleanup)},t.prototype.cleanup=function(){this.sourceModel&&(this.stopListening(this.sourceModel,"change:"+this.sourceAttr,null),this.stopListening(this.sourceModel,"destroy",null)),this.targetModel&&this.stopListening(this.targetModel,"destroy",null)},t.serializers=w(w({},y.serializers),{target:{deserialize:r.unpack_models},source:{deserialize:r.unpack_models}}),t}(y),C=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return M(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"LinkModel"})},t.prototype.updateBindings=function(){var t=this;e.prototype.updateBindings.call(this),this.targetModel&&this.listenTo(this.targetModel,"change:"+this.targetAttr,(function(){t.updateValue(t.targetModel,t.targetAttr,t.sourceModel,t.sourceAttr)}))},t.prototype.cleanup=function(){e.prototype.cleanup.call(this),this.targetModel&&this.stopListening(this.targetModel,"change:"+this.targetAttr,null)},t}(A),x=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),E=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{value:!1,disabled:!1,_model_name:"BoolModel"})},t}(b),L=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{indent:!0,_view_name:"CheckboxView",_model_name:"CheckboxModel"})},t}(b),S=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-checkbox"),this.label.innerHTML="&#8203;",this.checkboxLabel=document.createElement("label"),this.checkboxLabel.classList.add("widget-label-basic"),this.el.appendChild(this.checkboxLabel),this.checkbox=document.createElement("input"),this.checkbox.setAttribute("type","checkbox"),this.checkboxLabel.appendChild(this.checkbox),this.descriptionSpan=document.createElement("span"),this.checkboxLabel.appendChild(this.descriptionSpan),this.listenTo(this.model,"change:indent",this.updateIndent),this.update(),this.updateDescription(),this.updateIndent()},t.prototype.updateDescription=function(){if(null!=this.checkboxLabel){var e=this.model.get("description");this.descriptionSpan.innerHTML=e,this.typeset(this.descriptionSpan),this.descriptionSpan.title=e,this.checkbox.title=e}},t.prototype.updateIndent=function(){var e=this.model.get("indent");this.label.style.display=e?"":"none"},t.prototype.events=function(){return{'click input[type="checkbox"]':"_handle_click"}},t.prototype._handle_click=function(){var e=this.model.get("value");this.model.set("value",!e,{updated_view:this}),this.touch()},t.prototype.update=function(t){return this.checkbox.checked=this.model.get("value"),void 0!==t&&t.updated_view==this||(this.checkbox.disabled=this.model.get("disabled")),e.prototype.update.call(this)},t}(p),T=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"ToggleButtonView",_model_name:"ToggleButtonModel",tooltip:"",icon:"",button_style:""})},t}(E),O=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("jupyter-button"),this.el.classList.add("widget-toggle-button"),this.listenTo(this.model,"change:button_style",this.update_button_style),this.set_button_style(),this.update()},t.prototype.update_button_style=function(){this.update_mapped_classes(t.class_map,"button_style")},t.prototype.set_button_style=function(){this.set_mapped_classes(t.class_map,"button_style")},t.prototype.update=function(t){if(this.model.get("value")?this.el.classList.add("mod-active"):this.el.classList.remove("mod-active"),void 0===t||t.updated_view!==this){this.el.disabled=this.model.get("disabled"),this.el.setAttribute("title",this.model.get("tooltip"));var n=this.model.get("description"),r=this.model.get("icon");if(0===n.trim().length&&0===r.trim().length)this.el.innerHTML="&nbsp;";else{if(this.el.textContent="",r.trim().length){var i=document.createElement("i");this.el.appendChild(i),i.classList.add("fa"),i.classList.add("fa-"+r)}this.el.appendChild(document.createTextNode(n))}}return e.prototype.update.call(this)},t.prototype.events=function(){return{click:"_handle_click"}},t.prototype._handle_click=function(e){e.preventDefault();var t=this.model.get("value");this.model.set("value",!t,{updated_view:this}),this.touch()},Object.defineProperty(t.prototype,"tagName",{get:function(){return"button"},enumerable:!0,configurable:!0}),t.class_map={primary:["mod-primary"],success:["mod-success"],info:["mod-info"],warning:["mod-warning"],danger:["mod-danger"]},t}(r.DOMWidgetView),I=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{readout:"Invalid",_view_name:"ValidView",_model_name:"ValidModel"})},t}(E),k=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return x(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-valid"),this.el.classList.add("widget-inline-hbox"),this.icon=document.createElement("i"),this.icon.classList.add("fa","fa-fw"),this.el.appendChild(this.icon),this.readout=document.createElement("span"),this.readout.classList.add("widget-valid-readout"),this.readout.classList.add("widget-readout"),this.el.appendChild(this.readout),this.update()},t.prototype.update=function(){this.el.classList.remove("mod-valid"),this.el.classList.remove("mod-invalid"),this.icon.classList.remove("fa-check"),this.icon.classList.remove("fa-times"),this.readout.textContent=this.model.get("readout"),this.model.get("value")?(this.el.classList.add("mod-valid"),this.icon.classList.add("fa-check")):(this.el.classList.add("mod-invalid"),this.icon.classList.add("fa-times"))},t}(p),D=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),N=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return D(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ButtonStyleModel",_model_module:"@jupyter-widgets/controls",_model_module_version:l.a})},t.styleProperties={button_color:{selector:"",attribute:"background-color",default:null},font_weight:{selector:"",attribute:"font-weight",default:""}},t}(r.StyleModel),j=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return D(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{description:"",tooltip:"",disabled:!1,icon:"",button_style:"",_view_name:"ButtonView",_model_name:"ButtonModel",style:null})},t}(_),P=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return D(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("jupyter-button"),this.el.classList.add("widget-button"),this.listenTo(this.model,"change:button_style",this.update_button_style),this.set_button_style(),this.update()},t.prototype.update=function(){this.el.disabled=this.model.get("disabled"),this.el.setAttribute("title",this.model.get("tooltip"));var t=this.model.get("description"),n=this.model.get("icon");if(t.length||n.length){if(this.el.textContent="",n.length){var r=document.createElement("i");r.classList.add("fa"),r.classList.add("fa-"+n),0===t.length&&r.classList.add("center"),this.el.appendChild(r)}this.el.appendChild(document.createTextNode(t))}return e.prototype.update.call(this)},t.prototype.update_button_style=function(){this.update_mapped_classes(t.class_map,"button_style")},t.prototype.set_button_style=function(){this.set_mapped_classes(t.class_map,"button_style")},t.prototype.events=function(){return{click:"_handle_click"}},t.prototype._handle_click=function(e){e.preventDefault(),this.send({event:"click"})},Object.defineProperty(t.prototype,"tagName",{get:function(){return"button"},enumerable:!0,configurable:!0}),t.class_map={primary:["mod-primary"],success:["mod-success"],info:["mod-info"],warning:["mod-warning"],danger:["mod-danger"]},t}(r.DOMWidgetView),z=n(2),R=n(8),B=n(3),H=n(41),F=n.n(H),Y=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),V=function(){return(V=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},U=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"BoxView",_model_name:"BoxModel",children:[],box_style:""})},t.serializers=V(V({},_.serializers),{children:{deserialize:r.unpack_models}}),t}(_),W=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"HBoxView",_model_name:"HBoxModel"})},t}(U),G=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"VBoxView",_model_name:"VBoxModel"})},t}(U),q=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype._createElement=function(e){return this.pWidget=new r.JupyterPhosphorPanelWidget({view:this}),this.pWidget.node},t.prototype._setElement=function(e){if(this.el||e!==this.pWidget.node)throw new Error("Cannot reset the DOM element.");this.el=this.pWidget.node,this.$el=F()(this.pWidget.node)},t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.children_views=new r.ViewList(this.add_child_model,null,this),this.listenTo(this.model,"change:children",this.update_children),this.listenTo(this.model,"change:box_style",this.update_box_style),this.pWidget.addClass("jupyter-widgets"),this.pWidget.addClass("widget-container"),this.pWidget.addClass("widget-box")},t.prototype.render=function(){e.prototype.render.call(this),this.update_children(),this.set_box_style()},t.prototype.update_children=function(){this.children_views.update(this.model.get("children")).then((function(e){e.forEach((function(e){R.c.postMessage(e.pWidget,B.Widget.ResizeMessage.UnknownSize)}))}))},t.prototype.update_box_style=function(){this.update_mapped_classes(t.class_map,"box_style")},t.prototype.set_box_style=function(){this.set_mapped_classes(t.class_map,"box_style")},t.prototype.add_child_model=function(e){var t=this,n=new B.Widget;return this.pWidget.addWidget(n),this.create_child_view(e).then((function(e){var r=z.ArrayExt.firstIndexOf(t.pWidget.widgets,n);return t.pWidget.insertWidget(r,e.pWidget),n.dispose(),e})).catch(i("Could not add child view to box",!0))},t.prototype.remove=function(){this.children_views=null,e.prototype.remove.call(this)},t.class_map={success:["alert","alert-success"],info:["alert","alert-info"],warning:["alert","alert-warning"],danger:["alert","alert-danger"]},t}(r.DOMWidgetView),K=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.pWidget.addClass("widget-hbox")},t}(q),X=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.pWidget.addClass("widget-vbox")},t}(q),J=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.pWidget.addClass("widget-gridbox"),this.pWidget.removeClass("widget-box")},t}(q),Q=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Y(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"GridBoxView",_model_name:"GridBoxModel"})},t}(U),Z=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),$=function(){return($=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},ee=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Z(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ImageModel",_view_name:"ImageView",format:"png",width:"",height:"",value:new DataView(new ArrayBuffer(0))})},t.serializers=$($({},_.serializers),{value:{serialize:function(e){return new DataView(e.buffer.slice(0))}}}),t}(_),te=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Z(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.pWidget.addClass("jupyter-widgets"),this.pWidget.addClass("widget-image"),this.update()},t.prototype.update=function(){var t,n=this.model.get("format"),r=this.model.get("value");if("url"!==n){var i=new Blob([r],{type:"image/"+this.model.get("format")});t=URL.createObjectURL(i)}else t=new TextDecoder("utf-8").decode(r.buffer);var o=this.el.src;this.el.src=t,o&&"string"!=typeof o&&URL.revokeObjectURL(o);var a=this.model.get("width");void 0!==a&&a.length>0?this.el.setAttribute("width",a):this.el.removeAttribute("width");var s=this.model.get("height");return void 0!==s&&s.length>0?this.el.setAttribute("height",s):this.el.removeAttribute("height"),e.prototype.update.call(this)},t.prototype.remove=function(){this.el.src&&URL.revokeObjectURL(this.el.src),e.prototype.remove.call(this)},Object.defineProperty(t.prototype,"tagName",{get:function(){return"img"},enumerable:!0,configurable:!0}),t}(r.DOMWidgetView),ne=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),re=function(){return(re=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},ie=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ne(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"VideoModel",_view_name:"VideoView",format:"mp4",width:"",height:"",autoplay:!0,loop:!0,controls:!0,value:new DataView(new ArrayBuffer(0))})},t.serializers=re(re({},_.serializers),{value:{serialize:function(e){return new DataView(e.buffer.slice(0))}}}),t}(_),oe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ne(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.pWidget.addClass("jupyter-widgets"),this.pWidget.addClass("widget-image"),this.update()},t.prototype.update=function(){var t,n=this.model.get("format"),r=this.model.get("value");if("url"!==n){var i=new Blob([r],{type:"video/"+this.model.get("format")});t=URL.createObjectURL(i)}else t=new TextDecoder("utf-8").decode(r.buffer);var o=this.el.src;this.el.src=t,o&&"string"!=typeof o&&URL.revokeObjectURL(o);var a=this.model.get("width");void 0!==a&&a.length>0?this.el.setAttribute("width",a):this.el.removeAttribute("width");var s=this.model.get("height");return void 0!==s&&s.length>0?this.el.setAttribute("height",s):this.el.removeAttribute("height"),this.el.loop=this.model.get("loop"),this.el.autoplay=this.model.get("autoplay"),this.el.controls=this.model.get("controls"),e.prototype.update.call(this)},t.prototype.remove=function(){this.el.src&&URL.revokeObjectURL(this.el.src),e.prototype.remove.call(this)},Object.defineProperty(t.prototype,"tagName",{get:function(){return"video"},enumerable:!0,configurable:!0}),t}(r.DOMWidgetView),ae=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),se=function(){return(se=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},le=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ae(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"AudioModel",_view_name:"AudioView",format:"mp3",autoplay:!0,loop:!0,controls:!0,value:new DataView(new ArrayBuffer(0))})},t.serializers=se(se({},_.serializers),{value:{serialize:function(e){return new DataView(e.buffer.slice(0))}}}),t}(_),ce=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ae(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.pWidget.addClass("jupyter-widgets"),this.update()},t.prototype.update=function(){var t,n=this.model.get("format"),r=this.model.get("value");if("url"!==n){var i=new Blob([r],{type:"audio/"+this.model.get("format")});t=URL.createObjectURL(i)}else t=new TextDecoder("utf-8").decode(r.buffer);var o=this.el.src;return this.el.src=t,o&&"string"!=typeof o&&URL.revokeObjectURL(o),this.el.loop=this.model.get("loop"),this.el.autoplay=this.model.get("autoplay"),this.el.controls=this.model.get("controls"),e.prototype.update.call(this)},t.prototype.remove=function(){this.el.src&&URL.revokeObjectURL(this.el.src),e.prototype.remove.call(this)},Object.defineProperty(t.prototype,"tagName",{get:function(){return"audio"},enumerable:!0,configurable:!0}),t}(r.DOMWidgetView),ue=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),de=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ue(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{value:"black",concise:!1,_model_name:"ColorPickerModel",_view_name:"ColorPickerView"})},t}(b),he=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ue(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-colorpicker"),this._color_container=document.createElement("div"),this._color_container.className="widget-inline-hbox widget-colorpicker-input",this.el.appendChild(this._color_container),this._textbox=document.createElement("input"),this._textbox.setAttribute("type","text"),this._textbox.id=this.label.htmlFor=Object(r.uuid)(),this._color_container.appendChild(this._textbox),this._textbox.value=this.model.get("value"),this._colorpicker=document.createElement("input"),this._colorpicker.setAttribute("type","color"),this._color_container.appendChild(this._colorpicker),this.listenTo(this.model,"change:value",this._update_value),this.listenTo(this.model,"change:concise",this._update_concise),this._update_concise(),this._update_value(),this.update()},t.prototype.update=function(t){if(void 0===t||t.updated_view!=this){var n=this.model.get("disabled");this._textbox.disabled=n,this._colorpicker.disabled=n}return e.prototype.update.call(this)},t.prototype.events=function(){return this._picker_change,this._text_change,{'change [type="color"]':"_picker_change",'change [type="text"]':"_text_change"}},t.prototype._update_value=function(){var e,t,n=this.model.get("value");this._colorpicker.value=pe[(e=n).toLowerCase()]||(7===(t=e).length?t:"#"+t.charAt(1)+t.charAt(1)+t.charAt(2)+t.charAt(2)+t.charAt(3)+t.charAt(3)),this._textbox.value=n},t.prototype._update_concise=function(){this.model.get("concise")?(this.el.classList.add("concise"),this._textbox.style.display="none"):(this.el.classList.remove("concise"),this._textbox.style.display="")},t.prototype._picker_change=function(){this.model.set("value",this._colorpicker.value),this.touch()},t.prototype._text_change=function(){var e=this._validate_color(this._textbox.value,this.model.get("value"));this.model.set("value",e),this.touch()},t.prototype._validate_color=function(e,t){return e.match(/#[a-fA-F0-9]{3}(?:[a-fA-F0-9]{3})?$/)||pe[e.toLowerCase()]?e:t},t}(p),pe={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgrey:"#a9a9a9",darkgreen:"#006400",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",grey:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgreen:"#90ee90",lightgray:"#d3d3d3",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var fe=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),me=function(){return(me=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function ge(e){return null===e?null:{year:e.getUTCFullYear(),month:e.getUTCMonth(),date:e.getUTCDate()}}function ve(e){if(null===e)return null;var t=new Date;return t.setUTCFullYear(e.year,e.month,e.date),t.setUTCHours(0,0,0,0),t}var ye=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return fe(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{value:null,_model_name:"DatePickerModel",_view_name:"DatePickerView"})},t.serializers=me(me({},b.serializers),{value:{serialize:ge,deserialize:ve}}),t}(b),_e=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return fe(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-datepicker"),this._datepicker=document.createElement("input"),this._datepicker.setAttribute("type","date"),this._datepicker.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this._datepicker),this.listenTo(this.model,"change:value",this._update_value),this._update_value(),this.update()},t.prototype.update=function(t){return void 0!==t&&t.updated_view===this||(this._datepicker.disabled=this.model.get("disabled")),e.prototype.update.call(this)},t.prototype.events=function(){return this._picker_change,this._picker_focusout,{'change [type="date"]':"_picker_change",'focusout [type="date"]':"_picker_focusout"}},t.prototype._update_value=function(){var e=this.model.get("value");this._datepicker.valueAsDate=e},t.prototype._picker_change=function(){this._datepicker.validity.badInput||(this.model.set("value",this._datepicker.valueAsDate),this.touch())},t.prototype._picker_focusout=function(){this._datepicker.validity.badInput&&(this.model.set("value",null),this.touch())},t}(p);function be(e,t){if((n=(e=t?e.toExponential(t-1):e.toExponential()).indexOf("e"))<0)return null;var n,r=e.slice(0,n);return[r.length>1?r[0]+r.slice(2):r,+e.slice(n+1)]}var Me=/^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;function we(e){if(!(t=Me.exec(e)))throw new Error("invalid format: "+e);var t;return new Ae({fill:t[1],align:t[2],sign:t[3],symbol:t[4],zero:t[5],width:t[6],comma:t[7],precision:t[8]&&t[8].slice(1),trim:t[9],type:t[10]})}function Ae(e){this.fill=void 0===e.fill?" ":e.fill+"",this.align=void 0===e.align?">":e.align+"",this.sign=void 0===e.sign?"-":e.sign+"",this.symbol=void 0===e.symbol?"":e.symbol+"",this.zero=!!e.zero,this.width=void 0===e.width?void 0:+e.width,this.comma=!!e.comma,this.precision=void 0===e.precision?void 0:+e.precision,this.trim=!!e.trim,this.type=void 0===e.type?"":e.type+""}we.prototype=Ae.prototype,Ae.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(void 0===this.width?"":Math.max(1,0|this.width))+(this.comma?",":"")+(void 0===this.precision?"":"."+Math.max(0,0|this.precision))+(this.trim?"~":"")+this.type};var Ce,xe,Ee,Le=function(e,t){var n=be(e,t);if(!n)return e+"";var r=n[0],i=n[1];return i<0?"0."+new Array(-i).join("0")+r:r.length>i+1?r.slice(0,i+1)+"."+r.slice(i+1):r+new Array(i-r.length+2).join("0")},Se={"%":function(e,t){return(100*e).toFixed(t)},b:function(e){return Math.round(e).toString(2)},c:function(e){return e+""},d:function(e){return Math.abs(e=Math.round(e))>=1e21?e.toLocaleString("en").replace(/,/g,""):e.toString(10)},e:function(e,t){return e.toExponential(t)},f:function(e,t){return e.toFixed(t)},g:function(e,t){return e.toPrecision(t)},o:function(e){return Math.round(e).toString(8)},p:function(e,t){return Le(100*e,t)},r:Le,s:function(e,t){var n=be(e,t);if(!n)return e+"";var r=n[0],i=n[1],o=i-(Ce=3*Math.max(-8,Math.min(8,Math.floor(i/3))))+1,a=r.length;return o===a?r:o>a?r+new Array(o-a+1).join("0"):o>0?r.slice(0,o)+"."+r.slice(o):"0."+new Array(1-o).join("0")+be(e,Math.max(0,t+o-1))[0]},X:function(e){return Math.round(e).toString(16).toUpperCase()},x:function(e){return Math.round(e).toString(16)}},Te=function(e){return e},Oe=Array.prototype.map,Ie=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"];xe=function(e){var t,n,r=void 0===e.grouping||void 0===e.thousands?Te:(t=Oe.call(e.grouping,Number),n=e.thousands+"",function(e,r){for(var i=e.length,o=[],a=0,s=t[0],l=0;i>0&&s>0&&(l+s+1>r&&(s=Math.max(1,r-l)),o.push(e.substring(i-=s,i+s)),!((l+=s+1)>r));)s=t[a=(a+1)%t.length];return o.reverse().join(n)}),i=void 0===e.currency?"":e.currency[0]+"",o=void 0===e.currency?"":e.currency[1]+"",a=void 0===e.decimal?".":e.decimal+"",s=void 0===e.numerals?Te:function(e){return function(t){return t.replace(/[0-9]/g,(function(t){return e[+t]}))}}(Oe.call(e.numerals,String)),l=void 0===e.percent?"%":e.percent+"",c=void 0===e.minus?"-":e.minus+"",u=void 0===e.nan?"NaN":e.nan+"";function d(e){var t=(e=we(e)).fill,n=e.align,d=e.sign,h=e.symbol,p=e.zero,f=e.width,m=e.comma,g=e.precision,v=e.trim,y=e.type;"n"===y?(m=!0,y="g"):Se[y]||(void 0===g&&(g=12),v=!0,y="g"),(p||"0"===t&&"="===n)&&(p=!0,t="0",n="=");var _="$"===h?i:"#"===h&&/[boxX]/.test(y)?"0"+y.toLowerCase():"",b="$"===h?o:/[%p]/.test(y)?l:"",M=Se[y],w=/[defgprs%]/.test(y);function A(e){var i,o,l,h=_,A=b;if("c"===y)A=M(e)+A,e="";else{var C=(e=+e)<0||1/e<0;if(e=isNaN(e)?u:M(Math.abs(e),g),v&&(e=function(e){e:for(var t,n=e.length,r=1,i=-1;r<n;++r)switch(e[r]){case".":i=t=r;break;case"0":0===i&&(i=r),t=r;break;default:if(!+e[r])break e;i>0&&(i=0)}return i>0?e.slice(0,i)+e.slice(t+1):e}(e)),C&&0==+e&&"+"!==d&&(C=!1),h=(C?"("===d?d:c:"-"===d||"("===d?"":d)+h,A=("s"===y?Ie[8+Ce/3]:"")+A+(C&&"("===d?")":""),w)for(i=-1,o=e.length;++i<o;)if(48>(l=e.charCodeAt(i))||l>57){A=(46===l?a+e.slice(i+1):e.slice(i))+A,e=e.slice(0,i);break}}m&&!p&&(e=r(e,1/0));var x=h.length+e.length+A.length,E=x<f?new Array(f-x+1).join(t):"";switch(m&&p&&(e=r(E+e,E.length?f-A.length:1/0),E=""),n){case"<":e=h+e+A+E;break;case"=":e=h+E+e+A;break;case"^":e=E.slice(0,x=E.length>>1)+h+e+A+E.slice(x);break;default:e=E+h+e+A}return s(e)}return g=void 0===g?6:/[gprs]/.test(y)?Math.max(1,Math.min(21,g)):Math.max(0,Math.min(20,g)),A.toString=function(){return e+""},A}return{format:d,formatPrefix:function(e,t){var n,r=d(((e=we(e)).type="f",e)),i=3*Math.max(-8,Math.min(8,Math.floor((n=t,((n=be(Math.abs(n)))?n[1]:NaN)/3)))),o=Math.pow(10,-i),a=Ie[8+i/3];return function(e){return r(o*e)+a}}}}({decimal:".",thousands:",",grouping:[3],currency:["$",""],minus:"-"}),Ee=xe.format,xe.formatPrefix;n(814);var ke=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),De=function(){return(De=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},Ne=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"IntModel",value:0})},t}(b),je=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"BoundedIntModel",max:100,min:0})},t}(Ne),Pe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return De(De({},e.prototype.defaults.call(this)),{_model_name:"SliderStyleModel"})},t.styleProperties=De(De({},d.styleProperties),{handle_color:{selector:".ui-slider-handle",attribute:"background-color",default:null}}),t}(d),ze=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"IntSliderModel",_view_name:"IntSliderView",step:1,orientation:"horizontal",readout:!0,readout_format:"d",continuous_update:!0,style:null,disabled:!1})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),this.on("change:readout_format",this.update_readout_format,this),this.update_readout_format()},t.prototype.update_readout_format=function(){this.readout_formatter=Ee(this.get("readout_format"))},t}(je),Re=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t}(ze),Be=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseInt,t}return ke(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-slider"),this.el.classList.add("widget-hslider"),(this.$slider=F()("<div />")).slider({slide:this.handleSliderChange.bind(this),stop:this.handleSliderChanged.bind(this)}).addClass("slider"),this.slider_container=document.createElement("div"),this.slider_container.classList.add("slider-container"),this.slider_container.appendChild(this.$slider[0]),this.el.appendChild(this.slider_container),this.readout=document.createElement("div"),this.el.appendChild(this.readout),this.readout.classList.add("widget-readout"),this.readout.contentEditable="true",this.readout.style.display="none",this.update()},t.prototype.update=function(t){if(void 0===t||t.updated_view!==this){var n=this;n.$slider.slider({}),["step","disabled"].forEach((function(e){var t=n.model.get(e);void 0!==t&&n.$slider.slider("option",e,t)})),this.model.get("disabled")?this.readout.contentEditable="false":this.readout.contentEditable="true";var r=this.model.get("max"),i=this.model.get("min");i<=r&&(void 0!==r&&this.$slider.slider("option","max",r),void 0!==i&&this.$slider.slider("option","min",i));var o=this.model.get("orientation");this.$slider.slider("option","orientation",o),"vertical"===o?(this.el.classList.remove("widget-hslider"),this.el.classList.add("widget-vslider"),this.el.classList.remove("widget-inline-hbox"),this.el.classList.add("widget-inline-vbox")):(this.el.classList.remove("widget-vslider"),this.el.classList.add("widget-hslider"),this.el.classList.remove("widget-inline-vbox"),this.el.classList.add("widget-inline-hbox")),this.model.get("readout")?(this.readout.style.display="",this.displayed.then((function(){n.readout_overflow()?n.readout.classList.add("overflow"):n.readout.classList.remove("overflow")}))):this.readout.style.display="none"}return e.prototype.update.call(this)},t.prototype.readout_overflow=function(){return this.readout.scrollWidth>this.readout.clientWidth},t.prototype.events=function(){return{slide:"handleSliderChange",slidestop:"handleSliderChanged","blur [contentEditable=true]":"handleTextChange","keydown [contentEditable=true]":"handleKeyDown"}},t.prototype.handleKeyDown=function(e){13===e.keyCode&&(e.preventDefault(),this.handleTextChange())},t.prototype._validate_slide_value=function(e){return Math.floor(e)},t}(p),He=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._range_regex=/^\s*([+-]?\d+)\s*[-:–]\s*([+-]?\d+)/,t}return ke(t,e),t.prototype.update=function(t){e.prototype.update.call(this,t),this.$slider.slider("option","range",!0);var n=this.model.get("value");this.$slider.slider("option","values",n.slice()),this.readout.textContent=this.valueToString(n),this.model.get("value")!==n&&(this.model.set("value",n,{updated_view:this}),this.touch())},t.prototype.valueToString=function(e){var t=this.model.readout_formatter;return e.map((function(e){return t(e)})).join(" – ")},t.prototype.stringToValue=function(e){var t=this._range_regex.exec(e);return t?[this._parse_value(t[1]),this._parse_value(t[2])]:null},t.prototype.handleTextChange=function(){var e=this.stringToValue(this.readout.textContent),t=this.model.get("min"),n=this.model.get("max");null===e||isNaN(e[0])||isNaN(e[1])||e[0]>e[1]?this.readout.textContent=this.valueToString(this.model.get("value")):(e=[Math.max(Math.min(e[0],n),t),Math.max(Math.min(e[1],n),t)])[0]!==this.model.get("value")[0]||e[1]!==this.model.get("value")[1]?(this.readout.textContent=this.valueToString(e),this.model.set("value",e,{updated_view:this}),this.touch()):this.readout.textContent=this.valueToString(this.model.get("value"))},t.prototype.handleSliderChange=function(e,t){var n=t.values.map(this._validate_slide_value);this.readout.textContent=this.valueToString(n),this.model.get("continuous_update")&&this.handleSliderChanged(e,t)},t.prototype.handleSliderChanged=function(e,t){var n=t.values.map(this._validate_slide_value);this.model.set("value",n,{updated_view:this}),this.touch()},t}(Be),Fe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.update=function(t){e.prototype.update.call(this,t);var n=this.model.get("min"),r=this.model.get("max"),i=this.model.get("value");i>r?i=r:i<n&&(i=n),this.$slider.slider("option","value",i),this.readout.textContent=this.valueToString(i),this.model.get("value")!==i&&(this.model.set("value",i,{updated_view:this}),this.touch())},t.prototype.valueToString=function(e){return(0,this.model.readout_formatter)(e)},t.prototype.stringToValue=function(e){return this._parse_value(e)},t.prototype.handleTextChange=function(){var e=this.stringToValue(this.readout.textContent),t=this.model.get("min"),n=this.model.get("max");isNaN(e)?this.readout.textContent=this.valueToString(this.model.get("value")):(e=Math.max(Math.min(e,n),t))!==this.model.get("value")?(this.readout.textContent=this.valueToString(e),this.model.set("value",e,{updated_view:this}),this.touch()):this.readout.textContent=this.valueToString(this.model.get("value"))},t.prototype.handleSliderChange=function(e,t){var n=this._validate_slide_value(t.value);this.readout.textContent=this.valueToString(n),this.model.get("continuous_update")&&this.handleSliderChanged(e,t)},t.prototype.handleSliderChanged=function(e,t){var n=this._validate_slide_value(t.value);this.model.set("value",n,{updated_view:this}),this.touch()},t}(Be),Ye=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"IntTextModel",_view_name:"IntTextView",disabled:!1,continuous_update:!1})},t}(Ne),Ve=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"BoundedIntTextModel",_view_name:"IntTextView",disabled:!1,continuous_update:!1,step:1})},t}(je),Ue=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseInt,t._default_step="1",t}return ke(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-text"),this.textbox=document.createElement("input"),this.textbox.type="number",this.textbox.required=!0,this.textbox.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this.textbox),this.update()},t.prototype.update=function(t){if(void 0===t||t.updated_view!==this){var n=this.model.get("value");this._parse_value(this.textbox.value)!==n&&(this.textbox.value=n.toString()),void 0!==this.model.get("min")&&(this.textbox.min=this.model.get("min")),void 0!==this.model.get("max")&&(this.textbox.max=this.model.get("max")),void 0!==this.model.get("step")&&null!==this.model.get("step")?this.textbox.step=this.model.get("step"):this.textbox.step=this._default_step,this.textbox.disabled=this.model.get("disabled")}return e.prototype.update.call(this)},t.prototype.events=function(){return{"keydown input":"handleKeyDown","keypress input":"handleKeypress","keyup input":"handleKeyUp","input input":"handleChanging","change input":"handleChanged"}},t.prototype.handleKeyDown=function(e){e.stopPropagation()},t.prototype.handleKeypress=function(e){/[e,.\s]/.test(String.fromCharCode(e.keyCode))&&e.preventDefault()},t.prototype.handleKeyUp=function(e){if(!e.altKey&&!e.ctrlKey){var t=e.target,n=t.value;if((n=n.replace(/[e,.\s]/g,"")).length>=1){var r=n.substr(1);n=n[0]+r.replace(/[+-]/g,"")}t.value!=n&&(e.preventDefault(),t.value=n)}},t.prototype.handleChanging=function(e){var t=e.target.value.trim();""===t||["-","-.",".","+.","+"].indexOf(t)>=0||this.model.get("continuous_update")&&this.handleChanged(e)},t.prototype.handleChanged=function(e){var t=e.target,n=this._parse_value(t.value);if(isNaN(n))t.value=this.model.get("value");else{var r=n;void 0!==this.model.get("max")&&(r=Math.min(this.model.get("max"),r)),void 0!==this.model.get("min")&&(r=Math.max(this.model.get("min"),r)),r!==n&&(t.value=r,n=r),n!==this.model.get("value")&&(this.model.set("value",n,{updated_view:this}),this.touch())}},t}(p),We=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return De(De({},e.prototype.defaults.call(this)),{_model_name:"ProgressStyleModel"})},t.styleProperties=De(De({},d.styleProperties),{bar_color:{selector:".progress-bar",attribute:"background-color",default:null}}),t}(d),Ge=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"IntProgressModel",_view_name:"ProgressView",orientation:"horizontal",bar_style:"",style:null})},t}(je),qe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.listenTo(this.model,"change:bar_style",this.update_bar_style),this.pWidget.addClass("jupyter-widgets")},t.prototype.render=function(){e.prototype.render.call(this);var t="horizontal"===this.model.get("orientation")?"widget-hprogress":"widget-vprogress";this.el.classList.add(t),this.progress=document.createElement("div"),this.progress.classList.add("progress"),this.progress.style.position="relative",this.el.appendChild(this.progress),this.bar=document.createElement("div"),this.bar.classList.add("progress-bar"),this.bar.style.position="absolute",this.bar.style.bottom="0px",this.bar.style.left="0px",this.progress.appendChild(this.bar),this.update(),this.set_bar_style()},t.prototype.update=function(){var t=this.model.get("value"),n=this.model.get("max"),r=this.model.get("min"),i=100*(t-r)/(n-r);return"horizontal"===this.model.get("orientation")?(this.el.classList.remove("widget-inline-vbox"),this.el.classList.remove("widget-vprogress"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-hprogress"),this.bar.style.width=i+"%",this.bar.style.height="100%"):(this.el.classList.remove("widget-inline-hbox"),this.el.classList.remove("widget-hprogress"),this.el.classList.add("widget-inline-vbox"),this.el.classList.add("widget-vprogress"),this.bar.style.width="100%",this.bar.style.height=i+"%"),e.prototype.update.call(this)},t.prototype.update_bar_style=function(){this.update_mapped_classes(t.class_map,"bar_style",this.bar)},t.prototype.set_bar_style=function(){this.set_mapped_classes(t.class_map,"bar_style",this.bar)},t.class_map={success:["progress-bar-success"],info:["progress-bar-info"],warning:["progress-bar-warning"],danger:["progress-bar-danger"]},t}(p),Ke=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"PlayModel",_view_name:"PlayView",_playing:!1,_repeat:!1,show_repeat:!0,interval:100,step:1,disabled:!1})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n)},t.prototype.loop=function(){if(this.get("_playing")){var e=this.get("value")+this.get("step");e<=this.get("max")?(this.set("value",e),this.schedule_next()):this.get("_repeat")?(this.set("value",this.get("min")),this.schedule_next()):this.set("_playing",!1),this.save_changes()}},t.prototype.schedule_next=function(){window.setTimeout(this.loop.bind(this),this.get("interval"))},t.prototype.stop=function(){this.set("_playing",!1),this.set("value",this.get("min")),this.save_changes()},t.prototype.pause=function(){this.set("_playing",!1),this.save_changes()},t.prototype.play=function(){this.set("_playing",!0),this.get("value")==this.get("max")?(this.set("value",this.get("min")),this.schedule_next(),this.save_changes()):this.loop()},t.prototype.repeat=function(){this.set("_repeat",!this.get("_repeat")),this.save_changes()},t}(je),Xe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ke(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-play"),this.playButton=document.createElement("button"),this.pauseButton=document.createElement("button"),this.stopButton=document.createElement("button"),this.repeatButton=document.createElement("button"),this.playButton.className="jupyter-button",this.pauseButton.className="jupyter-button",this.stopButton.className="jupyter-button",this.repeatButton.className="jupyter-button",this.el.appendChild(this.playButton),this.el.appendChild(this.pauseButton),this.el.appendChild(this.stopButton),this.el.appendChild(this.repeatButton);var t=document.createElement("i");t.className="fa fa-play",this.playButton.appendChild(t);var n=document.createElement("i");n.className="fa fa-pause",this.pauseButton.appendChild(n);var r=document.createElement("i");r.className="fa fa-stop",this.stopButton.appendChild(r);var i=document.createElement("i");i.className="fa fa-retweet",this.repeatButton.appendChild(i),this.playButton.onclick=this.model.play.bind(this.model),this.pauseButton.onclick=this.model.pause.bind(this.model),this.stopButton.onclick=this.model.stop.bind(this.model),this.repeatButton.onclick=this.model.repeat.bind(this.model),this.listenTo(this.model,"change:_playing",this.update_playing),this.listenTo(this.model,"change:_repeat",this.update_repeat),this.listenTo(this.model,"change:show_repeat",this.update_repeat),this.update_playing(),this.update_repeat(),this.update()},t.prototype.update=function(){var e=this.model.get("disabled");this.playButton.disabled=e,this.pauseButton.disabled=e,this.stopButton.disabled=e,this.repeatButton.disabled=e,this.update_playing()},t.prototype.update_playing=function(){var e=this.model.get("_playing"),t=this.model.get("disabled");e?(t||(this.pauseButton.disabled=!1),this.playButton.classList.add("mod-active")):(t||(this.pauseButton.disabled=!0),this.playButton.classList.remove("mod-active"))},t.prototype.update_repeat=function(){var e=this.model.get("_repeat");this.repeatButton.style.display=this.model.get("show_repeat")?this.playButton.style.display:"none",e?this.repeatButton.classList.add("mod-active"):this.repeatButton.classList.remove("mod-active")},t}(r.DOMWidgetView),Je=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),Qe=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FloatModel",value:0})},t}(b),Ze=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"BoundedFloatModel",max:100,min:0})},t}(Qe),$e=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FloatSliderModel",_view_name:"FloatSliderView",step:1,orientation:"horizontal",_range:!1,readout:!0,readout_format:".2f",slider_color:null,continuous_update:!0,disabled:!1})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),this.on("change:readout_format",this.update_readout_format,this),this.update_readout_format()},t.prototype.update_readout_format=function(){this.readout_formatter=Ee(this.get("readout_format"))},t}(Ze),et=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FloatLogSliderModel",_view_name:"FloatLogSliderView",step:.1,orientation:"horizontal",_range:!1,readout:!0,readout_format:".3g",slider_color:null,continuous_update:!0,disabled:!1,base:10,value:1,min:0,max:4})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),this.on("change:readout_format",this.update_readout_format,this),this.update_readout_format()},t.prototype.update_readout_format=function(){this.readout_formatter=Ee(this.get("readout_format"))},t}(Ze),tt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t}($e),nt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseFloat,t}return Je(t,e),t.prototype._validate_slide_value=function(e){return e},t}(Fe),rt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseFloat,t}return Je(t,e),t.prototype.update=function(t){e.prototype.update.call(this,t);var n=this.model.get("min"),r=this.model.get("max"),i=this.model.get("value"),o=this.model.get("base"),a=Math.log(i)/Math.log(o);a>r?a=r:a<n&&(a=n),this.$slider.slider("option","value",a),this.readout.textContent=this.valueToString(i),this.model.get("value")!==i&&(this.model.set("value",i,{updated_view:this}),this.touch())},t.prototype.valueToString=function(e){return(0,this.model.readout_formatter)(e)},t.prototype.stringToValue=function(e){return this._parse_value(e)},t.prototype.handleTextChange=function(){var e=this.stringToValue(this.readout.textContent),t=this.model.get("min"),n=this.model.get("max"),r=this.model.get("base");isNaN(e)?this.readout.textContent=this.valueToString(this.model.get("value")):(e=Math.max(Math.min(e,Math.pow(r,n)),Math.pow(r,t)))!==this.model.get("value")?(this.readout.textContent=this.valueToString(e),this.model.set("value",e,{updated_view:this}),this.touch()):this.readout.textContent=this.valueToString(this.model.get("value"))},t.prototype.handleSliderChange=function(e,t){var n=this.model.get("base"),r=Math.pow(n,this._validate_slide_value(t.value));this.readout.textContent=this.valueToString(r),this.model.get("continuous_update")&&this.handleSliderChanged(e,t)},t.prototype.handleSliderChanged=function(e,t){var n=this.model.get("base"),r=Math.pow(n,this._validate_slide_value(t.value));this.model.set("value",r,{updated_view:this}),this.touch()},t.prototype._validate_slide_value=function(e){return e},t}(Be),it=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseFloat,t._range_regex=/^\s*([+-]?(?:\d*\.?\d+|\d+\.)(?:[eE][-:]?\d+)?)\s*[-:–]\s*([+-]?(?:\d*\.?\d+|\d+\.)(?:[eE][+-]?\d+)?)/,t}return Je(t,e),t.prototype._validate_slide_value=function(e){return e},t}(He),ot=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FloatTextModel",_view_name:"FloatTextView",disabled:!1,continuous_update:!1})},t}(Qe),at=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"BoundedFloatTextModel",_view_name:"FloatTextView",disabled:!1,continuous_update:!1,step:.1})},t}(Ze),st=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._parse_value=parseFloat,t._default_step="any",t}return Je(t,e),t.prototype.handleKeypress=function(e){e.stopPropagation()},t.prototype.handleKeyUp=function(e){},t}(Ue),lt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Je(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FloatProgressModel",_view_name:"ProgressView",orientation:"horizontal",bar_style:"",style:null})},t}(Ze),ct=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),ut=function(){return(ut=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},dt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ControllerButtonModel",_view_name:"ControllerButtonView",value:0,pressed:!1})},t}(_),ht=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype.render=function(){this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-controller-button"),this.el.style.width="fit-content",this.support=document.createElement("div"),this.support.style.position="relative",this.support.style.margin="1px",this.support.style.width="16px",this.support.style.height="16px",this.support.style.border="1px solid black",this.support.style.background="lightgray",this.el.appendChild(this.support),this.bar=document.createElement("div"),this.bar.style.position="absolute",this.bar.style.width="100%",this.bar.style.bottom="0px",this.bar.style.background="gray",this.support.appendChild(this.bar),this.update(),this.label=document.createElement("div"),this.label.textContent=this.model.get("description"),this.label.style.textAlign="center",this.el.appendChild(this.label)},t.prototype.update=function(){this.bar.style.height=100*this.model.get("value")+"%"},t}(r.DOMWidgetView),pt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ControllerAxisModel",_view_name:"ControllerAxisView",value:0})},t}(_),ft=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype.render=function(){this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-controller-axis"),this.el.style.width="16px",this.el.style.padding="4px",this.support=document.createElement("div"),this.support.style.position="relative",this.support.style.margin="1px",this.support.style.width="4px",this.support.style.height="64px",this.support.style.border="1px solid black",this.support.style.background="lightgray",this.bullet=document.createElement("div"),this.bullet.style.position="absolute",this.bullet.style.margin="-3px",this.bullet.style.boxSizing="unset",this.bullet.style.width="10px",this.bullet.style.height="10px",this.bullet.style.background="gray",this.label=document.createElement("div"),this.label.textContent=this.model.get("description"),this.label.style.textAlign="center",this.support.appendChild(this.bullet),this.el.appendChild(this.support),this.el.appendChild(this.label),this.update()},t.prototype.update=function(){this.bullet.style.top=50*(this.model.get("value")+1)+"%"},t}(r.DOMWidgetView),mt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ControllerModel",_view_name:"ControllerView",index:0,name:"",mapping:"",connected:!1,timestamp:0,buttons:[],axes:[]})},t.prototype.initialize=function(t,n){e.prototype.initialize.call(this,t,n),void 0===navigator.getGamepads?(this.readout="This browser does not support gamepads.",console.error(this.readout)):(this.readout="Connect gamepad and press any button.",this.get("connected")?this.update_loop():this.wait_loop())},t.prototype.wait_loop=function(){var e=this.get("index"),t=navigator.getGamepads()[e];if(t){var n=this;this.setup(t).then((function(e){n.set(e),n.save_changes(),window.requestAnimationFrame(n.update_loop.bind(n))}))}else window.requestAnimationFrame(this.wait_loop.bind(this))},t.prototype.setup=function(e){this.set({name:e.id,mapping:e.mapping,connected:e.connected,timestamp:e.timestamp});var t=this;return r.resolvePromisesDict({buttons:Promise.all(e.buttons.map((function(e,n){return t._create_button_model(n)}))),axes:Promise.all(e.axes.map((function(e,n){return t._create_axis_model(n)})))})},t.prototype.update_loop=function(){var e=this.get("index"),t=this.get("name"),n=navigator.getGamepads()[e];n&&e===n.index&&t===n.id?(this.set({timestamp:n.timestamp,connected:n.connected}),this.save_changes(),this.get("buttons").forEach((function(e,t){e.set({value:n.buttons[t].value,pressed:n.buttons[t].pressed}),e.save_changes()})),this.get("axes").forEach((function(e,t){e.set("value",n.axes[t]),e.save_changes()})),window.requestAnimationFrame(this.update_loop.bind(this))):this.reset_gamepad()},t.prototype.reset_gamepad=function(){this.get("buttons").forEach((function(e){e.close()})),this.get("axes").forEach((function(e){e.close()})),this.set({name:"",mapping:"",connected:!1,timestamp:0,buttons:[],axes:[]}),this.save_changes(),window.requestAnimationFrame(this.wait_loop.bind(this))},t.prototype._create_button_model=function(e){return this.widget_manager.new_widget({model_name:"ControllerButtonModel",model_module:"@jupyter-widgets/controls",model_module_version:this.get("_model_module_version"),view_name:"ControllerButtonView",view_module:"@jupyter-widgets/controls",view_module_version:this.get("_view_module_version")}).then((function(t){return t.set("description",e),t}))},t.prototype._create_axis_model=function(e){return this.widget_manager.new_widget({model_name:"ControllerAxisModel",model_module:"@jupyter-widgets/controls",model_module_version:this.get("_model_module_version"),view_name:"ControllerAxisView",view_module:"@jupyter-widgets/controls",view_module_version:this.get("_view_module_version")}).then((function(t){return t.set("description",e),t}))},t.serializers=ut(ut({},_.serializers),{buttons:{deserialize:r.unpack_models},axes:{deserialize:r.unpack_models}}),t}(_),gt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ct(t,e),t.prototype._createElement=function(e){return this.pWidget=new r.JupyterPhosphorPanelWidget({view:this}),this.pWidget.node},t.prototype._setElement=function(e){if(this.el||e!==this.pWidget.node)throw new Error("Cannot reset the DOM element.");this.el=this.pWidget.node,this.$el=F()(this.pWidget.node)},t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.button_views=new r.ViewList(this.add_button,null,this),this.listenTo(this.model,"change:buttons",(function(e,t){this.button_views.update(t)})),this.axis_views=new r.ViewList(this.add_axis,null,this),this.listenTo(this.model,"change:axes",(function(e,t){this.axis_views.update(t)})),this.listenTo(this.model,"change:name",this.update_label)},t.prototype.render=function(){this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-controller"),this.label=document.createElement("div"),this.el.appendChild(this.label),this.axis_box=new B.Panel,this.axis_box.node.style.display="flex",this.pWidget.addWidget(this.axis_box),this.button_box=new B.Panel,this.button_box.node.style.display="flex",this.pWidget.addWidget(this.button_box),this.button_views.update(this.model.get("buttons")),this.axis_views.update(this.model.get("axes")),this.update_label()},t.prototype.update_label=function(){this.label.textContent=this.model.get("name")||this.model.readout},t.prototype.add_button=function(e){var t=this,n=new B.Widget;return this.button_box.addWidget(n),this.create_child_view(e).then((function(e){var r=z.ArrayExt.firstIndexOf(t.button_box.widgets,n);return t.button_box.insertWidget(r,e.pWidget),n.dispose(),e})).catch(i("Could not add child button view to controller",!0))},t.prototype.add_axis=function(e){var t=this,n=new B.Widget;return this.axis_box.addWidget(n),this.create_child_view(e).then((function(e){var r=z.ArrayExt.firstIndexOf(t.axis_box.widgets,n);return t.axis_box.insertWidget(r,e.pWidget),n.dispose(),e})).catch(i("Could not add child axis view to controller",!0))},t.prototype.remove=function(){e.prototype.remove.call(this),this.button_views.remove(),this.axis_views.remove()},t}(r.DOMWidgetView),vt=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),yt=function(){return(yt=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},_t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"SelectionModel",index:"",_options_labels:[],disabled:!1})},t}(b),bt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"DropdownModel",_view_name:"DropdownView",button_style:""})},t}(_t),Mt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.initialize=function(t){var n=this;e.prototype.initialize.call(this,t),this.listenTo(this.model,"change:_options_labels",(function(){return n._updateOptions()}))},t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-dropdown"),this.listbox=document.createElement("select"),this.listbox.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this.listbox),this._updateOptions(),this.update()},t.prototype.update=function(){this.listbox.disabled=this.model.get("disabled");var t=this.model.get("index");return this.listbox.selectedIndex=null===t?-1:t,e.prototype.update.call(this)},t.prototype._updateOptions=function(){this.listbox.textContent="";for(var e=this.model.get("_options_labels"),t=0;t<e.length;t++){var n=e[t],r=document.createElement("option");r.textContent=n.replace(/ /g," "),r.setAttribute("data-value",encodeURIComponent(n)),r.value=n,this.listbox.appendChild(r)}},t.prototype.events=function(){return{"change select":"_handle_change"}},t.prototype._handle_change=function(){this.model.set("index",-1===this.listbox.selectedIndex?null:this.listbox.selectedIndex),this.touch()},t}(p),wt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"SelectModel",_view_name:"SelectView",rows:5})},t}(_t),At=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.initialize=function(t){var n=this;e.prototype.initialize.call(this,t),this.listenTo(this.model,"change:_options_labels",(function(){return n._updateOptions()})),this.listenTo(this.model,"change:index",(function(e,t,r){return n.updateSelection(r)})),this.listbox=document.createElement("select")},t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-select"),this.listbox.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this.listbox),this._updateOptions(),this.update(),this.updateSelection()},t.prototype.update=function(){e.prototype.update.call(this),this.listbox.disabled=this.model.get("disabled");var t=this.model.get("rows");null===t&&(t=""),this.listbox.setAttribute("size",t)},t.prototype.updateSelection=function(e){if(void 0===e&&(e={}),e.updated_view!==this){var t=this.model.get("index");this.listbox.selectedIndex=null===t?-1:t}},t.prototype._updateOptions=function(){this.listbox.textContent="";for(var e=this.model.get("_options_labels"),t=0;t<e.length;t++){var n=e[t],r=document.createElement("option");r.textContent=n.replace(/ /g," "),r.setAttribute("data-value",encodeURIComponent(n)),r.value=n,this.listbox.appendChild(r)}},t.prototype.events=function(){return{"change select":"_handle_change"}},t.prototype._handle_change=function(){this.model.set("index",this.listbox.selectedIndex,{updated_view:this}),this.touch()},t}(p),Ct=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"RadioButtonsModel",_view_name:"RadioButtonsView",tooltips:[],icons:[],button_style:""})},t}(_t),xt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-radio"),this.container=document.createElement("div"),this.el.appendChild(this.container),this.container.classList.add("widget-radio-box"),this.update()},t.prototype.update=function(t){var n=this,r=this.model.get("_options_labels"),i=g.pluck(this.container.querySelectorAll('input[type="radio"]'),"value"),o=r.length!=i.length;if(!o)for(var a=0,s=r.length;a<s;++a)if(i[a]!==r[a]){o=!0;break}return!o||void 0!==t&&t.updated_view===this||(this.container.textContent="",r.forEach((function(e,t){var r=document.createElement("label");r.textContent=e,n.container.appendChild(r);var i=document.createElement("input");i.setAttribute("type","radio"),i.value=t.toString(),i.setAttribute("data-value",encodeURIComponent(e)),r.appendChild(i)}))),r.forEach((function(e,t){var r='input[data-value="'+encodeURIComponent(e)+'"]',i=n.container.querySelectorAll(r);if(i.length>0){var o=i[0];o.checked=n.model.get("index")===t,o.disabled=n.model.get("disabled")}})),setTimeout(this.adjustPadding,0,this),e.prototype.update.call(this,t)},t.prototype.adjustPadding=function(e){var t=window.getComputedStyle(e.el),n=parseInt(t.marginTop,10)+parseInt(t.marginBottom,10),r=e.label.offsetHeight+n,i=window.getComputedStyle(e.container),o=parseInt(i.marginBottom),a=(e.el.offsetHeight+n-o)%r,s=0==a?0:r-a;e.container.style.marginBottom=s+"px"},t.prototype.events=function(){return{'click input[type="radio"]':"_handle_click"}},t.prototype._handle_click=function(e){var t=e.target;this.model.set("index",parseInt(t.value),{updated_view:this}),this.touch()},t}(p),Et=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"ToggleButtonsStyleModel"})},t.styleProperties=yt(yt({},d.styleProperties),{button_width:{selector:".widget-toggle-button",attribute:"width",default:null},font_weight:{selector:".widget-toggle-button",attribute:"font-weight",default:""}}),t}(d),Lt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"ToggleButtonsModel",_view_name:"ToggleButtonsView"})},t}(_t),St=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.initialize=function(t){this._css_state={},e.prototype.initialize.call(this,t),this.listenTo(this.model,"change:button_style",this.update_button_style)},t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-toggle-buttons"),this.buttongroup=document.createElement("div"),this.el.appendChild(this.buttongroup),this.update(),this.set_button_style()},t.prototype.update=function(n){for(var r=this,i=this.model.get("_options_labels"),o=this.model.get("icons")||[],s=this.model.previous("icons")||[],l=t.classMap[this.model.previous("button_style")]||"",c=r.model.get("tooltips")||[],u=this.model.get("disabled"),d=this.buttongroup.querySelectorAll("button"),h=g.pluck(d,"value"),p=!1,f=0,m=i.length;f<m;++f)if(h[f]!==i[f]||o[f]!==s[f]){p=!0;break}return!p||void 0!==n&&n.updated_view===this||(this.buttongroup.textContent="",i.forEach((function(e,t){var n;n=0===e.trim().length&&(!o[t]||0===o[t].trim().length)?"&nbsp;":a(e);var i=document.createElement("i"),s=document.createElement("button");o[t]&&(i.className="fa fa-"+o[t]),s.setAttribute("type","button"),s.className="widget-toggle-button jupyter-button",l&&s.classList.add(l),s.innerHTML=n,s.setAttribute("data-value",encodeURIComponent(e)),s.setAttribute("value",t.toString()),s.appendChild(i),s.disabled=u,c[t]&&s.setAttribute("title",c[t]),r.update_style_traits(s),r.buttongroup.appendChild(s)}))),i.forEach((function(e,t){var n='[data-value="'+encodeURIComponent(e)+'"]',i=r.buttongroup.querySelector(n);r.model.get("index")===t?i.classList.add("mod-active"):i.classList.remove("mod-active")})),this.stylePromise.then((function(e){e&&e.style()})),e.prototype.update.call(this,n)},t.prototype.update_style_traits=function(e){for(var t in this._css_state)if(this._css_state.hasOwnProperty(t))if("margin"===t)this.buttongroup.style[t]=this._css_state[t];else if("width"!==t)if(e)e.style[t]=this._css_state[t];else{var n=this.buttongroup.querySelectorAll("button");n.length&&(n[0].style[t]=this._css_state[t])}},t.prototype.update_button_style=function(){for(var e=this.buttongroup.querySelectorAll("button"),n=0;n<e.length;n++)this.update_mapped_classes(t.classMap,"button_style",e[n])},t.prototype.set_button_style=function(){for(var e=this.buttongroup.querySelectorAll("button"),n=0;n<e.length;n++)this.set_mapped_classes(t.classMap,"button_style",e[n])},t.prototype.events=function(){return{"click button":"_handle_click"}},t.prototype._handle_click=function(e){var t=e.target;this.model.set("index",parseInt(t.value,10),{updated_view:this}),this.touch(),this.send({event:"click"})},t}(p);(St||(St={})).classMap={primary:["mod-primary"],success:["mod-success"],info:["mod-info"],warning:["mod-warning"],danger:["mod-danger"]};var Tt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"SelectionSliderModel",_view_name:"SelectionSliderView",orientation:"horizontal",readout:!0,continuous_update:!0})},t}(_t),Ot=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.render=function(){var t=this;e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-hslider"),this.el.classList.add("widget-slider"),(this.$slider=F()("<div />")).slider({slide:this.handleSliderChange.bind(this),stop:this.handleSliderChanged.bind(this)}).addClass("slider"),this.slider_container=document.createElement("div"),this.slider_container.classList.add("slider-container"),this.slider_container.appendChild(this.$slider[0]),this.el.appendChild(this.slider_container),this.readout=document.createElement("div"),this.el.appendChild(this.readout),this.readout.classList.add("widget-readout"),this.readout.style.display="none",this.listenTo(this.model,"change:slider_color",(function(e,n){t.$slider.find("a").css("background",n)})),this.$slider.find("a").css("background",this.model.get("slider_color")),this.update()},t.prototype.update=function(t){if(void 0===t||t.updated_view!==this){var n=this.model.get("_options_labels").length-1;this.$slider.slider("option","step",1),this.$slider.slider("option","max",n),this.$slider.slider("option","min",0);var r=this.model.get("orientation");this.$slider.slider("option","value",0),this.$slider.slider("option","orientation",r);var i=this.model.get("disabled");this.$slider.slider("option","disabled",i),this.readout.contentEditable=i?"false":"true","vertical"===r?(this.el.classList.remove("widget-hslider"),this.el.classList.remove("widget-inline-hbox"),this.el.classList.add("widget-vslider"),this.el.classList.add("widget-inline-vbox")):(this.el.classList.remove("widget-vslider"),this.el.classList.remove("widget-inline-vbox"),this.el.classList.add("widget-hslider"),this.el.classList.add("widget-inline-hbox"));var o=this.model.get("readout");this.readout.style.display=o?"":"none",this.updateSelection()}return e.prototype.update.call(this,t)},t.prototype.events=function(){return{slide:"handleSliderChange",slidestop:"handleSliderChanged"}},t.prototype.updateSelection=function(){var e=this.model.get("index");this.$slider.slider("option","value",e),this.updateReadout(e)},t.prototype.updateReadout=function(e){var t=this.model.get("_options_labels")[e];this.readout.textContent=t},t.prototype.handleSliderChange=function(e,t){this.updateReadout(t.value),this.model.get("continuous_update")&&this.handleSliderChanged(e,t)},t.prototype.handleSliderChanged=function(e,t){this.updateReadout(t.value),this.model.set("index",t.value,{updated_view:this}),this.touch()},t}(p),It=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"MultipleSelectionModel"})},t}(_t),kt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"SelectMultipleModel",_view_name:"SelectMultipleView",rows:null})},t}(It),Dt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.initialize=function(t){e.prototype.initialize.call(this,t),this.listbox.multiple=!0},t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("widget-select-multiple")},t.prototype.updateSelection=function(e){if(void 0===e&&(e={}),e.updated_view!==this){var t=this.model.get("index")||[],n=this.listbox.options;this.listbox.selectedIndex=-1,t.forEach((function(e){n[e].selected=!0}))}},t.prototype._handle_change=function(){var e=Array.prototype.map.call(this.listbox.selectedOptions||[],(function(e){return e.index}));this.model.set("index",e,{updated_view:this}),this.touch()},t}(At),Nt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.defaults=function(){return yt(yt({},e.prototype.defaults.call(this)),{_model_name:"SelectionSliderModel",_view_name:"SelectionSliderView",orientation:"horizontal",readout:!0,continuous_update:!0})},t}(It),jt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vt(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.$slider.slider("option","range",!0)},t.prototype.updateSelection=function(){var e=this.model.get("index");this.$slider.slider("option","values",e.slice()),this.updateReadout(e)},t.prototype.updateReadout=function(e){var t=this.model.get("_options_labels"),n=t[e[0]],r=t[e[1]];this.readout.textContent=n+"-"+r},t.prototype.handleSliderChange=function(e,t){this.updateReadout(t.values),this.model.get("continuous_update")&&this.handleSliderChanged(e,t)},t.prototype.handleSliderChanged=function(e,t){this.updateReadout(t.values),this.model.set("index",t.values.slice(),{updated_view:this}),this.touch()},t}(Ot),Pt=n(4),zt=n(21),Rt=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),Bt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._widgetRemoved=new Pt.Signal(t),t}return Rt(t,e),Object.defineProperty(t.prototype,"widgetRemoved",{get:function(){return this._widgetRemoved},enumerable:!0,configurable:!0}),t.prototype.onChildRemoved=function(e){this._widgetRemoved.emit(e.child)},t}(B.Panel),Ht=function(e){function t(t){void 0===t&&(t={});var n=e.call(this)||this;n._currentChanged=new Pt.Signal(n),n.addClass("p-TabPanel"),n.tabBar=new B.TabBar(t),n.tabBar.addClass("p-TabPanel-tabBar"),n.tabContents=new Bt,n.tabContents.addClass("p-TabPanel-tabContents"),n.tabBar.tabMoved.connect(n._onTabMoved,n),n.tabBar.currentChanged.connect(n._onCurrentChanged,n),n.tabBar.tabCloseRequested.connect(n._onTabCloseRequested,n),n.tabBar.tabActivateRequested.connect(n._onTabActivateRequested,n),n.tabContents.widgetRemoved.connect(n._onWidgetRemoved,n);var r=new B.PanelLayout;return r.addWidget(n.tabBar),r.addWidget(n.tabContents),n.layout=r,n}return Rt(t,e),Object.defineProperty(t.prototype,"currentChanged",{get:function(){return this._currentChanged},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentIndex",{get:function(){var e=this.tabBar.currentIndex;return-1===e?null:e},set:function(e){this.tabBar.currentIndex=null===e?-1:e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"currentWidget",{get:function(){var e=this.tabBar.currentTitle;return e?e.owner:null},set:function(e){this.tabBar.currentTitle=e?e.title:null},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"tabsMovable",{get:function(){return this.tabBar.tabsMovable},set:function(e){this.tabBar.tabsMovable=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"widgets",{get:function(){return this.tabContents.widgets},enumerable:!0,configurable:!0}),t.prototype.addWidget=function(e){this.insertWidget(this.widgets.length,e)},t.prototype.insertWidget=function(e,t){t!==this.currentWidget&&t.hide(),this.tabContents.insertWidget(e,t),this.tabBar.insertTab(e,t.title)},t.prototype._onCurrentChanged=function(e,t){var n=t.previousIndex,r=t.previousTitle,i=t.currentIndex,o=t.currentTitle,a=r?r.owner:null,s=o?o.owner:null;a&&a.hide(),s&&s.show(),this._currentChanged.emit({previousIndex:n,previousWidget:a,currentIndex:i,currentWidget:s}),(zt.Platform.IS_EDGE||zt.Platform.IS_IE)&&R.c.flush()},t.prototype._onTabActivateRequested=function(e,t){t.title.owner.activate()},t.prototype._onTabCloseRequested=function(e,t){t.title.owner.close()},t.prototype._onTabMoved=function(e,t){this.tabContents.insertWidget(t.toIndex,t.title.owner)},t.prototype._onWidgetRemoved=function(e,t){this.tabBar.removeTab(t.title)},t}(B.Widget),Ft=function(){function e(e,t){void 0===t&&(t={}),this._array=null,this._value=null,this._previousValue=null,this._selectionChanged=new Pt.Signal(this),this._array=e,this._insertBehavior=t.insertBehavior||"select-item-if-needed",this._removeBehavior=t.removeBehavior||"select-item-after"}return Object.defineProperty(e.prototype,"selectionChanged",{get:function(){return this._selectionChanged},enumerable:!0,configurable:!0}),e.prototype.adjustSelectionForSet=function(e){var t=this.index,n=this.value;if(e===t){this._updateSelectedValue();var r=this.value;this._previousValue=null,n!==r&&this._selectionChanged.emit({previousIndex:t,previousValue:n,currentIndex:t,currentValue:r})}},Object.defineProperty(e.prototype,"value",{get:function(){return this._value},set:function(e){this.index=null===e?null:z.ArrayExt.firstIndexOf(this._array,e)},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"index",{get:function(){return this._index},set:function(e){var t;if(null!==e?((t=Math.floor(e))<0||t>=this._array.length)&&(t=null):t=null,this._index!==t){var n=this._index,r=this._value;this._index=t,this._updateSelectedValue(),this._previousValue=r,this._selectionChanged.emit({previousIndex:n,previousValue:r,currentIndex:t,currentValue:this._value})}},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"insertBehavior",{get:function(){return this._insertBehavior},set:function(e){this._insertBehavior=e},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"removeBehavior",{get:function(){return this._removeBehavior},set:function(e){this._removeBehavior=e},enumerable:!0,configurable:!0}),e.prototype.adjustSelectionForInsert=function(e,t){var n=this._value,r=this._index,i=this._insertBehavior;if("select-item"===i||"select-item-if-needed"===i&&null===r)return this._index=e,this._value=t,this._previousValue=n,void this._selectionChanged.emit({previousIndex:r,previousValue:n,currentIndex:e,currentValue:t});r>=e&&this._index++},e.prototype.adjustSelectionForMove=function(e,t){this._index===e?this._index=t:this._index<e&&this._index>=t?this._index++:this._index>e&&this._index<=t&&this._index--},e.prototype.clearSelection=function(){var e=this._index,t=this._value;this._index=null,this._value=null,this._previousValue=null,null!==e&&this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this._value})},e.prototype.adjustSelectionForRemove=function(e,t){var n=this._index,r=this._removeBehavior;if(n===e){if(0===this._array.length)return this._index=null,this._value=null,this._previousValue=null,void this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this._value});if("select-item-after"===r)return this._index=Math.min(e,this._array.length-1),this._updateSelectedValue(),this._previousValue=null,void this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this._value});if("select-item-before"===r)return this._index=Math.max(0,e-1),this._updateSelectedValue(),this._previousValue=null,void this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this._value});if("select-previous-item"===r)return this._previousValue?this.value=this._previousValue:(this._index=Math.min(e,this._array.length-1),this._updateSelectedValue()),this._previousValue=null,void this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this.value});this._index=null,this._value=null,this._previousValue=null,this._selectionChanged.emit({previousIndex:e,previousValue:t,currentIndex:this._index,currentValue:this._value})}else n>e&&this._index--},e.prototype._updateSelectedValue=function(){var e=this._index;this._value=null!==e?this._array[e]:null},e}(),Yt=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),Vt=function(e){function t(t){var n=e.call(this,t)||this;n._collapseChanged=new Pt.Signal(n),n.addClass("p-Collapse"),n._header=new B.Widget,n._header.addClass("p-Collapse-header"),n._header.node.addEventListener("click",n);var r=document.createElement("i");r.classList.add("fa","fa-fw","fa-caret-right"),n._header.node.appendChild(r),n._header.node.appendChild(document.createElement("span")),n._content=new B.Panel,n._content.addClass("p-Collapse-contents");var i=new B.PanelLayout;return n.layout=i,i.addWidget(n._header),i.addWidget(n._content),t.widget&&(n.widget=t.widget),n.collapsed=!1,n}return Yt(t,e),t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._header=null,this._widget=null,this._content=null)},Object.defineProperty(t.prototype,"widget",{get:function(){return this._widget},set:function(e){var t=this._widget;t&&(t.disposed.disconnect(this._onChildDisposed,this),t.title.changed.disconnect(this._onTitleChanged,this),t.parent=null),this._widget=e,e.disposed.connect(this._onChildDisposed,this),e.title.changed.connect(this._onTitleChanged,this),this._onTitleChanged(e.title),this._content.addWidget(e)},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"collapsed",{get:function(){return this._collapsed},set:function(e){e!==this._collapsed&&(e?this._collapse():this._uncollapse())},enumerable:!0,configurable:!0}),t.prototype.toggle=function(){this.collapsed=!this.collapsed},Object.defineProperty(t.prototype,"collapseChanged",{get:function(){return this._collapseChanged},enumerable:!0,configurable:!0}),t.prototype._collapse=function(){this._collapsed=!0,this._content&&this._content.hide(),this.removeClass("p-Collapse-open"),this._header.node.children[0].classList.add("fa-caret-right"),this._header.node.children[0].classList.remove("fa-caret-down"),this._collapseChanged.emit(void 0)},t.prototype._uncollapse=function(){this._collapsed=!1,this._content&&this._content.show(),this.addClass("p-Collapse-open"),this._header.node.children[0].classList.add("fa-caret-down"),this._header.node.children[0].classList.remove("fa-caret-right"),this._collapseChanged.emit(void 0)},t.prototype.handleEvent=function(e){switch(e.type){case"click":this._evtClick(e)}},t.prototype._evtClick=function(e){this.toggle()},t.prototype._onTitleChanged=function(e){this._header.node.children[1].textContent=this._widget.title.label},t.prototype._onChildDisposed=function(e){this.dispose()},t}(B.Widget),Ut=function(e){function t(t){var n=e.call(this,t)||this;return n._selection=new Ft(n.widgets),n._selection.selectionChanged.connect(n._onSelectionChanged,n),n.addClass("p-Accordion"),n}return Yt(t,e),Object.defineProperty(t.prototype,"collapseWidgets",{get:function(){return this.layout.widgets},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"selection",{get:function(){return this._selection},enumerable:!0,configurable:!0}),t.prototype.indexOf=function(e){return z.ArrayExt.findFirstIndex(this.collapseWidgets,(function(t){return t.widget===e}))},t.prototype.addWidget=function(t){var n=this._wrapWidget(t);return n.collapsed=!0,e.prototype.addWidget.call(this,n),this._selection.adjustSelectionForInsert(this.widgets.length-1,n),n},t.prototype.insertWidget=function(t,n){var r=this._wrapWidget(n);r.collapsed=!0,e.prototype.insertWidget.call(this,t,r),this._selection.adjustSelectionForInsert(t,r)},t.prototype.removeWidget=function(e){var t=this.indexOf(e);if(t>=0){var n=this.collapseWidgets[t];e.parent=null,n.dispose(),this._selection.adjustSelectionForRemove(t,null)}},t.prototype._wrapWidget=function(e){var t=new Vt({widget:e});return t.addClass("p-Accordion-child"),t.collapseChanged.connect(this._onCollapseChange,this),t},t.prototype._onCollapseChange=function(e){e.collapsed?this._selection.value===e&&e.collapsed&&(this._selection.value=null):this._selection.value=e},t.prototype._onSelectionChanged=function(e,t){var n=t.previousValue,r=t.currentValue;n&&(n.collapsed=!0,n.removeClass("p-Accordion-child-active")),r&&(r.collapsed=!1,r.addClass("p-Accordion-child-active"))},t}(B.Panel),Wt=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),Gt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Wt(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"SelectionContainerModel",selected_index:0,_titles:{}})},t}(U),qt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Wt(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"AccordionModel",_view_name:"AccordionView"})},t}(Gt),Kt=function(e){function t(t){var n=this,r=t.view;return delete t.view,(n=e.call(this,t)||this)._view=r,n}return Wt(t,e),t.prototype.processMessage=function(t){e.prototype.processMessage.call(this,t),this._view.processPhosphorMessage(t)},t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._view&&this._view.remove(),this._view=null)},t}(Ut),Xt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Wt(t,e),t.prototype._createElement=function(e){return this.pWidget=new Kt({view:this}),this.pWidget.node},t.prototype._setElement=function(e){if(this.el||e!==this.pWidget.node)throw new Error("Cannot reset the DOM element.");this.el=this.pWidget.node,this.$el=F()(this.pWidget.node)},t.prototype.initialize=function(t){var n=this;e.prototype.initialize.call(this,t),this.children_views=new r.ViewList(this.add_child_view,this.remove_child_view,this),this.listenTo(this.model,"change:children",(function(){return n.updateChildren()})),this.listenTo(this.model,"change:selected_index",(function(){return n.update_selected_index()})),this.listenTo(this.model,"change:_titles",(function(){return n.update_titles()}))},t.prototype.render=function(){var t=this;e.prototype.render.call(this);var n=this.pWidget;n.addClass("jupyter-widgets"),n.addClass("widget-accordion"),n.addClass("widget-container"),n.selection.selectionChanged.connect((function(e){t.updatingChildren||(t.model.set("selected_index",n.selection.index),t.touch())})),this.children_views.update(this.model.get("children")),this.update_titles(),this.update_selected_index()},t.prototype.updateChildren=function(){this.updatingChildren=!0,this.pWidget.selection.index=null,this.children_views.update(this.model.get("children")),this.update_selected_index(),this.updatingChildren=!1},t.prototype.update_titles=function(){for(var e=this.pWidget.collapseWidgets,t=this.model.get("_titles"),n=0;n<e.length;n++)void 0!==t[n]&&(e[n].widget.title.label=t[n])},t.prototype.update_selected_index=function(){this.pWidget.selection.index=this.model.get("selected_index")},t.prototype.remove_child_view=function(e){this.pWidget.removeWidget(e.pWidget),e.remove()},t.prototype.add_child_view=function(e,t){var n=this.pWidget,r=new B.Widget;return r.title.label=this.model.get("_titles")[t]||"",n.addWidget(r),this.create_child_view(e).then((function(e){var t=e.pWidget;return t.title.label=r.title.label,n.collapseWidgets[n.indexOf(r)].widget=t,r.dispose(),e})).catch(i("Could not add child view to box",!0))},t.prototype.remove=function(){this.children_views=null,e.prototype.remove.call(this)},t}(r.DOMWidgetView),Jt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Wt(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"TabModel",_view_name:"TabView"})},t}(Gt),Qt=function(e){function t(t){var n=this,r=t.view;return delete t.view,(n=e.call(this,t)||this)._view=r,R.c.installMessageHook(n.tabContents,(function(e,t){return n._view.processPhosphorMessage(t),!0})),n}return Wt(t,e),t.prototype.dispose=function(){this.isDisposed||(e.prototype.dispose.call(this),this._view&&this._view.remove(),this._view=null)},t}(Ht),Zt=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.updatingTabs=!1,t}return Wt(t,e),t.prototype._createElement=function(e){return this.pWidget=new Qt({view:this}),this.pWidget.node},t.prototype._setElement=function(e){if(this.el||e!==this.pWidget.node)throw new Error("Cannot reset the DOM element.");this.el=this.pWidget.node,this.$el=F()(this.pWidget.node)},t.prototype.initialize=function(t){var n=this;e.prototype.initialize.call(this,t),this.childrenViews=new r.ViewList(this.addChildView,(function(e){e.remove()}),this),this.listenTo(this.model,"change:children",(function(){return n.updateTabs()})),this.listenTo(this.model,"change:_titles",(function(){return n.updateTitles()}))},t.prototype.render=function(){e.prototype.render.call(this);var t=this.pWidget;t.addClass("jupyter-widgets"),t.addClass("widget-container"),t.addClass("widget-tab"),t.tabsMovable=!0,t.tabBar.insertBehavior="none",t.tabBar.currentChanged.connect(this._onTabChanged,this),t.tabBar.tabMoved.connect(this._onTabMoved,this),t.tabBar.addClass("widget-tab-bar"),t.tabContents.addClass("widget-tab-contents"),t.tabBar.tabsMovable=!1,this.updateTabs(),this.update()},t.prototype.updateTabs=function(){this.updatingTabs=!0,this.pWidget.currentIndex=null,this.childrenViews.update(this.model.get("children")),this.pWidget.currentIndex=this.model.get("selected_index"),this.updatingTabs=!1},t.prototype.addChildView=function(e,t){var n=this.model.get("_titles")[t]||"",r=this.pWidget,o=new B.Widget;return o.title.label=n,r.addWidget(o),this.create_child_view(e).then((function(e){var t=e.pWidget;t.title.label=o.title.label,t.title.closable=!1;var n=z.ArrayExt.firstIndexOf(r.widgets,o);return r.insertWidget(n+1,t),o.dispose(),e})).catch(i("Could not add child view to box",!0))},t.prototype.update=function(){return this.updateSelectedIndex(),e.prototype.update.call(this)},t.prototype.updateTitles=function(){var e=this.model.get("_titles")||{};Object(z.each)(this.pWidget.widgets,(function(t,n){t.title.label=e[n]||""}))},t.prototype.updateSelectedIndex=function(){this.pWidget.currentIndex=this.model.get("selected_index")},t.prototype.remove=function(){this.childrenViews=null,e.prototype.remove.call(this)},t.prototype._onTabChanged=function(e,t){if(!this.updatingTabs){var n=t.currentIndex;this.model.set("selected_index",-1===n?null:n),this.touch()}},t.prototype._onTabMoved=function(e,t){var n=this.model.get("children").slice();z.ArrayExt.move(n,t.fromIndex,t.toIndex),this.model.set("children",n),this.touch()},t}(r.DOMWidgetView),$t=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),en=function(){return(en=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},tn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{value:"",disabled:!1,placeholder:"​",_model_name:"StringModel"})},t}(b),nn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"HTMLView",_model_name:"HTMLModel"})},t}(tn),rn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-html"),this.content=document.createElement("div"),this.content.classList.add("widget-html-content"),this.el.appendChild(this.content),this.update()},t.prototype.update=function(){return this.content.innerHTML=this.model.get("value"),e.prototype.update.call(this)},t}(p),on=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"HTMLMathView",_model_name:"HTMLMathModel"})},t}(tn),an=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-htmlmath"),this.content=document.createElement("div"),this.content.classList.add("widget-htmlmath-content"),this.el.appendChild(this.content),this.update()},t.prototype.update=function(){return this.content.innerHTML=this.model.get("value"),this.typeset(this.content),e.prototype.update.call(this)},t}(p),sn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"LabelView",_model_name:"LabelModel"})},t}(tn),ln=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.render=function(){e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-label"),this.update()},t.prototype.update=function(){return this.typeset(this.el,this.model.get("value")),e.prototype.update.call(this)},t}(p),cn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"TextareaView",_model_name:"TextareaModel",rows:null,continuous_update:!0})},t}(tn),un=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.render=function(){var t=this;e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-textarea"),this.textbox=document.createElement("textarea"),this.textbox.setAttribute("rows","5"),this.textbox.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this.textbox),this.update(),this.listenTo(this.model,"change:placeholder",(function(e,n,r){t.update_placeholder(n)})),this.update_placeholder()},t.prototype.update_placeholder=function(e){e=e||this.model.get("placeholder"),this.textbox.setAttribute("placeholder",e.toString())},t.prototype.update=function(t){if(void 0===t||t.updated_view!=this){this.textbox.value=this.model.get("value");var n=this.model.get("rows");null===n&&(n=""),this.textbox.setAttribute("rows",n),this.textbox.disabled=this.model.get("disabled")}return e.prototype.update.call(this)},t.prototype.events=function(){return{"keydown input":"handleKeyDown","keypress input":"handleKeypress","input textarea":"handleChanging","change textarea":"handleChanged"}},t.prototype.handleKeyDown=function(e){e.stopPropagation()},t.prototype.handleKeypress=function(e){e.stopPropagation()},t.prototype.handleChanging=function(e){this.model.get("continuous_update")&&this.handleChanged(e)},t.prototype.handleChanged=function(e){var t=e.target;this.model.set("value",t.value,{updated_view:this}),this.touch()},t}(p),dn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"TextView",_model_name:"TextModel",continuous_update:!0})},t}(tn),hn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.inputType="text",t}return $t(t,e),t.prototype.render=function(){var t=this;e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-inline-hbox"),this.el.classList.add("widget-text"),this.textbox=document.createElement("input"),this.textbox.setAttribute("type",this.inputType),this.textbox.id=this.label.htmlFor=Object(r.uuid)(),this.el.appendChild(this.textbox),this.update(),this.listenTo(this.model,"change:placeholder",(function(e,n,r){t.update_placeholder(n)})),this.listenTo(this.model,"change:description_tooltip",this.update_title),this.listenTo(this.model,"change:description",this.update_title),this.update_placeholder(),this.update_title()},t.prototype.update_placeholder=function(e){this.textbox.setAttribute("placeholder",e||this.model.get("placeholder"))},t.prototype.update_title=function(){var e=this.model.get("description_tooltip");e?0===this.model.get("description").length&&this.textbox.setAttribute("title",e):this.textbox.removeAttribute("title")},t.prototype.update=function(t){return void 0!==t&&t.updated_view===this||(this.textbox.value!==this.model.get("value")&&(this.textbox.value=this.model.get("value")),this.textbox.disabled=this.model.get("disabled")),e.prototype.update.call(this)},t.prototype.events=function(){return{"keydown input":"handleKeyDown","keypress input":"handleKeypress","input input":"handleChanging","change input":"handleChanged"}},t.prototype.handleKeyDown=function(e){e.stopPropagation()},t.prototype.handleKeypress=function(e){e.stopPropagation(),13===e.keyCode&&this.send({event:"submit"})},t.prototype.handleChanging=function(e){this.model.get("continuous_update")&&this.handleChanged(e)},t.prototype.handleChanged=function(e){var t=e.target;this.model.set("value",t.value,{updated_view:this}),this.touch()},t}(p),pn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_view_name:"PasswordView",_model_name:"PasswordModel"})},t}(dn),fn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.inputType="password",t}return $t(t,e),t}(hn),mn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return $t(t,e),t.prototype.defaults=function(){return en(en({},e.prototype.defaults.call(this)),{_model_name:"ComboboxModel",_view_name:"ComboboxView",options:[],ensure_options:!1})},t}(dn),gn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.isInitialRender=!0,t}return $t(t,e),t.prototype.render=function(){this.datalist=document.createElement("datalist"),this.datalist.id=Object(r.uuid)(),e.prototype.render.call(this),this.textbox.setAttribute("list",this.datalist.id),this.el.appendChild(this.datalist)},t.prototype.update=function(t){if(e.prototype.update.call(this,t),this.datalist){var n=this.isValid(this.model.get("value"));if(this.highlightValidState(n),!(void 0!==t&&t.updated_view||!this.model.hasChanged("options")&&!this.isInitialRender)){this.isInitialRender=!1;var r=this.model.get("options").map((function(e){return'<option value="'+e+'"></option>'}));this.datalist.innerHTML=r.join("\n")}}},t.prototype.isValid=function(e){if(!0===this.model.get("ensure_option")&&-1===this.model.get("options").indexOf(e))return!1;return!0},t.prototype.handleChanging=function(t){var n=t.target,r=this.isValid(n.value);this.highlightValidState(r),r&&e.prototype.handleChanging.call(this,t)},t.prototype.handleChanged=function(t){var n=t.target,r=this.isValid(n.value);this.highlightValidState(r),r&&e.prototype.handleChanged.call(this,t)},t.prototype.highlightValidState=function(e){this.textbox.classList.toggle("jpwidgets-invalidComboValue",!e)},t}(hn),vn=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}(),yn=function(){return(yn=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},_n=function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r},bn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vn(t,e),t.prototype.defaults=function(){return g.extend(e.prototype.defaults.call(this),{_model_name:"FileUploadModel",_view_name:"FileUploadView",_counter:0,accept:"",description:"Upload",tooltip:"",disabled:!1,icon:"upload",button_style:"",multiple:!1,metadata:[],data:[],error:"",style:null})},t.serializers=yn(yn({},_.serializers),{data:{serialize:function(e){return _n(e)}}}),t}(_),Mn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return vn(t,e),Object.defineProperty(t.prototype,"tagName",{get:function(){return"button"},enumerable:!0,configurable:!0}),t.prototype.render=function(){var t=this;e.prototype.render.call(this),this.el.classList.add("jupyter-widgets"),this.el.classList.add("widget-upload"),this.el.classList.add("jupyter-button"),this.fileInput=document.createElement("input"),this.fileInput.type="file",this.fileInput.style.display="none",this.el.appendChild(this.fileInput),this.el.addEventListener("click",(function(){t.fileInput.click()})),this.fileInput.addEventListener("click",(function(){t.fileInput.value=""})),this.fileInput.addEventListener("change",(function(){var e=[];Array.from(t.fileInput.files).forEach((function(n){e.push(new Promise((function(e,r){var i={name:n.name,type:n.type,size:n.size,lastModified:n.lastModified};t.fileReader=new FileReader,t.fileReader.onload=function(t){var n=t.target.result;e({buffer:n,metadata:i,error:""})},t.fileReader.onerror=function(){r()},t.fileReader.onabort=t.fileReader.onerror,t.fileReader.readAsArrayBuffer(n)})))})),Promise.all(e).then((function(e){var n=[],r=[];e.forEach((function(e){n.push(e.metadata),r.push(e.buffer)}));var i=t.model.get("_counter");t.model.set({_counter:i+e.length,metadata:n,data:r,error:""}),t.touch()})).catch((function(e){console.error("error in file upload: %o",e),t.model.set({error:e}),t.touch()}))})),this.listenTo(this.model,"change:button_style",this.update_button_style),this.set_button_style(),this.update()},t.prototype.update=function(){this.el.disabled=this.model.get("disabled"),this.el.setAttribute("title",this.model.get("tooltip"));var t=this.model.get("description")+" ("+this.model.get("_counter")+")",n=this.model.get("icon");if(t.length||n.length){if(this.el.textContent="",n.length){var r=document.createElement("i");r.classList.add("fa"),r.classList.add("fa-"+n),0===t.length&&r.classList.add("center"),this.el.appendChild(r)}this.el.appendChild(document.createTextNode(t))}return this.fileInput.accept=this.model.get("accept"),this.fileInput.multiple=this.model.get("multiple"),e.prototype.update.call(this)},t.prototype.update_button_style=function(){this.update_mapped_classes(t.class_map,"button_style",this.el)},t.prototype.set_button_style=function(){this.set_mapped_classes(t.class_map,"button_style",this.el)},t.class_map={primary:["mod-primary"],success:["mod-success"],info:["mod-info"],warning:["mod-warning"],danger:["mod-danger"]},t}(r.DOMWidgetView),wn=n(818).version},function(e,t,n){"use strict";(function(t){function n(e){if("string"!=typeof e)throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}function r(e,t){for(var n,r="",i=0,o=-1,a=0,s=0;s<=e.length;++s){if(s<e.length)n=e.charCodeAt(s);else{if(47===n)break;n=47}if(47===n){if(o===s-1||1===a);else if(o!==s-1&&2===a){if(r.length<2||2!==i||46!==r.charCodeAt(r.length-1)||46!==r.charCodeAt(r.length-2))if(r.length>2){var l=r.lastIndexOf("/");if(l!==r.length-1){-1===l?(r="",i=0):i=(r=r.slice(0,l)).length-1-r.lastIndexOf("/"),o=s,a=0;continue}}else if(2===r.length||1===r.length){r="",i=0,o=s,a=0;continue}t&&(r.length>0?r+="/..":r="..",i=2)}else r.length>0?r+="/"+e.slice(o+1,s):r=e.slice(o+1,s),i=s-o-1;o=s,a=0}else 46===n&&-1!==a?++a:a=-1}return r}var i={resolve:function(){for(var e,i="",o=!1,a=arguments.length-1;a>=-1&&!o;a--){var s;a>=0?s=arguments[a]:(void 0===e&&(e=t.cwd()),s=e),n(s),0!==s.length&&(i=s+"/"+i,o=47===s.charCodeAt(0))}return i=r(i,!o),o?i.length>0?"/"+i:"/":i.length>0?i:"."},normalize:function(e){if(n(e),0===e.length)return".";var t=47===e.charCodeAt(0),i=47===e.charCodeAt(e.length-1);return 0!==(e=r(e,!t)).length||t||(e="."),e.length>0&&i&&(e+="/"),t?"/"+e:e},isAbsolute:function(e){return n(e),e.length>0&&47===e.charCodeAt(0)},join:function(){if(0===arguments.length)return".";for(var e,t=0;t<arguments.length;++t){var r=arguments[t];n(r),r.length>0&&(void 0===e?e=r:e+="/"+r)}return void 0===e?".":i.normalize(e)},relative:function(e,t){if(n(e),n(t),e===t)return"";if((e=i.resolve(e))===(t=i.resolve(t)))return"";for(var r=1;r<e.length&&47===e.charCodeAt(r);++r);for(var o=e.length,a=o-r,s=1;s<t.length&&47===t.charCodeAt(s);++s);for(var l=t.length-s,c=a<l?a:l,u=-1,d=0;d<=c;++d){if(d===c){if(l>c){if(47===t.charCodeAt(s+d))return t.slice(s+d+1);if(0===d)return t.slice(s+d)}else a>c&&(47===e.charCodeAt(r+d)?u=d:0===d&&(u=0));break}var h=e.charCodeAt(r+d);if(h!==t.charCodeAt(s+d))break;47===h&&(u=d)}var p="";for(d=r+u+1;d<=o;++d)d!==o&&47!==e.charCodeAt(d)||(0===p.length?p+="..":p+="/..");return p.length>0?p+t.slice(s+u):(s+=u,47===t.charCodeAt(s)&&++s,t.slice(s))},_makeLong:function(e){return e},dirname:function(e){if(n(e),0===e.length)return".";for(var t=e.charCodeAt(0),r=47===t,i=-1,o=!0,a=e.length-1;a>=1;--a)if(47===(t=e.charCodeAt(a))){if(!o){i=a;break}}else o=!1;return-1===i?r?"/":".":r&&1===i?"//":e.slice(0,i)},basename:function(e,t){if(void 0!==t&&"string"!=typeof t)throw new TypeError('"ext" argument must be a string');n(e);var r,i=0,o=-1,a=!0;if(void 0!==t&&t.length>0&&t.length<=e.length){if(t.length===e.length&&t===e)return"";var s=t.length-1,l=-1;for(r=e.length-1;r>=0;--r){var c=e.charCodeAt(r);if(47===c){if(!a){i=r+1;break}}else-1===l&&(a=!1,l=r+1),s>=0&&(c===t.charCodeAt(s)?-1==--s&&(o=r):(s=-1,o=l))}return i===o?o=l:-1===o&&(o=e.length),e.slice(i,o)}for(r=e.length-1;r>=0;--r)if(47===e.charCodeAt(r)){if(!a){i=r+1;break}}else-1===o&&(a=!1,o=r+1);return-1===o?"":e.slice(i,o)},extname:function(e){n(e);for(var t=-1,r=0,i=-1,o=!0,a=0,s=e.length-1;s>=0;--s){var l=e.charCodeAt(s);if(47!==l)-1===i&&(o=!1,i=s+1),46===l?-1===t?t=s:1!==a&&(a=1):-1!==t&&(a=-1);else if(!o){r=s+1;break}}return-1===t||-1===i||0===a||1===a&&t===i-1&&t===r+1?"":e.slice(t,i)},format:function(e){if(null===e||"object"!=typeof e)throw new TypeError('The "pathObject" argument must be of type Object. Received type '+typeof e);return function(e,t){var n=t.dir||t.root,r=t.base||(t.name||"")+(t.ext||"");return n?n===t.root?n+r:n+e+r:r}("/",e)},parse:function(e){n(e);var t={root:"",dir:"",base:"",ext:"",name:""};if(0===e.length)return t;var r,i=e.charCodeAt(0),o=47===i;o?(t.root="/",r=1):r=0;for(var a=-1,s=0,l=-1,c=!0,u=e.length-1,d=0;u>=r;--u)if(47!==(i=e.charCodeAt(u)))-1===l&&(c=!1,l=u+1),46===i?-1===a?a=u:1!==d&&(d=1):-1!==a&&(d=-1);else if(!c){s=u+1;break}return-1===a||-1===l||0===d||1===d&&a===l-1&&a===s+1?-1!==l&&(t.base=t.name=0===s&&o?e.slice(1,l):e.slice(s,l)):(0===s&&o?(t.name=e.slice(1,a),t.base=e.slice(1,l)):(t.name=e.slice(s,a),t.base=e.slice(s,l)),t.ext=e.slice(a,l)),s>0?t.dir=e.slice(0,s-1):o&&(t.dir="/"),t},sep:"/",delimiter:":",win32:null,posix:null};i.posix=i,e.exports=i}).call(this,n(61))},function(e,t){e.exports=function(e){return e.webpackPolyfill||(e.deprecate=function(){},e.paths=[],e.children||(e.children=[]),Object.defineProperty(e,"loaded",{enumerable:!0,get:function(){return e.l}}),Object.defineProperty(e,"id",{enumerable:!0,get:function(){return e.i}}),e.webpackPolyfill=1),e}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getKernelModel=t.shutdownKernel=t.interruptKernel=t.restartKernel=t.startNew=t.listRunning=t.KERNEL_SERVICE_URL=void 0;const r=n(56),i=n(12),o=n(153);t.KERNEL_SERVICE_URL="api/kernels",t.listRunning=async function(e=r.ServerConnection.makeSettings()){const n=i.URLExt.join(e.baseUrl,t.KERNEL_SERVICE_URL),a=await r.ServerConnection.makeRequest(n,{},e);if(200!==a.status){throw await r.ServerConnection.ResponseError.create(a)}const s=await a.json();return o.validateModels(s),s},t.startNew=async function(e={},n=r.ServerConnection.makeSettings()){const a=i.URLExt.join(n.baseUrl,t.KERNEL_SERVICE_URL),s={method:"POST",body:JSON.stringify(e)},l=await r.ServerConnection.makeRequest(a,s,n);if(201!==l.status){throw await r.ServerConnection.ResponseError.create(l)}const c=await l.json();return o.validateModel(c),c},t.restartKernel=async function(e,n=r.ServerConnection.makeSettings()){const a=i.URLExt.join(n.baseUrl,t.KERNEL_SERVICE_URL,encodeURIComponent(e),"restart"),s=await r.ServerConnection.makeRequest(a,{method:"POST"},n);if(200!==s.status){throw await r.ServerConnection.ResponseError.create(s)}const l=await s.json();o.validateModel(l)},t.interruptKernel=async function(e,n=r.ServerConnection.makeSettings()){const o=i.URLExt.join(n.baseUrl,t.KERNEL_SERVICE_URL,encodeURIComponent(e),"interrupt"),a=await r.ServerConnection.makeRequest(o,{method:"POST"},n);if(204!==a.status){throw await r.ServerConnection.ResponseError.create(a)}},t.shutdownKernel=async function(e,n=r.ServerConnection.makeSettings()){const o=i.URLExt.join(n.baseUrl,t.KERNEL_SERVICE_URL,encodeURIComponent(e)),a=await r.ServerConnection.makeRequest(o,{method:"DELETE"},n);if(404===a.status){const t=`The kernel "${e}" does not exist on the server`;console.warn(t)}else if(204!==a.status){throw await r.ServerConnection.ResponseError.create(a)}},t.getKernelModel=async function(e,n=r.ServerConnection.makeSettings()){const a=i.URLExt.join(n.baseUrl,t.KERNEL_SERVICE_URL,encodeURIComponent(e)),s=await r.ServerConnection.makeRequest(a,{},n);if(404===s.status)return;if(200!==s.status){throw await r.ServerConnection.ResponseError.create(s)}const l=await s.json();return o.validateModel(l),l}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.validateModels=t.validateModel=t.validateMessage=void 0;const r=n(119),i=["username","version","session","msg_id","msg_type"],o={stream:{name:"string",text:"string"},display_data:{data:"object",metadata:"object"},execute_input:{code:"string",execution_count:"number"},execute_result:{execution_count:"number",data:"object",metadata:"object"},error:{ename:"string",evalue:"string",traceback:"object"},status:{execution_state:["string",["starting","idle","busy","restarting","dead"]]},clear_output:{wait:"boolean"},comm_open:{comm_id:"string",target_name:"string",data:"object"},comm_msg:{comm_id:"string",data:"object"},comm_close:{comm_id:"string"},shutdown_reply:{restart:"boolean"}};function a(e){r.validateProperty(e,"name","string"),r.validateProperty(e,"id","string")}t.validateMessage=function(e){r.validateProperty(e,"metadata","object"),r.validateProperty(e,"content","object"),r.validateProperty(e,"channel","string"),function(e){for(let t=0;t<i.length;t++)r.validateProperty(e,i[t],"string")}(e.header),"iopub"===e.channel&&function(e){if("iopub"===e.channel){const t=o[e.header.msg_type];if(void 0===t)return;const n=Object.keys(t),i=e.content;for(let e=0;e<n.length;e++){let o=t[n[e]];Array.isArray(o)||(o=[o]),r.validateProperty(i,n[e],...o)}}}(e)},t.validateModel=a,t.validateModels=function(e){if(!Array.isArray(e))throw new Error("Invalid kernel list");e.forEach(e=>a(e))}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t},a=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.KernelSpecAPI=t.KernelSpec=void 0;const s=o(n(629));t.KernelSpec=s;const l=o(n(348));t.KernelSpecAPI=l,a(n(631),t)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.updateSession=t.startSession=t.getSessionModel=t.shutdownSession=t.getSessionUrl=t.listRunning=t.SESSION_SERVICE_URL=void 0;const r=n(56),i=n(12),o=n(635);function a(e,n){return i.URLExt.join(e,t.SESSION_SERVICE_URL,n)}t.SESSION_SERVICE_URL="api/sessions",t.listRunning=async function(e=r.ServerConnection.makeSettings()){const n=i.URLExt.join(e.baseUrl,t.SESSION_SERVICE_URL),a=await r.ServerConnection.makeRequest(n,{},e);if(200!==a.status){throw await r.ServerConnection.ResponseError.create(a)}const s=await a.json();if(!Array.isArray(s))throw new Error("Invalid Session list");return s.forEach(e=>{o.updateLegacySessionModel(e),o.validateModel(e)}),s},t.getSessionUrl=a,t.shutdownSession=async function(e,t=r.ServerConnection.makeSettings()){var n;const i=a(t.baseUrl,e),o=await r.ServerConnection.makeRequest(i,{method:"DELETE"},t);if(404===o.status){const t=null!==(n=(await o.json()).message)&&void 0!==n?n:`The session "${e}"" does not exist on the server`;console.warn(t)}else{if(410===o.status)throw new r.ServerConnection.ResponseError(o,"The kernel was deleted but the session was not");if(204!==o.status){throw await r.ServerConnection.ResponseError.create(o)}}},t.getSessionModel=async function(e,t=r.ServerConnection.makeSettings()){const n=a(t.baseUrl,e),i=await r.ServerConnection.makeRequest(n,{},t);if(200!==i.status){throw await r.ServerConnection.ResponseError.create(i)}const s=await i.json();return o.updateLegacySessionModel(s),o.validateModel(s),s},t.startSession=async function(e,n=r.ServerConnection.makeSettings()){const a=i.URLExt.join(n.baseUrl,t.SESSION_SERVICE_URL),s={method:"POST",body:JSON.stringify(e)},l=await r.ServerConnection.makeRequest(a,s,n);if(201!==l.status){throw await r.ServerConnection.ResponseError.create(l)}const c=await l.json();return o.updateLegacySessionModel(c),o.validateModel(c),c},t.updateSession=async function(e,t=r.ServerConnection.makeSettings()){const n=a(t.baseUrl,e.id),i={method:"PATCH",body:JSON.stringify(e)},s=await r.ServerConnection.makeRequest(n,i,t);if(200!==s.status){throw await r.ServerConnection.ResponseError.create(s)}const l=await s.json();return o.updateLegacySessionModel(l),o.validateModel(l),l}},function(e){e.exports=JSON.parse('{"Aacute":"Á","aacute":"á","Abreve":"Ă","abreve":"ă","ac":"∾","acd":"∿","acE":"∾̳","Acirc":"Â","acirc":"â","acute":"´","Acy":"А","acy":"а","AElig":"Æ","aelig":"æ","af":"⁡","Afr":"𝔄","afr":"𝔞","Agrave":"À","agrave":"à","alefsym":"ℵ","aleph":"ℵ","Alpha":"Α","alpha":"α","Amacr":"Ā","amacr":"ā","amalg":"⨿","amp":"&","AMP":"&","andand":"⩕","And":"⩓","and":"∧","andd":"⩜","andslope":"⩘","andv":"⩚","ang":"∠","ange":"⦤","angle":"∠","angmsdaa":"⦨","angmsdab":"⦩","angmsdac":"⦪","angmsdad":"⦫","angmsdae":"⦬","angmsdaf":"⦭","angmsdag":"⦮","angmsdah":"⦯","angmsd":"∡","angrt":"∟","angrtvb":"⊾","angrtvbd":"⦝","angsph":"∢","angst":"Å","angzarr":"⍼","Aogon":"Ą","aogon":"ą","Aopf":"𝔸","aopf":"𝕒","apacir":"⩯","ap":"≈","apE":"⩰","ape":"≊","apid":"≋","apos":"\'","ApplyFunction":"⁡","approx":"≈","approxeq":"≊","Aring":"Å","aring":"å","Ascr":"𝒜","ascr":"𝒶","Assign":"≔","ast":"*","asymp":"≈","asympeq":"≍","Atilde":"Ã","atilde":"ã","Auml":"Ä","auml":"ä","awconint":"∳","awint":"⨑","backcong":"≌","backepsilon":"϶","backprime":"‵","backsim":"∽","backsimeq":"⋍","Backslash":"∖","Barv":"⫧","barvee":"⊽","barwed":"⌅","Barwed":"⌆","barwedge":"⌅","bbrk":"⎵","bbrktbrk":"⎶","bcong":"≌","Bcy":"Б","bcy":"б","bdquo":"„","becaus":"∵","because":"∵","Because":"∵","bemptyv":"⦰","bepsi":"϶","bernou":"ℬ","Bernoullis":"ℬ","Beta":"Β","beta":"β","beth":"ℶ","between":"≬","Bfr":"𝔅","bfr":"𝔟","bigcap":"⋂","bigcirc":"◯","bigcup":"⋃","bigodot":"⨀","bigoplus":"⨁","bigotimes":"⨂","bigsqcup":"⨆","bigstar":"★","bigtriangledown":"▽","bigtriangleup":"△","biguplus":"⨄","bigvee":"⋁","bigwedge":"⋀","bkarow":"⤍","blacklozenge":"⧫","blacksquare":"▪","blacktriangle":"▴","blacktriangledown":"▾","blacktriangleleft":"◂","blacktriangleright":"▸","blank":"␣","blk12":"▒","blk14":"░","blk34":"▓","block":"█","bne":"=⃥","bnequiv":"≡⃥","bNot":"⫭","bnot":"⌐","Bopf":"𝔹","bopf":"𝕓","bot":"⊥","bottom":"⊥","bowtie":"⋈","boxbox":"⧉","boxdl":"┐","boxdL":"╕","boxDl":"╖","boxDL":"╗","boxdr":"┌","boxdR":"╒","boxDr":"╓","boxDR":"╔","boxh":"─","boxH":"═","boxhd":"┬","boxHd":"╤","boxhD":"╥","boxHD":"╦","boxhu":"┴","boxHu":"╧","boxhU":"╨","boxHU":"╩","boxminus":"⊟","boxplus":"⊞","boxtimes":"⊠","boxul":"┘","boxuL":"╛","boxUl":"╜","boxUL":"╝","boxur":"└","boxuR":"╘","boxUr":"╙","boxUR":"╚","boxv":"│","boxV":"║","boxvh":"┼","boxvH":"╪","boxVh":"╫","boxVH":"╬","boxvl":"┤","boxvL":"╡","boxVl":"╢","boxVL":"╣","boxvr":"├","boxvR":"╞","boxVr":"╟","boxVR":"╠","bprime":"‵","breve":"˘","Breve":"˘","brvbar":"¦","bscr":"𝒷","Bscr":"ℬ","bsemi":"⁏","bsim":"∽","bsime":"⋍","bsolb":"⧅","bsol":"\\\\","bsolhsub":"⟈","bull":"•","bullet":"•","bump":"≎","bumpE":"⪮","bumpe":"≏","Bumpeq":"≎","bumpeq":"≏","Cacute":"Ć","cacute":"ć","capand":"⩄","capbrcup":"⩉","capcap":"⩋","cap":"∩","Cap":"⋒","capcup":"⩇","capdot":"⩀","CapitalDifferentialD":"ⅅ","caps":"∩︀","caret":"⁁","caron":"ˇ","Cayleys":"ℭ","ccaps":"⩍","Ccaron":"Č","ccaron":"č","Ccedil":"Ç","ccedil":"ç","Ccirc":"Ĉ","ccirc":"ĉ","Cconint":"∰","ccups":"⩌","ccupssm":"⩐","Cdot":"Ċ","cdot":"ċ","cedil":"¸","Cedilla":"¸","cemptyv":"⦲","cent":"¢","centerdot":"·","CenterDot":"·","cfr":"𝔠","Cfr":"ℭ","CHcy":"Ч","chcy":"ч","check":"✓","checkmark":"✓","Chi":"Χ","chi":"χ","circ":"ˆ","circeq":"≗","circlearrowleft":"↺","circlearrowright":"↻","circledast":"⊛","circledcirc":"⊚","circleddash":"⊝","CircleDot":"⊙","circledR":"®","circledS":"Ⓢ","CircleMinus":"⊖","CirclePlus":"⊕","CircleTimes":"⊗","cir":"○","cirE":"⧃","cire":"≗","cirfnint":"⨐","cirmid":"⫯","cirscir":"⧂","ClockwiseContourIntegral":"∲","CloseCurlyDoubleQuote":"”","CloseCurlyQuote":"’","clubs":"♣","clubsuit":"♣","colon":":","Colon":"∷","Colone":"⩴","colone":"≔","coloneq":"≔","comma":",","commat":"@","comp":"∁","compfn":"∘","complement":"∁","complexes":"ℂ","cong":"≅","congdot":"⩭","Congruent":"≡","conint":"∮","Conint":"∯","ContourIntegral":"∮","copf":"𝕔","Copf":"ℂ","coprod":"∐","Coproduct":"∐","copy":"©","COPY":"©","copysr":"℗","CounterClockwiseContourIntegral":"∳","crarr":"↵","cross":"✗","Cross":"⨯","Cscr":"𝒞","cscr":"𝒸","csub":"⫏","csube":"⫑","csup":"⫐","csupe":"⫒","ctdot":"⋯","cudarrl":"⤸","cudarrr":"⤵","cuepr":"⋞","cuesc":"⋟","cularr":"↶","cularrp":"⤽","cupbrcap":"⩈","cupcap":"⩆","CupCap":"≍","cup":"∪","Cup":"⋓","cupcup":"⩊","cupdot":"⊍","cupor":"⩅","cups":"∪︀","curarr":"↷","curarrm":"⤼","curlyeqprec":"⋞","curlyeqsucc":"⋟","curlyvee":"⋎","curlywedge":"⋏","curren":"¤","curvearrowleft":"↶","curvearrowright":"↷","cuvee":"⋎","cuwed":"⋏","cwconint":"∲","cwint":"∱","cylcty":"⌭","dagger":"†","Dagger":"‡","daleth":"ℸ","darr":"↓","Darr":"↡","dArr":"⇓","dash":"‐","Dashv":"⫤","dashv":"⊣","dbkarow":"⤏","dblac":"˝","Dcaron":"Ď","dcaron":"ď","Dcy":"Д","dcy":"д","ddagger":"‡","ddarr":"⇊","DD":"ⅅ","dd":"ⅆ","DDotrahd":"⤑","ddotseq":"⩷","deg":"°","Del":"∇","Delta":"Δ","delta":"δ","demptyv":"⦱","dfisht":"⥿","Dfr":"𝔇","dfr":"𝔡","dHar":"⥥","dharl":"⇃","dharr":"⇂","DiacriticalAcute":"´","DiacriticalDot":"˙","DiacriticalDoubleAcute":"˝","DiacriticalGrave":"`","DiacriticalTilde":"˜","diam":"⋄","diamond":"⋄","Diamond":"⋄","diamondsuit":"♦","diams":"♦","die":"¨","DifferentialD":"ⅆ","digamma":"ϝ","disin":"⋲","div":"÷","divide":"÷","divideontimes":"⋇","divonx":"⋇","DJcy":"Ђ","djcy":"ђ","dlcorn":"⌞","dlcrop":"⌍","dollar":"$","Dopf":"𝔻","dopf":"𝕕","Dot":"¨","dot":"˙","DotDot":"⃜","doteq":"≐","doteqdot":"≑","DotEqual":"≐","dotminus":"∸","dotplus":"∔","dotsquare":"⊡","doublebarwedge":"⌆","DoubleContourIntegral":"∯","DoubleDot":"¨","DoubleDownArrow":"⇓","DoubleLeftArrow":"⇐","DoubleLeftRightArrow":"⇔","DoubleLeftTee":"⫤","DoubleLongLeftArrow":"⟸","DoubleLongLeftRightArrow":"⟺","DoubleLongRightArrow":"⟹","DoubleRightArrow":"⇒","DoubleRightTee":"⊨","DoubleUpArrow":"⇑","DoubleUpDownArrow":"⇕","DoubleVerticalBar":"∥","DownArrowBar":"⤓","downarrow":"↓","DownArrow":"↓","Downarrow":"⇓","DownArrowUpArrow":"⇵","DownBreve":"̑","downdownarrows":"⇊","downharpoonleft":"⇃","downharpoonright":"⇂","DownLeftRightVector":"⥐","DownLeftTeeVector":"⥞","DownLeftVectorBar":"⥖","DownLeftVector":"↽","DownRightTeeVector":"⥟","DownRightVectorBar":"⥗","DownRightVector":"⇁","DownTeeArrow":"↧","DownTee":"⊤","drbkarow":"⤐","drcorn":"⌟","drcrop":"⌌","Dscr":"𝒟","dscr":"𝒹","DScy":"Ѕ","dscy":"ѕ","dsol":"⧶","Dstrok":"Đ","dstrok":"đ","dtdot":"⋱","dtri":"▿","dtrif":"▾","duarr":"⇵","duhar":"⥯","dwangle":"⦦","DZcy":"Џ","dzcy":"џ","dzigrarr":"⟿","Eacute":"É","eacute":"é","easter":"⩮","Ecaron":"Ě","ecaron":"ě","Ecirc":"Ê","ecirc":"ê","ecir":"≖","ecolon":"≕","Ecy":"Э","ecy":"э","eDDot":"⩷","Edot":"Ė","edot":"ė","eDot":"≑","ee":"ⅇ","efDot":"≒","Efr":"𝔈","efr":"𝔢","eg":"⪚","Egrave":"È","egrave":"è","egs":"⪖","egsdot":"⪘","el":"⪙","Element":"∈","elinters":"⏧","ell":"ℓ","els":"⪕","elsdot":"⪗","Emacr":"Ē","emacr":"ē","empty":"∅","emptyset":"∅","EmptySmallSquare":"◻","emptyv":"∅","EmptyVerySmallSquare":"▫","emsp13":" ","emsp14":" ","emsp":" ","ENG":"Ŋ","eng":"ŋ","ensp":" ","Eogon":"Ę","eogon":"ę","Eopf":"𝔼","eopf":"𝕖","epar":"⋕","eparsl":"⧣","eplus":"⩱","epsi":"ε","Epsilon":"Ε","epsilon":"ε","epsiv":"ϵ","eqcirc":"≖","eqcolon":"≕","eqsim":"≂","eqslantgtr":"⪖","eqslantless":"⪕","Equal":"⩵","equals":"=","EqualTilde":"≂","equest":"≟","Equilibrium":"⇌","equiv":"≡","equivDD":"⩸","eqvparsl":"⧥","erarr":"⥱","erDot":"≓","escr":"ℯ","Escr":"ℰ","esdot":"≐","Esim":"⩳","esim":"≂","Eta":"Η","eta":"η","ETH":"Ð","eth":"ð","Euml":"Ë","euml":"ë","euro":"€","excl":"!","exist":"∃","Exists":"∃","expectation":"ℰ","exponentiale":"ⅇ","ExponentialE":"ⅇ","fallingdotseq":"≒","Fcy":"Ф","fcy":"ф","female":"♀","ffilig":"ﬃ","fflig":"ﬀ","ffllig":"ﬄ","Ffr":"𝔉","ffr":"𝔣","filig":"ﬁ","FilledSmallSquare":"◼","FilledVerySmallSquare":"▪","fjlig":"fj","flat":"♭","fllig":"ﬂ","fltns":"▱","fnof":"ƒ","Fopf":"𝔽","fopf":"𝕗","forall":"∀","ForAll":"∀","fork":"⋔","forkv":"⫙","Fouriertrf":"ℱ","fpartint":"⨍","frac12":"½","frac13":"⅓","frac14":"¼","frac15":"⅕","frac16":"⅙","frac18":"⅛","frac23":"⅔","frac25":"⅖","frac34":"¾","frac35":"⅗","frac38":"⅜","frac45":"⅘","frac56":"⅚","frac58":"⅝","frac78":"⅞","frasl":"⁄","frown":"⌢","fscr":"𝒻","Fscr":"ℱ","gacute":"ǵ","Gamma":"Γ","gamma":"γ","Gammad":"Ϝ","gammad":"ϝ","gap":"⪆","Gbreve":"Ğ","gbreve":"ğ","Gcedil":"Ģ","Gcirc":"Ĝ","gcirc":"ĝ","Gcy":"Г","gcy":"г","Gdot":"Ġ","gdot":"ġ","ge":"≥","gE":"≧","gEl":"⪌","gel":"⋛","geq":"≥","geqq":"≧","geqslant":"⩾","gescc":"⪩","ges":"⩾","gesdot":"⪀","gesdoto":"⪂","gesdotol":"⪄","gesl":"⋛︀","gesles":"⪔","Gfr":"𝔊","gfr":"𝔤","gg":"≫","Gg":"⋙","ggg":"⋙","gimel":"ℷ","GJcy":"Ѓ","gjcy":"ѓ","gla":"⪥","gl":"≷","glE":"⪒","glj":"⪤","gnap":"⪊","gnapprox":"⪊","gne":"⪈","gnE":"≩","gneq":"⪈","gneqq":"≩","gnsim":"⋧","Gopf":"𝔾","gopf":"𝕘","grave":"`","GreaterEqual":"≥","GreaterEqualLess":"⋛","GreaterFullEqual":"≧","GreaterGreater":"⪢","GreaterLess":"≷","GreaterSlantEqual":"⩾","GreaterTilde":"≳","Gscr":"𝒢","gscr":"ℊ","gsim":"≳","gsime":"⪎","gsiml":"⪐","gtcc":"⪧","gtcir":"⩺","gt":">","GT":">","Gt":"≫","gtdot":"⋗","gtlPar":"⦕","gtquest":"⩼","gtrapprox":"⪆","gtrarr":"⥸","gtrdot":"⋗","gtreqless":"⋛","gtreqqless":"⪌","gtrless":"≷","gtrsim":"≳","gvertneqq":"≩︀","gvnE":"≩︀","Hacek":"ˇ","hairsp":" ","half":"½","hamilt":"ℋ","HARDcy":"Ъ","hardcy":"ъ","harrcir":"⥈","harr":"↔","hArr":"⇔","harrw":"↭","Hat":"^","hbar":"ℏ","Hcirc":"Ĥ","hcirc":"ĥ","hearts":"♥","heartsuit":"♥","hellip":"…","hercon":"⊹","hfr":"𝔥","Hfr":"ℌ","HilbertSpace":"ℋ","hksearow":"⤥","hkswarow":"⤦","hoarr":"⇿","homtht":"∻","hookleftarrow":"↩","hookrightarrow":"↪","hopf":"𝕙","Hopf":"ℍ","horbar":"―","HorizontalLine":"─","hscr":"𝒽","Hscr":"ℋ","hslash":"ℏ","Hstrok":"Ħ","hstrok":"ħ","HumpDownHump":"≎","HumpEqual":"≏","hybull":"⁃","hyphen":"‐","Iacute":"Í","iacute":"í","ic":"⁣","Icirc":"Î","icirc":"î","Icy":"И","icy":"и","Idot":"İ","IEcy":"Е","iecy":"е","iexcl":"¡","iff":"⇔","ifr":"𝔦","Ifr":"ℑ","Igrave":"Ì","igrave":"ì","ii":"ⅈ","iiiint":"⨌","iiint":"∭","iinfin":"⧜","iiota":"℩","IJlig":"Ĳ","ijlig":"ĳ","Imacr":"Ī","imacr":"ī","image":"ℑ","ImaginaryI":"ⅈ","imagline":"ℐ","imagpart":"ℑ","imath":"ı","Im":"ℑ","imof":"⊷","imped":"Ƶ","Implies":"⇒","incare":"℅","in":"∈","infin":"∞","infintie":"⧝","inodot":"ı","intcal":"⊺","int":"∫","Int":"∬","integers":"ℤ","Integral":"∫","intercal":"⊺","Intersection":"⋂","intlarhk":"⨗","intprod":"⨼","InvisibleComma":"⁣","InvisibleTimes":"⁢","IOcy":"Ё","iocy":"ё","Iogon":"Į","iogon":"į","Iopf":"𝕀","iopf":"𝕚","Iota":"Ι","iota":"ι","iprod":"⨼","iquest":"¿","iscr":"𝒾","Iscr":"ℐ","isin":"∈","isindot":"⋵","isinE":"⋹","isins":"⋴","isinsv":"⋳","isinv":"∈","it":"⁢","Itilde":"Ĩ","itilde":"ĩ","Iukcy":"І","iukcy":"і","Iuml":"Ï","iuml":"ï","Jcirc":"Ĵ","jcirc":"ĵ","Jcy":"Й","jcy":"й","Jfr":"𝔍","jfr":"𝔧","jmath":"ȷ","Jopf":"𝕁","jopf":"𝕛","Jscr":"𝒥","jscr":"𝒿","Jsercy":"Ј","jsercy":"ј","Jukcy":"Є","jukcy":"є","Kappa":"Κ","kappa":"κ","kappav":"ϰ","Kcedil":"Ķ","kcedil":"ķ","Kcy":"К","kcy":"к","Kfr":"𝔎","kfr":"𝔨","kgreen":"ĸ","KHcy":"Х","khcy":"х","KJcy":"Ќ","kjcy":"ќ","Kopf":"𝕂","kopf":"𝕜","Kscr":"𝒦","kscr":"𝓀","lAarr":"⇚","Lacute":"Ĺ","lacute":"ĺ","laemptyv":"⦴","lagran":"ℒ","Lambda":"Λ","lambda":"λ","lang":"⟨","Lang":"⟪","langd":"⦑","langle":"⟨","lap":"⪅","Laplacetrf":"ℒ","laquo":"«","larrb":"⇤","larrbfs":"⤟","larr":"←","Larr":"↞","lArr":"⇐","larrfs":"⤝","larrhk":"↩","larrlp":"↫","larrpl":"⤹","larrsim":"⥳","larrtl":"↢","latail":"⤙","lAtail":"⤛","lat":"⪫","late":"⪭","lates":"⪭︀","lbarr":"⤌","lBarr":"⤎","lbbrk":"❲","lbrace":"{","lbrack":"[","lbrke":"⦋","lbrksld":"⦏","lbrkslu":"⦍","Lcaron":"Ľ","lcaron":"ľ","Lcedil":"Ļ","lcedil":"ļ","lceil":"⌈","lcub":"{","Lcy":"Л","lcy":"л","ldca":"⤶","ldquo":"“","ldquor":"„","ldrdhar":"⥧","ldrushar":"⥋","ldsh":"↲","le":"≤","lE":"≦","LeftAngleBracket":"⟨","LeftArrowBar":"⇤","leftarrow":"←","LeftArrow":"←","Leftarrow":"⇐","LeftArrowRightArrow":"⇆","leftarrowtail":"↢","LeftCeiling":"⌈","LeftDoubleBracket":"⟦","LeftDownTeeVector":"⥡","LeftDownVectorBar":"⥙","LeftDownVector":"⇃","LeftFloor":"⌊","leftharpoondown":"↽","leftharpoonup":"↼","leftleftarrows":"⇇","leftrightarrow":"↔","LeftRightArrow":"↔","Leftrightarrow":"⇔","leftrightarrows":"⇆","leftrightharpoons":"⇋","leftrightsquigarrow":"↭","LeftRightVector":"⥎","LeftTeeArrow":"↤","LeftTee":"⊣","LeftTeeVector":"⥚","leftthreetimes":"⋋","LeftTriangleBar":"⧏","LeftTriangle":"⊲","LeftTriangleEqual":"⊴","LeftUpDownVector":"⥑","LeftUpTeeVector":"⥠","LeftUpVectorBar":"⥘","LeftUpVector":"↿","LeftVectorBar":"⥒","LeftVector":"↼","lEg":"⪋","leg":"⋚","leq":"≤","leqq":"≦","leqslant":"⩽","lescc":"⪨","les":"⩽","lesdot":"⩿","lesdoto":"⪁","lesdotor":"⪃","lesg":"⋚︀","lesges":"⪓","lessapprox":"⪅","lessdot":"⋖","lesseqgtr":"⋚","lesseqqgtr":"⪋","LessEqualGreater":"⋚","LessFullEqual":"≦","LessGreater":"≶","lessgtr":"≶","LessLess":"⪡","lesssim":"≲","LessSlantEqual":"⩽","LessTilde":"≲","lfisht":"⥼","lfloor":"⌊","Lfr":"𝔏","lfr":"𝔩","lg":"≶","lgE":"⪑","lHar":"⥢","lhard":"↽","lharu":"↼","lharul":"⥪","lhblk":"▄","LJcy":"Љ","ljcy":"љ","llarr":"⇇","ll":"≪","Ll":"⋘","llcorner":"⌞","Lleftarrow":"⇚","llhard":"⥫","lltri":"◺","Lmidot":"Ŀ","lmidot":"ŀ","lmoustache":"⎰","lmoust":"⎰","lnap":"⪉","lnapprox":"⪉","lne":"⪇","lnE":"≨","lneq":"⪇","lneqq":"≨","lnsim":"⋦","loang":"⟬","loarr":"⇽","lobrk":"⟦","longleftarrow":"⟵","LongLeftArrow":"⟵","Longleftarrow":"⟸","longleftrightarrow":"⟷","LongLeftRightArrow":"⟷","Longleftrightarrow":"⟺","longmapsto":"⟼","longrightarrow":"⟶","LongRightArrow":"⟶","Longrightarrow":"⟹","looparrowleft":"↫","looparrowright":"↬","lopar":"⦅","Lopf":"𝕃","lopf":"𝕝","loplus":"⨭","lotimes":"⨴","lowast":"∗","lowbar":"_","LowerLeftArrow":"↙","LowerRightArrow":"↘","loz":"◊","lozenge":"◊","lozf":"⧫","lpar":"(","lparlt":"⦓","lrarr":"⇆","lrcorner":"⌟","lrhar":"⇋","lrhard":"⥭","lrm":"‎","lrtri":"⊿","lsaquo":"‹","lscr":"𝓁","Lscr":"ℒ","lsh":"↰","Lsh":"↰","lsim":"≲","lsime":"⪍","lsimg":"⪏","lsqb":"[","lsquo":"‘","lsquor":"‚","Lstrok":"Ł","lstrok":"ł","ltcc":"⪦","ltcir":"⩹","lt":"<","LT":"<","Lt":"≪","ltdot":"⋖","lthree":"⋋","ltimes":"⋉","ltlarr":"⥶","ltquest":"⩻","ltri":"◃","ltrie":"⊴","ltrif":"◂","ltrPar":"⦖","lurdshar":"⥊","luruhar":"⥦","lvertneqq":"≨︀","lvnE":"≨︀","macr":"¯","male":"♂","malt":"✠","maltese":"✠","Map":"⤅","map":"↦","mapsto":"↦","mapstodown":"↧","mapstoleft":"↤","mapstoup":"↥","marker":"▮","mcomma":"⨩","Mcy":"М","mcy":"м","mdash":"—","mDDot":"∺","measuredangle":"∡","MediumSpace":" ","Mellintrf":"ℳ","Mfr":"𝔐","mfr":"𝔪","mho":"℧","micro":"µ","midast":"*","midcir":"⫰","mid":"∣","middot":"·","minusb":"⊟","minus":"−","minusd":"∸","minusdu":"⨪","MinusPlus":"∓","mlcp":"⫛","mldr":"…","mnplus":"∓","models":"⊧","Mopf":"𝕄","mopf":"𝕞","mp":"∓","mscr":"𝓂","Mscr":"ℳ","mstpos":"∾","Mu":"Μ","mu":"μ","multimap":"⊸","mumap":"⊸","nabla":"∇","Nacute":"Ń","nacute":"ń","nang":"∠⃒","nap":"≉","napE":"⩰̸","napid":"≋̸","napos":"ŉ","napprox":"≉","natural":"♮","naturals":"ℕ","natur":"♮","nbsp":" ","nbump":"≎̸","nbumpe":"≏̸","ncap":"⩃","Ncaron":"Ň","ncaron":"ň","Ncedil":"Ņ","ncedil":"ņ","ncong":"≇","ncongdot":"⩭̸","ncup":"⩂","Ncy":"Н","ncy":"н","ndash":"–","nearhk":"⤤","nearr":"↗","neArr":"⇗","nearrow":"↗","ne":"≠","nedot":"≐̸","NegativeMediumSpace":"​","NegativeThickSpace":"​","NegativeThinSpace":"​","NegativeVeryThinSpace":"​","nequiv":"≢","nesear":"⤨","nesim":"≂̸","NestedGreaterGreater":"≫","NestedLessLess":"≪","NewLine":"\\n","nexist":"∄","nexists":"∄","Nfr":"𝔑","nfr":"𝔫","ngE":"≧̸","nge":"≱","ngeq":"≱","ngeqq":"≧̸","ngeqslant":"⩾̸","nges":"⩾̸","nGg":"⋙̸","ngsim":"≵","nGt":"≫⃒","ngt":"≯","ngtr":"≯","nGtv":"≫̸","nharr":"↮","nhArr":"⇎","nhpar":"⫲","ni":"∋","nis":"⋼","nisd":"⋺","niv":"∋","NJcy":"Њ","njcy":"њ","nlarr":"↚","nlArr":"⇍","nldr":"‥","nlE":"≦̸","nle":"≰","nleftarrow":"↚","nLeftarrow":"⇍","nleftrightarrow":"↮","nLeftrightarrow":"⇎","nleq":"≰","nleqq":"≦̸","nleqslant":"⩽̸","nles":"⩽̸","nless":"≮","nLl":"⋘̸","nlsim":"≴","nLt":"≪⃒","nlt":"≮","nltri":"⋪","nltrie":"⋬","nLtv":"≪̸","nmid":"∤","NoBreak":"⁠","NonBreakingSpace":" ","nopf":"𝕟","Nopf":"ℕ","Not":"⫬","not":"¬","NotCongruent":"≢","NotCupCap":"≭","NotDoubleVerticalBar":"∦","NotElement":"∉","NotEqual":"≠","NotEqualTilde":"≂̸","NotExists":"∄","NotGreater":"≯","NotGreaterEqual":"≱","NotGreaterFullEqual":"≧̸","NotGreaterGreater":"≫̸","NotGreaterLess":"≹","NotGreaterSlantEqual":"⩾̸","NotGreaterTilde":"≵","NotHumpDownHump":"≎̸","NotHumpEqual":"≏̸","notin":"∉","notindot":"⋵̸","notinE":"⋹̸","notinva":"∉","notinvb":"⋷","notinvc":"⋶","NotLeftTriangleBar":"⧏̸","NotLeftTriangle":"⋪","NotLeftTriangleEqual":"⋬","NotLess":"≮","NotLessEqual":"≰","NotLessGreater":"≸","NotLessLess":"≪̸","NotLessSlantEqual":"⩽̸","NotLessTilde":"≴","NotNestedGreaterGreater":"⪢̸","NotNestedLessLess":"⪡̸","notni":"∌","notniva":"∌","notnivb":"⋾","notnivc":"⋽","NotPrecedes":"⊀","NotPrecedesEqual":"⪯̸","NotPrecedesSlantEqual":"⋠","NotReverseElement":"∌","NotRightTriangleBar":"⧐̸","NotRightTriangle":"⋫","NotRightTriangleEqual":"⋭","NotSquareSubset":"⊏̸","NotSquareSubsetEqual":"⋢","NotSquareSuperset":"⊐̸","NotSquareSupersetEqual":"⋣","NotSubset":"⊂⃒","NotSubsetEqual":"⊈","NotSucceeds":"⊁","NotSucceedsEqual":"⪰̸","NotSucceedsSlantEqual":"⋡","NotSucceedsTilde":"≿̸","NotSuperset":"⊃⃒","NotSupersetEqual":"⊉","NotTilde":"≁","NotTildeEqual":"≄","NotTildeFullEqual":"≇","NotTildeTilde":"≉","NotVerticalBar":"∤","nparallel":"∦","npar":"∦","nparsl":"⫽⃥","npart":"∂̸","npolint":"⨔","npr":"⊀","nprcue":"⋠","nprec":"⊀","npreceq":"⪯̸","npre":"⪯̸","nrarrc":"⤳̸","nrarr":"↛","nrArr":"⇏","nrarrw":"↝̸","nrightarrow":"↛","nRightarrow":"⇏","nrtri":"⋫","nrtrie":"⋭","nsc":"⊁","nsccue":"⋡","nsce":"⪰̸","Nscr":"𝒩","nscr":"𝓃","nshortmid":"∤","nshortparallel":"∦","nsim":"≁","nsime":"≄","nsimeq":"≄","nsmid":"∤","nspar":"∦","nsqsube":"⋢","nsqsupe":"⋣","nsub":"⊄","nsubE":"⫅̸","nsube":"⊈","nsubset":"⊂⃒","nsubseteq":"⊈","nsubseteqq":"⫅̸","nsucc":"⊁","nsucceq":"⪰̸","nsup":"⊅","nsupE":"⫆̸","nsupe":"⊉","nsupset":"⊃⃒","nsupseteq":"⊉","nsupseteqq":"⫆̸","ntgl":"≹","Ntilde":"Ñ","ntilde":"ñ","ntlg":"≸","ntriangleleft":"⋪","ntrianglelefteq":"⋬","ntriangleright":"⋫","ntrianglerighteq":"⋭","Nu":"Ν","nu":"ν","num":"#","numero":"№","numsp":" ","nvap":"≍⃒","nvdash":"⊬","nvDash":"⊭","nVdash":"⊮","nVDash":"⊯","nvge":"≥⃒","nvgt":">⃒","nvHarr":"⤄","nvinfin":"⧞","nvlArr":"⤂","nvle":"≤⃒","nvlt":"<⃒","nvltrie":"⊴⃒","nvrArr":"⤃","nvrtrie":"⊵⃒","nvsim":"∼⃒","nwarhk":"⤣","nwarr":"↖","nwArr":"⇖","nwarrow":"↖","nwnear":"⤧","Oacute":"Ó","oacute":"ó","oast":"⊛","Ocirc":"Ô","ocirc":"ô","ocir":"⊚","Ocy":"О","ocy":"о","odash":"⊝","Odblac":"Ő","odblac":"ő","odiv":"⨸","odot":"⊙","odsold":"⦼","OElig":"Œ","oelig":"œ","ofcir":"⦿","Ofr":"𝔒","ofr":"𝔬","ogon":"˛","Ograve":"Ò","ograve":"ò","ogt":"⧁","ohbar":"⦵","ohm":"Ω","oint":"∮","olarr":"↺","olcir":"⦾","olcross":"⦻","oline":"‾","olt":"⧀","Omacr":"Ō","omacr":"ō","Omega":"Ω","omega":"ω","Omicron":"Ο","omicron":"ο","omid":"⦶","ominus":"⊖","Oopf":"𝕆","oopf":"𝕠","opar":"⦷","OpenCurlyDoubleQuote":"“","OpenCurlyQuote":"‘","operp":"⦹","oplus":"⊕","orarr":"↻","Or":"⩔","or":"∨","ord":"⩝","order":"ℴ","orderof":"ℴ","ordf":"ª","ordm":"º","origof":"⊶","oror":"⩖","orslope":"⩗","orv":"⩛","oS":"Ⓢ","Oscr":"𝒪","oscr":"ℴ","Oslash":"Ø","oslash":"ø","osol":"⊘","Otilde":"Õ","otilde":"õ","otimesas":"⨶","Otimes":"⨷","otimes":"⊗","Ouml":"Ö","ouml":"ö","ovbar":"⌽","OverBar":"‾","OverBrace":"⏞","OverBracket":"⎴","OverParenthesis":"⏜","para":"¶","parallel":"∥","par":"∥","parsim":"⫳","parsl":"⫽","part":"∂","PartialD":"∂","Pcy":"П","pcy":"п","percnt":"%","period":".","permil":"‰","perp":"⊥","pertenk":"‱","Pfr":"𝔓","pfr":"𝔭","Phi":"Φ","phi":"φ","phiv":"ϕ","phmmat":"ℳ","phone":"☎","Pi":"Π","pi":"π","pitchfork":"⋔","piv":"ϖ","planck":"ℏ","planckh":"ℎ","plankv":"ℏ","plusacir":"⨣","plusb":"⊞","pluscir":"⨢","plus":"+","plusdo":"∔","plusdu":"⨥","pluse":"⩲","PlusMinus":"±","plusmn":"±","plussim":"⨦","plustwo":"⨧","pm":"±","Poincareplane":"ℌ","pointint":"⨕","popf":"𝕡","Popf":"ℙ","pound":"£","prap":"⪷","Pr":"⪻","pr":"≺","prcue":"≼","precapprox":"⪷","prec":"≺","preccurlyeq":"≼","Precedes":"≺","PrecedesEqual":"⪯","PrecedesSlantEqual":"≼","PrecedesTilde":"≾","preceq":"⪯","precnapprox":"⪹","precneqq":"⪵","precnsim":"⋨","pre":"⪯","prE":"⪳","precsim":"≾","prime":"′","Prime":"″","primes":"ℙ","prnap":"⪹","prnE":"⪵","prnsim":"⋨","prod":"∏","Product":"∏","profalar":"⌮","profline":"⌒","profsurf":"⌓","prop":"∝","Proportional":"∝","Proportion":"∷","propto":"∝","prsim":"≾","prurel":"⊰","Pscr":"𝒫","pscr":"𝓅","Psi":"Ψ","psi":"ψ","puncsp":" ","Qfr":"𝔔","qfr":"𝔮","qint":"⨌","qopf":"𝕢","Qopf":"ℚ","qprime":"⁗","Qscr":"𝒬","qscr":"𝓆","quaternions":"ℍ","quatint":"⨖","quest":"?","questeq":"≟","quot":"\\"","QUOT":"\\"","rAarr":"⇛","race":"∽̱","Racute":"Ŕ","racute":"ŕ","radic":"√","raemptyv":"⦳","rang":"⟩","Rang":"⟫","rangd":"⦒","range":"⦥","rangle":"⟩","raquo":"»","rarrap":"⥵","rarrb":"⇥","rarrbfs":"⤠","rarrc":"⤳","rarr":"→","Rarr":"↠","rArr":"⇒","rarrfs":"⤞","rarrhk":"↪","rarrlp":"↬","rarrpl":"⥅","rarrsim":"⥴","Rarrtl":"⤖","rarrtl":"↣","rarrw":"↝","ratail":"⤚","rAtail":"⤜","ratio":"∶","rationals":"ℚ","rbarr":"⤍","rBarr":"⤏","RBarr":"⤐","rbbrk":"❳","rbrace":"}","rbrack":"]","rbrke":"⦌","rbrksld":"⦎","rbrkslu":"⦐","Rcaron":"Ř","rcaron":"ř","Rcedil":"Ŗ","rcedil":"ŗ","rceil":"⌉","rcub":"}","Rcy":"Р","rcy":"р","rdca":"⤷","rdldhar":"⥩","rdquo":"”","rdquor":"”","rdsh":"↳","real":"ℜ","realine":"ℛ","realpart":"ℜ","reals":"ℝ","Re":"ℜ","rect":"▭","reg":"®","REG":"®","ReverseElement":"∋","ReverseEquilibrium":"⇋","ReverseUpEquilibrium":"⥯","rfisht":"⥽","rfloor":"⌋","rfr":"𝔯","Rfr":"ℜ","rHar":"⥤","rhard":"⇁","rharu":"⇀","rharul":"⥬","Rho":"Ρ","rho":"ρ","rhov":"ϱ","RightAngleBracket":"⟩","RightArrowBar":"⇥","rightarrow":"→","RightArrow":"→","Rightarrow":"⇒","RightArrowLeftArrow":"⇄","rightarrowtail":"↣","RightCeiling":"⌉","RightDoubleBracket":"⟧","RightDownTeeVector":"⥝","RightDownVectorBar":"⥕","RightDownVector":"⇂","RightFloor":"⌋","rightharpoondown":"⇁","rightharpoonup":"⇀","rightleftarrows":"⇄","rightleftharpoons":"⇌","rightrightarrows":"⇉","rightsquigarrow":"↝","RightTeeArrow":"↦","RightTee":"⊢","RightTeeVector":"⥛","rightthreetimes":"⋌","RightTriangleBar":"⧐","RightTriangle":"⊳","RightTriangleEqual":"⊵","RightUpDownVector":"⥏","RightUpTeeVector":"⥜","RightUpVectorBar":"⥔","RightUpVector":"↾","RightVectorBar":"⥓","RightVector":"⇀","ring":"˚","risingdotseq":"≓","rlarr":"⇄","rlhar":"⇌","rlm":"‏","rmoustache":"⎱","rmoust":"⎱","rnmid":"⫮","roang":"⟭","roarr":"⇾","robrk":"⟧","ropar":"⦆","ropf":"𝕣","Ropf":"ℝ","roplus":"⨮","rotimes":"⨵","RoundImplies":"⥰","rpar":")","rpargt":"⦔","rppolint":"⨒","rrarr":"⇉","Rrightarrow":"⇛","rsaquo":"›","rscr":"𝓇","Rscr":"ℛ","rsh":"↱","Rsh":"↱","rsqb":"]","rsquo":"’","rsquor":"’","rthree":"⋌","rtimes":"⋊","rtri":"▹","rtrie":"⊵","rtrif":"▸","rtriltri":"⧎","RuleDelayed":"⧴","ruluhar":"⥨","rx":"℞","Sacute":"Ś","sacute":"ś","sbquo":"‚","scap":"⪸","Scaron":"Š","scaron":"š","Sc":"⪼","sc":"≻","sccue":"≽","sce":"⪰","scE":"⪴","Scedil":"Ş","scedil":"ş","Scirc":"Ŝ","scirc":"ŝ","scnap":"⪺","scnE":"⪶","scnsim":"⋩","scpolint":"⨓","scsim":"≿","Scy":"С","scy":"с","sdotb":"⊡","sdot":"⋅","sdote":"⩦","searhk":"⤥","searr":"↘","seArr":"⇘","searrow":"↘","sect":"§","semi":";","seswar":"⤩","setminus":"∖","setmn":"∖","sext":"✶","Sfr":"𝔖","sfr":"𝔰","sfrown":"⌢","sharp":"♯","SHCHcy":"Щ","shchcy":"щ","SHcy":"Ш","shcy":"ш","ShortDownArrow":"↓","ShortLeftArrow":"←","shortmid":"∣","shortparallel":"∥","ShortRightArrow":"→","ShortUpArrow":"↑","shy":"­","Sigma":"Σ","sigma":"σ","sigmaf":"ς","sigmav":"ς","sim":"∼","simdot":"⩪","sime":"≃","simeq":"≃","simg":"⪞","simgE":"⪠","siml":"⪝","simlE":"⪟","simne":"≆","simplus":"⨤","simrarr":"⥲","slarr":"←","SmallCircle":"∘","smallsetminus":"∖","smashp":"⨳","smeparsl":"⧤","smid":"∣","smile":"⌣","smt":"⪪","smte":"⪬","smtes":"⪬︀","SOFTcy":"Ь","softcy":"ь","solbar":"⌿","solb":"⧄","sol":"/","Sopf":"𝕊","sopf":"𝕤","spades":"♠","spadesuit":"♠","spar":"∥","sqcap":"⊓","sqcaps":"⊓︀","sqcup":"⊔","sqcups":"⊔︀","Sqrt":"√","sqsub":"⊏","sqsube":"⊑","sqsubset":"⊏","sqsubseteq":"⊑","sqsup":"⊐","sqsupe":"⊒","sqsupset":"⊐","sqsupseteq":"⊒","square":"□","Square":"□","SquareIntersection":"⊓","SquareSubset":"⊏","SquareSubsetEqual":"⊑","SquareSuperset":"⊐","SquareSupersetEqual":"⊒","SquareUnion":"⊔","squarf":"▪","squ":"□","squf":"▪","srarr":"→","Sscr":"𝒮","sscr":"𝓈","ssetmn":"∖","ssmile":"⌣","sstarf":"⋆","Star":"⋆","star":"☆","starf":"★","straightepsilon":"ϵ","straightphi":"ϕ","strns":"¯","sub":"⊂","Sub":"⋐","subdot":"⪽","subE":"⫅","sube":"⊆","subedot":"⫃","submult":"⫁","subnE":"⫋","subne":"⊊","subplus":"⪿","subrarr":"⥹","subset":"⊂","Subset":"⋐","subseteq":"⊆","subseteqq":"⫅","SubsetEqual":"⊆","subsetneq":"⊊","subsetneqq":"⫋","subsim":"⫇","subsub":"⫕","subsup":"⫓","succapprox":"⪸","succ":"≻","succcurlyeq":"≽","Succeeds":"≻","SucceedsEqual":"⪰","SucceedsSlantEqual":"≽","SucceedsTilde":"≿","succeq":"⪰","succnapprox":"⪺","succneqq":"⪶","succnsim":"⋩","succsim":"≿","SuchThat":"∋","sum":"∑","Sum":"∑","sung":"♪","sup1":"¹","sup2":"²","sup3":"³","sup":"⊃","Sup":"⋑","supdot":"⪾","supdsub":"⫘","supE":"⫆","supe":"⊇","supedot":"⫄","Superset":"⊃","SupersetEqual":"⊇","suphsol":"⟉","suphsub":"⫗","suplarr":"⥻","supmult":"⫂","supnE":"⫌","supne":"⊋","supplus":"⫀","supset":"⊃","Supset":"⋑","supseteq":"⊇","supseteqq":"⫆","supsetneq":"⊋","supsetneqq":"⫌","supsim":"⫈","supsub":"⫔","supsup":"⫖","swarhk":"⤦","swarr":"↙","swArr":"⇙","swarrow":"↙","swnwar":"⤪","szlig":"ß","Tab":"\\t","target":"⌖","Tau":"Τ","tau":"τ","tbrk":"⎴","Tcaron":"Ť","tcaron":"ť","Tcedil":"Ţ","tcedil":"ţ","Tcy":"Т","tcy":"т","tdot":"⃛","telrec":"⌕","Tfr":"𝔗","tfr":"𝔱","there4":"∴","therefore":"∴","Therefore":"∴","Theta":"Θ","theta":"θ","thetasym":"ϑ","thetav":"ϑ","thickapprox":"≈","thicksim":"∼","ThickSpace":"  ","ThinSpace":" ","thinsp":" ","thkap":"≈","thksim":"∼","THORN":"Þ","thorn":"þ","tilde":"˜","Tilde":"∼","TildeEqual":"≃","TildeFullEqual":"≅","TildeTilde":"≈","timesbar":"⨱","timesb":"⊠","times":"×","timesd":"⨰","tint":"∭","toea":"⤨","topbot":"⌶","topcir":"⫱","top":"⊤","Topf":"𝕋","topf":"𝕥","topfork":"⫚","tosa":"⤩","tprime":"‴","trade":"™","TRADE":"™","triangle":"▵","triangledown":"▿","triangleleft":"◃","trianglelefteq":"⊴","triangleq":"≜","triangleright":"▹","trianglerighteq":"⊵","tridot":"◬","trie":"≜","triminus":"⨺","TripleDot":"⃛","triplus":"⨹","trisb":"⧍","tritime":"⨻","trpezium":"⏢","Tscr":"𝒯","tscr":"𝓉","TScy":"Ц","tscy":"ц","TSHcy":"Ћ","tshcy":"ћ","Tstrok":"Ŧ","tstrok":"ŧ","twixt":"≬","twoheadleftarrow":"↞","twoheadrightarrow":"↠","Uacute":"Ú","uacute":"ú","uarr":"↑","Uarr":"↟","uArr":"⇑","Uarrocir":"⥉","Ubrcy":"Ў","ubrcy":"ў","Ubreve":"Ŭ","ubreve":"ŭ","Ucirc":"Û","ucirc":"û","Ucy":"У","ucy":"у","udarr":"⇅","Udblac":"Ű","udblac":"ű","udhar":"⥮","ufisht":"⥾","Ufr":"𝔘","ufr":"𝔲","Ugrave":"Ù","ugrave":"ù","uHar":"⥣","uharl":"↿","uharr":"↾","uhblk":"▀","ulcorn":"⌜","ulcorner":"⌜","ulcrop":"⌏","ultri":"◸","Umacr":"Ū","umacr":"ū","uml":"¨","UnderBar":"_","UnderBrace":"⏟","UnderBracket":"⎵","UnderParenthesis":"⏝","Union":"⋃","UnionPlus":"⊎","Uogon":"Ų","uogon":"ų","Uopf":"𝕌","uopf":"𝕦","UpArrowBar":"⤒","uparrow":"↑","UpArrow":"↑","Uparrow":"⇑","UpArrowDownArrow":"⇅","updownarrow":"↕","UpDownArrow":"↕","Updownarrow":"⇕","UpEquilibrium":"⥮","upharpoonleft":"↿","upharpoonright":"↾","uplus":"⊎","UpperLeftArrow":"↖","UpperRightArrow":"↗","upsi":"υ","Upsi":"ϒ","upsih":"ϒ","Upsilon":"Υ","upsilon":"υ","UpTeeArrow":"↥","UpTee":"⊥","upuparrows":"⇈","urcorn":"⌝","urcorner":"⌝","urcrop":"⌎","Uring":"Ů","uring":"ů","urtri":"◹","Uscr":"𝒰","uscr":"𝓊","utdot":"⋰","Utilde":"Ũ","utilde":"ũ","utri":"▵","utrif":"▴","uuarr":"⇈","Uuml":"Ü","uuml":"ü","uwangle":"⦧","vangrt":"⦜","varepsilon":"ϵ","varkappa":"ϰ","varnothing":"∅","varphi":"ϕ","varpi":"ϖ","varpropto":"∝","varr":"↕","vArr":"⇕","varrho":"ϱ","varsigma":"ς","varsubsetneq":"⊊︀","varsubsetneqq":"⫋︀","varsupsetneq":"⊋︀","varsupsetneqq":"⫌︀","vartheta":"ϑ","vartriangleleft":"⊲","vartriangleright":"⊳","vBar":"⫨","Vbar":"⫫","vBarv":"⫩","Vcy":"В","vcy":"в","vdash":"⊢","vDash":"⊨","Vdash":"⊩","VDash":"⊫","Vdashl":"⫦","veebar":"⊻","vee":"∨","Vee":"⋁","veeeq":"≚","vellip":"⋮","verbar":"|","Verbar":"‖","vert":"|","Vert":"‖","VerticalBar":"∣","VerticalLine":"|","VerticalSeparator":"❘","VerticalTilde":"≀","VeryThinSpace":" ","Vfr":"𝔙","vfr":"𝔳","vltri":"⊲","vnsub":"⊂⃒","vnsup":"⊃⃒","Vopf":"𝕍","vopf":"𝕧","vprop":"∝","vrtri":"⊳","Vscr":"𝒱","vscr":"𝓋","vsubnE":"⫋︀","vsubne":"⊊︀","vsupnE":"⫌︀","vsupne":"⊋︀","Vvdash":"⊪","vzigzag":"⦚","Wcirc":"Ŵ","wcirc":"ŵ","wedbar":"⩟","wedge":"∧","Wedge":"⋀","wedgeq":"≙","weierp":"℘","Wfr":"𝔚","wfr":"𝔴","Wopf":"𝕎","wopf":"𝕨","wp":"℘","wr":"≀","wreath":"≀","Wscr":"𝒲","wscr":"𝓌","xcap":"⋂","xcirc":"◯","xcup":"⋃","xdtri":"▽","Xfr":"𝔛","xfr":"𝔵","xharr":"⟷","xhArr":"⟺","Xi":"Ξ","xi":"ξ","xlarr":"⟵","xlArr":"⟸","xmap":"⟼","xnis":"⋻","xodot":"⨀","Xopf":"𝕏","xopf":"𝕩","xoplus":"⨁","xotime":"⨂","xrarr":"⟶","xrArr":"⟹","Xscr":"𝒳","xscr":"𝓍","xsqcup":"⨆","xuplus":"⨄","xutri":"△","xvee":"⋁","xwedge":"⋀","Yacute":"Ý","yacute":"ý","YAcy":"Я","yacy":"я","Ycirc":"Ŷ","ycirc":"ŷ","Ycy":"Ы","ycy":"ы","yen":"¥","Yfr":"𝔜","yfr":"𝔶","YIcy":"Ї","yicy":"ї","Yopf":"𝕐","yopf":"𝕪","Yscr":"𝒴","yscr":"𝓎","YUcy":"Ю","yucy":"ю","yuml":"ÿ","Yuml":"Ÿ","Zacute":"Ź","zacute":"ź","Zcaron":"Ž","zcaron":"ž","Zcy":"З","zcy":"з","Zdot":"Ż","zdot":"ż","zeetrf":"ℨ","ZeroWidthSpace":"​","Zeta":"Ζ","zeta":"ζ","zfr":"𝔷","Zfr":"ℨ","ZHcy":"Ж","zhcy":"ж","zigrarr":"⇝","zopf":"𝕫","Zopf":"ℤ","Zscr":"𝒵","zscr":"𝓏","zwj":"‍","zwnj":"‌"}')},function(e){e.exports=JSON.parse('{"amp":"&","apos":"\'","gt":">","lt":"<","quot":"\\""}')},function(e,t,n){"use strict";let r=n(660),i=n(367);class o extends Error{constructor(e,t,n,r,i,a){super(e),this.name="CssSyntaxError",this.reason=e,i&&(this.file=i),r&&(this.source=r),a&&(this.plugin=a),void 0!==t&&void 0!==n&&("number"==typeof t?(this.line=t,this.column=n):(this.line=t.line,this.column=t.column,this.endLine=n.line,this.endColumn=n.column)),this.setMessage(),Error.captureStackTrace&&Error.captureStackTrace(this,o)}setMessage(){this.message=this.plugin?this.plugin+": ":"",this.message+=this.file?this.file:"<css input>",void 0!==this.line&&(this.message+=":"+this.line+":"+this.column),this.message+=": "+this.reason}showSourceCode(e){if(!this.source)return"";let t=this.source;null==e&&(e=r.isColorSupported),i&&e&&(t=i(t));let n,o,a=t.split(/\r?\n/),s=Math.max(this.line-3,0),l=Math.min(this.line+2,a.length),c=String(l).length;if(e){let{bold:e,red:t,gray:i}=r.createColors(!0);n=n=>e(t(n)),o=e=>i(e)}else n=o=e=>e;return a.slice(s,l).map((e,t)=>{let r=s+1+t,i=" "+(" "+r).slice(-c)+" | ";if(r===this.line){let t=o(i.replace(/\d/g," "))+e.slice(0,this.column-1).replace(/[^\t]/g," ");return n(">")+o(i)+e+"\n "+t+n("^")}return" "+o(i)+e}).join("\n")}toString(){let e=this.showSourceCode();return e&&(e="\n\n"+e+"\n"),this.name+": "+this.message+e}}e.exports=o,o.default=o},function(e,t,n){"use strict";e.exports.isClean=Symbol("isClean"),e.exports.my=Symbol("my")},function(e,t,n){"use strict";(function(e){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <http://feross.org>
 * @license  MIT
 */
var r=n(143),i=n(661),o=n(662);function a(){return l.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function s(e,t){if(a()<t)throw new RangeError("Invalid typed array length");return l.TYPED_ARRAY_SUPPORT?(e=new Uint8Array(t)).__proto__=l.prototype:(null===e&&(e=new l(t)),e.length=t),e}function l(e,t,n){if(!(l.TYPED_ARRAY_SUPPORT||this instanceof l))return new l(e,t,n);if("number"==typeof e){if("string"==typeof t)throw new Error("If encoding is specified then the first argument must be a string");return d(this,e)}return c(this,e,t,n)}function c(e,t,n,r){if("number"==typeof t)throw new TypeError('"value" argument must not be a number');return"undefined"!=typeof ArrayBuffer&&t instanceof ArrayBuffer?function(e,t,n,r){if(t.byteLength,n<0||t.byteLength<n)throw new RangeError("'offset' is out of bounds");if(t.byteLength<n+(r||0))throw new RangeError("'length' is out of bounds");t=void 0===n&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,n):new Uint8Array(t,n,r);l.TYPED_ARRAY_SUPPORT?(e=t).__proto__=l.prototype:e=h(e,t);return e}(e,t,n,r):"string"==typeof t?function(e,t,n){"string"==typeof n&&""!==n||(n="utf8");if(!l.isEncoding(n))throw new TypeError('"encoding" must be a valid string encoding');var r=0|f(t,n),i=(e=s(e,r)).write(t,n);i!==r&&(e=e.slice(0,i));return e}(e,t,n):function(e,t){if(l.isBuffer(t)){var n=0|p(t.length);return 0===(e=s(e,n)).length||t.copy(e,0,0,n),e}if(t){if("undefined"!=typeof ArrayBuffer&&t.buffer instanceof ArrayBuffer||"length"in t)return"number"!=typeof t.length||(r=t.length)!=r?s(e,0):h(e,t);if("Buffer"===t.type&&o(t.data))return h(e,t.data)}var r;throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}(e,t)}function u(e){if("number"!=typeof e)throw new TypeError('"size" argument must be a number');if(e<0)throw new RangeError('"size" argument must not be negative')}function d(e,t){if(u(t),e=s(e,t<0?0:0|p(t)),!l.TYPED_ARRAY_SUPPORT)for(var n=0;n<t;++n)e[n]=0;return e}function h(e,t){var n=t.length<0?0:0|p(t.length);e=s(e,n);for(var r=0;r<n;r+=1)e[r]=255&t[r];return e}function p(e){if(e>=a())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+a().toString(16)+" bytes");return 0|e}function f(e,t){if(l.isBuffer(e))return e.length;if("undefined"!=typeof ArrayBuffer&&"function"==typeof ArrayBuffer.isView&&(ArrayBuffer.isView(e)||e instanceof ArrayBuffer))return e.byteLength;"string"!=typeof e&&(e=""+e);var n=e.length;if(0===n)return 0;for(var r=!1;;)switch(t){case"ascii":case"latin1":case"binary":return n;case"utf8":case"utf-8":case void 0:return H(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*n;case"hex":return n>>>1;case"base64":return F(e).length;default:if(r)return H(e).length;t=(""+t).toLowerCase(),r=!0}}function m(e,t,n){var r=!1;if((void 0===t||t<0)&&(t=0),t>this.length)return"";if((void 0===n||n>this.length)&&(n=this.length),n<=0)return"";if((n>>>=0)<=(t>>>=0))return"";for(e||(e="utf8");;)switch(e){case"hex":return T(this,t,n);case"utf8":case"utf-8":return E(this,t,n);case"ascii":return L(this,t,n);case"latin1":case"binary":return S(this,t,n);case"base64":return x(this,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return O(this,t,n);default:if(r)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),r=!0}}function g(e,t,n){var r=e[t];e[t]=e[n],e[n]=r}function v(e,t,n,r,i){if(0===e.length)return-1;if("string"==typeof n?(r=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),n=+n,isNaN(n)&&(n=i?0:e.length-1),n<0&&(n=e.length+n),n>=e.length){if(i)return-1;n=e.length-1}else if(n<0){if(!i)return-1;n=0}if("string"==typeof t&&(t=l.from(t,r)),l.isBuffer(t))return 0===t.length?-1:y(e,t,n,r,i);if("number"==typeof t)return t&=255,l.TYPED_ARRAY_SUPPORT&&"function"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(e,t,n):Uint8Array.prototype.lastIndexOf.call(e,t,n):y(e,[t],n,r,i);throw new TypeError("val must be string, number or Buffer")}function y(e,t,n,r,i){var o,a=1,s=e.length,l=t.length;if(void 0!==r&&("ucs2"===(r=String(r).toLowerCase())||"ucs-2"===r||"utf16le"===r||"utf-16le"===r)){if(e.length<2||t.length<2)return-1;a=2,s/=2,l/=2,n/=2}function c(e,t){return 1===a?e[t]:e.readUInt16BE(t*a)}if(i){var u=-1;for(o=n;o<s;o++)if(c(e,o)===c(t,-1===u?0:o-u)){if(-1===u&&(u=o),o-u+1===l)return u*a}else-1!==u&&(o-=o-u),u=-1}else for(n+l>s&&(n=s-l),o=n;o>=0;o--){for(var d=!0,h=0;h<l;h++)if(c(e,o+h)!==c(t,h)){d=!1;break}if(d)return o}return-1}function _(e,t,n,r){n=Number(n)||0;var i=e.length-n;r?(r=Number(r))>i&&(r=i):r=i;var o=t.length;if(o%2!=0)throw new TypeError("Invalid hex string");r>o/2&&(r=o/2);for(var a=0;a<r;++a){var s=parseInt(t.substr(2*a,2),16);if(isNaN(s))return a;e[n+a]=s}return a}function b(e,t,n,r){return Y(H(t,e.length-n),e,n,r)}function M(e,t,n,r){return Y(function(e){for(var t=[],n=0;n<e.length;++n)t.push(255&e.charCodeAt(n));return t}(t),e,n,r)}function w(e,t,n,r){return M(e,t,n,r)}function A(e,t,n,r){return Y(F(t),e,n,r)}function C(e,t,n,r){return Y(function(e,t){for(var n,r,i,o=[],a=0;a<e.length&&!((t-=2)<0);++a)n=e.charCodeAt(a),r=n>>8,i=n%256,o.push(i),o.push(r);return o}(t,e.length-n),e,n,r)}function x(e,t,n){return 0===t&&n===e.length?r.fromByteArray(e):r.fromByteArray(e.slice(t,n))}function E(e,t,n){n=Math.min(e.length,n);for(var r=[],i=t;i<n;){var o,a,s,l,c=e[i],u=null,d=c>239?4:c>223?3:c>191?2:1;if(i+d<=n)switch(d){case 1:c<128&&(u=c);break;case 2:128==(192&(o=e[i+1]))&&(l=(31&c)<<6|63&o)>127&&(u=l);break;case 3:o=e[i+1],a=e[i+2],128==(192&o)&&128==(192&a)&&(l=(15&c)<<12|(63&o)<<6|63&a)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:o=e[i+1],a=e[i+2],s=e[i+3],128==(192&o)&&128==(192&a)&&128==(192&s)&&(l=(15&c)<<18|(63&o)<<12|(63&a)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,d=1):u>65535&&(u-=65536,r.push(u>>>10&1023|55296),u=56320|1023&u),r.push(u),i+=d}return function(e){var t=e.length;if(t<=4096)return String.fromCharCode.apply(String,e);var n="",r=0;for(;r<t;)n+=String.fromCharCode.apply(String,e.slice(r,r+=4096));return n}(r)}t.Buffer=l,t.SlowBuffer=function(e){+e!=e&&(e=0);return l.alloc(+e)},t.INSPECT_MAX_BYTES=50,l.TYPED_ARRAY_SUPPORT=void 0!==e.TYPED_ARRAY_SUPPORT?e.TYPED_ARRAY_SUPPORT:function(){try{var e=new Uint8Array(1);return e.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===e.foo()&&"function"==typeof e.subarray&&0===e.subarray(1,1).byteLength}catch(e){return!1}}(),t.kMaxLength=a(),l.poolSize=8192,l._augment=function(e){return e.__proto__=l.prototype,e},l.from=function(e,t,n){return c(null,e,t,n)},l.TYPED_ARRAY_SUPPORT&&(l.prototype.__proto__=Uint8Array.prototype,l.__proto__=Uint8Array,"undefined"!=typeof Symbol&&Symbol.species&&l[Symbol.species]===l&&Object.defineProperty(l,Symbol.species,{value:null,configurable:!0})),l.alloc=function(e,t,n){return function(e,t,n,r){return u(t),t<=0?s(e,t):void 0!==n?"string"==typeof r?s(e,t).fill(n,r):s(e,t).fill(n):s(e,t)}(null,e,t,n)},l.allocUnsafe=function(e){return d(null,e)},l.allocUnsafeSlow=function(e){return d(null,e)},l.isBuffer=function(e){return!(null==e||!e._isBuffer)},l.compare=function(e,t){if(!l.isBuffer(e)||!l.isBuffer(t))throw new TypeError("Arguments must be Buffers");if(e===t)return 0;for(var n=e.length,r=t.length,i=0,o=Math.min(n,r);i<o;++i)if(e[i]!==t[i]){n=e[i],r=t[i];break}return n<r?-1:r<n?1:0},l.isEncoding=function(e){switch(String(e).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},l.concat=function(e,t){if(!o(e))throw new TypeError('"list" argument must be an Array of Buffers');if(0===e.length)return l.alloc(0);var n;if(void 0===t)for(t=0,n=0;n<e.length;++n)t+=e[n].length;var r=l.allocUnsafe(t),i=0;for(n=0;n<e.length;++n){var a=e[n];if(!l.isBuffer(a))throw new TypeError('"list" argument must be an Array of Buffers');a.copy(r,i),i+=a.length}return r},l.byteLength=f,l.prototype._isBuffer=!0,l.prototype.swap16=function(){var e=this.length;if(e%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var t=0;t<e;t+=2)g(this,t,t+1);return this},l.prototype.swap32=function(){var e=this.length;if(e%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var t=0;t<e;t+=4)g(this,t,t+3),g(this,t+1,t+2);return this},l.prototype.swap64=function(){var e=this.length;if(e%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var t=0;t<e;t+=8)g(this,t,t+7),g(this,t+1,t+6),g(this,t+2,t+5),g(this,t+3,t+4);return this},l.prototype.toString=function(){var e=0|this.length;return 0===e?"":0===arguments.length?E(this,0,e):m.apply(this,arguments)},l.prototype.equals=function(e){if(!l.isBuffer(e))throw new TypeError("Argument must be a Buffer");return this===e||0===l.compare(this,e)},l.prototype.inspect=function(){var e="",n=t.INSPECT_MAX_BYTES;return this.length>0&&(e=this.toString("hex",0,n).match(/.{2}/g).join(" "),this.length>n&&(e+=" ... ")),"<Buffer "+e+">"},l.prototype.compare=function(e,t,n,r,i){if(!l.isBuffer(e))throw new TypeError("Argument must be a Buffer");if(void 0===t&&(t=0),void 0===n&&(n=e?e.length:0),void 0===r&&(r=0),void 0===i&&(i=this.length),t<0||n>e.length||r<0||i>this.length)throw new RangeError("out of range index");if(r>=i&&t>=n)return 0;if(r>=i)return-1;if(t>=n)return 1;if(this===e)return 0;for(var o=(i>>>=0)-(r>>>=0),a=(n>>>=0)-(t>>>=0),s=Math.min(o,a),c=this.slice(r,i),u=e.slice(t,n),d=0;d<s;++d)if(c[d]!==u[d]){o=c[d],a=u[d];break}return o<a?-1:a<o?1:0},l.prototype.includes=function(e,t,n){return-1!==this.indexOf(e,t,n)},l.prototype.indexOf=function(e,t,n){return v(this,e,t,n,!0)},l.prototype.lastIndexOf=function(e,t,n){return v(this,e,t,n,!1)},l.prototype.write=function(e,t,n,r){if(void 0===t)r="utf8",n=this.length,t=0;else if(void 0===n&&"string"==typeof t)r=t,n=this.length,t=0;else{if(!isFinite(t))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");t|=0,isFinite(n)?(n|=0,void 0===r&&(r="utf8")):(r=n,n=void 0)}var i=this.length-t;if((void 0===n||n>i)&&(n=i),e.length>0&&(n<0||t<0)||t>this.length)throw new RangeError("Attempt to write outside buffer bounds");r||(r="utf8");for(var o=!1;;)switch(r){case"hex":return _(this,e,t,n);case"utf8":case"utf-8":return b(this,e,t,n);case"ascii":return M(this,e,t,n);case"latin1":case"binary":return w(this,e,t,n);case"base64":return A(this,e,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return C(this,e,t,n);default:if(o)throw new TypeError("Unknown encoding: "+r);r=(""+r).toLowerCase(),o=!0}},l.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};function L(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;i<n;++i)r+=String.fromCharCode(127&e[i]);return r}function S(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;i<n;++i)r+=String.fromCharCode(e[i]);return r}function T(e,t,n){var r=e.length;(!t||t<0)&&(t=0),(!n||n<0||n>r)&&(n=r);for(var i="",o=t;o<n;++o)i+=B(e[o]);return i}function O(e,t,n){for(var r=e.slice(t,n),i="",o=0;o<r.length;o+=2)i+=String.fromCharCode(r[o]+256*r[o+1]);return i}function I(e,t,n){if(e%1!=0||e<0)throw new RangeError("offset is not uint");if(e+t>n)throw new RangeError("Trying to access beyond buffer length")}function k(e,t,n,r,i,o){if(!l.isBuffer(e))throw new TypeError('"buffer" argument must be a Buffer instance');if(t>i||t<o)throw new RangeError('"value" argument is out of bounds');if(n+r>e.length)throw new RangeError("Index out of range")}function D(e,t,n,r){t<0&&(t=65535+t+1);for(var i=0,o=Math.min(e.length-n,2);i<o;++i)e[n+i]=(t&255<<8*(r?i:1-i))>>>8*(r?i:1-i)}function N(e,t,n,r){t<0&&(t=4294967295+t+1);for(var i=0,o=Math.min(e.length-n,4);i<o;++i)e[n+i]=t>>>8*(r?i:3-i)&255}function j(e,t,n,r,i,o){if(n+r>e.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("Index out of range")}function P(e,t,n,r,o){return o||j(e,0,n,4),i.write(e,t,n,r,23,4),n+4}function z(e,t,n,r,o){return o||j(e,0,n,8),i.write(e,t,n,r,52,8),n+8}l.prototype.slice=function(e,t){var n,r=this.length;if((e=~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),(t=void 0===t?r:~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),t<e&&(t=e),l.TYPED_ARRAY_SUPPORT)(n=this.subarray(e,t)).__proto__=l.prototype;else{var i=t-e;n=new l(i,void 0);for(var o=0;o<i;++o)n[o]=this[o+e]}return n},l.prototype.readUIntLE=function(e,t,n){e|=0,t|=0,n||I(e,t,this.length);for(var r=this[e],i=1,o=0;++o<t&&(i*=256);)r+=this[e+o]*i;return r},l.prototype.readUIntBE=function(e,t,n){e|=0,t|=0,n||I(e,t,this.length);for(var r=this[e+--t],i=1;t>0&&(i*=256);)r+=this[e+--t]*i;return r},l.prototype.readUInt8=function(e,t){return t||I(e,1,this.length),this[e]},l.prototype.readUInt16LE=function(e,t){return t||I(e,2,this.length),this[e]|this[e+1]<<8},l.prototype.readUInt16BE=function(e,t){return t||I(e,2,this.length),this[e]<<8|this[e+1]},l.prototype.readUInt32LE=function(e,t){return t||I(e,4,this.length),(this[e]|this[e+1]<<8|this[e+2]<<16)+16777216*this[e+3]},l.prototype.readUInt32BE=function(e,t){return t||I(e,4,this.length),16777216*this[e]+(this[e+1]<<16|this[e+2]<<8|this[e+3])},l.prototype.readIntLE=function(e,t,n){e|=0,t|=0,n||I(e,t,this.length);for(var r=this[e],i=1,o=0;++o<t&&(i*=256);)r+=this[e+o]*i;return r>=(i*=128)&&(r-=Math.pow(2,8*t)),r},l.prototype.readIntBE=function(e,t,n){e|=0,t|=0,n||I(e,t,this.length);for(var r=t,i=1,o=this[e+--r];r>0&&(i*=256);)o+=this[e+--r]*i;return o>=(i*=128)&&(o-=Math.pow(2,8*t)),o},l.prototype.readInt8=function(e,t){return t||I(e,1,this.length),128&this[e]?-1*(255-this[e]+1):this[e]},l.prototype.readInt16LE=function(e,t){t||I(e,2,this.length);var n=this[e]|this[e+1]<<8;return 32768&n?4294901760|n:n},l.prototype.readInt16BE=function(e,t){t||I(e,2,this.length);var n=this[e+1]|this[e]<<8;return 32768&n?4294901760|n:n},l.prototype.readInt32LE=function(e,t){return t||I(e,4,this.length),this[e]|this[e+1]<<8|this[e+2]<<16|this[e+3]<<24},l.prototype.readInt32BE=function(e,t){return t||I(e,4,this.length),this[e]<<24|this[e+1]<<16|this[e+2]<<8|this[e+3]},l.prototype.readFloatLE=function(e,t){return t||I(e,4,this.length),i.read(this,e,!0,23,4)},l.prototype.readFloatBE=function(e,t){return t||I(e,4,this.length),i.read(this,e,!1,23,4)},l.prototype.readDoubleLE=function(e,t){return t||I(e,8,this.length),i.read(this,e,!0,52,8)},l.prototype.readDoubleBE=function(e,t){return t||I(e,8,this.length),i.read(this,e,!1,52,8)},l.prototype.writeUIntLE=function(e,t,n,r){(e=+e,t|=0,n|=0,r)||k(this,e,t,n,Math.pow(2,8*n)-1,0);var i=1,o=0;for(this[t]=255&e;++o<n&&(i*=256);)this[t+o]=e/i&255;return t+n},l.prototype.writeUIntBE=function(e,t,n,r){(e=+e,t|=0,n|=0,r)||k(this,e,t,n,Math.pow(2,8*n)-1,0);var i=n-1,o=1;for(this[t+i]=255&e;--i>=0&&(o*=256);)this[t+i]=e/o&255;return t+n},l.prototype.writeUInt8=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,1,255,0),l.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),this[t]=255&e,t+1},l.prototype.writeUInt16LE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,2,65535,0),l.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):D(this,e,t,!0),t+2},l.prototype.writeUInt16BE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,2,65535,0),l.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):D(this,e,t,!1),t+2},l.prototype.writeUInt32LE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,4,4294967295,0),l.TYPED_ARRAY_SUPPORT?(this[t+3]=e>>>24,this[t+2]=e>>>16,this[t+1]=e>>>8,this[t]=255&e):N(this,e,t,!0),t+4},l.prototype.writeUInt32BE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,4,4294967295,0),l.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):N(this,e,t,!1),t+4},l.prototype.writeIntLE=function(e,t,n,r){if(e=+e,t|=0,!r){var i=Math.pow(2,8*n-1);k(this,e,t,n,i-1,-i)}var o=0,a=1,s=0;for(this[t]=255&e;++o<n&&(a*=256);)e<0&&0===s&&0!==this[t+o-1]&&(s=1),this[t+o]=(e/a>>0)-s&255;return t+n},l.prototype.writeIntBE=function(e,t,n,r){if(e=+e,t|=0,!r){var i=Math.pow(2,8*n-1);k(this,e,t,n,i-1,-i)}var o=n-1,a=1,s=0;for(this[t+o]=255&e;--o>=0&&(a*=256);)e<0&&0===s&&0!==this[t+o+1]&&(s=1),this[t+o]=(e/a>>0)-s&255;return t+n},l.prototype.writeInt8=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,1,127,-128),l.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),e<0&&(e=255+e+1),this[t]=255&e,t+1},l.prototype.writeInt16LE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,2,32767,-32768),l.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):D(this,e,t,!0),t+2},l.prototype.writeInt16BE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,2,32767,-32768),l.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):D(this,e,t,!1),t+2},l.prototype.writeInt32LE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,4,2147483647,-2147483648),l.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8,this[t+2]=e>>>16,this[t+3]=e>>>24):N(this,e,t,!0),t+4},l.prototype.writeInt32BE=function(e,t,n){return e=+e,t|=0,n||k(this,e,t,4,2147483647,-2147483648),e<0&&(e=4294967295+e+1),l.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):N(this,e,t,!1),t+4},l.prototype.writeFloatLE=function(e,t,n){return P(this,e,t,!0,n)},l.prototype.writeFloatBE=function(e,t,n){return P(this,e,t,!1,n)},l.prototype.writeDoubleLE=function(e,t,n){return z(this,e,t,!0,n)},l.prototype.writeDoubleBE=function(e,t,n){return z(this,e,t,!1,n)},l.prototype.copy=function(e,t,n,r){if(n||(n=0),r||0===r||(r=this.length),t>=e.length&&(t=e.length),t||(t=0),r>0&&r<n&&(r=n),r===n)return 0;if(0===e.length||0===this.length)return 0;if(t<0)throw new RangeError("targetStart out of bounds");if(n<0||n>=this.length)throw new RangeError("sourceStart out of bounds");if(r<0)throw new RangeError("sourceEnd out of bounds");r>this.length&&(r=this.length),e.length-t<r-n&&(r=e.length-t+n);var i,o=r-n;if(this===e&&n<t&&t<r)for(i=o-1;i>=0;--i)e[i+t]=this[i+n];else if(o<1e3||!l.TYPED_ARRAY_SUPPORT)for(i=0;i<o;++i)e[i+t]=this[i+n];else Uint8Array.prototype.set.call(e,this.subarray(n,n+o),t);return o},l.prototype.fill=function(e,t,n,r){if("string"==typeof e){if("string"==typeof t?(r=t,t=0,n=this.length):"string"==typeof n&&(r=n,n=this.length),1===e.length){var i=e.charCodeAt(0);i<256&&(e=i)}if(void 0!==r&&"string"!=typeof r)throw new TypeError("encoding must be a string");if("string"==typeof r&&!l.isEncoding(r))throw new TypeError("Unknown encoding: "+r)}else"number"==typeof e&&(e&=255);if(t<0||this.length<t||this.length<n)throw new RangeError("Out of range index");if(n<=t)return this;var o;if(t>>>=0,n=void 0===n?this.length:n>>>0,e||(e=0),"number"==typeof e)for(o=t;o<n;++o)this[o]=e;else{var a=l.isBuffer(e)?e:H(new l(e,r).toString()),s=a.length;for(o=0;o<n-t;++o)this[o+t]=a[o%s]}return this};var R=/[^+\/0-9A-Za-z-_]/g;function B(e){return e<16?"0"+e.toString(16):e.toString(16)}function H(e,t){var n;t=t||1/0;for(var r=e.length,i=null,o=[],a=0;a<r;++a){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){if(n>56319){(t-=3)>-1&&o.push(239,191,189);continue}if(a+1===r){(t-=3)>-1&&o.push(239,191,189);continue}i=n;continue}if(n<56320){(t-=3)>-1&&o.push(239,191,189),i=n;continue}n=65536+(i-55296<<10|n-56320)}else i&&(t-=3)>-1&&o.push(239,191,189);if(i=null,n<128){if((t-=1)<0)break;o.push(n)}else if(n<2048){if((t-=2)<0)break;o.push(n>>6|192,63&n|128)}else if(n<65536){if((t-=3)<0)break;o.push(n>>12|224,n>>6&63|128,63&n|128)}else{if(!(n<1114112))throw new Error("Invalid code point");if((t-=4)<0)break;o.push(n>>18|240,n>>12&63|128,n>>6&63|128,63&n|128)}}return o}function F(e){return r.toByteArray(function(e){if((e=function(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}(e).replace(R,"")).length<2)return"";for(;e.length%4!=0;)e+="=";return e}(e))}function Y(e,t,n,r){for(var i=0;i<r&&!(i+n>=t.length||i>=e.length);++i)t[i+n]=e[i];return i}}).call(this,n(55))},function(e,t){},function(e,t){},function(e,t,n){"use strict";let r,i,o=n(83);class a extends o{constructor(e){super({type:"document",...e}),this.nodes||(this.nodes=[])}toResult(e={}){return new r(new i,this,e).stringify()}}a.registerLazyResult=e=>{r=e},a.registerProcessor=e=>{i=e},e.exports=a,a.default=a},function(e,t,n){"use strict";let r=n(374);class i{constructor(e,t,n){this.processor=e,this.messages=[],this.root=t,this.opts=n,this.css=void 0,this.map=void 0}toString(){return this.css}warn(e,t={}){t.plugin||this.lastPlugin&&this.lastPlugin.postcssPlugin&&(t.plugin=this.lastPlugin.postcssPlugin);let n=new r(e,t);return this.messages.push(n),n}warnings(){return this.messages.filter(e=>"warning"===e.type)}get content(){return this.css}}e.exports=i,i.default=i},function(e,t,n){"use strict";let r=n(83),i=n(665),o=n(126);function a(e,t){let n=new o(e,t),r=new i(n);try{r.parse()}catch(e){throw e}return r.root}e.exports=a,a.default=a,r.registerParse(a)},function(e,t,n){"use strict";let r=n(83);class i extends r{constructor(e){super(e),this.type="atrule"}append(...e){return this.proxyOf.nodes||(this.nodes=[]),super.append(...e)}prepend(...e){return this.proxyOf.nodes||(this.nodes=[]),super.prepend(...e)}}e.exports=i,i.default=i,r.registerAtRule(i)},function(e,t,n){"use strict";let r=n(83),i=n(375);class o extends r{constructor(e){super(e),this.type="rule",this.nodes||(this.nodes=[])}get selectors(){return i.comma(this.selector)}set selectors(e){let t=this.selector?this.selector.match(/,\s*/):null,n=t?t[0]:","+this.raw("between","beforeOpen");this.selector=e.join(n)}}e.exports=o,o.default=o,r.registerRule(o)},function(e,t,n){!function(e){"use strict";var t,n,r=e.Pos;function i(e,t){for(var n=function(e){var t=e.flags;return null!=t?t:(e.ignoreCase?"i":"")+(e.global?"g":"")+(e.multiline?"m":"")}(e),r=n,i=0;i<t.length;i++)-1==r.indexOf(t.charAt(i))&&(r+=t.charAt(i));return n==r?e:new RegExp(e.source,r)}function o(e){return/\\s|\\n|\n|\\W|\\D|\[\^/.test(e.source)}function a(e,t,n){t=i(t,"g");for(var o=n.line,a=n.ch,s=e.lastLine();o<=s;o++,a=0){t.lastIndex=a;var l=e.getLine(o),c=t.exec(l);if(c)return{from:r(o,c.index),to:r(o,c.index+c[0].length),match:c}}}function s(e,t,n){if(!o(t))return a(e,t,n);t=i(t,"gm");for(var s,l=1,c=n.line,u=e.lastLine();c<=u;){for(var d=0;d<l&&!(c>u);d++){var h=e.getLine(c++);s=null==s?h:s+"\n"+h}l*=2,t.lastIndex=n.ch;var p=t.exec(s);if(p){var f=s.slice(0,p.index).split("\n"),m=p[0].split("\n"),g=n.line+f.length-1,v=f[f.length-1].length;return{from:r(g,v),to:r(g+m.length-1,1==m.length?v+m[0].length:m[m.length-1].length),match:p}}}}function l(e,t,n){for(var r,i=0;i<=e.length;){t.lastIndex=i;var o=t.exec(e);if(!o)break;var a=o.index+o[0].length;if(a>e.length-n)break;(!r||a>r.index+r[0].length)&&(r=o),i=o.index+1}return r}function c(e,t,n){t=i(t,"g");for(var o=n.line,a=n.ch,s=e.firstLine();o>=s;o--,a=-1){var c=e.getLine(o),u=l(c,t,a<0?0:c.length-a);if(u)return{from:r(o,u.index),to:r(o,u.index+u[0].length),match:u}}}function u(e,t,n){if(!o(t))return c(e,t,n);t=i(t,"gm");for(var a,s=1,u=e.getLine(n.line).length-n.ch,d=n.line,h=e.firstLine();d>=h;){for(var p=0;p<s&&d>=h;p++){var f=e.getLine(d--);a=null==a?f:f+"\n"+a}s*=2;var m=l(a,t,u);if(m){var g=a.slice(0,m.index).split("\n"),v=m[0].split("\n"),y=d+g.length,_=g[g.length-1].length;return{from:r(y,_),to:r(y+v.length-1,1==v.length?_+v[0].length:v[v.length-1].length),match:m}}}}function d(e,t,n,r){if(e.length==t.length)return n;for(var i=0,o=n+Math.max(0,e.length-t.length);;){if(i==o)return i;var a=i+o>>1,s=r(e.slice(0,a)).length;if(s==n)return a;s>n?o=a:i=a+1}}function h(e,i,o,a){if(!i.length)return null;var s=a?t:n,l=s(i).split(/\r|\n\r?/);e:for(var c=o.line,u=o.ch,h=e.lastLine()+1-l.length;c<=h;c++,u=0){var p=e.getLine(c).slice(u),f=s(p);if(1==l.length){var m=f.indexOf(l[0]);if(-1==m)continue e;return o=d(p,f,m,s)+u,{from:r(c,d(p,f,m,s)+u),to:r(c,d(p,f,m+l[0].length,s)+u)}}var g=f.length-l[0].length;if(f.slice(g)==l[0]){for(var v=1;v<l.length-1;v++)if(s(e.getLine(c+v))!=l[v])continue e;var y=e.getLine(c+l.length-1),_=s(y),b=l[l.length-1];if(_.slice(0,b.length)==b)return{from:r(c,d(p,f,g,s)+u),to:r(c+l.length-1,d(y,_,b.length,s))}}}}function p(e,i,o,a){if(!i.length)return null;var s=a?t:n,l=s(i).split(/\r|\n\r?/);e:for(var c=o.line,u=o.ch,h=e.firstLine()-1+l.length;c>=h;c--,u=-1){var p=e.getLine(c);u>-1&&(p=p.slice(0,u));var f=s(p);if(1==l.length){var m=f.lastIndexOf(l[0]);if(-1==m)continue e;return{from:r(c,d(p,f,m,s)),to:r(c,d(p,f,m+l[0].length,s))}}var g=l[l.length-1];if(f.slice(0,g.length)==g){var v=1;for(o=c-l.length+1;v<l.length-1;v++)if(s(e.getLine(o+v))!=l[v])continue e;var y=e.getLine(c+1-l.length),_=s(y);if(_.slice(_.length-l[0].length)==l[0])return{from:r(c+1-l.length,d(y,_,y.length-l[0].length,s)),to:r(c,d(p,f,g.length,s))}}}}function f(e,t,n,o){var l;this.atOccurrence=!1,this.doc=e,n=n?e.clipPos(n):r(0,0),this.pos={from:n,to:n},"object"==typeof o?l=o.caseFold:(l=o,o=null),"string"==typeof t?(null==l&&(l=!1),this.matches=function(n,r){return(n?p:h)(e,t,r,l)}):(t=i(t,"gm"),o&&!1===o.multiline?this.matches=function(n,r){return(n?c:a)(e,t,r)}:this.matches=function(n,r){return(n?u:s)(e,t,r)})}String.prototype.normalize?(t=function(e){return e.normalize("NFD").toLowerCase()},n=function(e){return e.normalize("NFD")}):(t=function(e){return e.toLowerCase()},n=function(e){return e}),f.prototype={findNext:function(){return this.find(!1)},findPrevious:function(){return this.find(!0)},find:function(t){for(var n=this.matches(t,this.doc.clipPos(t?this.pos.from:this.pos.to));n&&0==e.cmpPos(n.from,n.to);)t?n.from.ch?n.from=r(n.from.line,n.from.ch-1):n=n.from.line==this.doc.firstLine()?null:this.matches(t,this.doc.clipPos(r(n.from.line-1))):n.to.ch<this.doc.getLine(n.to.line).length?n.to=r(n.to.line,n.to.ch+1):n=n.to.line==this.doc.lastLine()?null:this.matches(t,r(n.to.line+1,0));if(n)return this.pos=n,this.atOccurrence=!0,this.pos.match||!0;var i=r(t?this.doc.firstLine():this.doc.lastLine()+1,0);return this.pos={from:i,to:i},this.atOccurrence=!1},from:function(){if(this.atOccurrence)return this.pos.from},to:function(){if(this.atOccurrence)return this.pos.to},replace:function(t,n){if(this.atOccurrence){var i=e.splitLines(t);this.doc.replaceRange(i,this.pos.from,this.pos.to,n),this.pos.to=r(this.pos.from.line+i.length-1,i[i.length-1].length+(1==i.length?this.pos.from.ch:0))}}},e.defineExtension("getSearchCursor",(function(e,t,n){return new f(this.doc,e,t,n)})),e.defineDocExtension("getSearchCursor",(function(e,t,n){return new f(this,e,t,n)})),e.defineExtension("selectMatches",(function(t,n){for(var r=[],i=this.getSearchCursor(t,this.getCursor("from"),n);i.findNext()&&!(e.cmpPos(i.to(),this.getCursor("to"))>0);)r.push({anchor:i.from(),head:i.to()});r.length&&this.setSelections(r,0)}))}(n(14))},function(e,t,n){!function(e){"use strict";e.modeInfo=[{name:"APL",mime:"text/apl",mode:"apl",ext:["dyalog","apl"]},{name:"PGP",mimes:["application/pgp","application/pgp-encrypted","application/pgp-keys","application/pgp-signature"],mode:"asciiarmor",ext:["asc","pgp","sig"]},{name:"ASN.1",mime:"text/x-ttcn-asn",mode:"asn.1",ext:["asn","asn1"]},{name:"Asterisk",mime:"text/x-asterisk",mode:"asterisk",file:/^extensions\.conf$/i},{name:"Brainfuck",mime:"text/x-brainfuck",mode:"brainfuck",ext:["b","bf"]},{name:"C",mime:"text/x-csrc",mode:"clike",ext:["c","h","ino"]},{name:"C++",mime:"text/x-c++src",mode:"clike",ext:["cpp","c++","cc","cxx","hpp","h++","hh","hxx"],alias:["cpp"]},{name:"Cobol",mime:"text/x-cobol",mode:"cobol",ext:["cob","cpy"]},{name:"C#",mime:"text/x-csharp",mode:"clike",ext:["cs"],alias:["csharp","cs"]},{name:"Clojure",mime:"text/x-clojure",mode:"clojure",ext:["clj","cljc","cljx"]},{name:"ClojureScript",mime:"text/x-clojurescript",mode:"clojure",ext:["cljs"]},{name:"Closure Stylesheets (GSS)",mime:"text/x-gss",mode:"css",ext:["gss"]},{name:"CMake",mime:"text/x-cmake",mode:"cmake",ext:["cmake","cmake.in"],file:/^CMakeLists\.txt$/},{name:"CoffeeScript",mimes:["application/vnd.coffeescript","text/coffeescript","text/x-coffeescript"],mode:"coffeescript",ext:["coffee"],alias:["coffee","coffee-script"]},{name:"Common Lisp",mime:"text/x-common-lisp",mode:"commonlisp",ext:["cl","lisp","el"],alias:["lisp"]},{name:"Cypher",mime:"application/x-cypher-query",mode:"cypher",ext:["cyp","cypher"]},{name:"Cython",mime:"text/x-cython",mode:"python",ext:["pyx","pxd","pxi"]},{name:"Crystal",mime:"text/x-crystal",mode:"crystal",ext:["cr"]},{name:"CSS",mime:"text/css",mode:"css",ext:["css"]},{name:"CQL",mime:"text/x-cassandra",mode:"sql",ext:["cql"]},{name:"D",mime:"text/x-d",mode:"d",ext:["d"]},{name:"Dart",mimes:["application/dart","text/x-dart"],mode:"dart",ext:["dart"]},{name:"diff",mime:"text/x-diff",mode:"diff",ext:["diff","patch"]},{name:"Django",mime:"text/x-django",mode:"django"},{name:"Dockerfile",mime:"text/x-dockerfile",mode:"dockerfile",file:/^Dockerfile$/},{name:"DTD",mime:"application/xml-dtd",mode:"dtd",ext:["dtd"]},{name:"Dylan",mime:"text/x-dylan",mode:"dylan",ext:["dylan","dyl","intr"]},{name:"EBNF",mime:"text/x-ebnf",mode:"ebnf"},{name:"ECL",mime:"text/x-ecl",mode:"ecl",ext:["ecl"]},{name:"edn",mime:"application/edn",mode:"clojure",ext:["edn"]},{name:"Eiffel",mime:"text/x-eiffel",mode:"eiffel",ext:["e"]},{name:"Elm",mime:"text/x-elm",mode:"elm",ext:["elm"]},{name:"Embedded JavaScript",mime:"application/x-ejs",mode:"htmlembedded",ext:["ejs"]},{name:"Embedded Ruby",mime:"application/x-erb",mode:"htmlembedded",ext:["erb"]},{name:"Erlang",mime:"text/x-erlang",mode:"erlang",ext:["erl"]},{name:"Esper",mime:"text/x-esper",mode:"sql"},{name:"Factor",mime:"text/x-factor",mode:"factor",ext:["factor"]},{name:"FCL",mime:"text/x-fcl",mode:"fcl"},{name:"Forth",mime:"text/x-forth",mode:"forth",ext:["forth","fth","4th"]},{name:"Fortran",mime:"text/x-fortran",mode:"fortran",ext:["f","for","f77","f90","f95"]},{name:"F#",mime:"text/x-fsharp",mode:"mllike",ext:["fs"],alias:["fsharp"]},{name:"Gas",mime:"text/x-gas",mode:"gas",ext:["s"]},{name:"Gherkin",mime:"text/x-feature",mode:"gherkin",ext:["feature"]},{name:"GitHub Flavored Markdown",mime:"text/x-gfm",mode:"gfm",file:/^(readme|contributing|history)\.md$/i},{name:"Go",mime:"text/x-go",mode:"go",ext:["go"]},{name:"Groovy",mime:"text/x-groovy",mode:"groovy",ext:["groovy","gradle"],file:/^Jenkinsfile$/},{name:"HAML",mime:"text/x-haml",mode:"haml",ext:["haml"]},{name:"Haskell",mime:"text/x-haskell",mode:"haskell",ext:["hs"]},{name:"Haskell (Literate)",mime:"text/x-literate-haskell",mode:"haskell-literate",ext:["lhs"]},{name:"Haxe",mime:"text/x-haxe",mode:"haxe",ext:["hx"]},{name:"HXML",mime:"text/x-hxml",mode:"haxe",ext:["hxml"]},{name:"ASP.NET",mime:"application/x-aspx",mode:"htmlembedded",ext:["aspx"],alias:["asp","aspx"]},{name:"HTML",mime:"text/html",mode:"htmlmixed",ext:["html","htm","handlebars","hbs"],alias:["xhtml"]},{name:"HTTP",mime:"message/http",mode:"http"},{name:"IDL",mime:"text/x-idl",mode:"idl",ext:["pro"]},{name:"Pug",mime:"text/x-pug",mode:"pug",ext:["jade","pug"],alias:["jade"]},{name:"Java",mime:"text/x-java",mode:"clike",ext:["java"]},{name:"Java Server Pages",mime:"application/x-jsp",mode:"htmlembedded",ext:["jsp"],alias:["jsp"]},{name:"JavaScript",mimes:["text/javascript","text/ecmascript","application/javascript","application/x-javascript","application/ecmascript"],mode:"javascript",ext:["js"],alias:["ecmascript","js","node"]},{name:"JSON",mimes:["application/json","application/x-json"],mode:"javascript",ext:["json","map"],alias:["json5"]},{name:"JSON-LD",mime:"application/ld+json",mode:"javascript",ext:["jsonld"],alias:["jsonld"]},{name:"JSX",mime:"text/jsx",mode:"jsx",ext:["jsx"]},{name:"Jinja2",mime:"text/jinja2",mode:"jinja2",ext:["j2","jinja","jinja2"]},{name:"Julia",mime:"text/x-julia",mode:"julia",ext:["jl"],alias:["jl"]},{name:"Kotlin",mime:"text/x-kotlin",mode:"clike",ext:["kt"]},{name:"LESS",mime:"text/x-less",mode:"css",ext:["less"]},{name:"LiveScript",mime:"text/x-livescript",mode:"livescript",ext:["ls"],alias:["ls"]},{name:"Lua",mime:"text/x-lua",mode:"lua",ext:["lua"]},{name:"Markdown",mime:"text/x-markdown",mode:"markdown",ext:["markdown","md","mkd"]},{name:"mIRC",mime:"text/mirc",mode:"mirc"},{name:"MariaDB SQL",mime:"text/x-mariadb",mode:"sql"},{name:"Mathematica",mime:"text/x-mathematica",mode:"mathematica",ext:["m","nb","wl","wls"]},{name:"Modelica",mime:"text/x-modelica",mode:"modelica",ext:["mo"]},{name:"MUMPS",mime:"text/x-mumps",mode:"mumps",ext:["mps"]},{name:"MS SQL",mime:"text/x-mssql",mode:"sql"},{name:"mbox",mime:"application/mbox",mode:"mbox",ext:["mbox"]},{name:"MySQL",mime:"text/x-mysql",mode:"sql"},{name:"Nginx",mime:"text/x-nginx-conf",mode:"nginx",file:/nginx.*\.conf$/i},{name:"NSIS",mime:"text/x-nsis",mode:"nsis",ext:["nsh","nsi"]},{name:"NTriples",mimes:["application/n-triples","application/n-quads","text/n-triples"],mode:"ntriples",ext:["nt","nq"]},{name:"Objective-C",mime:"text/x-objectivec",mode:"clike",ext:["m"],alias:["objective-c","objc"]},{name:"Objective-C++",mime:"text/x-objectivec++",mode:"clike",ext:["mm"],alias:["objective-c++","objc++"]},{name:"OCaml",mime:"text/x-ocaml",mode:"mllike",ext:["ml","mli","mll","mly"]},{name:"Octave",mime:"text/x-octave",mode:"octave",ext:["m"]},{name:"Oz",mime:"text/x-oz",mode:"oz",ext:["oz"]},{name:"Pascal",mime:"text/x-pascal",mode:"pascal",ext:["p","pas"]},{name:"PEG.js",mime:"null",mode:"pegjs",ext:["jsonld"]},{name:"Perl",mime:"text/x-perl",mode:"perl",ext:["pl","pm"]},{name:"PHP",mimes:["text/x-php","application/x-httpd-php","application/x-httpd-php-open"],mode:"php",ext:["php","php3","php4","php5","php7","phtml"]},{name:"Pig",mime:"text/x-pig",mode:"pig",ext:["pig"]},{name:"Plain Text",mime:"text/plain",mode:"null",ext:["txt","text","conf","def","list","log"]},{name:"PLSQL",mime:"text/x-plsql",mode:"sql",ext:["pls"]},{name:"PostgreSQL",mime:"text/x-pgsql",mode:"sql"},{name:"PowerShell",mime:"application/x-powershell",mode:"powershell",ext:["ps1","psd1","psm1"]},{name:"Properties files",mime:"text/x-properties",mode:"properties",ext:["properties","ini","in"],alias:["ini","properties"]},{name:"ProtoBuf",mime:"text/x-protobuf",mode:"protobuf",ext:["proto"]},{name:"Python",mime:"text/x-python",mode:"python",ext:["BUILD","bzl","py","pyw"],file:/^(BUCK|BUILD)$/},{name:"Puppet",mime:"text/x-puppet",mode:"puppet",ext:["pp"]},{name:"Q",mime:"text/x-q",mode:"q",ext:["q"]},{name:"R",mime:"text/x-rsrc",mode:"r",ext:["r","R"],alias:["rscript"]},{name:"reStructuredText",mime:"text/x-rst",mode:"rst",ext:["rst"],alias:["rst"]},{name:"RPM Changes",mime:"text/x-rpm-changes",mode:"rpm"},{name:"RPM Spec",mime:"text/x-rpm-spec",mode:"rpm",ext:["spec"]},{name:"Ruby",mime:"text/x-ruby",mode:"ruby",ext:["rb"],alias:["jruby","macruby","rake","rb","rbx"]},{name:"Rust",mime:"text/x-rustsrc",mode:"rust",ext:["rs"]},{name:"SAS",mime:"text/x-sas",mode:"sas",ext:["sas"]},{name:"Sass",mime:"text/x-sass",mode:"sass",ext:["sass"]},{name:"Scala",mime:"text/x-scala",mode:"clike",ext:["scala"]},{name:"Scheme",mime:"text/x-scheme",mode:"scheme",ext:["scm","ss"]},{name:"SCSS",mime:"text/x-scss",mode:"css",ext:["scss"]},{name:"Shell",mimes:["text/x-sh","application/x-sh"],mode:"shell",ext:["sh","ksh","bash"],alias:["bash","sh","zsh"],file:/^PKGBUILD$/},{name:"Sieve",mime:"application/sieve",mode:"sieve",ext:["siv","sieve"]},{name:"Slim",mimes:["text/x-slim","application/x-slim"],mode:"slim",ext:["slim"]},{name:"Smalltalk",mime:"text/x-stsrc",mode:"smalltalk",ext:["st"]},{name:"Smarty",mime:"text/x-smarty",mode:"smarty",ext:["tpl"]},{name:"Solr",mime:"text/x-solr",mode:"solr"},{name:"SML",mime:"text/x-sml",mode:"mllike",ext:["sml","sig","fun","smackspec"]},{name:"Soy",mime:"text/x-soy",mode:"soy",ext:["soy"],alias:["closure template"]},{name:"SPARQL",mime:"application/sparql-query",mode:"sparql",ext:["rq","sparql"],alias:["sparul"]},{name:"Spreadsheet",mime:"text/x-spreadsheet",mode:"spreadsheet",alias:["excel","formula"]},{name:"SQL",mime:"text/x-sql",mode:"sql",ext:["sql"]},{name:"SQLite",mime:"text/x-sqlite",mode:"sql"},{name:"Squirrel",mime:"text/x-squirrel",mode:"clike",ext:["nut"]},{name:"Stylus",mime:"text/x-styl",mode:"stylus",ext:["styl"]},{name:"Swift",mime:"text/x-swift",mode:"swift",ext:["swift"]},{name:"sTeX",mime:"text/x-stex",mode:"stex"},{name:"LaTeX",mime:"text/x-latex",mode:"stex",ext:["text","ltx","tex"],alias:["tex"]},{name:"SystemVerilog",mime:"text/x-systemverilog",mode:"verilog",ext:["v","sv","svh"]},{name:"Tcl",mime:"text/x-tcl",mode:"tcl",ext:["tcl"]},{name:"Textile",mime:"text/x-textile",mode:"textile",ext:["textile"]},{name:"TiddlyWiki",mime:"text/x-tiddlywiki",mode:"tiddlywiki"},{name:"Tiki wiki",mime:"text/tiki",mode:"tiki"},{name:"TOML",mime:"text/x-toml",mode:"toml",ext:["toml"]},{name:"Tornado",mime:"text/x-tornado",mode:"tornado"},{name:"troff",mime:"text/troff",mode:"troff",ext:["1","2","3","4","5","6","7","8","9"]},{name:"TTCN",mime:"text/x-ttcn",mode:"ttcn",ext:["ttcn","ttcn3","ttcnpp"]},{name:"TTCN_CFG",mime:"text/x-ttcn-cfg",mode:"ttcn-cfg",ext:["cfg"]},{name:"Turtle",mime:"text/turtle",mode:"turtle",ext:["ttl"]},{name:"TypeScript",mime:"application/typescript",mode:"javascript",ext:["ts"],alias:["ts"]},{name:"TypeScript-JSX",mime:"text/typescript-jsx",mode:"jsx",ext:["tsx"],alias:["tsx"]},{name:"Twig",mime:"text/x-twig",mode:"twig"},{name:"Web IDL",mime:"text/x-webidl",mode:"webidl",ext:["webidl"]},{name:"VB.NET",mime:"text/x-vb",mode:"vb",ext:["vb"]},{name:"VBScript",mime:"text/vbscript",mode:"vbscript",ext:["vbs"]},{name:"Velocity",mime:"text/velocity",mode:"velocity",ext:["vtl"]},{name:"Verilog",mime:"text/x-verilog",mode:"verilog",ext:["v"]},{name:"VHDL",mime:"text/x-vhdl",mode:"vhdl",ext:["vhd","vhdl"]},{name:"Vue.js Component",mimes:["script/x-vue","text/x-vue"],mode:"vue",ext:["vue"]},{name:"XML",mimes:["application/xml","text/xml"],mode:"xml",ext:["xml","xsl","xsd","svg"],alias:["rss","wsdl","xsd"]},{name:"XQuery",mime:"application/xquery",mode:"xquery",ext:["xy","xquery"]},{name:"Yacas",mime:"text/x-yacas",mode:"yacas",ext:["ys"]},{name:"YAML",mimes:["text/x-yaml","text/yaml"],mode:"yaml",ext:["yaml","yml"],alias:["yml"]},{name:"Z80",mime:"text/x-z80",mode:"z80",ext:["z80"]},{name:"mscgen",mime:"text/x-mscgen",mode:"mscgen",ext:["mscgen","mscin","msc"]},{name:"xu",mime:"text/x-xu",mode:"mscgen",ext:["xu"]},{name:"msgenny",mime:"text/x-msgenny",mode:"mscgen",ext:["msgenny"]},{name:"WebAssembly",mime:"text/webassembly",mode:"wast",ext:["wat","wast"]}];for(var t=0;t<e.modeInfo.length;t++){var n=e.modeInfo[t];n.mimes&&(n.mime=n.mimes[0])}e.findModeByMIME=function(t){t=t.toLowerCase();for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.mime==t)return r;if(r.mimes)for(var i=0;i<r.mimes.length;i++)if(r.mimes[i]==t)return r}return/\+xml$/.test(t)?e.findModeByMIME("application/xml"):/\+json$/.test(t)?e.findModeByMIME("application/json"):void 0},e.findModeByExtension=function(t){t=t.toLowerCase();for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.ext)for(var i=0;i<r.ext.length;i++)if(r.ext[i]==t)return r}},e.findModeByFileName=function(t){for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.file&&r.file.test(t))return r}var i=t.lastIndexOf("."),o=i>-1&&t.substring(i+1,t.length);if(o)return e.findModeByExtension(o)},e.findModeByName=function(t){t=t.toLowerCase();for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.name.toLowerCase()==t)return r;if(r.alias)for(var i=0;i<r.alias.length;i++)if(r.alias[i].toLowerCase()==t)return r}}}(n(14))},function(e,t,n){"use strict";function r(e){return null!=e&&"function"!=typeof e}function i(e){return"function"==typeof e}function o(e,t){r(e)?e.current=t:i(e)&&e(t)}function a(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){e.forEach((function(e){o(e,t)}))}}Object.defineProperty(t,"__esModule",{value:!0}),t.refHandler=t.getRef=t.mergeRefs=t.combineRefs=t.setRef=t.isRefCallback=t.isRefObject=void 0,t.isRefObject=r,t.isRefCallback=i,t.setRef=o,t.combineRefs=function(e,t){return a(e,t)},t.mergeRefs=a,t.getRef=function(e){var t;return null===e?null:null!==(t=e.current)&&void 0!==t?t:e},t.refHandler=function(e,t,n){return function(r){e[t]=r,o(n,r)}}},function(e,t,n){"use strict";function r(e){return"function"==typeof e}Object.defineProperty(t,"__esModule",{value:!0}),t.safeInvokeOrValue=t.safeInvoke=t.isFunction=void 0,t.isFunction=r,t.safeInvoke=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(r(e))return e.apply(void 0,t)},t.safeInvokeOrValue=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return r(e)?e.apply(void 0,t):e}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TOASTER_MAX_TOASTS_INVALID=t.DRAWER_ANGLE_POSITIONS_ARE_CASTED=t.DRAWER_VERTICAL_IS_IGNORED=t.DIALOG_WARN_NO_HEADER_CLOSE_BUTTON=t.DIALOG_WARN_NO_HEADER_ICON=t.TOASTER_WARN_INLINE=t.TOASTER_CREATE_NULL=t.SPINNER_WARN_CLASSES_SIZE=t.MULTISLIDER_WARN_LABEL_STEP_SIZE_LABEL_VALUES_MUTEX=t.MULTISLIDER_INVALID_CHILD=t.RANGESLIDER_NULL_VALUE=t.SLIDER_ZERO_LABEL_STEP=t.SLIDER_ZERO_STEP=t.RADIOGROUP_WARN_CHILDREN_OPTIONS_MUTEX=t.PORTAL_CONTEXT_CLASS_NAME_STRING=t.POPOVER_WARN_UNCONTROLLED_ONINTERACTION=t.POPOVER_WARN_PLACEMENT_AND_POSITION_MUTEX=t.POPOVER_WARN_HAS_BACKDROP_INLINE=t.POPOVER_WARN_EMPTY_CONTENT=t.POPOVER_WARN_DOUBLE_TARGET=t.POPOVER_WARN_DOUBLE_CONTENT=t.POPOVER_WARN_TOO_MANY_CHILDREN=t.POPOVER_HAS_BACKDROP_INTERACTION=t.POPOVER_REQUIRES_TARGET=t.OVERFLOW_LIST_OBSERVE_PARENTS_CHANGED=t.PANEL_STACK_REQUIRES_PANEL=t.PANEL_STACK_INITIAL_PANEL_STACK_MUTEX=t.NUMERIC_INPUT_CONTROLLED_VALUE_INVALID=t.NUMERIC_INPUT_STEP_SIZE_NON_POSITIVE=t.NUMERIC_INPUT_MAJOR_STEP_SIZE_NON_POSITIVE=t.NUMERIC_INPUT_MINOR_STEP_SIZE_NON_POSITIVE=t.NUMERIC_INPUT_MAJOR_STEP_SIZE_BOUND=t.NUMERIC_INPUT_MINOR_STEP_SIZE_BOUND=t.NUMERIC_INPUT_MIN_MAX=t.INPUT_WARN_LEFT_ELEMENT_LEFT_ICON_MUTEX=t.HOTKEYS_TARGET2_CHILDREN_LOCAL_HOTKEYS=t.HOTKEYS_WARN_DECORATOR_NEEDS_REACT_ELEMENT=t.HOTKEYS_WARN_DECORATOR_NO_METHOD=t.HOTKEYS_HOTKEY_CHILDREN=t.CONTEXTMENU_WARN_DECORATOR_NEEDS_REACT_ELEMENT=t.CONTEXTMENU_WARN_DECORATOR_NO_METHOD=t.COLLAPSIBLE_LIST_INVALID_CHILD=t.ALERT_WARN_CANCEL_OUTSIDE_CLICK=t.ALERT_WARN_CANCEL_ESCAPE_KEY=t.ALERT_WARN_CANCEL_PROPS=t.CLAMP_MIN_MAX=void 0;var r="[Blueprint]";t.CLAMP_MIN_MAX=r+" clamp: max cannot be less than min",t.ALERT_WARN_CANCEL_PROPS=r+" <Alert> cancelButtonText and onCancel should be set together.",t.ALERT_WARN_CANCEL_ESCAPE_KEY=r+" <Alert> canEscapeKeyCancel enabled without onCancel or onClose handler.",t.ALERT_WARN_CANCEL_OUTSIDE_CLICK=r+" <Alert> canOutsideClickCancel enabled without onCancel or onClose handler.",t.COLLAPSIBLE_LIST_INVALID_CHILD=r+" <CollapsibleList> children must be <MenuItem>s",t.CONTEXTMENU_WARN_DECORATOR_NO_METHOD=r+" @ContextMenuTarget-decorated class should implement renderContextMenu.",t.CONTEXTMENU_WARN_DECORATOR_NEEDS_REACT_ELEMENT=r+' "@ContextMenuTarget-decorated components must return a single JSX.Element or an empty render.',t.HOTKEYS_HOTKEY_CHILDREN=r+" <Hotkeys> only accepts <Hotkey> children.",t.HOTKEYS_WARN_DECORATOR_NO_METHOD=r+" @HotkeysTarget-decorated class should implement renderHotkeys.",t.HOTKEYS_WARN_DECORATOR_NEEDS_REACT_ELEMENT=r+' "@HotkeysTarget-decorated components must return a single JSX.Element or an empty render.',t.HOTKEYS_TARGET2_CHILDREN_LOCAL_HOTKEYS=r+" <HotkeysTarget2> was configured with local hotkeys, but you did not use the generated event handlers to bind their event handlers. Try using a render function as the child of this component.",t.INPUT_WARN_LEFT_ELEMENT_LEFT_ICON_MUTEX=r+" <InputGroup> leftElement and leftIcon prop are mutually exclusive, with leftElement taking priority.",t.NUMERIC_INPUT_MIN_MAX=r+" <NumericInput> requires min to be no greater than max if both are defined.",t.NUMERIC_INPUT_MINOR_STEP_SIZE_BOUND=r+" <NumericInput> requires minorStepSize to be no greater than stepSize.",t.NUMERIC_INPUT_MAJOR_STEP_SIZE_BOUND=r+" <NumericInput> requires stepSize to be no greater than majorStepSize.",t.NUMERIC_INPUT_MINOR_STEP_SIZE_NON_POSITIVE=r+" <NumericInput> requires minorStepSize to be strictly greater than zero.",t.NUMERIC_INPUT_MAJOR_STEP_SIZE_NON_POSITIVE=r+" <NumericInput> requires majorStepSize to be strictly greater than zero.",t.NUMERIC_INPUT_STEP_SIZE_NON_POSITIVE=r+" <NumericInput> requires stepSize to be strictly greater than zero.",t.NUMERIC_INPUT_CONTROLLED_VALUE_INVALID=r+" <NumericInput> controlled value prop does not adhere to stepSize, min, and/or max constraints.",t.PANEL_STACK_INITIAL_PANEL_STACK_MUTEX=r+" <PanelStack> requires exactly one of initialPanel and stack prop",t.PANEL_STACK_REQUIRES_PANEL=r+" <PanelStack> requires at least one panel in the stack",t.OVERFLOW_LIST_OBSERVE_PARENTS_CHANGED=r+" <OverflowList> does not support changing observeParents after mounting.",t.POPOVER_REQUIRES_TARGET=r+" <Popover> requires target prop or at least one child element.",t.POPOVER_HAS_BACKDROP_INTERACTION=r+" <Popover hasBackdrop={true}> requires interactionKind={PopoverInteractionKind.CLICK}.",t.POPOVER_WARN_TOO_MANY_CHILDREN=r+" <Popover> supports one or two children; additional children are ignored. First child is the target, second child is the content. You may instead supply these two as props.",t.POPOVER_WARN_DOUBLE_CONTENT=r+" <Popover> with two children ignores content prop; use either prop or children.",t.POPOVER_WARN_DOUBLE_TARGET=r+" <Popover> with children ignores target prop; use either prop or children.",t.POPOVER_WARN_EMPTY_CONTENT=r+" Disabling <Popover> with empty/whitespace content...",t.POPOVER_WARN_HAS_BACKDROP_INLINE=r+" <Popover usePortal={false}> ignores hasBackdrop",t.POPOVER_WARN_PLACEMENT_AND_POSITION_MUTEX=r+" <Popover> supports either placement or position prop, not both.",t.POPOVER_WARN_UNCONTROLLED_ONINTERACTION=r+" <Popover> onInteraction is ignored when uncontrolled.",t.PORTAL_CONTEXT_CLASS_NAME_STRING=r+" <Portal> context blueprintPortalClassName must be string",t.RADIOGROUP_WARN_CHILDREN_OPTIONS_MUTEX=r+" <RadioGroup> children and options prop are mutually exclusive, with options taking priority.",t.SLIDER_ZERO_STEP=r+" <Slider> stepSize must be greater than zero.",t.SLIDER_ZERO_LABEL_STEP=r+" <Slider> labelStepSize must be greater than zero.",t.RANGESLIDER_NULL_VALUE=r+" <RangeSlider> value prop must be an array of two non-null numbers.",t.MULTISLIDER_INVALID_CHILD=r+" <MultiSlider> children must be <SliderHandle>s or <SliderTrackStop>s",t.MULTISLIDER_WARN_LABEL_STEP_SIZE_LABEL_VALUES_MUTEX=r+" <MultiSlider> labelStepSize and labelValues prop are mutually exclusive, with labelStepSize taking priority.",t.SPINNER_WARN_CLASSES_SIZE=r+" <Spinner> Classes.SMALL/LARGE are ignored if size prop is set.",t.TOASTER_CREATE_NULL=r+" Toaster.create() is not supported inside React lifecycle methods in React 16. See usage example on the docs site.",t.TOASTER_WARN_INLINE=r+" Toaster.create() ignores inline prop as it always creates a new element.",t.DIALOG_WARN_NO_HEADER_ICON=r+" <Dialog> iconName is ignored if title is omitted.",t.DIALOG_WARN_NO_HEADER_CLOSE_BUTTON=r+" <Dialog> isCloseButtonShown prop is ignored if title is omitted.",t.DRAWER_VERTICAL_IS_IGNORED=r+" <Drawer> vertical is ignored if position is defined",t.DRAWER_ANGLE_POSITIONS_ARE_CASTED=r+" <Drawer> all angle positions are casted into pure position (TOP, BOTTOM, LEFT or RIGHT)",t.TOASTER_MAX_TOASTS_INVALID=r+" <Toaster> maxToasts is set to an invalid number, must be greater than 0"},function(e,t,n){"use strict";n.d(t,"a",(function(){return r})),n.d(t,"b",(function(){return i}));var r={add:["M10.99 6.99h-2v-2c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1zm-3-7c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.68 6-6 6z"],"add-clip":["M12 0a1 1 0 00-1 1v2H9a1 1 0 000 2h2v2a1 1 0 102 0V5h2a1 1 0 100-2h-2V1a1 1 0 00-1-1zM0 4a1 1 0 011-1h3.5a1 1 0 010 2H2v2a1 1 0 01-2 0V4zm1 12a1 1 0 01-1-1v-3a1 1 0 112 0v2h2.5a1 1 0 110 2H1zm11 0a1 1 0 001-1v-3a1 1 0 10-2 0v2H9a1 1 0 100 2h3zm-5.5-4a2.5 2.5 0 100-5 2.5 2.5 0 000 5z"],"add-column-left":["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-5 14H2V2h8v12zm4 0h-3V2h3v12zM4 9h1v1c0 .55.45 1 1 1s1-.45 1-1V9h1c.55 0 1-.45 1-1s-.45-1-1-1H7V6c0-.55-.45-1-1-1s-1 .45-1 1v1H4c-.55 0-1 .45-1 1s.45 1 1 1z"],"add-column-right":["M8 9h1v1c0 .55.45 1 1 1s1-.45 1-1V9h1c.55 0 1-.45 1-1s-.45-1-1-1h-1V6c0-.55-.45-1-1-1s-1 .45-1 1v1H8c-.55 0-1 .45-1 1s.45 1 1 1zm7-9H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM5 14H2V2h3v12zm9 0H6V2h8v12z"],"add-location":["M8 0a1 1 0 110 2 6 6 0 106 6 1 1 0 012 0 8 8 0 11-8-8zm0 5a3 3 0 110 6 3 3 0 010-6zm5-5a1 1 0 011 1v.999L15 2a1 1 0 010 2h-1v1a1 1 0 01-2 0V4h-1a1 1 0 010-2h1V1a1 1 0 011-1z"],"add-row-bottom":["M6 11h1v1c0 .55.45 1 1 1s1-.45 1-1v-1h1c.55 0 1-.45 1-1s-.45-1-1-1H9V8c0-.55-.45-1-1-1s-1 .45-1 1v1H6c-.55 0-1 .45-1 1s.45 1 1 1zm9-11H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2V6h12v8zm0-9H2V2h12v3z"],"add-row-top":["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2v-3h12v3zm0-4H2V2h12v8zM6 7h1v1c0 .55.45 1 1 1s1-.45 1-1V7h1c.55 0 1-.45 1-1s-.45-1-1-1H9V4c0-.55-.45-1-1-1s-1 .45-1 1v1H6c-.55 0-1 .45-1 1s.45 1 1 1z"],"add-to-artifact":["M14 4.01h-1v-1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1v-1h1c.55 0 1-.45 1-1 0-.56-.45-1-1-1zm-13 2h6c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm8 6H1c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1 0-.56-.45-1-1-1zm0-4H1c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1 0-.56-.45-1-1-1z"],"add-to-folder":["M.01 7V5H16v7c0 .55-.45 1-1 1H9.005v-2.99C8.974 8.332 7.644 7 5.996 7H.01zM15 2H7.416L5.706.29a.996.996 0 00-.71-.29H1C.45 0 0 .45 0 1v3h15.99V3c.01-.55-.44-1-.99-1zM5.997 9H2c-.55 0-1 .45-1 1s.45 1 1 1h1.589L.3 14.29a1.003 1.003 0 001.42 1.42l3.287-3.29v1.59c0 .55.45 1 1 1 .549 0 .999-.45.999-1v-4A1.02 1.02 0 005.996 9z"],airplane:["M16 1.5A1.498 1.498 0 0013.44.44L9.91 3.97 2 1 1 3l5.93 3.95L3.88 10H1l-1 1 3 2 2 3 1-1v-2.88l3.05-3.05L13 15l2-1-2.97-7.91 3.53-3.53c.27-.27.44-.65.44-1.06z"],"align-center":["M4 4c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1H4zM1 3h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm13 10H2c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zm1-6H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm-5 5c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1s.45 1 1 1h4z"],"align-justify":["M15 12.98H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm-14-10h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1 0 .56.45 1 1 1zm14 4H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm0-3H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm0 6H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"align-left":["M13 13H1c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zM1 3h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm0 3h8c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 1H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM1 12h4c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1z"],"align-right":["M15 12.98H3c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zm-14-10h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1 0 .56.45 1 1 1zm14 1H7c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1zm0 6h-4c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1zm0-3H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"alignment-bottom":["M10 12h3c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1h-3c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1zm5 2H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM3 12h3c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1z"],"alignment-horizontal-center":["M15 7h-1V6c0-.55-.45-1-1-1h-3c-.55 0-1 .45-1 1v1H7V3c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v4H1c-.55 0-1 .45-1 1s.45 1 1 1h1v4c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V9h2v1c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V9h1c.55 0 1-.45 1-1s-.45-1-1-1z"],"alignment-left":["M9 9H5c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1zM1 0C.45 0 0 .45 0 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm13 2H5c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],"alignment-right":["M11 9H7c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1zm4-9c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm-4 2H2c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],"alignment-top":["M15 0H1C.45 0 0 .45 0 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM6 4H3c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm7 0h-3c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],"alignment-vertical-center":["M13 2H9V1c0-.55-.45-1-1-1S7 .45 7 1v1H3c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h4v2H6c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1v-1h1c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1H9V7h4c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],annotation:["M15.52 2.77c.3-.29.48-.7.48-1.15C16 .73 15.27 0 14.38 0c-.45 0-.85.18-1.15.48l-1.34 1.34 2.3 2.3 1.33-1.35zM7.4 10.9l6.21-6.21-2.3-2.3L5.1 8.6l2.3 2.3zM14 14H2V2h6.34l2-2H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V5.66l-2 2V14zM3 13l3.58-1.29-2.29-2.27L3 13z"],antenna:["M2.673 10.758a1.396 1.396 0 01.093.234c.127.442.012.932-.362 1.212-.441.332-1.075.246-1.349-.233a8 8 0 1114.014-.225c-.259.488-.889.594-1.341.277-.382-.269-.513-.755-.4-1.2a1.259 1.259 0 01.085-.238 6 6 0 10-10.74.173zm2.464-1.862a1.783 1.783 0 01.076.404c.03.415-.096.831-.43 1.078-.444.328-1.08.237-1.314-.264a5.003 5.003 0 01-.24-.62l-.004-.011a5 5 0 119.574-.08l-.003.011c-.063.213-.14.422-.23.625-.226.504-.861.606-1.31.285-.338-.241-.47-.654-.448-1.07a1.737 1.737 0 01.07-.405 2.99 2.99 0 00-.216-2.233 3 3 0 00-5.525 2.28zM8 7a1 1 0 011 1v3.586l2.707 2.707a1 1 0 01-1.414 1.414L8 13.414l-2.293 2.293a1 1 0 01-1.414-1.414L7 11.586V8a1 1 0 011-1z"],"app-header":["M15 0a1 1 0 011 1v14a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1h14zM6 4a1 1 0 00-1.993-.117L4 4v8a1 1 0 001.993.117L6 12V9h4v3a1 1 0 001.993.117L12 12V4a1 1 0 00-1.993-.117L10 4v3H6V4z"],application:["M3.5 7h7c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-7c-.28 0-.5.22-.5.5s.22.5.5.5zM15 1H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm-1 12H2V5h12v8zM3.5 9h4c.28 0 .5-.22.5-.5S7.78 8 7.5 8h-4c-.28 0-.5.22-.5.5s.22.5.5.5zm0 2h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-5c-.28 0-.5.22-.5.5s.22.5.5.5z"],applications:["M3.5 11h2c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-2c-.28 0-.5.22-.5.5s.22.5.5.5zm0-2h5c.28 0 .5-.22.5-.5S8.78 8 8.5 8h-5c-.28 0-.5.22-.5.5s.22.5.5.5zM11 4H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm-1 10H2V7h8v7zm5-14H5c-.55 0-1 .45-1 1v2h2V2h8v7h-1v2h2c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM3.5 13h3c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-3c-.28 0-.5.22-.5.5s.22.5.5.5z"],archive:["M13.382 0a1 1 0 01.894.553L16 4v11a1 1 0 01-1 1H1a1 1 0 01-1-1V4L1.724.553A1 1 0 012.618 0h10.764zM8 6c-.55 0-1 .45-1 1v2.59l-.29-.29-.081-.076A.97.97 0 006 9a1.003 1.003 0 00-.71 1.71l2 2 .096.084c.168.13.38.206.614.206.28 0 .53-.11.71-.29l2-2 .084-.096A1.003 1.003 0 009.29 9.29l-.29.3V7l-.007-.116A1.004 1.004 0 008 6zm5-4H3L2 4h12l-1-2z"],"area-of-interest":["M4 3.664C4 1.644 5.793 0 8 0s3.993 1.643 4 3.664C12 5.692 8 11 8 11S4 5.692 4 3.664zM6 4a2 2 0 104.001-.001A2 2 0 006 4zm7.504 6.269l-2.68-1.609.021-.033c.34-.538.688-1.115 1-1.687l3.67 2.202a1 1 0 01.266 1.482l-4 5A1 1 0 0111 16H5a1 1 0 01-.78-.376l-4-5a1 1 0 01.266-1.482l3.67-2.202a30.46 30.46 0 00.999 1.687l.021.033-2.68 1.609 2.985 3.73h5.038l2.985-3.73z"],array:["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm4 7a1 1 0 110 2 1 1 0 010-2zM5 7a1 1 0 110 2 1 1 0 010-2zm6 0a1 1 0 110 2 1 1 0 010-2z"],"array-boolean":["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm7 6a1 1 0 01.993.883L12 7v2a1 1 0 01-.883.993L11 10H5a1 1 0 01-.993-.883L4 9V7a1 1 0 01.883-.993L5 6h6zm0 1H8v2h3V7z"],"array-date":["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm6.5 4a.5.5 0 01.5.5V5a1 1 0 01.993.883L12 6v5a1 1 0 01-.883.993L11 12H5a1 1 0 01-.993-.883L4 11V6a1 1 0 01.883-.993L5 5v-.5a.5.5 0 011 0V5h4v-.5a.5.5 0 01.5-.5zm.5 3H5v4h6V7z"],"array-numeric":["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm6.904 5c.256 0 .483.037.68.112a1.343 1.343 0 01.812.788c.072.184.108.385.108.604 0 .23-.05.441-.152.636a1.314 1.314 0 01-.456.492v.016l.08.04c.055.031.111.072.168.124.085.077.163.172.232.284a1.673 1.673 0 01.24.872c0 .25-.043.477-.128.68a1.518 1.518 0 01-.896.852 1.937 1.937 0 01-.68.116c-.427 0-.792-.101-1.096-.304a1.362 1.362 0 01-.584-.864c-.01-.053.01-.088.064-.104l.696-.16.033-.002c.03.002.051.022.063.058.059.16.155.296.288.408.133.112.312.168.536.168.256 0 .453-.076.592-.228a.827.827 0 00.208-.58c0-.277-.08-.495-.24-.652-.16-.157-.376-.236-.648-.236h-.232l-.035-.005c-.03-.01-.045-.035-.045-.075v-.632l.005-.035c.01-.03.035-.045.075-.045h.216l.138-.009a.734.734 0 00.438-.207c.144-.144.216-.336.216-.576a.745.745 0 00-.192-.532c-.128-.136-.307-.204-.536-.204-.203 0-.363.05-.48.152a.815.815 0 00-.248.408c-.016.048-.048.067-.096.056l-.68-.16-.034-.012c-.028-.016-.038-.044-.03-.084a1.347 1.347 0 01.516-.828c.136-.104.296-.185.48-.244A1.98 1.98 0 0110.904 5zm-6.152.088l.035.005c.03.01.045.035.045.075v5.28l-.005.035c-.01.03-.035.045-.075.045h-.736l-.035-.005c-.03-.01-.045-.035-.045-.075V6.16H3.92l-.832.584-.032.016C3.02 6.773 3 6.751 3 6.696V5.88l.006-.04a.157.157 0 01.05-.072l.872-.632.04-.027a.236.236 0 01.104-.021h.68zM7.344 5c.256 0 .483.04.68.12.197.08.364.188.5.324s.24.296.312.48c.072.184.108.383.108.596 0 .245-.045.47-.136.676-.09.205-.216.404-.376.596l-1.584 1.92v.016h2.016l.035.005c.03.01.045.035.045.075v.64l-.005.035c-.01.03-.035.045-.075.045H5.808l-.035-.005c-.03-.01-.045-.035-.045-.075v-.6l.004-.04a.132.132 0 01.036-.064l1.92-2.392.1-.133a1.95 1.95 0 00.156-.267.985.985 0 00.096-.432.736.736 0 00-.188-.512c-.125-.139-.303-.208-.532-.208-.219 0-.39.061-.512.184a.826.826 0 00-.224.496c-.01.053-.04.075-.088.064L5.792 6.4l-.034-.012c-.028-.016-.038-.044-.03-.084a1.425 1.425 0 01.94-1.192A1.88 1.88 0 017.344 5z"],"array-string":["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm1.61 5c.514 0 .962.212 1.343.637.382.425.573.997.573 1.716 0 .838-.258 1.588-.773 2.252-.514.663-1.327 1.2-2.437 1.609v-.465l.233-.095a3.09 3.09 0 001.274-1.017c.366-.505.55-1.03.55-1.577a.478.478 0 00-.057-.26c-.018-.037-.043-.056-.074-.056s-.08.025-.149.075c-.198.142-.446.214-.744.214-.36 0-.675-.145-.944-.433A1.453 1.453 0 014 6.572c0-.422.155-.79.465-1.102.31-.313.692-.47 1.144-.47zm4.474 0c.514 0 .963.212 1.344.637.381.425.572.997.572 1.716 0 .838-.257 1.588-.772 2.252-.515.663-1.327 1.2-2.437 1.609v-.465l.233-.095a3.09 3.09 0 001.274-1.017c.366-.505.549-1.03.549-1.577a.478.478 0 00-.056-.26c-.019-.037-.044-.056-.075-.056-.03 0-.08.025-.149.075-.198.142-.446.214-.744.214-.36 0-.674-.145-.944-.433a1.453 1.453 0 01-.405-1.028c0-.422.155-.79.466-1.102.31-.313.691-.47 1.144-.47z"],"array-timestamp":["M15 0a1 1 0 01.993.883L16 1v14a1 1 0 01-.883.993L15 16h-3a1 1 0 01-.117-1.993L12 14h2V2h-2a1 1 0 01-.993-.883L11 1a1 1 0 01.883-.993L12 0h3zM4 0a1 1 0 01.117 1.993L4 2H2v12h2a1 1 0 01.993.883L5 15a1 1 0 01-.883.993L4 16H1a1 1 0 01-.993-.883L0 15V1A1 1 0 01.883.007L1 0h3zm4 3a5 5 0 110 10A5 5 0 018 3zm0 1a4 4 0 100 8 4 4 0 000-8zm2.354 1.646a.5.5 0 01.057.638l-.057.07-2 2a.5.5 0 01-.638.057l-.07-.057-1-1a.5.5 0 01.638-.765l.07.057.646.647 1.646-1.647a.5.5 0 01.708 0z"],"arrow-bottom-left":["M14 3a1.003 1.003 0 00-1.71-.71L4 10.59V6c0-.55-.45-1-1-1s-1 .45-1 1v7c0 .55.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1H5.41l8.29-8.29c.19-.18.3-.43.3-.71z"],"arrow-bottom-right":["M13 5c-.55 0-1 .45-1 1v4.59l-8.29-8.3a1.003 1.003 0 00-1.42 1.42l8.3 8.29H6c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1z"],"arrow-down":["M13 8c-.3 0-.5.1-.7.3L9 11.6V2c0-.5-.4-1-1-1s-1 .5-1 1v9.6L3.7 8.3C3.5 8.1 3.3 8 3 8c-.5 0-1 .5-1 1 0 .3.1.5.3.7l5 5c.2.2.4.3.7.3s.5-.1.7-.3l5-5c.2-.2.3-.4.3-.7 0-.6-.4-1-1-1z"],"arrow-left":["M13.99 6.99H4.41L7.7 3.7a1.003 1.003 0 00-1.42-1.42l-5 5a1.014 1.014 0 000 1.42l5 5a1.003 1.003 0 001.42-1.42L4.41 8.99H14c.55 0 1-.45 1-1s-.46-1-1.01-1z"],"arrow-right":["M14.7 7.29l-5-5a.965.965 0 00-.71-.3 1.003 1.003 0 00-.71 1.71l3.29 3.29H1.99c-.55 0-1 .45-1 1s.45 1 1 1h9.59l-3.29 3.29a1.003 1.003 0 001.42 1.42l5-5c.18-.18.29-.43.29-.71s-.12-.52-.3-.7z"],"arrow-top-left":["M13.71 12.29L5.41 4H10c.55 0 1-.45 1-1s-.45-1-1-1H3c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1s1-.45 1-1V5.41l8.29 8.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"arrow-top-right":["M13 2H6c-.55 0-1 .45-1 1s.45 1 1 1h4.59L2.3 12.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L12 5.41V10c0 .55.45 1 1 1s1-.45 1-1V3c0-.55-.45-1-1-1z"],"arrow-up":["M13.7 6.3l-5-5C8.5 1.1 8.3 1 8 1s-.5.1-.7.3l-5 5c-.2.2-.3.4-.3.7 0 .6.5 1 1 1 .3 0 .5-.1.7-.3L7 4.4V14c0 .6.4 1 1 1s1-.4 1-1V4.4l3.3 3.3c.2.2.4.3.7.3.6 0 1-.4 1-1 0-.3-.1-.5-.3-.7z"],"arrows-horizontal":["M15.7 7.3l-4-4c-.2-.2-.4-.3-.7-.3-.6 0-1 .5-1 1 0 .3.1.5.3.7L12.6 7H3.4l2.3-2.3c.2-.2.3-.4.3-.7 0-.5-.4-1-1-1-.3 0-.5.1-.7.3l-4 4c-.2.2-.3.4-.3.7s.1.5.3.7l4 4c.2.2.4.3.7.3.6 0 1-.4 1-1 0-.3-.1-.5-.3-.7L3.4 9h9.2l-2.3 2.3c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3l4-4c.2-.2.3-.4.3-.7s-.1-.5-.3-.7z"],"arrows-vertical":["M12 10c-.3 0-.5.1-.7.3L9 12.6V3.4l2.3 2.3c.2.2.4.3.7.3.6 0 1-.4 1-1 0-.3-.1-.5-.3-.7l-4-4C8.5.1 8.3 0 8 0s-.5.1-.7.3l-4 4c-.2.2-.3.4-.3.7 0 .6.5 1 1 1 .3 0 .5-.1.7-.3L7 3.4v9.2l-2.3-2.3c-.2-.2-.4-.3-.7-.3-.5 0-1 .4-1 1 0 .3.1.5.3.7l4 4c.2.2.4.3.7.3s.5-.1.7-.3l4-4c.2-.2.3-.4.3-.7 0-.6-.4-1-1-1z"],asterisk:["M14.54 11.18l.01-.02L9.8 8l4.75-3.17-.01-.02c.27-.17.46-.46.46-.81 0-.55-.45-1-1-1-.21 0-.39.08-.54.18l-.01-.02L9 6.13V1c0-.55-.45-1-1-1S7 .45 7 1v5.13L2.55 3.17l-.01.01A.969.969 0 002 3c-.55 0-1 .45-1 1 0 .35.19.64.46.82l-.01.01L6.2 8l-4.75 3.17.01.02c-.27.17-.46.46-.46.81 0 .55.45 1 1 1 .21 0 .39-.08.54-.18l.01.02L7 9.87V15c0 .55.45 1 1 1s1-.45 1-1V9.87l4.45 2.96.01-.02c.15.11.33.19.54.19.55 0 1-.45 1-1 0-.35-.19-.64-.46-.82z"],"automatic-updates":["M8 14c-3.31 0-6-2.69-6-6 0-1.77.78-3.36 2-4.46V5c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1H1C.45 0 0 .45 0 1s.45 1 1 1h1.74A7.95 7.95 0 000 8c0 4.42 3.58 8 8 8 .55 0 1-.45 1-1s-.45-1-1-1zM8 2a5.9 5.9 0 012.95.81l1.47-1.47A7.893 7.893 0 008 0c-.55 0-1 .45-1 1s.45 1 1 1zm2.71 6.71l5-5a1.003 1.003 0 00-1.42-1.42L10 6.59l-1.29-1.3a1.003 1.003 0 00-1.42 1.42l2 2c.18.18.43.29.71.29s.53-.11.71-.29zM16 8c0-.55-.06-1.08-.16-1.6l-1.87 1.87A5.966 5.966 0 0112 12.45V11c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1h-1.74A7.95 7.95 0 0016 8z"],backlink:["M14 10a1 1 0 110 2h-.585l2.292 2.293a1 1 0 01-1.32 1.497l-.094-.083L12 13.415V14a1 1 0 11-2 0l.003-3.075.012-.1.012-.059.033-.108.034-.081.052-.098.067-.096.08-.09a1.01 1.01 0 01.112-.097l.11-.071.143-.065.076-.024.091-.02.116-.014L14 10zM6.036 6.136l-3.45 3.45-.117.127a2 2 0 002.818 2.818l.127-.117 3.45-3.449a4 4 0 01-.885 3.704l-.15.16-1 1A4 4 0 011.02 8.33l.15-.16 1-1a3.998 3.998 0 013.865-1.035zm4.671-1.843a1 1 0 01.083 1.32l-.083.094-5 5a1 1 0 01-1.497-1.32l.083-.094 5-5a1 1 0 011.414 0zm3.121-3.121a4 4 0 01.151 5.497l-.15.16-1 1a3.998 3.998 0 01-3.864 1.036l3.45-3.45.116-.128a2 2 0 00-2.818-2.818l-.127.117-3.45 3.45A4 4 0 017.02 2.33l.15-.16 1-1a4 4 0 015.657 0z"],badge:["M13.36 4.59c-.15-1.13.5-2.01 1.1-2.87L13.43.53c-1.72.88-4.12.65-5.63-.53-1.51 1.18-3.91 1.41-5.63.52l-1.03 1.2c.61.86 1.25 1.74 1.1 2.87-.3 2.29-2.45 4.17-1.32 6.68.45 1.14 1.44 1.9 2.72 2.2 1.56.36 3.52.72 4.16 2.53.64-1.81 2.6-2.16 4.16-2.54 1.28-.3 2.27-1.06 2.72-2.2 1.12-2.5-1.03-4.38-1.32-6.67z"],"ban-circle":["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm3 9H5c-.55 0-1-.45-1-1s.45-1 1-1h6c.55 0 1 .45 1 1s-.45 1-1 1z"],"bank-account":["M15.36 6.46l-.62-.14c-.31-1.12-.98-2.15-1.87-2.99l.4-1.77a.438.438 0 00-.49-.56c-.85.09-1.6.42-2.14.98-.84-.32-1.87-.51-2.85-.51-2.49 0-4.63 1.17-5.92 2.89-.18-.04-.36-.09-.53-.09-.76 0-1.34.61-1.34 1.4 0 .56.31 1.03.76 1.26-.05.33-.09.7-.09 1.07 0 1.68.71 3.17 1.83 4.34l-.27 1.59c-.09.56.35 1.07.89 1.07h.58c.45 0 .8-.33.89-.79l.04-.37c.94.42 2 .7 3.16.7 1.11 0 2.23-.23 3.16-.7l.05.37c.09.47.45.79.89.79h.58c.53 0 .98-.51.89-1.07l-.27-1.54c.62-.61 1.07-1.35 1.38-2.15l.8-.19c.4-.09.71-.47.71-.93V7.4c.09-.47-.22-.84-.62-.94zM12 8c-.6 0-1-.7-1-1.5S11.4 5 12 5s1 .7 1 1.5S12.6 8 12 8zM6.21 4.92c-.41.2-.91.04-1.12-.36-.21-.4-.04-.88.37-1.07 1.35-.65 2.73-.65 4.08 0 .41.2.58.68.37 1.07-.21.4-.71.56-1.12.36-.87-.43-1.71-.43-2.58 0z"],barcode:["M0 14h2V2H0v12zm6 0h1V2H6v12zm2 0h1V2H8v12zm-5 0h2V2H3v12zM15 2v12h1V2h-1zm-5 12h1V2h-1v12zm2 0h2V2h-2v12z"],blank:[],"blocked-person":["M9.39 12.69c-1.2-.53-1.04-.85-1.08-1.29-.01-.07-.01-.13-.02-.2.41-.37.75-.87.97-1.44 0 0 .01-.03.01-.04.05-.13.09-.26.13-.39.27-.06.43-.36.5-.63.01-.03.03-.08.05-.12C8.18 7.8 6.94 6.04 6.94 4c0-.32.04-.62.09-.92-.17-.03-.35-.08-.51-.08-.65 0-1.37.2-1.88.59-.5.38-.87.92-1.05 1.51-.04.14-.07.27-.09.41-.09.48-.14 1.23-.14 1.74v.06c-.19.08-.36.27-.4.68-.03.31.1.59.16.7.06.28.23.59.51.64.04.14.08.27.13.39 0 .01.01.02.01.02v.01c.22.59.57 1.1.99 1.46 0 .06-.01.12-.01.17-.04.44.08.76-1.12 1.29-1.2.53-3.01 1.1-3.38 1.95C-.12 15.5.03 16 .03 16h12.96s.15-.5-.22-1.36c-.37-.85-2.18-1.42-3.38-1.95zM11.97 0C9.75 0 7.94 1.79 7.94 4s1.8 4 4.03 4S16 6.21 16 4s-1.8-4-4.03-4zM9.96 4c0-1.1.9-2 2.01-2 .37 0 .72.11 1.02.28l-2.75 2.73c-.17-.3-.28-.64-.28-1.01zm2.01 2c-.37 0-.72-.11-1.02-.28l2.75-2.73c.18.3.28.64.28 1.01.01 1.1-.9 2-2.01 2z"],bold:["M11.7 7c.2-.4.3-1 .3-1.5v-.4V5c0-.1 0-.2-.1-.3v-.1C11.4 3.1 10.1 2 8.5 2H4c-.5 0-1 .4-1 1v10c0 .5.4 1 1 1h5c2.2 0 4-1.8 4-4 0-1.2-.5-2.3-1.3-3zM6 5h2c.6 0 1 .4 1 1s-.4 1-1 1H6V5zm3 6H6V9h3c.6 0 1 .4 1 1s-.4 1-1 1z"],book:["M2 1v14c0 .55.45 1 1 1h1V0H3c-.55 0-1 .45-1 1zm11-1h-1v7l-2-2-2 2V0H5v16h8c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],bookmark:["M11.2.01h-.15C11.03.01 11.02 0 11 0H5c-.02 0-.03.01-.05.01H4.8c-.44 0-.8.37-.8.82v14.75c0 .45.25.56.57.24l2.87-2.94c.31-.32.82-.32 1.13 0l2.87 2.94c.31.32.57.21.57-.24V.83C12 .38 11.64.01 11.2.01z"],box:["M6 10h4c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1s.45 1 1 1zm9.93-4.37v-.02L13.94.63C13.78.26 13.42 0 13 0H3c-.42 0-.78.26-.93.63L.08 5.61l-.01.02C.03 5.74 0 5.87 0 6v9c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V6c0-.13-.03-.26-.07-.37zM9 2h3.32l1.2 3H9V2zM3.68 2H7v3H2.48l1.2-3zM14 14H2V7h12v7z"],briefcase:["M15 3.98h-3v-2c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v2H1c-.55 0-1 .45-1 1v4h3v-1h2v1h6v-1h2v1h3v-4c0-.55-.45-1-1-1zm-5 0H6v-1h4v1zm3 7h-2v-1H5v1H3v-1H0v4c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-4h-3v1z"],"bring-data":["M14 14a1 1 0 010 2H2a1 1 0 010-2h12zM7.995 3.005c.55 0 1 .45 1 .999v5.584l1.29-1.288a1.002 1.002 0 011.42 1.419l-3 2.996a1.015 1.015 0 01-1.42 0l-3-2.997A1.002 1.002 0 015.705 8.3l1.29 1.29V4.013c0-.55.45-1.009 1-1.009zM14 0a1 1 0 110 2 1 1 0 010-2zm-3 0a1 1 0 110 2 1 1 0 010-2zM8 0a1 1 0 110 2 1 1 0 010-2zM5 0a1 1 0 110 2 1 1 0 010-2zM2 0a1 1 0 110 2 1 1 0 010-2z"],buggy:["M13.928.629A1 1 0 0012.89.006l-9 1a1 1 0 00-.747.48L.431 6.005A.5.5 0 000 6.5v3a.5.5 0 00.5.5h2.798c.341 0 .672.116.938.329l1.952 1.561A.5.5 0 006.5 12H10a.5.5 0 00.4-.2l.9-1.2a1.5 1.5 0 011.2-.6h3a.5.5 0 00.5-.5v-4a.5.5 0 00-.308-.462L13.928.628zM12.36 2.094l-.006-.016-3.166.352 1.121 3.083 2.052-3.419zm.467 1.166l-1.649 2.748 2.51-.594-.861-2.154zM9.603 6.496L8.166 2.543l-3.563.396L2.766 6H3.5a.5.5 0 01.367.16L6.218 8.7h1.914l1.452-2.177a.5.5 0 01.019-.027zM2.5 16a2.5 2.5 0 100-5 2.5 2.5 0 000 5zm11 0a2.5 2.5 0 100-5 2.5 2.5 0 000 5z"],build:["M15.39 12.41L7.7 6l1.07-1.1c.34-.34-.12-.63.12-1.26.88-2.17 3.41-2.35 3.41-2.35s.36-.37.71-.72C9.74-.81 7.53.53 6.54 1.4L3.12 4.9l-.71.72c-.39.4-.39 1.05 0 1.45l-.7.72c-.39-.4-1.02-.4-1.41 0s-.39 1.05 0 1.45l1.41 1.45c.39.4 1.02.4 1.41 0s.39-1.05 0-1.45l.71-.72c.39.4 1.02.4 1.41 0l.8-.82 6.39 7.67c.82.82 2.14.82 2.96 0 .81-.82.81-2.15 0-2.96z"],calculator:["M13 0H3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM6 14H4v-2h2v2zm0-3H4V9h2v2zm0-3H4V6h2v2zm3 6H7v-2h2v2zm0-3H7V9h2v2zm0-3H7V6h2v2zm3 6h-2V9h2v5zm0-6h-2V6h2v2zm0-3H4V2h8v3z"],calendar:["M11 3c.6 0 1-.5 1-1V1c0-.6-.4-1-1-1s-1 .4-1 1v1c0 .5.4 1 1 1zm3-2h-1v1c0 1.1-.9 2-2 2s-2-.9-2-2V1H6v1c0 1.1-.9 2-2 2s-2-.9-2-2V1H1c-.6 0-1 .5-1 1v12c0 .6.4 1 1 1h13c.6 0 1-.4 1-1V2c0-.6-.5-1-1-1zM5 13H2v-3h3v3zm0-4H2V6h3v3zm4 4H6v-3h3v3zm0-4H6V6h3v3zm4 4h-3v-3h3v3zm0-4h-3V6h3v3zM4 3c.6 0 1-.5 1-1V1c0-.6-.4-1-1-1S3 .4 3 1v1c0 .5.4 1 1 1z"],camera:["M15 3h-2.59L10.7 1.29A.956.956 0 0010 1H6c-.28 0-.53.11-.71.29L3.59 3H1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h2.56c1.1 1.22 2.67 2 4.44 2s3.34-.78 4.44-2H15c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zM3 6H1V5h2v1zm5 6c-2.21 0-4-1.79-4-4s1.79-4 4-4 4 1.79 4 4-1.79 4-4 4zm0-6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],"caret-down":["M12 6.5c0-.28-.22-.5-.5-.5h-7a.495.495 0 00-.37.83l3.5 4c.09.1.22.17.37.17s.28-.07.37-.17l3.5-4c.08-.09.13-.2.13-.33z"],"caret-left":["M9.5 4c-.13 0-.24.05-.33.13l-4 3.5c-.1.09-.17.22-.17.37s.07.28.17.37l4 3.5a.495.495 0 00.83-.37v-7c0-.28-.22-.5-.5-.5z"],"caret-right":["M11 8c0-.15-.07-.28-.17-.37l-4-3.5A.495.495 0 006 4.5v7a.495.495 0 00.83.37l4-3.5c.1-.09.17-.22.17-.37z"],"caret-up":["M11.87 9.17s.01 0 0 0l-3.5-4C8.28 5.07 8.15 5 8 5s-.28.07-.37.17l-3.5 4a.495.495 0 00.37.83h7a.495.495 0 00.37-.83z"],"cargo-ship":["M10 1h3a1 1 0 011 1v2h-4V1zM2.25 4a.25.25 0 00-.25.25V9H.883a.5.5 0 00-.429.757l1.072 1.787c.207.344.477.638.791.87A9.76 9.76 0 011 12.5a.5.5 0 000 1c2.067 0 3.414-.543 4.161-.917.55.373 1.505.917 2.839.917 1.32 0 2.27-.533 2.822-.905l.004.002c.196.105.48.24.856.374.75.268 1.857.529 3.318.529a.5.5 0 000-1c-.326 0-.63-.014-.916-.039.47-.328.848-.79 1.07-1.347l.572-1.428A.5.5 0 0015.26 9H4V4.25A.25.25 0 003.75 4h-1.5zm2.714 9.56a.5.5 0 01.527.033c.455.325 1.277.907 2.509.907s2.054-.582 2.51-.907a.5.5 0 01.579-.001l.006.004.036.023c.034.022.09.055.168.097.154.082.394.197.72.313.649.232 1.642.471 2.981.471a.5.5 0 010 1c-1.46 0-2.568-.261-3.318-.53a6.316 6.316 0 01-.856-.373l-.004-.002c-.552.372-1.502.905-2.822.905-1.334 0-2.289-.544-2.839-.917-.747.374-2.094.917-4.161.917a.5.5 0 010-1c2.129 0 3.384-.63 3.964-.94zM14 5h-4v3h3a1 1 0 001-1V5zM5 2a1 1 0 011-1h3v3H5V2zm4 3H5v2a1 1 0 001 1h3V5z"],"cell-tower":["M8.97 6.76c-.01-.05-.04-.08-.06-.13-.02-.05-.03-.1-.05-.15.08-.14.14-.3.14-.48 0-.55-.45-1-1-1s-1 .45-1 1c0 .18.06.34.14.48-.03.05-.03.1-.05.15-.02.05-.05.08-.06.13l-2 8c-.13.54.19 1.08.73 1.21a.995.995 0 001.21-.73L7.53 13h.94l.56 2.24a1 1 0 001.94-.48l-2-8zM3.72 1.7C4.1 1.3 4.09.67 3.7.28S2.67-.09 2.28.3c-3.05 3.12-3.05 8.28 0 11.4a.996.996 0 101.43-1.39c-2.28-2.35-2.28-6.27.01-8.61zM11.6 3.2c-.44-.33-1.07-.24-1.4.2-.33.44-.24 1.07.2 1.4.43.32.53 1.96-.04 2.43-.42.35-.48.98-.13 1.41.35.42.98.48 1.41.13 1.59-1.33 1.39-4.5-.04-5.57z","M13.72.3c-.39-.4-1.02-.4-1.41-.02s-.41 1.02-.03 1.42c2.29 2.34 2.29 6.26 0 8.6-.39.39-.38 1.03.02 1.41s1.03.38 1.41-.02c3.05-3.11 3.05-8.27.01-11.39zM5.4 7.23c-.57-.47-.47-2.11-.04-2.43.44-.33.53-.96.2-1.4s-.96-.53-1.4-.2c-1.44 1.07-1.63 4.24-.04 5.57.42.35 1.05.3 1.41-.13.35-.42.29-1.06-.13-1.41z"],changes:["M8.29 7.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3a1.003 1.003 0 00-1.42-1.42L13 7.59V1c0-.55-.45-1-1-1s-1 .45-1 1v6.59l-1.29-1.3a1.003 1.003 0 00-1.42 1.42zM14.5 13h-13c-.83 0-1.5.67-1.5 1.5S.67 16 1.5 16h13c.83 0 1.5-.67 1.5-1.5s-.67-1.5-1.5-1.5zM1 5c.28 0 .53-.11.71-.29L3 3.41V10c0 .55.45 1 1 1s1-.45 1-1V3.41L6.29 4.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3C4.53.11 4.28 0 4 0s-.53.11-.71.29l-3 3A1.003 1.003 0 001 5z"],chart:["M0 15c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V9.4L0 11v4zm6-5.5V15c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-5l-1 1-3-1.5zM13 7l-1 1v7c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V7.88c-.26.07-.58.12-1 .12-1.96 0-2-1-2-1zm2-6h-3c-.55 0-1 .45-1 1s.45 1 1 1h.59L8.8 6.78 5.45 5.11v.01C5.31 5.05 5.16 5 5 5s-.31.05-.44.11V5.1l-4 2v.01C.23 7.28 0 7.61 0 8c0 .55.45 1 1 1 .16 0 .31-.05.44-.11v.01L5 7.12 8.55 8.9v-.01c.14.06.29.11.45.11.28 0 .53-.11.71-.29L14 4.41V5c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],chat:["M6 10c-1.1 0-2-.9-2-2V3H1c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1v2a1.003 1.003 0 001.71.71L5.41 13H10c.55 0 1-.45 1-1v-1.17l-.83-.83H6zm9-10H6c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h4.59l2.71 2.71c.17.18.42.29.7.29.55 0 1-.45 1-1V9c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"chevron-backward":["M7.41 8l3.29-3.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L6 6.59V4c0-.55-.45-1-1-1s-1 .45-1 1v8c0 .55.45 1 1 1s1-.45 1-1V9.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L7.41 8z"],"chevron-down":["M12 5c-.28 0-.53.11-.71.29L8 8.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4c.18.18.43.29.71.29s.53-.11.71-.29l4-4A1.003 1.003 0 0012 5z"],"chevron-forward":["M10 3c-.55 0-1 .45-1 1v2.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42L7.59 8 4.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L9 9.41V12c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1z"],"chevron-left":["M7.41 8l3.29-3.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C5.11 7.47 5 7.72 5 8c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L7.41 8z"],"chevron-right":["M10.71 7.29l-4-4a1.003 1.003 0 00-1.42 1.42L8.59 8 5.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"chevron-up":["M12.71 9.29l-4-4C8.53 5.11 8.28 5 8 5s-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L8 7.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],circle:["M8 0C3.6 0 0 3.6 0 8s3.6 8 8 8 8-3.6 8-8-3.6-8-8-8zm0 14c-3.3 0-6-2.7-6-6s2.7-6 6-6 6 2.7 6 6-2.7 6-6 6z"],"circle-arrow-down":["M11 7c-.28 0-.53.11-.71.29L9 8.59V5c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-1.29-1.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 0011 7zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],"circle-arrow-left":["M11 7H7.41L8.7 5.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C4.11 7.47 4 7.72 4 8c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L7.41 9H11c.55 0 1-.45 1-1s-.45-1-1-1zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],"circle-arrow-right":["M8.71 4.29a1.003 1.003 0 00-1.42 1.42L8.59 7H5c-.55 0-1 .45-1 1s.45 1 1 1h3.59L7.3 10.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],"circle-arrow-up":["M8.71 4.29C8.53 4.11 8.28 4 8 4s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L7 7.41V11c0 .55.45 1 1 1s1-.45 1-1V7.41l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],citation:["M15.02 5c0-1.66-1.34-3-3-3s-3 1.34-3 3a2.996 2.996 0 003.6 2.94C12.1 9.76 11.14 11 10.02 11c-.55 0-1 .45-1 1s.45 1 1 1c2.76 0 5-3.13 5-7 0-.2-.02-.39-.04-.58.01-.14.04-.28.04-.42zm-11-3c-1.66 0-3 1.34-3 3a2.996 2.996 0 003.6 2.94C4.1 9.76 3.14 11 2.02 11c-.55 0-1 .45-1 1s.45 1 1 1c2.76 0 5-3.13 5-7 0-.2-.02-.39-.04-.58.01-.14.04-.28.04-.42 0-1.66-1.35-3-3-3z"],clean:["M12 8l-1.2 2.796-2.8 1.2 2.8 1.197L12 16l1.2-2.807L16 12l-2.8-1.204zM5 0L3.5 3.5 0 4.995 3.5 6.5 5 10l1.5-3.5L10 5 6.5 3.5z"],clip:["M0 1a1 1 0 011-1h4a1 1 0 010 2H2v3a1 1 0 01-2 0V1zm1 15a1 1 0 01-1-1v-4a1 1 0 112 0v3h3a1 1 0 110 2H1zm14 0a1 1 0 001-1v-4a1 1 0 10-2 0v3h-3a1 1 0 100 2h4zm0-16a1 1 0 011 1v4a1 1 0 11-2 0V2h-3a1 1 0 110-2h4zM8 11a3 3 0 100-6 3 3 0 000 6z"],clipboard:["M11 2c0-.55-.45-1-1-1h.22C9.88.4 9.24 0 8.5 0S7.12.4 6.78 1H7c-.55 0-1 .45-1 1v1h5V2zm2 0h-1v2H5V2H4c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],cloud:["M12 6c-.03 0-.07 0-.1.01A5 5 0 002 7c0 .11.01.22.02.33A3.51 3.51 0 000 10.5C0 12.43 1.57 14 3.5 14H12c2.21 0 4-1.79 4-4s-1.79-4-4-4z"],"cloud-download":["M11 11c-.28 0-.53.11-.71.29L9 12.59V8c0-.55-.45-1-1-1s-1 .45-1 1v4.59L5.71 11.3A.965.965 0 005 11a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 0011 11zm1-7c-.03 0-.07 0-.1.01A5 5 0 002 5c0 .11.01.22.02.33A3.51 3.51 0 000 8.5c0 1.41.84 2.61 2.03 3.17C2.2 10.17 3.46 9 5 9c.06 0 .13.02.19.02C5.07 8.7 5 8.36 5 8c0-1.66 1.34-3 3-3s3 1.34 3 3c0 .36-.07.7-.19 1.02.06 0 .13-.02.19-.02 1.48 0 2.7 1.07 2.95 2.47A3.964 3.964 0 0016 8c0-2.21-1.79-4-4-4z"],"cloud-upload":["M8.71 7.29C8.53 7.11 8.28 7 8 7s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L7 10.41V15c0 .55.45 1 1 1s1-.45 1-1v-4.59l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3zM12 4c-.03 0-.07 0-.1.01A5 5 0 002 5c0 .11.01.22.02.33a3.495 3.495 0 00.07 6.37c-.05-.23-.09-.46-.09-.7 0-.83.34-1.58.88-2.12l3-3a2.993 2.993 0 014.24 0l3 3c.54.54.88 1.29.88 2.12 0 .16-.02.32-.05.47C15.17 10.78 16 9.5 16 8c0-2.21-1.79-4-4-4z"],code:["M15.71 7.29l-3-3a1.003 1.003 0 00-1.42 1.42L13.59 8l-2.29 2.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM5 5a1.003 1.003 0 00-1.71-.71l-3 3C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L2.41 8 4.7 5.71c.19-.18.3-.43.3-.71zm4-3c-.48 0-.87.35-.96.81l-2 10c-.01.06-.04.12-.04.19 0 .55.45 1 1 1 .48 0 .87-.35.96-.81l2-10c.01-.06.04-.12.04-.19 0-.55-.45-1-1-1z"],"code-block":["M15 3h-2V2c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1v1H7V2c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v1H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zm-8.29 8.29a1.003 1.003 0 01-1.42 1.42l-3-3C2.11 9.53 2 9.28 2 9s.11-.53.29-.71l3-3a1.003 1.003 0 011.42 1.42L4.41 9l2.3 2.29zm7-1.58l-3 3a1.003 1.003 0 01-1.42-1.42L11.59 9l-2.3-2.29a1.003 1.003 0 011.42-1.42l3 3c.18.18.29.43.29.71s-.11.53-.29.71z"],cog:["M15.19 6.39h-1.85c-.11-.37-.27-.71-.45-1.04l1.36-1.36c.31-.31.31-.82 0-1.13l-1.13-1.13a.803.803 0 00-1.13 0l-1.36 1.36c-.33-.17-.67-.33-1.04-.44V.79c0-.44-.36-.8-.8-.8h-1.6c-.44 0-.8.36-.8.8v1.86c-.39.12-.75.28-1.1.47l-1.3-1.3c-.3-.3-.79-.3-1.09 0L1.82 2.91c-.3.3-.3.79 0 1.09l1.3 1.3c-.2.34-.36.7-.48 1.09H.79c-.44 0-.8.36-.8.8v1.6c0 .44.36.8.8.8h1.85c.11.37.27.71.45 1.04l-1.36 1.36c-.31.31-.31.82 0 1.13l1.13 1.13c.31.31.82.31 1.13 0l1.36-1.36c.33.18.67.33 1.04.44v1.86c0 .44.36.8.8.8h1.6c.44 0 .8-.36.8-.8v-1.86c.39-.12.75-.28 1.1-.47l1.3 1.3c.3.3.79.3 1.09 0l1.09-1.09c.3-.3.3-.79 0-1.09l-1.3-1.3c.19-.35.36-.71.48-1.1h1.85c.44 0 .8-.36.8-.8v-1.6a.816.816 0 00-.81-.79zm-7.2 4.6c-1.66 0-3-1.34-3-3s1.34-3 3-3 3 1.34 3 3-1.34 3-3 3z"],"collapse-all":["M7.29 6.71c.18.18.43.29.71.29s.53-.11.71-.29l4-4a1.003 1.003 0 00-1.42-1.42L8 4.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4zm1.42 2.58C8.53 9.11 8.28 9 8 9s-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L8 11.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4z"],"column-layout":["M15 1H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM4 13H2V3h2v10zm3 0H5V3h2v10zm7 0H8V3h6v10z"],comment:["M14 1H1c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h2v3a1.003 1.003 0 001.71.71L8.41 12H14c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM3.5 8C2.67 8 2 7.33 2 6.5S2.67 5 3.5 5 5 5.67 5 6.5 4.33 8 3.5 8zm4 0C6.67 8 6 7.33 6 6.5S6.67 5 7.5 5 9 5.67 9 6.5 8.33 8 7.5 8zm4 0c-.83 0-1.5-.67-1.5-1.5S10.67 5 11.5 5s1.5.67 1.5 1.5S12.33 8 11.5 8z"],comparison:["M7.99-.01c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1v-14c0-.55-.45-1-1-1zm-3 3h-4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zm10 0h-4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zm0 3h-4v-2h4v2zm0 3h-4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zm0 3h-4v-2h4v2zm-10-3h-4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1z"],compass:["M12 8c0 .14-.03.27-.08.39l-3 6.99c-.15.37-.51.62-.92.62s-.77-.25-.92-.61l-3-6.99a1.006 1.006 0 010-.79l3-6.99C7.23.25 7.59 0 8 0s.77.25.92.61l3 6.99c.05.13.08.26.08.4zM8 3.54L6.09 8h3.82L8 3.54z"],compressed:["M15.93 5.63v-.02L13.94.63C13.78.26 13.42 0 13 0H3c-.42 0-.78.26-.93.63L.08 5.61l-.01.02C.03 5.74 0 5.87 0 6v9c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V6c0-.13-.03-.26-.07-.37zM9 2h3.32l1.2 3H9V2zM3.68 2H7v3H2.48l1.2-3zM14 14H2V7h5v2.59l-1.29-1.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3a1.003 1.003 0 00-1.42-1.42L9 9.59V7h5v7z"],confirm:["M8.7 4.29a.965.965 0 00-.71-.3 1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l5-5a1.003 1.003 0 00-1.42-1.42l-4.29 4.3L8.7 4.29zm5.22 3.01c.03.23.07.45.07.69 0 3.31-2.69 6-6 6s-6-2.69-6-6 2.69-6 6-6c.81 0 1.59.17 2.3.46l1.5-1.5A7.998 7.998 0 00-.01 7.99c0 4.42 3.58 8 8 8s8-3.58 8-8c0-.83-.13-1.64-.36-2.39l-1.71 1.7z"],console:["M15 15H1c-.55 0-1-.45-1-1V2c0-.55.45-1 1-1h14c.55 0 1 .45 1 1v12c0 .55-.45 1-1 1zM14 5H2v8h12V5zM4 6c.28 0 .53.11.71.29l2 2c.18.18.29.43.29.71s-.11.53-.29.71l-2 2a1.003 1.003 0 01-1.42-1.42L4.59 9l-1.3-1.29A1.003 1.003 0 014 6zm5 4h3c.55 0 1 .45 1 1s-.45 1-1 1H9c-.55 0-1-.45-1-1s.45-1 1-1z"],contrast:["M15.2 6.4h-1.44c-.13-.47-.32-.92-.56-1.34L14.26 4c.31-.31.31-.82 0-1.13l-1.13-1.13a.803.803 0 00-1.13 0L10.94 2.8c-.42-.24-.86-.42-1.34-.56V.8c0-.44-.36-.8-.8-.8H7.2c-.44 0-.8.36-.8.8v1.44c-.5.14-.96.34-1.4.59l-1-1c-.3-.3-.79-.3-1.09 0L1.83 2.91c-.3.3-.3.79 0 1.09l1 1c-.25.44-.45.9-.59 1.4H.8c-.44 0-.8.36-.8.8v1.6c0 .44.36.8.8.8h1.44c.13.47.32.92.56 1.34L1.74 12c-.31.31-.31.82 0 1.13l1.13 1.13c.31.31.82.31 1.13 0l1.06-1.06c.42.24.86.42 1.34.56v1.44c0 .44.36.8.8.8h1.6c.44 0 .8-.36.8-.8v-1.44c.5-.14.96-.33 1.4-.59l1 1c.3.3.79.3 1.09 0l1.09-1.09c.3-.3.3-.79 0-1.09l-1-1c.25-.43.45-.9.59-1.4h1.44c.44 0 .8-.36.8-.8V7.2a.818.818 0 00-.81-.8zM8 12c-2.21 0-4-1.79-4-4s1.79-4 4-4v8z"],control:["M13 8H8v5h5V8zm0-5H8v4h5V3zm2-3H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2V2h12v12zM7 3H3v10h4V3z"],"credit-card":["M14.99 2.95h-14c-.55 0-1 .45-1 1v1h16v-1c0-.55-.45-1-1-1zm-15 10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-6h-16v6zm5.5-2h5c.28 0 .5.22.5.5s-.22.5-.5.5h-5c-.28 0-.5-.22-.5-.5s.23-.5.5-.5zm-3 0h1c.28 0 .5.22.5.5s-.22.5-.5.5h-1c-.28 0-.5-.22-.5-.5s.23-.5.5-.5z"],cross:["M9.41 8l3.29-3.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L8 6.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42L6.59 8 3.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L8 9.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L9.41 8z"],crown:["M2 6l3 2 3-4 3 4 3-2-1 6H3L2 6zm6-5a1 1 0 110 2 1 1 0 010-2zM1 3a1 1 0 110 2 1 1 0 010-2zm14 0a1 1 0 110 2 1 1 0 010-2zM3 13h10v2H3v-2z"],cube:["M14.194 3.54L8 7.41 1.806 3.54 7.504.283a1 1 0 01.992 0l5.698 3.255zm.75.71a1 1 0 01.056.33v6.84a1 1 0 01-.504.868L8.5 15.714V8.277l6.444-4.027zm-13.888 0L7.5 8.277v7.437l-5.996-3.426A1 1 0 011 11.42V4.58a1 1 0 01.056-.33z"],"cube-add":["M14 2h1a1 1 0 010 2h-1v1a1 1 0 01-2 0V4h-1a1 1 0 010-2h1V1a1 1 0 012 0v1zM9.136.65a3.001 3.001 0 00.992 5.222c.018.058.038.115.059.172L8 7.41 1.806 3.54 7.504.283a1 1 0 01.992 0l.64.365zM15 7.235v4.184a1 1 0 01-.504.868L8.5 15.714V8.277l2.187-1.367A2.994 2.994 0 0013 8c.768 0 1.47-.289 2-.764zM1.056 4.25L7.5 8.277v7.437l-5.996-3.426A1 1 0 011 11.42V4.58a1 1 0 01.056-.33z"],"cube-remove":["M10.365 5.933L8 7.41 1.806 3.54 7.504.283a1 1 0 01.992 0l.64.365a3.001 3.001 0 001.228 5.283zM15 6v5.42a1 1 0 01-.504.868L8.5 15.714V8.277L12.143 6H15zM1.056 4.25L7.5 8.277v7.437l-5.996-3.426A1 1 0 011 11.42V4.58a1 1 0 01.056-.33zM11 2h4a1 1 0 010 2h-4a1 1 0 010-2z"],"curved-range-chart":["M15 12H3.12l1.81-1.39c1.73 1.01 5.53-.03 9.08-2.61l-1.22-1.5C10.3 8.3 7.86 9.37 6.65 9.29L14.3 3.4l-.6-.8-7.83 6.03c-.01-1.07 1.8-3.19 4.47-5.13L9.12 2C5.38 4.7 3.34 8.1 4.25 9.87L2 11.6V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],cut:["M13 2s.71-1.29 0-2L8.66 5.07l1.05 1.32L13 2zm.07 8c-.42 0-.82.09-1.18.26L3.31 0c-.69.71 0 2 0 2l3.68 5.02-2.77 3.24A2.996 2.996 0 000 13c0 1.66 1.34 3 3 3s3-1.34 3-3c0-.46-.11-.89-.29-1.27L8.1 8.54l2.33 3.19c-.18.39-.29.82-.29 1.27 0 1.66 1.31 3 2.93 3S16 14.66 16 13s-1.31-3-2.93-3zM3 14c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm10.07 0c-.54 0-.98-.45-.98-1s.44-1 .98-1 .98.45.98 1-.44 1-.98 1z"],cycle:["M13 9a3 3 0 110 6 3 3 0 010-6zM3 9a3 3 0 110 6 3 3 0 010-6zm6.169-5.27l.087.09 1.51 1.746 1.589.549a1 1 0 01.65 1.16l-.032.112a1 1 0 01-1.159.65l-.112-.032-1.843-.636a1 1 0 01-.337-.198l-.092-.093-.959-1.109L7.041 7.5l1.691 1.819a1 1 0 01.26.556L9 10v3a1 1 0 01-1.993.117L7 13l-.001-2.608-2.056-2.211a1 1 0 01-.081-1.264l.082-.1 2.825-3.026a1 1 0 011.4-.061zM13 10.5a1.5 1.5 0 100 3 1.5 1.5 0 000-3zm-10 0a1.5 1.5 0 100 3 1.5 1.5 0 000-3zM11 1a1.5 1.5 0 110 3 1.5 1.5 0 010-3z"],dashboard:["M5 4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zM4 7c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm4-2c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zm-2 6c0 1.1.9 2 2 2s2-.9 2-2c0-.53-2-5-2-5s-2 4.47-2 5zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6zm4-9c0-.55-.45-1-1-1s-1 .45-1 1 .45 1 1 1 1-.45 1-1zm0 2c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1z"],"data-connection":["M1 9.52c.889.641 2.308 1.133 4.003 1.354L5 11a5.994 5.994 0 002.664 4.988c-.217.008-.44.012-.664.012-3.215 0-5.846-.85-5.993-1.906L1 14V9.52zM11 6c2.762 0 5 2.238 5 5s-2.238 5-5 5-5-2.238-5-5 2.238-5 5-5zm1 1l-4 5h2.5l-.5 3 4-5h-2.5l.5-3zm1-3.48v1.822a6.002 6.002 0 00-7.9 4.556l-.248-.03c-2.168-.28-3.733-.966-3.845-1.774L1 8V3.52C2.22 4.4 4.44 5 7 5s4.78-.6 6-1.48zM7 0c3.31 0 6 .9 6 2s-2.69 2-6 2c-3.32 0-6-.9-6-2s2.68-2 6-2z"],"data-lineage":["M1.067 0C.477 0 0 .478 0 1.067V3.2c0 .59.478 1.067 1.067 1.067h2.24a5.342 5.342 0 002.9 3.734 5.337 5.337 0 00-2.9 3.733h-2.24C.477 11.733 0 12.21 0 12.8v2.133C0 15.523.478 16 1.067 16H6.4c.59 0 1.067-.478 1.067-1.067V12.8c0-.59-.478-1.067-1.067-1.067H4.401a4.27 4.27 0 013.92-3.194l.212-.006V9.6c0 .59.478 1.067 1.067 1.067h5.333c.59 0 1.067-.478 1.067-1.067V6.4c0-.59-.478-1.067-1.067-1.067H9.6c-.59 0-1.067.478-1.067 1.067v1.067a4.268 4.268 0 01-4.132-3.2H6.4c.59 0 1.067-.478 1.067-1.067V1.067C7.467.477 6.989 0 6.4 0H1.067z"],database:["M8 4c3.31 0 6-.9 6-2s-2.69-2-6-2C4.68 0 2 .9 2 2s2.68 2 6 2zm-6-.48V8c0 1.1 2.69 2 6 2s6-.9 6-2V3.52C12.78 4.4 10.56 5 8 5s-4.78-.6-6-1.48zm0 6V14c0 1.1 2.69 2 6 2s6-.9 6-2V9.52C12.78 10.4 10.56 11 8 11s-4.78-.6-6-1.48z"],delete:["M11.99 4.99a1.003 1.003 0 00-1.71-.71l-2.29 2.3L5.7 4.29a.965.965 0 00-.71-.3 1.003 1.003 0 00-.71 1.71l2.29 2.29-2.29 2.29A1.003 1.003 0 005.7 11.7l2.29-2.29 2.29 2.29a1.003 1.003 0 001.42-1.42L9.41 7.99 11.7 5.7c.18-.18.29-.43.29-.71zm-4-5c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.68 6-6 6z"],delta:["M8 0L0 16h16L8 0zM7 5l5 10H2L7 5z"],"derive-column":["M6.08 6.67h-.84c.24-.92.56-1.6.96-2.03.24-.27.48-.4.71-.4.05 0 .08.01.11.04s.04.06.04.1c0 .04-.03.11-.1.21-.06.1-.1.2-.1.29 0 .13.05.24.15.33.1.09.23.14.39.14.17 0 .31-.06.42-.17A.58.58 0 008 4.73c0-.22-.09-.39-.26-.53-.17-.13-.44-.2-.81-.2-.59 0-1.12.16-1.59.48-.48.32-.93.85-1.36 1.59-.15.26-.29.42-.42.49s-.35.11-.64.1l-.19.65h.81l-1.19 4.37c-.2.72-.33 1.16-.4 1.33-.1.24-.26.45-.46.62-.08.07-.18.1-.3.1-.03 0-.06-.01-.08-.03l-.03-.04c0-.02.03-.06.09-.11.06-.06.09-.14.09-.26 0-.13-.05-.23-.14-.32a.6.6 0 00-.4-.13c-.21 0-.38.05-.51.16s-.21.25-.21.4c0 .16.08.3.23.42.16.12.4.18.74.18.53 0 .99-.13 1.4-.39.41-.26.76-.65 1.07-1.19.3-.54.62-1.4.94-2.59l.68-2.53h.82l.2-.63zM15 0H8c-.55 0-1 .45-1 1v2h2V2h5v12H9v-1H7v2c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM8.3 9.94c.18.52.33.89.46 1.13.13.24.28.4.44.51.17.1.37.16.62.16.24 0 .49-.08.74-.25.33-.21.66-.58 1.01-1.09l-.21-.11c-.23.31-.41.5-.52.57a.44.44 0 01-.26.07c-.12 0-.24-.07-.36-.21-.2-.24-.46-.91-.8-2 .3-.49.55-.81.75-.96.15-.11.3-.16.47-.16.06 0 .17.02.34.06.16.04.31.06.43.06.17 0 .31-.06.43-.17.1-.11.16-.25.16-.43 0-.19-.06-.33-.17-.44-.12-.11-.28-.16-.49-.16-.19 0-.37.04-.54.13-.17.09-.39.27-.65.56-.2.21-.48.58-.87 1.11-.15-.66-.41-1.26-.78-1.81l-2.05.33-.04.21c.15-.03.28-.04.39-.04.2 0 .37.08.5.25.21.26.5 1.03.88 2.33-.29.37-.49.61-.6.72-.18.18-.33.3-.44.36-.09.04-.19.07-.3.07-.09 0-.23-.04-.42-.13a.866.866 0 00-.36-.09c-.2 0-.36.06-.49.18a.59.59 0 00-.19.46c0 .17.06.32.18.43.12.11.28.16.48.16.2 0 .38-.04.55-.11.17-.08.39-.24.65-.49.24-.27.6-.66 1.06-1.21z"],desktop:["M15 0H1C.45 0 0 .45 0 1v10c0 .55.45 1 1 1h4.75l-.5 2H4c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1h-1.25l-.5-2H15c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 10H2V2h12v8z"],diagnosis:["M3.2 1a1 1 0 01.117 1.993L3.2 3H3v3a2 2 0 001.85 1.995L5 8a2 2 0 001.995-1.85L7 6V3h-.2a1 1 0 01-.993-.883L5.8 2a1 1 0 01.883-.993L6.8 1H8a1 1 0 01.993.883L9 2v4a4.002 4.002 0 01-3.007 3.876v.007L6 10a3 3 0 005.995.176L12 10V7.792a2.5 2.5 0 112 0V10a5 5 0 01-10 0c0-.042.003-.084.008-.125A4 4 0 011.005 6.2L1 6V2a1 1 0 01.883-.993L2 1h1.2z"],"diagram-tree":["M15 8v3h-2V9H9v2H7V9H3v2H1V8a1 1 0 011-1h5V5h2v2h5a1 1 0 011 1zM1 12h2a1 1 0 011 1v2a1 1 0 01-1 1H1a1 1 0 01-1-1v-2a1 1 0 011-1zm12 0h2a1 1 0 011 1v2a1 1 0 01-1 1h-2a1 1 0 01-1-1v-2a1 1 0 011-1zm-6 0h2a1 1 0 011 1v2a1 1 0 01-1 1H7a1 1 0 01-1-1v-2a1 1 0 011-1zM7 0h2a1 1 0 011 1v2a1 1 0 01-1 1H7a1 1 0 01-1-1V1a1 1 0 011-1z"],"direction-left":["M16 1.99l-16 6 16 6-4-6z"],"direction-right":["M16 7.99l-16-6 4 6-4 6z"],disable:["M7.99-.01c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm-6 8c0-3.31 2.69-6 6-6 1.3 0 2.49.42 3.47 1.12l-8.35 8.35c-.7-.98-1.12-2.17-1.12-3.47zm6 6c-1.3 0-2.49-.42-3.47-1.12l8.35-8.35c.7.98 1.12 2.17 1.12 3.47 0 3.32-2.68 6-6 6z"],document:["M9 0H3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V5L9 0zm3 14H4V2h4v4h4v8z"],"document-open":["M6 12c0 .55.45 1 1 1s1-.45 1-1V8c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1s.45 1 1 1h1.59L1.3 12.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L6 10.41V12zm4-12H4c-.55 0-1 .45-1 1v4h2V2h4v4h4v8H5.24l-1.8 1.8c.16.12.35.2.56.2h10c.55 0 1-.45 1-1V5l-5-5z"],"document-share":["M10 14H2V2h4v4h1c0-.83.36-1.55.91-2.09l-.03-.03.9-.9C8.3 2.45 8 1.77 8 1L7 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V8.22c-.53.48-1.23.78-2 .78v5zm5-14h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59l-3.3 3.29a1.003 1.003 0 001.42 1.42L14 3.41V5c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],dollar:["M12.83 9.51c-.1-.3-.25-.58-.45-.84s-.45-.49-.75-.7c-.3-.2-.65-.36-1.05-.48-.16-.04-.43-.11-.8-.2-.35-.09-.73-.18-1.12-.28-.39-.1-.74-.19-1.06-.27-.31-.08-.49-.12-.54-.13-.43-.12-.78-.29-1.05-.52-.27-.23-.4-.55-.4-.95 0-.29.07-.53.21-.72.14-.19.32-.34.54-.46.22-.11.46-.19.72-.24.26-.05.52-.08.77-.08.74 0 1.35.15 1.83.46.48.3.75.83.81 1.56h2.14c0-.6-.13-1.13-.38-1.58-.25-.45-.59-.84-1.02-1.15-.43-.31-.93-.54-1.49-.7-.24-.06-.49-.1-.75-.14V1c0-.55-.45-1-1-1s-1 .45-1 1v1.08c-.23.03-.46.07-.68.13-.54.13-1.02.34-1.44.61-.42.28-.76.63-1.02 1.05-.26.43-.39.93-.39 1.5 0 .3.04.59.13.88.09.29.23.56.44.82.21.26.48.49.83.7.35.21.79.38 1.31.51.85.21 1.56.38 2.14.52.58.13 1.08.28 1.52.42.25.09.48.23.69.44.21.21.32.53.32.97 0 .21-.05.42-.14.63-.09.21-.24.39-.45.55-.21.16-.47.29-.81.39-.33.1-.73.15-1.2.15-.43 0-.84-.05-1.21-.14-.37-.09-.7-.24-.99-.43-.29-.2-.51-.45-.67-.76-.16-.31-.24-.68-.24-1.12H3c.01.71.15 1.32.43 1.84.27.52.64.94 1.1 1.27.46.33.99.58 1.61.74.27.07.56.12.85.16V15c0 .55.45 1 1 1s1-.45 1-1v-1.05c.3-.03.61-.08.9-.15.58-.13 1.1-.34 1.56-.63.46-.29.83-.66 1.11-1.11.28-.45.42-1 .42-1.64 0-.31-.05-.61-.15-.91z"],dot:["M8 5a3 3 0 100 6 3 3 0 100-6z"],"double-caret-horizontal":["M13.71 7.29l-3-3A1.003 1.003 0 009 5v6a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM6 4c-.28 0-.53.11-.71.29l-3 3C2.11 7.47 2 7.72 2 8c0 .28.11.53.29.71l3 3A1.003 1.003 0 007 11V5c0-.55-.45-1-1-1z"],"double-caret-vertical":["M5 7h6a1.003 1.003 0 00.71-1.71l-3-3C8.53 2.11 8.28 2 8 2s-.53.11-.71.29l-3 3A1.003 1.003 0 005 7zm6 2H5a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 0011 9z"],"double-chevron-down":["M7.29 8.71c.18.18.43.29.71.29s.53-.11.71-.29l4-4a1.003 1.003 0 00-1.42-1.42L8 6.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4zM12 8c-.28 0-.53.11-.71.29L8 11.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4c.18.18.43.29.71.29s.53-.11.71-.29l4-4A1.003 1.003 0 0012 8z"],"double-chevron-left":["M4.41 8L7.7 4.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C2.11 7.47 2 7.72 2 8c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L4.41 8zm5 0l3.29-3.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C7.11 7.47 7 7.72 7 8c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L9.41 8z"],"double-chevron-right":["M9 8c0-.28-.11-.53-.29-.71l-4-4a1.003 1.003 0 00-1.42 1.42L6.59 8 3.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4C8.89 8.53 9 8.28 9 8zm4.71-.71l-4-4a1.003 1.003 0 00-1.42 1.42L11.59 8 8.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"double-chevron-up":["M4 8c.28 0 .53-.11.71-.29L8 4.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4C8.53 2.11 8.28 2 8 2s-.53.11-.71.29l-4 4A1.003 1.003 0 004 8zm4.71-.71C8.53 7.11 8.28 7 8 7s-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L8 9.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4z"],"doughnut-chart":["M11.86 7h4.05C15.45 3.39 12.61.52 9 .07v4.07A4 4 0 0111.86 7zM12 8c0 2.21-1.79 4-4 4s-4-1.79-4-4 1.79-4 4-4V0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8h-4z"],download:["M7.99-.01c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zM11.7 9.7l-3 3c-.18.18-.43.29-.71.29s-.53-.11-.71-.29l-3-3A1.003 1.003 0 015.7 8.28l1.29 1.29V3.99c0-.55.45-1 1-1s1 .45 1 1v5.59l1.29-1.29a1.003 1.003 0 011.71.71c0 .27-.11.52-.29.7z"],"drag-handle-horizontal":["M2 9c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0-4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm4 4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm8-2c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zm0 2c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm-4-4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0 4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zM6 5c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1z"],"drag-handle-vertical":["M6 9c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm4-6c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zM6 13c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0-8c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0-4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm4 8c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0-4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0 8c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1z"],draw:["M14.9 11c-.3 0-.5.1-.7.3l-3 3c-.2.2-.3.4-.3.7 0 .6.5 1 1 1 .3 0 .5-.1.7-.3l3-3c.2-.2.3-.4.3-.7 0-.5-.4-1-1-1zm-1-1v-.2l-1-5c-.1-.3-.3-.6-.6-.7l-11-4-.3.3 5.8 5.8c.2-.1.4-.2.6-.2.8 0 1.5.7 1.5 1.5S8.3 9 7.4 9s-1.5-.7-1.5-1.5c0-.2.1-.4.2-.6L.3 1.1l-.3.3 4 11c.1.3.4.6.7.6l5 1h.2c.3 0 .5-.1.7-.3l3-3c.2-.2.3-.4.3-.7z"],"drawer-left":["M7 0a1 1 0 011 1v14a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1h6zM6 2H2v12h4V2zm2 5h4.59L11.3 5.71A.965.965 0 0111 5a1.003 1.003 0 011.71-.71l3 3c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-3 3a1.003 1.003 0 01-1.42-1.42L12.59 9H8V7z"],"drawer-left-filled":["M1 0h6a1 1 0 011 1v14a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1zm7 7h4.59L11.3 5.71A.965.965 0 0111 5a1.003 1.003 0 011.71-.71l3 3c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-3 3a1.003 1.003 0 01-1.42-1.42L12.59 9H8V7z"],"drawer-right":["M15 0a1 1 0 011 1v14a1 1 0 01-1 1H9a1 1 0 01-1-1V1a1 1 0 011-1h6zm-1 2h-4v12h4V2zM8 7H3.41L4.7 5.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L3.41 9H8V7z"],"drawer-right-filled":["M9 0h6a1 1 0 011 1v14a1 1 0 01-1 1H9a1 1 0 01-1-1V1a1 1 0 011-1zM8 7H3.41L4.7 5.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L3.41 9H8V7z"],"drive-time":["M15.12 4.76h-1.05l-.76-2.12c-.19-.53-.76-1.08-1.27-1.24 0 0-1.32-.4-4.04-.4-2.72 0-4.04.4-4.04.4-.5.16-1.07.71-1.26 1.24l-.77 2.12H.88c-.48 0-.88.42-.88.94s.4.94.88.94h.38L1 7c-.03.69 0 1.44 0 2v5c0 .66.38 1 1 1s1-.34 1-1v-1h10v1c0 .66.38 1 1 1s1-.34 1-1V9c0-.56-.01-1.37 0-2l-.26-.37h.38c.48 0 .88-.42.88-.93 0-.52-.4-.94-.88-.94zM5 10H3V8h2v2zm8 0h-2V8h2v2zm0-4H3c-.18 0-.06-.82 0-1l.73-1.63C3.79 3.19 3.82 3 4 3h8c.18 0 .21.19.27.37L13 5c.06.18.18 1 0 1z"],duplicate:["M15 0H5c-.55 0-1 .45-1 1v2h2V2h8v7h-1v2h2c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-4 4H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm-1 10H2V6h8v8z"],edit:["M3.25 10.26l2.47 2.47 6.69-6.69-2.46-2.48-6.7 6.7zM.99 14.99l3.86-1.39-2.46-2.44-1.4 3.83zm12.25-14c-.48 0-.92.2-1.24.51l-1.44 1.44 2.47 2.47 1.44-1.44c.32-.32.51-.75.51-1.24.01-.95-.77-1.74-1.74-1.74z"],eject:["M4 9h8a1.003 1.003 0 00.71-1.71l-4-4C8.53 3.11 8.28 3 8 3s-.53.11-.71.29l-4 4A1.003 1.003 0 004 9zm8 1H4c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h8c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1z"],emoji:["M8 0a8 8 0 110 16A8 8 0 018 0zm0 1a7 7 0 100 14A7 7 0 008 1zM4 8c.228 2.262 2 4 4 4 1.938 0 3.77-1.738 3.984-3.8L12 8h1c-.128 2.888-2.317 5-5 5a5 5 0 01-4.995-4.783L3 8h1zm2-3a1 1 0 110 2 1 1 0 010-2zm4 0a1 1 0 110 2 1 1 0 010-2z"],endorsed:["M15.86 7.5l-.81-1.42V4.5c0-.36-.19-.68-.49-.87l-1.37-.8-.81-1.41c-.19-.31-.51-.49-.86-.49H9.89L8.5.14a.948.948 0 00-1 0l-1.39.8H4.52a1 1 0 00-.86.49l-.8 1.37-1.44.83c-.3.19-.49.51-.49.87v1.65l-.8 1.37c-.08.15-.13.32-.13.49s.05.34.14.49l.8 1.37v1.65c0 .36.19.68.49.87l1.42.81.8 1.37c.19.31.51.49.86.49H6.1l1.39.8c.15.09.32.14.48.14s.34-.05.49-.14l1.39-.8h1.63a1 1 0 00.86-.49l.81-1.41 1.37-.8c.3-.19.49-.51.49-.87V9.93l.81-1.42a.89.89 0 00.04-1.01zm-4.12-.82l-4.01 4.01c-.18.18-.43.29-.71.29s-.53-.11-.71-.29l-2-2c-.18-.19-.3-.44-.3-.71a1.003 1.003 0 011.71-.71l1.3 1.3 3.3-3.3a1.003 1.003 0 011.71.71.95.95 0 01-.29.7z"],envelope:["M0 3.06v9.88L4.94 8 0 3.06zM14.94 2H1.06L8 8.94 14.94 2zm-6.41 8.53c-.14.14-.32.22-.53.22s-.39-.08-.53-.22L6 9.06 1.06 14h13.88L10 9.06l-1.47 1.47zM11.06 8L16 12.94V3.06L11.06 8z"],equals:["M3 5h10a1 1 0 010 2H3a1 1 0 110-2zm0 4h10a1 1 0 010 2H3a1 1 0 010-2z"],eraser:["M8.06 13.91l7.63-7.44c.41-.4.41-1.05 0-1.45L10.86.3c-.41-.4-1.08-.4-1.49 0L.31 9.13c-.41.4-.41 1.05 0 1.45l5.58 5.44h8.12v-.01c.55 0 1-.45 1-1s-.45-1-1-1H7.96l.1-.1zm-2.17.06L1.67 9.85l4.22-4.11 4.22 4.11-4.22 4.12z"],error:["M7.99-.01c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm1 13h-2v-2h2v2zm0-3h-2v-7h2v7z"],euro:["M6.52 3.18c.51-.27 1.12-.4 1.83-.4.48 0 .91.06 1.27.18.37.12.68.29.96.51.18.14.3.33.44.51l1.53-1.53c-.12-.11-.23-.22-.36-.32a5.61 5.61 0 00-1.74-.83c-.66-.2-1.36-.3-2.1-.3-.99 0-1.88.18-2.66.53-.79.35-1.45.82-2 1.41-.55.58-.96 1.27-1.26 2.06H2c-.55 0-1 .45-1 1s.45 1 1 1h.04c-.01.17-.04.33-.04.5 0 .17.03.33.04.5H2c-.55 0-1 .45-1 1s.45 1 1 1h.43c0 .01 0 .02.01.02a6.2 6.2 0 001.25 2.07 5.77 5.77 0 002 1.4c.78.34 1.67.51 2.66.51.81 0 1.54-.12 2.21-.36.67-.24 1.25-.59 1.75-1.03l.03-.03-1.55-1.33c-.01.01-.02.03-.03.04-.29.3-.63.53-1.02.69-.4.17-.85.25-1.37.25-.71 0-1.32-.13-1.83-.4s-.93-.62-1.25-1.07c-.19-.24-.34-.49-.46-.76H9c.55 0 1-.45 1-1s-.45-1-1-1H4.35c-.01-.17-.03-.33-.03-.5 0-.17.02-.34.03-.5H10c.55 0 1-.45 1-1s-.45-1-1-1H4.83c.13-.27.27-.52.44-.76.32-.44.74-.8 1.25-1.06zM14 8.98v0z"],exchange:["M1.99 5.99c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.89-2-2-2zm4.15 1.86a.495.495 0 10.7-.7L5.7 5.99h5.79c.28 0 .5-.22.5-.5s-.22-.5-.5-.5H5.7l1.15-1.15a.495.495 0 10-.7-.7l-2 2c-.1.09-.16.21-.16.35s.06.26.15.35l2 2.01zm7.85-1.86c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.89-2-2-2zM9.85 8.14a.533.533 0 00-.36-.15.495.495 0 00-.35.85l1.15 1.15h-5.8c-.28 0-.5.22-.5.5s.22.5.5.5h5.79l-1.15 1.15a.495.495 0 10.7.7l2-2c.09-.09.15-.22.15-.35s-.06-.26-.15-.35l-1.98-2z"],"exclude-row":["M0 10a1.003 1.003 0 001.71.71L3 9.41l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L4.41 8 5.7 6.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L3 6.59l-1.29-1.3A1.003 1.003 0 00.29 6.71L1.59 8 .29 9.29C.11 9.47 0 9.72 0 10zm1-7h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 10H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm-1-7H9c-1.1 0-2 .9-2 2s.9 2 2 2h5c1.1 0 2-.9 2-2s-.9-2-2-2z"],"expand-all":["M4 7c.28 0 .53-.11.71-.29L8 3.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4C8.53 1.11 8.28 1 8 1s-.53.11-.71.29l-4 4A1.003 1.003 0 004 7zm8 2c-.28 0-.53.11-.71.29L8 12.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4c.18.18.43.29.71.29s.53-.11.71-.29l4-4A1.003 1.003 0 0012 9z"],export:["M4 6c.28 0 .53-.11.71-.29L7 3.41V11c0 .55.45 1 1 1s1-.45 1-1V3.41l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4C8.53.11 8.28 0 8 0s-.53.11-.71.29l-4 4A1.003 1.003 0 004 6zm11 5c-.55 0-1 .45-1 1v2H2v-2c0-.55-.45-1-1-1s-1 .45-1 1v3c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1z"],"eye-off":["M16 7.97v-.02-.01-.02-.02a.672.672 0 00-.17-.36c-.49-.63-1.07-1.2-1.65-1.72l-3.16 2.26a2.978 2.978 0 01-2.98 2.9c-.31 0-.6-.06-.88-.15L5.09 12.3c.44.19.9.36 1.37.47.97.23 1.94.24 2.92.05.88-.17 1.74-.54 2.53-.98 1.25-.7 2.39-1.67 3.38-2.75.18-.2.37-.41.53-.62.09-.1.15-.22.17-.36v-.02-.02-.01-.02-.03c.01-.02.01-.03.01-.04zm-.43-4.17c.25-.18.43-.46.43-.8 0-.55-.45-1-1-1-.22 0-.41.08-.57.2l-.01-.01-2.67 1.91c-.69-.38-1.41-.69-2.17-.87a6.8 6.8 0 00-2.91-.05c-.88.18-1.74.54-2.53.99-1.25.7-2.39 1.67-3.38 2.75-.18.2-.37.41-.53.62-.23.29-.23.63-.01.92.51.66 1.11 1.25 1.73 1.79.18.16.38.29.56.44l-2.09 1.5.01.01c-.25.18-.43.46-.43.8 0 .55.45 1 1 1 .22 0 .41-.08.57-.2l.01.01 14-10-.01-.01zm-10.41 5a3.03 3.03 0 01-.11-.8 2.99 2.99 0 012.99-2.98c.62 0 1.19.21 1.66.53L5.16 8.8z"],"eye-on":["M10.29 6.7c.18.18.43.29.71.29s.53-.11.71-.29l4-4c.17-.18.29-.43.29-.7a1.003 1.003 0 00-1.71-.71L11 4.58 9.71 3.29A.997.997 0 009 3c-.55 0-1 .44-1 1a1 1 0 00.3.7l1.99 2zM16 7.96v-.02-.01-.02-.02a.64.64 0 00-.17-.36c-.3-.4-.65-.76-1-1.12l-1.7 1.7c-.55.55-1.3.88-2.13.88-.06 0-.11-.01-.17-.02C10.42 10.15 9.32 11 8.01 11A3.005 3.005 0 016.4 5.46c-.24-.43-.39-.93-.39-1.46 0-.26.04-.5.1-.74-.7.2-1.37.5-2.01.86-1.26.7-2.4 1.68-3.4 2.77-.18.21-.36.41-.53.63-.22.29-.22.64 0 .93.51.67 1.12 1.27 1.73 1.81 1.33 1.17 2.85 2.15 4.53 2.55.97.23 1.95.24 2.92.05.89-.18 1.74-.54 2.54-.99 1.25-.71 2.4-1.69 3.39-2.78.18-.2.37-.41.54-.63.09-.1.15-.23.17-.37v-.02-.02-.01-.02-.03c.01-.01.01-.02.01-.03zM8.01 9c.48 0 .87-.35.96-.81a.55.55 0 01-.07-.09l-.02.01L7.8 7.03c-.45.1-.79.48-.79.96 0 .56.45 1.01 1 1.01z"],"eye-open":["M8.002 7.003a1.003 1.003 0 000 2.005 1.003 1.003 0 000-2.005zm7.988.972v-.02-.01-.02-.02a.675.675 0 00-.17-.36c-.509-.673-1.118-1.264-1.737-1.806-1.328-1.173-2.846-2.155-4.523-2.546a6.702 6.702 0 00-2.925-.06c-.889.18-1.738.541-2.546.992C2.84 4.837 1.692 5.81.694 6.902c-.18.211-.36.411-.53.632a.742.742 0 000 .932c.51.672 1.119 1.264 1.738 1.805 1.328 1.173 2.846 2.156 4.523 2.547.968.23 1.947.24 2.925.04.889-.18 1.738-.542 2.546-.993 1.248-.712 2.397-1.684 3.395-2.777.18-.2.37-.411.54-.632.09-.1.149-.23.169-.36v-.02-.02-.01-.02-.03c0-.01-.01-.01-.01-.02zm-7.988 3.038a2.998 2.998 0 01-2.995-3.008 2.998 2.998 0 012.995-3.008 2.998 2.998 0 012.996 3.008 2.998 2.998 0 01-2.996 3.008z"],"fast-backward":["M14 3c-.24 0-.44.09-.62.23l-.01-.01L9 6.72V4c0-.55-.45-1-1-1-.24 0-.44.09-.62.23v-.01l-5 4 .01.01C2.16 7.41 2 7.68 2 8s.16.59.38.77v.01l5 4 .01-.01c.17.14.37.23.61.23.55 0 1-.45 1-1V9.28l4.38 3.5.01-.01c.17.14.37.23.61.23.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"fast-forward":["M15 8c0-.32-.16-.59-.38-.77l.01-.01-5-4-.01.01A.987.987 0 009 3c-.55 0-1 .45-1 1v2.72l-4.38-3.5v.01A.987.987 0 003 3c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1 .24 0 .44-.09.62-.23l.01.01L8 9.28V12c0 .55.45 1 1 1 .24 0 .44-.09.62-.23l.01.01 5-4-.01-.01c.22-.18.38-.45.38-.77z"],feed:["M1.99 11.99c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.89-2-2-2zm1-4c-.55 0-1 .45-1 1s.45 1 1 1c1.66 0 3 1.34 3 3 0 .55.45 1 1 1s1-.45 1-1c0-2.76-2.24-5-5-5zm0-4c-.55 0-1 .45-1 1s.45 1 1 1c3.87 0 7 3.13 7 7 0 .55.45 1 1 1s1-.45 1-1a9 9 0 00-9-9zm0-4c-.55 0-1 .45-1 1s.45 1 1 1c6.08 0 11 4.92 11 11 0 .55.45 1 1 1s1-.45 1-1c0-7.18-5.82-13-13-13z"],"feed-subscribed":["M3 2c1.06 0 2.08.16 3.06.45.13-.71.52-1.32 1.05-1.76C5.82.25 4.44 0 3 0c-.55 0-1 .45-1 1s.45 1 1 1zM2 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm8.32-6.33a.99.99 0 001.4 0l3.98-3.98c.19-.18.3-.42.3-.7 0-.55-.45-.99-1-.99-.28 0-.52.11-.7.29l-3.28 3.28-1.29-1.29a.99.99 0 00-.7-.29 1 1 0 00-1 .99c0 .27.11.52.29.7l2 1.99zm3.73.53l-.93.93-.02-.02c-.17.17-.35.33-.56.45C13.47 9.16 14 11.02 14 13c0 .55.45 1 1 1s1-.45 1-1c0-2.5-.73-4.82-1.95-6.8zM3 8c-.55 0-1 .45-1 1s.45 1 1 1c1.66 0 3 1.34 3 3 0 .55.45 1 1 1s1-.45 1-1c0-2.76-2.24-5-5-5zm5.91-.91l-.03.03-2-2 .03-.03c-.11-.11-.23-.2-.33-.33A8.9 8.9 0 003 4c-.55 0-1 .45-1 1s.45 1 1 1c3.87 0 7 3.13 7 7 0 .55.45 1 1 1s1-.45 1-1c0-1.87-.57-3.61-1.55-5.06-.61-.11-1.13-.42-1.54-.85z"],film:["M15 1h-5v2H6V1H1c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h5v-2h4v2h5c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM4 13H2v-2h2v2zm0-3H2V8h2v2zm0-3H2V5h2v2zm0-3H2V2h2v2zm6 6H6V5h4v5zm4 3h-2v-2h2v2zm0-3h-2V8h2v2zm0-3h-2V5h2v2zm0-3h-2V2h2v2z"],filter:["M13.99.99h-12a1.003 1.003 0 00-.71 1.71l4.71 4.71V14a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71V7.41L14.7 2.7a1.003 1.003 0 00-.71-1.71z"],"filter-keep":["M15 10c-.28 0-.53.11-.71.29L12 12.59l-1.29-1.29A.965.965 0 0010 11a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 0015 10zm-3-8c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L4 6.41V12a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71V6.41l3.71-3.71c.18-.17.29-.42.29-.7z"],"filter-list":["M9 8c0 .55.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1h-5c-.55 0-1 .45-1 1zm3-6c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L4 6.41V12a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71V6.41l3.71-3.71c.18-.17.29-.42.29-.7zm3 8h-5c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm0 3h-5c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1z"],"filter-open":["M15.707 10.293a1 1 0 010 1.414l-3 3c-.63.63-1.707.184-1.707-.707V8c0-.89 1.077-1.337 1.707-.707l3 3zM12 2c0 .28-.11.53-.29.7L8 6.41V10c0 .28-.11.53-.29.71l-2 2A1.003 1.003 0 014 12V6.41L.29 2.71A1.003 1.003 0 011 1h10c.55 0 1 .45 1 1z"],"filter-remove":["M12 2c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L4 6.41V12a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71V6.41l3.71-3.71c.18-.17.29-.42.29-.7zm2.41 10l1.29-1.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L13 10.59 11.71 9.3A.965.965 0 0011 9a1.003 1.003 0 00-.71 1.71l1.3 1.29-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l1.29-1.3 1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L14.41 12z"],flag:["M2.99 2.99c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1s1-.45 1-1v-11c0-.55-.45-1-1-1zm0-3c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm2 3.03v7.23c2.07-2.11 5.92 1.75 9 0V3.02c-3 2.07-6.94-2.03-9 0z"],flame:["M9.217 0c0 1.368.368 2.462 1.104 3.282C12.774 5.197 14 7.385 14 9.846c0 2.735-1.472 4.786-4.415 6.154 2.165-2.4 1.84-3.385-.368-6.4-2.342 1.2-1.967 2-1.592 3.6-.786 0-1.5 0-1.875-.4 0 .547.898 2 1.464 3.2-2.943-.82-6.092-5.744-4.988-6.154.736-.273 1.594-.137 2.575.41C3.575 5.333 5.047 1.915 9.217 0z"],flash:["M4 8c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1h2c.55 0 1-.45 1-1zm4-4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1S7 .45 7 1v2c0 .55.45 1 1 1zM3.79 5.21a1.003 1.003 0 001.42-1.42l-1.5-1.5a1.003 1.003 0 00-1.42 1.42l1.5 1.5zm.71 5.29c-.28 0-.53.11-.71.29l-1.5 1.5a1.003 1.003 0 001.42 1.42l1.5-1.5a1.003 1.003 0 00-.71-1.71zm7-5c.28 0 .53-.11.71-.29l1.5-1.5a1.003 1.003 0 00-1.42-1.42l-1.5 1.5a1.003 1.003 0 00.71 1.71zm.71 5.29a1.003 1.003 0 00-1.42 1.42l1.5 1.5a1.003 1.003 0 001.42-1.42l-1.5-1.5zM15 7h-2c-.55 0-1 .45-1 1s.45 1 1 1h2c.55 0 1-.45 1-1s-.45-1-1-1zM8 5C6.34 5 5 6.34 5 8s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3zm0 4c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm0 3c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1s1-.45 1-1v-2c0-.55-.45-1-1-1z"],"floppy-disk":["M15.71 2.29l-2-2A.997.997 0 0013 0h-1v6H4V0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V3c0-.28-.11-.53-.29-.71zM14 15H2V9c0-.55.45-1 1-1h10c.55 0 1 .45 1 1v6zM11 1H9v4h2V1z"],"flow-branch":["M10.643 6.595c.22.418.344.894.344 1.399 0 .439-.094.855-.263 1.231l3.265 3.462-.002-1.75a.973.973 0 01.314-.68.99.99 0 011.388.048c.186.2.316.46.3.715l-.009 4.03a.959.959 0 01-.3.68.972.972 0 01-.698.266l-4.053.002a.97.97 0 01-.679-.314 1.031 1.031 0 01.05-1.42.972.972 0 01.698-.266l1.7-.001-3.305-3.35a2.998 2.998 0 01-4.228-1.653H.999a1 1 0 010-2h4.166a2.998 2.998 0 014.06-1.735l3.449-3.268-1.745.002a.979.979 0 01-.631-1.692c.199-.186.459-.316.713-.3l4.025.009c.247.008.493.1.679.3.186.2.274.451.265.7l.002 4.046a.972.972 0 01-.313.68 1.03 1.03 0 01-1.42-.05.973.973 0 01-.266-.7V3.295l-3.34 3.301z"],"flow-end":["M9.702 7.31c.176.176.293.41.293.684a.976.976 0 01-.283.695c-1.888 1.91-2.892 2.918-3.011 3.027-.179.164-.42.284-.693.284a.995.995 0 01-.997-.985c0-.274.112-.541.292-.72.12-.12.624-.551 1.514-1.293H.98c-.536 0-.975-.47-.975-1.008 0-.537.439-.996.975-.996h5.837c-.895-.752-1.4-1.187-1.514-1.304a1.03 1.03 0 01-.292-.705C5.01 4.45 5.464 4 6 4c.272 0 .52.108.695.294A535.7 535.7 0 009.702 7.31zM13 11.002c-1.657 0-3-1.347-3-3.008a3.004 3.004 0 013-3.007c1.657 0 3 1.346 3 3.007a3.004 3.004 0 01-3 3.008z"],"flow-linear":["M4.16 9.002H.977C.44 9.002 0 8.532 0 7.994c0-.537.44-.99.978-.99h3.18A3.01 3.01 0 016.995 5a3.01 3.01 0 012.839 2.004h2.98c-.898-.756-1.404-1.193-1.518-1.31a1.03 1.03 0 01-.293-.705c0-.538.454-.989.992-.989.274 0 .521.108.697.294.118.124 1.122 1.13 3.014 3.016a.96.96 0 01.293.684.975.975 0 01-.284.695l-3.018 3.027a.974.974 0 01-.694.284c-.553 0-1-.447-1-.985 0-.274.117-.545.293-.72l1.518-1.293H9.833A3.01 3.01 0 016.996 11 3.01 3.01 0 014.16 9.002z"],"flow-review":["M5.175 7.004a3.003 3.003 0 012.83-2.001c1.305 0 2.416.835 2.83 2.001h1.985c-.896-.756-1.401-1.193-1.515-1.31a1.03 1.03 0 01-.292-.705c0-.538.453-.989.99-.989a.95.95 0 01.696.294c.117.124 1.12 1.13 3.008 3.016.176.176.293.41.293.684a.976.976 0 01-.283.695l-3.013 3.027a.995.995 0 01-1.691-.702c0-.273.116-.544.292-.72l1.515-1.292h-1.98a3.003 3.003 0 01-2.835 2.016A3.003 3.003 0 015.17 9.002H3.18l1.515 1.292c.176.176.292.447.292.72a.995.995 0 01-1.69.702L.282 8.69A.976.976 0 010 7.994c0-.273.117-.508.293-.684A535.858 535.858 0 003.3 4.294.95.95 0 013.997 4c.537 0 .99.45.99.989 0 .273-.12.528-.292.705-.114.117-.62.554-1.515 1.31h1.995z"],"flow-review-branch":["M10.392 10.647A3.002 3.002 0 016.16 8.995H3.37l1.338 1.318c.172.178.287.41.282.683-.01.536-.524.995-.99.995-.465 0-.63-.187-.747-.294L.281 8.682A.956.956 0 010 7.994a.971.971 0 01.294-.687l3.01-3.028a.973.973 0 01.697-.27c.536.01.998.485.989 1.021a.971.971 0 01-.295.687L3.37 6.997h2.79a3.002 3.002 0 014.106-1.716l2.416-2.277-1.732.004a.99.99 0 01-.679-.329.978.978 0 01.05-1.378c.199-.186.459-.315.714-.3l4.012.005c.248.009.493.1.68.3.185.2.273.45.264.699L15.99 6.05a.973.973 0 01-.314.679 1.03 1.03 0 01-1.421-.048.971.971 0 01-.265-.699V4.29L11.65 6.602c.219.416.343.89.343 1.394 0 .451-.1.88-.279 1.263L14 11.68l-.004-1.73a.982.982 0 01.323-.68.978.978 0 011.378.049c.187.2.316.46.3.714l-.004 4.011a.983.983 0 01-.3.691.972.972 0 01-.7.265l-4.046-.001a.987.987 0 01-.679-.326 1.017 1.017 0 01.048-1.41.972.972 0 01.699-.265h1.693l-2.315-2.35z"],flows:["M13.5 6a2.5 2.5 0 00-2.45 2h-1.3L5.74 4l-.75.75L8.25 8h-3.3a2.5 2.5 0 100 1h3.3l-3.26 3.25.75.75 4.01-4h1.3a2.5 2.5 0 102.45-3z"],"folder-close":["M-.01 14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V7h-16v7zm15-10H7.41L5.7 2.3a.965.965 0 00-.71-.3h-4c-.55 0-1 .45-1 1v3h16V5c0-.55-.45-1-1-1z"],"folder-new":["M10.165 7a3.003 3.003 0 002.827 2 3.003 3.003 0 002.827-2H16v7c0 .55-.45 1-1 1H1.01c-.55 0-1-.45-1-1V7h10.155zM8.76 6H0V3c0-.55.45-1 1-1h1.998c.28 0 .53.11.71.29L5.417 4h2.578c0 .768.29 1.469.765 2zm6.23-3c.55 0 1 .45 1 1s-.45 1-1 1h-.999v1c0 .55-.45 1-1 1-.549 0-.998-.45-.998-1V5h-1c-.55 0-1-.45-1-1s.45-1 1-1h1V2c0-.55.45-1 .999-1 .55 0 1 .45 1 1v1h.999z"],"folder-open":["M2.06 6.69c.14-.4.5-.69.94-.69h11V5c0-.55-.45-1-1-1H6.41l-1.7-1.71A.997.997 0 004 2H1c-.55 0-1 .45-1 1v9.84l2.05-6.15h.01zM16 8c0-.55-.45-1-1-1H4a.99.99 0 00-.94.69l-2 6c-.04.09-.06.2-.06.31 0 .55.45 1 1 1h11c.44 0 .81-.29.94-.69l2-6c.04-.09.06-.2.06-.31z"],"folder-shared":["M8.76 5.98c-.47-.53-.77-1.22-.77-1.99h-.58L5.7 2.29a.965.965 0 00-.71-.3h-4c-.55 0-1 .45-1 1v3h8.76l.01-.01zm6.23-2.99h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59l-3.3 3.3a.99.99 0 00-.29.7 1.003 1.003 0 001.71.71l3.29-3.29V8c0 .55.45 1 1 1s1-.45 1-1V4c0-.56-.45-1.01-1-1.01zm-1.98 7.23l-.9.9-.01-.01c-.54.55-1.28.89-2.11.89-1.66 0-3-1.34-3-3 0-.77.3-1.47.78-2H-.01v7c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-3.18c-.31.11-.65.18-1 .18-.76-.01-1.45-.31-1.98-.78z"],"folder-shared-open":["M13.02 10.22l-.9.9-.01-.01c-.54.55-1.28.89-2.11.89-1.66 0-3-1.34-3-3 0-.77.3-1.47.78-2H4a.99.99 0 00-.94.69l-2 6c-.04.09-.06.2-.06.31 0 .55.45 1 1 1h11c.44 0 .81-.29.94-.69l1.11-3.32c-.01 0-.03.01-.05.01-.77 0-1.45-.3-1.98-.78zM2.06 6.69c.14-.4.5-.69.94-.69h5.76l.01-.01C8.3 5.46 8 4.77 8 4H6.41l-1.7-1.71A.997.997 0 004 2H1c-.55 0-1 .45-1 1v9.84l2.05-6.15h.01zM15 3h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59l-3.3 3.29a1.003 1.003 0 001.42 1.42L14 6.41V8c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1z"],follower:["M9.37 12.69c-1.2-.53-1.04-.85-1.08-1.29-.01-.06-.01-.12-.01-.19.41-.37.75-.87.97-1.44 0 0 .01-.03.01-.04.05-.13.09-.26.12-.39.28-.06.44-.36.5-.63.06-.11.19-.39.16-.7-.04-.4-.2-.59-.38-.67v-.07c0-.52-.05-1.26-.14-1.74a2.72 2.72 0 00-.09-.43 3.02 3.02 0 00-1.04-1.51C7.87 3.2 7.15 3 6.5 3c-.64 0-1.36.2-1.87.59-.5.38-.87.92-1.05 1.51-.04.13-.07.27-.09.4-.09.49-.14 1.24-.14 1.75v.06c-.19.07-.36.26-.4.68-.03.31.1.59.16.7.06.28.23.59.51.64.04.14.08.27.13.39 0 .01.01.02.01.02v.01c.22.59.57 1.1.99 1.46 0 .06-.01.12-.01.17-.04.44.08.76-1.12 1.29-1.2.53-3.01 1.1-3.38 1.95C-.13 15.5.02 16 .02 16h12.96s.15-.5-.22-1.36c-.38-.85-2.19-1.42-3.39-1.95zm6.33-10.4l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H9.99c-.55 0-1 .45-1 1s.45 1 1 1h2.58l-.29.29a1.003 1.003 0 001.42 1.42l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],following:["M9.37 12.69c-1.2-.53-1.04-.85-1.08-1.29-.01-.06-.01-.12-.01-.19.41-.37.75-.87.97-1.44 0 0 .01-.03.01-.04.05-.13.09-.26.12-.39.28-.06.44-.36.5-.63.06-.11.19-.39.16-.7-.04-.4-.2-.59-.38-.67v-.07c0-.52-.05-1.26-.14-1.74a2.72 2.72 0 00-.09-.43 3.02 3.02 0 00-1.04-1.51C7.87 3.2 7.15 3 6.5 3c-.64 0-1.36.2-1.87.59-.5.38-.87.92-1.05 1.51-.04.13-.07.27-.09.4-.09.49-.14 1.24-.14 1.75v.06c-.19.07-.36.26-.4.68-.03.31.1.59.16.7.06.28.23.59.51.64.04.14.08.27.13.39 0 .01.01.02.01.02v.01c.22.59.57 1.1.99 1.46 0 .06-.01.12-.01.17-.04.44.08.76-1.12 1.29-1.2.53-3.01 1.1-3.38 1.95C-.13 15.5.02 16 .02 16h12.96s.15-.5-.22-1.36c-.38-.85-2.19-1.42-3.39-1.95zM14.99 2h-2.58l.29-.29A1.003 1.003 0 0011.28.29l-2 2c-.17.18-.29.43-.29.71 0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L12.41 4h2.58c.55 0 1-.45 1-1s-.45-1-1-1z"],font:["M13.93 14.67L8.94.67h-.01C8.79.28 8.43 0 8 0s-.79.28-.93.67h-.01l-5 14h.01c-.04.1-.07.21-.07.33 0 .55.45 1 1 1 .43 0 .79-.28.93-.67h.01L5.49 11h5.02l1.55 4.34h.01c.14.38.5.66.93.66.55 0 1-.45 1-1 0-.12-.03-.23-.07-.33zM6.2 9L8 3.97 9.8 9H6.2z"],fork:["M13.7 9.29a1.003 1.003 0 00-1.42 1.42l.29.29H11.4l-5-5h6.17l-.29.29a1.003 1.003 0 001.42 1.42l2-2c.18-.18.29-.43.29-.71s-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l.29.29H.99c-.55 0-1 .45-1 1s.45 1 1 1h2.59l6.71 6.71c.18.18.43.29.71.29h1.59l-.29.29a1.003 1.003 0 001.42 1.42l2-2c.18-.18.29-.43.29-.71s-.11-.53-.29-.71l-2.02-2z"],form:["M2 11v2h2v-2H2zM1 9h4c.55 0 1 .45 1 1v4c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1v-4c0-.55.45-1 1-1zm9-6h5c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1zM6 1a1.003 1.003 0 01.71 1.71l-3 4C3.53 6.89 3.28 7 3 7s-.53-.11-.71-.29l-2-2a1.003 1.003 0 011.42-1.42L3 4.59l2.29-3.3C5.47 1.11 5.72 1 6 1zm4 10h5c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1z"],"full-circle":["M8 0a8 8 0 100 16A8 8 0 108 0z"],"full-stacked-chart":["M13 12h1c.55 0 1-.45 1-1V8h-3v3c0 .55.45 1 1 1zM10 2c0-.55-.45-1-1-1H8c-.55 0-1 .45-1 1v3h3V2zm0 4H7v3h3V6zm5-4c0-.55-.45-1-1-1h-1c-.55 0-1 .45-1 1v2h3V2zm0 3h-3v2h3V5zM5 5H2v3h3V5zm-2 7h1c.55 0 1-.45 1-1V9H2v2c0 .55.45 1 1 1zm12 1H2c-.55 0-1 .45-1 1s.45 1 1 1h13c.55 0 1-.45 1-1s-.45-1-1-1zM5 2c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v2h3V2zm3 10h1c.55 0 1-.45 1-1v-1H7v1c0 .55.45 1 1 1z"],fullscreen:["M3.41 2H5c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v4c0 .55.45 1 1 1s1-.45 1-1V3.41L5.29 6.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L3.41 2zM6 9c-.28 0-.53.11-.71.29L2 12.59V11c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.41l3.29-3.29c.19-.18.3-.43.3-.71 0-.55-.45-1-1-1zm9 1c-.55 0-1 .45-1 1v1.59L10.71 9.3A.965.965 0 0010 9a1.003 1.003 0 00-.71 1.71l3.3 3.29H11c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1zm0-10h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59l-3.3 3.29a1.003 1.003 0 001.42 1.42L14 3.41V5c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],function:["M8.12 4.74H6.98c.33-1.29.75-2.24 1.28-2.84.33-.37.64-.56.95-.56.06 0 .11.02.15.05.04.04.06.09.06.15 0 .05-.04.15-.13.29-.09.14-.13.28-.13.4 0 .18.07.33.2.46.14.13.31.19.52.19.22 0 .41-.08.56-.23.15-.16.23-.37.23-.63 0-.3-.11-.55-.34-.74C10.1 1.09 9.74 1 9.24 1c-.78 0-1.49.22-2.12.67-.64.45-1.24 1.2-1.81 2.23-.2.36-.38.59-.56.69-.18.1-.46.15-.85.15l-.26.9h1.08l-1.59 6.12c-.27 1.01-.44 1.63-.54 1.86-.14.34-.34.63-.62.87-.11.1-.24.15-.4.15a.15.15 0 01-.11-.04l-.04-.05c0-.03.04-.08.12-.16.08-.08.12-.2.12-.36 0-.18-.06-.33-.19-.44-.12-.12-.3-.18-.54-.18-.28 0-.51.08-.68.23-.16.14-.25.32-.25.53 0 .22.1.42.31.59.21.17.53.25.97.25.7 0 1.32-.18 1.87-.54.54-.36 1.02-.92 1.42-1.67.41-.75.82-1.96 1.25-3.63l.91-3.54h1.1l.29-.89zm5.43 1.52c.2-.15.41-.23.62-.23.08 0 .23.03.45.09s.41.09.57.09c.23 0 .42-.08.57-.23.16-.16.24-.36.24-.61 0-.26-.08-.47-.23-.62-.15-.15-.37-.23-.66-.23-.25 0-.5.06-.72.18-.23.12-.51.38-.86.78-.26.3-.64.81-1.15 1.55-.2-.91-.55-1.75-1.05-2.51l-2.72.46-.06.29c.2-.04.37-.06.51-.06.27 0 .49.11.67.34.28.36.67 1.45 1.17 3.26-.39.52-.66.85-.8 1.01-.24.26-.44.42-.59.5-.12.06-.25.09-.41.09-.11 0-.3-.06-.56-.18-.18-.08-.34-.12-.48-.12-.27 0-.48.08-.66.25-.17.17-.26.38-.26.64 0 .25.08.44.24.6.16.15.37.23.64.23.26 0 .5-.05.73-.16.23-.11.52-.34.86-.69.35-.35.82-.9 1.43-1.67.23.73.44 1.25.61 1.58s.37.57.59.71c.22.15.5.22.83.22.32 0 .65-.11.98-.34.44-.3.88-.81 1.34-1.53l-.26-.15c-.31.43-.54.7-.69.8-.1.07-.22.1-.35.1-.16 0-.32-.1-.48-.3-.27-.34-.62-1.27-1.06-2.8.4-.68.73-1.13 1-1.34z"],"gantt-chart":["M10 10c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1h-4c-.55 0-1 .45-1 1zM6 7c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1zm9 5H2V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM4 5h3c.55 0 1-.45 1-1s-.45-1-1-1H4c-.55 0-1 .45-1 1s.45 1 1 1z"],geofence:["M6 9c.55 0 1 .45 1 1v4c0 .55-.45 1-1 1s-1-.45-1-1v-1.59l-3.29 3.3A1.003 1.003 0 010 15c0-.28.11-.53.3-.71L3.59 11H2c-.55 0-1-.45-1-1s.45-1 1-1zM9.088.004l.097.013.097.024.057.018.1.042.054.029.095.061.052.04 6 5 .05.046.076.08.053.07.06.095.051.11c.056.141.079.294.067.446l-.014.105-.037.143-.035.087-.043.083-4 7-.034.056-.059.08-.038.044-.096.092-.114.082-.116.062-.086.034-.109.03-.1.017-.069.006H8.83c.088-.25.144-.515.163-.79L9 13v-3a3 3 0 00-2.824-2.995L6 7H3c-.351 0-.689.06-1.002.171L2 5l.002-.07.013-.1.015-.073.025-.085.043-.104.056-.101.045-.066.079-.093.084-.078.083-.062 6-4 .07-.043.12-.056.111-.036.108-.022.083-.01h.031c.046-.002.083 0 .12.003z"],geolocation:["M-.01 6.66l7.34 2 2 7.33 6.66-16z"],geosearch:["M8.82 12.4h.66c.23 0 .36-.17.36-.4v-1.48l.19-.18c-.27.03-.55.06-.83.06-.28 0-.56-.03-.84-.07.02.04.05.08.07.13V12c0 .23.15.4.39.4zM6.4 15.1A5.51 5.51 0 01.9 9.6c0-.49.06-.98.18-1.43.03 0 .05-.01.08-.01h.08v.44c0 .19.17.34.36.34.03 0 .07-.01.1-.01l.71.7c.07.07.19.07.26 0s.07-.19 0-.26l-.7-.72c0-.02.03-.03.03-.05v-.11c0-.15.08-.2.23-.33h.42c.08 0 .15-.01.22-.04h.02c.02-.02.03-.02.04-.04.01-.01.01-.01.02-.01l.02-.01.9-.9c-.13-.26-.24-.52-.34-.8h-.5v-.43c0-.01.05.05.04-.08h.31c-.03-.13-.06-.26-.08-.39h-.57c.16-.12.34-.24.51-.36-.02-.23-.04-.46-.04-.7 0-.12.01-.23.02-.34A6.385 6.385 0 000 9.6C0 13.13 2.87 16 6.4 16c3.1 0 5.67-2.22 6.26-5.15l-.78-.88c-.21 2.85-2.58 5.13-5.48 5.13zm-1.7-2.93v-.28h.12c.23 0 .39-.19.39-.42v-.54s.01-.01 0-.01L3.77 9.45h-.62c-.23 0-.38.19-.38.42v1.6c0 .23.14.42.38.42h.26v1.61c0 .23.22.41.45.41s.45-.18.45-.41v-.97H4.3c.24 0 .4-.13.4-.36zm11.07-2.34l-2.94-2.94c.11-.17.21-.34.3-.52.01-.03.03-.06.04-.09.08-.18.16-.36.22-.55v-.01c.06-.19.1-.38.14-.58.01-.05.01-.09.02-.14.03-.2.05-.4.05-.61a4.4 4.4 0 00-4.4-4.4C6.77 0 4.8 1.97 4.8 4.4s1.97 4.4 4.4 4.4c.21 0 .41-.02.61-.05.04 0 .09-.01.14-.02.2-.03.39-.08.58-.14h.01c.19-.06.37-.14.55-.22.03-.01.06-.03.09-.04.18-.09.35-.19.52-.3l2.94 2.94a.8.8 0 00.57.23c.44 0 .8-.36.8-.8a.895.895 0 00-.24-.57zM9.2 7.6C7.43 7.6 6 6.17 6 4.4c0-1.77 1.43-3.2 3.2-3.2s3.2 1.43 3.2 3.2c0 1.77-1.43 3.2-3.2 3.2zm1.54 4.26v-.52c0-.09-.1-.17-.19-.17s-.19.07-.19.17v.52c0 .09.1.17.19.17s.19-.07.19-.17z"],"git-branch":["M12 1c-1.66 0-3 1.34-3 3 0 1.25.76 2.32 1.85 2.77A2.02 2.02 0 019 8H7c-.73 0-1.41.2-2 .55V5.82C6.16 5.4 7 4.3 7 3c0-1.66-1.34-3-3-3S1 1.34 1 3c0 1.3.84 2.4 2 2.82v4.37c-1.16.4-2 1.51-2 2.81 0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.04-.53-1.95-1.32-2.49.35-.31.81-.51 1.32-.51h2c1.92 0 3.52-1.35 3.91-3.15A2.996 2.996 0 0012 1zM4 2c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm0 12c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm8-9c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-commit":["M15 7h-3.14c-.45-1.72-2-3-3.86-3S4.59 5.28 4.14 7H1c-.55 0-1 .45-1 1s.45 1 1 1h3.14c.45 1.72 2 3 3.86 3s3.41-1.28 3.86-3H15c.55 0 1-.45 1-1s-.45-1-1-1zm-7 3c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"],"git-merge":["M12 6c-1.3 0-2.4.84-2.82 2H9c-1.62 0-3-.96-3.63-2.34C6.33 5.16 7 4.16 7 3c0-1.66-1.34-3-3-3S1 1.34 1 3c0 1.3.84 2.4 2 2.81v4.37C1.84 10.6 1 11.7 1 13c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.3-.84-2.4-2-2.82V8.43A5.89 5.89 0 009 10h.18A2.996 2.996 0 0015 9c0-1.66-1.34-3-3-3zm-8 8c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zM4 4c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm8 6c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-new-branch":["M14 2h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1zm-3.18 4.8C10.51 7.51 9.82 8 9 8H7c-.73 0-1.41.2-2 .55V5.82C6.16 5.4 7 4.3 7 3c0-1.66-1.34-3-3-3S1 1.34 1 3c0 1.3.84 2.4 2 2.82v4.37c-1.16.4-2 1.51-2 2.81 0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.04-.53-1.95-1.32-2.49.35-.31.81-.51 1.32-.51h2c1.9 0 3.49-1.33 3.89-3.11-.29.07-.58.11-.89.11-.41 0-.8-.08-1.18-.2zM4 2c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm0 12c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-pull":["M3 1C1.34 1 0 2.34 0 4c0 1.3.84 2.4 2 2.82v3.37C.84 10.6 0 11.7 0 13c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.3-.84-2.4-2-2.82V6.82C5.16 6.4 6 5.3 6 4c0-1.66-1.34-3-3-3zm0 13c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm0-9c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm11 5.18V6c0-1.66-1.34-3-3-3H9.41l1.29-1.29c.19-.18.3-.43.3-.71A1.003 1.003 0 009.29.29l-3 3C6.11 3.47 6 3.72 6 4c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L9.41 5H11c.55 0 1 .45 1 1v4.18A2.996 2.996 0 0013 16c1.66 0 3-1.34 3-3 0-1.3-.84-2.4-2-2.82zM13 14c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-push":["M4 6h1V5H4v1zm9 3c0-.28-.11-.53-.29-.71l-3-3C9.53 5.11 9.28 5 9 5s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L8 8.41V15c0 .55.45 1 1 1s1-.45 1-1V8.41l1.29 1.29c.18.19.43.3.71.3.55 0 1-.45 1-1zM5 3H4v1h1V3zm10-3H1C.45 0 0 .45 0 1v13c0 .55.45 1 1 1h5v-2H2v-1h4v-1H3V2h11v9h-2v1h2v1h-2v2h3c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"git-repo":["M5 9H4v1h1V9zm10-9H1C.45 0 0 .45 0 1v13c0 .55.45 1 1 1h3v1l2-1 2 1v-1h7c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM4 13H2v-1h2v1zm10 0H8v-1h6v1zm0-2H3V2h11v9zM5 3H4v1h1V3zm0 4H4v1h1V7zm0-2H4v1h1V5z"],glass:["M2 0v4c0 2.97 2.16 5.43 5 5.91V14H5c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1H9V9.91c2.84-.48 5-2.94 5-5.91V0H2z"],globe:["M4.45 7.83c-.26 0-.41.21-.41.46v1.75c0 .26.16.46.41.46h.29v1.77c0 .25.24.45.49.45s.49-.2.49-.45V11.2h-.01c.26 0 .44-.14.44-.4v-.3h.14c.26 0 .43-.2.43-.46v-.59s.01-.01 0-.01l-1.58-1.6h-.69zM8.51 3.9h.22c.06 0 .12-.01.12-.07 0-.06-.05-.07-.12-.07h-.22c-.06 0-.12.01-.12.07.01.06.06.07.12.07zm-2.33-.05c.07-.07.07-.19 0-.26l-.5-.5a.187.187 0 00-.26 0c-.07.07-.07.19 0 .26l.5.5c.07.07.19.07.26 0zm3.06.89c.07 0 .14-.06.14-.12v-.31c0-.07-.07-.12-.14-.12s-.14.06-.14.12v.31c0 .07.07.12.14.12zM8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6 0-.55.1-1.07.23-1.57h.11v.47c0 .2.18.37.39.37.03 0 .08-.01.11-.02l.78.77c.08.08.2.08.28 0 .08-.08.08-.2 0-.28l-.75-.78c0-.02.04-.04.04-.06v-.12c0-.16.09-.22.25-.36h.46c.09 0 .17-.01.24-.05h.02c.02-.01.03-.02.05-.03.01-.01.01-.01.02-.01l.02-.02 1.59-1.58c.18-.18.18-.46 0-.64s-.47-.15-.65.03l-.3.34h-.57v-.48c0-.01.05.05.05-.09h.64c.12 0 .22-.09.22-.21s-.1-.21-.22-.21H4.1c.18-.15.34-.31.54-.44l.01-.01c.21-.14.45-.25.68-.37.15-.07.29-.15.44-.21.17-.07.35-.11.53-.17.18-.05.35-.12.53-.16a6.05 6.05 0 013.47.35c.05.02.1.05.16.08.25.11.48.24.71.39.25.16.49.34.71.55H10.6s0-.03-.01-.03c-.04 0-.09 0-.13.03l-.51.51a.17.17 0 000 .23c.06.06.17.06.23 0l.42-.44.01-.02h.25c0 .14-.07.09-.07.12v.07c0 .22-.15.37-.36.37h-.38c-.19 0-.38.21-.38.4v.17h-.1c-.12 0-.2.06-.2.18v.25h-.23c-.17 0-.3.11-.3.28 0 .17.13.26.3.26.07 0 .14.03.19-.11l.04.01.49-.46h.17l.39.37c.03.03.08.02.12-.01.03-.03.03-.12 0-.15l-.32-.35h.23l.09.12c.18.18.48.17.66-.01l.09-.1h.4c.02 0 .08.05.08.05v.24l-.05-.01h-.36c-.11 0-.21.1-.21.21 0 .11.09.21.21.21h.41v.15c-.14.21-.24.42-.45.42h-.94v-.01l-.44-.44a.47.47 0 00-.66 0l-.42.43v.01H8.6c-.26 0-.49.21-.49.46v.92c0 .26.23.45.49.45h.9c.34.14.57.35.72.69v1.68c0 .26.17.44.42.44h.72c.26 0 .4-.18.4-.44V9l.89-.86.03-.02.02-.01h.03c.07-.08.15-.19.15-.31v-.91c0-.18-.16-.32-.31-.46H13c.01.28.21.42.46.42h.42c.08.37.12.76.12 1.15 0 3.31-2.69 6-6 6zm4.54-4.27c-.1 0-.21.08-.21.18v.57c0 .1.11.18.21.18.1 0 .21-.08.21-.18v-.57c0-.1-.11-.18-.21-.18zM8.37 3.19c0-.25-.2-.42-.46-.42h-.54c-.25 0-.42.18-.42.43 0 .03-.1.04.05.08v.47c0 .15.06.27.21.27s.21-.12.21-.27v-.14h.5c.24 0 .45-.16.45-.42z"],"globe-network":["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm5.17 5h-2.44c-.21-1.11-.51-2.03-.91-2.69 1.43.46 2.61 1.43 3.35 2.69zM10 8c0 .73-.05 1.39-.12 2H6.12C6.05 9.39 6 8.73 6 8s.05-1.39.12-2h3.76c.07.61.12 1.27.12 2zM8 2c.67 0 1.36 1.1 1.73 3H6.27C6.64 3.1 7.33 2 8 2zm-1.82.31c-.4.66-.71 1.58-.91 2.69H2.83a6.025 6.025 0 013.35-2.69zM2 8c0-.7.13-1.37.35-2h2.76C5.04 6.62 5 7.28 5 8s.04 1.38.11 2H2.35C2.13 9.37 2 8.7 2 8zm.83 3h2.44c.21 1.11.51 2.03.91 2.69A6.025 6.025 0 012.83 11zM8 14c-.67 0-1.36-1.1-1.73-3h3.46c-.37 1.9-1.06 3-1.73 3zm1.82-.31c.4-.66.7-1.58.91-2.69h2.44a6.025 6.025 0 01-3.35 2.69zM13.65 10h-2.76c.07-.62.11-1.28.11-2s-.04-1.38-.11-2h2.76c.22.63.35 1.3.35 2s-.13 1.37-.35 2z"],graph:["M14 3c-1.06 0-1.92.83-1.99 1.88l-1.93.97A2.95 2.95 0 008 5c-.56 0-1.08.16-1.52.43L3.97 3.34C3.98 3.23 4 3.12 4 3c0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.24 0 .47-.05.68-.13l2.51 2.09C5.08 7.29 5 7.63 5 8c0 .96.46 1.81 1.16 2.35l-.56 1.69c-.91.19-1.6.99-1.6 1.96 0 1.1.9 2 2 2s2-.9 2-2c0-.51-.2-.97-.51-1.32l.56-1.69A2.99 2.99 0 0011 8c0-.12-.02-.24-.04-.36l1.94-.97c.32.21.69.33 1.1.33 1.1 0 2-.9 2-2s-.9-2-2-2z"],"graph-remove":["M12.89 8.11l-.01.01-.38-.38-.38.38-.02-.02c-.54.55-1.27.9-2.1.9-1.66 0-3-1.34-3-3 0-.83.35-1.56.9-2.1l-.02-.02.38-.38-.38-.38.01-.01C7.35 2.57 7 1.83 7 1c0-.34.07-.65.17-.96A8.004 8.004 0 000 8c0 4.42 3.58 8 8 8 4.14 0 7.54-3.14 7.96-7.17-.31.1-.62.17-.96.17-.83 0-1.57-.35-2.11-.89zm1.02-4.61l1.79-1.79c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-1.79 1.8L10.71.3A.965.965 0 0010 0a1.003 1.003 0 00-.71 1.71l1.79 1.79-1.79 1.79a1.003 1.003 0 001.42 1.42l1.79-1.79 1.79 1.79a1.003 1.003 0 001.42-1.42l-1.8-1.79z"],"greater-than":["M2.713 5.958a1 1 0 01.574-1.916l10 3c.95.285.95 1.63 0 1.916l-10 3a1 1 0 01-.574-1.916L9.52 8 2.713 5.958z"],"greater-than-or-equal-to":["M2.713 3.958a1 1 0 01.574-1.916l10 3c.95.285.95 1.63 0 1.916l-10 3a1 1 0 01-.574-1.916L9.52 6 2.713 3.958zM3 12h10a1 1 0 010 2H3a1 1 0 010-2z"],grid:["M15 9c.55 0 1-.45 1-1s-.45-1-1-1h-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1H9V1c0-.55-.45-1-1-1S7 .45 7 1v1H4V1c0-.55-.45-1-1-1S2 .45 2 1v1H1c-.55 0-1 .45-1 1s.45 1 1 1h1v3H1c-.55 0-1 .45-1 1s.45 1 1 1h1v3H1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1v-1h3v1c0 .55.45 1 1 1s1-.45 1-1v-1h3v1c0 .55.45 1 1 1s1-.45 1-1v-1h1c.55 0 1-.45 1-1s-.45-1-1-1h-1V9h1zm-8 3H4V9h3v3zm0-5H4V4h3v3zm5 5H9V9h3v3zm0-5H9V4h3v3z"],"grid-view":["M0 1v6h7V0H1C.45 0 0 .45 0 1zm0 14c0 .55.45 1 1 1h6V9H0v6zM15 0H9v7h7V1c0-.55-.45-1-1-1zM9 16h6c.55 0 1-.45 1-1V9H9v7z"],"group-objects":["M5 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6-3H5C2.24 3 0 5.24 0 8s2.24 5 5 5h6c2.76 0 5-2.24 5-5s-2.24-5-5-5zm0 9H5c-2.21 0-4-1.79-4-4s1.79-4 4-4h6c2.21 0 4 1.79 4 4s-1.79 4-4 4zm0-6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],"grouped-bar-chart":["M10 12c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1s-1 .45-1 1v8c0 .55.45 1 1 1zm3 0c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1s-1 .45-1 1v5c0 .55.45 1 1 1zm2 1H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm-9-1c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1s-1 .45-1 1v3c0 .55.45 1 1 1zm-3 0c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1s-1 .45-1 1v9c0 .55.45 1 1 1z"],hand:["M15 5c0-.55-.45-1-1-1-.41 0-.76.24-.91.59v.01s0 .01-.01.01L11.57 8h-.36l.78-4.84C12 3.11 12 3.05 12 3a1 1 0 00-1.99-.16v.01L9.18 8H9V1c0-.55-.45-1-1-1S7 .45 7 1v7h-.09l-.93-5.18A1 1 0 005 2c-.55 0-1 .45-1 1 0 .05 0 .11.01.16L5.26 11h-.04L2.83 7.44C2.65 7.18 2.35 7 2 7c-.55 0-1 .45-1 1 0 .17.04.33.12.47l3 5.69h.01v.01A5.002 5.002 0 0013 11v-.59l1.93-5.05c.05-.11.07-.23.07-.36z"],"hand-down":["M14.72 7.87c-1.54-.67-2.99-2.68-3.7-3.95C10.11 1.95 9.93 0 6.14 0 4.05 0 2.71.61 1.92 2.12 1.27 3.36 1 5.21 1 7.83v.79c0 .65.6 1.18 1.35 1.18.34 0 .64-.11.88-.29.17.48.68.84 1.29.84.41 0 .78-.16 1.03-.42.23.37.67.63 1.19.63.57 0 1.05-.31 1.25-.74l.01.63v4.05c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5V7.9c.58.41 1.55 1.21 2.47 1.29 1.57.14 1.82-1.07 1.25-1.32z"],"hand-left":["M12.08 4.97c-1.26-.71-3.27-2.15-3.95-3.7C7.88.7 6.67.96 6.81 2.52c.09.93.89 1.9 1.3 2.48H1.5C.67 5 0 5.67 0 6.5S.67 8 1.5 8h4.05l.63.01c-.44.2-.75.69-.75 1.25 0 .52.26.96.63 1.19-.26.25-.42.61-.42 1.03 0 .61.35 1.12.84 1.29-.18.24-.29.54-.29.88 0 .75.54 1.35 1.19 1.35h.79c2.62 0 4.47-.28 5.71-.92 1.51-.79 2.12-2.14 2.12-4.22 0-3.79-1.95-3.97-3.92-4.89z"],"hand-right":["M14.5 5H7.89c.41-.58 1.21-1.55 1.3-2.47C9.34.97 8.12.71 7.87 1.28c-.67 1.54-2.68 2.99-3.95 3.7C1.95 5.89 0 6.07 0 9.86c0 2.09.61 3.43 2.12 4.22 1.24.65 3.09.92 5.71.92h.79c.65 0 1.18-.6 1.18-1.35 0-.34-.11-.64-.29-.88.48-.17.84-.68.84-1.29 0-.41-.16-.78-.42-1.03.37-.23.63-.67.63-1.19 0-.57-.31-1.05-.74-1.25l.63-.01h4.05c.83 0 1.5-.67 1.5-1.5S15.33 5 14.5 5z"],"hand-up":["M13.65 6.19c-.34 0-.64.11-.88.29-.17-.48-.68-.84-1.29-.84-.41 0-.78.16-1.03.42-.23-.37-.67-.63-1.19-.63-.57 0-1.05.31-1.25.74L8 5.55V1.5C8 .67 7.33 0 6.5 0S5 .67 5 1.5v6.61c-.58-.41-1.55-1.21-2.48-1.3C.96 6.67.7 7.88 1.28 8.13c1.54.67 2.99 2.68 3.7 3.95C5.89 14.05 6.07 16 9.86 16c2.09 0 3.43-.61 4.22-2.12.64-1.24.92-3.09.92-5.71v-.79c0-.65-.6-1.19-1.35-1.19z"],hat:["M15 10c.495 0 .933.379.993.882L16 11v.505c0 1.461-3.524 2.45-7.707 2.493L8 14c-4.31 0-8-1-8-2.495V11c0-.561.466-1 1-1 .895 0 3 1 7 1l.381-.003C12.135 10.937 14.134 10 15 10zm-4-8c1.13 0 2.02 2.153 2.671 6.46-1.063.266-2.644.652-4.887.727l-.403.01L8 9.2c-2.664 0-4.488-.444-5.673-.74C2.98 4.153 3.87 2 5 2c2 0 1.329 2 3 2s1-2 3-2z"],header:["M13 1c-.55 0-1 .45-1 1v5H4V2c0-.55-.45-1-1-1s-1 .45-1 1v12c0 .55.45 1 1 1s1-.45 1-1V9h8v5c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],"header-one":["M14.06 8c-.04.23-.12.44-.25.61-.13.17-.29.3-.48.41-.18.11-.39.18-.62.23-.23.04-.46.07-.71.07v1.03h1.74V16H15V8h-.94zM7 0c-.56 0-1 .45-1 1v4H2V1c0-.55-.45-1-1-1-.56 0-1 .45-1 1v10c0 .55.45 1 1 1 .56 0 1-.45 1-1V7h4v4c0 .55.45 1 1 1 .56 0 1-.45 1-1V1c0-.54-.45-1-1-1z"],"header-three":["M1 0C.44 0 0 .45 0 1v10c0 .54.45 1 1 1 .56 0 1-.45 1-1V7h4v4c0 .54.45 1 1 1 .56 0 1-.45 1-1V1c0-.54-.45-1-1-1-.56 0-1 .45-1 1v4H2V1c0-.54-.45-1-1-1zm13.71 11.72c.41.08.72.3.95.65.23.35.34.77.34 1.27 0 .37-.07.7-.2.97-.14.29-.32.54-.55.74-.23.2-.5.36-.8.47-.3.11-.62.16-.96.16-.41 0-.77-.06-1.08-.19-.31-.12-.56-.31-.77-.54-.21-.24-.36-.52-.47-.85-.11-.33-.16-.7-.17-1.1h1.14c-.01.47.09.86.32 1.17.23.31.57.47 1.02.47.39 0 .71-.12.97-.36s.39-.58.39-1.02c0-.3-.05-.53-.16-.71-.11-.17-.25-.31-.43-.4-.17-.09-.37-.15-.59-.17-.22-.02-.44-.03-.67-.02v-.93c.19.01.38 0 .57-.04.19-.03.36-.1.51-.19.14-.09.26-.22.35-.38.09-.16.14-.36.14-.59 0-.33-.1-.59-.31-.79-.2-.2-.47-.3-.79-.3-.21 0-.38.04-.53.13-.15.09-.27.21-.37.36-.1.15-.17.32-.22.51-.05.19-.07.38-.06.58h-1.15c.01-.38.08-.72.19-1.04.11-.32.27-.6.47-.83.19-.23.44-.42.72-.55.28-.13.6-.2.96-.2.28 0 .55.04.82.13.27.08.51.21.72.38.21.17.38.38.51.64s.19.56.19.9c0 .39-.08.73-.24 1.02-.16.29-.42.5-.76.63v.02z"],"header-two":["M13.17 13.93c-.17.15-.33.29-.46.44-.13.16-.22.32-.27.49h3.55V16H11c.01-.65.16-1.22.44-1.71s.67-.91 1.17-1.27c.24-.18.49-.36.75-.54.25-.18.49-.36.71-.57.21-.2.39-.42.53-.65.14-.24.21-.51.22-.82 0-.14-.02-.29-.05-.45-.03-.16-.09-.31-.18-.45a1.13 1.13 0 00-.37-.35c-.16-.09-.37-.14-.63-.14-.24 0-.43.05-.59.15-.16.1-.29.24-.38.42-.1.17-.17.38-.21.62-.05.24-.07.5-.08.77h-1.19c0-.43.05-.83.16-1.2s.27-.69.49-.96c.21-.25.48-.46.79-.62.31-.15.67-.23 1.07-.23.45 0 .82.08 1.11.23.3.16.55.36.73.6.19.24.32.5.39.79.08.28.12.54.12.79 0 .31-.04.6-.13.85s-.22.49-.37.7c-.15.21-.32.41-.52.59s-.4.35-.61.51l-.63.45c-.21.14-.39.28-.57.42zM0 1c0-.55.44-1 1-1 .55 0 1 .46 1 1v10c0 .55-.44 1-1 1-.55 0-1-.46-1-1V1zm6 0c0-.55.44-1 1-1 .55 0 1 .46 1 1v10c0 .55-.44 1-1 1-.55 0-1-.46-1-1V1zM2 5h4v2H2V5z"],headset:["M14.85 6.34C14.18 2.72 11.37 0 8 0S1.82 2.72 1.15 6.34C.47 6.9 0 8.1 0 9.5 0 11.43.9 13 2 13c0 1.1.9 2 2 2h2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1H7c-.55 0-1 .45-1 1H4c-.55 0-1-.45-1-1 .55 0 1-.45 1-1V7c0-.45-.3-.81-.71-.94C3.97 3.7 5.81 2 8 2s4.03 1.7 4.71 4.06c-.41.13-.71.49-.71.94v5c0 .55.45 1 1 1h1c1.1 0 2-1.57 2-3.5 0-1.4-.47-2.6-1.15-3.16z"],heart:["M16 5.095c0-2.255-1.88-4.083-4.2-4.083-1.682 0-3.13.964-3.8 2.352a4.206 4.206 0 00-3.8-2.352C1.88 1.012 0 2.84 0 5.095c0 .066.007.13.01.194H.004c.001.047.01.096.014.143l.013.142c.07.8.321 1.663.824 2.573C2.073 10.354 4.232 12.018 8 15c3.767-2.982 5.926-4.647 7.144-6.854.501-.905.752-1.766.823-2.562.007-.055.012-.11.016-.164.003-.043.012-.088.013-.13h-.006c.003-.066.01-.13.01-.195z"],"heart-broken":["M7.71 8.87L6.17 6.55l.02-.01A.906.906 0 016 6c0-.07.03-.13.04-.19h-.02l.78-3.92C6.09 1.34 5.19 1 4.2 1 1.88 1 0 2.83 0 5.09c0 .07.01.13.01.19H0c0 .05.01.1.01.14 0 .05.01.1.01.14.07.8.32 1.66.82 2.57 1.07 1.94 2.88 3.47 5.86 5.84l-.68-2.74h.02C6.03 11.16 6 11.08 6 11c0-.28.11-.53.29-.71l1.42-1.42zM16 5.09C16 2.83 14.12 1 11.8 1c-1.2 0-2.27.5-3.04 1.28l-.7 3.51 1.77 2.66-.01.01c.1.15.18.33.18.54 0 .28-.11.53-.29.71l-1.6 1.6.75 3.01c3.23-2.56 5.16-4.15 6.28-6.18.5-.91.75-1.77.82-2.56.01-.05.01-.11.02-.16 0-.04.01-.09.01-.13h-.01c.01-.07.02-.14.02-.2z"],"heat-grid":["M0 10h5V7H0v3zm1-2h3v1H1V8zm14-5h-4v3h5V4c0-.55-.45-1-1-1zm0 2h-3V4h3v1zM0 4v2h5V3H1c-.55 0-1 .45-1 1zm0 9c0 .55.45 1 1 1h4v-3H0v2zm6-7h4V3H6v3zm0 8h4v-3H6v3zm1-2h2v1H7v-1zm4 2h4c.55 0 1-.45 1-1v-2h-5v3zm0-4h5V7h-5v3zm-5 0h4V7H6v3z"],heatmap:["M2 11c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm11-7c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm3 4.5A2.5 2.5 0 0013.5 6c-.98 0-1.82.57-2.23 1.39-.6-.78-1.51-1.3-2.56-1.36.18-.49.29-.99.29-1.53C9 2.01 6.99 0 4.5 0S0 2.01 0 4.5 2.01 9 4.5 9c.19 0 .37-.03.56-.06-.03.19-.06.37-.06.56C5 11.43 6.57 13 8.5 13c1.63 0 2.98-1.11 3.37-2.62.44.38 1 .62 1.63.62A2.5 2.5 0 0016 8.5zM14.5 13c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z"],helicopter:["M.5 2a.5.5 0 01.5.5V4h7V3H2.5a.5.5 0 010-1h13a.5.5 0 010 1H10v1h1c2.26 0 4 1.79 4 4 0 1.87-1.247 3.44-3 3.878V13h.382l1.894-.947a.5.5 0 11.448.894L12.618 14H4.5a.5.5 0 010-1H7v-2.306C5.749 9.736 5 8.368 5 7L1 6v1.5a.5.5 0 01-1 0v-5A.5.5 0 01.5 2zM8 11.316V13h3v-1a6.73 6.73 0 01-3-.684zM11 5v3h3a3 3 0 00-3-3z"],help:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm1 13H7v-2h2v2zm1.93-6.52c-.14.32-.35.64-.62.97L9.25 8.83c-.12.15-.24.29-.28.42-.04.13-.09.3-.09.52V10H7.12V8.88s.05-.51.21-.71L8.4 6.73c.22-.26.35-.49.44-.68.09-.19.12-.38.12-.58 0-.3-.1-.55-.28-.75-.18-.19-.44-.28-.76-.28-.33 0-.59.1-.78.29-.19.19-.33.46-.4.81-.03.11-.1.15-.2.14l-1.7-.25c-.12-.01-.16-.08-.14-.19.12-.82.46-1.47 1.03-1.94.57-.48 1.32-.72 2.25-.72.47 0 .9.07 1.29.22s.72.34 1 .59c.28.25.49.55.65.89.15.35.22.72.22 1.12s-.07.75-.21 1.08z"],"helper-management":["M13 5h-2v2h2V5zm0 6h-2v2h2v-2zm0-3h-2v2h2V8zm2-8H1C.4 0 0 .4 0 1v14c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V1c0-.6-.4-1-1-1zm-1 14H2V2h12v12zm-7-3H5v2h2v-2zm3 0H8v2h2v-2z"],"high-priority":["M9 14v2H7v-2h2zm1-14L9 12H7L6 0h4z"],highlight:["M9.12 11.07l2-2.02.71.71 4-4.04L10.17 0l-4 4.04.71.71-2 2.02 4.24 4.3zM2 12.97h4c.28 0 .53-.11.71-.3l1-1.01-3.42-3.45-3 3.03c-.18.18-.29.44-.29.72 0 .55.45 1.01 1 1.01zm13 1.01H1c-.55 0-1 .45-1 1.01S.45 16 1 16h14c.55 0 1-.45 1-1.01s-.45-1.01-1-1.01z"],history:["M8 3c-.55 0-1 .45-1 1v4c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L9 7.59V4c0-.55-.45-1-1-1zm0-3a7.95 7.95 0 00-6 2.74V1c0-.55-.45-1-1-1S0 .45 0 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.54C4.64 2.78 6.23 2 8 2c3.31 0 6 2.69 6 6 0 2.61-1.67 4.81-4 5.63v-.01c-.63.23-1.29.38-2 .38-3.31 0-6-2.69-6-6 0-.55-.45-1-1-1s-1 .45-1 1c0 4.42 3.58 8 8 8 .34 0 .67-.03 1-.07.02 0 .04-.01.06-.01C12.98 15.4 16 12.06 16 8c0-4.42-3.58-8-8-8z"],home:["M2 10v5c0 .55.45 1 1 1h3v-5h4v5h3c.55 0 1-.45 1-1v-5L8 4l-6 6zm13.71-2.71L14 5.59V2c0-.55-.45-1-1-1s-1 .45-1 1v1.59L8.71.29C8.53.11 8.28 0 8 0s-.53.11-.71.29l-7 7a1.003 1.003 0 001.42 1.42L8 2.41l6.29 6.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"horizontal-bar-chart":["M4 5h7c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zM1 1c-.55 0-1 .45-1 1v13c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1zm14 6H4c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h11c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-6 5H4c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1z"],"horizontal-bar-chart-asc":["M1 3h5c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm0 4h7c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 6H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM1 11h10c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1z"],"horizontal-bar-chart-desc":["M15 1H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM8 9H1c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1zm-2 4H1c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm5-8H1c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1z"],"horizontal-distribution":["M2 0c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm13 0c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm-5 2H7c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],hurricane:["M3.5 12c-.86 0-2.5-.5-3.5-1 1 3.5 4.506 4 7 4a7 7 0 007-7l-.006-.004a5.974 5.974 0 00-1.29-3.988c.896.066 2.37.53 3.296.992-1-3.5-4.506-4-7-4a6.998 6.998 0 00-6.14 3.635 5.972 5.972 0 00-.859 3.226L2 8l.006.005a5.98 5.98 0 001.771 3.99A7.469 7.469 0 013.5 12zM8 6a2 2 0 100 4 2 2 0 000-4z","M0 0h16v16H0z"],"id-number":["M2 5v7h12V5H2zm0-2h12c1.1 0 2 .9 2 2v7c0 1.1-.9 2-2 2H2c-1.1 0-2-.9-2-2V5c0-1.1.9-2 2-2z","M7.9 10.48c-.14-.33-.84-.55-1.3-.75-.46-.2-.4-.33-.42-.5v-.07c.16-.14.29-.33.37-.56 0 0 0-.01.01-.02.02-.05.03-.1.05-.15.1-.01.16-.13.19-.23.03-.04.07-.15.06-.27-.02-.16-.08-.24-.15-.26v-.03c0-.2-.02-.48-.05-.67-.01-.05-.02-.1-.03-.16-.07-.23-.21-.44-.4-.58-.2-.15-.48-.23-.73-.23s-.53.08-.72.23c-.19.14-.33.35-.4.58-.02.05-.03.1-.03.16-.05.18-.06.47-.06.67v.03c-.07.03-.14.1-.15.26-.02.12.03.22.06.27.02.1.09.22.2.24.01.05.03.1.05.15v.01c.08.23.22.42.38.56v.07c-.02.17.03.29-.43.5-.46.2-1.16.42-1.3.75s-.09.52-.09.52H8c-.01 0 .05-.19-.1-.52zM10 6h2c.55 0 1 .45 1 1s-.45 1-1 1h-2c-.55 0-1-.45-1-1s.45-1 1-1zM10 9h2c.55 0 1 .45 1 1s-.45 1-1 1h-2c-.55 0-1-.45-1-1s.45-1 1-1z"],"image-rotate-left":["M13 2h-1.59l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C8.11 2.47 8 2.72 8 3c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H13c.55 0 1 .45 1 1v3c0 .55.45 1 1 1s1-.45 1-1V5c0-1.66-1.34-3-3-3zm-5.5 9c.28 0 .5-.22.5-.5s-.22-.5-.5-.5-.5.22-.5.5.22.5.5.5zM10 7H1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-1 6.33L7 12l-1 1-2-3-2 2.67V9h7v4.33z"],"image-rotate-right":["M5.71 5.71l2-2C7.89 3.53 8 3.28 8 3c0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H3C1.34 2 0 3.34 0 5v3c0 .55.45 1 1 1s1-.45 1-1V5c0-.55.45-1 1-1h1.59l-.3.29a1.003 1.003 0 001.42 1.42zM12.5 11c.28 0 .5-.22.5-.5s-.22-.5-.5-.5-.5.22-.5.5.22.5.5.5zM15 7H6c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-1 6.33L12 12l-1 1-2-3-2 2.67V9h7v4.33z"],import:["M7.29 11.71c.18.18.43.29.71.29s.53-.11.71-.29l4-4a1.003 1.003 0 00-1.42-1.42L9 8.59V1c0-.55-.45-1-1-1S7 .45 7 1v7.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l4 4zM15 11c-.55 0-1 .45-1 1v2H2v-2c0-.55-.45-1-1-1s-1 .45-1 1v3c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1z"],inbox:["M13.91 2.6c-.16-.36-.51-.61-.92-.61h-10c-.41 0-.77.25-.92.61L-.01 7.45v5.54c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V7.45L13.91 2.6zm-1.92 5.39c-.55 0-1 .45-1 1v1h-6v-1c0-.55-.45-1-1-1H1.94l1.71-4h8.68l1.71 4h-2.05z"],"inbox-filtered":["M6.432 2c.094.14.202.273.324.394L8.42 4H3.66L1.95 8H4c.55 0 1 .45 1 1v1h6.557c.693 0 1.363-.262 1.837-.736l.103-.102.85-1.14a2.564 2.564 0 00.623-1.682V5.058L16 7.46V13c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V7.46l2.08-4.85C2.23 2.25 2.59 2 3 2h3.432zm9.048-2c.31 0 .52.26.52.57 0 .16-.06.3-.17.41l-2.86 2.73v2.63c0 .16-.06.3-.17.41l-.82 1.1c-.1.1-.25.17-.41.17-.31 0-.57-.26-.57-.57V3.71L8.17.98A.566.566 0 018 .57c0-.31.26-.57.57-.57h6.91z"],"inbox-geo":["M6.341 2A5.99 5.99 0 006 4H3.66L1.95 8H4c.55 0 1 .45 1 1v1h7a5.978 5.978 0 004-1.528V13c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V7.46l2.08-4.85C2.23 2.25 2.59 2 3 2h3.341zm3.679 2.145c0-.125.075-.23.205-.225h.345l.79.8c.005 0 0 .005 0 .005v.295c0 .13-.085.23-.215.23h-.07v.15c0 .13-.09.2-.215.2v.535c0 .125-.12.225-.245.225s-.245-.1-.245-.225V5.25h-.145c-.125 0-.205-.1-.205-.23v-.875zm2.235-2.195c-.03 0-.055-.005-.06-.035 0-.03.03-.035.06-.035h.11c.035 0 .06.005.06.035 0 .03-.03.035-.06.035h-.11zm-1.165-.025a.094.094 0 01-.13 0l-.25-.25a.094.094 0 010-.13.094.094 0 01.13 0l.25.25a.094.094 0 010 .13zm1.53.445c-.035 0-.07-.025-.07-.06v-.155c0-.03.035-.06.07-.06s.07.025.07.06v.155c0 .03-.035.06-.07.06zM12 0c2.21 0 4 1.79 4 4s-1.79 4-4 4-4-1.79-4-4 1.79-4 4-4zm0 7c1.655 0 3-1.345 3-3 0-.195-.02-.39-.06-.575h-.21c-.125 0-.225-.07-.23-.21h-.215c.075.07.155.14.155.23V3.9c0 .06-.04.115-.075.155h-.015l-.01.005-.015.01-.445.43v.815c0 .13-.07.22-.2.22h-.36c-.125 0-.21-.09-.21-.22v-.84a.627.627 0 00-.36-.345h-.45c-.13 0-.245-.095-.245-.225v-.46c0-.125.115-.23.245-.23l.13-.005.21-.215c.09-.09.24-.09.33 0l.22.225h.47c.105 0 .155-.105.225-.21v-.075h-.205a.106.106 0 01-.105-.105.11.11 0 01.105-.105h.18l.025.005v-.12s-.03-.025-.04-.025h-.2l-.045.05a.235.235 0 01-.33.005l-.045-.06h-.115l.16.175c.015.015.015.06 0 .075-.02.015-.045.02-.06.005l-.195-.185h-.085l-.245.23-.02-.005c-.025.07-.06.055-.095.055-.085 0-.15-.045-.15-.13s.065-.14.15-.14h.115v-.125c0-.06.04-.09.1-.09h.05V2.36c0-.095.095-.2.19-.2h.19c.105 0 .18-.075.18-.185V1.94c0-.015.035.01.035-.06h-.125l-.005.01-.21.22a.085.085 0 01-.115 0 .085.085 0 010-.115l.255-.255c.02-.015.045-.015.065-.015.005 0 .005.015.005.015h.64a2.327 2.327 0 00-.355-.275 2.452 2.452 0 00-.355-.195c-.03-.015-.055-.03-.08-.04a3.025 3.025 0 00-1.735-.175c-.09.02-.175.055-.265.08-.09.03-.18.05-.265.085-.075.03-.145.07-.22.105-.115.06-.235.115-.34.185l-.005.005c-.1.065-.18.145-.27.22h.455c.06 0 .11.045.11.105s-.05.105-.11.105h-.32c0 .07-.025.04-.025.045v.24h.285l.15-.17c.09-.09.235-.105.325-.015.09.09.09.23 0 .32l-.795.79-.01.01c-.005 0-.005 0-.01.005l-.025.015h-.01a.235.235 0 01-.12.025h-.23c-.08.07-.125.1-.125.18v.06c0 .01-.02.02-.02.03l.375.39c.04.04.04.1 0 .14-.04.04-.1.04-.14 0l-.39-.385a.213.213 0 01-.055.01c-.105 0-.195-.085-.195-.185v-.235h-.055A3.1 3.1 0 009 4c0 1.655 1.345 3 3 3zm2.27-2.135c.05 0 .105.04.105.09v.285c0 .05-.055.09-.105.09-.05 0-.105-.04-.105-.09v-.285c0-.05.055-.09.105-.09zm-2.085-3.27c0 .13-.105.21-.225.21h-.25v.07c0 .075-.03.135-.105.135s-.105-.06-.105-.135V1.64c-.075-.02-.025-.025-.025-.04 0-.125.085-.215.21-.215h.27c.13 0 .23.085.23.21z"],"inbox-search":["M5.639 2a5.391 5.391 0 00-.144 2H3.66L1.95 8H4c.55 0 1 .45 1 1v1h6V9c0-.088.012-.174.033-.255.12-.007.238-.019.39-.038.154-.008.252-.03.442-.077a5.34 5.34 0 00.24-.05h.05l.122-.04 1.266 1.271c.425.47 1.116.769 1.847.769.21 0 .414-.025.61-.071V13c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V7.46l2.08-4.85C2.23 2.25 2.59 2 3 2h2.639zM15.82 7.53c.1.12.17.27.18.44 0 .34-.27.61-.61.61a.57.57 0 01-.43-.18l-2.24-2.25c-.13.08-.26.16-.4.23-.02.01-.05.02-.07.03-.14.06-.27.12-.42.17h-.01c-.14.05-.29.08-.44.11-.04.01-.08.02-.11.02-.15.02-.3.04-.46.04-1.85 0-3.35-1.51-3.35-3.37S8.96.01 10.81 0c1.85 0 3.35 1.51 3.35 3.37 0 .16-.02.31-.04.47-.01.04-.01.07-.02.11-.02.15-.05.29-.1.44v.01c-.05.15-.11.28-.17.42-.01.02-.02.05-.03.07-.07.14-.14.27-.23.4l2.25 2.24zm-5.01-1.94c1.22 0 2.21-.99 2.21-2.22 0-1.23-.99-2.22-2.21-2.22S8.6 2.14 8.6 3.37c0 1.22.99 2.22 2.21 2.22z"],"inbox-update":["M8.1 2a5.023 5.023 0 000 2H3.66L1.95 8H4c.55 0 1 .45 1 1v1h6V9c0-.55.45-1 1-1h2.05c.708 0 1.352-.241 1.905-.645L16 7.46V13c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V7.46l2.08-4.85C2.23 2.25 2.59 2 3 2h5.1zM13 6a3 3 0 110-6 3 3 0 010 6z"],"info-sign":["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zM7 3h2v2H7V3zm3 10H6v-1h1V7H6V6h3v6h1v1z"],inheritance:["M5 8c0 1.66 1.34 3 3 3h4.59L11.3 9.71A.965.965 0 0111 9a1.003 1.003 0 011.71-.71l3 3c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-3 3a1.003 1.003 0 01-1.42-1.42l1.3-1.29H8c-2.76 0-5-2.24-5-5H1a1 1 0 01-1-1V1a1 1 0 011-1h6a1 1 0 011 1v6a1 1 0 01-1 1H5zM2 2v4h4V2H2z"],"inherited-group":["M1 7c.51 0 .935.388.993.884L2 8v3c0 .51.388.935.884.993L3 12h1.59l-.3-.29a1.003 1.003 0 011.324-1.504l.096.084 2 2c.18.18.29.43.29.71 0 .233-.076.446-.206.614l-.084.096-2 2A1.003 1.003 0 014 15c0-.24.08-.458.224-.629l.076-.081.29-.29H3a2.996 2.996 0 01-2.995-2.823L0 11V8c0-.55.45-1 1-1zm5.388-7c.629 0 1.338.21 1.838.6.48.38.85.91 1.019 1.52.04.13.07.27.09.4.09.48.14 1.22.14 1.73v.07c.18.08.34.27.37.67.03.32-.09.59-.16.71-.06.28-.21.58-.48.63-.03.13-.07.26-.12.39 0 .01-.01.04-.01.04-.22.58-.55 1.08-.949 1.45v.18c.04.45-.12.77 1.059 1.3 1.179.53 2.947 1.09 3.307 1.95.37.86.22 1.36.22 1.36H9c0-.539-.21-1.045-.583-1.417l-2-2A1.997 1.997 0 005 9c-.149 0-.296-.015-.442-.045.099-.19.082-.37.101-.575 0-.05.01-.11.01-.17-.41-.35-.75-.86-.969-1.45v-.01s-.01-.01-.01-.02c-.04-.12-.09-.26-.12-.39-.28-.05-.44-.36-.5-.64-.06-.12-.19-.39-.16-.71.04-.41.21-.6.39-.68v-.06c0-.51.05-1.26.14-1.74.02-.13.05-.27.09-.4.17-.6.54-1.13 1.02-1.51C5.048.21 5.757 0 6.387 0zm4.625 2.04c.49 0 1.05.16 1.439.46.38.29.67.7.8 1.17.03.1.05.21.07.31.07.37.11.94.11 1.33v.05c.139.06.269.21.289.51.02.25-.07.45-.13.54-.05.21-.16.44-.38.48a1.711 1.711 0 01-.1.33c-.17.44-.43.83-.749 1.11v.14c.03.35-.09.59.83 1 .929.41 2.317.84 2.597 1.5.29.66.17 1.04.17 1.04H13.66v.01c-.05-.24-.14-.5-.25-.76-.36-.86-1.119-1.33-2.687-2-.14-.06-.59-.25-.6-.25-.21-.09-.36-.15-.5-.22.02-.1.02-.2.03-.31 0-.04.01-.08.01-.13-.07-.06-.13-.12-.19-.19.22-.32.4-.67.54-1.05.02-.06.02-.06.03-.1.29-.23.48-.57.59-.96.16-.33.25-.73.21-1.16-.03-.4-.16-.76-.37-1.03-.02-.53-.07-1.13-.15-1.54-.01-.06-.02-.12-.03-.19.23-.06.48-.09.72-.09z"],"inner-join":["M6.6 3.3C5.3 4.4 4.5 6.1 4.5 8s.8 3.6 2.1 4.7c-.5.2-1 .3-1.6.3-2.8 0-5-2.2-5-5s2.2-5 5-5c.6 0 1.1.1 1.6.3zm-1.96 8.68C3.92 10.83 3.5 9.46 3.5 8s.42-2.83 1.14-3.98C2.6 4.2 1 5.91 1 8s1.6 3.8 3.64 3.98zM8 4c-1.2.9-2 2.4-2 4s.8 3.1 2 4c1.2-.9 2-2.3 2-4s-.8-3.1-2-4zm3-1c2.8 0 5 2.2 5 5s-2.2 5-5 5c-.6 0-1.1-.1-1.6-.3 1.3-1.1 2.1-2.9 2.1-4.7s-.8-3.5-2.1-4.7c.5-.2 1-.3 1.6-.3zm.35 1.02c.73 1.15 1.14 2.52 1.14 3.98s-.42 2.83-1.14 3.98c2.04-.18 3.64-1.9 3.64-3.98s-1.6-3.8-3.64-3.98z"],insert:["M5 9h2v2c0 .6.4 1 1 1s1-.4 1-1V9h2c.6 0 1-.4 1-1s-.4-1-1-1H9V5c0-.6-.4-1-1-1s-1 .4-1 1v2H5c-.6 0-1 .4-1 1s.4 1 1 1zm10-9H1C.4 0 0 .4 0 1v14c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V1c0-.6-.4-1-1-1zm-1 14H2V2h12v12z"],intersection:["M10 3c-.92 0-1.76.26-2.5.69C6.76 3.26 5.92 3 5 3 2.24 3 0 5.24 0 8s2.24 5 5 5c.92 0 1.76-.26 2.5-.69.74.43 1.58.69 2.5.69 2.76 0 5-2.24 5-5s-2.24-5-5-5zm-4.1 7.85c-.29.09-.59.15-.9.15-1.66 0-3-1.34-3-3s1.34-3 3-3c.31 0 .61.06.9.15C5.33 5.96 5 6.94 5 8s.33 2.04.9 2.85zM10 11c-.31 0-.61-.06-.9-.15.57-.81.9-1.79.9-2.85s-.33-2.04-.9-2.85c.29-.09.59-.15.9-.15 1.66 0 3 1.34 3 3s-1.34 3-3 3z"],"ip-address":["M5 2.66C5 4.14 8 8 8 8s3-3.86 3-5.34C10.99 1.2 9.66 0 8 0S5 1.2 5 2.66zM7 3c0-.55.45-1 1-1s1 .45 1 1-.45 1-1 1-1-.45-1-1zM10.5 10H8v5h1v-4h1v1H9v1h2v-3h-.5zM2 9h12c.55 0 1 .45 1 1v5c0 .55-.45 1-1 1H2c-.55 0-1-.45-1-1v-5c0-.55.45-1 1-1zm4 1v5h1v-5H6z"],issue:["M8 16A8 8 0 118 0a8 8 0 010 16zm0-2A6 6 0 108 2a6 6 0 000 12zm1-2H7v-2h2v2zm0-3H7V4h2v5z"],"issue-closed":["M9.296.104a2.99 2.99 0 00-1.003.664 2.987 2.987 0 00-.75 1.25 6 6 0 106.28 4.527c.043-.039.085-.079.127-.12l1.456-1.456A8 8 0 119.296.105zm2.532 5.2a.997.997 0 01-.707-.294L9.707 3.596a1 1 0 011.414-1.414l.707.707 1.768-1.768a1 1 0 111.414 1.415L12.536 5.01a.997.997 0 01-.708.293zM9 12H7v-2h2v2zm0-3H7V4h2v5z"],"issue-new":["M10.568.421c-.01.04-.018.08-.026.121-.837.156-1.53.73-1.85 1.497a6 6 0 105.27 5.273 2.51 2.51 0 001.496-1.854c.04-.008.081-.016.121-.026A8 8 0 1110.568.421zM9 12H7v-2h2v2zm0-3H7V4h2v5zm1-6c0-.55.45-1 1-1h1V1c0-.55.45-1 1-1s1 .45 1 1v1h1c.55 0 1 .45 1 1s-.45 1-1 1h-1v1.005c0 .55-.45 1-1 1s-1-.45-1-1V4h-1c-.55 0-1-.45-1-1z"],italic:["M9.8 4H11c.5 0 1-.4 1-1s-.4-1-1-1H7c-.5 0-1 .4-1 1s.4 1 1 1h.8l-1.6 8H5c-.5 0-1 .4-1 1s.4 1 1 1h4c.5 0 1-.4 1-1s-.4-1-1-1h-.8l1.6-8z"],"join-table":["M15 5h-3V2c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h3v3c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-5-1v2H6V4h4zm0 6H6V7h4v3zM2 4h3v2H2V4zm0 5V7h3v2H2zm4 4v-2h4v2H6zm8 0h-3v-2h3v2zm0-3h-3V8h3v2z"],key:["M11 0C8.24 0 6 2.24 6 5c0 1.02.31 1.96.83 2.75L.29 14.29a1.003 1.003 0 001.42 1.42L3 14.41l1.29 1.29c.18.19.43.3.71.3s.53-.11.71-.29l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71L6.41 11l1.83-1.83c.8.52 1.74.83 2.76.83 2.76 0 5-2.24 5-5s-2.24-5-5-5zm0 8c-.23 0-.45-.03-.66-.08-.01 0-.02-.01-.03-.01-.21-.05-.41-.12-.6-.21a3.014 3.014 0 01-1.62-2c0-.01-.01-.02-.01-.03C8.03 5.45 8 5.23 8 5c0-1.66 1.34-3 3-3s3 1.34 3 3-1.34 3-3 3z"],"key-backspace":["M15 2H6c-.28 0-.53.11-.71.29l-5 5C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l5 5c.18.18.43.29.71.29h9c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm-2.29 7.29a1.003 1.003 0 01-1.42 1.42L10 9.41 8.71 10.7c-.18.19-.43.3-.71.3a1.003 1.003 0 01-.71-1.71L8.59 8l-1.3-1.29a1.003 1.003 0 011.42-1.42L10 6.59l1.29-1.29c.18-.19.43-.3.71-.3a1.003 1.003 0 01.71 1.71L11.41 8l1.3 1.29z"],"key-command":["M12 9h-1V7h1c1.66 0 3-1.34 3-3s-1.34-3-3-3-3 1.34-3 3v1H7V4c0-1.66-1.34-3-3-3S1 2.34 1 4s1.34 3 3 3h1v2H4c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3v-1h2v1c0 1.66 1.34 3 3 3s3-1.34 3-3-1.34-3-3-3zm0-6c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zM4 13c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm0-8c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm5 4H7V7h2v2zm3 4c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"key-control":["M12.71 5.29l-4-4C8.53 1.11 8.28 1 8 1s-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L8 3.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"key-delete":["M15.71 7.29l-5-5A.997.997 0 0010 2H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h9c.28 0 .53-.11.71-.29l5-5c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zm-7 2a1.003 1.003 0 01-1.42 1.42L6 9.41 4.71 10.7c-.18.19-.43.3-.71.3a1.003 1.003 0 01-.71-1.71L4.59 8l-1.3-1.29a1.003 1.003 0 011.42-1.42L6 6.59 7.29 5.3c.18-.19.43-.3.71-.3a1.003 1.003 0 01.71 1.71L7.41 8l1.3 1.29z"],"key-enter":["M14 2c-.55 0-1 .45-1 1v3c0 1.66-1.34 3-3 3H4.41L5.7 7.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L4.41 11H10c2.76 0 5-2.24 5-5V3c0-.55-.45-1-1-1z"],"key-escape":["M2 7c.55 0 1-.45 1-1V4.41L7.29 8.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L4.41 3H6c.55 0 1-.45 1-1s-.45-1-1-1H2c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1zm7-5.9v2A5 5 0 113.1 9h-2c.49 3.39 3.38 6 6.9 6 3.87 0 7-3.13 7-7 0-3.52-2.61-6.41-6-6.9z"],"key-option":["M11 4h4c.55 0 1-.45 1-1s-.45-1-1-1h-4c-.55 0-1 .45-1 1s.45 1 1 1zm4 8h-3.43L5.86 2.49h-.02A.975.975 0 005 2H1c-.55 0-1 .45-1 1s.45 1 1 1h3.43l5.71 9.51.01-.01c.18.3.49.5.85.5h4c.55 0 1-.45 1-1s-.45-1-1-1z"],"key-shift":["M13.71 7.29l-5-5C8.53 2.11 8.28 2 8 2s-.53.11-.71.29l-5 5A1.003 1.003 0 003 9h2v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V9h2a1.003 1.003 0 00.71-1.71z"],"key-tab":["M15 10H4.41L5.7 8.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L2 9.59V8c0-.55-.45-1-1-1s-1 .45-1 1v6c0 .55.45 1 1 1s1-.45 1-1v-1.59l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L4.41 12H15c.55 0 1-.45 1-1s-.45-1-1-1zm0-9c-.55 0-1 .45-1 1v1.59L11.71 1.3A.965.965 0 0011 1a1.003 1.003 0 00-.71 1.71L11.59 4H1c-.55 0-1 .45-1 1s.45 1 1 1h10.59L10.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L14 6.41V8c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],"known-vehicle":["M15 3a.997.997 0 00-.707.293L12 5.586l-1.293-1.293a1 1 0 10-1.414 1.414l2 2a.997.997 0 001.414 0l3-3A1 1 0 0015 3zm-.879 6.121l-.007-.007c-.313.309-.69.552-1.114.702V10h-.998H12h-1v-.184c-.424-.15-.8-.395-1.112-.704l-.01.01-2-2 .012-.012A2.978 2.978 0 017.184 6H3c-.176 0-.06-.824 0-1l.73-1.63C3.79 3.192 3.823 3 4 3H7.78C8.328 2.39 9.115 2 10 2c.768 0 1.461.293 1.987.77l.844-.844c-.238-.244-.524-.442-.794-.524C12.037 1.402 10.72 1 8 1c-2.72 0-4.037.402-4.037.402-.508.155-1.078.711-1.268 1.237l-.763 2.117H.88c-.484 0-.88.423-.88.939s.396.939.88.939h.375L1 7c-.034.685 0 1.436 0 2v5c0 .657.384 1 1 1s1-.343 1-1v-1h10v1c0 .657.384 1 1 1s1-.343 1-1V9l-.003-.754-.876.875zM5.001 10H3V8h2v2z"],"lab-test":["M11 1a1 1 0 010 2v3l3 7v1.25a.75.75 0 01-.75.75H2.75a.75.75 0 01-.75-.75V13l3-7V3a1 1 0 110-2h6zM9 3H7v3l-1.714 4h5.428L9 6V3z"],label:["M11 2H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V7l-5-5zm3 10H2V4h8v2H3v1h7v1h4v4zm-3-5V4l3 3h-3zm-8 3h10V9H3v1z"],layer:["M16 8c0-.37-.21-.68-.51-.85l.01-.01-7-4-.01.01C8.34 3.06 8.18 3 8 3s-.34.06-.49.15l-.01-.02-7 4 .01.01C.21 7.32 0 7.63 0 8s.21.68.51.85l-.01.01 7 4 .01-.01c.15.09.31.15.49.15s.34-.06.49-.15l.01.01 7-4-.01-.01c.3-.17.51-.48.51-.85z"],"layer-outline":["M7.504 3.132l-7 4a1 1 0 000 1.736l7 4a1 1 0 00.992 0l7-4a1 1 0 000-1.736l-7-4a1 1 0 00-.992 0zM8 5.152L12.983 8 8 10.847 3.016 8 8 5.152z"],layers:["M.55 4.89l7 3.5c.14.07.29.11.45.11s.31-.04.45-.11l7-3.5a.998.998 0 00-.06-1.81L8.4.08a1.006 1.006 0 00-.79 0l-6.99 3a.992.992 0 00-.07 1.81zM15 10c-.16 0-.31.04-.45.11L8 13.38 1.45 10.1c-.14-.06-.29-.1-.45-.1-.55 0-1 .45-1 1 0 .39.23.73.55.89l7 3.5c.14.07.29.11.45.11s.31-.04.45-.11l7-3.5c.32-.16.55-.5.55-.89 0-.55-.45-1-1-1zm0-3.5c-.16 0-.31.04-.45.11L8 9.88 1.45 6.61A.997.997 0 001 6.5c-.55 0-1 .45-1 1 0 .39.23.73.55.89l7 3.5c.14.07.29.11.45.11s.31-.04.45-.11l7-3.5c.32-.16.55-.5.55-.89 0-.55-.45-1-1-1z"],layout:["M14 4c-1.1 0-2 .9-2 2 0 .47.17.9.44 1.24l-.68.91A1.996 1.996 0 009.07 9.5H7.93C7.71 8.64 6.93 8 6 8c-.47 0-.9.17-1.24.44l-.91-.68c.1-.23.15-.49.15-.76 0-.37-.11-.71-.28-1.01l2.27-2.27c.3.17.64.28 1.01.28 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .37.11.71.28 1.01L3.01 5.28C2.71 5.11 2.37 5 2 5 .9 5 0 5.9 0 7s.9 2 2 2c.47 0 .9-.17 1.24-.44l.91.68c-.1.23-.15.49-.15.76 0 .37.11.71.28 1.01l-1.27 1.27C2.71 12.11 2.37 12 2 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2c0-.37-.11-.71-.28-1.01l1.27-1.27c.3.17.64.28 1.01.28.93 0 1.71-.64 1.93-1.5h1.14c.22.86 1 1.5 1.93 1.5 1.1 0 2-.9 2-2 0-.47-.17-.9-.44-1.24l.68-.91c.23.1.49.15.76.15 1.1 0 2-.9 2-2s-.9-2-2-2z"],"layout-auto":["M14 9.5c-.56 0-1.06.23-1.42.59L8.99 8l3.59-2.09A2.002 2.002 0 0016 4.5c0-1.1-.9-2-2-2s-2 .9-2 2c0 .19.03.37.08.54L8.5 7.13v-3.2c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S6 .9 6 2c0 .93.64 1.71 1.5 1.93v3.2L3.92 5.04c.05-.17.08-.35.08-.54 0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.56 0 1.06-.23 1.42-.59L7.01 8l-3.59 2.09A2.002 2.002 0 000 11.5c0 1.1.9 2 2 2s2-.9 2-2c0-.19-.03-.37-.08-.54L7.5 8.87v3.2c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93v-3.2l3.58 2.09c-.05.17-.08.35-.08.54 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2z"],"layout-balloon":["M14 11c-.2 0-.38.04-.56.09L12.42 9.4c.36-.36.58-.85.58-1.4 0-.55-.22-1.04-.58-1.4l1.01-1.69c.19.05.37.09.57.09 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .55.22 1.04.58 1.4l-1.01 1.69C11.38 6.04 11.2 6 11 6c-.93 0-1.71.64-1.93 1.5H6.93C6.71 6.64 5.93 6 5 6c-.2 0-.38.04-.56.09L3.42 4.4C3.78 4.04 4 3.55 4 3c0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.2 0 .38-.04.56-.09L3.58 6.6C3.22 6.96 3 7.45 3 8c0 .55.22 1.04.58 1.4l-1.01 1.69C2.38 11.04 2.2 11 2 11c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2c0-.55-.22-1.04-.58-1.4l1.01-1.69c.19.05.37.09.57.09.93 0 1.71-.64 1.93-1.5h2.14c.22.86 1 1.5 1.93 1.5.2 0 .38-.04.56-.09l1.01 1.69c-.35.36-.57.85-.57 1.4 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2z"],"layout-circle":["M14.16 6.02c-.12-.36-.26-.7-.43-1.03.17-.29.27-.63.27-.99 0-1.1-.9-2-2-2-.36 0-.7.1-.99.27-.33-.17-.67-.31-1.03-.43A1.987 1.987 0 008 0C6.95 0 6.1.81 6.02 1.84c-.36.12-.7.26-1.03.43C4.7 2.1 4.36 2 4 2c-1.1 0-2 .9-2 2 0 .36.1.7.27.99-.17.33-.31.67-.43 1.03C.81 6.1 0 6.95 0 8c0 1.05.81 1.9 1.84 1.98.12.36.26.7.43 1.03-.17.29-.27.63-.27.99 0 1.1.9 2 2 2 .36 0 .7-.1.99-.27.33.17.67.32 1.03.43C6.1 15.19 6.95 16 8 16c1.05 0 1.9-.81 1.98-1.84.36-.12.7-.26 1.03-.43.29.17.63.27.99.27 1.1 0 2-.9 2-2 0-.36-.1-.7-.27-.99.17-.33.31-.67.43-1.03C15.19 9.9 16 9.05 16 8c0-1.05-.81-1.9-1.84-1.98zm-.99 3.79c-.05.16-.11.31-.17.46-.3-.17-.64-.27-1-.27-1.1 0-2 .9-2 2 0 .36.1.7.27 1-.15.07-.3.12-.46.17C9.5 12.48 8.81 12 8 12s-1.5.48-1.81 1.17c-.16-.06-.32-.11-.46-.17.17-.3.27-.64.27-1 0-1.1-.9-2-2-2-.36 0-.7.1-1 .27-.07-.15-.12-.3-.17-.46C3.52 9.5 4 8.81 4 8s-.48-1.5-1.17-1.81c.06-.16.11-.32.17-.46.3.17.64.27 1 .27 1.1 0 2-.9 2-2 0-.36-.1-.7-.27-1 .15-.07.3-.12.46-.17C6.5 3.52 7.19 4 8 4s1.5-.48 1.81-1.17c.16.06.32.11.46.17-.17.3-.27.64-.27 1 0 1.1.9 2 2 2 .36 0 .7-.1 1-.27.07.15.12.3.17.46C12.48 6.5 12 7.19 12 8s.48 1.5 1.17 1.81z"],"layout-grid":["M2 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-6C.9 6 0 6.9 0 8s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-6C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12 4c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm0 2c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM8 0C6.9 0 6 .9 6 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM8 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],"layout-group-by":["M2 6C.9 6 0 6.9 0 8s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 5c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12-7c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM2 1C.9 1 0 1.9 0 3s.9 2 2 2 2-.9 2-2-.9-2-2-2zm7 8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm5 3c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],"layout-hierarchy":["M14.5 12.07V9.93c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2-.93 0-1.71.64-1.93 1.5H9.93c-.18-.7-.73-1.25-1.43-1.43V3.93c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S6 .9 6 2c0 .93.64 1.71 1.5 1.93v2.14c-.7.18-1.25.73-1.43 1.43H3.93C3.71 6.64 2.93 6 2 6 .9 6 0 6.9 0 8c0 .93.64 1.71 1.5 1.93v2.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93V9.93c.7-.18 1.25-.73 1.43-1.43h2.14c.18.7.73 1.25 1.43 1.43v2.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93V9.93c.7-.18 1.25-.73 1.43-1.43h2.14c.18.7.73 1.25 1.43 1.43v2.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93z"],"layout-linear":["M14 6c-.93 0-1.71.64-1.93 1.5H9.93C9.71 6.64 8.93 6 8 6s-1.71.64-1.93 1.5H3.93C3.71 6.64 2.93 6 2 6 .9 6 0 6.9 0 8s.9 2 2 2c.93 0 1.71-.64 1.93-1.5h2.13C6.29 9.36 7.07 10 8 10s1.71-.64 1.93-1.5h2.13c.22.86 1 1.5 1.93 1.5 1.1 0 2-.9 2-2C16 6.9 15.1 6 14 6z"],"layout-skew-grid":["M2 6C.9 6 0 6.9 0 8s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12-2c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM2 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6 9c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6-3c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM8 3c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6 9c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],"layout-sorted-clusters":["M2 6C.9 6 0 6.9 0 8s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM8 9c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],learning:["M8.441 1.104a.985.985 0 00-.882 0L.365 5c-.487.253-.487.747 0 1L7.56 9.896a.985.985 0 00.882 0L15.635 6c.487-.253.487-.747 0-1L8.44 1.104z","M14 5.5l.016 4.514c.002.548.447.99.994.99a.99.99 0 00.99-.99V5.5h-2zM3.371 9.047l4.387 2.432a.5.5 0 00.485 0l4.39-2.432a.25.25 0 01.371.218v2.955a.25.25 0 01-.134.222l-4.635 2.436a.5.5 0 01-.466 0l-4.635-2.436A.25.25 0 013 12.22V9.265a.25.25 0 01.371-.218z"],"left-join":["M6.6 3.3C6.1 3.1 5.6 3 5 3 2.2 3 0 5.2 0 8s2.2 5 5 5c.6 0 1.1-.1 1.6-.3C5.3 11.6 4.5 9.9 4.5 8s.8-3.6 2.1-4.7zM8 4c-1.2.9-2 2.4-2 4s.8 3.1 2 4c1.2-.9 2-2.3 2-4s-.8-3.1-2-4zm3-1c2.8 0 5 2.2 5 5s-2.2 5-5 5c-.6 0-1.1-.1-1.6-.3 1.3-1.1 2.1-2.9 2.1-4.7s-.8-3.5-2.1-4.7c.5-.2 1-.3 1.6-.3zm.35 1.02c.73 1.15 1.14 2.52 1.14 3.98s-.42 2.83-1.14 3.98c2.04-.18 3.64-1.9 3.64-3.98s-1.6-3.8-3.64-3.98z"],"less-than":["M13.287 5.958a1 1 0 00-.574-1.916l-10 3c-.95.285-.95 1.631 0 1.916l10 3a1 1 0 00.574-1.916L6.48 8l6.807-2.042z"],"less-than-or-equal-to":["M13.287 3.958a1 1 0 00-.575-1.916l-10 3c-.95.285-.95 1.63 0 1.916l10 3a1 1 0 00.575-1.916L6.48 6l6.807-2.042zM13 12H3a1 1 0 000 2h10a1 1 0 000-2z"],lifesaver:["M9.405 11.746C8.968 11.91 8.495 12 8 12c-.494 0-.968-.09-1.405-.254l-.702 1.873C6.548 13.865 7.258 14 8 14c.742 0 1.452-.135 2.107-.38l-.702-1.874zm2.341-2.341l1.873.702C13.865 9.452 14 8.742 14 8c0-.742-.135-1.452-.38-2.107l-1.874.702c.164.437.254.91.254 1.405 0 .494-.09.968-.254 1.405zM9.405 4.254l.702-1.873A5.987 5.987 0 008 2c-.742 0-1.452.135-2.107.38l.702 1.874C7.032 4.09 7.505 4 8 4c.494 0 .968.09 1.405.254zM4.254 6.595L2.38 5.893A5.987 5.987 0 002 8c0 .742.135 1.452.38 2.107l1.874-.702A3.991 3.991 0 014 8c0-.494.09-.968.254-1.405zM8 16A8 8 0 118 0a8 8 0 010 16zm0-6a2 2 0 100-4 2 2 0 000 4z"],lightbulb:["M9.01 14h-2c-.55 0-1 .45-1 1s.45 1 1 1h2c.55 0 1-.45 1-1s-.44-1-1-1zm1-3h-4c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1s-.44-1-1-1zm-2-11C5.26 0 3.03 1.95 3.03 4.35c0 2.37 1.63 2.64 1.94 5.22 0 .24.22.44.5.44h5.09c.28 0 .5-.19.5-.44C11.37 6.99 13 6.72 13 4.35 13 1.95 10.77 0 8.01 0z"],lightning:["M7 9H5a1 1 0 01-1-1L4.89.876A1 1 0 015.884 0h4.27a.847.847 0 01.793 1.144L9.125 6h2.05a.825.825 0 01.754 1.16L8.16 15.64A.606.606 0 017 15.394V9z"],link:["M4.99 11.99c.28 0 .53-.11.71-.29l6-6a1.003 1.003 0 00-1.42-1.42l-6 6a1.003 1.003 0 00.71 1.71zm3.85-2.02L6.4 12.41l-1 1-.01-.01c-.36.36-.85.6-1.4.6-1.1 0-2-.9-2-2 0-.55.24-1.04.6-1.4l-.01-.01 1-1 2.44-2.44c-.33-.1-.67-.16-1.03-.16-1.1 0-2.09.46-2.81 1.19l-.02-.02-1 1 .02.02c-.73.72-1.19 1.71-1.19 2.81 0 2.21 1.79 4 4 4 1.1 0 2.09-.46 2.81-1.19l.02.02 1-1-.02-.02c.73-.72 1.19-1.71 1.19-2.81 0-.35-.06-.69-.15-1.02zm7.15-5.98c0-2.21-1.79-4-4-4-1.1 0-2.09.46-2.81 1.19l-.02-.02-1 1 .02.02c-.72.72-1.19 1.71-1.19 2.81 0 .36.06.69.15 1.02l2.44-2.44 1-1 .01.01c.36-.36.85-.6 1.4-.6 1.1 0 2 .9 2 2 0 .55-.24 1.04-.6 1.4l.01.01-1 1-2.43 2.45c.33.09.67.15 1.02.15 1.1 0 2.09-.46 2.81-1.19l.02.02 1-1-.02-.02a3.92 3.92 0 001.19-2.81z"],list:["M1 3h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 10H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"list-columns":["M6 1c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1h5zm9-12c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1h5zm0 4c.55 0 1 .45 1 1s-.45 1-1 1h-5c-.55 0-1-.45-1-1s.45-1 1-1h5z"],"list-detail-view":["M6 9H1c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm0 4H1c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm9-12h-5c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM6 5H1c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H1c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1z"],locate:["M15 7h-.09A6.98 6.98 0 009 1.1V1c0-.55-.45-1-1-1S7 .45 7 1v.09A6.98 6.98 0 001.1 7H1c-.55 0-1 .45-1 1s.45 1 1 1h.1A6.969 6.969 0 007 14.91V15c0 .55.45 1 1 1s1-.45 1-1v-.09A6.98 6.98 0 0014.9 9h.1c.55 0 1-.45 1-1s-.45-1-1-1zm-6.02 5.9c-.05-.5-.46-.9-.98-.9s-.93.4-.98.9A5.017 5.017 0 013.1 8.98c.5-.05.9-.46.9-.98s-.4-.93-.9-.98A5.017 5.017 0 017.02 3.1c.05.5.46.9.98.9s.93-.4.98-.9c1.97.39 3.52 1.95 3.92 3.92-.5.05-.9.46-.9.98s.4.93.9.98a5.017 5.017 0 01-3.92 3.92zM8 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],lock:["M13.96 7H12V3.95C12 1.77 10.21 0 8 0S4 1.77 4 3.95V7H1.96c-.55 0-.96.35-.96.9v6.91c0 .54.41 1.19.96 1.19h12c.55 0 1.04-.65 1.04-1.19V7.9c0-.55-.49-.9-1.04-.9zM6 7V3.95c0-1.09.9-1.97 2-1.97s2 .88 2 1.97V7H6z"],"log-in":["M11 8c0-.28-.11-.53-.29-.71l-3-3a1.003 1.003 0 00-1.42 1.42L7.59 7H1c-.55 0-1 .45-1 1s.45 1 1 1h6.59L6.3 10.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71zm4-8H9c-.55 0-1 .45-1 1s.45 1 1 1h5v12H9c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"log-out":["M7 14H2V2h5c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1zm8.71-6.71l-3-3a1.003 1.003 0 00-1.42 1.42L12.59 7H6c-.55 0-1 .45-1 1s.45 1 1 1h6.59l-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],manual:["M15.99 1.13c-.02-.41-.33-.77-.78-.87C12.26-.36 9.84.13 8 1.7 6.16.13 3.74-.36.78.26.33.35.03.72.01 1.13H0v12c0 .08 0 .17.02.26.12.51.65.82 1.19.71 2.63-.55 4.59-.04 6.01 1.57.02.03.06.04.08.06.02.02.03.04.05.06.04.03.09.04.13.07.05.03.09.05.14.07.11.04.23.07.35.07h.04c.12 0 .24-.03.35-.07.05-.02.09-.05.14-.07.04-.02.09-.04.13-.07.02-.02.03-.04.05-.06.03-.02.06-.03.08-.06 1.42-1.6 3.39-2.12 6.01-1.57.54.11 1.07-.21 1.19-.71.04-.09.04-.18.04-.26l-.01-12zM7 12.99c-1.4-.83-3.07-1.14-5-.93V1.96c2.11-.28 3.75.2 5 1.46v9.57zm7-.92c-1.93-.21-3.6.1-5 .93V3.42c1.25-1.26 2.89-1.74 5-1.46v10.11z"],"manually-entered-data":["M1 8h3.76l2-2H1c-.55 0-1 .45-1 1s.45 1 1 1zm14.49-4.01c.31-.32.51-.76.51-1.24C16 1.78 15.22 1 14.25 1c-.48 0-.92.2-1.24.51l-1.44 1.44 2.47 2.47 1.45-1.43zM1 4h7.76l2-2H1c-.55 0-1 .45-1 1s.45 1 1 1zm0 6c-.55 0-1 .45-1 1 0 .48.35.86.8.96L2.76 10H1zm9.95-6.43l-6.69 6.69 2.47 2.47 6.69-6.69-2.47-2.47zm4.25 2.47L13.24 8H15c.55 0 1-.45 1-1 0-.48-.35-.86-.8-.96zM2 15l3.86-1.39-2.46-2.44L2 15zm13-5h-3.76l-2 2H15c.55 0 1-.45 1-1s-.45-1-1-1z"],"many-to-many":["M3 3a1 1 0 100 2 1 1 0 000-2zm3 1c0 .047-.001.094-.003.14.255.081.538.209.832.41.406.28.8.676 1.171 1.225.37-.549.765-.945 1.171-1.224a3.14 3.14 0 01.832-.411 3 3 0 11.77 1.87 1.038 1.038 0 00-.47.19c-.291.2-.752.672-1.227 1.8.475 1.128.936 1.6 1.227 1.8.183.126.336.173.47.19a3 3 0 11-.77 1.87 3.141 3.141 0 01-.832-.41c-.406-.28-.8-.676-1.171-1.225-.37.549-.765.945-1.171 1.224-.294.202-.577.33-.832.411a3 3 0 11-.77-1.87c.134-.017.287-.064.47-.19.291-.2.752-.672 1.227-1.8-.475-1.128-.936-1.6-1.227-1.8a1.038 1.038 0 00-.47-.19A3 3 0 116 4zm6 0a1 1 0 112 0 1 1 0 01-2 0zm-9 7a1 1 0 100 2 1 1 0 000-2zm9 1a1 1 0 112 0 1 1 0 01-2 0z"],"many-to-one":["M3 2a1 1 0 100 2 1 1 0 000-2zm0-2c1.385 0 2.551.94 2.896 2.215.168.044.34.096.51.158 1.076.394 2.237 1.242 2.575 2.93.161.809.664 1.211 1.293 1.443a3 3 0 110 2.508c-.629.232-1.132.634-1.293 1.442-.338 1.69-1.499 2.537-2.575 2.93a5.436 5.436 0 01-.51.159A3.001 3.001 0 010 13a3 3 0 015.726-1.254c.629-.232 1.132-.634 1.293-1.442.216-1.076.765-1.81 1.413-2.304-.648-.493-1.197-1.228-1.413-2.304-.161-.808-.664-1.21-1.293-1.442A3 3 0 113 0zm1 13a1 1 0 10-2 0 1 1 0 002 0zm8-5a1 1 0 102 0 1 1 0 00-2 0z"],map:["M15.55 3.17l-4.49-3A.975.975 0 009.99.15L5.53 2.82 1.56.17A1.003 1.003 0 000 1v11c0 .35.18.65.45.83l4.49 3a.975.975 0 001.07.02l4.46-2.67 3.97 2.65A1.003 1.003 0 0016 15V4c0-.35-.18-.65-.45-.83zM5 13.46l-3-2v-8.6l2.94 1.96c.02.02.04.03.06.04v8.6zm5-2.32s-.01 0-.01.01L6 13.53V4.86s.01 0 .01-.01L10 2.47v8.67zm4 1.99l-2.94-1.96c-.02-.01-.04-.02-.05-.03v-8.6l3 2v8.59z"],"map-create":["M14 6.82v6.32l-2.94-1.96c-.02-.01-.04-.02-.05-.03V6.22c-.08-.07-.15-.16-.22-.24-.28-.02-.54-.08-.79-.16v5.32s-.01 0-.01.01L6 13.53V4.86s.01 0 .01-.01l2.05-1.23C8.02 3.42 8 3.21 8 3c0-.98.47-1.84 1.2-2.39l-3.67 2.2L1.56.17A1.003 1.003 0 000 1v11c0 .35.18.65.45.83l4.49 3a.975.975 0 001.07.02l4.46-2.67 3.97 2.65A1.003 1.003 0 0016 15V5.82c-.25.09-.52.14-.8.16-.33.36-.73.67-1.2.84zm-9 6.64l-3-2v-8.6l2.94 1.96c.02.02.04.03.06.04v8.6zM11 4h1v1c0 .55.45 1 1 1s1-.45 1-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1z"],"map-marker":["M8.46 0C5.42 0 2.95 2.39 2.95 5.33 2.95 8.28 8.46 16 8.46 16s5.51-7.72 5.51-10.67C13.96 2.39 11.5 0 8.46 0zm0 8a2.5 2.5 0 010-5 2.5 2.5 0 010 5z"],maximize:["M5.99 8.99c-.28 0-.53.11-.71.29l-3.29 3.29v-1.59c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.41L6.7 10.7a1.003 1.003 0 00-.71-1.71zm9-9h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59l-3.3 3.3a.99.99 0 00-.29.7 1.003 1.003 0 001.71.71l3.29-3.29V5c0 .55.45 1 1 1s1-.45 1-1V1c0-.56-.45-1.01-1-1.01z"],media:["M11.99 6.99c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zm3-5h-14c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-10c0-.55-.45-1-1-1zm-1 9l-5-3-1 2-3-4-3 5v-7h12v7z"],menu:["M1 4h14c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 8H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm0-5H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"menu-closed":["M14.99 6.99h-9c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zm-12-2c-.28 0-.53.11-.71.29l-2 2a1.014 1.014 0 000 1.42l2 2a1.003 1.003 0 001.71-.71v-4c0-.55-.45-1-1-1zm3-1h9c.55 0 1-.45 1-1s-.45-1-1-1h-9c-.55 0-1 .45-1 1s.45 1 1 1zm9 8h-9c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1z"],"menu-open":["M9.99 11.99h-9c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zm0-5h-9c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zm0-5h-9c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zm5.71 5.3l-2-2a1.003 1.003 0 00-1.71.71v4a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71s-.11-.53-.29-.71z"],"merge-columns":["M5.71 5.29a1.003 1.003 0 00-1.42 1.42l.3.29H2V2h3v1.51c.52.06.99.29 1.34.65l.66.66V1c0-.55-.45-1-1-1H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-3.82l-.66.66c-.35.35-.82.59-1.34.65V14H2V9h2.59l-.3.29a1.003 1.003 0 001.42 1.42l2-2C7.89 8.53 8 8.28 8 8c0-.28-.11-.53-.29-.71l-2-2zM15 0h-5c-.55 0-1 .45-1 1v3.82l.66-.66c.35-.35.82-.59 1.34-.65V2h3v5h-2.59l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C8.11 7.47 8 7.72 8 8c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H14v5h-3v-1.51c-.52-.06-.99-.29-1.34-.65L9 11.18V15c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"merge-links":["M8 7c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0 4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm0-8c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm6 3c-.93 0-1.71.64-1.93 1.5H11V3c0-1.66-1.34-3-3-3S5 1.34 5 3v4.5H3.93C3.71 6.64 2.93 6 2 6 .9 6 0 6.9 0 8s.9 2 2 2c.93 0 1.71-.64 1.93-1.5H5V13c0 1.66 1.34 3 3 3s3-1.34 3-3V8.5h1.07c.22.86 1 1.5 1.93 1.5 1.1 0 2-.9 2-2s-.9-2-2-2zm-4 7c0 1.1-.9 2-2 2s-2-.9-2-2V3c0-1.1.9-2 2-2s2 .9 2 2v10z"],minimize:["M15.99.99a1.003 1.003 0 00-1.71-.71l-3.29 3.29V1.99c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H12.4l3.3-3.29c.18-.18.29-.43.29-.71zm-10 8h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59L.29 14.28a1.003 1.003 0 001.42 1.42L5 12.41V14c0 .55.45 1 1 1s1-.45 1-1v-4a1.02 1.02 0 00-1.01-1.01z"],minus:["M13 7H3c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1z"],"mobile-phone":["M12 0H4c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h8c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM8 15c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm3-3H5V3h6v9z"],"mobile-video":["M15 4c-.28 0-.53.11-.71.29L12 6.59V4c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V9.41l2.29 2.29c.18.19.43.3.71.3.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],modal:["M15 1a1 1 0 011 1v12a1 1 0 01-1 1H1a1 1 0 01-1-1V2a1 1 0 011-1h14zm-1 4H2v8h12V5zm-3-3H9v2h2V2zm3 0h-2v2h2V2z"],"modal-filled":["M15 1H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm1 4H0V3h16v2zm-3-2h-2V1h2v2z"],moon:["M15 11.38A7.835 7.835 0 017.85 16C3.51 16 0 12.49 0 8.15 0 4.97 1.89 2.23 4.62 1c-.45.99-.7 2.08-.7 3.23a7.85 7.85 0 007.85 7.85c1.15 0 2.24-.25 3.23-.7z"],more:["M2 6.03a2 2 0 100 4 2 2 0 100-4zM14 6.03a2 2 0 100 4 2 2 0 100-4zM8 6.03a2 2 0 100 4 2 2 0 100-4z"],mountain:["M16 13H3l6-9h1l2 2h1l3 7zm-2.5-3.5l-1-2.5h-1l-2-2-3 4.5L9 8l1 1 1-1 2.5 1.5zM5.94 7l-4.122 6H0l5-6h.94z"],move:["M15.71 7.29l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H9V3.41l.29.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-2-2C8.53.11 8.28 0 8 0s-.53.11-.71.29l-2 2a1.003 1.003 0 001.42 1.42l.29-.3V7H3.41l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L3.41 9H7v3.59l-.29-.29A.965.965 0 006 12a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2a1.003 1.003 0 00-1.42-1.42l-.29.3V9h3.59l-.29.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],mugshot:["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14h-.15c-.03-.09-.04-.16-.08-.25-.34-.79-2.01-1.31-3.12-1.8-1.11-.49-.96-.79-1-1.2-.01-.06-.01-.12-.01-.18.38-.34.69-.8.89-1.33 0 0 .01-.03.01-.04.04-.12.08-.24.11-.36.25-.05.4-.33.46-.59.06-.1.18-.36.15-.65-.04-.37-.19-.55-.35-.62v-.06c0-.48-.04-1.16-.13-1.61-.02-.12-.05-.25-.08-.37-.16-.55-.51-1.05-.96-1.39C9.26 3.19 8.6 3 8 3c-.59 0-1.26.19-1.73.55-.45.35-.8.84-.96 1.39-.04.13-.06.25-.08.38-.09.45-.13 1.13-.13 1.61v.06c-.18.06-.33.24-.37.62-.03.29.09.54.15.65.06.26.21.54.47.59.03.12.07.25.11.36 0 .01.01.02.01.02v.01c.21.54.53 1.01.92 1.35 0 .05-.01.11-.01.16-.04.41.08.7-1.03 1.2-1.11.49-2.77 1.01-3.12 1.8-.04.09-.05.16-.08.25H2V2h12v12z"],"multi-select":["M12 3.98H4c-.55 0-1 .45-1 1v1h8v5h1c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1zm3-3H7c-.55 0-1 .45-1 1v1h8v5h1c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1zm-6 6H1c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1h8c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1zm-1 5H2v-3h6v3z"],music:["M15 0c-.07 0-.13.03-.19.04V.02l-10 2v.02C4.35 2.13 4 2.52 4 3v9.12c-.31-.07-.65-.12-1-.12-1.66 0-3 .9-3 2s1.34 2 3 2 3-.9 3-2V6.32l8-1.6v5.4c-.31-.07-.65-.12-1-.12-1.66 0-3 .9-3 2s1.34 2 3 2 3-.9 3-2V1c0-.55-.45-1-1-1z"],nest:["M2 2c.55 0 1 .45 1 1v3c0 1.66 1.34 3 3 3h5.59L10.3 7.71A.965.965 0 0110 7a1.003 1.003 0 011.71-.71l3 3c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-3 3a1.003 1.003 0 01-1.42-1.42l1.3-1.29H6c-2.76 0-5-2.24-5-5V3c0-.55.45-1 1-1z"],"new-drawing":["M14.9 11c.6 0 1 .5 1 1 0 .257-.073.44-.22.614l-.08.086-3 3c-.2.2-.4.3-.7.3-.5 0-1-.4-1-1 0-.257.073-.44.22-.614l.08-.086 3-3c.2-.2.4-.3.7-.3zM1.3.1l6.734 2.45a3.005 3.005 0 002.095 3.322 3.005 3.005 0 003.401 2.081L13.9 9.8v.2c0 .257-.073.44-.22.614l-.08.086-3 3c-.171.171-.343.27-.577.294L9.9 14h-.2l-5-1-.1-.01c-.231-.05-.45-.26-.56-.49L4 12.4l-4-11 .3-.3 5.8 5.8c-.1.2-.2.4-.2.6 0 .8.6 1.5 1.5 1.5s1.5-.7 1.5-1.5S8.2 6 7.4 6c-.16 0-.32.064-.48.14l-.12.06L1 .4l.3-.3zM13 0c.55 0 1 .45 1 1v1h1c.55 0 1 .45 1 1s-.45 1-1 1h-1v1c0 .503-.376.922-.861.99l-.013.002A.999.999 0 0113 6l.097-.006-.027.004a1 1 0 01-.037.001L13 6c-.55 0-1-.45-1-1V4h-1a.993.993 0 01-.855-.482A1 1 0 0110 3c0-.55.45-1 1-1h1V1c0-.55.45-1 1-1z"],"new-grid-item":["M6 0H1C.45 0 0 .45 0 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm5 14c0-.55-.45-1-1-1s-1 .45-1 1v1c0 .55.45 1 1 1h1c.55 0 1-.45 1-1s-.45-1-1-1zM6 9H1c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1zm9 4c-.55 0-1 .45-1 1-.55 0-1 .45-1 1s.45 1 1 1h1c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm-4-4h-1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1s1-.45 1-1c.55 0 1-.45 1-1s-.45-1-1-1zm4-9h-5c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm0 9h-1c-.55 0-1 .45-1 1s.45 1 1 1c0 .55.45 1 1 1s1-.45 1-1v-1c0-.55-.45-1-1-1z"],"new-layer":["M13.982 6.272l1.518.868-.01.01c.3.17.51.48.51.85s-.21.68-.51.85l.01.01-7 4-.01-.01A.94.94 0 018 13a.94.94 0 01-.49-.15l-.01.01-7-4 .01-.01A.977.977 0 010 8c0-.37.21-.68.51-.86L.5 7.13l7-4 .01.02A.94.94 0 018 3c.086 0 .168.014.246.038a2 2 0 105.736 3.234zM14 3c.55 0 1 .45 1 1s-.45 1-1 1h-1v1c0 .55-.45 1-1 1s-1-.45-1-1V5h-1c-.55 0-1-.45-1-1s.45-1 1-1h1V2c0-.55.45-1 1-1s1 .45 1 1v1h1z"],"new-layers":["M13 3h2a1 1 0 010 2h-2v2a1 1 0 01-2 0V5H9a1 1 0 110-2h2V1a1 1 0 012 0v2zm-3-1.983V2H9a2 2 0 100 4h1v1c0 .279.057.544.16.785l-1.71.855c-.14.07-.29.11-.45.11-.16 0-.31-.04-.45-.11l-7-3.5a.992.992 0 01.07-1.81l6.99-3a1.006 1.006 0 01.79 0l1.6.687zm.91 7.66a2 2 0 003.085-1.54l.555-.277c.14-.07.29-.11.45-.11.55 0 1 .45 1 1 0 .39-.23.73-.55.89l-7 3.5c-.14.07-.29.11-.45.11-.16 0-.31-.04-.45-.11l-7-3.5C.23 8.48 0 8.14 0 7.75c0-.55.45-1 1-1 .16 0 .31.04.45.11L8 10.13l2.91-1.453zM15 10.25c.55 0 1 .45 1 1 0 .39-.23.73-.55.89l-7 3.5c-.14.07-.29.11-.45.11-.16 0-.31-.04-.45-.11l-7-3.5c-.32-.16-.55-.5-.55-.89 0-.55.45-1 1-1 .16 0 .31.04.45.1L8 13.63l6.55-3.27c.14-.07.29-.11.45-.11z"],"new-link":["M15 3h-1V2c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V5h1c.55 0 1-.45 1-1s-.45-1-1-1zm-3.5 6a2.5 2.5 0 00-2.45 2h-4.1a2.5 2.5 0 100 1h4.1a2.5 2.5 0 102.45-3z"],"new-object":["M8 4c0 .6.4 1 1 1h2v2c0 .6.4 1 1 1s1-.4 1-1V5h2c.6 0 1-.4 1-1s-.4-1-1-1h-2V1c0-.6-.4-1-1-1s-1 .4-1 1v2H9c-.6 0-1 .5-1 1zm6.5 2.5V7c0 1.4-1.1 2.5-2.5 2.5S9.5 8.4 9.5 7v-.5H9C7.6 6.5 6.5 5.4 6.5 4S7.6 1.5 9 1.5h.5V1c0-.3.1-.6.1-.8C9.1.1 8.6 0 8 0 3.6 0 0 3.6 0 8s3.6 8 8 8 8-3.6 8-8c0-.6-.1-1.3-.2-1.9-.4.3-.8.4-1.3.4z"],"new-person":["M9.12 12.69c-1.17-.53-1.01-.85-1.05-1.29-.01-.06-.01-.12-.01-.19.4-.37.73-.87.94-1.44 0 0 .01-.03.01-.04.05-.14.09-.27.12-.4.27-.06.43-.36.49-.63.06-.11.19-.39.16-.7-.04-.41-.2-.6-.38-.68v-.07c0-.51-.05-1.25-.14-1.74-.02-.13-.05-.27-.09-.4-.17-.6-.53-1.14-1.01-1.52C7.66 3.2 6.96 3 6.33 3c-.62 0-1.33.2-1.82.59-.49.38-.85.92-1.02 1.52-.04.13-.07.26-.09.4-.09.49-.13 1.23-.13 1.74v.06c-.19.08-.35.27-.39.68-.03.31.1.59.16.7.06.28.22.59.5.64.03.14.07.27.11.4 0 .01.01.02.01.02v.01c.22.59.55 1.1.96 1.46 0 .06-.01.12-.01.17-.04.44.08.76-1.09 1.29-1.17.53-2.93 1.1-3.29 1.95-.35.87-.2 1.37-.2 1.37h12.6s.15-.5-.22-1.36c-.36-.85-2.12-1.42-3.29-1.95zM14.89 2h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1z"],"new-prescription":["M9.82 11.66l2.48-2.87c.12-.2.13-.37.04-.53-.11-.19-.3-.26-.52-.26h-1.29c-.27 0-.49.13-.63.34L8.44 9.9 6.95 8a.482.482 0 00-.08-.1L5.82 6.55c.57-.24 1.04-.57 1.42-1.01.49-.57.74-1.27.74-2.08 0-.51-.1-.99-.32-1.42-.21-.43-.51-.8-.89-1.11A4.1 4.1 0 005.42.24C4.91.08 4.34 0 3.72 0H.61C.26 0 0 .23 0 .56v9.89c0 .33.26.55.61.55h.8c.36 0 .61-.23.61-.56V6.99H3.3l3.73 4.74-2.71 3.48c-.12.2-.13.37-.04.53.11.19.3.26.52.26h1.27c.27 0 .51-.12.64-.34l1.69-2.15 1.66 2.14c.12.21.34.35.62.35h1.43c.2 0 .39-.08.5-.25.12-.18.09-.38-.02-.55l-2.77-3.54zM4.18 5H1.99V2.02h2.19c.62 0 1.08.13 1.38.37.29.22.44.62.44 1.08 0 .45-.15.94-.44 1.17-.31.23-.76.36-1.38.36zM15 2h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1zM9.99 3.01c0 .02.01.04.01.06V2.95c0 .02-.01.04-.01.06z"],"new-text-box":["M5 6.5c0 .28.22.5.5.5H7v3.5c0 .28.22.5.5.5s.5-.22.5-.5V7h1.5c.28 0 .5-.22.5-.5S9.78 6 9.5 6h-4c-.28 0-.5.22-.5.5zM15 2h-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V4h1c.55 0 1-.45 1-1s-.45-1-1-1zm-2 5c-.55 0-1 .45-1 1v5H3V4h5c.55 0 1-.45 1-1s-.45-1-1-1H2c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h11c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1z"],ninja:["M16 5s-2.52 2.11-4.96 1.99C11.03 4.89 10.39.23 5 0c0 0 2.11 2.54 1.96 4.99C4.86 5.01.23 5.65 0 11c0 0 2.56-2.12 5.02-1.95.02 2.11.67 6.72 5.98 6.95 0 0-2.09-2.54-1.94-4.99 2.11-.02 6.71-.68 6.94-6.01zM8 9.5c-.83 0-1.5-.67-1.5-1.5S7.17 6.5 8 6.5s1.5.67 1.5 1.5S8.83 9.5 8 9.5z"],"not-equal-to":["M7.58 5l.44-2.196a1 1 0 011.96.392L9.62 5H13a1 1 0 010 2H9.22l-.4 2H13a1 1 0 010 2H8.42l-.44 2.196a1 1 0 01-1.96-.392L6.38 11H3a1 1 0 010-2h3.78l.4-2H3a1 1 0 110-2h4.58z"],notifications:["M8 16c1.1 0 2-.9 2-2H6c0 1.1.9 2 2 2zm6-5c-.55 0-1-.45-1-1V6c0-2.43-1.73-4.45-4.02-4.9 0-.04.02-.06.02-.1 0-.55-.45-1-1-1S7 .45 7 1c0 .04.02.06.02.1A4.992 4.992 0 003 6v4c0 .55-.45 1-1 1s-1 .45-1 1 .45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1z"],"notifications-snooze":["M9 14c0 1.1-.9 2-2 2s-2-.9-2-2zM7 0c.404 0 .755.243.912.59L7.9.6c-.7.6-.9 1.36-.9 1.9 0 .8.267 1.433.8 1.9-.533.6-.795 1.222-.784 1.867l.004.358A2.8 2.8 0 009.82 9.4L12 9.399V10c0 .51.388.935.884.993L13 11c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1 1-.45 1-1V6c0-2.43 1.73-4.45 4.02-4.9L6 1c0-.55.45-1 1-1z","M13 6.702a.632.632 0 00-.632-.632h-1.743l2.208-2.734A.75.75 0 0013 2.864v-.3A.565.565 0 0012.435 2H9.561a.561.561 0 100 1.123h1.814L9.221 5.795A1 1 0 009 6.423v.279c0 .349.283.631.632.631h2.736A.632.632 0 0013 6.702z"],"notifications-updated":["M8 16c1.1 0 2-.9 2-2H6c0 1.1.9 2 2 2zm3.399-13.667l-.413.412A2.99 2.99 0 009 1.99a3 3 0 00-3 2.99c0 .8.32 1.558.876 2.114l2.002 1.992A2.99 2.99 0 0013 9.184V10c0 .55.45 1 1 1s1 .45 1 1-.45 1-1 1H2c-.55 0-1-.45-1-1s.45-1 1-1 1-.45 1-1V6c0-2.43 1.73-4.45 4.02-4.9 0-.04-.02-.06-.02-.1 0-.55.45-1 1-1s1 .45 1 1c0 .04-.02.06-.02.1a4.97 4.97 0 012.419 1.233zM10.29 7.67l-2-1.99a.99.99 0 01-.29-.7 1 1 0 011-.99c.27 0 .52.11.7.29l1.29 1.29 3.28-3.28c.18-.18.42-.29.7-.29.55 0 1 .44 1 .99 0 .28-.11.52-.3.7l-3.98 3.98a.99.99 0 01-1.4 0z"],"numbered-list":["M2.76 7h1.26V0h-.94c-.04.21-.12.39-.25.54-.13.15-.29.27-.48.36-.18.09-.39.16-.62.2-.23.04-.46.06-.71.06v.9h1.74V7zm-.59 7.17c.18-.12.37-.25.58-.37a10.763 10.763 0 001.24-.83c.2-.16.37-.33.52-.51.15-.19.28-.39.37-.61.09-.22.14-.47.14-.74 0-.22-.04-.45-.12-.7-.08-.26-.21-.49-.4-.69-.18-.21-.43-.39-.72-.52-.3-.14-.68-.21-1.12-.21-.41 0-.77.07-1.08.2-.32.14-.58.32-.8.56-.22.23-.38.51-.49.84-.11.32-.16.67-.16 1.05h1.19c.01-.24.03-.47.08-.67.05-.21.11-.39.21-.54.09-.15.22-.27.38-.36.16-.09.35-.13.59-.13.26 0 .47.04.63.12.16.08.29.18.38.3.09.12.15.25.18.39s.05.27.05.4c-.01.27-.08.5-.22.71-.14.21-.32.4-.53.57-.22.18-.45.34-.71.49-.26.15-.51.31-.74.47-.5.31-.89.68-1.17 1.11-.3.41-.44.91-.45 1.48h5v-1H1.43c.05-.15.14-.29.27-.43.14-.13.29-.26.47-.38zM15.01 1.99h-7c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-1c0-.55-.44-1-1-1zm0 9h-7c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-1c0-.55-.44-1-1-1z"],numerical:["M2.79 4.61c-.13.17-.29.3-.48.41-.18.11-.39.18-.62.23-.23.04-.46.07-.71.07v1.03h1.74V12h1.26V4h-.94c-.04.23-.12.44-.25.61zm4.37 5.31c.18-.14.37-.28.58-.42l.63-.45c.21-.16.41-.33.61-.51s.37-.38.52-.59c.15-.21.28-.45.37-.7.09-.25.13-.54.13-.85 0-.25-.04-.52-.12-.8-.07-.29-.2-.55-.39-.79a2.18 2.18 0 00-.73-.6c-.29-.15-.66-.23-1.11-.23-.41 0-.77.08-1.08.23-.31.16-.58.37-.79.64-.22.27-.38.59-.49.96-.11.37-.16.77-.16 1.2h1.19c.01-.27.03-.53.08-.77.04-.24.11-.45.21-.62.09-.18.22-.32.38-.42.16-.1.35-.15.59-.15.26 0 .47.05.63.14.15.09.28.21.37.35.09.14.15.29.18.45.03.16.05.31.05.45-.01.31-.08.58-.22.82-.14.23-.32.45-.53.65-.22.21-.46.39-.71.57-.26.18-.51.36-.75.54-.5.36-.89.78-1.17 1.27-.28.49-.43 1.06-.44 1.71h5v-1.15H6.43c.05-.17.14-.33.27-.49.13-.15.29-.29.46-.44zm8.5-1.56c-.23-.35-.54-.57-.95-.65v-.02c.34-.13.6-.34.76-.63.16-.29.24-.63.24-1.02 0-.34-.06-.64-.19-.9s-.3-.47-.51-.64c-.21-.17-.45-.3-.72-.38-.27-.09-.54-.13-.82-.13-.36 0-.68.07-.96.2-.28.13-.53.32-.72.55-.2.23-.36.51-.47.83-.11.32-.18.66-.19 1.04h1.15c-.01-.2.01-.39.06-.58.05-.19.12-.36.22-.51.1-.15.22-.27.37-.36.15-.09.32-.13.53-.13.32 0 .59.1.79.3.21.2.31.46.31.79 0 .23-.05.43-.14.59-.09.16-.21.29-.35.38-.15.09-.32.16-.51.19-.19.04-.38.05-.57.04v.93c.23-.01.45 0 .67.02.22.02.42.08.59.17.18.09.32.23.43.4.11.18.16.41.16.71 0 .44-.13.78-.39 1.02s-.58.36-.97.36c-.45 0-.79-.16-1.02-.47-.23-.31-.33-.7-.32-1.17H11c.01.4.06.77.17 1.1.11.33.26.61.47.85.21.23.46.42.77.54.31.13.67.19 1.08.19.34 0 .66-.05.96-.16.3-.11.57-.27.8-.47.23-.2.41-.45.55-.74.13-.27.2-.6.2-.97 0-.5-.11-.92-.34-1.27z"],office:["M15 5h-3V1c0-.55-.45-1-1-1H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h3v-4h4v4h7c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zM5 10H2V7h3v3zm0-5H2V2h3v3zm5 5H7V7h3v3zm0-5H7V2h3v3zm4 9h-2v-2h2v2zm0-4h-2V7h2v3z"],offline:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zM6 14l1-5H4l6-7-1 5h3l-6 7z"],"oil-field":["M15 14h-1.35l-3.34-7.51 2.46-.95 1.45 3.21c.09.2.36.3.6.23.1-.03.18-.08.24-.15.05-.08 1.23-1.56.87-4.2-.11-.79-.52-4.62-3.26-4.62-.93 0-1.68.62-1.67 1.37 0 .14.03.28.09.42l.87 1.92L.64 8.07v.01A.98.98 0 000 9c0 .55.45 1 1 1 .13 0 .25-.03.36-.07v.01l1.04-.4L3.67 14H2c-.55 0-1 .45-1 1s.45 1 1 1h13c.55 0 1-.45 1-1s-.45-1-1-1zM4.27 8.81L7.14 7.7 5.2 12.08l-.93-3.27zM6.54 14L9 8.46 11.46 14H6.54z"],"one-column":["M11.99-.01h-3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h3c.55 0 1-.45 1-1v-14c0-.55-.45-1-1-1zm-6 5c-.28 0-.53.11-.71.29l-2 2a1.014 1.014 0 000 1.42l2 2a1.003 1.003 0 001.71-.71v-4c0-.55-.45-1-1-1z"],"one-to-many":["M14 3a1 1 0 11-2 0 1 1 0 012 0zm-3.726 1.254a3 3 0 10-.17-2.039 5.467 5.467 0 00-.51.158c-1.076.394-2.237 1.242-2.575 2.93-.161.809-.664 1.211-1.293 1.443a3 3 0 100 2.508c.629.232 1.132.634 1.293 1.442.338 1.69 1.499 2.537 2.575 2.93.17.063.342.115.51.159a3.001 3.001 0 10.17-2.04c-.629-.231-1.132-.633-1.293-1.441C8.765 9.228 8.216 8.494 7.568 8c.648-.493 1.197-1.228 1.413-2.304.161-.808.664-1.21 1.293-1.442zM13 14a1 1 0 110-2 1 1 0 010 2zM4 8a1 1 0 10-2 0 1 1 0 002 0z"],"one-to-one":["M2 8a1 1 0 112 0 1 1 0 01-2 0zm3.83-1a3.001 3.001 0 100 2h4.34a3.001 3.001 0 100-2H5.83zM13 7a1 1 0 100 2 1 1 0 000-2z"],outdated:["M8 0c4.42 0 8 3.58 8 8 0 4.06-3.02 7.4-6.94 7.92-.02 0-.04.01-.06.01-.33.04-.66.07-1 .07-4.42 0-8-3.58-8-8 0-.55.45-1 1-1s1 .45 1 1c0 3.31 2.69 6 6 6 .71 0 1.37-.15 2-.38v.01c2.33-.82 4-3.02 4-5.63 0-3.31-2.69-6-6-6-1.78 0-3.36.78-4.46 2H5c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V1c0-.55.45-1 1-1s1 .45 1 1v1.74A7.95 7.95 0 018 0zm1 12H7v-2h2v2zm0-3H7V4h2v5z"],"page-layout":["M15 .95H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-12c0-.55-.45-1-1-1zm-9 12H2v-6h4v6zm8 0H7v-6h7v6zm0-7H2v-3h12v3z"],"panel-stats":["M10 4h3v1h-3zM10 6h3v1h-3zM10 8h3v1h-3zM10 10h3v1h-3z","M15 1H1c-.6 0-1 .4-1 1v11c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V2c0-.6-.4-1-1-1zM8 12H2V3h6v9zm6 0H9V3h5v9z"],"panel-table":["M15 1H1c-.6 0-1 .4-1 1v11c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V2c0-.6-.4-1-1-1zM8 9H6V7h2v2zm0-3H6V4h2v2zm-6 6V3h3v9H2zm4 0v-2h2v2H6zm8 0H9v-2h5v2zm0-3H9V7h5v2zm0-3H9V4h5v2z"],paperclip:["M14.68 2.31A4.54 4.54 0 0011.46.99c-1.15 0-2.31.44-3.19 1.32L.95 9.63c-.63.63-.95 1.46-.95 2.28a3.21 3.21 0 003.23 3.22c.83 0 1.66-.31 2.3-.95l7.31-7.32c.76-.77.76-1.98.01-2.73s-1.99-.76-2.75 0l-6.07 6.08c-.24.25-.24.65.01.9s.65.25.91.01l6.07-6.08c.25-.25.67-.25.91-.01.25.25.25.67 0 .92l-7.31 7.32c-.75.75-2.04.74-2.76.01-.75-.75-.73-2.02.01-2.76L9.2 3.21c1.24-1.24 3.35-1.26 4.58-.03 1.24 1.24 1.24 3.36 0 4.6l-7.12 7.13c-.24.25-.24.64.01.88.24.24.63.24.88.01v.01l7.13-7.13A4.41 4.41 0 0016 5.51c0-1.16-.44-2.32-1.32-3.2z"],paragraph:["M13 1H6C3.8 1 2 2.8 2 5s1.8 4 4 4v5c0 .6.4 1 1 1s1-.5 1-1V3h2v11c0 .6.4 1 1 1s1-.5 1-1V3h1c.5 0 1-.4 1-1s-.4-1-1-1z"],path:["M14.5 0h-13C.67 0 0 .67 0 1.5S.67 3 1.5 3H7v3H3.5C2.67 6 2 6.67 2 7.5S2.67 9 3.5 9H7v3H5.5c-.83 0-1.5.67-1.5 1.5S4.67 15 5.5 15h5c.83 0 1.5-.67 1.5-1.5s-.67-1.5-1.5-1.5H9V9h3.5c.83 0 1.5-.67 1.5-1.5S13.33 6 12.5 6H9V3h5.5c.83 0 1.5-.67 1.5-1.5S15.33 0 14.5 0z"],"path-search":["M15 14.62l-4-2.4V9.77c-.32.09-.66.15-1 .18v2.27l-4 2.4V8.71c-.38-.31-.72-.66-1-1.06v6.97l-4-2.4V8c.55 0 1-.45 1-1s-.45-1-1-1V1.38l3.15 1.89c.08-.34.18-.66.32-.97L.76.07v.01A.496.496 0 00.5 0C.22 0 0 .22 0 .5v12c0 .18.1.33.25.42v.01l5 3v-.01c.07.05.16.08.25.08s.18-.03.25-.08v.01l4.74-2.85 4.74 2.85v-.01c.09.05.18.08.27.08.28 0 .5-.22.5-.5v-3.78c-.3.17-.63.28-1 .28v2.62zM2 5c0 .55.45 1 1 1s1-.45 1-1-.45-1-1-1-1 .45-1 1zm6-1c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm7.75-.92l-1.19-.72c.18.43.29.9.36 1.38l.08.04v3.39l1 1V3.5c0-.18-.1-.33-.25-.42zM10 2c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm3.3 4.89c.44-.7.7-1.51.7-2.39C14 2.01 11.99 0 9.5 0S5 2.01 5 4.5 7.01 9 9.5 9c.88 0 1.69-.26 2.39-.7l2.41 2.41c.17.18.42.29.7.29a1.003 1.003 0 00.71-1.71l-2.41-2.4zM9.5 8C7.57 8 6 6.43 6 4.5S7.57 1 9.5 1 13 2.57 13 4.5 11.43 8 9.5 8z"],pause:["M6 3H4c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zm6 0h-2c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],people:["M13.69 13.98c-.05-.24-.14-.5-.25-.76-.36-.86-1.12-1.33-2.69-2-.14-.06-.59-.25-.6-.25-.21-.09-.36-.15-.5-.22.02-.1.02-.2.03-.31 0-.04.01-.08.01-.13-.07-.06-.13-.12-.19-.19.22-.32.4-.67.54-1.05.02-.06.02-.06.03-.1.29-.23.48-.57.59-.96.16-.33.25-.73.21-1.16-.03-.4-.16-.76-.37-1.03-.02-.53-.07-1.13-.15-1.54-.01-.06-.02-.12-.03-.19.23-.06.48-.09.72-.09.49 0 1.05.16 1.44.46.38.29.67.7.8 1.17.03.1.05.21.07.31.07.37.11.94.11 1.33v.05c.14.06.27.21.29.51.02.25-.07.45-.13.54-.05.21-.16.44-.38.48-.02.1-.05.2-.09.3 0 .01-.01.03-.01.03-.17.44-.43.83-.75 1.11v.14c.03.35-.09.59.83 1 .93.41 2.32.84 2.6 1.5.29.66.17 1.04.17 1.04h-2.3zm-1.17-.38c.37.86.22 1.36.22 1.36H.06s-.14-.5.22-1.36 2.13-1.43 3.31-1.96c1.17-.54 1.05-.86 1.09-1.3 0-.05.01-.11.01-.17-.41-.35-.75-.86-.97-1.45v-.01s-.01-.01-.01-.02c-.04-.12-.09-.26-.12-.39-.28-.05-.44-.36-.5-.64-.06-.12-.19-.39-.16-.71.04-.41.21-.6.39-.68v-.06c0-.51.05-1.26.14-1.74.02-.13.05-.27.09-.4.17-.6.54-1.13 1.02-1.51.5-.39 1.21-.6 1.84-.6s1.34.21 1.84.6c.48.38.85.91 1.02 1.52.04.13.07.27.09.4.09.48.14 1.22.14 1.73v.07c.18.08.34.27.37.67.03.32-.09.59-.16.71-.06.28-.21.58-.48.63-.03.13-.07.26-.12.39 0 .01-.01.04-.01.04-.22.58-.55 1.08-.95 1.45v.18c.04.45-.12.77 1.06 1.3 1.18.53 2.95 1.09 3.31 1.95z"],percentage:["M6 6V4c0-1.1-.9-2-2-2H3c-1.1 0-2 .9-2 2v2c0 1.1.9 2 2 2h1c1.1 0 2-.9 2-2zM3.5 6c-.28 0-.5-.22-.5-.5v-1c0-.28.22-.5.5-.5s.5.22.5.5v1c0 .28-.22.5-.5.5zM13 8h-1c-1.1 0-2 .9-2 2v2c0 1.1.9 2 2 2h1c1.1 0 2-.9 2-2v-2c0-1.1-.9-2-2-2zm0 3.5c0 .28-.22.5-.5.5s-.5-.22-.5-.5v-1c0-.28.22-.5.5-.5s.5.22.5.5v1zM12 3a1.003 1.003 0 00-1.87-.5l-5.99 9.98c-.09.15-.14.33-.14.52a1.003 1.003 0 001.87.5l5.99-9.98c.09-.15.14-.33.14-.52z"],person:["M15.68 14.32c-.46-1.05-2.68-1.75-4.16-2.4-1.48-.65-1.28-1.05-1.33-1.59-.01-.07-.01-.15-.01-.23.51-.45.92-1.07 1.19-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.34-.07.54-.44.61-.78.08-.14.23-.48.2-.87-.05-.5-.25-.73-.47-.82v-.09c0-.63-.06-1.55-.17-2.15A3.671 3.671 0 0010.32.72C9.68.25 8.79-.01 8-.01c-.79 0-1.68.25-2.31.73-.61.47-1.06 1.13-1.28 1.86-.05.17-.09.33-.11.5-.12.6-.17 1.51-.17 2.15v.08c-.24.09-.45.32-.5.83-.03.38.13.72.2.86.08.35.28.72.63.78.04.17.09.33.15.49 0 .01.01.02.01.03l.01.01c.27.72.7 1.35 1.22 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.37 1.59-1.48.65-3.7 1.35-4.16 2.4-.46 1.05-.27 1.67-.27 1.67h15.92c-.01.01.18-.61-.28-1.66z"],phone:["M15.9 12.41c-.06-.06-3.37-2-3.48-2.05a.794.794 0 00-.32-.08c-.15 0-.34.11-.57.32-.23.22-.94 1.19-1.15 1.4-.21.22-.38.32-.52.32-.07 0-.15-.02-.25-.06-.1-.04-1.16-.58-3.36-2.52-2.2-1.93-2.49-3.2-2.5-3.55 0-.14.11-.31.32-.52.22-.21.45-.41.7-.6.25-.19.49-.4.7-.62.22-.23.32-.42.32-.57 0-.11-.03-.21-.08-.32C5.66 3.46 3.66.15 3.59.08 3.44-.07 2.85 0 2.55.16.16 1.46-.03 3.2 0 3.89c.04.71.49 4.46 4.16 7.95C8.72 16.17 11.89 16 12.1 16c.69 0 2.82-.38 3.72-2.55.13-.32.25-.87.08-1.04z"],"pie-chart":["M7 1.08c-3.37.5-5.97 3.4-5.97 6.92 0 3.87 3.13 7 6.98 7 3.52 0 6.42-2.61 6.91-6H7V1.08z","M8 0v8h8c0-4.42-3.58-8-8-8z"],pin:["M9.41.92c-.51.51-.41 1.5.15 2.56L4.34 7.54C2.8 6.48 1.45 6.05.92 6.58l3.54 3.54-3.54 4.95 4.95-3.54 3.54 3.54c.53-.53.1-1.88-.96-3.42l4.06-5.22c1.06.56 2.04.66 2.55.15L9.41.92z"],pivot:["M4.57 7.02L.3 11.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4.27-4.27c-.58-.35-1.07-.84-1.41-1.42zM15 8c-.55 0-1 .45-1 1v.59l-2.57-2.57c-.34.58-.83 1.07-1.41 1.41L12.59 11H12c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm-4-3c0-1.66-1.34-3-3-3S5 3.34 5 5s1.34 3 3 3 3-1.34 3-3zM8 6c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"pivot-table":["M2 4H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm0-4H1C.45 0 0 .45 0 1v1c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm11.71 4.29C13.53 4.11 13.28 4 13 4s-.53.11-.71.29l-2 2a1.003 1.003 0 001.42 1.42l.29-.3V9c0 1.66-1.34 3-3 3H7.41l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H9c2.76 0 5-2.24 5-5V7.41l.29.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-2-2zM15 0H5c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],play:["M12 8c0-.35-.19-.64-.46-.82l.01-.02-6-4-.01.02A.969.969 0 005 3c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1 .21 0 .39-.08.54-.18l.01.02 6-4-.01-.02c.27-.18.46-.47.46-.82z"],plus:["M13 7H9V3c0-.55-.45-1-1-1s-1 .45-1 1v4H3c-.55 0-1 .45-1 1s.45 1 1 1h4v4c0 .55.45 1 1 1s1-.45 1-1V9h4c.55 0 1-.45 1-1s-.45-1-1-1z"],"polygon-filter":["M14 5c-.24 0-.47.05-.68.13L9.97 2.34c.01-.11.03-.22.03-.34 0-1.1-.9-2-2-2S6 .9 6 2c0 .04.01.08.01.12L2.88 4.21C2.61 4.08 2.32 4 2 4 .9 4 0 4.9 0 6c0 .74.4 1.38 1 1.72v4.55c-.6.35-1 .99-1 1.73 0 1.1.9 2 2 2 .74 0 1.38-.4 1.72-1h4.55c.35.6.98 1 1.72 1 1.1 0 2-.9 2-2 0-.37-.11-.7-.28-1L14 9c1.11-.01 2-.9 2-2s-.9-2-2-2zm-4.01 7c-.73 0-1.37.41-1.71 1H3.73c-.18-.3-.43-.55-.73-.72V7.72c.6-.34 1-.98 1-1.72 0-.04-.01-.08-.01-.12l3.13-2.09c.27.13.56.21.88.21.24 0 .47-.05.68-.13l3.35 2.79c-.01.11-.03.22-.03.34 0 .37.11.7.28 1l-2.29 4z"],power:["M8 8c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1S7 .45 7 1v6c0 .55.45 1 1 1zm3-5.32v2.34c1.21.91 2 2.35 2 3.98 0 2.76-2.24 5-5 5s-5-2.24-5-5c0-1.63.79-3.06 2-3.98V2.68C2.64 3.81 1 6.21 1 9c0 3.87 3.13 7 7 7s7-3.13 7-7c0-2.79-1.64-5.19-4-6.32z"],"predictive-analysis":["M16 6.41c0-1.01-.49-1.94-1.29-2.49-.43-1.92-2.07-3.28-4-3.28-.46 0-.92.08-1.35.24C8.83.31 8.11 0 7.34 0c-.9 0-1.74.44-2.28 1.16-.12-.01-.24-.02-.36-.02-1.31 0-2.42.89-2.77 2.17C.78 3.72 0 4.84 0 6.13c0 .38.07.76.21 1.12C.07 7.6 0 7.98 0 8.36c0 1.11.58 2.11 1.51 2.63.54.56 1.27.87 2.03.87.49 0 .95-.12 1.37-.36a2.85 2.85 0 002.18 1.04c.52 0 1.03-.14 1.47-.42.49.39 1.07.65 1.69.73 1.04 1.15 1.84 2.63 1.84 2.64 0 0 .28.49.26.49.77 0 1.41-.16 1.32-1.04 0 .02-.73-2.31-.73-2.31.41-.21.75-.55.97-.98.9-.52 1.47-1.53 1.47-2.61 0-.24-.03-.48-.08-.71.45-.52.7-1.21.7-1.92zm-1.23 1.02l-.15-.16-.61-.67c-.27-.29-.54-.94-.58-1.39l-.1-1.01c-.05-.59-.94-.58-.91.11 0 .02.1 1.01.1 1.01.03.29.12.62.24.93-.06-.01-.12-.02-.18-.02 0 0-2.06-.1-2.05-.11-.58-.02-.71.97-.04 1l2.05.11c.42.02 1.04.3 1.29.58l.49.54.02.05c.08.21.12.44.12.66 0 .74-.41 1.41-1.07 1.75l-.16.08-.07.18c-.15.38-.48.66-.88.74l-.54.11.7 2.2c-.38-.61-.95-1.43-1.62-2.14l-.12-.13-.17-.01c-.41-.03-.8-.17-1.14-.38l1.36-1.18c.35-.31.83-.44.99-.39 0 0 .63.17.62.18.63.16.83-.74.23-.97l-.62-.18c-.55-.16-1.33.18-1.79.58l-1.53 1.33-.31.26c-.35.29-.75.44-1.2.44-.64 0-1.23-.33-1.58-.86V9.15c0-.4.17-.79.27-.85 0 0 .52-.34.51-.35.71-.53.18-1.23-.49-.89 0-.01-.52.35-.52.35-.26.15-.45.44-.58.77-.11-.11-.22-.2-.34-.28 0 0-1.53-1.01-1.53-1.02-.65-.45-1.2.51-.49.89 0-.01 1.51 1.02 1.51 1.02.37.24.62.78.62 1.09v.67c-.34.19-.63.29-.99.29-.54 0-1.05-.23-1.41-.63l-.05-.06-.07-.04c-.65-.34-1.05-1-1.05-1.73 0-.3.07-.6.2-.87l.12-.25L1.15 7c-.13-.27-.2-.56-.2-.87 0-.9.61-1.68 1.48-1.89l.31-.08.05-.34a1.926 1.926 0 012.38-1.58l.32.08.18-.31c.35-.6.99-.97 1.67-.97.44 0 .86.15 1.2.42l-.36.36v-.01l-.25.26c-.33.27-.74.42-.89.4 0 0-.67-.1-.67-.11-.67-.13-.87.86-.14 1.02.01 0 .67.11.67.11.02 0 .05 0 .07.01-.11.37-.15.77-.1 1.12 0 0 .17.99.15.99.11.52 1.06.36.93-.18 0-.01-.15-.99-.15-.99-.05-.37.12-.94.36-1.19l.39-.4c.05-.05.1-.09.15-.14l.74-.76c.4-.18.83-.27 1.27-.27 1.55 0 2.86 1.12 3.11 2.67l.04.25.21.12c.61.35.98 1 .98 1.7 0 .36-.1.7-.28 1.01z"],prescription:["M10.91 8.34c.14-.21.36-.34.63-.34h1.29c.22 0 .41.07.52.26.09.16.08.33-.04.53l-2.49 2.87 2.77 3.54c.12.17.14.37.02.55-.11.17-.3.25-.5.25h-1.44a.69.69 0 01-.61-.35L9.4 13.51l-1.69 2.15c-.13.21-.36.34-.63.34H5.8c-.22 0-.41-.07-.52-.26-.09-.16-.08-.33.04-.53l2.71-3.48L4.3 6.99H3.03v3.47c0 .33-.26.56-.62.56h-.8c-.35-.01-.61-.23-.61-.56V.56c0-.33.26-.56.62-.56h3.11c.62 0 1.19.08 1.7.24.51.16.96.39 1.34.69a3.194 3.194 0 011.21 2.53c0 .81-.25 1.5-.74 2.08-.37.44-.84.77-1.42 1.01L7.88 7.9c.04.04.07.08.08.1l1.49 1.9 1.46-1.56zM5.18 5c.62 0 1.08-.13 1.39-.37.29-.23.44-.71.44-1.16s-.15-.87-.44-1.1C6.26 2.12 5.8 2 5.18 2H2.99v3h2.19z"],presentation:["M15 1H9c0-.55-.45-1-1-1S7 .45 7 1H1c-.55 0-1 .45-1 1s.45 1 1 1v8c0 .55.45 1 1 1h3.59L3.3 14.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L7 13.41V15c0 .55.45 1 1 1s1-.45 1-1v-1.59l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L10.41 12H14c.55 0 1-.45 1-1V3c.55 0 1-.45 1-1s-.45-1-1-1zm-2 9H3V3h10v7z"],print:["M12 2.02c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v1h8v-1zm3 2H1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h1v-3h12v3h1c.55 0 1-.45 1-1v-6c0-.56-.45-1-1-1zm-1 3h-2v-1h2v1zm-3 6H5v-3H3v4c0 .55.45 1 1 1h8c.55 0 1-.45 1-1v-4h-2v3z"],projects:["M14 3c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v1h12V3zm-2-3H4c-.55 0-1 .45-1 1h10c0-.55-.45-1-1-1zm3 5H1c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-3 6c0 .55-.45 1-1 1H5c-.55 0-1-.45-1-1V9h1v2h6V9h1v2z"],properties:["M2 6C.9 6 0 6.9 0 8s.9 2 2 2 2-.9 2-2-.9-2-2-2zm4-3h9c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1s.45 1 1 1zm-4 9c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm13-5H6c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zm0 6H6c-.55 0-1 .45-1 1s.45 1 1 1h9c.55 0 1-.45 1-1s-.45-1-1-1zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],property:["M3 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm-.5-6.5a2.5 2.5 0 000 5 2.5 2.5 0 000-5zM7 3h8c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1s.45 1 1 1zm8 10H7c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1zM3 0C1.9 0 1 .9 1 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12 6H7c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h8c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1z"],"publish-function":["M12.16 3.76c.15-.11.3-.16.47-.16.06 0 .17.02.34.06.16.04.31.06.43.06a.58.58 0 00.6-.6c0-.19-.06-.33-.17-.44-.11-.11-.28-.16-.49-.16-.19 0-.37.04-.54.13-.17.09-.39.27-.65.55-.2.21-.48.58-.87 1.11a5.22 5.22 0 00-.78-1.79l-2.05.32-.04.21c.15-.03.28-.04.39-.04.2 0 .37.08.5.25.21.26.5 1.03.88 2.33-.29.36-.49.6-.6.71-.18.19-.33.31-.45.36-.09.04-.19.07-.3.07-.09 0-.23-.04-.42-.13a.904.904 0 00-.36-.09c-.2 0-.36.06-.49.18a.59.59 0 00-.19.46c0 .18.06.32.18.43.12.11.28.16.48.16.2 0 .38-.04.55-.12.17-.08.39-.24.65-.49s.62-.65 1.07-1.19c.18.52.33.89.46 1.13.13.24.28.4.44.51.17.1.37.16.62.16.24 0 .49-.08.74-.25.33-.21.66-.58 1.01-1.09l-.21-.11c-.23.31-.41.5-.52.57a.44.44 0 01-.26.07c-.12 0-.24-.07-.36-.21-.2-.24-.46-.91-.8-2 .29-.49.54-.81.74-.96zM6.37 5.83l.68-2.53h.83l.2-.64h-.84c.24-.91.56-1.59.96-2.01.24-.27.48-.4.71-.4.05 0 .08.01.11.04s.04.06.04.1c0 .04-.03.11-.1.21-.06.1-.1.2-.1.29 0 .13.05.24.15.33.1.09.23.14.39.14.17 0 .31-.06.42-.17.12-.12.18-.27.18-.46 0-.21-.08-.39-.25-.52C9.57.07 9.3 0 8.93 0c-.59 0-1.12.16-1.59.48-.48.32-.93.85-1.36 1.59-.15.26-.29.42-.42.49s-.35.11-.64.1l-.19.65h.81L4.35 7.68c-.2.72-.33 1.16-.4 1.33-.1.24-.26.45-.46.62a.48.48 0 01-.31.1c-.03 0-.06-.01-.08-.03l-.03-.03c0-.02.03-.06.09-.11.06-.06.09-.15.09-.26 0-.13-.05-.23-.14-.32-.1-.09-.23-.13-.41-.13-.21 0-.38.05-.51.16A.52.52 0 002 9.4c0 .16.08.3.23.42.16.12.4.18.74.18.53 0 .99-.13 1.4-.39.41-.26.76-.65 1.07-1.19.3-.53.61-1.39.93-2.59zm2.34 3.46A.997.997 0 008 9c-.28 0-.53.11-.71.29l-2 2a1.003 1.003 0 001.42 1.42l.29-.3V15c0 .55.45 1 1 1s1-.45 1-1v-2.59l.29.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-2-2z"],pulse:["M15 8h-1.46l-1.7-2.55-.02.01A.984.984 0 0011 5c-.43 0-.79.27-.93.65h-.01l-1.69 4.51-1.38-8.32h-.02A.989.989 0 006 1c-.41 0-.77.25-.92.61L2.34 8H1c-.55 0-1 .45-1 1s.45 1 1 1h2c.41 0 .77-.25.92-.61l1.65-3.86 1.44 8.63h.02c.08.47.47.84.97.84.43 0 .79-.27.93-.65h.01l2.31-6.17.92 1.38.02-.01c.17.26.46.45.81.45h2c.55 0 1-.45 1-1s-.45-1-1-1z"],rain:["M3.5 8a2.5 2.5 0 11.608-4.926 4.002 4.002 0 017.381-1.03A3 3 0 1112 8H3.501zM3 10a1 1 0 012 0v4a1 1 0 11-2 0v-4zm7-1a1 1 0 00-1 1v5a1 1 0 102 0v-5a1 1 0 00-1-1zm2 1a1 1 0 112 0v2a1 1 0 11-2 0v-2zM7 9a1 1 0 00-1 1v2a1 1 0 102 0v-2a1 1 0 00-1-1z"],random:["M11.48 4h1.11l-.29.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H11c-.32 0-.59.16-.77.38l-.01-.01L8.28 4.8l1.28 1.6L11.48 4zm2.23 6.29a1.003 1.003 0 00-1.42 1.42l.3.29h-1.11l-7.7-9.62h-.01A.996.996 0 003 2H1c-.55 0-1 .45-1 1s.45 1 1 1h1.52l7.7 9.62.01-.01c.18.23.45.39.77.39h1.59l-.29.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2-2zM2.52 12H1c-.55 0-1 .45-1 1s.45 1 1 1h2c.32 0 .59-.16.77-.38l.01.01 1.94-2.42L4.44 9.6 2.52 12z"],record:["M8 3a5 5 0 100 10A5 5 0 108 3z"],redo:["M12 11c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm3.71-6.71l-3-3a1.003 1.003 0 00-1.42 1.42L12.59 4H5C2.24 4 0 6.24 0 9s2.24 5 5 5h4v-2H5c-1.66 0-3-1.34-3-3s1.34-3 3-3h7.59L11.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],refresh:["M14.99 6.99c-.55 0-1 .45-1 1 0 3.31-2.69 6-6 6-1.77 0-3.36-.78-4.46-2h1.46c.55 0 1-.45 1-1s-.45-1-1-1h-4c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1s1-.45 1-1v-1.74a7.95 7.95 0 006 2.74c4.42 0 8-3.58 8-8 0-.55-.45-1-1-1zm0-7c-.55 0-1 .45-1 1v1.74a7.95 7.95 0 00-6-2.74c-4.42 0-8 3.58-8 8 0 .55.45 1 1 1s1-.45 1-1c0-3.31 2.69-6 6-6 1.77 0 3.36.78 4.46 2h-1.46c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1z"],"regression-chart":["M13 6.5c0 .83.67 1.5 1.5 1.5S16 7.33 16 6.5 15.33 5 14.5 5 13 5.67 13 6.5zM8.5 5c.83 0 1.5-.67 1.5-1.5S9.33 2 8.5 2 7 2.67 7 3.5 7.67 5 8.5 5zM9 9.5c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5S11.33 8 10.5 8 9 8.67 9 9.5zM4.5 8C5.33 8 6 7.33 6 6.5S5.33 5 4.5 5 3 5.67 3 6.5 3.67 8 4.5 8zM15 12H3.26l12.03-8.59-.58-.81L2 11.67V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],remove:["M10.99 6.99h-6c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1zm-3-7c-4.42 0-8 3.58-8 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.68 6-6 6z"],"remove-column":["M14 0H4c-.55 0-1 .45-1 1v3h2V2h3v12H5v-2H3v3c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14h-3V2h3v12zm-8.71-3.29a1.003 1.003 0 001.42-1.42L4.41 8 5.7 6.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L3 6.59l-1.29-1.3A1.003 1.003 0 00.29 6.71L1.59 8 .29 9.29a1.003 1.003 0 001.42 1.42L3 9.41l1.29 1.3z"],"remove-column-left":["M4 9h4c.55 0 1-.45 1-1s-.45-1-1-1H4c-.55 0-1 .45-1 1s.45 1 1 1zm11-9H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-5 14H2V2h8v12zm4 0h-3V2h3v12z"],"remove-column-right":["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM5 14H2V2h3v12zm9 0H6V2h8v12zM8 9h4c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1z"],"remove-row-bottom":["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2V6h12v8zm0-9H2V2h12v3zm-8 6h4c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1s.45 1 1 1z"],"remove-row-top":["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2v-3h12v3zm0-4H2V2h12v8zM6 7h4c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1s.45 1 1 1z"],repeat:["M10 5c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1s-1 .45-1 1v1.74A7.95 7.95 0 008 0C3.58 0 0 3.58 0 8c0 4.06 3.02 7.4 6.94 7.92.02 0 .04.01.06.01.33.04.66.07 1 .07 4.42 0 8-3.58 8-8 0-.55-.45-1-1-1s-1 .45-1 1c0 3.31-2.69 6-6 6-.71 0-1.37-.15-2-.38v.01C3.67 12.81 2 10.61 2 8c0-3.31 2.69-6 6-6 1.77 0 3.36.78 4.46 2H11c-.55 0-1 .45-1 1z"],reset:["M6 5c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V1c0-.55.45-1 1-1s1 .45 1 1v1.74A7.95 7.95 0 018 0c4.42 0 8 3.58 8 8 0 4.06-3.02 7.4-6.94 7.92-.02 0-.04.01-.06.01-.33.04-.66.07-1 .07-4.42 0-8-3.58-8-8 0-.55.45-1 1-1s1 .45 1 1c0 3.31 2.69 6 6 6 .71 0 1.37-.15 2-.38v.01c2.33-.82 4-3.02 4-5.63 0-3.31-2.69-6-6-6-1.77 0-3.36.78-4.46 2H5c.55 0 1 .45 1 1z"],resolve:["M6.6 3.3C6.1 3.1 5.6 3 5 3 2.2 3 0 5.2 0 8s2.2 5 5 5c.6 0 1.1-.1 1.6-.3C5.3 11.6 4.5 9.9 4.5 8s.8-3.6 2.1-4.7zM8 4c-1.2.9-2 2.4-2 4s.8 3.1 2 4c1.2-.9 2-2.3 2-4s-.8-3.1-2-4zm3-1c-.6 0-1.1.1-1.6.3 1.3 1.2 2.1 2.9 2.1 4.7s-.8 3.6-2.1 4.7c.5.2 1 .3 1.6.3 2.8 0 5-2.2 5-5s-2.2-5-5-5z"],rig:["M5.71 3c0 1.1.96 2 2.14 2C9.04 5 10 3.96 10 3c0-1.96-1.47-3-2.14-3H5c0 1.96 2.68 1.4.71 3zm2.5 3l.01.01s0-.01-.01-.01zm6.5 8.29L10 9.59V7c0-.55-.45-1-1-1H7c-.55 0-1 .45-1 1v2.58l-4.71 4.7c-.18.19-.29.44-.29.72a1.003 1.003 0 001.71.71L6 12.42V15c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-2.58l3.29 3.29a1.003 1.003 0 001.42-1.42z"],"right-join":["M6.6 3.3C5.3 4.4 4.5 6.1 4.5 8s.8 3.6 2.1 4.7c-.5.2-1 .3-1.6.3-2.8 0-5-2.2-5-5s2.2-5 5-5c.6 0 1.1.1 1.6.3zm-1.96 8.68C3.92 10.83 3.5 9.46 3.5 8s.42-2.83 1.14-3.98C2.6 4.2 1 5.91 1 8s1.6 3.8 3.64 3.98zM8 4c-1.2.9-2 2.4-2 4s.8 3.1 2 4c1.2-.9 2-2.3 2-4s-.8-3.1-2-4zm3-1c2.8 0 5 2.2 5 5s-2.2 5-5 5c-.6 0-1.1-.1-1.6-.3 1.3-1.1 2.1-2.9 2.1-4.7s-.8-3.5-2.1-4.7c.5-.2 1-.3 1.6-.3z"],ring:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 12c-2.21 0-4-1.79-4-4s1.79-4 4-4 4 1.79 4 4-1.79 4-4 4z"],rocket:["M6 12C4.397 7.46 4.415 4.465 8 0c3.585 4.485 3.602 7.48 2 12H6zm3-7a1 1 0 11-2 0 1 1 0 012 0zm-7 8.022l3-1-.054-.158C4.636 10.954 4.076 9.317 4 8L3 9l-1 4.022zm9-1l3 1L13 9l-1-1c-.076 1.317-.635 2.954-.946 3.864l-.054.158zM7 13h2c0 1.5-.5 2.5-1 3-.5-.5-1-1.5-1-3z"],"rocket-slant":["M3.992 10c2-5 5-9 11-9 0 6-4 9-9 11l-2-2zm7.714-4.285a1 1 0 11-1.414-1.414 1 1 0 011.414 1.414zm-6.555-.218L2.992 6l-3 2L3.24 9.195c.542-1.301 1.166-2.556 1.911-3.698zM7.992 16l-1.236-3.232c1.3-.539 2.552-1.158 3.694-1.898L9.992 13l-2 3zm-4.931-4.94L5 13c-.992.991-2.186 1.154-3.001 1-.154-.815.07-1.948 1.06-2.94z"],"rotate-document":["M12 2h-1.59l.29-.29c.19-.18.3-.43.3-.71A1.003 1.003 0 009.29.29l-2 2C7.11 2.47 7 2.72 7 3c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H12c.55 0 1 .45 1 1v3c0 .55.45 1 1 1s1-.45 1-1V5c0-1.66-1.34-3-3-3zM5.71 5.29A.997.997 0 005 5H1c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V9c0-.28-.11-.53-.29-.71l-3-3zM7 14H2V7h2v2c0 .55.45 1 1 1h2v4z"],"rotate-page":["M8 6H2c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h6c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1zm-1 8H3V8h4v6zm5-12h-1.59l.29-.29c.19-.18.3-.43.3-.71A1.003 1.003 0 009.29.29l-2 2C7.11 2.47 7 2.72 7 3c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H12c.55 0 1 .45 1 1v3c0 .55.45 1 1 1s1-.45 1-1V5c0-1.66-1.34-3-3-3z"],route:["M11.669 5.066l.099.189c.113.213.236.434.367.661.226.39.468.78.709 1.151l-.198-.004-.48-.004c-1.745.003-2.369.233-2.369.688 0 .053.226.19 1.038.436l.84.24C13.9 9.064 15 9.83 15 11.63c0 2.123-1.607 3.122-4.027 3.366-.651.065-1.266.075-2.043.05l-.958-.035H5.196l.268-.406c.336-.517.672-1.052.998-1.593h1.636l.572.023c.857.036 1.475.034 2.103-.03 1.526-.153 2.227-.59 2.227-1.375 0-.531-.402-.84-1.66-1.22l-.691-.198c-1.04-.293-1.764-.562-2.222-.946C8.8 8.366 9 7.612 9 6.997a5.03 5.03 0 00-.184-1.334c.645-.395 1.598-.562 2.853-.597zM4 3a4.007 4.007 0 014 3.997C8 9.21 4 15 4 15l-.416-.62C2.56 12.827 0 8.767 0 6.997A4.002 4.002 0 014 3zm0 2a2 2 0 10.001 4.001A2 2 0 004 5zm10-4c1.103 0 1.996.896 2 1.999C16 4.105 14 7 14 7l-.293-.44C13.15 5.707 12 3.838 12 2.999 12 1.896 12.897 1 14 1z"],satellite:["M3 9c0-.6.4-1 1-1s1 .4 1 1c0 1.1.9 2 2 2 .6 0 1 .4 1 1s-.4 1-1 1c-2.2 0-4-1.8-4-4zM0 9c0-.6.4-1 1-1s1 .4 1 1c0 2.8 2.2 5 5 5 .6 0 1 .4 1 1s-.4 1-1 1c-3.9 0-7-3.1-7-7zm7 1c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1zm1.3-2.8c-.4-.4-.4-1 0-1.4l4.5-4.5c.4-.4 1-.4 1.4 0l.5.5c.4.4.4 1 0 1.4l-4.5 4.5c-.4.4-1 .4-1.4 0l-.5-.5zM5.2.3c.4-.4 1-.4 1.4 0l2.1 2.1c.4.4.4 1 0 1.4l-.9.9c-.4.4-1 .4-1.4 0L4.3 2.6c-.4-.4-.4-1 0-1.4l.9-.9zm7 7c.4-.4 1-.4 1.4 0l2.1 2.1c.4.4.4 1 0 1.4l-.9.9c-.4.4-1 .4-1.4 0l-2.1-2.1c-.4-.4-.4-1 0-1.4l.9-.9z"],saved:["M6.71 9.29a1.003 1.003 0 00-1.42 1.42l2 2a.997.997 0 001.6-.27h.01l2-4h-.01c.06-.13.11-.28.11-.44 0-.55-.45-1-1-1-.39 0-.72.23-.89.56H9.1l-1.38 2.76-1.01-1.03zM9 0H3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V5L9 0zm3 14H4V2h4v4h4v8z"],"scatter-plot":["M15 12H2V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm-.5-7c.83 0 1.5-.67 1.5-1.5S15.33 2 14.5 2 13 2.67 13 3.5 13.67 5 14.5 5zm-3 4c.83 0 1.5-.67 1.5-1.5S12.33 6 11.5 6 10 6.67 10 7.5 10.67 9 11.5 9zm-4-2C8.33 7 9 6.33 9 5.5S8.33 4 7.5 4 6 4.67 6 5.5 6.67 7 7.5 7zm-3 4c.83 0 1.5-.67 1.5-1.5S5.33 8 4.5 8 3 8.67 3 9.5 3.67 11 4.5 11z"],search:["M15.55 13.43l-2.67-2.68a6.94 6.94 0 001.11-3.76c0-3.87-3.13-7-7-7s-7 3.13-7 7 3.13 7 7 7c1.39 0 2.68-.42 3.76-1.11l2.68 2.67a1.498 1.498 0 102.12-2.12zm-8.56-1.44c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],"search-around":["M13.5 11c-.51 0-.98.15-1.38.42l-2.4-2.41c.17-.3.28-.64.28-1.01s-.11-.71-.28-1.01l2.41-2.41c.39.27.86.42 1.37.42a2.5 2.5 0 000-5A2.5 2.5 0 0011 2.5c0 .51.15.98.42 1.38l-2.41 2.4C8.71 6.11 8.37 6 8 6s-.71.11-1.01.28l-2.41-2.4c.27-.4.42-.87.42-1.38a2.5 2.5 0 00-5 0A2.5 2.5 0 002.5 5c.51 0 .98-.15 1.38-.42l2.41 2.41C6.11 7.29 6 7.63 6 8s.11.71.28 1.01l-2.41 2.41c-.39-.27-.86-.42-1.37-.42a2.5 2.5 0 000 5A2.5 2.5 0 005 13.5c0-.51-.15-.98-.42-1.38l2.41-2.41c.3.18.64.29 1.01.29s.71-.11 1.01-.28l2.41 2.41c-.27.39-.42.86-.42 1.37a2.5 2.5 0 005 0 2.5 2.5 0 00-2.5-2.5zm0-10c.83 0 1.5.67 1.5 1.5S14.33 4 13.5 4 12 3.33 12 2.5 12.67 1 13.5 1zm-11 3C1.67 4 1 3.33 1 2.5S1.67 1 2.5 1 4 1.67 4 2.5 3.33 4 2.5 4zm0 11c-.83 0-1.5-.67-1.5-1.5S1.67 12 2.5 12s1.5.67 1.5 1.5S3.33 15 2.5 15zm11 0c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"],"search-template":["M15.55 13.43l-2.67-2.67c.7-1.09 1.11-2.38 1.11-3.77 0-3.87-3.13-7-7-7s-7 3.13-7 7 3.13 7 7 7c1.39 0 2.68-.41 3.77-1.11l2.67 2.67a1.498 1.498 0 102.12-2.12zm-8.56-1.44c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5zm2.5-6h-5c-.28 0-.5.22-.5.5s.22.5.5.5h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5zm0-2h-5c-.28 0-.5.22-.5.5s.22.5.5.5h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5zm0 4h-5c-.28 0-.5.22-.5.5s.22.5.5.5h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5z"],"search-text":["M9 4H5c-.55 0-1 .45-1 1s.45 1 1 1h1v3c0 .55.45 1 1 1s1-.45 1-1V6h1c.55 0 1-.45 1-1s-.45-1-1-1zm6.56 9.44l-2.67-2.67C13.59 9.68 14 8.39 14 7c0-3.87-3.13-7-7-7S0 3.13 0 7s3.13 7 7 7c1.39 0 2.68-.41 3.77-1.11l2.67 2.67a1.498 1.498 0 102.12-2.12zM7 12c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],"segmented-control":["M15 4H1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm-1 6H8V6h6v4z"],select:["M16 15c0-.28-.12-.52-.31-.69l.02-.02-3.12-3.12 3.41-.84-8.05-2.86c.03-.09.05-.17.05-.27V2c0-.55-.45-1-1-1H3c0-.55-.45-1-1-1S1 .45 1 1c-.55 0-1 .45-1 1s.45 1 1 1v4c0 .55.45 1 1 1h5.2c.1 0 .18-.02.27-.05L10.33 16l.85-3.41 3.12 3.12.02-.02c.16.19.4.31.68.31.04 0 .07-.02.1-.02s.06.02.1.02c.44 0 .8-.36.8-.8 0-.04-.02-.07-.02-.1s.02-.06.02-.1zM6 6H3V3h3v3z"],selection:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6zm0-9C6.34 5 5 6.34 5 8s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3z"],"send-message":["M15.399 9.01L1.527 15.875c-.535.267-1.175.081-1.421-.427A.953.953 0 010 15V10l8-2-8-2V1c0-.528.407-1 1.004-1 .169 0 .416.04.567.116L15.403 7.07a1.084 1.084 0 01-.005 1.939z"],"send-to":["M15 7.5c-.8 0-1.5-.4-2-1l-1.2 1.2c-.4.5-1.1.7-1.8.7-1.4.1-2.5-1-2.5-2.4 0-.7.3-1.3.7-1.8L9.5 3c-.6-.5-1-1.2-1-2 0-.3.1-.7.2-1H8C3.6 0 0 3.6 0 8s3.6 8 8 8 8-3.6 8-8v-.7c-.3.1-.6.2-1 .2zM15 0h-4c-.6 0-1 .5-1 1s.4 1 1 1h1.6L9.3 5.3c-.2.2-.3.4-.3.7 0 .5.4 1 1 1 .3 0 .5-.1.7-.3L14 3.4V5c0 .6.4 1 1 1 .5 0 1-.4 1-1V1c0-.5-.4-1-1-1z"],"send-to-graph":["M6 9H2c-.55 0-1 .45-1 1s.45 1 1 1h1.59L.3 14.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L5 12.41V14c0 .55.45 1 1 1s1-.45 1-1v-4c0-.55-.45-1-1-1zm8 .5c-.56 0-1.06.23-1.42.59l-2.13-1.24L8.99 8l3.59-2.09A2.002 2.002 0 0016 4.5c0-1.1-.9-2-2-2s-2 .9-2 2c0 .19.03.37.08.54L8.5 7.13v-3.2c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S6 .9 6 2c0 .93.64 1.71 1.5 1.93v3.2l-.88-.52-2.7-1.57c.05-.17.08-.35.08-.54 0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.56 0 1.06-.23 1.42-.59l2.13 1.24 3.84 2.24 2.7 1.57c-.06.17-.09.35-.09.54 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2z"],"send-to-map":["M6 9H2c-.55 0-1 .45-1 1s.45 1 1 1h1.59L.3 14.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L5 12.41V14c0 .55.45 1 1 1s1-.45 1-1v-4c0-.55-.45-1-1-1zm9.55-5.83l-4.49-3A.975.975 0 009.99.15L5.53 2.82 1.56.17A1.003 1.003 0 000 1v6h2V2.87l2.94 1.96.06.03V7h1V4.86s.01 0 .01-.01L10 2.47v8.67s-.01 0-.01.01l-.99.58v2.33l1.47-.88 3.97 2.65A1.003 1.003 0 0016 15V4c0-.35-.18-.65-.45-.83zM14 13.13l-2.94-1.96c-.02-.01-.04-.02-.05-.03v-8.6l3 2v8.59z"],"series-add":["M10.68 7.9c.44.54 1.07.92 1.79 1.05l-2.76 2.76c-.18.18-.43.29-.71.29s-.53-.11-.71-.3L5 8.41l-3 3V13h13c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V4c0-.55.45-1 1-1s1 .45 1 1v4.59l2.29-2.3C4.47 6.11 4.72 6 5 6s.53.11.71.29L9 9.59l1.68-1.69zM15 3c.55 0 1 .45 1 1s-.45 1-1 1h-1v1c0 .55-.45 1-1 1s-1-.45-1-1V5h-1c-.55 0-1-.45-1-1s.45-1 1-1h1V2c0-.55.45-1 1-1s1 .45 1 1v1h1z"],"series-configuration":["M9.94 9.64c.65.23 1.34.36 2.06.36.14 0 .29-.01.43-.01L9.7 12.71c-.18.18-.43.29-.71.29-.28 0-.53-.11-.71-.3L5 9.41l-3 3V14h12.99c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V5c0-.55.45-1 1-1s1 .45 1 1v4.59l2.29-2.3C4.47 7.11 4.72 7 5 7c.28 0 .53.11.71.29L9 10.59l.94-.95zm4.73-6.44h.92c.22 0 .4.18.4.4v.8c0 .22-.18.4-.4.4h-.93c-.06.2-.14.38-.24.55l.66.65c.15.15.15.4 0 .55l-.54.55c-.15.15-.4.15-.55 0l-.65-.65c-.17.1-.36.18-.55.24v.91c0 .22-.18.4-.4.4h-.8c-.22 0-.4-.18-.4-.4v-.93c-.18-.06-.36-.13-.52-.22l-.68.68c-.15.16-.41.16-.57 0l-.56-.56a.417.417 0 010-.57l.68-.68c-.08-.16-.16-.33-.22-.52h-.93c-.22 0-.4-.18-.4-.4v-.8c0-.22.18-.4.4-.4h.93c.06-.2.14-.38.24-.55l-.65-.64a.392.392 0 010-.55l.54-.55a.38.38 0 01.54 0l.65.65c.18-.1.36-.18.55-.24V.4c0-.22.18-.4.4-.4h.8c.22 0 .4.18.4.4v.93c.18.06.35.14.52.22l.68-.68c.15-.16.41-.16.57 0l.57.57c.15.16.15.41 0 .57l-.68.68c.09.16.16.33.22.51zm-4.18.8c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5c-.82 0-1.5.67-1.5 1.5z"],"series-derived":["M10.66 7.92c.44.54 1.07.91 1.8 1.03L9.71 11.7c-.18.19-.43.3-.71.3s-.53-.11-.71-.3L5 8.41l-3 3V13h13c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V4c0-.55.45-1 1-1s1 .45 1 1v4.59l2.29-2.3C4.47 6.11 4.72 6 5 6s.53.11.71.29L9 9.59l1.66-1.67zM12.3 5.3l.3-.3H8c-.6 0-1-.4-1-1s.4-1 1-1h4.6l-.3-.3c-.2-.2-.3-.4-.3-.7 0-.6.5-1 1-1 .3 0 .5.1.7.3l2 2c.2.2.3.4.3.7s-.1.5-.3.7l-2 2c-.2.2-.4.3-.7.3-.6 0-1-.4-1-1 0-.3.1-.5.3-.7z"],"series-filtered":["M9.29 9.3c.3.62.8 1.12 1.42 1.41l-1 1c-.18.18-.43.29-.71.29s-.53-.11-.71-.3L5 8.41l-3 3V13h13c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V4c0-.55.45-1 1-1s1 .45 1 1v4.59l2.29-2.3C4.47 6.11 4.72 6 5 6s.53.11.71.29L9 9.59l.29-.29zM15.48 1c.31 0 .52.26.52.57 0 .16-.06.3-.17.41l-2.86 2.73v2.63c0 .16-.06.3-.17.41l-.82 1.1c-.1.1-.25.17-.41.17-.31 0-.57-.26-.57-.57V4.71L8.17 1.98A.566.566 0 018 1.57c0-.31.26-.57.57-.57h6.91z"],"series-search":["M9.6 8.94a4.937 4.937 0 001.82.01c.1-.01.22-.04.39-.08l.23-.07c.04-.01.08-.02.11-.04l.22.22-2.7 2.72c-.18.19-.43.3-.71.3s-.53-.11-.71-.3L4.98 8.41l-2.99 3V13h12.94c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V3.99c0-.55.45-1 1-1s1 .45 1 1v4.59l2.28-2.3c.17-.18.42-.29.7-.29s.53.11.7.29l3.28 3.3.64-.64zm6.22-.41c.1.12.17.27.18.44 0 .34-.27.61-.61.61a.57.57 0 01-.43-.18l-2.24-2.25c-.13.08-.26.16-.4.23-.02.01-.05.02-.07.03-.14.06-.27.12-.42.17h-.01c-.14.05-.29.08-.44.11-.04.01-.08.02-.11.02-.15.02-.3.04-.46.04-1.85 0-3.35-1.51-3.35-3.37S8.96 1.01 10.81 1c1.85 0 3.35 1.51 3.35 3.37 0 .16-.02.31-.04.47-.01.04-.01.07-.02.11-.02.15-.05.29-.1.44v.01c-.05.15-.11.28-.17.42-.01.02-.02.05-.03.07-.07.14-.14.27-.23.4l2.25 2.24zm-5.01-1.94c1.22 0 2.21-.99 2.21-2.22 0-1.23-.99-2.22-2.21-2.22S8.6 3.14 8.6 4.37c0 1.22.99 2.22 2.21 2.22z"],settings:["M3 1c0-.55-.45-1-1-1S1 .45 1 1v3h2V1zm0 4H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm12-4c0-.55-.45-1-1-1s-1 .45-1 1v2h2V1zM9 1c0-.55-.45-1-1-1S7 .45 7 1v6h2V1zM1 15c0 .55.45 1 1 1s1-.45 1-1v-5H1v5zM15 4h-2c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm-2 11c0 .55.45 1 1 1s1-.45 1-1V9h-2v6zM9 8H7c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm-2 7c0 .55.45 1 1 1s1-.45 1-1v-2H7v2z"],shapes:["M5.92 8.139c.44-.282 1.006-.121 1.264.358l2.689 4.988c.083.155.127.33.127.51C10 14.55 9.587 15 9.077 15H3.924a.864.864 0 01-.438-.12c-.449-.263-.617-.873-.376-1.362l2.465-4.989c.08-.162.2-.297.346-.39zM12 4a3 3 0 110 6 3 3 0 010-6zM6 1a1 1 0 011 1v4a1 1 0 01-1 1H2a1 1 0 01-1-1V2a1 1 0 011-1h4z"],share:["M10.99 13.99h-9v-9h4.76l2-2H.99c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h11c.55 0 1-.45 1-1V7.24l-2 2v4.75zm4-14h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L7.29 7.28a1 1 0 00-.3.71 1.003 1.003 0 001.71.71l5.29-5.29V6c0 .55.45 1 1 1s1-.45 1-1V1c0-.56-.45-1.01-1-1.01z"],"shared-filter":["M13.843 15.163c.232.53.138.837.138.837H6.017s-.088-.308.138-.837c.226-.53 1.338-.88 2.079-1.206.735-.332.66-.53.685-.8 0-.03.006-.068.006-.105a2.171 2.171 0 01-.61-.892v-.006s-.006-.006-.006-.012c-.025-.074-.056-.16-.075-.24-.176-.031-.276-.222-.314-.394a.8.8 0 01-.1-.437c.025-.253.131-.37.244-.419v-.037c0-.313.032-.775.088-1.07A1.835 1.835 0 018.85 8.37c.315-.24.76-.37 1.156-.37.396 0 .842.13 1.156.37.301.233.534.56.64.935.026.08.045.166.057.246.057.295.088.75.088 1.064v.043c.113.05.214.167.232.413a.75.75 0 01-.1.437c-.038.172-.132.357-.301.387a1.77 1.77 0 01-.076.24.136.136 0 01-.006.025 2.346 2.346 0 01-.597.892v.111c.025.277-.075.474.666.8.741.326 1.853.67 2.079 1.2z","M14.852 15h1.131s.083-.27-.12-.732c-.16-.373-.82-.641-1.411-.88a15.328 15.328 0 01-.409-.17c-.565-.25-.57-.412-.577-.61-.001-.03-.002-.06-.005-.09v-.097c.22-.2.401-.469.522-.781 0 0 .005-.016.005-.022.028-.07.05-.14.066-.21.149-.026.231-.188.264-.339a.655.655 0 00.088-.382c-.016-.215-.104-.318-.203-.36v-.039c0-.274-.028-.673-.077-.931a1.598 1.598 0 00-.61-1.034 1.736 1.736 0 00-1.285-.3c.236.285.42.622.529.996.038.124.065.248.083.36.048.257.079.578.093.867a1.736 1.736 0 01.08 1.624 1.65 1.65 0 01-.217.453 1.42 1.42 0 01-.176.209c-.08.204-.178.4-.292.585l.202.083c.285.117.64.261.9.387.226.11.475.245.698.414.213.161.476.408.63.764.034.08.065.159.091.235zM12.14 14.12l.09.037zM11 1c.55 0 1 .45 1 1 0 .28-.11.53-.29.7L8 6.41v1.374a2.813 2.813 0 00-.833 1.589 6.925 6.925 0 00-.092.86 1.64 1.64 0 00-.25.739l-.001.004c-.02.217.006.413.046.573L5.71 12.71A1.003 1.003 0 014 12V6.41L.29 2.71A1.003 1.003 0 011 1h10z"],shield:["M8 16c4.667-3.048 7-7.238 7-12.571-1.556 0-3.889-1.143-7-3.429-3.111 2.286-5.444 3.429-7 3.429C1 8.762 3.333 12.952 8 16zM8 2.121c2.005 1.388 3.715 2.304 5.186 2.735-.342 3.702-2.05 6.683-5.186 9.038V2.121z"],ship:["M5.44.804L5.2 2H3a1 1 0 00-1 1v3.714l-1.08.309a.988.988 0 00-.69 1.192c.366 1.432.897 3.324 1.309 4.26a.644.644 0 00.005.01c-.175.01-.356.015-.544.015a.5.5 0 000 1c2.067 0 3.414-.543 4.161-.917.55.373 1.505.917 2.839.917 1.32 0 2.27-.533 2.822-.905l.004.002c.196.105.48.24.856.374.75.268 1.857.529 3.318.529a.5.5 0 000-1c-.295 0-.572-.012-.834-.032a.995.995 0 00.308-.458l1.208-3.74a1 1 0 00-.677-1.269L14 6.714V3a1 1 0 00-1-1h-2.2L10.56.804A1 1 0 009.58 0H6.42a1 1 0 00-.98.804zM4 6.143l3-.857V4H4v2.143zm5-.857l3 .857V4H9v1.286zm-4.036 8.273a.5.5 0 01.527.034c.455.325 1.277.907 2.509.907s2.054-.582 2.51-.907a.5.5 0 01.579-.001l.006.004.036.023c.034.022.09.055.168.097.154.082.394.197.72.313.649.232 1.642.471 2.981.471a.5.5 0 010 1c-1.46 0-2.568-.261-3.318-.53a6.316 6.316 0 01-.856-.373l-.004-.002c-.552.372-1.502.905-2.822.905-1.334 0-2.289-.544-2.839-.917-.747.374-2.094.917-4.161.917a.5.5 0 010-1c2.129 0 3.384-.63 3.964-.94z"],shop:["M3 2h10c.55 0 1-.45 1-1s-.45-1-1-1H3c-.55 0-1 .45-1 1s.45 1 1 1zm9 11H4v-3H2v5c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-5h-2v3zm4-6l-1.01-3.17C14.9 3.36 14.49 3 14 3H2c-.49 0-.9.36-.98.83L.01 7H0c0 1.1.9 2 2 2s2-.9 2-2c0 1.1.9 2 2 2s2-.9 2-2c0 1.1.9 2 2 2s2-.9 2-2c0 1.1.9 2 2 2s2-.9 2-2z"],"shopping-cart":["M14 10H7.72l-.33-1H13c.39 0 .72-.23.89-.56h.01l2-4h-.01c.06-.13.11-.28.11-.44 0-.55-.45-1-1-1H5.39l-.44-1.32h-.01C4.8 1.29 4.44 1 4 1H1c-.55 0-1 .45-1 1s.45 1 1 1h2.28l2.33 7H4c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2h6c0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2zM6.05 5h7.33l-1 2H6.72l-.67-2z"],"signal-search":["M5.474 7.971A5.31 5.31 0 006.66 8.9l.007.019.018.056c.015.038.038.06.045.098l1.5 5.999a.75.75 0 01-1.455.36l-.42-1.68h-.704l-.42 1.68a.746.746 0 01-.907.547.746.746 0 01-.547-.907l1.5-6c.007-.037.03-.06.044-.097.015-.037.015-.075.038-.112a.722.722 0 01-.105-.36c0-.207.084-.394.22-.53zM2.795 5.277a.763.763 0 00-.015-1.065.756.756 0 00-1.065.015c-2.286 2.34-2.286 6.21 0 8.549a.747.747 0 101.072-1.042c-1.709-1.763-1.709-4.702.008-6.457zM7.808 9.388a5.318 5.318 0 001.58.211 2.236 2.236 0 01-.656.98.756.756 0 01-1.057-.098.756.756 0 01.097-1.057l.036-.036zM11.544 9.105l.378.378a6.02 6.02 0 01-1.638 3.285c-.285.3-.757.3-1.057.015a.74.74 0 01-.015-1.057 4.52 4.52 0 001.185-2.24c.4-.083.785-.212 1.147-.381z","M4.054 9.424c-.427-.352-.352-1.582-.03-1.822a.752.752 0 00.15-1.05.752.752 0 00-1.05-.15c-1.079.802-1.221 3.18-.03 4.177a.75.75 0 10.96-1.155zM9.318 0a4.318 4.318 0 014.317 4.318c0 .206-.02.402-.049.598-.01.05-.01.088-.02.138-.039.196-.078.382-.137.569v.01c-.059.186-.137.363-.216.54l-.039.087a5.285 5.285 0 01-.294.51l2.884 2.886a.878.878 0 01.236.559.787.787 0 01-.785.785.785.785 0 01-.56-.226L11.772 7.89a5.285 5.285 0 01-.51.295l-.089.039c-.176.079-.353.157-.54.216h-.01a3.701 3.701 0 01-.568.137c-.05.01-.099.02-.138.02-.196.03-.392.049-.598.049A4.318 4.318 0 015 4.327 4.332 4.332 0 019.318 0zm-.02 1.1A3.195 3.195 0 006.1 4.298a3.195 3.195 0 003.198 3.198 3.195 3.195 0 003.198-3.198A3.195 3.195 0 009.298 1.1z"],"sim-card":["M13.71 4.29l-4-4A.997.997 0 009 0H3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V5c0-.28-.11-.53-.29-.71zM7 6h2v2H7V6zM4 6h2v2H4V6zm2 8H4v-2h2v2zm3 0H7v-2h2v2zm3 0h-2v-2h2v2zm0-3H4V9h8v2zm0-3h-2V6h2v2z"],slash:["M10 2a.99.99 0 00-.96.73l-2.99 9.96A1.003 1.003 0 007 14c.46 0 .85-.31.96-.73l2.99-9.96A1.003 1.003 0 0010 2z"],"small-cross":["M9.41 8l2.29-2.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L8 6.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42L6.59 8 4.3 10.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L8 9.41l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L9.41 8z"],"small-minus":["M11 7H5c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1z"],"small-plus":["M11 7H9V5c0-.55-.45-1-1-1s-1 .45-1 1v2H5c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V9h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"small-square":["M5 5v6h6V5H5zM4 3a1 1 0 00-1 1v8a1 1 0 001 1h8a1 1 0 001-1V4a1 1 0 00-1-1H4z"],"small-tick":["M12 5c-.28 0-.53.11-.71.29L7 9.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l5-5A1.003 1.003 0 0012 5z"],snowflake:["M13.364 9l.879.879a1 1 0 11-1.415 1.414l-2.12-2.121A1.003 1.003 0 0110.568 9H9v1.604c.042.03.083.065.121.103l2.122 2.121a1 1 0 01-1.415 1.415L9 13.414V15a1 1 0 01-2 0v-1.636l-.879.879a1 1 0 11-1.414-1.415l2.121-2.12c.054-.054.111-.1.172-.139V9H5.38c-.038.06-.084.118-.137.172l-2.122 2.12A1 1 0 111.707 9.88L2.586 9H1a1 1 0 110-2h1.536l-.829-.828a1 1 0 011.414-1.415L5.243 6.88c.038.038.072.079.103.121H7V5.38a1.003 1.003 0 01-.172-.137L4.708 3.12A1 1 0 016.12 1.707L7 2.586V1a1 1 0 112 0v1.536l.828-.829a1 1 0 011.415 1.414L9.12 5.243A1.007 1.007 0 019 5.346V7h1.604c.03-.042.065-.083.103-.121l2.121-2.122a1 1 0 011.415 1.415L13.414 7H15a1 1 0 010 2h-1.636z"],"social-media":["M9.5 4c.4 0 .8-.1 1.1-.3C12 4.5 12.9 6 13 7.6c0 .5.5.9 1 .9.6 0 1-.4 1-1v-.2c-.2-2.4-1.5-4.4-3.5-5.5-.1-1-.9-1.8-2-1.8s-2 .9-2 2 .9 2 2 2zM4 8.5c0-.7-.4-1.3-.9-1.7.3-1.4 1.2-2.6 2.5-3.3.3-.1.6-.4.6-.9s-.4-1-1-1c-.2 0-.3 0-.5.1-1.9 1-3.2 2.8-3.6 5C.4 7.1 0 7.8 0 8.5c0 1.1.9 2 2 2s2-.9 2-2zm8.8 1.2c-1.1 0-2 .9-2 2v.3c-.8.6-1.8.9-2.8.9-1.2 0-2.3-.4-3.2-1.1-.2-.2-.4-.3-.7-.3-.6 0-1 .4-1 1 0 .3.1.6.3.8C4.6 14.4 6.2 15 8 15c1.5 0 3-.5 4.1-1.3.2.1.5.1.7.1 1.1 0 2-.9 2-2s-.9-2.1-2-2.1z"],sort:["M5 12c-.28 0-.53.11-.71.29l-.29.3V9c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29A.965.965 0 001 12a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 005 12zm3-9h7c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zm7 2H8c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1zm0 8H8c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H8c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1z"],"sort-alphabetical":["M6 12c-.28 0-.53.11-.71.29l-.29.3V9c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29A.965.965 0 002 12a1.003 1.003 0 00-.71 1.71l2 2c.19.18.44.29.71.29.28 0 .53-.11.71-.29l2-2c.18-.18.29-.43.29-.71a.99.99 0 00-1-1zm7.93-.95v-1.04H9.25v1.11h2.94L9 14.96V16h5.02v-1.11h-3.27l3.18-3.84zm-1.42-4.84l.62 1.78H15L11.94.01H10.1L7 7.99h1.81l.64-1.78h3.06zm-1.52-4.24h.02l1.03 2.93H9.92l1.07-2.93z"],"sort-alphabetical-desc":["M5.99 11.99c-.28 0-.53.11-.71.29l-.29.29V8.99c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29a1.003 1.003 0 00-1.42 1.42l2 2c.18.18.43.29.71.29.28 0 .53-.11.71-.29l2-2c.18-.18.29-.43.29-.71 0-.56-.45-1.01-1-1.01zM12.7 10h-1.38L9 15.99h1.36l.48-1.33h2.3l.46 1.33H15L12.7 10zm-1.51 3.67l.8-2.2h.02l.77 2.2h-1.59zm3.8-7.17h-4.57l4.45-5.12V0H8.34v1.48h4.1L7.99 6.59v1.39h7V6.5z"],"sort-asc":["M8 7h3c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zm0-4h1c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zm0 8h5c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zm-3 1c-.28 0-.53.11-.71.29l-.29.3V9c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29A.965.965 0 001 12a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 005 12zm10 1H8c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1z"],"sort-desc":["M5 12c-.28 0-.53.11-.71.29l-.29.3V9c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29A.965.965 0 001 12a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 005 12zm4 1H8c-.55 0-1 .45-1 1s.45 1 1 1h1c.55 0 1-.45 1-1s-.45-1-1-1zm4-8H8c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm-2 4H8c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1s-.45-1-1-1zm4-8H8c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1z"],"sort-numerical":["M6 11.99c-.28 0-.53.11-.71.29l-.29.3V8.99c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29c-.18-.18-.43-.3-.71-.3a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29.28 0 .53-.11.71-.29l2-2A1.003 1.003 0 006 11.99zm7.91-.08c-.06-.36-.17-.68-.33-.96-.16-.28-.37-.51-.64-.69-.27-.17-.61-.26-1.03-.26-.28 0-.54.06-.78.17-.23.11-.43.26-.6.45-.17.19-.3.41-.39.67a2.492 2.492 0 00-.04 1.52 1.623 1.623 0 00.89 1.03c.22.11.45.16.68.16.26 0 .5-.05.7-.15s.38-.26.53-.5l.02.02c-.01.16-.03.34-.07.54-.03.2-.09.4-.17.57-.08.18-.18.33-.31.45s-.29.19-.5.19a.63.63 0 01-.48-.21c-.13-.14-.21-.31-.25-.5H10.1c.03.25.1.48.19.68.1.2.22.37.38.5.16.14.33.24.54.31s.42.1.65.1c.39 0 .72-.09.99-.27.27-.18.49-.41.66-.7.17-.29.29-.61.37-.97.08-.36.12-.72.12-1.07 0-.36-.03-.72-.09-1.08zm-1.14.54c-.04.13-.09.24-.16.34a.78.78 0 01-.27.24c-.11.06-.24.09-.39.09a.75.75 0 01-.37-.09.777.777 0 01-.26-.25c-.07-.1-.12-.22-.15-.35-.03-.13-.05-.26-.05-.4 0-.13.02-.26.05-.39.04-.13.09-.24.16-.34.07-.1.16-.18.26-.24s.22-.09.35-.09c.14 0 .26.03.37.09.11.06.2.14.28.24a1.32 1.32 0 01.23.74c0 .15-.02.28-.05.41zm-1.56-4.47H13V0h-1.42c-.05.3-.16.56-.31.76-.16.21-.35.37-.58.5-.23.13-.49.21-.78.26-.3.05-.6.07-.91.06V2.8h2.21v5.18z"],"sort-numerical-desc":["M6 11.99c-.28 0-.53.11-.71.29l-.29.3V8.99c0-.55-.45-1-1-1s-1 .45-1 1v3.59l-.29-.29a.982.982 0 00-.71-.3 1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 006 11.99zm7.86-9.45c-.09-.48-.26-.9-.5-1.28S12.8.58 12.4.35C12 .12 11.49 0 10.86 0c-.43 0-.82.07-1.17.22s-.65.35-.9.6-.44.55-.58.89c-.14.34-.2.71-.2 1.11 0 .31.05.61.15.91.1.3.26.57.48.8.23.24.52.43.85.58.33.14.68.21 1.03.21.4 0 .75-.07 1.05-.2.3-.13.57-.35.79-.66l.02.02c-.02.21-.05.45-.1.73-.05.27-.13.53-.25.76-.12.24-.27.44-.47.6-.19.16-.44.25-.75.25a.98.98 0 01-.72-.29c-.19-.18-.31-.4-.37-.66H8.15c.05.34.14.64.29.9.15.26.34.49.57.67.23.18.5.32.8.41.31.1.63.15.98.15.58 0 1.08-.12 1.48-.36.4-.24.73-.55.99-.93.26-.39.44-.82.56-1.29.12-.48.18-.96.18-1.44s-.05-.96-.14-1.44zm-1.71.72c-.05.17-.14.32-.24.46-.11.13-.24.24-.41.31-.16.08-.36.12-.58.12-.21 0-.39-.04-.55-.13-.16-.08-.29-.19-.39-.33-.12-.14-.19-.29-.24-.46-.05-.17-.08-.35-.08-.54 0-.18.03-.35.08-.52.06-.16.14-.31.25-.44.11-.13.24-.24.4-.32.16-.08.33-.12.52-.12.21 0 .4.04.56.12.16.08.3.19.41.32.11.14.2.29.26.46.06.17.09.35.09.52 0 .2-.03.38-.08.55zm-.46 7.31c-.12.15-.26.28-.44.37-.17.09-.37.16-.58.2-.22.04-.44.05-.67.05v.92h1.65v3.88h1.33V10h-1.06c-.03.23-.11.42-.23.57z"],"split-columns":["M12 10a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H9V2h3v1.71c.31-.13.64-.21 1-.21s.69.08 1 .21V1c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v2.71c.31-.13.64-.21 1-.21s.69.08 1 .21V2h3v5H3.41l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C.11 7.47 0 7.72 0 8c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L3.41 9H7v5H4v-1.71c-.31.13-.64.21-1 .21s-.69-.08-1-.21V15c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-2.71c-.31.13-.64.21-1 .21s-.69-.08-1-.21V14H9V9h3.59l-.29.29c-.19.18-.3.43-.3.71z"],square:["M15 0H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H2V2h12v12z"],"stacked-chart":["M10 2c0-.55-.45-1-1-1H8c-.55 0-1 .45-1 1v3h3V2zm3 10h1c.55 0 1-.45 1-1V8h-3v3c0 .55.45 1 1 1zm2-7c0-.55-.45-1-1-1h-1c-.55 0-1 .45-1 1v2h3V5zm-5 1H7v3h3V6zM5 7c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v1h3V7zm3 5h1c.55 0 1-.45 1-1v-1H7v1c0 .55.45 1 1 1zm7 1H2c-.55 0-1 .45-1 1s.45 1 1 1h13c.55 0 1-.45 1-1s-.45-1-1-1zM3 12h1c.55 0 1-.45 1-1V9H2v2c0 .55.45 1 1 1z"],"stadium-geometry":["M12 6H4a2 2 0 100 4h8a2 2 0 100-4zM4 4a4 4 0 100 8h8a4 4 0 000-8H4z"],star:["M8 0l2.5 5.3 5.5.8-4 4.1.9 5.8L8 13.3 3.1 16l.9-5.8-4-4.1 5.5-.8z"],"star-empty":["M16 6.11l-5.53-.84L8 0 5.53 5.27 0 6.11l4 4.1L3.06 16 8 13.27 12.94 16 12 10.21l4-4.1zM4.91 13.2l.59-3.62L3 7.02l3.45-.53L8 3.2l1.55 3.29 3.45.53-2.5 2.56.59 3.62L8 11.49 4.91 13.2z"],"step-backward":["M12 3c-.24 0-.44.09-.62.23l-.01-.01L7 6.72V4c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V9.28l4.38 3.5.01-.01c.17.14.37.23.61.23.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"step-chart":["M15 12H2v-2h3c.55 0 1-.45 1-1V7h2v1c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V5h1c.55 0 1-.45 1-1s-.45-1-1-1h-2c-.55 0-1 .45-1 1v3h-2V6c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v2H2V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"step-forward":["M12 3h-1c-.55 0-1 .45-1 1v2.72l-4.38-3.5v.01A.987.987 0 005 3c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1 .24 0 .44-.09.62-.23l.01.01L10 9.28V12c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],stop:["M12 3H4c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h8c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],stopwatch:["M9 2v1.083A6.002 6.002 0 018 15 6 6 0 017 3.083V2H6a1 1 0 110-2h4a1 1 0 010 2H9zM8 5a4 4 0 104 4H8V5z"],strikethrough:["M14 7H8.65c-.38-.09-.73-.18-1.04-.26-.31-.08-.49-.13-.54-.14-.43-.11-.79-.29-1.05-.52-.27-.23-.4-.55-.4-.95 0-.29.07-.53.21-.72s.32-.34.54-.46c.22-.11.46-.19.72-.24.26-.05.52-.07.77-.07.74 0 1.36.15 1.84.46.32.2.55.5.68.9h2.22c-.06-.33-.17-.64-.32-.92-.25-.45-.59-.84-1.02-1.15-.43-.31-.93-.54-1.49-.7S8.59 2 7.95 2c-.55 0-1.1.07-1.63.2-.54.13-1.02.34-1.45.62-.42.28-.76.63-1.02 1.05-.26.42-.39.92-.39 1.5 0 .3.04.59.13.88.08.26.21.51.39.75H2c-.55 0-1 .45-1 1s.45 1 1 1h7.13c.25.07.49.14.71.22.25.09.48.23.7.44.21.21.32.53.32.97 0 .21-.05.43-.14.63-.09.21-.24.39-.45.55-.21.16-.48.29-.81.39-.33.1-.73.15-1.2.15-.44 0-.84-.05-1.21-.14-.37-.09-.7-.24-.99-.43-.29-.2-.51-.45-.67-.76-.01 0-.01-.01-.02-.02H3.14a3.68 3.68 0 001.39 2.03c.46.34 1 .58 1.62.74.61.15 1.27.23 1.97.23.61 0 1.2-.07 1.79-.2.58-.13 1.11-.34 1.56-.63.46-.29.83-.66 1.11-1.11.28-.45.42-1 .42-1.64 0-.3-.05-.6-.15-.9-.05-.19-.13-.36-.22-.52H14c.55 0 1-.45 1-1s-.45-1-1-1z"],style:["M14 14H2V2h8.76l2-2H1C.45 0 0 .45 0 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V6.24l-2 2V14zm1.4-14L9.7 5.7l2.1 2.1L16 3.6V0h-.6zM4 11.92c2.33.15 4.42.15 6.15-1.5.82-.83.82-2.25 0-3.08-.45-.38-.98-.6-1.5-.6-.53 0-1.05.22-1.43.6-.82.91-1.27 3.38-3.22 4.58z"],"swap-horizontal":["M0 7.02L.05 7H0v.02zm2-2.03h9.57l-1.29 1.29A1.003 1.003 0 0011.7 7.7l2.99-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2.99-3a1.07 1.07 0 00-.71-.28 1.003 1.003 0 00-.71 1.71L11.57 3H2c-.55 0-1 .45-1 1a1 1 0 001 .99zM15.96 9H16v-.02l-.04.02zM14 11.01H4.43l1.29-1.29A1.003 1.003 0 004.3 8.3l-2.99 3a.99.99 0 00-.29.7c0 .28.11.53.29.71l2.99 3a1.003 1.003 0 001.42-1.42L4.43 13H14c.55 0 1-.45 1-1s-.45-.99-1-.99z"],"swap-vertical":["M9 0h-.02L9 .04V0zM7 16h.02L7 15.95V16zM4.7 1.31c-.18-.18-.43-.29-.7-.29s-.53.11-.71.29l-3 2.99a1.003 1.003 0 001.42 1.42L3 4.43V14c0 .55.45 1 1 1s1-.45 1-1V4.43l1.29 1.29c.18.18.43.29.7.29A1.003 1.003 0 007.7 4.3l-3-2.99zM15 9.99c-.28 0-.53.11-.71.29L13 11.57V2c0-.55-.45-1-1-1s-1 .45-1 1v9.57l-1.29-1.29a.99.99 0 00-.7-.29 1.003 1.003 0 00-.71 1.71l3 2.99c.18.18.43.29.71.29.28 0 .53-.11.71-.29l3-2.99c.18-.18.29-.43.29-.71-.01-.55-.46-1-1.01-1z"],switch:["M9.293 2.293l1.414 1.414-4.999 5a3 3 0 11-1.415-1.415l5-5zM13 7a3 3 0 110 6 3 3 0 010-6zM3 9a1 1 0 100 2 1 1 0 000-2zm10 0a1 1 0 100 2 1 1 0 000-2z"],"symbol-circle":["M8 3.01a5 5 0 100 10 5 5 0 100-10z"],"symbol-cross":["M12 6.01h-2v-2c0-.55-.45-1-1-1H7c-.55 0-1 .45-1 1v2H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h2v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-2h2c.55 0 1-.45 1-1v-2c0-.56-.45-1-1-1z"],"symbol-diamond":["M12 8.01c0-.19-.07-.36-.16-.51l.01-.01-3-5-.01.01c-.17-.29-.48-.49-.84-.49s-.67.2-.84.49l-.02-.01-3 5 .02.01c-.09.15-.16.32-.16.51s.07.36.16.51h-.02l3 5 .01-.01c.18.29.49.5.85.5s.67-.2.84-.49l.01.01 3-5-.01-.01c.09-.16.16-.32.16-.51z"],"symbol-square":["M12 3.01H4c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h8c.55 0 1-.45 1-1v-8c0-.56-.45-1-1-1z"],"symbol-triangle-down":["M13 4.01c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1 0 .16.05.31.11.44H3.1l4 8h.01c.16.33.49.56.89.56s.72-.23.89-.56h.01l4-8h-.01c.06-.14.11-.28.11-.44z"],"symbol-triangle-up":["M12.89 11.56l-3.99-8h-.01c-.17-.32-.5-.55-.89-.55s-.72.23-.89.55H7.1l-4 8h.01c-.06.14-.11.29-.11.45 0 .55.45 1 1 1h8c.55 0 1-.45 1-1 0-.16-.05-.31-.11-.45z"],syringe:["M11.146.146a.5.5 0 000 .708l.647.646L10.5 2.793 8.854 1.146a.5.5 0 10-.708.708l.647.646-1.146 1.146-5.5 5.5a.5.5 0 000 .708l.646.646-1.647 1.646a.5.5 0 000 .708l.647.646-1.647 1.646a.5.5 0 00.708.708L2.5 14.207l.646.647a.5.5 0 00.708 0L5.5 13.207l.646.647a.5.5 0 00.708 0l5.5-5.5L13.5 7.207l.646.647a.5.5 0 00.708-.708L13.207 5.5 14.5 4.207l.646.647a.5.5 0 00.708-.708l-4-4a.5.5 0 00-.708 0zM11.293 8l-.793.793-1.646-1.647a.5.5 0 10-.708.708L9.793 9.5 8.5 10.793 6.854 9.146a.5.5 0 10-.708.708L7.793 11.5 6.5 12.793 3.207 9.5 8 4.707 11.293 8zM8.707 4L12 7.293l.793-.793L9.5 3.207 8.707 4zm-6.5 8.5L3.5 13.793 4.793 12.5 3.5 11.207 2.207 12.5zm11.586-9L12.5 2.207 11.207 3.5 12.5 4.793 13.793 3.5z"],tag:["M1 3a2 2 0 012-2h4.584a2 2 0 011.414.586l5.413 5.412a2 2 0 010 2.829L9.827 14.41a2 2 0 01-2.829 0L1.586 8.998A2 2 0 011 7.584V3zm3.487-.007a1.494 1.494 0 100 2.988 1.494 1.494 0 000-2.988z"],"take-action":["M9 11a1.003 1.003 0 001.71.71l4-4a1.003 1.003 0 00-1.42-1.42l-4 4c-.18.18-.29.43-.29.71zM4 6c.28 0 .53-.11.71-.29l4-4A1.003 1.003 0 007.29.29l-4 4A1.003 1.003 0 004 6zm4 4l5-5-.79-.79.5-.5a1.003 1.003 0 00-1.42-1.42l-.5.5L10 2 5 7l.79.79-5.5 5.5a1.003 1.003 0 001.42 1.42l5.5-5.5L8 10zm7 4H7c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1z"],tank:["M3.7 3.4a1 1 0 01.8-.4h5.086a1 1 0 01.707.293L11 4h3a1 1 0 110 2h-3v1h2.5a2.5 2.5 0 010 5h-11a2.5 2.5 0 010-5H3V4.667a1 1 0 01.2-.6l.5-.667zM2.5 9h11a.5.5 0 010 1h-11a.5.5 0 110-1z"],target:["M7 4a1 1 0 012 0v2a1 1 0 01-2 0V4zM10 7a1 1 0 000 2h2a1 1 0 000-2h-2zM3 8a1 1 0 011-1h2a1 1 0 010 2H4a1 1 0 01-1-1zM8 9a1 1 0 00-1 1v2a1 1 0 002 0v-2a1 1 0 00-1-1z","M8 16A8 8 0 108 0a8 8 0 000 16zm0-2A6 6 0 108 2a6 6 0 000 12z"],taxi:["M15.12 6.63h-.38L15 7c-.01.3-.01.64 0 .98V8c0 .07-.03.13-.04.19h.02L14 13.1v.9c0 .55-.45 1-1 1s-1-.45-1-1v-1H4v1c0 .55-.45 1-1 1s-1-.45-1-1v-.9l-.98-4.9h.02C1.03 8.13 1 8.07 1 8H.99c0-.33 0-.67.01-1l.26-.37H.88C.4 6.63 0 6.21 0 5.69s.4-.94.88-.94h1.05l.77-2.11c.19-.53.76-1.08 1.26-1.24 0 0 .68-.2 2.05-.32C6.01 1.05 6 1.03 6 1c0-.55.45-1 1-1h2c.55 0 1 .45 1 1 0 .03-.01.05-.02.08 1.37.12 2.05.32 2.05.32.51.15 1.08.71 1.27 1.24l.76 2.12h1.05c.49 0 .89.42.89.93 0 .52-.4.94-.88.94zM11 10h2V8h-2v2zm-8 0h2V8H3v2zm10-5l-.73-1.63C12.21 3.19 12.18 3 12 3H4c-.18 0-.21.19-.27.37L3 5c-.06.18-.18 1 0 1h10c.18 0 .06-.82 0-1z"],temperature:["M8.5 0A1.5 1.5 0 007 1.5v7.837a3.5 3.5 0 103 0V1.5A1.5 1.5 0 008.5 0zM2 5.5a.5.5 0 01.5-.5h3a.5.5 0 010 1h-3a.5.5 0 01-.5-.5zM2.5 1a.5.5 0 000 1h3a.5.5 0 000-1h-3zM4 3.5a.5.5 0 01.5-.5h1a.5.5 0 010 1h-1a.5.5 0 01-.5-.5zM4.5 7a.5.5 0 000 1h1a.5.5 0 000-1h-1z"],"text-highlight":["M9 10H2V6h7V4H1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h8v-2zm4 3h-1V3h1c.55 0 1-.45 1-1s-.45-1-1-1h-1c-.37 0-.7.11-1 .28-.3-.17-.63-.28-1-.28H9c-.55 0-1 .45-1 1s.45 1 1 1h1v10H9c-.55 0-1 .45-1 1s.45 1 1 1h1c.37 0 .7-.11 1-.28.3.17.63.28 1 .28h1c.55 0 1-.45 1-1s-.45-1-1-1zm2-9h-2v2h1v4h-1v2h2c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],th:["M15 1H1c-.6 0-1 .5-1 1v12c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1zM6 13H2v-2h4v2zm0-3H2V8h4v2zm0-3H2V5h4v2zm8 6H7v-2h7v2zm0-3H7V8h7v2zm0-3H7V5h7v2z"],"th-derived":["M5.6 10l-.3.3c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3l2-2c.2-.2.3-.4.3-.7s-.1-.5-.3-.7l-2-2C6.5 6.1 6.3 6 6 6c-.5 0-1 .4-1 1 0 .3.1.5.3.7l.3.3H1c-.6 0-1 .4-1 1s.4 1 1 1h4.6zM15 1H2c-.5 0-1 .5-1 1v5h2V5h11v2H8.8l.6.6c.1.1.2.3.3.4H14v2H9.7c-.1.1-.2.3-.3.4l-.6.6H14v2H3v-2H1v3c0 .5.5 1 1 1h13c.6 0 1-.5 1-1V2c0-.5-.4-1-1-1z"],"th-disconnect":["M12 1h3c.6 0 1 .5 1 1v12c0 .6-.4 1-1 1h-4.97l.286-2H14v-2h-3.398l.143-1H14V8h-2.97l.143-1H14V5h-2.541l.51-3.576C11.99 1.282 12 1.14 12 1zM5.97 1l-.572 4H2v2h3.112L4.97 8H2v2h2.684l-.143 1H2v2h2.255l-.225 1.576c-.02.142-.03.284-.03.424H1c-.6 0-1-.4-1-1V2c0-.5.4-1 1-1h4.97zM8.01.859a1 1 0 111.98.282l-2 14a1 1 0 11-1.98-.282l2-14z"],"th-filtered":["M10 10h3l1.78-2.226a1 1 0 00.22-.625V4.3l1-.9V14c0 .6-.4 1-1 1H1c-.6 0-1-.4-1-1V2c0-.5.4-1 1-1h4.333L9 4.3V5H7v2h2v1H7v2h3zm-4 3v-2H2v2h4zm0-3V8H2v2h4zm0-3V5H2v2h4zm8 6v-2H7v2h7z","M15.48 0c.31 0 .52.26.52.57 0 .16-.06.3-.17.41l-2.86 2.73v2.63c0 .16-.06.3-.17.41l-.82 1.1c-.1.1-.25.17-.41.17-.31 0-.57-.26-.57-.57V3.71L8.17.98A.566.566 0 018 .57c0-.31.26-.57.57-.57h6.91z"],"th-list":["M15 1H1c-.6 0-1 .5-1 1v12c0 .6.4 1 1 1h14c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1zm-1 12H2v-2h12v2zm0-3H2V8h12v2zm0-3H2V5h12v2z"],"third-party":["M4.448 9h.573c.025-.044.051-.088.079-.13A9.43 9.43 0 015.183 8h-.995A10.424 10.424 0 014 6c0-.717.068-1.391.188-2h3.624c.065.33.114.678.146 1.042A3.42 3.42 0 018.46 5c.168 0 .336.013.502.037A11.089 11.089 0 008.829 4h1.755c.148.338.26.696.33 1.068l.176-.028a2.74 2.74 0 01.5 0c.113 0 .225.006.336.018A6.001 6.001 0 000 6a6 6 0 005.672 5.991 4 4 0 01-.202-.441 1.842 1.842 0 01-.24-.26 1.82 1.82 0 01-.26-.55 2 2 0 01-.185-.92l-.012-.025A6.036 6.036 0 014.448 9zM3.171 8H1.416A4.983 4.983 0 011 6c0-.711.148-1.388.416-2h1.755C3.06 4.626 3 5.299 3 6c0 .701.06 1.374.17 2zM2 9H3.4c.18.618.412 1.167.685 1.62A5.015 5.015 0 012 9zm2.448-6h3.104a6.036 6.036 0 00-.325-.795C6.737 1.225 6.246 1 6 1c-.246 0-.737.225-1.227 1.205-.119.238-.228.504-.325.795zm4.15 0H10a5.016 5.016 0 00-2.086-1.62c.273.453.506 1.002.685 1.62zM4.087 1.38A6.834 6.834 0 003.401 3H2a5.015 5.015 0 012.086-1.62zM13.476 16s.118-.385-.172-1.046c-.228-.533-1.172-.915-2.015-1.257a22.113 22.113 0 01-.584-.243c-.808-.356-.816-.588-.825-.872-.002-.041-.003-.084-.007-.128v-.139c.314-.284.573-.669.745-1.115 0 0 .008-.023.008-.03.04-.1.071-.2.095-.3.212-.04.33-.27.377-.485.054-.093.149-.3.125-.547-.024-.307-.15-.453-.29-.515v-.054c0-.392-.04-.961-.11-1.33a2.16 2.16 0 00-.071-.308 2.283 2.283 0 00-.8-1.17C9.558 6.162 9.001 6 8.506 6c-.495 0-1.052.162-1.445.462A2.294 2.294 0 006.19 7.93c-.07.369-.11.946-.11 1.338v.046c-.14.062-.274.208-.306.523a1 1 0 00.126.547c.047.215.173.453.393.492.02.083.05.172.078.253l.016.047c0 .008.008.015.008.015v.008c.172.454.44.846.761 1.115a.804.804 0 01-.004.072c-.002.02-.004.04-.004.06l-.007.105c-.016.287-.028.523-.848.894-.176.078-.37.156-.568.237-.847.345-1.802.735-2.031 1.27C3.41 15.616 3.52 16 3.52 16h9.955zm2.503-1.25h-1.413a4.05 4.05 0 00-.116-.294c-.192-.445-.52-.753-.787-.955-.278-.21-.59-.38-.873-.517a21.373 21.373 0 00-1.122-.483l-.02-.008-.235-.097c.144-.23.266-.476.366-.731.089-.087.162-.177.22-.26.132-.192.217-.391.271-.568.117-.251.24-.64.199-1.105a2.025 2.025 0 00-.299-.925 8.626 8.626 0 00-.116-1.083 3.426 3.426 0 00-.104-.45 3.476 3.476 0 00-.661-1.246A2.18 2.18 0 0111.63 6c.432 0 .92.141 1.264.404.33.256.584.612.7 1.023.028.087.049.182.062.27.062.322.097.82.097 1.163v.048c.123.053.233.181.254.45a.82.82 0 01-.11.478c-.041.189-.144.391-.33.425a1.92 1.92 0 01-.082.262c0 .007-.007.027-.007.027-.151.39-.378.727-.653.976v.121c.004.038.005.075.006.111v.002c.008.247.015.451.722.762.158.07.332.14.51.213.739.299 1.565.634 1.764 1.1.254.579.151.915.151.915z"],"thumbs-down":["M2 2H0v7h2c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm13.99 4.38c.08-.58-.44-1.02-1.15-1.05-.25-.01-.52-.03-.81-.05.02 0 .05-.01.07-.01.7-.1 1.34-.49 1.41-1.07.06-.58-.46-.97-1.17-1.04-.25-.02-.52-.04-.79-.06.47-.15.84-.42.87-.93.04-.58-.79-1.03-1.5-1.09-.27-.02-.51-.04-.73-.05h-.09c-.23-.02-.43-.02-.62-.03C8.35.95 5.66 1.47 4 2.51v6c2.14 1.29 4.76 3.59 4.21 5.51-.18.59.31 1.05.98.98.81-.09 1.37-.91 1.4-1.78.04-1-.15-2.01-.5-2.91-.04-.25.01-.5.37-.53.49-.03 1.11-.06 1.59-.08.26 0 .51-.01.75-.02h.01c.41-.02.8-.05 1.13-.09.7-.09 1.35-.47 1.43-1.05.08-.58-.44-.97-1.15-1.05-.05-.01-.11-.01-.16-.02.17-.01.33-.03.49-.05.72-.08 1.37-.46 1.44-1.04z"],"thumbs-up":["M15.99 9.62c-.08-.58-.73-.96-1.43-1.05-.15-.02-.32-.04-.49-.05.06-.01.11-.01.16-.02.71-.08 1.23-.47 1.15-1.05-.08-.58-.73-.96-1.43-1.05-.34-.04-.72-.07-1.13-.09h-.01c-.24-.01-.49-.02-.75-.02-.48-.02-1.11-.04-1.59-.08-.36-.03-.41-.28-.37-.53.35-.9.54-1.91.5-2.91-.04-.85-.6-1.68-1.41-1.77-.67-.07-1.16.39-.99.98C8.76 3.91 6.13 6.2 4 7.49v6c1.66 1.03 4.35 1.56 7.48 1.5.19 0 .39-.01.62-.02h.09c.22-.01.46-.03.73-.05.71-.06 1.54-.51 1.5-1.09-.03-.51-.4-.79-.87-.93.27-.02.54-.04.79-.06.71-.06 1.24-.45 1.17-1.04-.06-.58-.7-.97-1.41-1.07-.02 0-.05-.01-.07-.01.29-.02.57-.03.81-.05.71-.03 1.23-.47 1.15-1.05zM2 7H0v7h2c.55 0 1-.45 1-1V8c0-.56-.45-1-1-1z"],tick:["M14 3c-.28 0-.53.11-.71.29L6 10.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l4 4c.18.18.43.29.71.29s.53-.11.71-.29l8-8A1.003 1.003 0 0014 3z"],"tick-circle":["M8 16c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm4-11c-.28 0-.53.11-.71.29L7 9.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l5-5A1.003 1.003 0 0012 5z"],time:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm0 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6zm1-6.41V4c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L9 7.59z"],"timeline-area-chart":["M15 2.59L9.91 7.68 6.6 5.2l-.01.01C6.42 5.09 6.23 5 6 5c-.24 0-.44.09-.62.23v-.01L3 7.12V11h12V2.59zM15 12H2V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"timeline-bar-chart":["M8 12h1c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1H8c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1zm5 0h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1h-1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1zm2 1H2c-.55 0-1 .45-1 1s.45 1 1 1h13c.55 0 1-.45 1-1s-.45-1-1-1zM3 12h1c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1z"],"timeline-events":["M8 11H7v1h1v-1zm-4 0H3v1h1v-1zm7-8c.6 0 1-.5 1-1V1c0-.5-.4-1-1-1s-1 .5-1 1v1c0 .5.5 1 1 1zM4 3c.5 0 1-.5 1-1V1c0-.5-.5-1-1-1S3 .5 3 1v1c0 .5.5 1 1 1zm10-2h-1v1c0 1.1-.9 2-2 2s-2-.9-2-2V1H6v1c0 1.1-.9 2-2 2s-2-.9-2-2V1H1c-.5 0-1 .5-1 1v12c0 .5.5 1 1 1h13c.6 0 1-.5 1-1V2c0-.5-.4-1-1-1zM5 13H2v-3h3v3zm0-4H2V6h3v3zm4 4H6v-3h3v3zm0-4H6V6h3v3zm4 4h-3v-3h3v3zm0-4h-3V6h3v3zm-1-2h-1v1h1V7z"],"timeline-line-chart":["M15 12H2V9.41l3-3L8.29 9.7c.18.19.43.3.71.3s.53-.11.71-.29l6-6a1.003 1.003 0 00-1.42-1.42L9 7.59l-3.29-3.3C5.53 4.11 5.28 4 5 4s-.53.11-.71.29L2 6.59V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],tint:["M7.88 1s-4.9 6.28-4.9 8.9c.01 2.82 2.34 5.1 4.99 5.1 2.65-.01 5.03-2.3 5.03-5.13C12.99 7.17 7.88 1 7.88 1z"],torch:["M5 15c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-1H5v1zm7-15H4c-.55 0-1 .45-1 1v1h10V1c0-.55-.45-1-1-1zM5 7v6h6V7l2-4H3l2 4zm2 0c0-.55.45-1 1-1s1 .45 1 1v2c0 .55-.45 1-1 1s-1-.45-1-1V7z"],tractor:["M3.5 9a3.5 3.5 0 110 7 3.5 3.5 0 010-7zm9.5 1a3 3 0 110 6 3 3 0 010-6zm-9.5 1a1.5 1.5 0 100 3 1.5 1.5 0 000-3zm9.5 1a1 1 0 100 2 1 1 0 000-2zM5 0c1.46 0 2.527.668 3 2l.815 3.255a78.9 78.9 0 012.186.195L11 2h2l.001 3.688c.698.095 1.37.198 2.013.312.623.11.986.479.986 1v3.354a4.001 4.001 0 00-6.873 1.645H7.999l-.026-.002A4.5 4.5 0 00.659 9.01l-.654.001v-.829C.003 7.386.002 6.423 0 6.022 0 5.5.376 4.99 1 4.99V1a1 1 0 011-1h3zm1 2H3v2.99c1.29.024 2.554.069 3.781.135L6 2z"],train:["M13 14h-1l1 2H3l1-2H3c-1.1 0-2-.9-2-2V2C1 .9 4.13 0 8 0s7 .9 7 2v10c0 1.1-.9 2-2 2zm-2-2h2v-2h-2v2zM9 7h4V3H9v4zm-6 5h2v-2H3v2zm0-5h4V3H3v4z"],translate:["M15.89 14.56l-3.99-8h-.01c-.17-.33-.5-.56-.89-.56s-.72.23-.89.56h-.01L9 8.76 7.17 7.38l.23-.18C8.37 6.47 9 5.31 9 4V3h1c.55 0 1-.45 1-1s-.45-1-1-1H7c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1H1c-.55 0-1 .45-1 1s.45 1 1 1h6v1c0 .66-.32 1.25-.82 1.61l-.68.51-.68-.5C4.32 5.25 4 4.66 4 4H2c0 1.31.63 2.47 1.6 3.2l.23.17L1.4 9.2l.01.01C1.17 9.4 1 9.67 1 10c0 .55.45 1 1 1 .23 0 .42-.09.59-.21l.01.01 2.9-2.17 2.6 1.95-1.99 3.98h.01c-.07.13-.12.28-.12.44 0 .55.45 1 1 1 .39 0 .72-.23.89-.56h.01L8.62 14h4.76l.72 1.45h.01c.17.32.5.55.89.55.55 0 1-.45 1-1 0-.16-.05-.31-.11-.44zM9.62 12L11 9.24 12.38 12H9.62z"],trash:["M14.49 3.99h-13c-.28 0-.5.22-.5.5s.22.5.5.5h.5v10c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-10h.5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5zm-8.5 9c0 .55-.45 1-1 1s-1-.45-1-1v-6c0-.55.45-1 1-1s1 .45 1 1v6zm3 0c0 .55-.45 1-1 1s-1-.45-1-1v-6c0-.55.45-1 1-1s1 .45 1 1v6zm3 0c0 .55-.45 1-1 1s-1-.45-1-1v-6c0-.55.45-1 1-1s1 .45 1 1v6zm2-12h-4c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1h-4c-.55 0-1 .45-1 1v1h14v-1c0-.55-.45-1-1-1z"],tree:["M9 11.857V16H7v-4.143L1 13l3.885-4.44L3 9l3.07-4.297L5 5l3-5 3 5-1.07-.297L13 9l-1.885-.44L15 13l-6-1.143z"],"trending-down":["M15 7c-.55 0-1 .45-1 1v.59l-4.29-4.3A.997.997 0 009 4c-.16 0-.31.05-.44.11V4.1L5 5.88 1.45 4.11v.01C1.31 4.05 1.16 4 1 4c-.55 0-1 .45-1 1 0 .39.23.72.56.89v.01l4 2v-.01c.13.06.28.11.44.11s.31-.05.44-.11v.01L8.8 6.22 12.59 10H12c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1z"],"trending-up":["M15 4h-3c-.55 0-1 .45-1 1s.45 1 1 1h.59L8.8 9.78 5.45 8.11v.01C5.31 8.05 5.16 8 5 8s-.31.05-.44.11V8.1l-4 2v.01c-.33.17-.56.5-.56.89 0 .55.45 1 1 1 .16 0 .31-.05.44-.11v.01L5 10.12l3.55 1.78v-.01c.14.06.29.11.45.11.28 0 .53-.11.71-.29L14 7.41V8c0 .55.45 1 1 1s1-.45 1-1V5c0-.55-.45-1-1-1z"],truck:["M12.5 0a.5.5 0 01.5.5V9a1 1 0 011 1v2h.5a.5.5 0 01.5.5v1a.5.5 0 01-.5.5H13v1a1 1 0 01-2 0v-1H5v1a1 1 0 01-2 0v-1H1.5a.5.5 0 01-.5-.5v-1a.5.5 0 01.5-.5H2v-2a1 1 0 011-1V.5a.5.5 0 011 0V3a2 2 0 012-2h4a2 2 0 012 2V.5a.5.5 0 01.5-.5zM9 8H7a1 1 0 00-1 1v2a1 1 0 001 1h2a1 1 0 001-1V9a1 1 0 00-1-1zm3.5 3h-1a.5.5 0 100 1h1a.5.5 0 100-1zm-8 0h-1a.5.5 0 100 1h1a.5.5 0 100-1zM9 9a.5.5 0 01.5.5v1l-.008.09A.5.5 0 019 11H7l-.09-.008a.5.5 0 01-.41-.492v-1l.008-.09A.5.5 0 017 9zm2-5H5v2h6V4z"],"two-columns":["M3.99-.01h-3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h3c.55 0 1-.45 1-1v-14c0-.55-.45-1-1-1zm11.71 7.3l-2-2a1.003 1.003 0 00-1.71.71v4a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71s-.11-.53-.29-.71zM9.99-.01h-3c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h3c.55 0 1-.45 1-1v-14c0-.55-.45-1-1-1z"],unarchive:["M13.382 0a1 1 0 01.894.553L16 4v11a1 1 0 01-1 1H1a1 1 0 01-1-1V4L1.724.553A1 1 0 012.618 0h10.764zM8 6c-.28 0-.53.11-.71.29l-2 2-.084.096A1.003 1.003 0 006.71 9.71l.29-.3V12l.007.116c.058.496.482.884.993.884.55 0 1-.45 1-1V9.41l.29.29.081.076A.97.97 0 0010 10a1.003 1.003 0 00.71-1.71l-2-2-.096-.084A1.002 1.002 0 008 6zm5-4H3L2 4h12l-1-2z"],underline:["M8 14c2.8 0 5-2.2 5-5V3c0-.6-.4-1-1-1s-1 .4-1 1v6c0 1.7-1.3 3-3 3s-3-1.3-3-3V3c0-.6-.4-1-1-1s-1 .4-1 1v6c0 2.8 2.2 5 5 5zM13.5 15h-11c-.3 0-.5.2-.5.5s.2.5.5.5h11c.3 0 .5-.2.5-.5s-.2-.5-.5-.5z"],undo:["M4 11c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm7-7H3.41L4.7 2.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C.11 4.47 0 4.72 0 5c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L3.41 6H11c1.66 0 3 1.34 3 3s-1.34 3-3 3H7v2h4c2.76 0 5-2.24 5-5s-2.24-5-5-5z"],"ungroup-objects":["M3.5 5C1.57 5 0 6.57 0 8.5S1.57 12 3.5 12 7 10.43 7 8.5 5.43 5 3.5 5zm9 0C10.57 5 9 6.57 9 8.5s1.57 3.5 3.5 3.5S16 10.43 16 8.5 14.43 5 12.5 5z"],"unknown-vehicle":["M10.507 9.75v-3.5c0-.089.023-.171.051-.25h-7.55c-.176 0-.061-.824 0-1l.729-1.63c.06-.177.095-.37.27-.37h4.5V1.01c-.166-.003-.32-.01-.5-.01-2.72 0-4.036.402-4.036.402-.508.155-1.079.711-1.268 1.237L1.94 4.756H.887c-.483 0-.88.423-.88.939s.397.939.88.939h.376L1.008 7c-.034.685 0 1.436 0 2v5c0 .657.384 1 1 1s1-.343 1-1v-1h10v1c0 .657.383 1 1 1s1-.343 1-1v-3.5h-3.75a.75.75 0 01-.75-.75zm-5.5.25h-2V8h2v2zm11-4.305zM15.34.826a2.807 2.807 0 00-.932-.598c-.386-.16-.868-.241-1.445-.241-.447 0-.851.076-1.213.228-.362.153-.67.364-.926.636s-.456.592-.598.963a3.535 3.535 0 00-.218 1.144V3h1.789c.003-.208.023-.405.069-.588.049-.193.124-.362.225-.506.102-.144.232-.259.39-.345.159-.087.348-.13.567-.13.325 0 .58.09.762.272.183.18.275.46.275.839.008.222-.031.407-.116.555a1.654 1.654 0 01-.335.408 7.4 7.4 0 01-.452.37c-.162.123-.316.27-.463.438a2.556 2.556 0 00-.384.611c-.11.239-.177.535-.2.889V6h1.645v-.1c.032-.248.111-.453.237-.618.126-.164.27-.31.433-.438.163-.128.335-.255.518-.383a2.413 2.413 0 00.878-1.117c.102-.255.152-.58.152-.975A2.241 2.241 0 0015.34.826zM12.007 7v2h2V7h-2z"],unlock:["M11.99-.01c-2.21 0-4 1.79-4 4v3h-7c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-7c0-.55-.45-1-1-1h-3v-3c0-1.1.9-2 2-2s2 .9 2 2v1c0 .55.45 1 1 1s1-.45 1-1v-1c0-2.21-1.79-4-4-4z"],unpin:["M9.39 1c-.5.5-.4 1.48.15 2.53L4.38 7.54C2.85 6.5 1.52 6.07 1 6.59l3.5 3.5c-.02.02-1.4 2.8-1.4 2.8l2.8-1.4 3.5 3.5c.53-.53.1-1.86-.95-3.38l4.02-5.16c1.04.55 2.01.65 2.51.14L9.39 1z"],unresolve:["M11 3c-.55 0-1.07.09-1.57.26a6.46 6.46 0 010 9.48c.5.17 1.02.26 1.57.26 2.76 0 5-2.24 5-5s-2.24-5-5-5zM9.78 9.38l.09-.27c.08-.36.13-.73.13-1.11s-.05-.75-.13-1.11l-.09-.27a5.32 5.32 0 00-.29-.79l-.12-.21c-.14-.27-.31-.52-.51-.76a.7.7 0 00-.08-.1c-.24-.27-.49-.52-.78-.74-.43-.32-.92-.58-1.45-.75l.01-.01c-.1-.03-.2-.05-.3-.08-.12-.03-.23-.07-.36-.09A5.28 5.28 0 005 3C2.24 3 0 5.24 0 8s2.24 5 5 5c.31 0 .61-.04.9-.09.12-.02.24-.06.36-.09.1-.03.21-.04.3-.08l-.01-.01c.88-.29 1.64-.8 2.22-1.49.03-.03.06-.07.09-.1.19-.24.36-.49.51-.76.04-.07.08-.14.11-.21.13-.25.23-.52.3-.79z"],updated:["M8 0a7.95 7.95 0 00-6 2.74V1c0-.55-.45-1-1-1S0 .45 0 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.54C4.64 2.78 6.22 2 8 2c3.31 0 6 2.69 6 6 0 2.61-1.67 4.81-4 5.63-.63.22-1.29.37-2 .37-3.31 0-6-2.69-6-6 0-.55-.45-1-1-1s-1 .45-1 1c0 4.42 3.58 8 8 8 .34 0 .67-.03 1-.07.02 0 .04-.01.06-.01C12.98 15.4 16 12.06 16 8c0-4.42-3.58-8-8-8zm3 5c-.28 0-.53.11-.71.29L7 8.58 5.71 7.29a1.003 1.003 0 00-1.42 1.42l2 2c.18.18.43.29.71.29.28 0 .53-.11.71-.29l4-4A1.003 1.003 0 0011 5z"],upload:["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zm3 8c-.28 0-.53-.11-.71-.29L9 6.41V12c0 .55-.45 1-1 1s-1-.45-1-1V6.41l-1.29 1.3a1.003 1.003 0 01-1.42-1.42l3-3C7.47 3.11 7.72 3 8 3s.53.11.71.29l3 3A1.003 1.003 0 0111 8z"],user:["M7.99-.01A7.998 7.998 0 00.03 8.77c.01.09.03.18.04.28.02.15.04.31.07.47.02.11.05.22.08.34.03.13.06.26.1.38.04.12.08.25.12.37.04.11.08.21.12.32a6.583 6.583 0 00.3.65c.07.14.14.27.22.4.04.07.08.13.12.2l.27.42.1.13a7.973 7.973 0 003.83 2.82c.03.01.05.02.07.03.37.12.75.22 1.14.29l.2.03c.39.06.79.1 1.2.1s.81-.04 1.2-.1l.2-.03c.39-.07.77-.16 1.14-.29.03-.01.05-.02.07-.03a8.037 8.037 0 003.83-2.82c.03-.04.06-.08.09-.13.1-.14.19-.28.28-.42.04-.07.08-.13.12-.2.08-.13.15-.27.22-.41.04-.08.08-.17.12-.26.06-.13.11-.26.17-.39.04-.1.08-.21.12-.32.04-.12.08-.24.12-.37.04-.13.07-.25.1-.38.03-.11.06-.22.08-.34.03-.16.05-.31.07-.47.01-.09.03-.18.04-.28.02-.26.04-.51.04-.78-.03-4.41-3.61-7.99-8.03-7.99zm0 14.4c-1.98 0-3.75-.9-4.92-2.31.67-.36 1.49-.66 2.14-.95 1.16-.52 1.04-.84 1.08-1.27.01-.06.01-.11.01-.17-.41-.36-.74-.86-.96-1.44v-.01c0-.01-.01-.02-.01-.02-.05-.13-.09-.26-.12-.39-.28-.05-.44-.35-.5-.63-.06-.11-.18-.38-.15-.69.04-.41.2-.59.38-.67v-.06c0-.51.05-1.24.14-1.72.02-.13.05-.26.09-.39.17-.59.53-1.12 1.01-1.49.49-.38 1.19-.59 1.82-.59.62 0 1.32.2 1.82.59.48.37.84.9 1.01 1.49.04.13.07.26.09.4.09.48.14 1.21.14 1.72v.07c.18.08.33.26.37.66.03.31-.1.58-.16.69-.06.27-.21.57-.48.62-.03.13-.07.26-.12.38 0 .01-.01.04-.01.04-.21.57-.54 1.06-.94 1.42 0 .06.01.13.01.19.04.43-.12.75 1.05 1.27.65.29 1.47.6 2.14.95a6.415 6.415 0 01-4.93 2.31z"],variable:["M3.94 3.15c.47-.66 1.05-1.24 1.76-1.73l.13-.4c-1.11.45-2.05 1.01-2.84 1.7-1.02.88-1.8 1.9-2.32 3.05C.22 6.76 0 7.75 0 8.75c0 1.75.66 3.5 1.99 5.25l.13-.42c-.39-.94-.59-1.82-.59-2.63 0-1.28.22-2.64.67-4.1.45-1.45 1.03-2.69 1.74-3.7zm7.51 6.41l-.27-.15c-.3.41-.52.66-.66.77-.09.06-.21.1-.33.1-.15 0-.3-.1-.45-.28-.25-.33-.59-1.22-1.01-2.69.38-.65.69-1.08.95-1.28.19-.15.39-.22.59-.22.08 0 .22.03.43.08.2.06.39.08.54.08.22 0 .4-.07.54-.22.15-.15.22-.34.22-.57 0-.25-.07-.45-.22-.59-.15-.15-.35-.22-.63-.22-.24 0-.47.06-.69.17-.21.11-.49.36-.82.74-.25.28-.61.78-1.1 1.48a6.72 6.72 0 00-.97-2.38l-2.59.44-.05.27c.19-.04.36-.06.49-.06.26 0 .47.11.64.33.26.34.63 1.38 1.11 3.12-.37.49-.63.81-.77.96-.23.24-.41.4-.56.47-.11.06-.24.09-.39.09-.11 0-.29-.06-.53-.18-.17-.07-.32-.11-.45-.11-.25 0-.46.08-.62.24-.16.16-.24.37-.24.61 0 .23.08.42.23.57.15.15.35.22.61.22.25 0 .48-.05.7-.15.22-.1.49-.32.82-.65.33-.33.78-.86 1.36-1.59.22.69.42 1.19.58 1.51.16.31.35.54.56.68.21.14.47.21.79.21.31 0 .62-.11.93-.33.4-.29.82-.77 1.26-1.47zm2.56-8.54l-.12.42c.39.95.59 1.82.59 2.64 0 1.09-.17 2.26-.5 3.51-.26.96-.6 1.87-1.02 2.71-.42.85-.82 1.51-1.21 1.98-.39.48-.87.92-1.44 1.32l-.14.4c1.11-.45 2.05-1.02 2.84-1.7 1.03-.89 1.81-1.91 2.33-3.05.44-.99.66-1.99.66-3 0-1.73-.66-3.48-1.99-5.23z"],"vertical-bar-chart-asc":["M6 7c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1s1-.45 1-1V8c0-.55-.45-1-1-1zM2 9c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1zm8-5c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1s1-.45 1-1V5c0-.55-.45-1-1-1zm4-4c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],"vertical-bar-chart-desc":["M6 4c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1s1-.45 1-1V5c0-.55-.45-1-1-1zM2 0c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm8 7c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1s1-.45 1-1V8c0-.55-.45-1-1-1zm4 2c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1z"],"vertical-distribution":["M1 2h14c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1s.45 1 1 1zm14 11H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM3 5c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1H3z"],video:["M15 2H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zM5 11V5l6 3-6 3z"],virus:["M11.918 11.107l.737.737.052-.051A1 1 0 0114.2 13.12l-.078.087-1.414 1.414a1 1 0 01-1.492-1.327l.029-.033-.863-.863c-.426.231-.89.402-1.38.502L9 14l.117.007A1 1 0 019 16H7l-.117-.007A1 1 0 017 14v-1.1a4.967 4.967 0 01-1.447-.539l-.846.846.078.087a1 1 0 01-1.492 1.327l-1.414-1.414-.078-.087a1 1 0 011.492-1.327l.744-.744A4.986 4.986 0 013.23 9.5H2a1 1 0 01-1.993.117L0 9.5v-2a1 1 0 011.993-.117L2 7.5h1.025a4.973 4.973 0 01.905-2.405l-.512-.513-.125.125A1 1 0 011.8 3.38l.078-.087 1.414-1.414a1 1 0 011.529 1.277l.573.575a4.969 4.969 0 011.604-.63V2l-.116-.007a1 1 0 010-1.986L7 0h2a1 1 0 01.117 1.993L9 2l.001 1.1c.639.13 1.233.381 1.757.73l.535-.537-.078-.087a1 1 0 011.492-1.327l1.414 1.414.078.087a1 1 0 01-1.492 1.327l-.535.536a4.97 4.97 0 01.803 2.257H14l.007-.117A1 1 0 0116 7.5v2l-.007.117A1 1 0 0114 9.5h-1.229a4.987 4.987 0 01-.853 1.607zM10 9a1 1 0 100 2 1 1 0 000-2zM6.5 5a1.5 1.5 0 100 3 1.5 1.5 0 000-3z"],"volume-down":["M9 2c-.28 0-.53.11-.71.29L5.59 5H3c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h2.59l2.71 2.71c.17.18.42.29.7.29.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm3.57 1.44l-1.59 1.22C11.62 5.61 12 6.76 12 8s-.38 2.39-1.02 3.34l1.59 1.22C13.47 11.27 14 9.7 14 8c0-1.7-.53-3.27-1.43-4.56z"],"volume-off":["M11 2c-.28 0-.53.11-.71.29L7.59 5H5c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h2.59l2.71 2.71c.17.18.42.29.7.29.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],"volume-up":["M7 1.86c-.28 0-.53.11-.71.29l-2.7 2.71H1c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h2.59l2.71 2.71a1.003 1.003 0 001.71-.71v-10c-.01-.55-.46-1-1.01-1zm6.74-.99l-1.58 1.22A9.985 9.985 0 0114 7.86c0 2.16-.69 4.15-1.85 5.78l1.58 1.22c1.42-1.97 2.26-4.38 2.26-7 .01-2.61-.84-5.02-2.25-6.99zM8.98 4.52C9.62 5.48 10 6.63 10 7.86s-.38 2.39-1.02 3.34l1.59 1.22c.9-1.29 1.43-2.86 1.43-4.56 0-1.7-.53-3.27-1.43-4.56L8.98 4.52z"],walk:["M13 8h-2c-.16 0-.31-.05-.44-.11v.01l-1.02-.51-.37 1.86 1.38.92-.01.02c.27.17.46.46.46.81v4c0 .55-.45 1-1 1s-1-.45-1-1v-3.46l-1.27-.85-1.8 4.67h-.01A.98.98 0 015 16c-.55 0-1-.45-1-1 0-.13.03-.25.07-.36h-.01L7.39 6H5.62l-.73 1.45h-.01C4.72 7.77 4.39 8 4 8c-.55 0-1-.45-1-1 0-.16.05-.31.11-.44H3.1l1-2h.01c.17-.33.5-.56.89-.56h3.16l.29-.75C8.17 2.9 8 2.47 8 2c0-1.1.9-2 2-2s2 .9 2 2c0 1-.73 1.82-1.69 1.97l-.5 1.32 1.43.71H13c.55 0 1 .45 1 1s-.45 1-1 1z"],"warning-sign":["M15.84 13.5l.01-.01-7-12-.01.01c-.17-.3-.48-.5-.85-.5s-.67.2-.85.5l-.01-.01-7 12 .01.01c-.09.15-.15.31-.15.5 0 .55.45 1 1 1h14c.55 0 1-.45 1-1 0-.19-.06-.35-.15-.5zm-6.85-.51h-2v-2h2v2zm0-3h-2v-5h2v5z"],"waterfall-chart":["M8 7c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zm-4 4h1c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1zm7-6c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1s-1 .45-1 1v1c0 .55.45 1 1 1zm4-3h-1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm0 10H2V3c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],waves:["M3 1a1 1 0 01.894.553c.102.202.393.607.779.957.419.381.72.49.827.49.108 0 .408-.109.827-.49.386-.35.677-.755.779-.957a1 1 0 011.788 0c.102.202.393.607.779.957.419.381.72.49.827.49.108 0 .408-.109.827-.49.386-.35.677-.755.779-.957a1 1 0 011.788 0c.173.344.38.75.637 1.072.277.347.437.375.469.375a1 1 0 110 2c-.968 0-1.642-.64-2.03-1.125a4.755 4.755 0 01-.076-.097 6.093 6.093 0 01-.221.212C12.175 4.442 11.393 5 10.5 5c-.892 0-1.675-.558-2.173-1.01A6.243 6.243 0 018 3.67c-.105.11-.214.217-.327.32C7.175 4.442 6.393 5 5.5 5c-.892 0-1.675-.558-2.173-1.01a6.119 6.119 0 01-.221-.212l-.075.097C2.64 4.36 1.968 5 1 5a1 1 0 010-2c.032 0 .191-.028.47-.375.256-.321.463-.728.636-1.072A1 1 0 013 1zm0 5a1 1 0 01.894.553c.102.202.393.607.779.957.419.381.72.49.827.49.108 0 .408-.109.827-.49.386-.35.677-.755.779-.957a1 1 0 011.788 0c.102.202.393.607.779.957.419.381.72.49.827.49.108 0 .408-.109.827-.49.386-.35.677-.755.779-.957a1 1 0 011.788 0c.173.344.38.75.637 1.072.277.347.437.375.469.375a1 1 0 110 2c-.968 0-1.642-.639-2.03-1.125a4.726 4.726 0 01-.076-.097 6.093 6.093 0 01-.221.212c-.498.452-1.28 1.01-2.173 1.01-.892 0-1.675-.558-2.173-1.01A6.243 6.243 0 018 8.67c-.105.11-.214.217-.327.32C7.175 9.442 6.393 10 5.5 10c-.892 0-1.675-.558-2.173-1.01a6.119 6.119 0 01-.221-.212l-.075.097C2.64 9.36 1.968 10 1 10a1 1 0 010-2c.032 0 .191-.028.47-.375.256-.321.463-.728.636-1.072A1 1 0 013 6zm.894 5.553a1 1 0 00-1.788 0c-.173.344-.38.75-.637 1.072-.278.347-.437.375-.469.375a1 1 0 100 2c.968 0 1.642-.639 2.03-1.125a4.9 4.9 0 00.076-.097c.072.073.146.143.221.212.498.452 1.28 1.01 2.173 1.01.892 0 1.675-.558 2.173-1.01.113-.103.222-.21.327-.32.105.11.214.217.327.32.498.452 1.28 1.01 2.173 1.01.892 0 1.675-.558 2.173-1.01.075-.069.149-.14.221-.212a4.9 4.9 0 00.075.097C13.36 14.36 14.032 15 15 15a1 1 0 100-2c-.032 0-.191-.028-.47-.375-.256-.321-.463-.728-.636-1.072a1 1 0 00-1.788 0c-.102.202-.393.607-.779.957-.419.381-.72.49-.827.49-.108 0-.408-.109-.827-.49-.386-.35-.677-.755-.779-.957a1 1 0 00-1.788 0c-.102.202-.393.607-.779.957-.419.381-.72.49-.827.49-.108 0-.408-.109-.827-.49-.386-.35-.677-.755-.779-.957z"],widget:["M13 11h2V5h-2v6zM3 5H1v6h2V5zm11-1c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM2 12c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm12 0c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM5 3h6V1H5v2zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm3 15h6v-2H5v2z"],"widget-button":["M1 3h14c.55 0 1 .45 1 1v8c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V4c0-.55.45-1 1-1zm1 2v6h12V5H2zm3 4c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm3 0c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm3 0c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"widget-footer":["M14 0H2c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H3v-3h10v3zm0-4H3V2h10v8z"],"widget-header":["M14 0H2c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 14H3V6h10v8zm0-9H3V2h10v3z"],wind:["M10 4a2 2 0 112 2H4a1 1 0 000 2h8a4 4 0 10-4-4 1 1 0 002 0zM1 9a1 1 0 100 2h7.5a1.5 1.5 0 010 3c-.749 0-1.386-.538-1.52-1.199a1 1 0 10-1.96.398C5.35 14.82 6.83 16 8.5 16a3.5 3.5 0 100-7H1z"],wrench:["M15.83 3.7l-3.06 3.05-2.84-.7-.7-2.83L12.29.17a5.004 5.004 0 00-4.83 1.29 4.967 4.967 0 00-1.12 5.36L.58 12.58c-.36.36-.58.86-.58 1.41 0 1.1.9 2 2 2 .55 0 1.05-.22 1.41-.59l5.77-5.77c1.79.69 3.91.33 5.35-1.12 1.32-1.3 1.74-3.15 1.3-4.81z"],"zoom-in":["M7.99 5.99v-2c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1h-2zm7.56 7.44l-2.67-2.68a6.94 6.94 0 001.11-3.76c0-3.87-3.13-7-7-7s-7 3.13-7 7 3.13 7 7 7c1.39 0 2.68-.42 3.76-1.11l2.68 2.67a1.498 1.498 0 102.12-2.12zm-8.56-1.44c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],"zoom-out":["M3.99 5.99c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1h-6zm11.56 7.44l-2.67-2.68a6.94 6.94 0 001.11-3.76c0-3.87-3.13-7-7-7s-7 3.13-7 7 3.13 7 7 7c1.39 0 2.68-.42 3.76-1.11l2.68 2.67a1.498 1.498 0 102.12-2.12zm-8.56-1.44c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],"zoom-to-fit":["M11 10a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42L12.59 8 11.3 9.29c-.19.18-.3.43-.3.71zM1 5c.55 0 1-.45 1-1V2h2c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v3c0 .55.45 1 1 1zm4 1a1.003 1.003 0 00-1.71-.71l-2 2C1.11 7.47 1 7.72 1 8c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L3.41 8 4.7 6.71c.19-.18.3-.43.3-.71zm1-1c.28 0 .53-.11.71-.29L8 3.41 9.29 4.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-2-2C8.53 1.11 8.28 1 8 1s-.53.11-.71.29l-2 2A1.003 1.003 0 006 5zm9 6c-.55 0-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1zm0-11h-3c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zM4 14H2v-2c0-.55-.45-1-1-1s-1 .45-1 1v3c0 .55.45 1 1 1h3c.55 0 1-.45 1-1s-.45-1-1-1zm6-3c-.28 0-.53.11-.71.29L8 12.59 6.71 11.3A.965.965 0 006 11a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 0010 11z"]},i={add:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm5-9h-4V5c0-.55-.45-1-1-1s-1 .45-1 1v4H5c-.55 0-1 .45-1 1s.45 1 1 1h4v4c0 .55.45 1 1 1s1-.45 1-1v-4h4c.55 0 1-.45 1-1s-.45-1-1-1z"],"add-clip":["M15 0a1 1 0 011 1v3h3a1 1 0 110 2h-3v3a1 1 0 11-2 0V6h-3a1 1 0 110-2h3V1a1 1 0 011-1zM1 4a1 1 0 00-1 1v4a1 1 0 002 0V6h3a1 1 0 000-2H1zM0 19a1 1 0 001 1h4a1 1 0 100-2H2v-3a1 1 0 10-2 0v4zm15 1h-4a1 1 0 110-2h3v-3a1 1 0 112 0v4a1 1 0 01-1 1zm-7-5a3 3 0 100-6 3 3 0 000 6z"],"add-column-left":["M4 11h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1H8V7c0-.55-.45-1-1-1s-1 .45-1 1v2H4c-.55 0-1 .45-1 1s.45 1 1 1zM19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-7 18H2V2h10v16zm6 0h-5V2h5v16z"],"add-column-right":["M10 11h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1h-2V7c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1zm9-11H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM7 18H2V2h5v16zm11 0H8V2h10v16z"],"add-location":["M10 0a1 1 0 010 2 8 8 0 108 8 1 1 0 012 0c0 5.523-4.477 10-10 10S0 15.523 0 10 4.477 0 10 0zm0 6a4 4 0 110 8 4 4 0 010-8zm6-6c.6 0 1 .4 1 1v2h2c.6 0 1 .4 1 1s-.4 1-1 1h-2v2c0 .6-.4 1-1 1s-1-.4-1-1V5h-2c-.6 0-1-.4-1-1 0-.5.4-1 1-1h2V1c0-.6.4-1 1-1z"],"add-row-bottom":["M19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2V8h16v10zm0-11H2V2h16v5zM7 14h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1h-2v-2c0-.55-.45-1-1-1s-1 .45-1 1v2H7c-.55 0-1 .45-1 1s.45 1 1 1z"],"add-row-top":["M7 8h2v2c0 .55.45 1 1 1s1-.45 1-1V8h2c.55 0 1-.45 1-1s-.45-1-1-1h-2V4c0-.55-.45-1-1-1s-1 .45-1 1v2H7c-.55 0-1 .45-1 1s.45 1 1 1zm12-8H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2v-5h16v5zm0-6H2V2h16v10z"],"add-to-artifact":["M13 12H1c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zm0 4H1c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zM1 6h9c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm12 2H1c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zm6-4h-2V2c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V6h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"add-to-folder":["M.01 10V6H20v10c0 .55-.45 1-1 1H9.995v-3.99C9.965 11.332 8.635 10 6.987 10H.01zM19 3c.55 0 1 .45.99 1v1H0V2c0-.55.45-1 1-1h5.997c.28 0 .53.11.71.29L9.414 3H19zM6.987 12c.55 0 .999.45 1.009 1.01v5c0 .55-.45 1-1 1s-.999-.45-.999-1v-2.59l-4.288 4.29a1.003 1.003 0 01-1.42-1.42L4.579 14H1.989c-.55 0-1-.45-1-1s.45-1 1-1h4.998z"],airplane:["M20 2c0-1.1-.9-2-2-2-.55 0-1.05.22-1.41.59l-4.84 4.84L2 1 1 3l7.53 5.64L4.17 13H1l-1 1 4 2 2 4 1-1v-3.17l4.36-4.36L17 19l2-1-4.43-9.74 4.84-4.84c.37-.37.59-.87.59-1.42z"],"align-center":["M5 5c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1H5zM1 3h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm12 12c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1s.45 1 1 1h6zm4 2H3c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm2-8H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],"align-justify":["M1 3h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm18 14H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0-12H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0 4H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0 4H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],"align-left":["M1 7h10c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm0-4h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm14 14H1c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zm4-8H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM1 15h6c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1z"],"align-right":["M19 17H5c-.55 0-1 .45-1 1s.45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1zM1 3h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm18 10h-6c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0-4H9c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1z"],"alignment-bottom":["M12 16h4c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1h-4c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1zm7 2H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM4 16h4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1z"],"alignment-horizontal-center":["M19 9h-2V7c0-.55-.45-1-1-1h-4c-.55 0-1 .45-1 1v2H9V3c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v6H1c-.55 0-1 .45-1 1s.45 1 1 1h2v6c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-6h2v2c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"alignment-left":["M1 0C.45 0 0 .45 0 1v18c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm11 11H5c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1zm7-8H5c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"alignment-right":["M19 0c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm-4 11H8c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1zm0-8H1c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"alignment-top":["M8 4H4c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm11-4H1C.45 0 0 .45 0 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm-3 4h-4c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],"alignment-vertical-center":["M17 3h-6V1c0-.55-.45-1-1-1S9 .45 9 1v2H3c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h6v2H7c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1h-2V9h6c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],annotation:["M9.41 13.41l7.65-7.65-2.83-2.83-7.65 7.65 2.83 2.83zm10-10c.37-.36.59-.86.59-1.41 0-1.1-.9-2-2-2-.55 0-1.05.22-1.41.59l-1.65 1.65 2.83 2.83 1.64-1.66zM18 18H2V2h8.93l2-2H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V7.07l-2 2V18zM4 16l4.41-1.59-2.81-2.79L4 16z"],antenna:["M2.01 10.758a8.025 8.025 0 001.01 3.204l.02.035c.034.058.061.117.084.178.163.44.054.951-.33 1.239-.435.328-1.059.242-1.342-.224a9.797 9.797 0 01-.221-.383 10 10 0 1117.48.106c-.269.474-.89.58-1.335.267-.392-.275-.518-.783-.37-1.228a1.19 1.19 0 01.078-.18l.019-.036A8.026 8.026 0 102.01 10.758zm4.272.772a1.464 1.464 0 01.091.32c.07.425-.052.87-.402 1.128-.44.325-1.068.235-1.316-.252a6 6 0 1110.734-.09c-.24.492-.867.593-1.312.275-.354-.253-.483-.695-.42-1.122a1.462 1.462 0 01.085-.321 4.021 4.021 0 00-5.87-4.878 4.02 4.02 0 00-1.59 4.94zm4.712 2.583A.999.999 0 0011 14v-4a1 1 0 10-2 0v4c0 .038.002.076.006.113l-3.753 4.223a1 1 0 001.494 1.328L10 16.005l3.252 3.66a1 1 0 101.495-1.33l-3.753-4.222z"],"app-header":["M19 0a1 1 0 011 1v18a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1h18zM8 6a1 1 0 00-1.993-.117L6 6v8a1 1 0 001.993.117L8 14v-3h4v3a1 1 0 001.993.117L14 14V6a1 1 0 00-1.993-.117L12 6v3H8V6z"],application:["M3.5 9h9c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-9c-.28 0-.5.22-.5.5s.22.5.5.5zm0 2h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-5c-.28 0-.5.22-.5.5s.22.5.5.5zM19 1H1c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm-1 16H2V6h16v11zM3.5 13h7c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-7c-.28 0-.5.22-.5.5s.22.5.5.5z"],applications:["M15 5H1c-.55 0-1 .45-1 1v13c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-1 13H2V8h12v10zM3.5 10h7c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-7c-.28 0-.5.22-.5.5s.22.5.5.5zm0 2h3c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-3c-.28 0-.5.22-.5.5s.22.5.5.5zm0 2h5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5h-5c-.28 0-.5.22-.5.5s.22.5.5.5zM19 0H5c-.55 0-1 .45-1 1v3h2V3h12v10h-1v2h2c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],archive:["M16.434 0a1 1 0 01.857.486L20 5v14a1 1 0 01-1 1H1a1 1 0 01-1-1V5L2.709.486A1 1 0 013.566 0h12.868zM10 8c-.55 0-1 .45-1 1v4.58l-1.29-1.29-.081-.073A.996.996 0 007 11.99a1.003 1.003 0 00-.71 1.71l3 3 .096.084c.168.13.38.206.614.206.28 0 .53-.11.71-.29l3-3 .084-.096a1.003 1.003 0 00-1.504-1.324L11 13.58V9l-.007-.116A1.004 1.004 0 0010 8zm6-6H4L2 5.002h16L16 2z"],"area-of-interest":["M5 4.664C5 2.09 7.241 0 10 0s4.99 2.091 5 4.664C15 7.245 10 14 10 14S5 7.245 5 4.664zM8 5a2 2 0 104.001-.001A2 2 0 008 5zM.504 12.132l4.302-2.458c.322.576.662 1.145.995 1.681l.025.04-3.294 1.881L6.468 18h7.064l3.936-4.724-3.293-1.882.024-.039c.333-.536.673-1.105.995-1.681l4.302 2.458a1 1 0 01.272 1.508l-5 6A1 1 0 0114 20H6a1 1 0 01-.768-.36l-5-6a1 1 0 01.272-1.508z"],array:["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm5 9a1 1 0 110 2 1 1 0 010-2zM6 9a1 1 0 110 2 1 1 0 010-2zm8 0a1 1 0 110 2 1 1 0 010-2z"],"array-boolean":["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm10 7a1 1 0 01.993.883L16 8v4a1 1 0 01-.883.993L15 13H5a1 1 0 01-.993-.883L4 12V8a1 1 0 01.883-.993L5 7h10zm0 1h-5v4h5V8z"],"array-date":["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm2.5 5a.5.5 0 01.5.5V6h4v-.5a.5.5 0 01.5-.5h1a.5.5 0 01.5.5V6h1a1 1 0 01.993.883L16 7v7a1 1 0 01-.883.993L15 15H5a1 1 0 01-.993-.883L4 14V7a1 1 0 01.883-.993L5 6h1v-.5a.5.5 0 01.5-.5h1zM15 9H5v5h10V9z"],"array-numeric":["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm8.995 6.09c.32 0 .603.047.85.14a1.679 1.679 0 011.015.985c.09.23.135.482.135.755 0 .287-.063.552-.19.795a1.642 1.642 0 01-.57.615v.02l.101.05c.068.039.138.09.209.155.107.097.203.215.29.355a2.09 2.09 0 01.3 1.09c0 .313-.053.597-.16.85a1.898 1.898 0 01-1.12 1.065 2.42 2.42 0 01-.85.145c-.533 0-.99-.127-1.37-.38a1.702 1.702 0 01-.73-1.08c-.013-.067.013-.11.08-.13l.87-.2.041-.003c.038.004.064.028.079.073.073.2.193.37.36.51.167.14.39.21.67.21.32 0 .567-.095.74-.285.173-.19.26-.432.26-.725 0-.347-.1-.618-.3-.815-.2-.197-.47-.295-.81-.295h-.29l-.044-.006c-.037-.013-.056-.044-.056-.094V9.1l.006-.044c.013-.037.044-.056.094-.056h.27l.145-.008a.925.925 0 00.575-.262c.18-.18.27-.42.27-.72 0-.273-.08-.495-.24-.665-.16-.17-.383-.255-.67-.255-.253 0-.453.063-.6.19-.147.127-.25.297-.31.51-.02.06-.06.083-.12.07l-.85-.2-.042-.015c-.035-.02-.048-.055-.038-.105a1.684 1.684 0 01.645-1.035c.17-.13.37-.232.6-.305.23-.073.482-.11.755-.11zm-7.99.11l.044.006c.037.013.056.044.056.094v6.6l-.006.044c-.013.037-.044.056-.094.056h-.92l-.044-.006c-.037-.013-.056-.044-.056-.094V7.54h-.02l-1.04.73-.04.02c-.047.016-.07-.01-.07-.08V7.19l.008-.051a.196.196 0 01.062-.089l1.09-.79.051-.033a.295.295 0 01.129-.027h.85zm3.34-.11c.32 0 .603.05.85.15.247.1.455.235.625.405.17.17.3.37.39.6.09.23.135.478.135.745 0 .307-.057.588-.17.845a3.16 3.16 0 01-.47.745l-1.98 2.4V12h2.52l.044.006c.037.013.056.044.056.094v.8l-.006.044c-.013.037-.044.056-.094.056h-3.82l-.044-.006c-.037-.013-.056-.044-.056-.094v-.75l.006-.05a.165.165 0 01.044-.08l2.4-2.99.124-.167c.077-.11.143-.222.196-.333.08-.167.12-.347.12-.54a.92.92 0 00-.235-.64c-.157-.173-.378-.26-.665-.26-.273 0-.487.077-.64.23-.153.153-.247.36-.28.62-.013.067-.05.093-.11.08l-.88-.18-.043-.015c-.035-.02-.047-.055-.037-.105a1.78 1.78 0 01.56-1.115c.167-.157.372-.282.615-.375a2.35 2.35 0 01.845-.14z"],"array-string":["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm2.012 6c.643 0 1.203.266 1.68.797.477.53.715 1.246.715 2.145a4.472 4.472 0 01-.965 2.814c-.644.83-1.66 1.5-3.047 2.011v-.581l.26-.104a3.87 3.87 0 001.624-1.285c.457-.632.686-1.29.686-1.971 0-.148-.023-.256-.07-.326-.023-.047-.054-.07-.093-.07-.038 0-.1.031-.186.093-.248.179-.558.268-.93.268-.45 0-.843-.18-1.18-.541A1.817 1.817 0 015 7.965c0-.527.194-.986.581-1.378A1.934 1.934 0 017.011 6zm5.593 0c.643 0 1.203.266 1.68.797.477.53.715 1.246.715 2.145a4.472 4.472 0 01-.965 2.814c-.644.83-1.659 1.5-3.047 2.011v-.581l.26-.104a3.87 3.87 0 001.624-1.285c.457-.632.686-1.29.686-1.971 0-.148-.023-.256-.07-.326-.023-.047-.054-.07-.093-.07-.038 0-.1.031-.186.093-.248.179-.558.268-.93.268-.45 0-.843-.18-1.18-.541a1.817 1.817 0 01-.506-1.285c0-.527.194-.986.581-1.378A1.934 1.934 0 0112.604 6z"],"array-timestamp":["M19 0a1 1 0 01.993.883L20 1v18a1 1 0 01-.883.993L19 20h-4a1 1 0 01-.117-1.993L15 18h3V2h-3a1 1 0 01-.993-.883L14 1a1 1 0 01.883-.993L15 0h4zM5 0a1 1 0 01.117 1.993L5 2H2v16h3a1 1 0 01.993.883L6 19a1 1 0 01-.883.993L5 20H1a1 1 0 01-.993-.883L0 19V1A1 1 0 01.883.007L1 0h4zm5 4a6 6 0 110 12 6 6 0 010-12zm0 1a5 5 0 100 10 5 5 0 000-10zm2.854 2.146a.5.5 0 01.057.638l-.057.07-2.5 2.5a.5.5 0 01-.638.057l-.07-.057-1.5-1.5a.5.5 0 01.638-.765l.07.057L10 9.293l2.146-2.147a.5.5 0 01.708 0z"],"arrow-bottom-left":["M18 3a1.003 1.003 0 00-1.71-.71L4 14.59V7c0-.55-.45-1-1-1s-1 .45-1 1v10c0 .55.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1H5.41l12.3-12.29c.18-.18.29-.43.29-.71z"],"arrow-bottom-right":["M17 6c-.55 0-1 .45-1 1v7.59L3.71 2.29a1.003 1.003 0 00-1.42 1.42L14.59 16H7c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1z"],"arrow-down":["M16 11c-.3 0-.5.1-.7.3L11 15.6V2c0-.5-.4-1-1-1s-1 .5-1 1v13.6l-4.3-4.3c-.2-.2-.4-.3-.7-.3-.5 0-1 .4-1 1 0 .3.1.5.3.7l6 6c.2.2.4.3.7.3s.5-.1.7-.3l6-6c.2-.2.3-.4.3-.7 0-.6-.5-1-1-1z"],"arrow-left":["M18 9H4.41L8.7 4.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-6 6c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l6 6a1.003 1.003 0 001.42-1.42L4.41 11H18c.55 0 1-.45 1-1s-.45-1-1-1z"],"arrow-right":["M18.71 9.29l-6-6a1.003 1.003 0 00-1.42 1.42L15.59 9H2c-.55 0-1 .45-1 1s.45 1 1 1h13.59l-4.29 4.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l6-6c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"arrow-top-left":["M17.71 16.29L5.41 4H13c.55 0 1-.45 1-1s-.45-1-1-1H3c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1s1-.45 1-1V5.41L16.29 17.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"arrow-top-right":["M17 2H7c-.55 0-1 .45-1 1s.45 1 1 1h7.59L2.29 16.29a1.003 1.003 0 001.42 1.42L16 5.41V13c0 .55.45 1 1 1s1-.45 1-1V3c0-.55-.45-1-1-1z"],"arrow-up":["M16.7 7.3l-6-6c-.2-.2-.4-.3-.7-.3s-.5.1-.7.3l-6 6c-.2.2-.3.4-.3.7 0 .6.5 1 1 1 .3 0 .5-.1.7-.3L9 4.4V18c0 .5.4 1 1 1s1-.5 1-1V4.4l4.3 4.3c.2.2.4.3.7.3.5 0 1-.4 1-1 0-.3-.1-.5-.3-.7z"],"arrows-horizontal":["M19.7 9.3l-5-5c-.2-.2-.4-.3-.7-.3-.6 0-1 .4-1 1 0 .3.1.5.3.7L16.6 9H3.4l3.3-3.3c.2-.2.3-.4.3-.7 0-.6-.4-1-1-1-.3 0-.5.1-.7.3l-5 5c-.2.2-.3.4-.3.7s.1.5.3.7l5 5c.2.2.4.3.7.3.6 0 1-.4 1-1 0-.3-.1-.5-.3-.7L3.4 11h13.2l-3.3 3.3c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3l5-5c.2-.2.3-.4.3-.7s-.1-.5-.3-.7z"],"arrows-vertical":["M15 13c-.3 0-.5.1-.7.3L11 16.6V3.4l3.3 3.3c.2.2.4.3.7.3.6 0 1-.4 1-1 0-.3-.1-.5-.3-.7l-5-5c-.2-.2-.4-.3-.7-.3s-.5.1-.7.3l-5 5c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3L9 3.4v13.2l-3.3-3.3c-.2-.2-.4-.3-.7-.3-.6 0-1 .4-1 1 0 .3.1.5.3.7l5 5c.2.2.4.3.7.3s.5-.1.7-.3l5-5c.2-.2.3-.4.3-.7 0-.5-.4-1-1-1z"],asterisk:["M18.52 14.17l.01-.02L11.89 10l6.64-4.15-.01-.02A.97.97 0 0019 5c0-.55-.45-1-1-1-.2 0-.37.07-.52.17l-.01-.02L11 8.2V1c0-.55-.45-1-1-1S9 .45 9 1v7.2L2.53 4.15l-.01.02A.922.922 0 002 4c-.55 0-1 .45-1 1 0 .36.2.66.48.83l-.01.02L8.11 10l-6.64 4.15.01.02A.97.97 0 001 15c0 .55.45 1 1 1 .2 0 .37-.07.52-.17l.01.02L9 11.8V19c0 .55.45 1 1 1s1-.45 1-1v-7.2l6.47 4.04.01-.02c.15.11.32.18.52.18.55 0 1-.45 1-1 0-.36-.2-.66-.48-.83z"],"automatic-updates":["M10 18c-4.42 0-8-3.58-8-8 0-2.52 1.18-4.76 3-6.22V5c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1H2c-.55 0-1 .45-1 1s.45 1 1 1h2.06C1.61 3.82 0 6.71 0 10c0 5.52 4.48 10 10 10 .55 0 1-.45 1-1s-.45-1-1-1zm0-16c1.64 0 3.15.49 4.42 1.34l1.43-1.43A9.869 9.869 0 0010 0c-.55 0-1 .45-1 1s.45 1 1 1zm10 8c0-1.13-.2-2.21-.54-3.22L17.84 8.4A7.962 7.962 0 0115 16.22V15c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1h-2.06c2.45-1.82 4.06-4.71 4.06-8zm0-7a1.003 1.003 0 00-1.71-.71L12 8.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l7-7c.18-.18.29-.43.29-.71z"],backlink:["M18.387 19.79l-.094-.083L14 15.415V18a1 1 0 01-2 0l.003-5.075.017-.126.03-.111.044-.111.052-.098.067-.096.08-.09a1.01 1.01 0 01.112-.097l.11-.071.114-.054.105-.035.15-.03L13 12h5a1 1 0 110 2h-2.585l4.292 4.293a1 1 0 01-1.32 1.497zM7.036 9.136l-4.45 4.45-.117.127a2 2 0 002.818 2.818l.127-.117 4.45-4.449a4 4 0 01-.885 3.704l-.15.16-2 2A4 4 0 011.02 12.33l.15-.16 2-2a3.998 3.998 0 013.865-1.035zm6.671-3.843a1 1 0 01.083 1.32l-.083.094-7 7a1 1 0 01-1.497-1.32l.083-.094 7-7a1 1 0 011.414 0zm4.121-4.121a4 4 0 01.151 5.497l-.15.16-2 2a3.998 3.998 0 01-3.864 1.036l4.45-4.45.116-.128a2 2 0 00-2.818-2.818l-.127.117-4.45 4.45a4 4 0 01.885-3.705l.15-.16 2-2a4 4 0 015.657 0z"],badge:["M16.94 5.73c-.19-1.41.62-2.52 1.38-3.59L17.03.65C14.89 1.76 11.88 1.48 10 0 8.12 1.48 5.11 1.76 2.97.65L1.68 2.14c.76 1.07 1.57 2.18 1.38 3.59C2.68 8.59 0 10.94 1.4 14.08c.56 1.43 1.81 2.37 3.4 2.75 1.95.46 4.4.91 5.2 3.17.8-2.26 3.25-2.71 5.2-3.17 1.6-.38 2.84-1.32 3.4-2.75 1.4-3.14-1.28-5.49-1.66-8.35z"],"ban-circle":["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm5 11H5c-.55 0-1-.45-1-1s.45-1 1-1h10c.55 0 1 .45 1 1s-.45 1-1 1z"],"bank-account":["M19.2 8.02l-.78-.18C18.03 6.4 17.2 5.08 16.08 4l.5-2.28c.11-.42-.22-.78-.61-.72-1.06.12-2 .54-2.67 1.26-1.06-.42-2.34-.66-3.56-.66-3.12 0-5.79 1.5-7.4 3.72-.23-.05-.45-.11-.67-.11C.72 5.21 0 5.98 0 7c0 .72.39 1.32.95 1.62-.06.42-.12.9-.12 1.38 0 2.16.89 4.08 2.28 5.58l-.33 2.04c-.11.72.45 1.38 1.12 1.38h.72c.56 0 1-.42 1.11-1.02l.06-.48c1.17.54 2.5.9 3.95.9 1.39 0 2.78-.3 3.95-.9l.06.48c.11.6.56 1.02 1.11 1.02h.72c.67 0 1.22-.66 1.11-1.38l-.33-1.98c.78-.78 1.34-1.74 1.73-2.76l1-.24c.5-.12.89-.6.89-1.2V9.22c.11-.6-.28-1.08-.78-1.2zM15 10c-.6 0-1-.7-1-1.5S14.4 7 15 7s1 .7 1 1.5-.4 1.5-1 1.5zM7.55 5.83a.99.99 0 01-1.38-.28.99.99 0 01.28-1.38c2.34-1.56 4.77-1.56 7.11 0 .46.31.58.93.28 1.39-.31.46-.93.58-1.39.28-1.67-1.12-3.23-1.12-4.9-.01z"],barcode:["M6 16.98h2v-14H6v14zm3 0h1v-14H9v14zm-6 0h2v-14H3v14zm-3 0h2v-14H0v14zm16 0h2v-14h-2v14zm-4 0h1v-14h-1v14zm7-14v14h1v-14h-1zm-5 14h1v-14h-1v14z"],blank:[],"blocked-person":["M11.55 15.92c-1.48-.65-1.28-1.05-1.33-1.59-.01-.07-.01-.15-.01-.23.51-.45.92-1.07 1.19-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.34-.07.54-.44.61-.78.06-.11.14-.35.17-.62C10.33 9.42 8.92 7.38 8.92 5c0-.3.05-.58.09-.87-.33-.08-.67-.13-.99-.13-.79 0-1.68.25-2.31.73-.61.47-1.07 1.13-1.29 1.86-.05.16-.09.33-.11.5-.12.6-.17 1.51-.17 2.14v.08c-.24.09-.45.32-.49.83-.04.39.12.73.2.87.08.35.28.72.63.78.04.17.09.33.15.48 0 .01.01.02.01.03l.01.01c.27.72.7 1.35 1.22 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.38 1.59C3 16.56.77 17.26.32 18.31-.15 19.38.04 20 .04 20h15.95s.18-.62-.27-1.67c-.46-1.06-2.69-1.75-4.17-2.41zM14.97 0c-2.78 0-5.03 2.24-5.03 5s2.25 5 5.03 5S20 7.76 20 5s-2.25-5-5.03-5zm-3.03 5c0-1.66 1.35-3 3.02-3 .47 0 .9.11 1.29.3l-4.01 3.99c-.18-.4-.3-.83-.3-1.29zm3.03 3c-.47 0-.9-.11-1.29-.3l4.01-3.99c.19.39.3.82.3 1.29 0 1.66-1.36 3-3.02 3z"],bold:["M14.3 9c.4-.8.7-1.6.7-2.5C15 4 13 2 10.5 2H5c-.6 0-1 .4-1 1v13c0 .6.4 1 1 1h6.5c2.5 0 4.5-2 4.5-4.5 0-1.4-.7-2.7-1.7-3.5zM7 5h3.5c.8 0 1.5.7 1.5 1.5S11.3 8 10.5 8H7V5zm4.5 9H7v-3h4.5c.8 0 1.5.7 1.5 1.5s-.7 1.5-1.5 1.5z"],book:["M3 1v18c0 .55.45 1 1 1h2V0H4c-.55 0-1 .45-1 1zm14-1h-2v8l-2-2-2 2V0H7v20h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],bookmark:["M6 0c-.55 0-1 .45-1 1v18c0 .55.32.68.71.29L9.3 15.7a.996.996 0 011.41 0l3.59 3.59c.38.39.7.26.7-.29v-8-4.5V1c0-.55-.45-1-1-1H6z"],box:["M19.89 6.56l-2.99-6h-.01C16.72.23 16.39 0 16 0H4c-.39 0-.72.23-.89.56H3.1l-3 6h.01C.05 6.69 0 6.84 0 7v12c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V7c0-.16-.05-.31-.11-.44zM11 2h4.38l2 4H11V2zM4.62 2H9v4H2.62l2-4zM18 18H2V8h16v10zM8 12h4c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1z"],briefcase:["M19 5h-4V2c0-.55-.45-1-1-1H6c-.55 0-1 .45-1 1v3H1c-.55 0-1 .45-1 1v5h4v-1h2v1h8v-1h2v1h4V6c0-.55-.45-1-1-1zm-6 0H7V3h6v2zm3 8h-2v-1H6v1H4v-1H0v6c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-6h-4v1z"],"bring-data":["M18 18a1 1 0 010 2H2a1 1 0 010-2h16zM9.995 3.005c.55 0 1 .45 1 .999v9.584l1.29-1.288a1.002 1.002 0 011.42 1.419l-3 2.996a1.015 1.015 0 01-1.42 0l-3-2.997a1.002 1.002 0 011.42-1.419l1.29 1.29V4.013c0-.55.45-1.009 1-1.009zM16 0a1 1 0 110 2 1 1 0 010-2zm-3 0a1 1 0 110 2 1 1 0 010-2zm-3 0a1 1 0 110 2 1 1 0 010-2zM7 0a1 1 0 110 2 1 1 0 010-2zM4 0a1 1 0 110 2 1 1 0 010-2z"],buggy:["M15.836 1.014a1 1 0 011.058.539l2.482 4.962.02-.004a.5.5 0 01.604.49v4.5a.5.5 0 01-.5.5h-3.93a1.5 1.5 0 00-1.248.667l-1.406 2.11A.5.5 0 0112.5 15H8a.5.5 0 01-.354-.146l-2.414-2.415A1.5 1.5 0 004.172 12H.5a.5.5 0 01-.5-.5v-3A.5.5 0 01.5 8h.823L3.072 3.63a1 1 0 01.764-.615l12-2zm.289 3.472l1.231 2.462-2.758.591 1.527-3.053zM14.5 3.264l-1.56 3.12-.252-.638-.825-2.043 2.637-.44zm-9.78 1.63l5.122-.854.988 2.445.899 2.27L10.232 11H7.707L4.854 8.147A.5.5 0 004.5 8H3.477l1.242-3.106zM3 19a3 3 0 100-6 3 3 0 000 6zm14 0a3 3 0 100-6 3 3 0 000 6z"],build:["M19.43 16.67L9.31 7.81l1.47-1.56c.41-.44-.15-.8.15-1.6 1.08-2.76 4.19-2.99 4.19-2.99s.45-.47.87-.92C11.98-1 9.26.7 8.04 1.8L3.83 6.25l-.86.92c-.48.51-.48 1.33 0 1.84l-.87.92c-.48-.51-1.26-.51-1.74 0s-.48 1.33 0 1.84l1.74 1.84c.48.51 1.26.51 1.74 0s.48-1.33 0-1.84l.87-.92c.48.51 1.26.51 1.74 0l1.41-1.49 8.81 10.07c.76.76 2 .76 2.76 0 .76-.76.76-2 0-2.76z"],calculator:["M16 0H4c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM7 18H5v-2h2v2zm0-4H5v-2h2v2zm0-4H5V8h2v2zm4 8H9v-2h2v2zm0-4H9v-2h2v2zm0-4H9V8h2v2zm4 8h-2v-6h2v6zm0-8h-2V8h2v2zm0-4H5V2h10v4z"],calendar:["M15 5c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1s-1 .5-1 1v2c0 .6.4 1 1 1zM5 5c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1s-1 .5-1 1v2c0 .6.4 1 1 1zm13-2h-1v1c0 1.1-.9 2-2 2s-2-.9-2-2V3H7v1c0 1.1-.9 2-2 2s-2-.9-2-2V3H2c-.5 0-1 .5-1 1v14c0 .5.5 1 1 1h16c.5 0 1-.5 1-1V4c0-.5-.5-1-1-1zM7 17H3v-4h4v4zm0-5H3V8h4v4zm5 5H8v-4h4v4zm0-5H8V8h4v4zm5 5h-4v-4h4v4zm0-5h-4V8h4v4z"],camera:["M10 8c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3zm9-4h-3.59L13.7 2.29A.956.956 0 0013 2H7c-.28 0-.53.11-.71.29L4.59 4H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h4.11c1.26 1.24 2.99 2 4.89 2s3.63-.76 4.89-2H19c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zM4 8H2V6h2v2zm6 8c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],"caret-down":["M16 7c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1 0 .24.1.46.24.63l-.01.01 5 6 .01-.01c.19.22.45.37.76.37s.57-.15.76-.37l.01.01 5-6-.01-.01c.14-.17.24-.39.24-.63z"],"caret-left":["M13 4c-.24 0-.46.1-.63.24l-.01-.01-6 5 .01.01c-.22.19-.37.45-.37.76s.15.57.37.76l-.01.01 6 5 .01-.01c.17.14.39.24.63.24.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],"caret-right":["M14 10c0-.31-.15-.57-.37-.76l.01-.01-6-5-.01.01C7.46 4.1 7.24 4 7 4c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1 .24 0 .46-.1.63-.24l.01.01 6-5-.01-.01c.22-.19.37-.45.37-.76z"],"caret-up":["M15.76 12.37l.01-.01-5-6-.01.01C10.57 6.15 10.31 6 10 6s-.57.15-.76.37l-.01-.01-5 6 .01.01c-.14.17-.24.39-.24.63 0 .55.45 1 1 1h10c.55 0 1-.45 1-1 0-.24-.1-.46-.24-.63z"],"cargo-ship":["M12.5 1.25h4a1 1 0 011 1V5h-5V1.25zM2.75 5a.25.25 0 00-.25.25v6H.883a.5.5 0 00-.429.757l1.672 2.787c.17.284.384.533.63.741-.458.057-.959.09-1.506.09a.625.625 0 100 1.25c2.583 0 4.268-.68 5.202-1.146.687.466 1.88 1.146 3.548 1.146 1.65 0 2.837-.666 3.528-1.132l.005.003c.244.131.6.3 1.07.468.938.335 2.321.661 4.147.661a.625.625 0 100-1.25c-.319 0-.622-.01-.91-.03.398-.318.717-.738.914-1.23l.972-2.43a.5.5 0 00-.464-.685H5v-6A.25.25 0 004.75 5h-2zm3.455 11.95a.625.625 0 01.658.041c.569.407 1.597 1.134 3.137 1.134s2.568-.727 3.137-1.134a.625.625 0 01.724-.001l.007.005.045.029c.044.027.114.069.21.12.194.104.493.247.9.392.812.29 2.053.589 3.727.589a.625.625 0 110 1.25c-1.826 0-3.21-.326-4.148-.661a7.894 7.894 0 01-1.069-.468l-.005-.003c-.691.466-1.878 1.132-3.528 1.132-1.667 0-2.861-.68-3.548-1.146-.934.467-2.619 1.146-5.202 1.146a.625.625 0 110-1.25c2.66 0 4.23-.787 4.955-1.176zM17.5 6.25h-5V10h4a1 1 0 001-1V6.25zm-11.25-4a1 1 0 011-1h4V5h-5V2.25zm5 4h-5V9a1 1 0 001 1h4V6.25z"],"cell-tower":["M11.5 8.32c.31-.35.51-.81.51-1.32 0-1.1-.9-2-2-2s-2 .9-2 2c0 .51.2.97.51 1.32L5.06 18.69c-.17.52.11 1.09.63 1.26s1.09-.11 1.26-.63L8.39 15h3.23l1.44 4.32c.17.52.74.81 1.26.63s.81-.74.63-1.26L11.5 8.32zM10.95 13H9.06l.95-2.84.94 2.84zM5.31 10.73a.996.996 0 101.37-1.45c-1.4-1.33-1.28-3.35-.01-4.54.4-.38.43-1.01.05-1.41-.36-.41-1-.43-1.4-.06-2.09 1.95-2.28 5.3-.01 7.46z","M4.6 12.2C3 11.1 2 9 2 7c0-2.1.9-3.9 2.6-5.2.5-.3.5-1 .2-1.4-.3-.5-1-.5-1.4-.2C1.2 1.9-.1 4.2 0 7c.1 2.7 1.4 5.3 3.4 6.8.2.1.4.2.6.2.3 0 .6-.1.8-.4.4-.5.3-1.1-.2-1.4zM13.27 10.69c.38.4 1.01.42 1.41.04 2.27-2.16 2.08-5.51-.01-7.46a.996.996 0 10-1.36 1.46c1.28 1.19 1.39 3.21-.01 4.54-.39.39-.41 1.02-.03 1.42z","M16.6.2c-.4-.3-1.1-.3-1.4.2-.3.4-.3 1.1.2 1.4C17.1 3.1 18 4.9 18 7c0 2-1 4.1-2.6 5.2-.5.3-.6.9-.2 1.4.2.3.5.4.8.4.2 0 .4-.1.6-.2C18.7 12.3 20 9.7 20 7c.09-2.8-1.2-5.1-3.4-6.8z"],changes:["M18 16H2c-1.1 0-2 .9-2 2s.9 2 2 2h16c1.1 0 2-.9 2-2s-.9-2-2-2zM3 5c.28 0 .53-.11.71-.29L5 3.41V13c0 .55.45 1 1 1s1-.45 1-1V3.41L8.29 4.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3C6.53.11 6.28 0 6 0s-.53.11-.71.29l-3 3A1.003 1.003 0 003 5zm7.29 5.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3a1.003 1.003 0 00-1.42-1.42L15 10.59V1c0-.55-.45-1-1-1s-1 .45-1 1v9.59L11.71 9.3A.965.965 0 0011 9a1.003 1.003 0 00-.71 1.71z"],chart:["M7 11v8c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-8l-2 2-4-2zm-7 8c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-8l-6 3v5zM17 7l-3 3v9c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V8.74c-.26.15-.58.26-1 .26-1.92 0-2-2-2-2zm2-6h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.59L10.8 8.78 7.45 7.11v.01C7.31 7.05 7.16 7 7 7s-.31.05-.44.11V7.1l-6 3v.01c-.33.17-.56.5-.56.89 0 .55.45 1 1 1 .16 0 .31-.05.44-.11v.01L7 9.12l3.55 1.78v-.01c.14.06.29.11.45.11.28 0 .53-.11.71-.29L18 4.41V6c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],chat:["M19 0H7c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h5.59l3.71 3.71c.17.18.42.29.7.29.55 0 1-.45 1-1v-3h1c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM7 13c-1.1 0-2-.9-2-2V4H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h1v3a1.003 1.003 0 001.71.71L7.41 16H13c.55 0 1-.45 1-1v-.17L12.17 13H7z"],"chevron-backward":["M8.41 10l5.29-5.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L7 8.59V4c0-.55-.45-1-1-1s-1 .45-1 1v12c0 .55.45 1 1 1s1-.45 1-1v-4.59l5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L8.41 10z"],"chevron-down":["M16 6c-.28 0-.53.11-.71.29L10 11.59l-5.29-5.3a1.003 1.003 0 00-1.42 1.42l6 6c.18.18.43.29.71.29s.53-.11.71-.29l6-6A1.003 1.003 0 0016 6z"],"chevron-forward":["M13 3c-.55 0-1 .45-1 1v4.59l-5.29-5.3a1.003 1.003 0 00-1.42 1.42l5.3 5.29-5.29 5.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l5.29-5.3V16c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1z"],"chevron-left":["M8.41 10l5.29-5.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-6 6c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l6 6a1.003 1.003 0 001.42-1.42L8.41 10z"],"chevron-right":["M13.71 9.29l-6-6a1.003 1.003 0 00-1.42 1.42l5.3 5.29-5.29 5.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l6-6c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"chevron-up":["M16.71 12.29l-6-6C10.53 6.11 10.28 6 10 6s-.53.11-.71.29l-6 6a1.003 1.003 0 001.42 1.42L10 8.41l5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],circle:["M10 0C4.5 0 0 4.5 0 10s4.5 10 10 10 10-4.5 10-10S15.5 0 10 0zm0 18c-4.4 0-8-3.6-8-8s3.6-8 8-8 8 3.6 8 8-3.6 8-8 8z"],"circle-arrow-down":["M14 10c-.28 0-.53.11-.71.29L11 12.59V5c0-.55-.45-1-1-1s-1 .45-1 1v7.59L6.71 10.3A.965.965 0 006 10a1.003 1.003 0 00-.71 1.71l4 4c.18.18.43.29.71.29s.53-.11.71-.29l4-4A1.003 1.003 0 0014 10zM10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"],"circle-arrow-left":["M15 9H7.41L9.7 6.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L7.41 11H15c.55 0 1-.45 1-1s-.45-1-1-1zm-5-9C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"],"circle-arrow-right":["M15.71 9.29l-4-4a1.003 1.003 0 00-1.42 1.42L12.59 9H5c-.55 0-1 .45-1 1s.45 1 1 1h7.59l-2.29 2.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"],"circle-arrow-up":["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm.71-13.71C10.53 4.11 10.28 4 10 4s-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L9 7.41V15c0 .55.45 1 1 1s1-.45 1-1V7.41l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-4-4z"],citation:["M4 1C1.79 1 0 2.79 0 5s1.79 4 4 4c.1 0 .2-.01.3-.02C3.82 11.32 2.53 13 1 13c-.55 0-1 .45-1 1s.45 1 1 1c3.87 0 7-4.48 7-10 0-2.21-1.79-4-4-4zM16 1c-2.21 0-4 1.79-4 4s1.79 4 4 4c.1 0 .2-.01.3-.02C15.82 11.32 14.53 13 13 13c-.55 0-1 .45-1 1s.45 1 1 1c3.87 0 7-4.48 7-10 0-2.21-1.79-4-4-4z"],clean:["M7 0L5 5 0 6.998 5 9l2 5 2-5 5-1.995L9 5zM15 10l-1.5 3.496-3.5 1.499 3.5 1.498L15 20l1.5-3.507L20 15l-3.5-1.504z"],clip:["M0 1a1 1 0 011-1h5a1 1 0 010 2H2v4a1 1 0 01-2 0V1zm1 19a1 1 0 01-1-1v-5a1 1 0 112 0v4h4a1 1 0 110 2H1zm18 0a1 1 0 001-1v-5a1 1 0 10-2 0v4h-4a1 1 0 100 2h5zm0-20a1 1 0 011 1v5a1 1 0 11-2 0V2h-4a1 1 0 110-2h5zm-9 14a4 4 0 100-8 4 4 0 000 8z"],clipboard:["M13 2c0-.55-.45-1-1-1h-.78a1.98 1.98 0 00-3.44 0H7c-.55 0-1 .45-1 1v2h7V2z","M16 2h-2v3H5V2H3c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1z"],cloud:["M15 7c-.12 0-.24.03-.36.04C13.83 4.69 11.62 3 9 3 5.69 3 3 5.69 3 9c0 .05.01.09.01.14A3.98 3.98 0 000 13c0 2.21 1.79 4 4 4h11c2.76 0 5-2.24 5-5s-2.24-5-5-5z"],"cloud-download":["M15 4c-.12 0-.24.03-.36.04C13.83 1.69 11.62 0 9 0 5.69 0 3 2.69 3 6c0 .05.01.09.01.14A3.98 3.98 0 000 10c0 2.21 1.79 4 4 4h.78c.55-.61 1.34-1 2.22-1v-2c0-1.66 1.34-3 3-3s3 1.34 3 3v2c.88 0 1.66.38 2.2.98C17.87 13.87 20 11.69 20 9c0-2.76-2.24-5-5-5zm-2 11c-.28 0-.53.11-.71.29L11 16.59V11c0-.55-.45-1-1-1s-1 .45-1 1v5.59L7.71 15.3A.965.965 0 007 15a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 0013 15z"],"cloud-upload":["M10.71 10.29c-.18-.18-.43-.29-.71-.29s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L9 13.41V19c0 .55.45 1 1 1s1-.45 1-1v-5.59l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3zM15 4c-.12 0-.24.03-.36.04C13.83 1.69 11.62 0 9 0 5.69 0 3 2.69 3 6c0 .05.01.09.01.14A3.98 3.98 0 000 10c0 2.21 1.79 4 4 4 0-.83.34-1.58.88-2.12l3-3a2.993 2.993 0 014.24 0l3 3-.01.01c.52.52.85 1.23.87 2.02C18.28 13.44 20 11.42 20 9c0-2.76-2.24-5-5-5z"],code:["M6 6a1.003 1.003 0 00-1.71-.71l-4 4C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L2.41 10 5.7 6.71c.19-.18.3-.43.3-.71zm6-4c-.46 0-.83.31-.95.73l-4 14c-.02.09-.05.17-.05.27 0 .55.45 1 1 1 .46 0 .83-.31.95-.73l4-14c.02-.09.05-.17.05-.27 0-.55-.45-1-1-1zm7.71 7.29l-4-4a1.003 1.003 0 00-1.42 1.42l3.3 3.29-3.29 3.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"code-block":["M19 5h-2V3c0-.55-.45-1-1-1h-4c-.55 0-1 .45-1 1v2H9V3c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v2H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zM8.71 15.29a1.003 1.003 0 01-1.42 1.42l-4-4C3.11 12.53 3 12.28 3 12s.11-.53.29-.71l4-4a1.003 1.003 0 011.42 1.42L5.41 12l3.3 3.29zm8-2.58l-4 4a1.003 1.003 0 01-1.42-1.42l3.3-3.29-3.29-3.29A.965.965 0 0111 8a1.003 1.003 0 011.71-.71l4 4c.18.18.29.43.29.71s-.11.53-.29.71z"],cog:["M19 8h-2.31c-.14-.46-.33-.89-.56-1.3l1.7-1.7a.996.996 0 000-1.41l-1.41-1.41a.996.996 0 00-1.41 0l-1.7 1.7c-.41-.22-.84-.41-1.3-.55V1c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v2.33c-.48.14-.94.34-1.37.58L5 2.28a.972.972 0 00-1.36 0L2.28 3.64c-.37.38-.37.99 0 1.36L3.9 6.62c-.24.44-.44.89-.59 1.38H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h2.31c.14.46.33.89.56 1.3L2.17 15a.996.996 0 000 1.41l1.41 1.41c.39.39 1.02.39 1.41 0l1.7-1.7c.41.22.84.41 1.3.55V19c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-2.33c.48-.14.94-.35 1.37-.59L15 17.72c.37.37.98.37 1.36 0l1.36-1.36c.37-.37.37-.98 0-1.36l-1.62-1.62c.24-.43.45-.89.6-1.38H19c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm-9 6c-2.21 0-4-1.79-4-4s1.79-4 4-4 4 1.79 4 4-1.79 4-4 4z"],"collapse-all":["M9.29 8.71c.18.18.43.29.71.29s.53-.11.71-.29l6-6a1.003 1.003 0 00-1.42-1.42L10 6.59l-5.29-5.3a1.003 1.003 0 00-1.42 1.42l6 6zm1.42 2.58c-.18-.18-.43-.29-.71-.29s-.53.11-.71.29l-6 6a1.003 1.003 0 001.42 1.42l5.29-5.3 5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-6-6z"],"column-layout":["M19 1H1c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM5 17H2V3h3v14zm4 0H6V3h3v14zm9 0h-8V3h8v14z"],comment:["M19 1H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h3v4a1.003 1.003 0 001.71.71l4.7-4.71H19c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM4 10c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zm6 0c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zm6 0c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"],comparison:["M6 8H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm13-6h-5c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm0 3h-5V3h5v2zM6 14H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zM6 2H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm4-2c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm9 14h-5c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zm0 3h-5v-2h5v2zm0-9h-5c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm0 3h-5V9h5v2z"],compass:["M15 10c0 .14-.03.28-.09.4l-3.99 8.98-.01.02a.991.991 0 01-1.82 0l-.01-.02-3.99-8.98c-.06-.12-.09-.26-.09-.4s.03-.28.09-.4L9.08.62 9.09.6a.991.991 0 011.82 0l.01.02 3.99 8.98c.06.12.09.26.09.4zm-5-6.54L7.09 10h5.81L10 3.46z"],compressed:["M19.89 6.56l-2.99-6h-.01C16.72.23 16.39 0 16 0H4c-.39 0-.72.23-.89.56H3.1l-3 6h.01C.05 6.69 0 6.84 0 7v12c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V7c0-.16-.05-.31-.11-.44zM11 2h4.38l2 4H11V2zM4.62 2H9v4H2.62l2-4zM18 18H2V8h7v4.59L6.71 10.3A.965.965 0 006 10a1.003 1.003 0 00-.71 1.71l4 4c.18.18.43.29.71.29s.53-.11.71-.29l4-4a1.003 1.003 0 00-1.42-1.42L11 12.59V8h7v10z"],confirm:["M9.71 5.29a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l7-7a1.003 1.003 0 00-1.42-1.42L12 7.59l-2.29-2.3zm7.93 2.32c.23.75.36 1.56.36 2.39 0 4.42-3.58 8-8 8s-8-3.58-8-8a7.998 7.998 0 0111.8-7.04l1.46-1.46C13.73.56 11.93 0 10 0 4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10c0-1.4-.29-2.73-.81-3.95l-1.55 1.56z"],console:["M19 19H1c-.55 0-1-.45-1-1V2c0-.55.45-1 1-1h18c.55 0 1 .45 1 1v16c0 .55-.45 1-1 1zM18 6H2v11h16V6zM4 8c.28 0 .53.11.71.29l2 2c.18.18.29.43.29.71s-.11.53-.29.71l-2 2a1.003 1.003 0 01-1.42-1.42L4.59 11l-1.3-1.29A1.003 1.003 0 014 8zm5 4h3c.55 0 1 .45 1 1s-.45 1-1 1H9c-.55 0-1-.45-1-1s.45-1 1-1z"],contrast:["M19 8h-1.26c-.19-.73-.48-1.42-.85-2.06l.94-.94a.996.996 0 000-1.41l-1.41-1.41a.996.996 0 00-1.41 0l-.94.94c-.65-.38-1.34-.67-2.07-.86V1c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v1.26c-.76.2-1.47.5-2.13.89L5 2.28a.972.972 0 00-1.36 0L2.28 3.64c-.37.38-.37.98 0 1.36l.87.87c-.39.66-.69 1.37-.89 2.13H1c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h1.26c.19.73.48 1.42.85 2.06l-.94.94a.996.996 0 000 1.41l1.41 1.41c.39.39 1.02.39 1.41 0l.94-.94c.64.38 1.33.66 2.06.85V19c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-1.26c.76-.2 1.47-.5 2.13-.89l.88.87c.37.37.98.37 1.36 0l1.36-1.36c.37-.38.37-.98 0-1.36l-.87-.87c.4-.65.7-1.37.89-2.13H19c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1zm-9 7c-2.76 0-5-2.24-5-5s2.24-5 5-5v10z"],control:["M17 10h-7v7h7v-7zm0-7h-7v6h7V3zM9 3H3v14h6V3zm10-3H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2V2h16v16z"],"credit-card":["M19 3H1c-.55 0-1 .45-1 1v2h20V4c0-.55-.45-1-1-1zM0 16c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V8H0v8zm6.5-2h7c.28 0 .5.22.5.5s-.22.5-.5.5h-7c-.28 0-.5-.22-.5-.5s.22-.5.5-.5zm-4 0h2c.28 0 .5.22.5.5s-.22.5-.5.5h-2c-.28 0-.5-.22-.5-.5s.22-.5.5-.5z"],cross:["M11.41 10l4.29-4.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L10 8.59l-4.29-4.3a1.003 1.003 0 00-1.42 1.42L8.59 10 4.3 14.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4.29-4.3 4.29 4.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L11.41 10z"],crown:["M2 8l4 2 4-5 4 5 4-2-1 7H3L2 8zm8-6a1 1 0 110 2 1 1 0 010-2zM1 5a1 1 0 110 2 1 1 0 010-2zm18 0a1 1 0 110 2 1 1 0 010-2zM3 16h14v2H3v-2z"],cube:["M1.953 4.481l7.41-4.02c.394-.215.88-.215 1.275 0l7.409 4.02L10 9.22 1.953 4.48zm-.817.68L9.5 10.085v9.281a1.316 1.316 0 01-.138-.064l-7.714-4.186A1.211 1.211 0 011 14.057v-8.35c0-.193.048-.38.136-.547zm17.728 0c.088.166.136.353.136.546v8.35c0 .438-.247.842-.648 1.06l-7.714 4.186c-.045.024-.091.046-.138.064v-9.281l8.364-4.926z"],"cube-add":["M17 3h2a1 1 0 010 2h-2v2a1 1 0 01-2 0V5h-2a1 1 0 010-2h2V1a1 1 0 012 0v2zm-3.969 4.435L10 9.22 1.953 4.48l7.41-4.02c.394-.215.88-.215 1.275 0l1.33.721A3.001 3.001 0 0013 7c0 .148.01.293.031.435zm.319.972A3 3 0 0019 7v7.057c0 .438-.247.842-.648 1.06l-7.714 4.186c-.045.024-.091.046-.138.064v-9.281l2.85-1.679zM1.136 5.16L9.5 10.086v9.281a1.316 1.316 0 01-.138-.064l-7.714-4.186A1.211 1.211 0 011 14.057v-8.35c0-.193.048-.38.136-.547z"],"cube-remove":["M11.968 1.182A3.001 3.001 0 0013 7h.77L10 9.22 1.953 4.48l7.41-4.02c.394-.215.88-.215 1.275 0l1.33.721zM19 7v7.057c0 .438-.247.842-.648 1.06l-7.714 4.186c-.045.024-.091.046-.138.064v-9.281L15.74 7H19zM1.136 5.16L9.5 10.086v9.281a1.316 1.316 0 01-.138-.064l-7.714-4.186A1.211 1.211 0 011 14.057v-8.35c0-.193.048-.38.136-.547zM13 3h6a1 1 0 010 2h-6a1 1 0 010-2z"],"curved-range-chart":["M19 16H3.02l2.14-1.74c2.25 1.7 7.33.46 11.83-2.99l-1.29-1.5c-3.56 2.74-7.31 4.03-8.93 3.19l10.55-8.57-.63-.78-10.59 8.6c-.64-1.64 1.46-4.91 5.09-7.7L9.9 3.01c-4.6 3.54-6.91 8.12-5.41 10.51L2 15.54V3c0-.55-.45-1-1-1s-1 .45-1 1v14a.998.998 0 001 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],cut:["M16 2s.72-1.28 0-2l-5.29 6.25 1.28 1.54L16 2zm.08 10c-.55 0-1.07.12-1.54.32L4.31 0c-.7.72 0 2 0 2l4.45 6.56-3.19 3.77C5.09 12.12 4.56 12 4 12c-2.21 0-4 1.79-4 4s1.79 4 4 4 4-1.79 4-4c0-.65-.17-1.26-.45-1.8l2.54-3.67 2.49 3.67c-.27.54-.44 1.15-.44 1.8 0 2.21 1.76 4 3.92 4 2.17 0 3.92-1.79 3.92-4 .02-2.21-1.74-4-3.9-4zM4 18c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zm12.08 0c-1.08 0-1.96-.9-1.96-2s.88-2 1.96-2 1.96.9 1.96 2-.88 2-1.96 2z"],cycle:["M16 10a4 4 0 110 8 4 4 0 010-8zM4 10a4 4 0 110 8 4 4 0 010-8zm7.299-5.543l.087.089 1.93 2.232 2.048.708a1 1 0 01.65 1.16l-.031.112a1 1 0 01-1.16.65l-.112-.031-2.302-.796a1 1 0 01-.337-.197l-.092-.094-1.387-1.603-1.891 1.982 2.046 2.274a1 1 0 01.25.547l.007.122v4.24a1 1 0 01-1.993.117l-.007-.117-.001-3.857-2.408-2.676a1 1 0 01-.063-1.26l.082-.099 3.29-3.45a1 1 0 011.394-.053zM16 12a2 2 0 100 4 2 2 0 000-4zM4 12a2 2 0 100 4 2 2 0 000-4zm9.5-10a1.5 1.5 0 110 3 1.5 1.5 0 010-3z"],dashboard:["M6 5c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zM4 9c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm6-4c.55 0 1-.45 1-1s-.45-1-1-1-1 .45-1 1 .45 1 1 1zm0-5C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm6-9c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm-8 5c0 1.1.9 2 2 2s2-.9 2-2c0-.33-2-8-2-8s-2 7.67-2 8zm6-9c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1z"],"data-connection":["M2 11.9c.935.674 2.339 1.217 4.023 1.536A6.996 6.996 0 009.393 20c-3.988-.019-7.231-1.083-7.387-2.4L2 17.5v-5.6zM13 8c3.315 0 6 2.685 6 6s-2.685 6-6 6-6-2.685-6-6 2.685-6 6-6zm1 1l-4 6h2.5l-.5 4 4-6h-2.5l.5-4zm3-4.6v3.855a7.003 7.003 0 00-10.779 3.992c-2.408-.391-4.097-1.202-4.214-2.142L2 10V4.4c1.525 1.1 4.3 1.85 7.5 1.85S15.475 5.5 17 4.4zM9.5 0C13.637 0 17 1.125 17 2.5S13.637 5 9.5 5C5.35 5 2 3.875 2 2.5S5.35 0 9.5 0z"],"data-lineage":["M1.053 0C.47 0 0 .471 0 1.053V4.21c0 .58.471 1.052 1.053 1.052h3.275a6.332 6.332 0 003.728 4.738 6.33 6.33 0 00-3.728 4.737l-3.275-.001C.47 14.737 0 15.208 0 15.789v3.158C0 19.53.471 20 1.053 20h7.435c.581 0 1.053-.471 1.053-1.053V15.79c0-.58-.472-1.052-1.053-1.052H5.406a5.293 5.293 0 015.195-4.21v2.105c0 .58.471 1.052 1.052 1.052h7.294c.582 0 1.053-.471 1.053-1.052V7.368c0-.58-.471-1.052-1.053-1.052h-7.294c-.581 0-1.052.471-1.052 1.052v2.106a5.293 5.293 0 01-5.194-4.21h3.081c.581 0 1.053-.472 1.053-1.053V1.053C9.54.47 9.069 0 8.488 0H1.053z"],database:["M2.01 5.1v5.4c0 1.38 3.58 2.5 8 2.5s8-1.12 8-2.5V5.1c-1.49 1.13-4.51 1.9-8 1.9-3.48 0-6.5-.77-8-1.9zm8 .9c4.42 0 8-1.12 8-2.5s-3.58-2.5-8-2.5-8 1.12-8 2.5S5.6 6 10.01 6zm-8 6.1v5.4c0 1.38 3.58 2.5 8 2.5s8-1.12 8-2.5v-5.4c-1.49 1.13-4.51 1.9-8 1.9-3.48 0-6.5-.77-8-1.9z"],delete:["M15 6a1.003 1.003 0 00-1.71-.71L10 8.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42L8.59 10 5.3 13.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3.29-3.3 3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L11.41 10l3.29-3.29c.19-.18.3-.43.3-.71zm-5-6C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"],delta:["M10 0L0 20h20L10 0zM9 6l6 12H3L9 6z"],"derive-column":["M7.1 8.2h-.99c.28-1.11.66-1.92 1.12-2.43.28-.32.56-.48.83-.48.05 0 .1.02.13.05.03.03.05.07.05.12 0 .04-.04.13-.11.25a.64.64 0 00-.12.35c0 .15.06.28.18.39.12.11.27.16.45.16.2 0 .36-.07.49-.2s.2-.31.2-.54c0-.26-.1-.47-.3-.63-.19-.16-.51-.24-.95-.24-.68 0-1.3.19-1.85.58-.56.38-1.09 1.02-1.59 1.91-.17.3-.34.5-.49.59-.15.08-.4.13-.74.12l-.23.77h.95l-1.39 5.24c-.23.86-.39 1.39-.47 1.59-.12.29-.3.54-.54.75-.1.08-.21.12-.35.12-.04 0-.07-.01-.1-.03l-.03-.04c0-.02.03-.07.1-.13.07-.07.1-.17.1-.31 0-.15-.05-.28-.16-.38-.11-.1-.27-.15-.47-.15-.25 0-.44.07-.59.2-.15.12-.23.28-.23.46 0 .19.09.36.27.5.19.14.47.21.86.21.61 0 1.16-.15 1.63-.46.48-.31.89-.78 1.25-1.43.35-.64.72-1.68 1.09-3.11l.8-3.03h.96l.24-.77zM19 0h-9c-.55 0-1 .45-1 1v3h2V2h7v16h-7v-2H9v3c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-8.79 13.49c.15.28.32.49.52.61.19.12.44.19.73.19.28 0 .57-.1.86-.3.38-.25.77-.69 1.17-1.31l-.25-.14c-.27.37-.48.6-.61.69-.09.06-.19.09-.31.09-.14 0-.28-.09-.42-.26-.23-.29-.54-1.09-.93-2.4.35-.59.64-.97.87-1.15.17-.13.35-.2.55-.2.07 0 .2.03.39.08s.36.08.5.08c.2 0 .37-.07.5-.2.15-.14.22-.31.22-.52 0-.22-.07-.4-.2-.53s-.33-.2-.58-.2c-.22 0-.43.05-.63.15-.2.1-.45.32-.75.67-.23.25-.56.7-1.01 1.33a6.52 6.52 0 00-.91-2.15l-2.39.39-.05.25c.18-.03.33-.05.45-.05.24 0 .43.1.59.3.25.31.59 1.24 1.02 2.8-.34.44-.58.73-.7.87-.21.22-.38.36-.52.43-.1.05-.22.08-.35.08-.1 0-.26-.05-.49-.16a1.01 1.01 0 00-.42-.11c-.23 0-.42.07-.57.22-.15.14-.23.33-.23.55 0 .21.07.38.21.51.14.13.33.2.56.2.23 0 .44-.05.64-.14.2-.09.45-.29.75-.59s.72-.78 1.25-1.43c.21.61.39 1.06.54 1.35z"],desktop:["M19 0H1C.45 0 0 .45 0 1v13c0 .55.45 1 1 1h5.67l-.5 3H5c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1h-1.17l-.5-3H19c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 13H2V2h16v11z"],diagnosis:["M4 2a1 1 0 01.117 1.993L4 4v5a2 2 0 001.85 1.995L6 11a2 2 0 001.995-1.85L8 9V4a1 1 0 01-.117-1.993L8 2h1a1 1 0 01.993.883L10 3v6a4.002 4.002 0 01-3 3.874V13a3 3 0 003 3 4 4 0 003.995-3.8L14 12V8.792a2.5 2.5 0 112 0V12a6 6 0 01-6 6 5 5 0 01-4.995-4.783L5 13v-.126A4.002 4.002 0 012.005 9.2L2 9V3a1 1 0 01.883-.993L3 2h1z"],"diagram-tree":["M19 10v5h-2v-4h-6v4H9v-4H3v4H1v-5a1 1 0 011-1h7V5h2v4h7a1 1 0 011 1zM1 16h2a1 1 0 011 1v2a1 1 0 01-1 1H1a1 1 0 01-1-1v-2a1 1 0 011-1zm16 0h2a1 1 0 011 1v2a1 1 0 01-1 1h-2a1 1 0 01-1-1v-2a1 1 0 011-1zm-8 0h2a1 1 0 011 1v2a1 1 0 01-1 1H9a1 1 0 01-1-1v-2a1 1 0 011-1zM9 0h2a1 1 0 011 1v2a1 1 0 01-1 1H9a1 1 0 01-1-1V1a1 1 0 011-1z"],"direction-left":["M20 3.02l-20 7 20 7-5-7z"],"direction-right":["M20 10.02l-20-7 5 7-5 7z"],disable:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM2 10c0-4.42 3.58-8 8-8 1.85 0 3.55.63 4.9 1.69L3.69 14.9A7.902 7.902 0 012 10zm8 8c-1.85 0-3.55-.63-4.9-1.69L16.31 5.1A7.902 7.902 0 0118 10c0 4.42-3.58 8-8 8z"],document:["M11.98 0h-8c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V6l-6-6zm4 18h-11V2h6v5h5v11z"],"document-open":["M8 15c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1s.45 1 1 1h2.59L1.3 16.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L8 12.41V15zm5-15H5c-.55 0-1 .45-1 1v6h2V2h6v5h5v11H6v-.76L4.04 19.2c.1.45.48.8.96.8h13c.55 0 1-.45 1-1V6l-6-6z"],"document-share":["M14.09 10.09c-.31.31-.67.57-1.09.72V18H2V2h6v5h1.18c.15-.42.39-.8.7-1.11v-.01l2.45-2.45c-.42-.29-.78-.65-1.01-1.11L9 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V9.24l-.88.88-.03-.03zM19 0h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L11.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 3.41V6c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],dollar:["M15.57 11.19c-.27-.51-.63-.93-1.07-1.26-.44-.33-.95-.6-1.51-.79-.56-.2-1.14-.36-1.72-.5-.6-.14-1.19-.26-1.75-.38-.57-.13-1.07-.27-1.51-.44-.44-.17-.8-.38-1.07-.63s-.41-.59-.41-1c0-.33.09-.6.28-.81.19-.21.42-.36.69-.47.27-.11.57-.18.88-.22.31-.04.58-.06.8-.06.71 0 1.35.14 1.9.41.55.27.91.81 1.06 1.62h3.36c-.09-.84-.32-1.56-.69-2.16-.37-.6-.83-1.08-1.38-1.45-.56-.37-1.18-.64-1.86-.81-.19-.05-.38-.07-.57-.1V1c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v1.1c-.22.03-.43.05-.66.1-.73.13-1.39.37-1.98.71-.6.34-1.09.8-1.47 1.35-.39.56-.58 1.25-.58 2.08 0 .76.13 1.41.4 1.93.26.52.62.95 1.06 1.28.44.33.94.6 1.5.79.55.2 1.13.36 1.74.5.58.14 1.16.26 1.72.38s1.07.26 1.51.43c.44.17.8.39 1.09.66.28.27.43.63.45 1.06.02.43-.08.78-.3 1.04-.22.26-.49.47-.83.6-.34.14-.7.23-1.09.28-.39.05-.73.07-1.03.07-.87 0-1.61-.2-2.23-.59-.62-.39-.98-1.08-1.07-2.06H3c.02.9.19 1.68.52 2.34.33.66.78 1.21 1.35 1.65.57.44 1.25.77 2.03.98.35.1.71.16 1.08.21V19c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-1.13c.25-.04.5-.07.76-.13.77-.18 1.47-.46 2.1-.85.63-.39 1.14-.9 1.54-1.53.4-.63.59-1.39.59-2.29.01-.75-.13-1.37-.4-1.88z"],dot:["M10 6a4 4 0 100 8 4 4 0 100-8z"],"double-caret-horizontal":["M8 4c-.24 0-.46.1-.63.24l-.01-.01-6 5 .01.01c-.22.19-.37.45-.37.76s.15.57.37.76l-.01.01 6 5 .01-.01c.17.14.39.24.63.24.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm11 6c0-.31-.15-.57-.37-.76l.01-.01-6-5-.01.01C12.46 4.1 12.24 4 12 4c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1 .24 0 .46-.1.63-.24l.01.01 6-5-.01-.01c.22-.19.37-.45.37-.76z"],"double-caret-vertical":["M5 9h10c.55 0 1-.45 1-1 0-.24-.1-.46-.24-.63l.01-.01-5-6-.01.01C10.57 1.15 10.31 1 10 1s-.57.15-.76.37l-.01-.01-5 6 .01.01C4.1 7.54 4 7.76 4 8c0 .55.45 1 1 1zm10 2H5c-.55 0-1 .45-1 1 0 .24.1.46.24.63l-.01.01 5 6 .01-.01c.19.22.45.37.76.37s.57-.15.76-.37l.01.01 5-6-.01-.01c.14-.17.24-.39.24-.63 0-.55-.45-1-1-1z"],"double-chevron-down":["M9.29 10.71c.18.18.43.29.71.29s.53-.11.71-.29l6-6a1.003 1.003 0 00-1.42-1.42L10 8.59l-5.29-5.3a1.003 1.003 0 00-1.42 1.42l6 6zM16 9c-.28 0-.53.11-.71.29L10 14.59l-5.29-5.3a1.003 1.003 0 00-1.42 1.42l6 6c.18.18.43.29.71.29s.53-.11.71-.29l6-6A1.003 1.003 0 0016 9z"],"double-chevron-left":["M5.41 10l5.29-5.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-6 6c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l6 6a1.003 1.003 0 001.42-1.42L5.41 10zm6 0l5.29-5.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-6 6c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l6 6a1.003 1.003 0 001.42-1.42L11.41 10z"],"double-chevron-right":["M11 10c0-.28-.11-.53-.29-.71l-6-6a1.003 1.003 0 00-1.42 1.42L8.59 10 3.3 15.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l6-6c.18-.18.29-.43.29-.71zm5.71-.71l-6-6a1.003 1.003 0 00-1.42 1.42l5.3 5.29-5.29 5.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l6-6c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"double-chevron-up":["M4 11c.28 0 .53-.11.71-.29L10 5.41l5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-6-6A.997.997 0 0010 3c-.28 0-.53.11-.71.29l-6 6A1.003 1.003 0 004 11zm6.71-1.71A.997.997 0 0010 9c-.28 0-.53.11-.71.29l-6 6a1.003 1.003 0 001.42 1.42l5.29-5.3 5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-6-6z"],"doughnut-chart":["M16 10c0 3.31-2.69 6-6 6s-6-2.69-6-6 2.69-6 6-6V0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10h-4zm-.09-1h4.04C19.48 4.28 15.72.52 11 .05V4.1A5.98 5.98 0 0115.91 9z"],download:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm4.71 11.71l-4 4c-.18.18-.43.29-.71.29s-.53-.11-.71-.29l-4-4a1.003 1.003 0 011.42-1.42L9 12.59V5c0-.55.45-1 1-1s1 .45 1 1v7.59l2.29-2.29c.18-.19.43-.3.71-.3a1.003 1.003 0 01.71 1.71z"],"drag-handle-horizontal":["M7.5 11c-.83 0-1.5.67-1.5 1.5S6.67 14 7.5 14 9 13.33 9 12.5 8.33 11 7.5 11zm-5-5C1.67 6 1 6.67 1 7.5S1.67 9 2.5 9 4 8.33 4 7.5 3.33 6 2.5 6zm0 5c-.83 0-1.5.67-1.5 1.5S1.67 14 2.5 14 4 13.33 4 12.5 3.33 11 2.5 11zm15-2c.83 0 1.5-.67 1.5-1.5S18.33 6 17.5 6 16 6.67 16 7.5 16.67 9 17.5 9zm-5 2c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm5 0c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm-10-5C6.67 6 6 6.67 6 7.5S6.67 9 7.5 9 9 8.33 9 7.5 8.33 6 7.5 6zm5 0c-.83 0-1.5.67-1.5 1.5S11.67 9 12.5 9 14 8.33 14 7.5 13.33 6 12.5 6z"],"drag-handle-vertical":["M7.5 6C6.67 6 6 6.67 6 7.5S6.67 9 7.5 9 9 8.33 9 7.5 8.33 6 7.5 6zm0 5c-.83 0-1.5.67-1.5 1.5S6.67 14 7.5 14 9 13.33 9 12.5 8.33 11 7.5 11zm0 5c-.83 0-1.5.67-1.5 1.5S6.67 19 7.5 19 9 18.33 9 17.5 8.33 16 7.5 16zm5-12c.83 0 1.5-.67 1.5-1.5S13.33 1 12.5 1 11 1.67 11 2.5 11.67 4 12.5 4zm-5-3C6.67 1 6 1.67 6 2.5S6.67 4 7.5 4 9 3.33 9 2.5 8.33 1 7.5 1zm5 10c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm0 5c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm0-10c-.83 0-1.5.67-1.5 1.5S11.67 9 12.5 9 14 8.33 14 7.5 13.33 6 12.5 6z"],draw:["M17.7 12.7c0-.1 0-.2-.1-.3l-2-7c-.1-.3-.3-.6-.6-.7L1.8 0l-.6.5L7.7 7c.3-.2.6-.3 1-.3 1.1 0 2 .9 2 2s-.9 2-2 2-2-.9-2-2c0-.4.1-.7.3-1L.5 1.2l-.5.6L4.7 15c.1.3.4.5.7.6l7 2c.1 0 .2.1.3.1.3 0 .5-.1.7-.3l4-4c.2-.2.3-.5.3-.7zm1 1c-.3 0-.5.1-.7.3l-4 4c-.2.2-.3.4-.3.7 0 .5.4 1 1 1 .3 0 .5-.1.7-.3l4-4c.2-.2.3-.4.3-.7 0-.6-.5-1-1-1z"],"drawer-left":["M9 0a1 1 0 011 1v18a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1h8zM8 2H2v16h6V2zm2 7h6.59L14.3 6.71A.965.965 0 0114 6a1.003 1.003 0 011.71-.71l4 4c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-4 4a1.003 1.003 0 01-1.42-1.42l2.3-2.29H10V9z"],"drawer-left-filled":["M1 0h8a1 1 0 011 1v18a1 1 0 01-1 1H1a1 1 0 01-1-1V1a1 1 0 011-1zm9 9h6.59L14.3 6.71A.965.965 0 0114 6a1.003 1.003 0 011.71-.71l4 4c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-4 4a1.003 1.003 0 01-1.42-1.42l2.3-2.29H10V9z"],"drawer-right":["M19 0a1 1 0 011 1v18a1 1 0 01-1 1h-8a1 1 0 01-1-1V1a1 1 0 011-1h8zm-1 2h-6v16h6V2zm-8 7H3.41L5.7 6.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L3.41 11H10V9z"],"drawer-right-filled":["M11 0h8a1 1 0 011 1v18a1 1 0 01-1 1h-8a1 1 0 01-1-1V1a1 1 0 011-1zm-1 9H3.41L5.7 6.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L3.41 11H10V9z"],"drive-time":["M20.01 7.7c0-.63-.5-1.14-1.1-1.14h-1.32l-.95-2.57c-.24-.64-.95-1.31-1.59-1.5 0 0-1.65-.49-5.05-.49s-5.04.49-5.04.49c-.63.19-1.35.86-1.59 1.5l-.95 2.57H1.1C.5 6.56 0 7.07 0 7.7c0 .63.5 1.14 1.1 1.14h.47l-.34.91c-.24.64-.43 1.72-.43 2.4v5.39c0 .8.63 1.45 1.4 1.45.77 0 1.4-.65 1.4-1.45v-.83h12.8v.83c0 .8.63 1.45 1.4 1.45s1.4-.65 1.4-1.45v-5.39c0-.68-.19-1.77-.43-2.4l-.34-.91h.47c.61 0 1.11-.51 1.11-1.14zm-16.47.34l1.12-3.16c.08-.22.32-.39.54-.39h9.6c.22 0 .46.17.54.39l1.12 3.16c.08.21-.04.39-.26.39H3.8c-.22-.01-.34-.18-.26-.39zm.96 4.94c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.68 1.5 1.5c0 .83-.67 1.5-1.5 1.5zm11 0c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"],duplicate:["M15 4H1c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm-1 14H2V6h12v12zm5-18H5c-.55 0-1 .45-1 1v2h2V2h12v12h-1v2h2c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],edit:["M4.59 12.59l2.83 2.83 7.65-7.65-2.83-2.83-7.65 7.65zM2 18l4.41-1.59-2.81-2.79L2 18zM16 2c-.55 0-1.05.22-1.41.59l-1.65 1.65 2.83 2.83 1.65-1.65A2.006 2.006 0 0016 2z"],eject:["M4 12h12c.55 0 1-.45 1-1 0-.25-.1-.47-.25-.64l.01-.01-6-7-.01.01C10.57 3.14 10.3 3 10 3s-.57.14-.75.36l-.01-.01-6 7 .01.01c-.15.17-.25.39-.25.64 0 .55.45 1 1 1zm12 1H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1z"],emoji:["M10 0c5.523 0 10 4.477 10 10s-4.477 10-10 10S0 15.523 0 10 4.477 0 10 0zm0 2a8 8 0 100 16 8 8 0 000-16zm-4 8l.015.215C6.219 12.42 7.925 14 10 14a4 4 0 003.995-3.8L14 10h2l-.013.238C15.754 13.552 13.163 16 10 16a6 6 0 01-5.996-5.775L4 10h2zm1.5-4a1.5 1.5 0 110 3 1.5 1.5 0 010-3zm5 0a1.5 1.5 0 110 3 1.5 1.5 0 010-3z"],endorsed:["M19.83 9.38L18.81 7.6V5.62c0-.45-.23-.85-.61-1.08l-1.71-1-1.02-1.76a1.25 1.25 0 00-1.08-.61h-2.03l-1.74-1c-.38-.23-.87-.23-1.25 0l-1.74 1H5.65c-.44 0-.85.23-1.08.61L3.58 3.5l-1.8 1.04c-.38.24-.62.64-.62 1.08v2.06L.17 9.4c-.11.19-.17.4-.17.61s.06.42.17.61l.99 1.72v2.06c0 .45.23.85.61 1.08l1.78 1.02.99 1.72c.23.38.63.61 1.08.61h1.99l1.74 1c.19.11.41.17.62.17.21 0 .42-.06.61-.17l1.74-1h2.03c.44 0 .85-.23 1.08-.61l1.02-1.76 1.71-1c.38-.23.61-.64.61-1.08v-1.97l1.02-1.78c.27-.38.27-.85.04-1.25zm-5.08-.71l-5.01 5.01c-.18.18-.43.29-.71.29-.28 0-.53-.11-.71-.29l-3.01-3.01a1.003 1.003 0 011.42-1.42l2.3 2.3 4.31-4.3a1.003 1.003 0 011.71.71c0 .28-.12.53-.3.71z"],envelope:["M0 4.01v11.91l6.27-6.27L0 4.01zm18.91-1.03H1.09L10 10.97l8.91-7.99zm-5.18 6.66L20 15.92V4.01l-6.27 5.63zm-3.23 2.9c-.13.12-.31.19-.5.19s-.37-.07-.5-.19l-2.11-1.89-6.33 6.33h17.88l-6.33-6.33-2.11 1.89z"],equals:["M4 7h12a1 1 0 010 2H4a1 1 0 110-2zm0 4h12a1 1 0 010 2H4a1 1 0 010-2z"],eraser:["M18.71 8.43c.39-.4.39-1.05 0-1.45l-5.53-5.72a.967.967 0 00-1.4 0L1.29 12.1c-.39.4-.39 1.05 0 1.45l4.25 4.39 2.13 2.05h9.27c.02 0 .03.01.05.01.55 0 1-.45 1-1s-.45-1-1-1H9.46l.05-.05h.01l.81-.84 8.38-8.68zM7.52 17.94l-4.95-5.12 4.46-4.61 4.95 5.12-4.46 4.61z"],error:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm1 16H9v-2h2v2zm0-3H9V4h2v9z"],euro:["M8.89 4.47c.56-.31 1.23-.47 2.03-.47.44 0 .85.07 1.25.22.4.14.76.35 1.07.6.17.14.33.3.47.47l2.32-2.32c-.16-.15-.3-.32-.47-.46-.62-.49-1.33-.87-2.12-1.13-.8-.25-1.64-.38-2.52-.38-1.24 0-2.35.22-3.33.66-.99.44-1.82 1.05-2.49 1.82-.68.78-1.2 1.68-1.56 2.72-.09.26-.13.54-.2.8H2c-.55 0-1 .45-1 1s.45 1 1 1h1.04c-.01.2-.04.38-.04.58 0 .15.03.28.03.42H2c-.55 0-1 .45-1 1s.45 1 1 1h1.31c.07.3.13.6.23.89.36 1.02.88 1.92 1.56 2.67.68.76 1.51 1.35 2.49 1.79.98.43 2.09.65 3.33.65.99 0 1.9-.15 2.73-.46.83-.3 1.55-.74 2.17-1.32.03-.03.05-.06.08-.09l-2.41-2.15c-.01.01-.02.02-.02.03-.61.67-1.46 1-2.54 1-.8 0-1.47-.16-2.03-.47-.56-.31-1.01-.72-1.35-1.24-.28-.38-.47-.83-.63-1.3H12c.55 0 1-.45 1-1s-.45-1-1-1H6.56c0-.14-.02-.28-.02-.42 0-.2.02-.39.03-.58H13c.55 0 1-.45 1-1s-.45-1-1-1H6.94c.15-.46.34-.9.59-1.28.35-.52.8-.94 1.36-1.25zM18 11.38v0z"],exchange:["M2.5 8a2.5 2.5 0 000 5 2.5 2.5 0 000-5zm10.35 3.15a.495.495 0 10-.7.7L13.3 13H5.5c-.28 0-.5.22-.5.5s.22.5.5.5h7.79l-1.15 1.15c-.08.09-.14.21-.14.35a.495.495 0 00.85.35l2-2c.09-.09.15-.21.15-.35s-.06-.26-.15-.35l-2-2zM17.5 8a2.5 2.5 0 000 5 2.5 2.5 0 000-5zM7.15 9.85a.495.495 0 10.7-.7L6.71 8h7.79c.28 0 .5-.22.5-.5s-.22-.5-.5-.5H6.71l1.15-1.15c.08-.09.14-.21.14-.35a.495.495 0 00-.85-.35l-2 2c-.09.09-.15.21-.15.35s.06.26.15.35l2 2z"],"exclude-row":["M1 3h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zM0 13a1.003 1.003 0 001.71.71L4 11.41l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L5.41 10 7.7 7.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L4 8.59l-2.29-2.3A1.003 1.003 0 00.29 7.71L2.59 10 .3 12.29c-.19.18-.3.43-.3.71zm18-5h-7c-1.1 0-2 .9-2 2s.9 2 2 2h7c1.1 0 2-.9 2-2s-.9-2-2-2zm1 9H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],"expand-all":["M4 9c.28 0 .53-.11.71-.29L10 3.41l5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-6-6C10.53 1.11 10.28 1 10 1s-.53.11-.71.29l-6 6A1.003 1.003 0 004 9zm12 2c-.28 0-.53.11-.71.29L10 16.59 4.71 11.3A.965.965 0 004 11a1.003 1.003 0 00-.71 1.71l6 6c.18.18.43.29.71.29s.53-.11.71-.29l6-6A1.003 1.003 0 0016 11z"],export:["M5 7c.28 0 .53-.11.71-.29L9 3.41V15c0 .55.45 1 1 1s1-.45 1-1V3.41l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-5-5C10.53.11 10.28 0 10 0s-.53.11-.71.29l-5 5A1.003 1.003 0 005 7zm14 7c-.55 0-1 .45-1 1v3H2v-3c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1z"],"eye-off":["M20 9.96v-.03-.01-.02-.02a.794.794 0 00-.21-.43c-.55-.69-1.19-1.3-1.85-1.87l-3.93 2.62a3.966 3.966 0 01-3.96 3.77c-.47 0-.91-.1-1.33-.24l-2.24 1.49c.52.21 1.05.39 1.6.51 1.21.27 2.43.28 3.64.05 1.11-.21 2.17-.64 3.17-1.18 1.56-.84 2.99-2 4.23-3.3.23-.24.46-.49.67-.75a.87.87 0 00.21-.43v-.02-.02-.01-.03V10v-.04zm-.46-5.14c.27-.18.46-.47.46-.82 0-.55-.45-1-1-1-.21 0-.39.08-.54.18l-.01-.02L15 5.46c-.95-.53-1.95-.96-3.01-1.2a9.158 9.158 0 00-3.65-.04c-1.11.21-2.17.64-3.17 1.18-1.56.84-2.99 2-4.23 3.3-.23.24-.46.48-.67.75-.27.34-.27.76 0 1.1.64.79 1.39 1.5 2.16 2.15.26.21.52.41.79.61L.44 15.16l.01.02A1 1 0 000 16c0 .55.45 1 1 1 .21 0 .39-.08.54-.18l.01.02 18-12-.01-.02zm-8.67 3.4c-.25-.12-.53-.2-.83-.2-1.1 0-1.99.89-1.99 1.99 0 .03.02.06.02.09l-1.78 1.19c-.14-.4-.22-.83-.22-1.28 0-2.19 1.78-3.97 3.98-3.97 1.01 0 1.91.38 2.61 1l-1.79 1.18z"],"eye-on":["M13.3 8.71c.18.18.43.29.71.29s.53-.11.71-.29l4.99-5a1.003 1.003 0 00-1.42-1.42L14 6.58l-2.29-2.29a.956.956 0 00-.7-.29 1.003 1.003 0 00-.71 1.71l3 3zM20 9.96v-.03-.01-.02-.02a.823.823 0 00-.21-.44c-.44-.55-.94-1.05-1.46-1.52l-2.2 2.2c-.55.54-1.3.88-2.12.88-.05 0-.09-.01-.14-.01a3.978 3.978 0 01-3.86 3.02 4.007 4.007 0 01-1.66-7.65A2.97 2.97 0 018.02 5c0-.28.05-.54.12-.8-1.05.22-2.07.64-3.02 1.15-1.57.85-3 2.02-4.24 3.33-.23.25-.46.5-.67.76-.28.35-.28.77 0 1.12.64.8 1.4 1.52 2.17 2.17 1.66 1.41 3.56 2.58 5.66 3.06 1.21.27 2.43.29 3.65.05 1.11-.21 2.18-.65 3.18-1.19 1.57-.85 3-2.02 4.24-3.33.23-.24.46-.49.67-.76.11-.12.18-.27.21-.44v-.02-.02-.01-.03V10c.01-.01.01-.03.01-.04zm-9.99 2.05c1.03 0 1.87-.79 1.98-1.8l-.09-.09-.01.01-2.1-2.11c-1 .11-1.77.95-1.77 1.98-.01 1.11.89 2.01 1.99 2.01z"],"eye-open":["M10.01 7.984A2.008 2.008 0 008.012 9.99c0 1.103.9 2.006 1.998 2.006a2.008 2.008 0 001.998-2.006c0-1.103-.9-2.006-1.998-2.006zM20 9.96v-.03-.01-.02-.02a.827.827 0 00-.21-.442c-.64-.802-1.398-1.514-2.168-2.166-1.658-1.404-3.566-2.587-5.664-3.058a8.982 8.982 0 00-3.656-.05c-1.11.2-2.178.641-3.177 1.183-1.569.852-2.997 2.016-4.246 3.33-.23.25-.46.49-.67.761-.279.351-.279.773 0 1.124.64.802 1.4 1.514 2.169 2.166 1.658 1.404 3.566 2.577 5.664 3.058 1.209.271 2.438.281 3.656.05 1.11-.21 2.178-.651 3.177-1.193 1.569-.852 2.997-2.016 4.246-3.33.23-.24.46-.49.67-.751.11-.12.179-.271.209-.442v-.02-.02-.01-.03V10v-.04zM10.01 14A4.003 4.003 0 016.014 9.99a4.003 4.003 0 013.996-4.011 4.003 4.003 0 013.996 4.011 4.003 4.003 0 01-3.996 4.011z"],"fast-backward":["M18 3c-.23 0-.42.09-.59.21l-.01-.01L11 8V4c0-.55-.45-1-1-1-.23 0-.42.09-.59.21L9.4 3.2l-8 6 .01.01C1.17 9.4 1 9.67 1 10s.17.6.41.79l-.01.01 8 6 .01-.01c.17.12.36.21.59.21.55 0 1-.45 1-1v-4l6.4 4.8.01-.01c.17.12.36.21.59.21.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"fast-forward":["M19 10c0-.33-.17-.6-.41-.79l.01-.01-8-6-.01.01C10.42 3.09 10.23 3 10 3c-.55 0-1 .45-1 1v4L2.6 3.2l-.01.01C2.42 3.09 2.23 3 2 3c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1 .23 0 .42-.09.59-.21l.01.01L9 12v4c0 .55.45 1 1 1 .23 0 .42-.09.59-.21l.01.01 8-6-.01-.01c.24-.19.41-.46.41-.79z"],feed:["M2.5 15a2.5 2.5 0 000 5 2.5 2.5 0 000-5zm.5-5c-.55 0-1 .45-1 1s.45 1 1 1c2.76 0 5 2.24 5 5 0 .55.45 1 1 1s1-.45 1-1c0-3.87-3.13-7-7-7zM3 0c-.55 0-1 .45-1 1s.45 1 1 1c8.28 0 15 6.72 15 15 0 .55.45 1 1 1s1-.45 1-1C20 7.61 12.39 0 3 0zm0 5c-.55 0-1 .45-1 1s.45 1 1 1c5.52 0 10 4.48 10 10 0 .55.45 1 1 1s1-.45 1-1C15 10.37 9.63 5 3 5z"],"feed-subscribed":["M2.5 15a2.5 2.5 0 000 5 2.5 2.5 0 000-5zM3 2c1.76 0 3.44.31 5.01.87.03-.71.31-1.35.75-1.85C6.96.37 5.03 0 3 0c-.55 0-1 .45-1 1s.45 1 1 1zm10.32 4.67a.99.99 0 001.4 0l4.98-4.98c.19-.17.3-.42.3-.7 0-.55-.45-1-1-1a.99.99 0 00-.7.29l-4.27 4.27-2.28-2.28a.99.99 0 00-.7-.29c-.55 0-.99.45-.99 1 0 .28.11.52.29.7l2.97 2.99zM3 10c-.55 0-1 .45-1 1s.45 1 1 1c2.76 0 5 2.24 5 5 0 .55.45 1 1 1s1-.45 1-1c0-3.87-3.13-7-7-7zm13.94-2.69l-.82.82-.02-.02c-.2.2-.42.37-.67.51A14.8 14.8 0 0118 17c0 .55.45 1 1 1s1-.45 1-1c0-3.61-1.14-6.94-3.06-9.69zM3 5c-.55 0-1 .45-1 1s.45 1 1 1c5.52 0 10 4.48 10 10 0 .55.45 1 1 1s1-.45 1-1C15 10.37 9.63 5 3 5z"],film:["M19 2h-5v3H6V2H1c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h5v-3h8v3h5c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zM4 17H2v-2h2v2zm0-3H2v-2h2v2zm0-3H2V9h2v2zm0-3H2V6h2v2zm0-3H2V3h2v2zm10 8H6V7h8v6zm4 4h-2v-2h2v2zm0-3h-2v-2h2v2zm0-3h-2V9h2v2zm0-3h-2V6h2v2zm0-3h-2V3h2v2z"],filter:["M18 1H2a1.003 1.003 0 00-.71 1.71L7 8.41V18a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71V8.41l5.71-5.71c.18-.17.29-.42.29-.7 0-.55-.45-1-1-1z"],"filter-keep":["M15 2c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L5 7.41V16a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71V7.41l4.71-4.71c.18-.17.29-.42.29-.7zm4 11c-.28 0-.53.11-.71.29L15 16.59l-1.29-1.29A.965.965 0 0013 15a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l4-4A1.003 1.003 0 0019 13z"],"filter-list":["M15 2c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L5 7.41V16a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71V7.41l4.71-4.71c.18-.17.29-.42.29-.7zm-4 8c0 .55.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1h-7c-.55 0-1 .45-1 1zm8 7h-7c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1zm0-4h-7c-.55 0-1 .45-1 1s.45 1 1 1h7c.55 0 1-.45 1-1s-.45-1-1-1z"],"filter-open":["M15 2c0 .28-.11.53-.29.7L10 7.41V13c0 .28-.11.53-.29.71l-3 3A1.003 1.003 0 015 16V7.41L.29 2.71A1.003 1.003 0 011 1h13c.55 0 1 .45 1 1zm4.707 11.293a1 1 0 010 1.414l-4 4c-.63.63-1.707.184-1.707-.707v-8c0-.89 1.077-1.337 1.707-.707l4 4z"],"filter-remove":["M15 2c0-.55-.45-1-1-1H1a1.003 1.003 0 00-.71 1.71L5 7.41V16a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71V7.41l4.71-4.71c.18-.17.29-.42.29-.7zm2.91 13.5l1.79-1.79c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-1.79 1.79-1.79-1.79a1.003 1.003 0 00-1.42 1.42l1.79 1.79-1.79 1.79a1.003 1.003 0 001.42 1.42l1.79-1.79 1.79 1.79a1.003 1.003 0 001.42-1.42l-1.8-1.79z"],flag:["M3 3c-.55 0-1 .45-1 1v15c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1zm0-3c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm2 4.08v8.28c3.01-2.41 8.67 2.64 13 0V4.08C13.61 7.14 8.01 1 5 4.08z"],flame:["M11.622 0c0 1.71.49 3.077 1.472 4.103C16.364 6.496 18 9.23 18 12.308c0 3.418-1.962 5.983-5.887 7.692 2.887-3 2.453-4.23-.49-8C8.5 13.5 9 14.5 9.5 16.5c-1.048 0-2 0-2.5-.5 0 .684 1.197 2.5 1.952 4-3.924-1.026-8.123-7.18-6.651-7.692.981-.342 2.126-.171 3.434.513C4.1 6.667 6.062 2.393 11.622 0z"],flash:["M4.96 6.37a1.003 1.003 0 001.42-1.42l-2-2a1.07 1.07 0 00-.71-.28 1.003 1.003 0 00-.71 1.71l2 1.99zm9.37.3c.28 0 .53-.11.71-.29l2-2a1.003 1.003 0 00-1.42-1.42l-2 2a1.003 1.003 0 00.71 1.71zM10 5c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1S9 .45 9 1v3c0 .55.45 1 1 1zm-5 5c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1zm14-1h-3c-.55 0-1 .45-1 1s.45 1 1 1h3c.55 0 1-.45 1-1s-.45-1-1-1zm-9-3c-2.21 0-4 1.79-4 4s1.79 4 4 4 4-1.79 4-4-1.79-4-4-4zm0 6c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zm5.04 1.63a1.003 1.003 0 00-1.42 1.42l2 2a1.003 1.003 0 001.42-1.42l-2-2zM10 15c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1s1-.45 1-1v-3c0-.55-.45-1-1-1zm-4.33-1.67c-.28 0-.53.11-.71.29l-2 2a1.003 1.003 0 001.42 1.42l2-2a1.003 1.003 0 00-.71-1.71z"],"floppy-disk":["M14 1h-3v5h3V1zm5.71 2.29l-3-3A.997.997 0 0016 0h-1v7H5V0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V4c0-.28-.11-.53-.29-.71zM17 19H3v-8c0-.55.45-1 1-1h12c.55 0 1 .45 1 1v8z"],"flow-branch":["M14.425 7.953a3.98 3.98 0 01.562 2.045 3.98 3.98 0 01-.583 2.08L18 15.671V12.98c0-.248.097-.496.29-.689.379-.379 1.047-.38 1.426 0a.94.94 0 01.283.696l-.001 5.049a.957.957 0 01-.276.69.955.955 0 01-.69.273h-5.059a.971.971 0 01-.689-.289 1.026 1.026 0 010-1.417.972.972 0 01.69-.29h2.702l-3.634-3.573a3.998 3.998 0 01-5.924-2.431H1a1 1 0 010-2h6.12a3.998 3.998 0 015.96-2.409L16.665 3l-2.694-.001a.972.972 0 01-.689-.29 1.035 1.035 0 010-1.425.94.94 0 01.696-.283l5.05.001c.248 0 .497.083.69.276a.954.954 0 01.272.69l.001 5.052a.971.971 0 01-.29.689 1.028 1.028 0 01-1.419 0 .972.972 0 01-.29-.69V4.323l-3.567 3.63z"],"flow-end":["M12 9.919a3.998 3.998 0 014-3.92c2.21 0 4 1.79 4 3.997a3.998 3.998 0 01-4 3.996 3.998 3.998 0 01-4-3.916.967.967 0 01-.28.612L7.685 14.71a.958.958 0 01-.686.285c-.536 0-.994-.461-.994-.997 0-.273.107-.528.283-.704l2.379-2.302H.98c-.537 0-.976-.46-.976-.996s.44-.992.976-.992h7.676L6.287 6.687a.957.957 0 01-.283-.686c0-.536.458-.996.994-.996.274 0 .51.1.686.285l4.027 4.024c.159.158.27.365.29.605z"],"flow-linear":["M5.125 10.997H.976C.439 10.997 0 10.537 0 10c0-.536.44-.993.976-.993h4.148a4.002 4.002 0 017.752 0h3.776L14.293 6.69a.962.962 0 01-.285-.687c0-.537.46-1.001.996-1.001a.96.96 0 01.698.3l4.005 4.015c.176.176.293.41.293.683a.972.972 0 01-.283.693L15.702 14.7a.997.997 0 01-.698.297c-.537 0-.996-.453-.996-.99 0-.273.107-.517.283-.692l2.371-2.318h-3.787a4.002 4.002 0 01-7.75 0z"],"flow-review":["M6.13 9.004A4.005 4.005 0 0110.012 6c1.87 0 3.44 1.278 3.881 3.005h2.768l-2.354-2.317a.97.97 0 01-.283-.691c0-.536.462-.995 1-.995.273 0 .517.107.693.283l4 4.041a.97.97 0 01.284.692.956.956 0 01-.293.682l-3.991 3.997a.944.944 0 01-.694.292c-.537 0-1-.46-1-.997a.97.97 0 01.284-.692l2.345-2.29h-2.765a4.005 4.005 0 01-3.875 2.981 4.005 4.005 0 01-3.874-2.981H3.349l2.376 2.308a.97.97 0 01.283.691 1 1 0 01-.994.983.989.989 0 01-.713-.291L.293 10.699A.956.956 0 010 10.017a.97.97 0 01.283-.692l4.03-4.037a.996.996 0 01.701-.283c.537 0 .994.464.994 1a.97.97 0 01-.283.691L3.34 9.004h2.79z"],"flow-review-branch":["M13.04 13.424c-.6.36-1.302.568-2.052.568a4 4 0 01-3.868-2.999H3.342l2.372 2.31c.176.176.283.42.283.694 0 .537-.452.998-.988.998a.935.935 0 01-.691-.289L.292 10.683A.96.96 0 010 9.999c0-.274.107-.518.283-.694l4.035-4.04a.973.973 0 01.691-.288c.536 0 .988.47.988 1.007a.975.975 0 01-.283.694L3.332 8.984h3.786a4 4 0 013.87-3.006c.771 0 1.492.22 2.102.599l3.565-3.57-2.538-.003a.974.974 0 01-.69-.29c-.38-.38-.38-1.052-.002-1.431A.94.94 0 0114.122 1l4.896.005a.96.96 0 01.69.277c.193.193.27.442.27.69l.005 4.9a.971.971 0 01-.289.69 1.023 1.023 0 01-1.416 0 .975.975 0 01-.29-.691l-.003-2.54-3.554 3.62c.351.596.553 1.291.553 2.034 0 .763-.213 1.477-.583 2.084l3.595 3.595.003-2.54c0-.249.097-.497.29-.69.38-.38 1.05-.381 1.429-.002a.94.94 0 01.282.697l-.005 4.9a.927.927 0 01-.277.675.974.974 0 01-.69.291L13.974 19a.97.97 0 01-.69-.29 1.03 1.03 0 01.002-1.42.974.974 0 01.69-.29l2.696-.003-3.632-3.573z"],flows:["M17.5 7.93a2.5 2.5 0 00-2.45 2h-2.3l-4.01-4-.75.75 3.26 3.25h-6.3a2.5 2.5 0 100 1h6.3l-3.26 3.25.75.75 4.01-4h2.3a2.5 2.5 0 102.45-3z"],"folder-close":["M0 17c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V7H0v10zM19 4H9.41l-1.7-1.71A.997.997 0 007 2H1c-.55 0-1 .45-1 1v3h20V5c0-.55-.45-1-1-1z"],"folder-new":["M12.994 7c0 1.655 1.344 3 2.998 3a3.002 3.002 0 002.999-3H20v10c0 .55-.45 1-1 1H1.01c-.55 0-1-.45-1-1V7h12.984zM10.76 6H0V3c0-.55.45-1 1-1h3.998c.28 0 .53.11.71.29L7.415 4h2.579c0 .768.29 1.469.765 2zm8.23-3c.55 0 1 .45 1 1s-.45 1-1 1h-1.998v2c0 .55-.45 1-1 1s-1-.45-1-1V5h-1.998c-.55 0-1-.45-1-1s.45-1 1-1h1.999V1c0-.55.45-1 .999-1 .55 0 1 .45 1 1v2h1.999z"],"folder-open":["M20 9c0-.55-.45-1-1-1H5c-.43 0-.79.27-.93.65h-.01l-3 8h.01c-.04.11-.07.23-.07.35 0 .55.45 1 1 1h14c.43 0 .79-.27.93-.65h.01l3-8h-.01c.04-.11.07-.23.07-.35zM3.07 7.63C3.22 7.26 3.58 7 4 7h14V5c0-.55-.45-1-1-1H8.41l-1.7-1.71A.997.997 0 006 2H1c-.55 0-1 .45-1 1v12.31l3.07-7.68z"],"folder-shared":["M11 4H9.41l-1.7-1.71A.997.997 0 007 2H1c-.55 0-1 .45-1 1v3h11.78C11.3 5.47 11 4.77 11 4zm8-1h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L12.3 9.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 6.41V9c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1zm-2.46 7.7l-1.42 1.42a2.996 2.996 0 11-4.24-4.24l.88-.88H0v10c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-5.18c-.31.11-.65.18-1 .18-1.02 0-1.92-.52-2.46-1.3z"],"folder-shared-open":["M3.07 7.63C3.22 7.26 3.58 7 4 7h7.76l.54-.54A2.97 2.97 0 0111 4H8.41l-1.7-1.71A.997.997 0 006 2H1c-.55 0-1 .45-1 1v12.31l3.07-7.68zm13.47 3.07l-1.42 1.42A2.996 2.996 0 0110 10c0-.77.3-1.47.78-2H5c-.43 0-.79.27-.93.65h-.01l-3 8h.01c-.04.11-.07.23-.07.35 0 .55.45 1 1 1h14c.43 0 .79-.27.93-.65h.01l2.01-5.36c-1-.01-1.88-.52-2.41-1.29zM19 3h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L12.3 9.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 6.41V9c0 .55.45 1 1 1s1-.45 1-1V4c0-.55-.45-1-1-1z"],follower:["M11.54 15.92c-1.48-.65-1.28-1.05-1.33-1.59-.01-.07-.01-.15-.01-.23.51-.45.92-1.07 1.19-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.34-.07.54-.44.61-.78.08-.14.23-.48.2-.87-.05-.5-.25-.73-.47-.82v-.09c0-.63-.06-1.55-.17-2.15-.02-.17-.06-.33-.11-.5a3.69 3.69 0 00-1.29-1.86C9.69 4.25 8.8 4 8.01 4c-.8 0-1.69.25-2.32.73-.61.47-1.06 1.13-1.28 1.86-.05.17-.09.33-.11.5-.12.6-.18 1.51-.18 2.14v.08c-.23.09-.44.32-.49.83-.04.39.12.73.2.87.08.35.28.72.63.78.04.17.09.33.15.48 0 .01.01.02.01.03l.01.01c.27.72.7 1.35 1.22 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.38 1.59-1.48.65-3.71 1.35-4.16 2.4C-.16 19.38.02 20 .02 20h15.95s.18-.62-.27-1.67c-.46-1.06-2.68-1.75-4.16-2.41zm8.15-12.63l-3-3a.956.956 0 00-.7-.29 1.003 1.003 0 00-.71 1.71L16.58 3H13c-.55 0-1 .45-1 1s.45 1 1 1h3.58l-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.3-.71z"],following:["M11.55 15.92c-1.48-.65-1.28-1.05-1.33-1.59-.01-.07-.01-.15-.01-.23.51-.45.92-1.07 1.19-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.34-.07.54-.44.61-.78.08-.14.23-.48.2-.87-.05-.5-.25-.73-.47-.82v-.09c0-.63-.06-1.55-.17-2.15-.02-.17-.06-.33-.11-.5a3.69 3.69 0 00-1.29-1.86C9.7 4.25 8.81 4 8.02 4c-.79 0-1.68.25-2.31.73-.61.47-1.07 1.13-1.29 1.86-.05.16-.09.33-.11.5-.12.6-.18 1.51-.18 2.14v.08c-.23.09-.44.32-.48.83-.04.39.12.73.2.87.08.35.28.72.63.78.04.17.09.33.15.48 0 .01.01.02.01.03l.01.01c.27.72.7 1.35 1.22 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.38 1.59C3 16.56.77 17.26.32 18.31-.15 19.38.04 20 .04 20h15.95s.18-.62-.27-1.67c-.46-1.06-2.69-1.75-4.17-2.41zM19 3h-3.58l1.29-1.29A1.003 1.003 0 0015.29.29l-3 3c-.17.18-.28.43-.28.71 0 .28.11.53.29.71l3 3c.18.18.43.29.7.29a1.003 1.003 0 00.71-1.71L15.42 5H19c.55 0 1-.45 1-1s-.45-1-1-1z"],font:["M17.93 18.64l-7-18C10.78.27 10.42 0 10 0s-.78.27-.93.64l-7 18c-.04.11-.07.23-.07.36 0 .55.45 1 1 1 .42 0 .78-.27.93-.64L6.41 13h7.19l2.47 6.36c.15.37.51.64.93.64.55 0 1-.45 1-1 0-.13-.03-.25-.07-.36zM7.18 11L10 3.76 12.82 11H7.18z"],fork:["M16.71 11.29a1.003 1.003 0 00-1.42 1.42l1.3 1.29h-2.17l-8-8h10.17L15.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3a1.003 1.003 0 00-1.42 1.42L16.59 4H1c-.55 0-1 .45-1 1s.45 1 1 1h2.59l9.71 9.71c.17.18.42.29.7.29h2.59l-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3z"],form:["M2 13v4h4v-4H2zm-1-2h6c.55 0 1 .45 1 1v6c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1v-6c0-.55.45-1 1-1zm11-7h7c.55 0 1 .45 1 1s-.45 1-1 1h-7c-.55 0-1-.45-1-1s.45-1 1-1zM8 1a1.003 1.003 0 01.71 1.71l-5 6C3.53 8.89 3.28 9 3 9s-.53-.11-.71-.29l-2-2a1.003 1.003 0 011.42-1.42L3 6.59l4.29-5.3C7.47 1.11 7.72 1 8 1zm4 13h7c.55 0 1 .45 1 1s-.45 1-1 1h-7c-.55 0-1-.45-1-1s.45-1 1-1z"],"full-circle":["M9.96 0a10 10 0 100 20 10 10 0 100-20z"],"full-stacked-chart":["M15 16h2c.55 0 1-.45 1-1v-5h-4v5c0 .55.45 1 1 1zM12 2c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v4h4V2zm6 4h-4v3h4V6zm0-4c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1v3h4V2zm-6 5H8v5h4V7zm-9 9h2c.55 0 1-.45 1-1v-3H2v3c0 .55.45 1 1 1zm6 0h2c.55 0 1-.45 1-1v-2H8v2c0 .55.45 1 1 1zm10 1H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM6 2c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v3h4V2zm0 4H2v5h4V6z"],fullscreen:["M3.41 2H6c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v5c0 .55.45 1 1 1s1-.45 1-1V3.41L7.29 8.7c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L3.41 2zM8 11c-.28 0-.53.11-.71.29L2 16.59V14c0-.55-.45-1-1-1s-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1H3.41l5.29-5.29c.19-.18.3-.43.3-.71 0-.55-.45-1-1-1zM19 0h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L11.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 3.41V6c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm0 13c-.55 0-1 .45-1 1v2.59l-5.29-5.29A.965.965 0 0012 11a1.003 1.003 0 00-.71 1.71l5.3 5.29H14c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1z"],function:["M10.14 5.82H8.73c.4-1.66.94-2.87 1.6-3.64.4-.48.8-.72 1.18-.72.08 0 .14.02.19.07.05.05.07.1.07.18 0 .07-.05.19-.16.37s-.16.36-.16.52c0 .23.08.43.25.59a.9.9 0 00.64.25c.28 0 .51-.1.7-.3.19-.2.28-.47.28-.81 0-.39-.14-.7-.42-.94-.28-.24-.74-.36-1.36-.36-.97 0-1.86.29-2.65.87-.79.56-1.54 1.52-2.26 2.85-.24.46-.48.75-.7.88-.22.13-.57.19-1.06.19l-.32 1.15H5.9l-1.99 7.85c-.33 1.29-.56 2.09-.67 2.39-.17.44-.43.81-.77 1.12a.74.74 0 01-.5.19c-.05 0-.1-.02-.14-.05l-.04-.07c0-.03.05-.1.15-.2.1-.1.15-.26.15-.47 0-.23-.08-.42-.23-.57-.16-.15-.38-.23-.67-.23-.35 0-.63.1-.85.29-.21.2-.32.43-.32.7 0 .29.13.54.39.75.25.22.65.33 1.2.33.88 0 1.66-.23 2.33-.69.68-.46 1.27-1.17 1.78-2.14.51-.96 1.03-2.52 1.56-4.66l1.14-4.54H9.8l.34-1.15zm6.8 1.95c.25-.2.51-.29.78-.29.1 0 .29.04.56.11.27.08.51.11.72.11.29 0 .52-.1.72-.3.18-.19.28-.45.28-.77 0-.33-.1-.6-.29-.8-.19-.2-.47-.29-.82-.29-.32 0-.62.08-.9.23-.28.15-.64.49-1.08 1-.33.38-.81 1.05-1.44 2a9.712 9.712 0 00-1.31-3.22l-3.4.59-.07.37c.25-.05.47-.08.64-.08.34 0 .62.15.84.44.35.46.84 1.85 1.46 4.19-.49.66-.82 1.09-1 1.3-.3.33-.55.54-.74.64-.15.08-.32.12-.51.12-.14 0-.38-.08-.7-.24-.22-.1-.42-.16-.59-.16-.33 0-.6.11-.82.32-.21.22-.32.49-.32.83 0 .31.1.57.3.77.2.2.47.29.8.29.32 0 .63-.07.92-.21.29-.14.64-.43 1.08-.88.43-.45 1.03-1.16 1.79-2.14.29.93.55 1.61.76 2.03.21.42.46.73.74.91.28.19.62.28 1.04.28.4 0 .81-.15 1.23-.44.55-.38 1.1-1.04 1.68-1.97l-.35-.21c-.39.55-.68.89-.87 1.03-.12.09-.27.13-.44.13-.2 0-.4-.13-.59-.38-.33-.43-.77-1.63-1.33-3.6.47-.86.89-1.44 1.23-1.71z"],"gantt-chart":["M4 7h5c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm3 2v1c0 .55.45 1 1 1h6c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1H8c-.55 0-1 .45-1 1zm12 3h-6c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm0 4H2V3c0-.55-.45-1-1-1s-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],geofence:["M8 11l.075.003.126.017.111.03.111.044.098.052.096.067.09.08c.036.035.068.073.097.112l.071.11.054.114.035.105.03.148L9 12V18a1 1 0 01-1.993.117L7 18v-3.586l-5.293 5.293a1 1 0 01-1.497-1.32l.083-.094L5.584 13h-3.58a1 1 0 01-.117-1.993L2.004 11H8zm3.018-11a1.003 1.003 0 01.39.087l.12.063.031.02.1.078 8.027 7.026.062.064.068.086.044.068.064.128.04.117.024.113.011.108v.1l-.007.073-.019.103-.037.121-.039.09-.05.087-4.996 7.994c-.06.097-.137.183-.226.254l-.093.067-.095.053-.087.037-.125.037a1.018 1.018 0 01-.218.026H11v-5a3 3 0 00-2.824-2.995L8 9H3V6a1 1 0 01.321-.734l.098-.08 7-5a1.01 1.01 0 01.45-.178L11.018 0z"],geolocation:["M0 8.33l9.17 2.5 2.5 9.17L20 0z"],geosearch:["M8 18.88c-3.79 0-6.88-3.09-6.88-6.88 0-.61.08-1.22.23-1.79.03.01.06-.01.1-.01h.09v.55c0 .23.21.42.44.42.04 0 .09-.01.12-.02l.9.88c.09.09.23.09.32 0s.09-.23 0-.32l-.86-.9c0-.02.05-.04.05-.07v-.13c0-.18.1-.25.29-.41h.53c.1 0 .19-.01.27-.05.01-.01.02 0 .03-.01.02-.01.03-.02.05-.04.01-.01.02-.01.02-.02l.02-.02 1.13-1.13c-.16-.32-.3-.65-.42-.99h-.64v-.53c0-.01.06.06.06-.1h.38c-.04-.16-.08-.32-.1-.48h-.71c.2-.16.42-.31.64-.45C4.02 6.09 4 5.8 4 5.5c0-.14.01-.28.02-.43C1.62 6.46 0 9.04 0 12c0 4.41 3.59 8 8 8 3.87 0 7.09-2.77 7.82-6.44l-.97-1.1c-.26 3.57-3.23 6.42-6.85 6.42zm-2.12-3.67v-.35h.15c.29 0 .49-.23.49-.53v-.68c0-.01.01-.01 0-.02L4.71 11.8h-.77c-.29 0-.47.24-.47.53v2c0 .29.18.53.47.53h.33v2.02c0 .28.28.51.56.51s.56-.23.56-.51v-1.22h-.01c.29 0 .5-.16.5-.45zm13.83-2.92l-3.68-3.68c.14-.21.27-.42.38-.65.02-.04.04-.07.05-.11.11-.22.2-.45.28-.69v-.01c.07-.24.13-.48.17-.73l.03-.17c.04-.24.06-.49.06-.75C17 2.46 14.54 0 11.5 0S6 2.46 6 5.5 8.46 11 11.5 11c.26 0 .51-.02.76-.06l.17-.03c.25-.04.49-.1.73-.17h.01c.24-.08.47-.17.69-.28.04-.02.07-.04.11-.05.23-.11.44-.24.65-.38l3.68 3.68c.17.18.42.29.7.29a1.003 1.003 0 00.71-1.71zM11.5 9.5c-2.21 0-4-1.79-4-4s1.79-4 4-4 4 1.79 4 4-1.79 4-4 4zm1.93 5.33v-.65c0-.11-.13-.21-.24-.21-.11 0-.24.09-.24.21v.65c0 .11.13.21.24.21.11 0 .24-.1.24-.21zm-2.41.67h.83c.29 0 .46-.21.46-.5v-1.86l.23-.22c-.34.05-.69.08-1.04.08-.36 0-.7-.03-1.05-.08.03.05.06.1.08.16V15c.01.29.2.5.49.5z"],"git-branch":["M15 2c-1.66 0-3 1.34-3 3 0 1.3.84 2.4 2 2.82V9c0 1.1-.9 2-2 2H8c-.73 0-1.41.21-2 .55V5.82C7.16 5.4 8 4.3 8 3c0-1.66-1.34-3-3-3S2 1.34 2 3c0 1.3.84 2.4 2 2.82v8.37C2.84 14.6 2 15.7 2 17c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.25-.77-2.3-1.85-2.75C6.45 13.52 7.16 13 8 13h4c2.21 0 4-1.79 4-4V7.82C17.16 7.4 18 6.3 18 5c0-1.66-1.34-3-3-3zM5 2c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm0 16c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zM15 6c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-commit":["M19 9h-4.1a5 5 0 00-9.8 0H1c-.55 0-1 .45-1 1s.45 1 1 1h4.1a5 5 0 009.8 0H19c.55 0 1-.45 1-1s-.45-1-1-1zm-9 4c-1.66 0-3-1.34-3-3s1.34-3 3-3 3 1.34 3 3-1.34 3-3 3z"],"git-merge":["M15 8c-1.3 0-2.4.84-2.82 2H11c-2.49 0-4.54-1.83-4.92-4.21A2.995 2.995 0 005 0C3.34 0 2 1.34 2 3c0 1.3.84 2.4 2 2.81v8.37C2.84 14.6 2 15.7 2 17c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.3-.84-2.4-2-2.82V9.86C7.27 11.17 9.03 12 11 12h1.18A2.996 2.996 0 0018 11c0-1.66-1.34-3-3-3zM5 18c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zM5 4c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm10 8c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-new-branch":["M17 3h-1V2c0-.55-.45-1-1-1s-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1V5h1c.55 0 1-.45 1-1s-.45-1-1-1zm-3 4.86V9c0 1.1-.9 2-2 2H8c-.73 0-1.41.21-2 .55V5.82C7.16 5.4 8 4.3 8 3c0-1.66-1.34-3-3-3S2 1.34 2 3c0 1.3.84 2.4 2 2.82v8.37C2.84 14.6 2 15.7 2 17c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.25-.77-2.3-1.85-2.75C6.45 13.52 7.16 13 8 13h4c2.21 0 4-1.79 4-4V7.86c-.32.08-.65.14-1 .14s-.68-.06-1-.14zM5 2c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm0 16c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-pull":["M17 14.18V7c0-2.21-1.79-4-4-4h-2.59l1.29-1.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C7.11 3.47 7 3.72 7 4c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L10.41 5H13c1.1 0 2 .9 2 2v7.18A2.996 2.996 0 0016 20c1.66 0 3-1.34 3-3 0-1.3-.84-2.4-2-2.82zM16 18c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zM4 1C2.34 1 1 2.34 1 4c0 1.3.84 2.4 2 2.82v7.37C1.84 14.6 1 15.7 1 17c0 1.66 1.34 3 3 3s3-1.34 3-3c0-1.3-.84-2.4-2-2.82V6.82C6.16 6.4 7 5.3 7 4c0-1.66-1.34-3-3-3zm0 17c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zM4 5c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"git-push":["M15 11c0-.28-.11-.53-.29-.71l-3-3C11.53 7.11 11.28 7 11 7s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42l1.29-1.3V19c0 .55.45 1 1 1s1-.45 1-1v-8.59l1.29 1.29c.18.19.43.3.71.3.55 0 1-.45 1-1zm4-11H1C.45 0 0 .45 0 1v16c0 .55.45 1 1 1h7v-2H2v-2h6v-1H4V2h14v11h-4v1h4v2h-4v2h5c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM5 8h2V6H5v2zm2-5H5v2h2V3z"],"git-repo":["M7 3H5v2h2V3zm0 6H5v2h2V9zm0-3H5v2h2V6zm12-6H1C.45 0 0 .45 0 1v16c0 .55.45 1 1 1h4v2l2-1 2 1v-2h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 16H9v-1H5v1H2v-2h16v2zm0-3H4V2h14v11z"],glass:["M17 6V0H3v6c0 3.53 2.61 6.43 6 6.92V18H6c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1h-3v-5.08c3.39-.49 6-3.39 6-6.92z"],globe:["M7.53 4.37c.1-.1.1-.26 0-.35l-.68-.68c-.1-.1-.25-.1-.35 0-.1.1-.1.26 0 .35l.68.68c.1.1.25.1.35 0zm3.17.06h.3c.09 0 .16-.01.16-.1 0-.09-.07-.1-.16-.1h-.3c-.09 0-.16.01-.16.1s.07.1.16.1zm.98 1.15c.09 0 .19-.08.19-.17v-.42c0-.09-.1-.17-.19-.17s-.19.08-.19.17v.42c0 .09.1.17.19.17zm-6.5 4.19c-.35 0-.56.28-.56.63v2.37c0 .35.21.62.56.62h.39v2.4c0 .34.33.61.67.61s.67-.27.67-.61v-1.44h-.02c.35 0 .6-.19.6-.54v-.41h.18c.35 0 .58-.28.58-.62v-.81c0-.01.01-.01 0-.02L6.1 9.77h-.92zM10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8 0-.74.11-1.46.3-2.14h.03v.65c0 .28.25.5.53.5.05 0 .1-.01.15-.02l1.05 1.05c.1.11.28.11.38 0 .1-.1.11-.27 0-.38L3.42 8.59c0-.03.05-.05.05-.08v-.16c0-.22.12-.3.34-.49h.63c.12 0 .23-.01.32-.07.01-.01.02 0 .03-.01.02-.02.04-.03.06-.04.01-.01.02-.01.03-.02l.02-.02 2.15-2.15c.24-.24.24-.63 0-.86-.23-.24-.62-.19-.86.04l-.41.46H5v-.64c0-.01.07.07.07-.12h.87c.17 0 .3-.12.3-.29 0-.17-.13-.29-.3-.29H4.88C6.27 2.7 8.05 2 10 2s3.73.7 5.12 1.86h-1.58l-.01-.04c-.06 0-.12 0-.17.04l-.71.7c-.09.09-.09.23 0 .31.09.09.23.09.32 0l.56-.6.01-.03h.34c0 .19-.1.13-.1.16v.1c0 .29-.2.5-.49.5h-.51c-.25 0-.52.28-.52.54v.23h-.12c-.16 0-.27.08-.27.24v.33h-.32c-.23 0-.41.15-.41.38 0 .22.18.35.41.35.1 0 .19.04.26-.16l.06.01.66-.59h.23l.53.5c.04.04.11.03.16-.01.04-.04.04-.16 0-.2L13 6.15h.32l.12.16c.25.25.65.23.89-.02l.12-.14H15c.02 0 .11.07.11.07v.33s-.06-.01-.07-.01h-.49c-.16 0-.28.13-.28.29 0 .16.13.29.28.29h.49c.01 0 .07-.01.07-.01v.2c-.19.28-.33.57-.62.57h-1.28s0-.01-.01-.01l-.58-.58a.622.622 0 00-.89 0l-.58.58s0 .01-.01.01h-.34c-.35 0-.67.28-.67.63v1.25c0 .35.32.61.67.61h1.22c.46.19.78.48.97.94v2.28c0 .35.23.6.58.6h.98c.35 0 .54-.25.54-.6v-2.2l1.21-1.17.04-.02.02-.01h.04c.1-.11.2-.26.2-.42V8.49c0-.25-.22-.44-.42-.63h.58c.02.38.29.57.63.57h.43c.13.51.18 1.03.18 1.57 0 4.42-3.58 8-8 8zm6.16-5.65c-.14 0-.29.11-.29.25v.77c0 .14.15.25.29.25.14 0 .29-.11.29-.25v-.77c0-.14-.15-.25-.29-.25zM10.5 3.48c0-.34-.28-.57-.62-.57h-.74c-.34 0-.57.25-.57.59 0 .05-.13.06.06.1v.64c0 .2.09.36.29.36.2 0 .29-.16.29-.36v-.19h.68c.33 0 .61-.23.61-.57z"],"globe-network":["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm7.39 7h-3.63c-.31-1.99-.92-3.66-1.72-4.73 2.45.65 4.41 2.42 5.35 4.73zM13 10c0 .69-.04 1.36-.11 2H7.11a18.419 18.419 0 010-4h5.77c.08.64.12 1.31.12 2zm-3-8c1.07 0 2.25 2.05 2.75 5h-5.5c.5-2.95 1.68-5 2.75-5zm-2.04.27C7.16 3.34 6.55 5.01 6.24 7H2.61c.94-2.31 2.9-4.08 5.35-4.73zM2 10c0-.69.11-1.36.28-2h3.83a18.419 18.419 0 000 4H2.28c-.17-.64-.28-1.31-.28-2zm.61 3h3.63c.31 1.99.92 3.66 1.72 4.73A7.996 7.996 0 012.61 13zM10 18c-1.07 0-2.25-2.05-2.75-5h5.5c-.5 2.95-1.68 5-2.75 5zm2.04-.27c.79-1.07 1.4-2.74 1.72-4.73h3.63a7.996 7.996 0 01-5.35 4.73zM13.89 12a18.419 18.419 0 000-4h3.83c.17.64.28 1.31.28 2s-.11 1.36-.28 2h-3.83z"],graph:["M17.5 4A2.5 2.5 0 0015 6.5c0 .06.01.12.02.18l-1.9.84C12.38 6.6 11.27 6 10 6c-.83 0-1.59.25-2.23.68L4.91 4.14c.05-.21.09-.42.09-.64a2.5 2.5 0 00-5 0A2.5 2.5 0 002.5 6c.42 0 .81-.11 1.16-.3l2.79 2.48C6.17 8.73 6 9.34 6 10c0 1.41.73 2.64 1.83 3.35l-.56 1.67A2.498 2.498 0 005 17.5a2.5 2.5 0 005 0c0-.74-.32-1.39-.83-1.85l.56-1.68c.09.01.18.03.27.03 2.21 0 4-1.79 4-4 0-.22-.03-.44-.07-.65l2.02-.9c.43.34.96.55 1.55.55a2.5 2.5 0 000-5z"],"graph-remove":["M17.41 4l2.29-2.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L16 2.59 13.71.3A.965.965 0 0013 0a1.003 1.003 0 00-.71 1.71L14.59 4 12.3 6.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L16 5.41l2.29 2.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L17.41 4zM19 10c-.83 0-1.55-.36-2.09-.91l-.03.03-.88-.88-.88.88a2.996 2.996 0 11-4.24-4.24l.88-.88-.88-.88.03-.03C10.36 2.55 10 1.83 10 1c0-.35.07-.68.18-.99-.06 0-.12-.01-.18-.01C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10c0-.06-.01-.12-.01-.18-.31.11-.64.18-.99.18z"],"greater-than":["M12.838 10l-9.154 3.051a1 1 0 00.632 1.898l12-4c.912-.304.912-1.594 0-1.898l-12-4a1 1 0 00-.632 1.898L12.838 10z"],"greater-than-or-equal-to":["M3.684 11.051a1 1 0 00.632 1.898l12-4c.912-.304.912-1.594 0-1.898l-12-4a1 1 0 00-.632 1.898L12.838 8l-9.154 3.051zM4 15h12a1 1 0 110 2H4a1 1 0 010-2z"],grid:["M19 11c.55 0 1-.45 1-1s-.45-1-1-1h-2V5h2c.55 0 1-.45 1-1s-.45-1-1-1h-2V1c0-.55-.45-1-1-1s-1 .45-1 1v2h-4V1c0-.55-.45-1-1-1S9 .45 9 1v2H5V1c0-.55-.45-1-1-1S3 .45 3 1v2H1c-.55 0-1 .45-1 1s.45 1 1 1h2v4H1c-.55 0-1 .45-1 1s.45 1 1 1h2v4H1c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1v-2h4v2c0 .55.45 1 1 1s1-.45 1-1v-2h4v2c0 .55.45 1 1 1s1-.45 1-1v-2h2c.55 0 1-.45 1-1s-.45-1-1-1h-2v-4h2zM9 15H5v-4h4v4zm0-6H5V5h4v4zm6 6h-4v-4h4v4zm0-6h-4V5h4v4z"],"grid-view":["M0 19c0 .55.45 1 1 1h8v-9H0v8zM0 1v8h9V0H1C.45 0 0 .45 0 1zm19-1h-8v9h9V1c0-.55-.45-1-1-1zm-8 20h8c.55 0 1-.45 1-1v-8h-9v9z"],"group-objects":["M6 7c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3zm8-3H6c-3.31 0-6 2.69-6 6s2.69 6 6 6h8c3.31 0 6-2.69 6-6s-2.69-6-6-6zm0 11H6c-2.76 0-5-2.24-5-5s2.24-5 5-5h8c2.76 0 5 2.24 5 5s-2.24 5-5 5zm0-8c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3z"],"grouped-bar-chart":["M12 16h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1h-1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1zm7 1H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm-3-1h1c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1h-1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1zm-9 0h1c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1H7c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1zm-4 0h1c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v13c0 .55.45 1 1 1z"],hand:["M17 5c-.42 0-.79.27-.93.64L14.38 10h-.77l1.34-6.67c.03-.1.05-.21.05-.33a.998.998 0 00-1.98-.19h-.01L11.57 10H11V1c0-.55-.45-1-1-1S9 .45 9 1v9h-.2L6.97 2.76a.997.997 0 00-1.73-.41l-.03.03c-.01.02-.02.03-.03.04-.01.02-.01.03-.02.04v.01c-.01.01-.02.02-.02.03v.01c-.02.01-.02.02-.03.03 0 0 0 .01-.01.01 0 .01 0 .02-.01.03 0 0 0 .01-.01.01 0 .01-.01.02-.01.03 0 0 0 .01-.01.01 0 .01-.01.02-.01.03 0 .01 0 .01-.01.02 0 .01-.01.02-.01.03 0 .01 0 .01-.01.02 0 .01-.01.02-.01.03v.02c0 .01 0 .02-.01.03V3c0 .05 0 .09.01.14l1.45 10.25L6 12.7v.01L3.84 9.45h-.01A.98.98 0 003 9c-.55 0-1 .45-1 1 0 .2.06.39.17.55L6 18.44C7.06 19.4 8.46 20 10 20c3.31 0 6-2.69 6-6v-1.84l.01-.03v-.06l1.94-5.75A1.003 1.003 0 0017 5z"],"hand-down":["M17.68 9.84C15.91 9 14.27 6.49 13.45 4.9 12.41 2.43 12.21 0 7.87 0 5.49 0 3.95.76 3.05 2.65 2.31 4.2 2 5.48 2 9.79v.99c0 .82.69 1.48 1.54 1.48.38 0 .73-.14 1-.36.19.6.78 1.05 1.47 1.05.47 0 .89-.2 1.17-.52.26.47.77.79 1.36.79.65 0 1.2-.39 1.43-.93l.03.77v5.44c0 .48.23.91.59 1.18.21.19.5.32.85.32h.06c.83 0 1.5-.67 1.5-1.5v-8.24l.01-.67c.85.98 1.92 1.76 3.24 1.89 1.79.19 2.09-1.33 1.43-1.64z"],"hand-left":["M15.1 6.54c-1.58-.81-4.09-2.46-4.94-4.23-.31-.65-1.82-.35-1.64 1.43.13 1.33.91 2.4 1.89 3.24L9.74 7H1.5C.67 7 0 7.67 0 8.5v.06c0 .36.13.64.32.85.27.36.7.59 1.18.59h5.44l.78.01c-.54.23-.93.78-.93 1.43 0 .59.32 1.1.79 1.36-.32.28-.52.7-.52 1.17 0 .69.44 1.28 1.05 1.47-.22.27-.36.62-.36 1 0 .85.66 1.54 1.48 1.54h.99c4.31 0 5.59-.31 7.14-1.05 1.89-.9 2.65-2.44 2.65-4.82-.01-4.32-2.44-4.52-4.91-5.57z"],"hand-right":["M20 8.5c0-.83-.67-1.5-1.5-1.5h-8.24l-.67-.01c.98-.85 1.76-1.92 1.89-3.24.18-1.79-1.33-2.08-1.65-1.43-.84 1.76-3.35 3.41-4.93 4.23C2.43 7.59 0 7.79 0 12.13c0 2.38.76 3.92 2.65 4.82C4.2 17.69 5.48 18 9.79 18h.99c.82 0 1.48-.69 1.48-1.54 0-.38-.14-.73-.36-1 .6-.19 1.05-.78 1.05-1.47 0-.47-.2-.89-.52-1.17.47-.26.79-.77.79-1.36 0-.65-.39-1.2-.93-1.43l.77-.03h5.44c.48 0 .91-.23 1.18-.59.19-.21.32-.49.32-.85v-.03-.03z"],"hand-up":["M16.46 7.74c-.38 0-.73.14-1 .36-.19-.6-.78-1.05-1.47-1.05-.47 0-.89.2-1.17.52-.26-.47-.77-.79-1.36-.79-.65 0-1.2.39-1.43.93L10 6.94V1.5c0-.48-.23-.91-.59-1.18C9.2.13 8.92 0 8.56 0H8.5C7.67 0 7 .67 7 1.5v8.24l-.01.67c-.84-.98-1.92-1.76-3.24-1.89-1.79-.18-2.08 1.33-1.43 1.65 1.77.84 3.41 3.35 4.23 4.94 1.05 2.47 1.25 4.9 5.58 4.9 2.38 0 3.92-.76 4.82-2.65.74-1.56 1.05-2.84 1.05-7.15v-.99c0-.81-.69-1.48-1.54-1.48z"],hat:["M18.5 13c1.118 0 1.466.534 1.498 1.366L20 14.5v.5c0 1.945-5.69 3-10 3S0 16.945 0 15v-.5c0-.908.323-1.5 1.5-1.5.895 0 3.5 1.2 8.5 1.2l.411-.003C15.143 14.134 17.631 13 18.5 13zm-5-10c1.725 0 2.954 2.729 3.688 8.186-1.455.263-3.805.72-6.392.801l-.434.01L10 12c-2.896 0-5.585-.524-7.189-.814C3.546 5.73 4.775 3 6.5 3 8.6 3 8.329 5.5 10 5.5S11.5 3 13.5 3z"],header:["M16 1c-.55 0-1 .45-1 1v7H5V2c0-.55-.45-1-1-1s-1 .45-1 1v16c0 .55.45 1 1 1s1-.45 1-1v-7h10v7c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],"header-one":["M10 0c.55 0 1 .45 1 1v14c0 .55-.45 1-1 1s-1-.45-1-1V9H2v6c0 .55-.45 1-1 1s-1-.45-1-1V1c0-.55.45-1 1-1s1 .45 1 1v6h7V1c0-.55.45-1 1-1zm7.4 10.77c.17-.2.29-.46.34-.77H19v10h-1.5v-7.11H15v-1.24c.32 0 .63-.03.93-.08.31-.06.58-.16.83-.29.26-.12.47-.3.64-.51z"],"header-three":["M10.989 1c0-.55-.45-1-.999-1-.55 0-.999.45-.999 1v6H1.998V1c0-.55-.45-1-.999-1C.449 0 0 .45 0 1v14c0 .55.45 1 .999 1 .55 0 .999-.45.999-1V9h6.993v6c0 .55.45 1 .999 1 .55 0 .999-.45.999-1V1zm7.461 13.645c.49.11.87.38 1.14.82.27.44.41.97.41 1.61a3 3 0 01-.24 1.23c-.16.36-.38.67-.66.92-.27.25-.59.44-.96.58-.37.14-.75.21-1.16.21-.5 0-.93-.08-1.3-.24a2.55 2.55 0 01-.93-.68c-.25-.29-.44-.65-.57-1.06-.13-.42-.2-.88-.21-1.38h1.39c-.02.58.11 1.07.38 1.46.28.39.68.58 1.23.58.47 0 .86-.15 1.17-.45.31-.3.47-.72.47-1.27 0-.37-.07-.67-.2-.89-.13-.22-.3-.39-.51-.5-.21-.11-.45-.18-.71-.21-.26-.03-.53-.04-.81-.03v-1.17c.22.01.45 0 .68-.05.23-.05.43-.13.61-.24.18-.11.32-.27.43-.47.11-.2.16-.45.16-.74 0-.41-.12-.74-.37-.99s-.57-.37-.96-.37c-.24 0-.45.06-.63.17-.18.11-.33.26-.45.45s-.2.4-.26.63c-.05.23-.08.47-.07.72h-1.39c.01-.47.09-.9.23-1.3s.33-.75.57-1.04c.24-.3.53-.53.87-.69.34-.17.73-.25 1.16-.25.33 0 .66.05.98.16.32.11.61.27.87.48.26.21.47.47.62.8.15.32.23.7.23 1.12 0 .48-.09.91-.29 1.27-.2.36-.5.63-.92.79v.02z"],"header-two":["M16.6 17.41c-.22.17-.4.36-.56.55-.16.19-.27.4-.33.61h4.28V20H14c.01-.81.18-1.52.53-2.13.35-.6.81-1.13 1.41-1.58.28-.23.58-.46.89-.68.31-.22.59-.46.85-.71.26-.26.48-.53.63-.83.16-.3.25-.64.26-1.02 0-.18-.02-.37-.06-.57-.04-.2-.11-.39-.22-.56s-.26-.31-.45-.43-.44-.18-.75-.18c-.28 0-.52.06-.71.19s-.34.3-.45.52c-.11.22-.2.48-.25.78-.05.3-.08.62-.09.97h-1.43c0-.54.07-1.04.2-1.5.13-.47.32-.87.58-1.2.26-.34.58-.6.95-.78.37-.19.81-.29 1.3-.29.54 0 .99.09 1.35.29.36.19.65.44.87.74.22.29.38.62.47.97.09.35.14.68.14 1 0 .4-.05.75-.16 1.07-.11.32-.26.61-.44.88-.19.27-.4.52-.63.74-.24.22-.48.43-.73.63s-.5.38-.75.56c-.26.17-.5.35-.71.53zM10 0c.55 0 1 .45 1 1v14c0 .55-.45 1-1 1s-1-.45-1-1V9H2v6c0 .55-.45 1-1 1s-1-.45-1-1V1c0-.55.45-1 1-1s1 .45 1 1v6h7V1c0-.55.45-1 1-1z"],headset:["M18.97 9H19A9 9 0 001 9h.03C.41 9.73 0 10.8 0 12c0 1.74.84 3.2 2 3.76V16c0 1.66 1.34 3 3 3h3c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1H5c-.55 0-1-.45-1-1 .55 0 1-.45 1-1V9c0-.55-.45-1-1-1h-.92C3.57 4.61 6.47 2 10 2s6.43 2.61 6.92 6H16c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h1c1.66 0 3-1.79 3-4 0-1.2-.41-2.27-1.03-3z"],heart:["M20 6.25C20 3.35 17.65 1 14.75 1c-1.02 0-1.95.31-2.75.82v-.04c-.09.06-.17.12-.26.19-.04.03-.09.06-.14.1-.68.51-1.24 1.18-1.6 1.96-.4-.86-1.04-1.57-1.8-2.1-.04-.02-.07-.05-.1-.08a7 7 0 00-.6-.33c-.13-.04-.23-.1-.35-.15-.05-.02-.1-.05-.15-.07v.02C6.45 1.13 5.87 1 5.25 1A5.25 5.25 0 000 6.25c0 .09.01.17.01.25H0c0 .06.01.12.02.18s.01.12.02.18C.13 7.89.44 9 1.07 10.17 2.23 12.33 4.1 14.11 7 16.53v.01c.9.75 1.89 1.55 3 2.46.71-.58 1.38-1.12 2-1.63 3.48-2.86 5.64-4.78 6.93-7.18.63-1.17.94-2.27 1.03-3.3.01-.07.01-.14.02-.21 0-.06.01-.11.02-.17h-.01c0-.09.01-.17.01-.26z"],"heart-broken":["M8.11 7.45C8.05 7.31 8 7.16 8 7c0-.07.03-.13.04-.19h-.02l.86-4.32A5.159 5.159 0 005.25 1 5.25 5.25 0 000 6.25c0 .09.01.17.01.25H0c0 .06.01.12.02.18s.01.12.02.18C.13 7.89.44 9 1.07 10.17c1.38 2.58 3.76 4.6 7.71 7.83l-.76-3.8h.02c-.01-.07-.04-.13-.04-.2 0-.21.08-.39.18-.54l-.02-.01 1.68-2.52-1.73-3.48zM20 6.25C20 3.35 17.65 1 14.75 1c-1.54 0-2.92.67-3.88 1.73l-.83 4.13 1.85 3.69h-.01c.07.14.12.29.12.45 0 .21-.08.39-.18.54l.02.01-1.77 2.66.81 4.07c4.16-3.39 6.63-5.45 8.05-8.1.63-1.17.94-2.27 1.03-3.3.01-.07.01-.14.02-.21 0-.06.01-.11.02-.17h-.01c0-.08.01-.16.01-.25z"],"heat-grid":["M14 12h6V8h-6v4zM0 12h6V8H0v4zm1-3h4v2H1V9zm-1 7c0 .55.45 1 1 1h5v-4H0v3zM19 3h-5v4h6V4c0-.55-.45-1-1-1zm0 3h-4V4h4v2zM0 4v3h6V3H1c-.55 0-1 .45-1 1zm7 3h6V3H7v4zm7 10h5c.55 0 1-.45 1-1v-3h-6v4zm-7 0h6v-4H7v4zm1-3h4v2H8v-2zm-1-2h6V8H7v4z"],heatmap:["M6 0a6 6 0 100 12A6 6 0 106 0z","M10.5 8a4.5 4.5 0 100 9 4.5 4.5 0 100-9z","M16.5 7a3.5 3.5 0 100 7 3.5 3.5 0 100-7zM18 16a2 2 0 100 4 2 2 0 100-4zM2.5 14a2.5 2.5 0 100 5 2.5 2.5 0 100-5zM16.5 0a2.5 2.5 0 100 5 2.5 2.5 0 100-5z"],helicopter:["M10 3v2H1V3.5a.5.5 0 00-1 0v5a.5.5 0 001 0V7l5 2c0 1.54.824 3.575 3 4.835V16H5.5a.5.5 0 100 1H16.5a.5.5 0 00.224-.053l2-1a.5.5 0 10-.448-.894L16.382 16H15v-1.1A5.002 5.002 0 0014 5h-1V3h6.5a.5.5 0 000-1h-16a.5.5 0 000 1H10zm4 13v-1c-1.608 0-2.928-.258-4-.683V16h4zm0-6V6a4 4 0 014 4h-4z"],help:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM7.41 4.62c.65-.54 1.51-.82 2.56-.82.54 0 1.03.08 1.48.25.44.17.83.39 1.14.68.32.29.56.63.74 1.02.17.39.26.82.26 1.27s-.08.87-.24 1.23c-.16.37-.4.73-.71 1.11l-1.21 1.58c-.14.17-.28.33-.32.48-.05.15-.11.35-.11.6v.97H9v-2s.06-.58.24-.81l1.21-1.64c.25-.3.41-.56.51-.77s.14-.44.14-.67c0-.35-.11-.63-.32-.85s-.5-.33-.88-.33c-.37 0-.67.11-.89.33-.22.23-.37.54-.46.94-.03.12-.11.17-.23.16l-1.95-.29c-.12-.01-.16-.08-.14-.22.13-.93.52-1.67 1.18-2.22zM9 14h2.02L11 16H9v-2z"],"helper-management":["M17 10h-3v3h3v-3zm0 4h-3v3h3v-3zm0-8h-3v3h3V6zm2-6H1C.4 0 0 .4 0 1v18c0 .5.4 1 1 1h18c.5 0 1-.5 1-1V1c0-.6-.5-1-1-1zm-1 18H2V2h16v16zm-9-4H6v3h3v-3zm4 0h-3v3h3v-3z"],"high-priority":["M12 16v4H8v-4h4zm1-16l-1 14H8L7 0h6z"],highlight:["M11.22 14.09l3.03-3.03.71.71L20 6.73l-5.71-5.71-5.04 5.04.71.71-3.02 3.04 4.28 4.28zm6.8 3.91h-16c-.55 0-1 .45-1 1s.45 1 1 1h16c.55 0 1-.45 1-1s-.45-1-1-1zm-15-1h4.04c.28 0 .53-.11.71-.3l2.02-2.02-3.44-3.45-4.04 4.04c-.18.18-.3.44-.3.71.01.57.46 1.02 1.01 1.02z"],history:["M10 0C6.71 0 3.82 1.6 2 4.05V2c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.76C5.23 3.17 7.47 2 10 2c4.42 0 8 3.58 8 8s-3.58 8-8 8-8-3.58-8-8c0-.55-.45-1-1-1s-1 .45-1 1c0 5.52 4.48 10 10 10s10-4.48 10-10S15.52 0 10 0zm0 3c-.55 0-1 .45-1 1v6c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L11 9.59V4c0-.55-.45-1-1-1z"],home:["M2 12v7c0 .55.45 1 1 1h5v-7h4v7h5c.55 0 1-.45 1-1v-7l-8-8-8 8zm17.71-2.71L17 6.59V3c0-.55-.45-1-1-1s-1 .45-1 1v1.59L10.71.3C10.53.11 10.28 0 10 0s-.53.11-.71.29l-9 9a1.003 1.003 0 001.42 1.42L10 2.41l8.29 8.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"horizontal-bar-chart":["M1 1c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1zm3 5h11c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1zm8 8H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h8c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1zm7-6H4c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h15c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1z"],"horizontal-bar-chart-asc":["M1 9h11c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm0-5h9c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm18 12H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zM1 14h14c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1z"],"horizontal-bar-chart-desc":["M10 16H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm2-5H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h11c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm3-5H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1zm4-5H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1z"],"horizontal-distribution":["M12 2H8c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zM1 0C.45 0 0 .45 0 1v18c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm18 0c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],hurricane:["M0 14c1.648.775 3 1 4 1-1-1-2-3.112-2-5a5.098 5.098 0 000-.045C2 5.17 6.201 1 11.172 1c3.206 0 6.9.667 8.828 5-1.648-.775-3-1-4-1 1 1 2 3.112 2 5v.045C18 14.83 13.799 19 8.828 19c-3.206 0-6.9-.667-8.828-5zm10-7a3 3 0 100 6 3 3 0 000-6z"],"id-number":["M2 5v10h16V5H2zm0-2h16c1.1 0 2 .9 2 2v10c0 1.1-.9 2-2 2H2c-1.1 0-2-.9-2-2V5c0-1.1.9-2 2-2z","M8.88 12.38c-.17-.39-1.01-.66-1.56-.9-.56-.24-.48-.39-.5-.6v-.09c.19-.17.35-.4.45-.67 0 0 0-.02.01-.02l.06-.18c.13-.03.2-.17.23-.29.03-.05.09-.18.08-.33-.04-.18-.11-.27-.2-.3v-.03c0-.24-.02-.58-.06-.81-.01-.06-.02-.12-.04-.19-.08-.27-.25-.52-.48-.7C6.63 7.09 6.3 7 6 7s-.63.09-.87.27c-.23.17-.4.42-.48.7-.02.06-.03.13-.04.19-.04.22-.06.57-.06.81V9c-.09.03-.17.12-.19.31-.01.14.05.27.08.32.03.14.1.27.23.3.02.06.03.12.06.18v.01c.11.27.27.51.47.68v.08c-.02.2.04.35-.51.6-.56.24-1.39.51-1.56.9-.19.39-.12.62-.12.62h5.98c-.01 0 .06-.23-.11-.62zM12 7h4c.55 0 1 .45 1 1s-.45 1-1 1h-4c-.55 0-1-.45-1-1s.45-1 1-1zM12 11h4c.55 0 1 .45 1 1s-.45 1-1 1h-4c-.55 0-1-.45-1-1s.45-1 1-1z"],"image-rotate-left":["M10.5 13c.83 0 1.5-.67 1.5-1.5s-.67-1.5-1.5-1.5-1.5.67-1.5 1.5.67 1.5 1.5 1.5zM14 7H1c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-1 10l-5-3-1 2-2-4-3 4.5V9h11v8zm3-15h-1.59l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H16c1.1 0 2 .9 2 2v3c0 .55.45 1 1 1s1-.45 1-1V6c0-2.21-1.79-4-4-4z"],"image-rotate-right":["M5.29 4.29a1.003 1.003 0 001.42 1.42l2-2C8.89 3.53 9 3.28 9 3c0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l.3.29H4C1.79 2 0 3.79 0 6v3c0 .55.45 1 1 1s1-.45 1-1V6c0-1.1.9-2 2-2h1.59l-.3.29zM15.5 13c.83 0 1.5-.67 1.5-1.5s-.67-1.5-1.5-1.5-1.5.67-1.5 1.5.67 1.5 1.5 1.5zM19 7H6c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-1 10l-5-3-1 2-2-4-3 4.5V9h11v8z"],import:["M9.29 15.71c.18.18.43.29.71.29s.53-.11.71-.29l5-5a1.003 1.003 0 00-1.42-1.42L11 12.59V1c0-.55-.45-1-1-1S9 .45 9 1v11.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42l5 5zM19 14c-.55 0-1 .45-1 1v3H2v-3c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1z"],inbox:["M16.92 3.56l-.01-.02c-.16-.35-.5-.6-.91-.6H4c-.41 0-.76.25-.91.6l-.01.02L0 10.49v6.46c0 .55.45 1 1 1h18c.55 0 1-.45 1-1v-6.46l-3.08-6.93zM15 10.95c-.55 0-1 .45-1 1v1H6v-1c0-.55-.45-1-1-1H1.98l2.67-6h10.7l2.67 6H15z"],"inbox-filtered":["M10.262 3l1.958 1.958v.05H4.65l-2.67 5.997H5c.55 0 1 .45 1 .999v1h8v-1c0-.55.45-1 1-1h3.02l-.635-1.426.625-.63c.354-.353.598-.8.707-1.289L20 10.545v6.456c0 .55-.45.999-1 .999H1c-.55 0-1-.45-1-1v-6.455L3.08 3.62l.01-.02c.15-.35.5-.6.91-.6h6.262zm9.088-3a.642.642 0 01.46 1.1l-3.03 3.03v2.95c0 .18-.07.34-.19.46l-1.28 1.29c-.11.1-.27.17-.45.17-.35 0-.64-.29-.64-.64V4.13L11.19 1.1a.642.642 0 01.45-1.1h7.71z"],"inbox-geo":["M7.427 3a7.467 7.467 0 00-.411 2.009H4.65l-2.67 5.996H5c.55 0 1 .45 1 .999v1h8V13c.165.01.332 0 .5 0a7.48 7.48 0 005.5-2.4V17c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1v-6.455L3.08 3.62l.01-.02c.15-.35.5-.6.91-.6h3.427zm5.715-.596a.133.133 0 01-.193 0l-.374-.374a.133.133 0 010-.193.133.133 0 01.193 0l.373.374a.133.133 0 010 .193zm1.743.033c-.05 0-.088-.006-.088-.055 0-.05.038-.056.088-.056h.165c.05 0 .088.006.088.055 0 .05-.038.056-.088.056h-.165zm.539.632c-.05 0-.104-.044-.104-.094v-.23c0-.05.054-.094.104-.094.05 0 .104.044.104.094v.23c0 .05-.055.094-.104.094zm-3.575 2.304h.506l1.182 1.2c.006.005 0 .005 0 .01v.446c0 .187-.126.341-.319.341h-.098v.226c0 .192-.138.296-.33.296h.01v.792c0 .188-.181.336-.368.336s-.369-.149-.369-.335v-1.32h-.214c-.193 0-.308-.149-.308-.341V5.72c0-.192.115-.346.308-.346zM14.5 0C17.536 0 20 2.464 20 5.5S17.536 11 14.5 11A5.502 5.502 0 019 5.5C9 2.464 11.464 0 14.5 0zm0 9.9c2.431 0 4.4-1.969 4.4-4.4 0-.297-.027-.583-.099-.864h-.236c-.188 0-.336-.104-.347-.313h-.319c.11.104.231.209.231.346v.705c0 .088-.055.17-.11.23h-.022l-.011.006-.022.011-.666.643v1.21c0 .193-.104.33-.296.33h-.54c-.192 0-.319-.137-.319-.33V6.221a.915.915 0 00-.533-.518h-.671c-.192 0-.368-.143-.368-.335V4.68c0-.192.176-.346.368-.346l.193-.005.319-.32a.342.342 0 01.489 0l.319.32c.005 0 .005.005.005.005h.704c.16 0 .237-.16.341-.313v-.11l-.038.005h-.27a.159.159 0 01-.153-.16c0-.087.066-.159.154-.159h.269l.039.006V3.42s-.05-.038-.061-.038h-.302l-.067.076a.342.342 0 01-.489.011l-.066-.088h-.176l.248.259c.021.022.021.088 0 .11-.028.022-.067.028-.088.006l-.292-.276h-.127l-.363.325-.033-.006c-.038.11-.087.089-.143.089-.126 0-.225-.072-.225-.193 0-.127.099-.209.225-.209h.176v-.182c0-.088.061-.131.149-.131h.066v-.127c0-.143.149-.297.286-.297h.28c.16 0 .27-.115.27-.275V2.42c0-.016.055.017.055-.088h-.187l-.005.017-.308.33a.123.123 0 01-.177 0c-.049-.044-.049-.121 0-.171l.391-.385c.027-.022.06-.022.094-.022l.005.022h.869A4.376 4.376 0 0014.5 1.1a4.402 4.402 0 00-2.816 1.018h.583c.094 0 .165.066.165.159s-.072.16-.165.16h-.478c0 .104-.039.06-.039.066v.351h.429l.226-.252c.132-.127.346-.155.473-.022a.332.332 0 010 .473l-1.183 1.182-.011.011c-.005.005-.011.005-.016.011a.115.115 0 00-.034.022c-.005.006-.01 0-.016.006a.309.309 0 01-.176.038h-.347c-.12.104-.187.148-.187.27v.088c0 .016-.027.027-.027.043l.561.589c.06.06.055.154 0 .209a.143.143 0 01-.209 0l-.578-.578a.425.425 0 01-.082.011c-.154 0-.292-.12-.292-.274v-.358h-.016c-.104.374-.165.77-.165 1.177 0 2.431 1.969 4.4 4.4 4.4zm3.388-3.107c.077 0 .16.06.16.137v.424c0 .077-.083.137-.16.137s-.16-.06-.16-.137V6.93c0-.077.083-.137.16-.137zm-3.113-4.879c0 .187-.154.314-.335.314h-.374v.104c0 .11-.05.198-.16.198s-.16-.088-.16-.198V1.98c-.104-.022-.033-.028-.033-.055 0-.187.127-.325.314-.325h.407c.187 0 .341.127.341.314z"],"inbox-search":["M7.136 3a6.327 6.327 0 00-.098 2.009H4.65l-2.67 5.996H5c.55 0 1 .45 1 .999v1h8v-1c0-.55.45-1 1-1h1.076l1.14 1.14a2.767 2.767 0 001.974.806c.282 0 .554-.042.81-.12V17c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1v-6.455L3.08 3.62l.01-.02c.15-.35.5-.6.91-.6h3.136zm3.244 1.33c0 1.62 1.31 2.93 2.93 2.93s2.93-1.31 2.93-2.93-1.31-2.93-2.93-2.93-2.93 1.31-2.93 2.93zm6.47 2.43l2.89 2.85c.13.15.22.35.23.56 0 .43-.35.78-.78.78-.23 0-.42-.08-.56-.22l-2.87-2.87c-.17.1-.33.2-.51.29-.03.01-.06.03-.09.04-.18.07-.35.15-.55.21-.19.06-.37.11-.57.14-.05.01-.1.02-.14.02-.2.03-.39.05-.6.05A4.3 4.3 0 019 4.31C9 1.93 10.93.01 13.3 0c2.37 0 4.3 1.93 4.3 4.3 0 .21-.02.4-.05.6-.01.05-.01.09-.02.14-.04.2-.08.38-.14.58-.05.19-.13.36-.21.54-.01.03-.03.06-.04.09-.08.18-.18.34-.29.51z"],"inbox-update":["M10.083 3a6.04 6.04 0 00.001 2.009H4.65l-2.67 5.996H5c.55 0 1 .45 1 .999v1h8v-1c0-.55.45-1 1-1h3.02l-.53-1.19a5.97 5.97 0 001.824-.811L20 10.545v6.456c0 .55-.45.999-1 .999H1c-.55 0-1-.45-1-1v-6.455L3.08 3.62l.01-.02c.15-.35.5-.6.91-.6h6.083zM16 8a4 4 0 110-8 4 4 0 010 8z"],"info-sign":["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM9 4h2v2H9V4zm4 12H7v-1h2V8H8V7h3v8h2v1z"],inheritance:["M6 10c0 2.21 1.79 4 4 4h6.59l-2.29-2.29A.965.965 0 0114 11a1.003 1.003 0 011.71-.71l4 4c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-4 4a1.003 1.003 0 01-1.42-1.42l2.3-2.29H10c-3.31 0-6-2.69-6-6H1a1 1 0 01-1-1V1a1 1 0 011-1h8a1 1 0 011 1v8a1 1 0 01-1 1H6zM2 2v6h6V2H2z"],"inherited-group":["M1 9c.55 0 1 .45 1 1v4c0 1.1.9 2 2 2h2.59l-.3-.29a1.003 1.003 0 011.42-1.42l2 2c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-2 2A1.003 1.003 0 016 19c0-.28.11-.53.3-.71l.29-.29H4c-2.21 0-4-1.79-4-4v-4c0-.55.45-1 1-1zm6.996-9c.79 0 1.68.25 2.309.73a3.63 3.63 0 011.4 2.36c.11.6.17 1.52.17 2.15v.09c.22.09.42.32.47.82.03.39-.12.73-.2.87-.07.34-.27.71-.61.78-.04.16-.09.33-.15.48-.01.01-.02.05-.02.05-.27.71-.68 1.33-1.19 1.78 0 .08 0 .16.01.23.05.55-.15.95 1.33 1.6 1.469.66 3.698 1.35 4.178 2.39.45 1.05.27 1.67.27 1.67h-5.227a1.982 1.982 0 00-.319-.417l-2-2A2.003 2.003 0 005 15H4c-.548 0-1-.452-1-1v-1.462c.511-.213 1.023-.413 1.468-.608 1.479-.65 1.329-1.05 1.379-1.59l.01-.21c-.52-.45-.95-1.08-1.22-1.8l-.01-.01-.01-.03c-.07-.15-.12-.32-.16-.49-.34-.06-.54-.43-.62-.78-.08-.14-.24-.48-.2-.87.05-.51.26-.74.49-.83v-.08c0-.64.05-1.55.17-2.15a3.648 3.648 0 011.4-2.36C6.317.25 7.207 0 7.996 0zm5.997 3c.59 0 1.26.19 1.73.55.46.35.8.85.97 1.4.04.13.07.25.08.38.08.45.13 1.14.13 1.61v.07c.16.07.31.24.35.62.02.29-.09.55-.15.65-.05.26-.2.53-.46.59-.03.12-.07.25-.11.36-.01.01-.01.04-.01.04-.2.53-.51 1-.89 1.34 0 .06 0 .12.01.17.04.41-.11.71 1 1.19 1.099.5 2.768 1.01 3.128 1.79.34.79.2 1.25.2 1.25h-3.039V15c-.06-.33-.17-.69-.33-1.06-.45-.97-1.37-1.52-3.238-2.3-.17-.07-.76-.31-.77-.32-.1-.04-.2-.08-.28-.12.05-.14.04-.29.06-.45l.01-.16c-.25-.21-.47-.48-.65-.79.22-.34.41-.71.56-1.12l.028-.078-.002.013-.006.035.06-.15c.36-.26.6-.67.72-1.13.18-.37.29-.82.25-1.3-.05-.5-.21-.92-.47-1.22-.02-.53-.06-1.11-.12-1.59.38-.17.83-.26 1.24-.26z"],"inner-join":["M8.7 4.7C7.4 6 6.5 7.9 6.5 10s.8 4 2.2 5.3c-.8.5-1.7.7-2.7.7-3.3 0-6-2.7-6-6s2.7-6 6-6c1 0 1.9.2 2.7.7zm-3.34 9.25c-.55-1.2-.86-2.54-.86-3.95s.31-2.75.86-3.95a4.001 4.001 0 000 7.9zM14 4c3.3 0 6 2.7 6 6s-2.7 6-6 6c-1 0-1.9-.2-2.7-.7 1.3-1.3 2.2-3.2 2.2-5.3s-.8-3.9-2.2-5.3C12.1 4.2 13 4 14 4zm.6 2.05c.55 1.2.86 2.54.86 3.95s-.31 2.75-.86 3.95c1.9-.31 3.36-1.96 3.36-3.95S16.5 6.36 14.6 6.05zM10 5.5C8.8 6.7 8 8.2 8 10s.8 3.3 2 4.4c1.2-1.1 2-2.7 2-4.5s-.8-3.3-2-4.4z"],insert:["M19 0H1C.4 0 0 .4 0 1v18c0 .5.4 1 1 1h18c.5 0 1-.5 1-1V1c0-.6-.5-1-1-1zm-1 18H2V2h16v16zM5 11h4v4c0 .6.4 1 1 1s1-.4 1-1v-4h4c.6 0 1-.4 1-1s-.4-1-1-1h-4V5c0-.6-.4-1-1-1s-1 .4-1 1v4H5c-.6 0-1 .4-1 1s.4 1 1 1z"],intersection:["M13 4c-1.31 0-2.51.43-3.5 1.14A5.977 5.977 0 006 4c-3.31 0-6 2.69-6 6s2.69 6 6 6c1.31 0 2.51-.43 3.5-1.14.99.71 2.19 1.14 3.5 1.14 3.31 0 6-2.69 6-6s-2.69-6-6-6zm-4.93 9.41c-.61.37-1.31.59-2.07.59-2.21 0-4-1.79-4-4s1.79-4 4-4c.76 0 1.46.22 2.07.59C7.4 7.56 7 8.73 7 10s.4 2.44 1.07 3.41zM13 14c-.76 0-1.46-.22-2.07-.59C11.6 12.44 12 11.27 12 10s-.4-2.44-1.07-3.41C11.54 6.22 12.24 6 13 6c2.21 0 4 1.79 4 4s-1.79 4-4 4z"],"ip-address":["M6 3.66C6 5.69 10 11 10 11s4-5.31 4-7.34C13.99 1.64 12.21 0 10 0S6 1.64 6 3.66zM8 4c0-1.1.9-2 2-2s2 .9 2 2-.9 2-2 2-2-.9-2-2zM14 13.5V13h-4v1h3v2h-2v1h3v-3.5zM3 12h14c.55 0 1 .45 1 1v6c0 .55-.45 1-1 1H3c-.55 0-1-.45-1-1v-6c0-.55.45-1 1-1zm4 1v6h1v-6H7zm3 1v5h1v-5h-1z"],issue:["M10 20C4.477 20 0 15.523 0 10S4.477 0 10 0s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 100-16 8 8 0 000 16zm1-2H9v-2h2v2zm0-3H9V4h2v9z"],"issue-closed":["M15.364 5.9a.997.997 0 01-.707-.293l-2.121-2.122a1 1 0 111.414-1.414l1.414 1.414L18.192.657a1 1 0 011.414 1.414l-3.535 3.536a.997.997 0 01-.707.292zM11.78.157a3.002 3.002 0 00-1.437 1.85 8 8 0 107.1 5.055l.042-.042 1.472-1.472A9.959 9.959 0 0120 10c0 5.523-4.477 10-10 10S0 15.523 0 10 4.477 0 10 0c.608 0 1.202.054 1.78.158zM11 16H9v-2h2v2zm0-3H9V4h2v9z"],"issue-new":["M13.167.512a2.98 2.98 0 00-.131.524c-.74.115-1.39.5-1.848 1.052a8 8 0 106.724 6.724 2.997 2.997 0 001.052-1.848 2.98 2.98 0 00.524-.13A9.99 9.99 0 0120 10c0 5.523-4.477 10-10 10S0 15.523 0 10 4.477 0 10 0a9.99 9.99 0 013.167.512zM11 16H9v-2h2v2zm0-3H9V4h2v9zm6-10h1.5a1 1 0 010 2H17v1.5a1 1 0 01-2 0V5h-1.5a1 1 0 010-2H15V1.5a1 1 0 012 0V3z"],italic:["M11.7 4H14c.6 0 1-.4 1-1s-.4-1-1-1H7c-.6 0-1 .4-1 1s.4 1 1 1h2.2L7.3 15H5c-.6 0-1 .4-1 1s.4 1 1 1h7c.6 0 1-.4 1-1s-.4-1-1-1H9.8l1.9-11z"],"join-table":["M19 6h-4V2c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h4v4c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1zM6 12H2V9h4v3zm0-4H2V5h4v3zm7 9H7v-3h6v3zm0-4H7V9h6v4zm0-5H7V5h6v3zm5 9h-4v-3h4v3zm0-4h-4v-3h4v3z"],key:["M14 0c-3.31 0-6 2.69-6 6 0 1.11.32 2.14.85 3.03L.44 17.44a1.498 1.498 0 102.12 2.12l.79-.79.94.94c.18.18.43.29.71.29s.53-.11.71-.29l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-.94-.94 3.2-3.2A5.9 5.9 0 0014 12c3.31 0 6-2.69 6-6s-2.69-6-6-6zm0 9c-1.66 0-3-1.34-3-3s1.34-3 3-3 3 1.34 3 3-1.34 3-3 3z"],"key-backspace":["M19 3H7c-.28 0-.53.11-.71.29l-6 6C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l6 6c.18.18.43.29.71.29h12c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zm-2.29 9.29a1.003 1.003 0 01-1.42 1.42L13 11.41l-2.29 2.29c-.18.19-.43.3-.71.3a1.003 1.003 0 01-.71-1.71l2.3-2.29-2.3-2.29a1.003 1.003 0 011.42-1.42L13 8.59l2.29-2.29c.18-.19.43-.3.71-.3a1.003 1.003 0 01.71 1.71L14.41 10l2.3 2.29z"],"key-command":["M15.5 12H14V8h1.5C17.43 8 19 6.43 19 4.5S17.43 1 15.5 1 12 2.57 12 4.5V6H8V4.5C8 2.57 6.43 1 4.5 1S1 2.57 1 4.5 2.57 8 4.5 8H6v4H4.5C2.57 12 1 13.57 1 15.5S2.57 19 4.5 19 8 17.43 8 15.5V14h4v1.5c0 1.93 1.57 3.5 3.5 3.5s3.5-1.57 3.5-3.5-1.57-3.5-3.5-3.5zm0-9c.83 0 1.5.67 1.5 1.5S16.33 6 15.5 6 14 5.33 14 4.5 14.67 3 15.5 3zm-11 14c-.83 0-1.5-.67-1.5-1.5S3.67 14 4.5 14s1.5.67 1.5 1.5S5.33 17 4.5 17zm0-11C3.67 6 3 5.33 3 4.5S3.67 3 4.5 3 6 3.67 6 4.5 5.33 6 4.5 6zm7.5 6H8V8h4v4zm3.5 5c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"],"key-control":["M16.71 7.29l-6-6C10.53 1.11 10.28 1 10 1s-.53.11-.71.29l-6 6a1.003 1.003 0 001.42 1.42L10 3.41l5.29 5.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71z"],"key-delete":["M19.71 9.29l-6-6A.997.997 0 0013 3H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h12c.28 0 .53-.11.71-.29l6-6c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zm-9 3a1.003 1.003 0 01-1.42 1.42L7 11.41 4.71 13.7c-.18.19-.43.3-.71.3a1.003 1.003 0 01-.71-1.71L5.59 10l-2.3-2.29a1.003 1.003 0 011.42-1.42L7 8.59 9.29 6.3c.18-.19.43-.3.71-.3a1.003 1.003 0 01.71 1.71L8.41 10l2.3 2.29z"],"key-enter":["M18 2c-.55 0-1 .45-1 1v5c0 2.21-1.79 4-4 4H4.41L6.7 9.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L4.41 14H13c3.31 0 6-2.69 6-6V3c0-.55-.45-1-1-1z"],"key-escape":["M2 8c.55 0 1-.45 1-1V4.41l6.29 6.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L4.41 3H7c.55 0 1-.45 1-1s-.45-1-1-1H2c-.55 0-1 .45-1 1v5c0 .55.45 1 1 1zm9-6.94V3.1c3.39.49 6 3.38 6 6.9 0 3.87-3.13 7-7 7-3.52 0-6.41-2.61-6.9-6H1.06c.5 4.5 4.31 8 8.94 8a9 9 0 009-9c0-4.63-3.5-8.44-8-8.94z"],"key-option":["M13 4h6c.55 0 1-.45 1-1s-.45-1-1-1h-6c-.55 0-1 .45-1 1s.45 1 1 1zm6 12h-4.42L6.87 2.5l-.02.01A.977.977 0 006 2H1c-.55 0-1 .45-1 1s.45 1 1 1h4.42l7.71 13.5.01-.01c.18.3.49.51.86.51h5c.55 0 1-.45 1-1s-.45-1-1-1z"],"key-shift":["M17.74 10.35l-6.99-8.01-.01.01C10.56 2.14 10.3 2 10 2s-.56.14-.74.35l-.01-.01-7 8 .01.01A.95.95 0 002 11c0 .55.45 1 1 1h3v5c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-5h3c.55 0 1-.45 1-1 0-.25-.1-.48-.26-.65z"],"key-tab":["M19 13H4.41l2.29-2.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L2 12.59V10c0-.55-.45-1-1-1s-1 .45-1 1v8c0 .55.45 1 1 1s1-.45 1-1v-2.59l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L4.41 15H19c.55 0 1-.45 1-1s-.45-1-1-1zm0-12c-.55 0-1 .45-1 1v2.59L14.71 1.3A.965.965 0 0014 1a1.003 1.003 0 00-.71 1.71L15.59 5H1c-.55 0-1 .45-1 1s.45 1 1 1h14.59L13.3 9.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 7.41V10c0 .55.45 1 1 1s1-.45 1-1V2c0-.55-.45-1-1-1z"],"known-vehicle":["M19 4a.997.997 0 00-.707.293L14 8.586l-2.293-2.293a1 1 0 00-1.414 1.414l3 3a.997.997 0 001.414 0l5-5A1 1 0 0019 4zm-2.048 7.291c.011.072.048.134.048.209a1.5 1.5 0 01-1.5 1.5c-.225 0-.433-.057-.624-.145-.279.085-.57.145-.876.145a2.99 2.99 0 01-2.121-.879l-3-3 .007-.007A3.027 3.027 0 018.184 8H4V7l1-3h10l.19.568 1.307-1.308c-.336-.356-.758-.658-1.165-.772 0 0-1.74-.488-5.332-.488s-5.332.488-5.332.488c-.67.188-1.424.864-1.674 1.502L2.99 4H3L2 7H1a1 1 0 000 2h.333l-.28.84L1 10v7.5a1.5 1.5 0 103 0V17h12v.5a1.5 1.5 0 003 0V10l-.19-.568-1.858 1.86zM4.5 13a1.5 1.5 0 110-3 1.5 1.5 0 010 3z"],"lab-test":["M13 2a1 1 0 010 2v4l4 8v1a1 1 0 01-1 1H4a1 1 0 01-1-1v-1l4-8V4a1 1 0 110-2h6zm-2 2H9v4l-2 4h6l-2-4V4z"],label:["M3 12h14v-1H3v1zm11-9H1c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V9l-6-6zm4 12H2V5h11v3H3v1h10v1h5v5zm-4-6V5l4 4h-4z"],layer:["M19.5 9.1l-9-5c-.2-.1-.3-.1-.5-.1s-.3 0-.5.1l-9 5c-.3.2-.5.5-.5.9s.2.7.5.9l9 5c.2.1.3.1.5.1s.3 0 .5-.1l9-5c.3-.2.5-.5.5-.9s-.2-.7-.5-.9z"],"layer-outline":["M9.514 4.126l-9 5a1 1 0 000 1.748l9 5a1 1 0 00.972 0l9-5a1 1 0 000-1.748l-9-5a1 1 0 00-.972 0zM10 6.144l6.94 3.855L10 13.855 3.059 9.999 10 6.144z"],layers:["M.5 6.9l9 5c.2.1.3.1.5.1s.3 0 .5-.1l9-5c.3-.2.5-.5.5-.9s-.2-.7-.5-.9l-9-5c-.2-.1-.3-.1-.5-.1s-.3 0-.5.1l-9 5c-.3.2-.5.5-.5.9s.2.7.5.9z","M19 9c-.2 0-.3 0-.5.1L10 13.9 1.5 9.1C1.3 9 1.2 9 1 9c-.6 0-1 .4-1 1 0 .4.2.7.5.9l9 5c.2.1.3.1.5.1s.3 0 .5-.1l9-5c.3-.2.5-.5.5-.9 0-.6-.4-1-1-1z","M19 13c-.2 0-.3 0-.5.1L10 17.9l-8.5-4.7c-.2-.2-.3-.2-.5-.2-.6 0-1 .4-1 1 0 .4.2.7.5.9l9 5c.2.1.3.1.5.1s.3 0 .5-.1l9-5c.3-.2.5-.5.5-.9 0-.6-.4-1-1-1z"],layout:["M18 6c-1.1 0-2 .9-2 2 0 .37.11.71.28 1.01l-2.27 2.27c-.3-.17-.64-.28-1.01-.28-.93 0-1.71.64-1.93 1.5H8.93c-.22-.86-1-1.5-1.93-1.5-.37 0-.71.11-1.01.28L3.72 9.01C3.89 8.71 4 8.37 4 8c0-.34-.09-.66-.24-.94l3.66-3.38c.31.2.68.32 1.08.32 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .34.09.66.24.94L3.08 6.32C2.77 6.12 2.4 6 2 6 .9 6 0 6.9 0 8s.9 2 2 2c.37 0 .71-.11 1.01-.28l2.27 2.27c-.17.3-.28.64-.28 1.01s.11.71.28 1.01l-2.27 2.27C2.71 16.11 2.37 16 2 16c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2c0-.37-.11-.71-.28-1.01l2.27-2.27c.3.17.64.28 1.01.28.93 0 1.71-.64 1.93-1.5h2.14c.22.86 1 1.5 1.93 1.5 1.1 0 2-.9 2-2 0-.37-.11-.71-.28-1.01l2.27-2.27c.3.17.64.28 1.01.28 1.1 0 2-.9 2-2s-.9-2-2-2z"],"layout-auto":["M18 13c-.53 0-1.01.21-1.37.55L11.9 10.6c.06-.19.1-.39.1-.6s-.04-.41-.1-.6l4.72-2.95c.37.34.85.55 1.38.55 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .21.04.41.1.6l-4.73 2.96c-.24-.23-.54-.4-.87-.48V3.93c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S8 .9 8 2c0 .93.64 1.71 1.5 1.93v4.14c-.33.09-.63.26-.87.48L3.9 5.6c.06-.19.1-.39.1-.6 0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.53 0 1.01-.21 1.37-.55L8.1 9.4c-.06.19-.1.39-.1.6s.04.41.1.6l-4.72 2.95C3.01 13.21 2.53 13 2 13c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2c0-.21-.04-.41-.1-.6l4.73-2.96c.24.23.54.4.87.48v4.14C8.64 16.29 8 17.07 8 18c0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93v-4.14c.33-.09.63-.26.87-.48l4.73 2.96c-.06.18-.1.38-.1.59 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2z"],"layout-balloon":["M18 16c-.14 0-.28.02-.42.05l-1.73-3.45c.69-.45 1.14-1.22 1.14-2.1s-.46-1.65-1.14-2.1l1.73-3.45c.14.03.28.05.42.05 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .6.27 1.13.69 1.5l-1.77 3.54c-.14-.02-.28-.04-.42-.04a2.5 2.5 0 00-2.45 2h-4.1A2.5 2.5 0 005.5 8c-.14 0-.28.02-.42.04L3.31 4.5C3.73 4.13 4 3.6 4 3c0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.14 0 .28-.02.42-.05L4.14 8.4C3.46 8.85 3 9.62 3 10.5s.46 1.65 1.14 2.1l-1.73 3.45A1.84 1.84 0 002 16c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2c0-.6-.27-1.13-.69-1.5l1.77-3.54c.14.02.28.04.42.04a2.5 2.5 0 002.45-2h4.1a2.5 2.5 0 002.45 2c.14 0 .28-.02.42-.04l1.77 3.54c-.42.37-.69.9-.69 1.5 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2z"],"layout-circle":["M18.3 8c-.2-.9-.6-1.7-1.1-2.5.2-.3.3-.7.3-1 0-1.1-.9-2-2-2-.4 0-.7.1-1 .3-.8-.5-1.6-.8-2.5-1.1-.1-1-1-1.7-2-1.7S8.2.8 8 1.7c-.9.3-1.7.6-2.5 1.1-.3-.2-.7-.3-1-.3-1.1 0-2 .9-2 2 0 .4.1.7.3 1-.5.8-.8 1.6-1.1 2.5C.8 8.2 0 9 0 10s.8 1.8 1.7 2c.2.9.6 1.7 1.1 2.5-.2.3-.3.7-.3 1 0 1.1.9 2 2 2 .4 0 .7-.1 1-.3.8.5 1.6.8 2.5 1.1.1 1 1 1.7 2 1.7s1.8-.8 2-1.7c.9-.2 1.7-.6 2.5-1.1.3.2.7.3 1 .3 1.1 0 2-.9 2-2 0-.4-.1-.7-.3-1 .5-.8.8-1.6 1.1-2.5 1-.1 1.7-1 1.7-2s-.8-1.8-1.7-2zm-1.8 5.8c-.3-.2-.6-.3-1-.3-1.1 0-2 .9-2 2 0 .4.1.7.3 1-.6.3-1.2.6-1.9.8-.3-.7-1-1.3-1.9-1.3-.8 0-1.6.5-1.9 1.3-.7-.2-1.3-.4-1.9-.8.2-.3.3-.6.3-1 0-1.1-.9-2-2-2-.4 0-.7.1-1 .3-.3-.6-.6-1.2-.8-1.9.8-.3 1.3-1.1 1.3-1.9s-.5-1.6-1.2-1.8c.2-.7.4-1.3.8-1.9.3.2.6.3 1 .3 1.1 0 2-.9 2-2 0-.4-.1-.7-.3-1 .6-.3 1.2-.6 1.9-.8.2.7 1 1.2 1.8 1.2s1.6-.5 1.9-1.3c.7.2 1.3.4 1.9.8-.2.3-.3.6-.3 1 0 1.1.9 2 2 2 .4 0 .7-.1 1-.3.3.6.6 1.2.8 1.9-.8.3-1.3 1.1-1.3 1.9s.5 1.6 1.2 1.8c-.1.7-.4 1.4-.7 2z"],"layout-grid":["M2 0a2 2 0 100 4 2 2 0 100-4zM10 0a2 2 0 100 4 2 2 0 100-4zM18 0a2 2 0 100 4 2 2 0 100-4zM18 8a2 2 0 100 4 2 2 0 100-4zM18 16a2 2 0 100 4 2 2 0 100-4zM10 16a2 2 0 100 4 2 2 0 100-4zM2 16a2 2 0 100 4 2 2 0 100-4zM2 8a2 2 0 100 4 2 2 0 100-4zM10 8a2 2 0 100 4 2 2 0 100-4z"],"layout-group-by":["M2 2a2 2 0 100 4 2 2 0 100-4zM18 0a2 2 0 100 4 2 2 0 100-4zM18 8a2 2 0 100 4 2 2 0 100-4zM18 16a2 2 0 100 4 2 2 0 100-4zM2 14a2 2 0 100 4 2 2 0 100-4zM2 8a2 2 0 100 4 2 2 0 100-4zM13 12a2 2 0 100 4 2 2 0 100-4zM13 4a2 2 0 100 4 2 2 0 100-4z"],"layout-hierarchy":["M18.5 16.07v-4.14c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2-.93 0-1.71.64-1.93 1.5h-4.14c-.18-.7-.73-1.25-1.43-1.43V3.93c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S8 .9 8 2c0 .93.64 1.71 1.5 1.93v4.14c-.7.18-1.25.73-1.43 1.43H3.93C3.71 8.64 2.93 8 2 8c-1.1 0-2 .9-2 2 0 .93.64 1.71 1.5 1.93v4.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93v-4.14c.7-.18 1.25-.73 1.43-1.43h4.14c.18.7.73 1.25 1.43 1.43v4.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93v-4.14c.7-.18 1.25-.73 1.43-1.43h4.14c.18.7.73 1.25 1.43 1.43v4.14c-.86.22-1.5 1-1.5 1.93 0 1.1.9 2 2 2s2-.9 2-2c0-.93-.64-1.71-1.5-1.93z"],"layout-linear":["M16.5 7a2.5 2.5 0 00-2.45 2h-2.1a2.5 2.5 0 00-4.9 0h-2.1a2.5 2.5 0 100 1h2.1a2.5 2.5 0 004.9 0h2.1a2.5 2.5 0 102.45-3z"],"layout-skew-grid":["M2 0a2 2 0 100 4 2 2 0 100-4zM18 0a2 2 0 100 4 2 2 0 100-4zM18 8a2 2 0 100 4 2 2 0 100-4zM18 16a2 2 0 100 4 2 2 0 100-4zM2 16a2 2 0 100 4 2 2 0 100-4zM2 8a2 2 0 100 4 2 2 0 100-4zM10 12a2 2 0 100 4 2 2 0 100-4zM10 4a2 2 0 100 4 2 2 0 100-4z"],"layout-sorted-clusters":["M2 8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm16 8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm-8 4c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],learning:["M10.551 1.127a1.256 1.256 0 00-1.102 0L.456 5.89c-.608.309-.608.913 0 1.222l8.993 4.762c.334.17.767.17 1.102 0l8.992-4.762c.61-.309.61-.913 0-1.222l-8.992-4.762z","M18 6.5l.016 4.514c.002.548.447.99.994.99a.99.99 0 00.99-.99V6.5h-2zM3.366 10.033l6.401 3.358a.5.5 0 00.465 0l6.406-3.358a.25.25 0 01.366.221v5.109a.25.25 0 01-.139.224l-6.64 3.302a.5.5 0 01-.446 0l-6.64-3.302A.25.25 0 013 15.363v-5.108a.25.25 0 01.366-.222z"],"left-join":["M8.7 4.7C7.4 6 6.5 7.9 6.5 10s.8 4 2.2 5.3c-.8.5-1.7.7-2.7.7-3.3 0-6-2.7-6-6s2.7-6 6-6c1 0 1.9.2 2.7.7zM14 4c3.3 0 6 2.7 6 6s-2.7 6-6 6c-1 0-1.9-.2-2.7-.7 1.3-1.3 2.2-3.2 2.2-5.3s-.8-3.9-2.2-5.3C12.1 4.2 13 4 14 4zm.6 2.05c.55 1.2.86 2.54.86 3.95s-.31 2.75-.86 3.95c1.9-.31 3.36-1.96 3.36-3.95S16.5 6.36 14.6 6.05zM10 5.5C8.8 6.7 8 8.2 8 10s.8 3.3 2 4.4c1.2-1.1 2-2.7 2-4.5s-.8-3.3-2-4.4z"],"less-than":["M7.162 10l9.154 3.052a1 1 0 01-.632 1.897l-12-4c-.912-.304-.912-1.594 0-1.897l12-4a1 1 0 01.632 1.897L7.162 10z"],"less-than-or-equal-to":["M16.316 11.051L7.162 8l9.154-3.051a1 1 0 10-.632-1.898l-12 4c-.912.304-.912 1.594 0 1.898l12 4a1 1 0 10.632-1.898zM16 15H4a1 1 0 100 2h12a1 1 0 100-2z"],lifesaver:["M8.143 14.644L7.028 17.43c.919.368 1.922.57 2.972.57s2.053-.202 2.972-.57l-1.115-2.786A4.986 4.986 0 0110 15a4.986 4.986 0 01-1.857-.356zm-2.787-2.787A4.986 4.986 0 015 10c0-.656.126-1.283.356-1.857L2.57 7.028A7.978 7.978 0 002 10c0 1.05.202 2.053.57 2.972l2.786-1.115zm2.787-6.5A4.986 4.986 0 0110 5c.656 0 1.283.126 1.857.356l1.115-2.786A7.978 7.978 0 0010 2c-1.05 0-2.053.202-2.972.57l1.115 2.786zm6.5 2.786c.23.574.357 1.2.357 1.857 0 .656-.126 1.283-.356 1.857l2.786 1.115c.368-.919.57-1.922.57-2.972s-.202-2.053-.57-2.972l-2.786 1.115zM10 13a3 3 0 100-6 3 3 0 000 6zm0 7C4.477 20 0 15.523 0 10S4.477 0 10 0s10 4.477 10 10-4.477 10-10 10z"],lightbulb:["M6.33 13.39c0 .34.27.61.6.61h6.13c.33 0 .6-.27.6-.61C14.03 9.78 16 9.4 16 6.09 16 2.72 13.31 0 10 0S4 2.72 4 6.09c0 3.31 1.97 3.69 2.33 7.3zM13 15H7c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1zm-1 3H8c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1z"],lightning:["M9 11H6a1 1 0 01-1-1L5.91.9a1 1 0 01.995-.9h6.256a.839.839 0 01.779 1.15L11.2 8h2.978a.822.822 0 01.748 1.162l-4.764 10.481A.608.608 0 019 19.392V11z"],link:["M10.85 11.98l-4.44 4.44-1 1c-.36.36-.86.58-1.41.58-1.1 0-2-.9-2-2 0-.55.22-1.05.59-1.41l5.44-5.44C7.69 9.06 7.36 9 7 9c-1.11 0-2.09.46-2.82 1.18l-.01-.01-3 3 .01.01C.46 13.91 0 14.89 0 16c0 2.21 1.79 4 4 4 1.11 0 2.09-.46 2.82-1.18l.01.01 3-3-.01-.01C10.54 15.09 11 14.11 11 13c0-.36-.06-.69-.15-1.02zM20 4c0-2.21-1.79-4-4-4-1.11 0-2.09.46-2.82 1.18l-.01-.01-3 3 .01.01C9.46 4.91 9 5.89 9 7c0 .36.06.69.15 1.02l4.44-4.44 1-1c.36-.36.86-.58 1.41-.58 1.1 0 2 .9 2 2 0 .55-.22 1.05-.59 1.41l-5.44 5.44c.34.09.67.15 1.03.15 1.11 0 2.09-.46 2.82-1.18l.01.01 3-3-.01-.01C19.54 6.09 20 5.11 20 4zM5 14a1.003 1.003 0 001.71.71l8-8a1.003 1.003 0 00-1.42-1.42l-2 2-2 2-2 2-2 2c-.18.18-.29.43-.29.71z"],list:["M1.03 1C.46 1 0 1.46 0 2.03v.95C0 3.54.46 4 1.03 4h17.95C19.54 4 20 3.54 20 2.97v-.94C20 1.46 19.54 1 18.97 1H1.03zM0 17.97C0 18.54.46 19 1.03 19h17.95c.56 0 1.03-.46 1.03-1.03v-.95c0-.56-.46-1.03-1.03-1.03H1.03C.46 16 0 16.46 0 17.03v.94zM0 12.97C0 13.54.46 14 1.03 14h17.95c.56 0 1.03-.46 1.03-1.03v-.95c0-.56-.46-1.03-1.03-1.03H1.03C.46 11 0 11.46 0 12.03v.94zM0 7.97C0 8.54.46 9 1.03 9h17.95C19.54 9 20 8.54 20 7.97v-.94C20 6.46 19.54 6 18.97 6H1.03C.46 6 0 6.46 0 7.03v.94z"],"list-columns":["M0 2.973v-.936C0 1.468.46 1.01 1.029 1H7.97C8.541 1 9 1.468 9 2.027v.946C9 3.542 8.53 4 7.971 4H1.03C.459 4 0 3.542 0 2.973zm0 5v-.936C0 6.468.46 6.01 1.029 6H7.97C8.541 6 9 6.468 9 7.027v.946C9 8.542 8.53 9 7.971 9H1.03C.459 9 0 8.542 0 7.973zm0 5v-.936C0 11.468.46 11.01 1.029 11H7.97C8.541 11 9 11.468 9 12.027v.946C9 13.542 8.53 14 7.971 14H1.03C.459 14 0 13.542 0 12.973zm0 5v-.936C0 16.468.46 16.01 1.029 16H7.97C8.541 16 9 16.468 9 17.027v.946C9 18.542 8.53 19 7.971 19H1.03C.459 19 0 18.542 0 17.973zm11-15v-.936c0-.569.46-1.027 1.029-1.037h6.942C19.541 1 20 1.468 20 2.027v.946C20 3.542 19.53 4 18.971 4H12.03C11.459 4 11 3.542 11 2.973zm0 5v-.936c0-.569.46-1.027 1.029-1.037h6.942C19.541 6 20 6.468 20 7.027v.946C20 8.542 19.53 9 18.971 9H12.03C11.459 9 11 8.542 11 7.973zm0 5v-.936c0-.569.46-1.027 1.029-1.037h6.942c.57 0 1.029.468 1.029 1.027v.946c0 .569-.47 1.027-1.029 1.027H12.03c-.57 0-1.029-.458-1.029-1.027zm0 5v-.936c0-.569.46-1.027 1.029-1.037h6.942c.57 0 1.029.468 1.029 1.027v.946c0 .569-.47 1.027-1.029 1.027H12.03c-.57 0-1.029-.458-1.029-1.027z"],"list-detail-view":["M8 6H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1zm0 5H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm0 5H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zM8 1H1c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm11 0h-7c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1z"],locate:["M10 8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm9 1h-1.07c-.45-3.61-3.32-6.45-6.93-6.91V1c0-.55-.45-1-1-1S9 .45 9 1v1.09C5.39 2.55 2.52 5.39 2.07 9H1c-.55 0-1 .45-1 1s.45 1 1 1h1.07c.45 3.61 3.32 6.45 6.93 6.91V19c0 .55.45 1 1 1s1-.45 1-1v-1.09c3.61-.46 6.48-3.29 6.93-6.91H19c.55 0 1-.45 1-1s-.45-1-1-1zm-4 2h.9a5.98 5.98 0 01-4.9 4.91V15c0-.55-.45-1-1-1s-1 .45-1 1v.91A5.98 5.98 0 014.1 11H5c.55 0 1-.45 1-1s-.45-1-1-1h-.9A5.98 5.98 0 019 4.09V5c0 .55.45 1 1 1s1-.45 1-1v-.91A5.98 5.98 0 0115.9 9H15c-.55 0-1 .45-1 1s.45 1 1 1z"],lock:["M15.93 9H14V4.99c0-2.21-1.79-4-4-4s-4 1.79-4 4V9H3.93c-.55 0-.93.44-.93.99v8c0 .55.38 1.01.93 1.01h12c.55 0 1.07-.46 1.07-1.01v-8c0-.55-.52-.99-1.07-.99zM8 9V4.99c0-1.1.9-2 2-2s2 .9 2 2V9H8z"],"log-in":["M19 0h-8c-.55 0-1 .45-1 1s.45 1 1 1h7v16h-7c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-4 10c0-.28-.11-.53-.29-.71l-5-5a1.003 1.003 0 00-1.42 1.42L11.59 9H1c-.55 0-1 .45-1 1s.45 1 1 1h10.59L8.3 14.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l5-5c.18-.18.29-.43.29-.71z"],"log-out":["M19.71 9.29l-5-5a1.003 1.003 0 00-1.42 1.42L16.59 9H6c-.55 0-1 .45-1 1s.45 1 1 1h10.59l-3.29 3.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l5-5c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM9 18H2V2h7c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1z"],manual:["M20 1.1a.976.976 0 00-.83-.88C15.15-.43 12.07.34 10 2.5 7.93.34 4.85-.43.84.22.37.3.03.67 0 1.1v15.01c0 .07 0 .14.01.21.09.52.61.88 1.15.79 3.85-.62 6.4.16 8 2.46.02.02.03.04.05.07.02.02.04.04.06.07l.01.01a1.07 1.07 0 00.28.19c.01 0 .01.01.02.01.03.01.07.03.1.04.01 0 .02.01.04.01.03.01.07.02.1.02.01 0 .02 0 .04.01H10c.04 0 .09 0 .13-.01.01 0 .03 0 .04-.01.03-.01.06-.01.1-.02.01 0 .03-.01.04-.01.03-.01.07-.02.1-.04.01 0 .02-.01.03-.01.07-.03.13-.07.19-.11.01 0 .01-.01.02-.01.02-.02.04-.03.06-.05.01-.01.02-.02.03-.02l.05-.05c.01-.01.02-.02.02-.03.01-.02.02-.03.04-.05 1.61-2.3 4.15-3.09 8-2.46.54.09 1.06-.26 1.15-.79-.01-.05 0-.09 0-.13V1.1zM9 16.63c-1.78-1.31-4.12-1.83-7-1.55V2c3.26-.37 5.51.39 7 2.35v12.28zm9-1.56c-2.88-.28-5.22.24-7 1.55V4.34c1.49-1.96 3.74-2.71 7-2.35v13.08z"],"manually-entered-data":["M1 12h4.34l2-2H1c-.55 0-1 .45-1 1s.45 1 1 1zm16.77-3.94l1.65-1.65c.36-.36.58-.86.58-1.41 0-1.1-.9-2-2-2-.55 0-1.05.22-1.41.59l-1.65 1.65 2.83 2.82zM1 4h12.34l2-2H1c-.55 0-1 .45-1 1s.45 1 1 1zM0 15c0 .55.45 1 1 1h.34l2-2H1c-.55 0-1 .45-1 1zm1-7h8.34l2-2H1c-.55 0-1 .45-1 1s.45 1 1 1zm18 2h-.34l-2 2H19c.55 0 1-.45 1-1s-.45-1-1-1zm0 4h-4.34l-2 2H19c.55 0 1-.45 1-1s-.45-1-1-1zM4 19l4.41-1.59-2.81-2.79L4 19zM14.23 5.94l-7.65 7.65 2.83 2.83 7.65-7.65-2.83-2.83z"],"many-to-many":["M17 6a1 1 0 100-2 1 1 0 000 2zm0 2a3 3 0 01-2.73-1.754c-.2.068-.408.154-.617.264-.884.465-1.92 1.418-2.605 3.49.685 2.072 1.721 3.025 2.605 3.49.21.11.416.196.617.264a3 3 0 11-.165 2.034 6.262 6.262 0 01-1.383-.528c-.983-.518-1.948-1.364-2.722-2.705-.774 1.34-1.739 2.187-2.722 2.705-.48.252-.95.419-1.383.528A3.001 3.001 0 010 15a3 3 0 015.73-1.246c.2-.068.408-.154.617-.264.884-.465 1.92-1.418 2.605-3.49-.685-2.072-1.721-3.025-2.605-3.49a4.21 4.21 0 00-.617-.264 3 3 0 11.165-2.034c.433.11.904.276 1.383.528.983.518 1.948 1.364 2.722 2.705.774-1.34 1.739-2.187 2.722-2.705.48-.252.95-.419 1.383-.528A3.001 3.001 0 0120 5a3 3 0 01-3 3zM4 5a1 1 0 10-2 0 1 1 0 002 0zm12 10a1 1 0 102 0 1 1 0 00-2 0zM3 14a1 1 0 110 2 1 1 0 010-2z"],"many-to-one":["M3 2a1 1 0 100 2 1 1 0 000-2zm0 4c1.296 0 2.4-.821 2.82-1.972.487.039 1.086.13 1.667.347.947.352 1.773 1 2.032 2.318.323 1.644 1.234 2.675 2.264 3.307-1.03.632-1.941 1.663-2.264 3.307-.259 1.318-1.085 1.966-2.032 2.318a6.244 6.244 0 01-1.668.347 3.001 3.001 0 10.019 2.004c.633-.042 1.491-.158 2.347-.476 1.402-.523 2.867-1.625 3.296-3.807.259-1.318 1.085-1.966 2.032-2.318.24-.09.484-.158.722-.21a3 3 0 100-2.33 5.329 5.329 0 01-.722-.21c-.947-.352-1.773-1-2.032-2.318-.428-2.182-1.894-3.284-3.296-3.807-.856-.318-1.714-.434-2.347-.476A3.001 3.001 0 000 3a3 3 0 003 3zm13 4a1 1 0 102 0 1 1 0 00-2 0zM2 17a1 1 0 112 0 1 1 0 01-2 0z"],map:["M19.54 4.18l.01-.02-6-4-.01.02C13.39.08 13.21 0 13 0s-.39.08-.54.18l-.01-.02L7 3.8 1.55.17l-.01.01A.969.969 0 001 0C.45 0 0 .45 0 1v14c0 .35.19.64.46.82l-.01.02 6 4 .01-.02c.15.1.33.18.54.18s.39-.08.54-.18l.01.02L13 16.2l5.45 3.63.01-.02c.15.11.33.19.54.19.55 0 1-.45 1-1V5c0-.35-.19-.64-.46-.82zM6 17.13l-4-2.67V2.87l4 2.67v11.59zm6-2.67l-4 2.67V5.54l4-2.67v11.59zm6 2.67l-4-2.67V2.87l4 2.67v11.59z"],"map-create":["M18 9.22v7.91l-4-2.67V9.22c-.61-.55-1-1.33-1-2.22-.35 0-.69-.07-1-.18v7.65l-4 2.67V5.54l2.02-1.35c0-.06-.02-.13-.02-.19 0-1.66 1.34-3 3-3 0-.34.07-.66.17-.97C13.12.02 13.06 0 13 0c-.21 0-.39.08-.54.18l-.01-.02L7 3.8 1.55.17l-.01.01A.969.969 0 001 0C.45 0 0 .45 0 1v14c0 .35.19.64.46.82l-.01.02 6 4 .01-.02c.15.1.33.18.54.18s.39-.08.54-.18l.01.02L13 16.2l5.45 3.63.01-.02c.15.11.33.19.54.19.55 0 1-.45 1-1V6.82c-.31.11-.65.18-1 .18 0 .89-.39 1.67-1 2.22zM6 17.13l-4-2.67V2.87l4 2.67v11.59zM12 4c0 .55.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V5h2c.55 0 1-.45 1-1s-.45-1-1-1h-2V1c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1z"],"map-marker":["M9.98 0c-3.87 0-7 2.98-7 6.67 0 3.68 7 13.33 7 13.33s7-9.65 7-13.33c0-3.68-3.14-6.67-7-6.67zm0 10c-1.66 0-3-1.34-3-3s1.34-3 3-3 3 1.34 3 3-1.34 3-3 3z"],maximize:["M19 0h-5c-.55 0-1 .45-1 1s.45 1 1 1h2.59L11.3 7.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L18 3.41V6c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zM8 11c-.28 0-.53.11-.71.29L2 16.59V14c0-.55-.45-1-1-1s-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1H3.41l5.29-5.29c.19-.18.3-.43.3-.71 0-.55-.45-1-1-1z"],media:["M15 9c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm4-7H1c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zm-1 13l-6-5-2 2-4-5-4 8V4h16v11z"],menu:["M1 6h18c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1s.45 1 1 1zm18 3H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0 5H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],"menu-closed":["M8 6h11c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zM4 6c-.28 0-.53.11-.71.29l-3 3C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l3 3A1.003 1.003 0 005 13V7c0-.55-.45-1-1-1zm15 8H8c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm0-5H8c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1z"],"menu-open":["M12 9H1c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm0 5H1c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm0-10H1c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm7.71 5.29l-3-3A1.003 1.003 0 0015 7v6a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],"merge-columns":["M6.71 6.29a1.003 1.003 0 00-1.42 1.42L6.59 9H2V2h5v2.18c.42.15.8.39 1.11.7l.01-.01.88.89V1c0-.55-.45-1-1-1H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-4.76l-.88.88-.01-.01c-.31.31-.69.56-1.11.71V18H2v-7h4.59L5.3 12.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3zM19 0h-7c-.55 0-1 .45-1 1v4.76l.88-.88.01.01c.31-.31.69-.55 1.11-.7V2h5v7h-4.59l1.29-1.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L13.41 11H18v7h-5v-2.18c-.42-.15-.8-.39-1.11-.7l-.01.01-.88-.89V19c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"merge-links":["M10 13c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm8-5c-.93 0-1.71.64-1.93 1.5H14V4c0-2.21-1.79-4-4-4S6 1.79 6 4v5.5H3.93C3.71 8.64 2.93 8 2 8c-1.1 0-2 .9-2 2s.9 2 2 2c.93 0 1.71-.64 1.93-1.5H6V16c0 2.21 1.79 4 4 4s4-1.79 4-4v-5.5h2.07c.22.86 1 1.5 1.93 1.5 1.1 0 2-.9 2-2s-.9-2-2-2zm-5 8c0 1.66-1.34 3-3 3s-3-1.34-3-3V4c0-1.66 1.34-3 3-3s3 1.34 3 3v12zM10 3c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],minimize:["M8 11H3c-.55 0-1 .45-1 1s.45 1 1 1h2.59L.3 18.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L7 14.41V17c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1zM20 1a1.003 1.003 0 00-1.71-.71L13 5.59V3c0-.55-.45-1-1-1s-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1h-2.59l5.29-5.29c.19-.18.3-.43.3-.71z"],minus:["M16 9H4c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1z"],"mobile-phone":["M15 0H5c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-5 19c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm4-3H6V3h8v13z"],"mobile-video":["M19 5c-.28 0-.53.11-.71.29L15 8.59V5c0-.55-.45-1-1-1H1c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h13c.55 0 1-.45 1-1v-3.59l3.29 3.29c.18.19.43.3.71.3.55 0 1-.45 1-1V6c0-.55-.45-1-1-1z"],modal:["M19 1a1 1 0 011 1v16a1 1 0 01-1 1H1a1 1 0 01-1-1V2a1 1 0 011-1h18zm-1 4H2v12h16V5zm-3-3h-2v2h2V2zm3 0h-2v2h2V2z"],"modal-filled":["M20 5v13a1 1 0 01-1 1H1a1 1 0 01-1-1V5h20zm-3-4h2a1 1 0 011 1v1h-3V1zm-2 2H0V2a1 1 0 011-1h14v2z"],moon:["M19 14.15A9.94 9.94 0 019.94 20C4.45 20 0 15.55 0 10.06 0 6.03 2.4 2.56 5.85 1a9.811 9.811 0 00-.88 4.09c0 5.49 4.45 9.94 9.94 9.94 1.46 0 2.84-.31 4.09-.88z"],more:["M3.5 8a2.5 2.5 0 100 5 2.5 2.5 0 100-5zM17.5 8a2.5 2.5 0 100 5 2.5 2.5 0 100-5zM10.5 8a2.5 2.5 0 100 5 2.5 2.5 0 100-5z"],mountain:["M20 16H4l7-11h1l2 2h1l5 9zm-4-5l-1.5-3h-1l-1-1-1-1L8 11.5l3-1.5 1 1 1-1 3 1zM8.055 8L2.79 16H0l7-8h1.055z"],move:["M19.71 9.29l-3-3a1.003 1.003 0 00-1.42 1.42L16.59 9H11V3.41l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3C10.53.11 10.28 0 10 0s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L9 3.41V9H3.41L4.7 7.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L3.41 11H9v5.59L7.71 15.3A.965.965 0 007 15a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3a1.003 1.003 0 00-1.42-1.42L11 16.59V11h5.59l-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71z"],mugshot:["M19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18h-.07c-.05-.2-.12-.42-.22-.67-.46-1.05-2.68-1.75-4.16-2.4-1.48-.65-1.28-1.05-1.33-1.59-.01-.07-.01-.15-.01-.23.51-.45.92-1.07 1.19-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.34-.07.54-.44.61-.78.08-.14.23-.48.2-.87-.05-.5-.25-.73-.47-.82v-.09c0-.63-.06-1.55-.17-2.15-.02-.17-.06-.33-.11-.5a3.67 3.67 0 00-1.29-1.86C11.7 3.25 10.81 3 10.02 3s-1.68.25-2.31.73c-.61.47-1.07 1.13-1.29 1.86-.05.16-.09.33-.11.5-.12.6-.17 1.51-.17 2.14v.08c-.24.09-.44.32-.49.83-.04.39.12.73.2.87.08.35.28.72.63.78.04.17.09.33.15.48 0 .01.01.02.01.03l.01.01c.27.72.7 1.35 1.22 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.38 1.59-1.48.65-3.7 1.35-4.16 2.4-.12.27-.18.49-.23.69H2V2h16v16z"],"multi-select":["M19 3H7c-.55 0-1 .45-1 1v1h12v6h1c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zm-6 6H1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-6c0-.55-.45-1-1-1zm-1 6H2v-4h10v4zm4-9H4c-.55 0-1 .45-1 1v1h12v6h1c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1z"],music:["M19 0c-.08 0-.16.03-.24.05V.03l-12 3v.02C6.33 3.16 6 3.53 6 4v11.35c-.59-.22-1.27-.35-2-.35-2.21 0-4 1.12-4 2.5S1.79 20 4 20c1.94 0 3.55-.86 3.92-2H8V7.78l10-2.5v7.07c-.59-.22-1.27-.35-2-.35-2.21 0-4 1.12-4 2.5s1.79 2.5 4 2.5c1.94 0 3.55-.86 3.92-2H20V1c0-.55-.45-1-1-1z"],nest:["M2 2c.55 0 1 .45 1 1v5c0 2.21 1.79 4 4 4h8.59L13.3 9.71A.965.965 0 0113 9a1.003 1.003 0 011.71-.71l4 4c.18.18.29.43.29.71 0 .28-.11.53-.29.71l-4 4a1.003 1.003 0 01-1.42-1.42l2.3-2.29H7c-3.31 0-6-2.69-6-6V3c0-.55.45-1 1-1z"],"new-drawing":["M18.7 13.7c.5 0 1 .4 1 1 0 .257-.073.44-.22.614l-.08.086-4 4c-.2.2-.4.3-.7.3-.6 0-1-.5-1-1 0-.257.073-.44.22-.614L14 18l4-4c.2-.2.4-.3.7-.3zM1.8 0l8.378 2.982A3.003 3.003 0 0013 7a3.003 3.003 0 003.877 2.87l.723 2.53.049.06a.41.41 0 01.051.24c0 .167-.07.403-.208.593l-.092.107-4 4c-.2.2-.4.3-.7.3-.075 0-.15-.056-.225-.084L12.4 17.6l-7-2-.112-.042c-.223-.094-.431-.244-.542-.45L4.7 15 0 1.8l.5-.6L7 7.7c-.2.3-.3.6-.3 1 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2a1.68 1.68 0 00-.871.22L7.7 7 1.2.5l.6-.5zM16 0c.55 0 1 .45 1 1v2h2c.55 0 1 .45 1 1s-.45 1-1 1h-2v2c0 .432-.278.803-.664.941l-.01.004A.989.989 0 0116 8c-.55 0-1-.45-1-1V5h-2c-.55 0-1-.45-1-1l.007-.116C12.065 3.388 12.489 3 13 3h2V1c0-.55.45-1 1-1z"],"new-grid-item":["M8 0H1C.45 0 0 .45 0 1v7c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm0 11H1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h7c.55 0 1-.45 1-1v-7c0-.55-.45-1-1-1zm6 7h-1v-1c0-.55-.45-1-1-1s-1 .45-1 1v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1s-.45-1-1-1zm5-7h-2c-.55 0-1 .45-1 1s.45 1 1 1h1v1c0 .55.45 1 1 1s1-.45 1-1v-2c0-.55-.45-1-1-1zm0-11h-7c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-5 11h-2c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1s1-.45 1-1v-1h1c.55 0 1-.45 1-1s-.45-1-1-1zm5 5c-.55 0-1 .45-1 1v1h-1c-.55 0-1 .45-1 1s.45 1 1 1h2c.55 0 1-.45 1-1v-2c0-.55-.45-1-1-1z"],"new-layer":["M11.513 2.663A2 2 0 0013 6h1v1a2 2 0 104 0v-.733l1.5.833c.3.2.5.5.5.9s-.2.7-.5.9l-9 5c-.2.1-.3.1-.5.1s-.3 0-.5-.1l-9-5C.2 8.7 0 8.4 0 8s.2-.7.5-.9l9-5c.2-.1.3-.1.5-.1s.3 0 .5.1l1.013.563zM17 3h2a1 1 0 010 2h-2v2a1 1 0 01-2 0V5h-2a1 1 0 010-2h2V1a1 1 0 012 0v2z"],"new-layers":["M17 3h2a1 1 0 010 2h-2v2a1 1 0 01-2 0V5h-2a1 1 0 010-2h2V1a1 1 0 012 0v2zm-1.252 5.984L10.5 11.9c-.2.1-.3.1-.5.1s-.3 0-.5-.1l-9-5C.2 6.7 0 6.4 0 6s.2-.7.5-.9l9-5c.2-.1.3-.1.5-.1s.3 0 .5.1L13.92 2H13a2 2 0 100 4h1v1a2 2 0 001.748 1.984zm2.07-1.15C17.935 7.58 18 7.298 18 7V6h1c.353 0 .684-.091.972-.251.018.078.028.162.028.251 0 .4-.2.7-.5.9l-1.682.934zM19 9c.6 0 1 .4 1 1 0 .4-.2.7-.5.9l-9 5c-.2.1-.3.1-.5.1s-.3 0-.5-.1l-9-5c-.3-.2-.5-.5-.5-.9 0-.6.4-1 1-1 .2 0 .3 0 .5.1l8.5 4.8 8.5-4.8c.2-.1.3-.1.5-.1zm0 4c.6 0 1 .4 1 1 0 .4-.2.7-.5.9l-9 5c-.2.1-.3.1-.5.1s-.3 0-.5-.1l-9-5c-.3-.2-.5-.5-.5-.9 0-.6.4-1 1-1 .2 0 .3 0 .5.2l8.5 4.7 8.5-4.8c.2-.1.3-.1.5-.1z"],"new-link":["M14.5 12a2.5 2.5 0 00-2.45 2h-7.1a2.5 2.5 0 100 1h7.1a2.5 2.5 0 102.45-3zM19 5h-2V3c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V7h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"new-object":["M12 4c0 .6.4 1 1 1h2v2c0 .6.4 1 1 1 .5 0 1-.4 1-1V5h2c.5 0 1-.4 1-1s-.5-1-1-1h-2V1c0-.6-.5-1-1-1-.6 0-1 .4-1 1v2h-2c-.6 0-1 .5-1 1zm7 3c0 1.7-1.3 3-3 3s-3-1.3-3-3c-1.7 0-3-1.3-3-3s1.3-3 3-3c0-.2 0-.4.1-.5-1-.3-2-.5-3.1-.5C4.5 0 0 4.5 0 10s4.5 10 10 10 10-4.5 10-10c0-1.1-.2-2.1-.5-3H19z"],"new-person":["M11.41 15.92c-1.46-.65-1.26-1.05-1.31-1.59-.01-.07-.01-.15-.01-.23.5-.45.91-1.07 1.18-1.78 0 0 .01-.04.02-.05.06-.15.11-.32.15-.48.33-.07.53-.44.6-.78.08-.14.23-.48.2-.87-.05-.5-.24-.73-.47-.82v-.09c0-.63-.06-1.55-.17-2.15-.02-.17-.06-.33-.11-.5-.22-.73-.67-1.4-1.27-1.86C9.58 4.25 8.7 4 7.92 4c-.78 0-1.66.25-2.28.73-.61.47-1.06 1.13-1.27 1.86-.05.16-.08.33-.11.5-.12.6-.18 1.51-.18 2.14v.08c-.23.09-.43.32-.48.83-.04.39.12.73.2.87.08.35.28.72.62.78.04.17.09.33.15.48 0 .01.01.02.01.03l.01.01c.27.72.69 1.35 1.21 1.8 0 .07-.01.14-.01.21-.05.54.1.94-1.36 1.59-1.46.65-3.66 1.35-4.11 2.4C-.14 19.38.04 20 .04 20h15.75s.18-.62-.27-1.67c-.45-1.06-2.65-1.75-4.11-2.41zM18.87 3h-2V1c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V5h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"new-prescription":["M11.95 10.23c.16-.18.22-.22.46-.22h1.48c.25 0 .47.08.59.33.1.2.09.41-.05.66l-2.71 3.58L14.88 19c.13.21.16.46.03.69-.12.21-.34.31-.57.31H12.7c-.31 0-.56-.17-.7-.44l-1.9-2.67-1.93 2.68c-.15.27-.42.43-.73.43H5.98c-.25 0-.47-.08-.59-.33-.1-.2-.09-.41.05-.66l3.09-4.35L4.26 9H3v4.32c0 .41-.3.69-.7.69H.7c-.41 0-.7-.28-.7-.69V.69C0 .28.3 0 .7 0h4.42c.71 0 1.36.1 1.94.3.59.2 1.11.49 1.54.87.44.38.78.84 1.02 1.39.25.54.37 1.13.37 1.77 0 1.01-.28 1.88-.84 2.6-.43.54-1.35 1.29-2 1.59l3.09 3.94 1.71-2.23zM4.71 6.04c.71 0 1.45-.16 1.81-.46.33-.28.5-.69.5-1.25s-.17-.97-.5-1.25c-.35-.3-1.1-.46-1.81-.46h-1.7v3.42h1.7zM19 3c.55 0 1 .45 1 1s-.45 1-1 1h-2v2c0 .55-.45 1-1 1s-1-.45-1-1V5h-2c-.55 0-1-.45-1-1s.45-1 1-1h2V1c0-.55.45-1 1-1s1 .45 1 1v2h2z"],"new-text-box":["M19 3h-2V1c0-.55-.45-1-1-1s-1 .45-1 1v2h-2c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V5h2c.55 0 1-.45 1-1s-.45-1-1-1zM5 7.5v1c0 .28.22.5.5.5s.5-.22.5-.5V8h2v7h-.5c-.28 0-.5.22-.5.5s.22.5.5.5h2c.28 0 .5-.22.5-.5s-.22-.5-.5-.5H9V8h2v.5c0 .28.22.5.5.5s.5-.22.5-.5v-1c0-.28-.22-.5-.5-.5h-6c-.28 0-.5.22-.5.5zM16 9c-.55 0-1 .45-1 1v8H2V5h8c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1v15c0 .55.45 1 1 1h15c.55 0 1-.45 1-1v-9c0-.55-.45-1-1-1z"],ninja:["M20 6s-2.98 2.43-6.12 2.19C13.52 5.31 12.05 0 6 0c0 0 2.41 2.99 2.16 6.12C5.27 6.49 0 7.97 0 14c0 0 2.98-2.43 6.11-2.19C6.47 14.69 7.94 20 14 20c0 0-2.42-2.99-2.16-6.13C14.73 13.51 20 12.02 20 6zm-10 6c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"],"not-equal-to":["M9.487 7l.532-3.196a1 1 0 011.962.392L11.513 7H16a1 1 0 010 2h-4.82l-.333 2H16a1 1 0 010 2h-5.487l-.532 3.196a1 1 0 01-1.962-.392L8.487 13H4a1 1 0 010-2h4.82l.333-2H4a1 1 0 110-2h5.487z"],notifications:["M10 20c1.1 0 2-.9 2-2H8c0 1.1.9 2 2 2zm7-5c-.55 0-1-.45-1-1V8c0-2.61-1.67-4.81-4-5.63V2c0-1.1-.9-2-2-2S8 .9 8 2v.37C5.67 3.19 4 5.39 4 8v6c0 .55-.45 1-1 1s-1 .45-1 1 .45 1 1 1h14c.55 0 1-.45 1-1s-.45-1-1-1z"],"notifications-snooze":["M10 18c0 1.1-.9 2-2 2s-2-.9-2-2zM8 0c.476 0 .914.168 1.258.448C8.508.878 8.09 1.562 8 2.5c-.133 1.4.4 2.367 1.6 2.9C8.533 6.6 8 7.467 8 8v1.2a2.8 2.8 0 002.8 2.8H14v2c0 .51.388.935.884.993L15 15c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1s.45-1 1-1 1-.45 1-1V8c0-2.61 1.67-4.81 4-5.63V2c0-1.1.9-2 2-2z","M16 9.25v-.395a.75.75 0 00-.75-.75h-2.813L15.834 3.9A.75.75 0 0016 3.43v-.68a.75.75 0 00-.75-.75h-4.5a.75.75 0 00-.75.75v.184c0 .414.336.75.75.75h2.813L10.22 7.831a1 1 0 00-.221.627v.792c0 .414.336.75.75.75h4.5a.75.75 0 00.75-.75z"],"notifications-updated":["M10 20c1.1 0 2-.9 2-2H8c0 1.1.9 2 2 2zm2-17.834A2.994 2.994 0 008 4.99c0 .808.319 1.557.876 2.114l2.97 2.99a2.99 2.99 0 004.154.072V14c0 .55.45 1 1 1s1 .45 1 1-.45 1-1 1H3c-.55 0-1-.45-1-1s.45-1 1-1 1-.45 1-1V8c0-2.61 1.67-4.81 4-5.63V2c0-1.1.9-2 2-2s2 .9 2 2v.166zm1.26 6.514l-2.97-2.99a.973.973 0 01-.29-.7c0-.55.44-1 .99-1 .27 0 .52.11.7.29l2.28 2.28 4.27-4.27a.99.99 0 01.7-.29c.55 0 1 .45 1 1 0 .28-.11.53-.3.7l-4.98 4.98a.99.99 0 01-1.4 0z"],"numbered-list":["M1.74 9.01h1.27V1h-.95c-.04.24-.12.45-.26.62-.13.17-.29.3-.47.41-.19.11-.4.18-.63.23-.23.04-.46.07-.71.07v1.03h1.75v5.65zm.43 7.93c.18-.14.37-.28.58-.43.21-.14.42-.29.63-.45.21-.16.41-.33.61-.5.2-.18.37-.38.52-.59.15-.21.28-.45.37-.7.09-.25.14-.54.14-.85 0-.25-.04-.52-.12-.8-.08-.28-.21-.54-.39-.78-.19-.24-.43-.44-.73-.59-.3-.17-.68-.25-1.12-.25-.41 0-.77.08-1.08.23-.32.16-.58.37-.8.64-.22.27-.38.59-.49.96-.11.37-.16.77-.16 1.21h1.19c.01-.28.03-.53.08-.77s.12-.45.21-.62c.09-.18.22-.31.38-.42.16-.1.35-.15.59-.15.26 0 .47.05.63.14.16.09.29.21.38.35.09.14.15.29.18.45.03.16.05.31.05.45-.01.31-.08.58-.22.81-.14.24-.32.45-.53.66-.22.2-.45.39-.71.57-.26.18-.51.36-.74.54-.5.36-.89.78-1.17 1.27-.3.47-.45 1.04-.46 1.69H5v-1.14H1.43c.05-.17.14-.33.27-.49.13-.15.29-.3.47-.44zM18 4.02H8c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-1c0-.56-.45-1-1-1zm0 9H8c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-1c0-.56-.45-1-1-1z"],numerical:["M2.39 5.75c-.17.21-.38.39-.63.52s-.52.23-.83.29c-.3.05-.61.08-.93.08v1.24h2.49V15h1.49V4.98H2.73c-.05.31-.17.57-.34.77zm17.2 4.71c-.27-.44-.65-.71-1.14-.82v-.02c.42-.16.72-.43.92-.79.2-.36.29-.79.29-1.27 0-.42-.08-.8-.23-1.12-.15-.33-.36-.59-.62-.8-.26-.21-.55-.37-.87-.48-.32-.11-.65-.16-.98-.16-.43 0-.82.08-1.16.25-.34.16-.63.39-.87.69-.24.29-.43.64-.57 1.04-.14.4-.22.83-.23 1.3h1.39c-.01-.25.02-.49.07-.72.06-.23.14-.44.26-.63s.27-.34.45-.45c.18-.11.39-.17.63-.17.39 0 .71.12.96.37s.37.58.37.99c0 .29-.05.54-.16.74-.11.2-.25.36-.43.47-.18.11-.38.19-.61.24-.23.05-.46.06-.68.05v1.17c.28-.01.55 0 .81.03s.5.1.71.21c.21.11.38.28.51.5.13.22.2.52.2.89 0 .55-.16.97-.47 1.27-.31.3-.7.45-1.17.45-.55 0-.95-.19-1.23-.58-.27-.39-.4-.88-.38-1.46h-1.39c.01.5.08.96.21 1.38.13.41.32.77.57 1.06.25.29.56.52.93.68.37.16.8.24 1.3.24.41 0 .79-.07 1.16-.21.37-.14.69-.33.96-.58.28-.25.5-.56.66-.92a3 3 0 00.24-1.23c0-.64-.14-1.17-.41-1.61zM8.58 12.41c.21-.18.45-.36.7-.53.25-.18.5-.36.75-.56.25-.2.49-.41.73-.63.23-.22.44-.47.63-.74.18-.27.33-.56.44-.88.11-.32.16-.67.16-1.07 0-.32-.05-.65-.14-1-.09-.35-.25-.68-.47-.97-.22-.3-.51-.55-.87-.74-.36-.2-.81-.29-1.35-.29-.49 0-.93.1-1.3.29-.37.18-.69.44-.95.78-.26.33-.45.73-.58 1.2-.13.46-.2.96-.2 1.5h1.43c.01-.35.04-.67.09-.97.05-.3.14-.56.25-.78.11-.22.26-.39.45-.52s.43-.19.71-.19c.31 0 .56.06.75.18.19.12.34.26.45.43.11.17.18.36.22.56.04.2.06.39.06.57-.01.38-.1.72-.26 1.02-.15.3-.37.57-.63.83-.26.25-.54.49-.85.71-.31.22-.61.45-.89.68-.6.45-1.06.98-1.41 1.58-.35.61-.52 1.32-.53 2.13h6.01v-1.43H7.69c.06-.21.17-.42.33-.61s.34-.38.56-.55z"],office:["M19 6h-5V1c0-.55-.45-1-1-1H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h4v-6h4v6h10c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1zM6 12H2V8h4v4zm0-6H2V2h4v4zm6 6H8V8h4v4zm0-6H8V2h4v4zm6 11h-4v-3h4v3zm0-5h-4V8h4v4z"],offline:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM7 18l2-7H5l8-9-2 7h4l-8 9z"],"oil-field":["M19 17.99h-1.36l-4.35-9.57 2.91-.86 1.66 4.1c.11.27.43.4.72.31.12-.04.22-.11.28-.2.06-.11 1.47-2.08 1.05-5.6C19.79 5.12 19.3 0 16.01 0 14.89.01 13.99.83 14 1.84c0 .19.04.38.1.56l1.34 3.31L.72 10.03v.02c-.41.12-.72.49-.72.94 0 .55.45 1 1 1 .1 0 .19-.03.28-.06v.02l2-.59 1.47 6.63H3c-.55 0-1 .45-1 1s.45 1 1 1h16c.55 0 1-.45 1-1s-.45-1-1-1zM5.2 10.8l3.95-1.16-2.83 6.22L5.2 10.8zm2.35 7.19l3.95-8.68 3.95 8.68h-7.9z"],"one-column":["M14.94 0h-4c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-8 6c-.28 0-.53.11-.71.29l-3 3c-.18.18-.29.43-.29.71s.11.53.29.71l3 3A1.003 1.003 0 007.94 13V7c0-.55-.45-1-1-1z"],"one-to-many":["M18 3a1 1 0 11-2 0 1 1 0 012 0zm-3.82 1.028a6.243 6.243 0 00-1.667.347c-.947.352-1.773 1-2.032 2.318C10.158 8.337 9.247 9.368 8.217 10c1.03.632 1.941 1.663 2.264 3.307.259 1.318 1.085 1.966 2.032 2.318.581.217 1.18.308 1.668.347a3.001 3.001 0 11-.019 2.004c-.633-.042-1.491-.158-2.347-.476-1.402-.523-2.868-1.625-3.296-3.807-.259-1.318-1.085-1.966-2.032-2.318a5.314 5.314 0 00-.722-.21 3 3 0 110-2.33c.238-.052.481-.12.722-.21.947-.352 1.773-1 2.032-2.318.428-2.182 1.894-3.284 3.296-3.807.856-.318 1.714-.434 2.347-.476A3.001 3.001 0 0120 3a3 3 0 01-5.82 1.028zM4 10a1 1 0 100 .002v-.002zM17 18a1 1 0 100-2 1 1 0 000 2z"],"one-to-one":["M2 10a1 1 0 112 0 1 1 0 01-2 0zm3.83-1a3.001 3.001 0 100 2h8.34a3.001 3.001 0 100-2H5.83zM17 9a1 1 0 100 2 1 1 0 000-2z"],outdated:["M10 0c5.52 0 10 4.48 10 10s-4.48 10-10 10S0 15.52 0 10c0-.55.45-1 1-1s1 .45 1 1c0 4.42 3.58 8 8 8s8-3.58 8-8-3.58-8-8-8C7.47 2 5.22 3.17 3.76 5H5c.55 0 1 .45 1 1s-.45 1-1 1H1c-.55 0-1-.45-1-1V2c0-.55.45-1 1-1s1 .45 1 1v2.05C3.82 1.6 6.71 0 10 0zm1 16H9v-2h2v2zm0-3H9V4h2v9z"],"page-layout":["M19 1H1c-.55 0-1 .45-1 1v16c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zM7 17H2V8h5v9zm11 0H8V8h10v9zm0-10H2V3h16v4z"],"panel-stats":["M1 1h18a1 1 0 011 1v15a1 1 0 01-1 1H1a1 1 0 01-1-1V2a1 1 0 011-1zm1 2v13h16V3H2zm9 0h1v13h-1V3zm2 7h3.952v1H13v-1zm0 2h3.952v1H13v-1zm0 2h3.952v1H13v-1zm0-6h3.952v1H13V8zm0-2h3.952v1H13V6zm0-2h3.952v1H13V4z"],"panel-table":["M19 1H1c-.6 0-1 .4-1 1v15c0 .6.4 1 1 1h18c.6 0 1-.4 1-1V2c0-.6-.4-1-1-1zm-9 11H7V9h3v3zm0-4H7V5h3v3zm-8 8V3h4v13H2zm5 0v-3h3v3H7zm11 0h-7v-3h7v3zm0-4h-7V9h7v3zm0-4h-7V5h7v3z"],paperclip:["M18.35 2.67A5.664 5.664 0 0014.33 1c-1.44 0-2.89.56-3.99 1.67l-9.16 9.27C.4 12.73 0 13.78 0 14.83s.39 2.1 1.18 2.9c.78.79 1.82 1.18 2.85 1.18 1.04 0 2.07-.39 2.87-1.2l9.14-9.27c.96-.96.96-2.5.02-3.45-.94-.95-2.49-.96-3.44 0l-7.59 7.69c-.31.32-.3.83.01 1.14.31.31.81.31 1.13.02l7.59-7.69c.31-.31.84-.31 1.13-.02.31.31.31.85 0 1.16l-9.14 9.27c-.93.95-2.54.93-3.45.02-.94-.95-.92-2.55.02-3.49l9.16-9.25c1.55-1.56 4.18-1.59 5.72-.03 1.56 1.57 1.55 4.26 0 5.82l-8.89 9.02c-.3.31-.3.81.01 1.11.3.3.79.31 1.1.01v.01l8.91-9.02A5.645 5.645 0 0020 6.73c0-1.48-.55-2.94-1.65-4.06z"],paragraph:["M16.5 1H7C4.2 1 2 3.2 2 6s2.2 5 5 5v6.5c0 .8.7 1.5 1.5 1.5s1.5-.7 1.5-1.5V4h2v13.5c0 .8.7 1.5 1.5 1.5s1.5-.7 1.5-1.5V4h1.5c.8 0 1.5-.7 1.5-1.5S17.3 1 16.5 1z"],path:["M18 0H2C.9 0 0 .9 0 2s.9 2 2 2h7v4H4c-1.1 0-2 .9-2 2s.9 2 2 2h5v4H6c-1.1 0-2 .9-2 2s.9 2 2 2h8c1.1 0 2-.9 2-2s-.9-2-2-2h-3v-4h5c1.1 0 2-.9 2-2s-.9-2-2-2h-5V4h7c1.1 0 2-.9 2-2s-.9-2-2-2z"],"path-search":["M4 7c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm15 11.69l-5-2.5v-3.63c-.32.11-.66.22-1 .29v3.32l-6 2.57v-7.25c-.36-.27-.69-.57-1-.9v8.1l-5-2.5V10c.55 0 1-.45 1-1s-.45-1-1-1V1.31l3.43 1.71c.11-.31.24-.62.39-.92L.72.05A.545.545 0 00.5 0C.22 0 0 .22 0 .5v16c0 .2.12.36.28.44l6 3c.07.04.14.06.22.06.07 0 .14-.01.2-.04l6.79-2.91 5.79 2.9c.07.03.14.05.22.05.28 0 .5-.22.5-.5v-4.21c-.31.13-.64.21-1 .21v3.19zM10 5c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm3-1c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1zm6.72-.94l-1.43-.72c.2.43.36.89.48 1.36l.23.11V5.5c-.55 0-1 .45-1 1s.45 1 1 1v1.96l1 1V3.5c0-.2-.12-.36-.28-.44zm-3.69 5.56c.14-.21.27-.42.38-.65.02-.04.04-.07.05-.11.11-.22.2-.45.28-.69v-.01c.07-.24.13-.48.17-.73l.03-.17c.04-.25.06-.5.06-.76C17 2.46 14.54 0 11.5 0S6 2.46 6 5.5 8.46 11 11.5 11c.26 0 .51-.02.76-.06l.17-.03c.25-.04.49-.1.73-.17h.01c.24-.08.47-.17.69-.28.04-.02.07-.03.11-.05.23-.11.44-.24.65-.38l.18.18 3.5 3.5c.17.18.42.29.7.29a1.003 1.003 0 00.71-1.71l-3.68-3.67zm-4.53.88c-2.21 0-4-1.79-4-4s1.79-4 4-4 4 1.79 4 4-1.79 4-4 4z"],pause:["M7 3H4c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1zm9 0h-3c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h3c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],people:["M16.94 17a4.92 4.92 0 00-.33-1.06c-.45-.97-1.37-1.52-3.24-2.3-.17-.07-.76-.31-.77-.32-.1-.04-.2-.08-.28-.12.05-.14.04-.29.06-.45 0-.05.01-.11.01-.16-.25-.21-.47-.48-.65-.79.22-.34.41-.71.56-1.12l.04-.11c-.01.02-.01.02-.02.08l.06-.15c.36-.26.6-.67.72-1.13.18-.37.29-.82.25-1.3-.05-.5-.21-.92-.47-1.22-.02-.53-.06-1.11-.12-1.59.38-.17.83-.26 1.24-.26.59 0 1.26.19 1.73.55.46.35.8.85.97 1.4.04.13.07.25.08.38.08.45.13 1.14.13 1.61v.07c.16.07.31.24.35.62.02.29-.09.55-.15.65-.05.26-.2.53-.46.59-.03.12-.07.25-.11.36-.01.01-.01.04-.01.04-.2.53-.51 1-.89 1.34 0 .06 0 .12.01.17.04.41-.11.71 1 1.19 1.1.5 2.77 1.01 3.13 1.79.34.79.2 1.25.2 1.25h-3.04zm-5.42-3.06c1.47.66 3.7 1.35 4.18 2.39.45 1.05.27 1.67.27 1.67H.04s-.19-.62.27-1.67c.46-1.05 2.68-1.75 4.16-2.4 1.48-.65 1.33-1.05 1.38-1.59 0-.07.01-.14.01-.21-.52-.45-.95-1.08-1.22-1.8l-.01-.01c0-.01-.01-.02-.01-.03-.07-.15-.12-.32-.16-.49-.34-.06-.54-.43-.62-.78-.08-.14-.24-.48-.2-.87.05-.51.26-.74.49-.83v-.08c0-.64.05-1.55.17-2.15a3.648 3.648 0 011.4-2.36C6.32 2.25 7.21 2 8 2s1.68.25 2.31.73a3.63 3.63 0 011.4 2.36c.11.6.17 1.52.17 2.15v.09c.22.09.42.32.47.82.03.39-.12.73-.2.87-.07.34-.27.71-.61.78-.04.16-.09.33-.15.48-.01.01-.02.05-.02.05-.27.71-.68 1.33-1.19 1.78 0 .08 0 .16.01.23.05.55-.15.95 1.33 1.6z"],percentage:["M15 10c-1.66 0-3 1.34-3 3v2c0 1.66 1.34 3 3 3s3-1.34 3-3v-2c0-1.66-1.34-3-3-3zm1 5c0 .55-.45 1-1 1s-1-.45-1-1v-2c0-.55.45-1 1-1s1 .45 1 1v2zM8 7V5c0-1.66-1.34-3-3-3S2 3.34 2 5v2c0 1.66 1.34 3 3 3s3-1.34 3-3zM4 7V5c0-.55.45-1 1-1s1 .45 1 1v2c0 .55-.45 1-1 1s-1-.45-1-1zm11-4a1.003 1.003 0 00-1.88-.48L5.14 16.49a1.003 1.003 0 101.74.99l7.99-13.97c.08-.15.13-.32.13-.51z"],person:["M19.61 17.91c-.57-1.32-3.35-2.19-5.19-3.01-1.85-.82-1.59-1.31-1.66-1.99-.01-.09-.01-.19-.02-.29.63-.56 1.15-1.33 1.49-2.22 0 0 .02-.05.02-.06.07-.19.13-.39.19-.6.42-.09.67-.55.76-.98.1-.17.29-.6.25-1.08-.06-.62-.31-.91-.59-1.03v-.11c0-.79-.07-1.93-.22-2.68A4.55 4.55 0 0012.9.92C12.11.32 11 0 10.01 0s-2.1.32-2.89.92a4.55 4.55 0 00-1.74 2.94c-.14.75-.22 1.89-.22 2.68v.1c-.29.11-.55.4-.61 1.04-.04.48.15.91.25 1.08.1.44.35.91.79.98.05.21.12.41.19.6 0 .01.01.03.01.04l.01.02c.34.91.87 1.69 1.52 2.25 0 .09-.01.18-.02.26-.07.68.13 1.17-1.72 1.99S.96 16.59.39 17.91C-.18 19.23.05 20 .05 20h19.9s.23-.77-.34-2.09z"],phone:["M19.91 15.51c-.08-.08-4.21-2.5-4.35-2.57a.876.876 0 00-.4-.1c-.19 0-.42.13-.71.4-.28.27-1.17 1.49-1.43 1.76s-.48.4-.65.4c-.08 0-.19-.02-.32-.07s-1.45-.73-4.2-3.15-3.11-4-3.13-4.44c0-.17.13-.39.4-.65.28-.25.57-.51.89-.74.32-.24.61-.5.88-.78s.4-.52.4-.71c0-.13-.03-.27-.1-.4C7.12 4.32 4.62.19 4.53.1c-.19-.18-.92-.1-1.29.1C.25 1.82 0 4 .05 4.86c.05.89.61 5.58 5.2 9.93 5.7 5.41 9.66 5.2 9.92 5.2.87 0 3.52-.48 4.65-3.19.16-.38.31-1.07.09-1.29z"],"pie-chart":["M9 .98c-4.5.5-8 4.31-8 8.94 0 4.97 4.03 9.04 9 9.04 4.63 0 8.44-3.96 8.94-7.96H9V.98z","M10-.08V10h10C20 4 15.52-.08 10-.08z"],pin:["M11.77 1.16c-.81.81-.74 2.28.02 3.76L6.1 8.71c-2.17-1.46-4.12-2-4.94-1.18l4.95 4.95-4.95 6.36 6.36-4.95 4.95 4.95c.82-.82.27-2.77-1.19-4.94l3.8-5.69c1.47.76 2.94.84 3.76.02l-7.07-7.07z"],pivot:["M5.83 9.75L.29 15.29a1.003 1.003 0 001.42 1.42l5.54-5.54c-.57-.37-1.05-.85-1.42-1.42zM19 11c-.55 0-1 .45-1 1v1.59l-3.83-3.83c-.37.56-.85 1.04-1.41 1.41L16.59 15H15c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1zm-5-4c0-2.21-1.79-4-4-4S6 4.79 6 7s1.79 4 4 4 4-1.79 4-4zm-4 2c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"],"pivot-table":["M3 5H1c-.55 0-1 .45-1 1v13c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm0-5H1C.45 0 0 .45 0 1v2c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm13.71 5.29C16.53 5.11 16.28 5 16 5s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L15 8.41V11c0 2.21-1.79 4-4 4H8.41l1.29-1.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L8.41 17H11c3.31 0 6-2.69 6-6V8.41l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3zM19 0H6c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],play:["M16 10c0-.36-.2-.67-.49-.84l.01-.01-10-6-.01.01A.991.991 0 005 3c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1 .19 0 .36-.07.51-.16l.01.01 10-6-.01-.01c.29-.17.49-.48.49-.84z"],plus:["M16 9h-5V4c0-.55-.45-1-1-1s-1 .45-1 1v5H4c-.55 0-1 .45-1 1s.45 1 1 1h5v5c0 .55.45 1 1 1s1-.45 1-1v-5h5c.55 0 1-.45 1-1s-.45-1-1-1z"],"polygon-filter":["M18 7c-.27 0-.52.05-.75.15l-6.28-4.88c.01-.09.03-.18.03-.27 0-1.1-.9-2-2-2S7 .9 7 2c0 .06.01.12.02.19l-4.19 3C2.57 5.07 2.29 5 2 5 .9 5 0 5.9 0 7c0 .74.4 1.38 1 1.72v7.55c-.6.35-1 .99-1 1.73 0 1.1.9 2 2 2 .74 0 1.38-.4 1.72-1h7.55c.35.6.98 1 1.72 1 1.1 0 2-.9 2-2 0-.37-.11-.72-.29-1.02L18.03 11A2 2 0 0018 7zm-5.03 9c-.72.01-1.35.41-1.69 1H3.72c-.17-.3-.42-.55-.72-.72V8.72c.6-.34 1-.98 1-1.72 0-.06-.01-.12-.02-.19l4.19-3c.26.12.54.19.83.19.27 0 .52-.05.75-.15l6.28 4.88c-.01.09-.03.18-.03.27 0 .37.11.72.29 1.02L12.97 16z"],power:["M10 10c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1S9 .45 9 1v8c0 .55.45 1 1 1zm3-7.45v2.16c2.36 1.12 4 3.5 4 6.29 0 3.87-3.13 7-7 7s-7-3.13-7-7c0-2.79 1.64-5.17 4-6.29V2.55C3.51 3.79 1 7.09 1 11a9 9 0 0018 0c0-3.91-2.51-7.21-6-8.45z"],"predictive-analysis":["M20 8.01c0-1.26-.61-2.43-1.61-3.12C17.86 2.5 15.8.79 13.4.79c-.58 0-1.14.1-1.69.29A3.533 3.533 0 009.17 0C8.05 0 7 .55 6.32 1.45c-.15-.02-.3-.03-.45-.03-1.63 0-3.03 1.12-3.46 2.71C.97 4.65 0 6.05 0 7.66c0 .48.09.95.26 1.4-.17.44-.26.91-.26 1.39 0 1.38.72 2.64 1.89 3.29.67.7 1.59 1.09 2.54 1.09.61 0 1.19-.15 1.71-.45.68.82 1.68 1.3 2.73 1.3.66 0 1.28-.18 1.83-.52.61.49 1.34.81 2.11.91 1.3 1.43 2.3 3.28 2.31 3.3 0 0 .35.61.33.61.96-.01 1.77-.2 1.64-1.3.01.02-.92-2.89-.92-2.89.52-.26.94-.69 1.21-1.23 1.12-.66 1.84-1.91 1.84-3.26 0-.3-.03-.6-.1-.89.57-.64.88-1.51.88-2.4zm-1.54 1.28l-.18-.2-.77-.84c-.33-.37-.67-1.17-.73-1.73 0 0-.13-1.25-.13-1.26-.06-.74-1.17-.73-1.13.14 0 .02.13 1.26.13 1.26.04.36.15.77.3 1.17-.08-.01-.15-.02-.22-.02 0 0-2.57-.12-2.57-.13-.73-.03-.89 1.22-.05 1.25l2.57.13c.53.03 1.29.37 1.61.72l.61.67.02.06c.1.27.14.55.14.83 0 .93-.51 1.77-1.34 2.18l-.2.1-.09.23c-.19.48-.6.82-1.1.93l-.67.14.87 2.75c-.48-.76-1.19-1.79-2.02-2.67l-.15-.16-.21-.02c-.51-.04-.99-.21-1.42-.48l1.7-1.48c.44-.39 1.04-.55 1.24-.49 0 0 .78.22.78.23.78.2 1.03-.92.29-1.21l-.78-.23c-.69-.2-1.67.22-2.24.72l-1.91 1.66-.39.32c-.44.36-.93.55-1.5.55-.8 0-1.54-.41-1.97-1.07v-1.88c0-.5.21-.98.34-1.07 0 0 .65-.43.64-.43.87-.69.21-1.57-.64-1.14 0-.01-.65.43-.65.43-.31.2-.54.56-.7.97-.13-.13-.28-.25-.43-.35 0 0-1.91-1.26-1.91-1.28-.81-.56-1.5.63-.61 1.11 0-.02 1.89 1.28 1.89 1.28.46.31.77.97.77 1.36v.84c-.43.24-.78.36-1.24.36-.67 0-1.31-.29-1.77-.79l-.07-.08-.09-.05a2.425 2.425 0 01-1.31-2.16c0-.38.09-.74.25-1.08l.15-.31-.14-.33c-.17-.34-.25-.7-.25-1.08 0-1.13.76-2.1 1.85-2.37l.39-.09.07-.43a2.41 2.41 0 012.39-2.05c.19 0 .39.02.58.07l.4.1.22-.38A2.41 2.41 0 019.17 1.3c.55 0 1.08.19 1.5.53l-.44.45-.01-.01-.31.31c-.41.35-.92.53-1.11.5 0 0-.84-.13-.84-.14-.83-.15-1.09 1.08-.18 1.29.01 0 .84.14.84.14.03 0 .06 0 .09.01-.14.46-.18.96-.12 1.4 0 0 .21 1.24.19 1.23.13.65 1.32.44 1.16-.22 0-.01-.19-1.23-.19-1.23-.07-.48.15-1.19.45-1.5l.48-.5c.07-.06.13-.12.19-.18l.93-.95c.5-.23 1.04-.34 1.59-.34 1.93 0 3.57 1.4 3.89 3.34l.05.31.26.15a2.445 2.445 0 01.87 3.4z"],prescription:["M13.95 10.23c.16-.18.22-.22.46-.22h1.48c.25 0 .47.08.59.33.1.2.09.41-.05.66l-2.71 3.58L16.88 19c.13.21.16.46.03.69-.12.21-.34.31-.57.31H14.7c-.31 0-.56-.17-.7-.44l-1.9-2.67-1.93 2.68c-.15.27-.42.43-.73.43H7.98c-.25 0-.47-.08-.59-.33-.1-.2-.09-.41.05-.66l3.09-4.35L6.26 9H5v4.32c0 .41-.3.69-.7.69H2.7c-.41 0-.7-.28-.7-.69V.69c0-.41.3-.69.7-.69h4.42c.71 0 1.36.1 1.94.3.59.2 1.11.49 1.54.87.44.38.78.84 1.02 1.39.24.54.36 1.14.36 1.78 0 1.01-.28 1.88-.84 2.6-.43.54-1.35 1.29-2 1.59l3.09 3.94 1.72-2.24zM6.71 6.04c.71 0 1.45-.16 1.81-.46.33-.28.5-.69.5-1.25s-.17-.97-.5-1.25c-.35-.3-1.1-.46-1.81-.46h-1.7v3.42h1.7z"],presentation:["M19 1h-8c0-.55-.45-1-1-1S9 .45 9 1H1c-.55 0-1 .45-1 1s.45 1 1 1h1v11c0 .55.45 1 1 1h4.59L4.3 18.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L9 16.41V19c0 .55.45 1 1 1s1-.45 1-1v-2.59l3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L12.41 15H17c.55 0 1-.45 1-1V3h1c.55 0 1-.45 1-1s-.45-1-1-1zm-3 12H4V3h12v10z"],print:["M14 16H6v-4H4v5c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-5h-2v4zm2-13c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v1h12V3zm3 2H1c-.55 0-1 .45-1 1v7c0 .55.45 1 1 1h2v-3h14v3h2c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-1 4h-2V7h2v2z"],projects:["M18 4c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v2h16V4zm-2-3c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v1h12V1zm3 6H1c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-5 7c0 .55-.45 1-1 1H7c-.55 0-1-.45-1-1v-2h1v2h6v-2h1v2z"],properties:["M2 15c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-7c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm5-4h12c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1s.45 1 1 1zM2 1C.9 1 0 1.9 0 3s.9 2 2 2 2-.9 2-2-.9-2-2-2zm17 8H7c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1zm0 7H7c-.55 0-1 .45-1 1s.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1z"],property:["M3 5c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm5-1h11c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zM3 15c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm16 1H8c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm-1-8H9c-1.1 0-2 .9-2 2s.9 2 2 2h9c1.1 0 2-.9 2-2s-.9-2-2-2zM3 7c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3z"],"publish-function":["M7.01 10.11c.35-.64.72-1.68 1.09-3.11l.8-3.03h.96l.24-.77h-.99c.28-1.11.66-1.92 1.12-2.43.28-.32.56-.48.83-.48.05 0 .1.02.13.05.03.03.05.07.05.12 0 .04-.04.13-.11.25-.08.12-.11.24-.11.35 0 .15.06.28.18.39.12.11.27.16.45.16.2 0 .36-.07.49-.2s.2-.31.2-.54c0-.26-.1-.47-.3-.63-.2-.16-.52-.24-.96-.24-.68 0-1.3.19-1.86.58-.55.38-1.08 1.02-1.58 1.91-.17.3-.34.5-.49.59-.15.08-.4.13-.74.12l-.23.77h.95L5.74 9.21c-.23.86-.39 1.39-.47 1.59-.12.29-.3.54-.54.75-.1.08-.21.12-.35.12-.04 0-.07-.01-.1-.03l-.03-.04c0-.02.03-.07.1-.13.07-.07.1-.17.1-.31 0-.15-.05-.28-.16-.38-.11-.1-.27-.15-.47-.15-.25 0-.44.07-.59.2-.15.12-.23.28-.23.46 0 .19.09.36.27.5.19.14.47.21.86.21.61 0 1.16-.15 1.63-.46.48-.31.89-.79 1.25-1.43zm3.7 1.18c-.18-.18-.43-.29-.71-.29s-.53.11-.71.29l-3 3a1.003 1.003 0 001.42 1.42L9 14.41V19c0 .55.45 1 1 1s1-.45 1-1v-4.59l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-3-3zm4.15-6.78c.17-.13.36-.2.55-.2.07 0 .2.03.39.08s.36.08.5.08c.2 0 .37-.07.5-.2.13-.14.2-.31.2-.52 0-.22-.07-.4-.2-.53s-.33-.2-.58-.2c-.22 0-.43.05-.63.15-.2.1-.45.32-.75.67-.23.25-.56.7-1.01 1.33a6.52 6.52 0 00-.91-2.15l-2.38.39-.05.25c.18-.03.33-.05.45-.05.24 0 .43.1.59.3.25.31.59 1.24 1.02 2.79-.34.44-.58.73-.7.87-.21.22-.38.36-.52.43-.1.05-.22.08-.35.08-.1 0-.26-.05-.49-.16a1.01 1.01 0 00-.42-.11c-.23 0-.42.07-.57.22-.17.14-.24.32-.24.55 0 .21.07.38.21.51.14.13.33.2.56.2.23 0 .44-.05.64-.14.2-.09.45-.29.75-.59s.72-.78 1.25-1.43c.2.62.38 1.07.53 1.35.15.28.32.49.52.61.19.12.44.19.73.19.28 0 .57-.1.86-.3.38-.25.77-.69 1.17-1.31l-.25-.14c-.27.37-.48.6-.61.69-.09.06-.19.09-.31.09-.14 0-.28-.09-.42-.26-.23-.29-.54-1.09-.93-2.4.37-.58.66-.96.9-1.14z"],pulse:["M19 10h-2.38L14.9 6.55h-.01c-.17-.32-.5-.55-.89-.55-.43 0-.79.28-.93.66h-.01l-2.75 7.57L7.98 1.82h-.02A.978.978 0 007 1c-.44 0-.8.29-.94.69h-.01L3.28 10H1c-.55 0-1 .45-1 1s.45 1 1 1h3c.44 0 .8-.29.94-.69h.01l1.78-5.34 2.29 12.21h.02c.08.46.47.82.96.82.43 0 .79-.28.93-.66h.01l3.21-8.82.96 1.92h.01c.16.33.49.56.88.56h3c.55 0 1-.45 1-1s-.45-1-1-1z"],rain:["M4 10a3 3 0 111.065-5.806A5.001 5.001 0 0114.63 3.11 3.5 3.5 0 1115.5 10H4zm0 2a1 1 0 011 1v5a1 1 0 11-2 0v-5a1 1 0 011-1zm9 1a1 1 0 10-2 0v6a1 1 0 102 0v-6zm3-1a1 1 0 011 1v3a1 1 0 11-2 0v-3a1 1 0 011-1zm-7 1a1 1 0 10-2 0v3a1 1 0 102 0v-3z"],random:["M14.47 5h2.12L15.3 6.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3a1.003 1.003 0 00-1.42 1.42L16.59 3H14c-.31 0-.57.15-.76.37l-.01-.01-2.93 3.52 1.3 1.56L14.47 5zm2.24 7.29a1.003 1.003 0 00-1.42 1.42l1.3 1.29h-2.12L4.77 3.36l-.01.01A.998.998 0 004 3H1c-.55 0-1 .45-1 1s.45 1 1 1h2.53l9.7 11.64.01-.01c.19.22.45.37.76.37h2.59l-1.29 1.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3zM3.53 15H1c-.55 0-1 .45-1 1s.45 1 1 1h3c.31 0 .57-.15.76-.37l.01.01 2.93-3.52-1.3-1.56L3.53 15z"],record:["M10 3a7 7 0 100 14 7 7 0 100-14z"],redo:["M19.71 5.29l-4-4a1.003 1.003 0 00-1.42 1.42L16.59 5H6c-3.31 0-6 2.69-6 6s2.69 6 6 6h5v-2H6c-2.21 0-4-1.79-4-4s1.79-4 4-4h10.59L14.3 9.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM15 14c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z"],refresh:["M19 1c-.55 0-1 .45-1 1v2.06C16.18 1.61 13.29 0 10 0 4.48 0 0 4.48 0 10c0 .55.45 1 1 1s1-.45 1-1c0-4.42 3.58-8 8-8 2.52 0 4.76 1.18 6.22 3H15c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm0 8c-.55 0-1 .45-1 1 0 4.42-3.58 8-8 8-2.52 0-4.76-1.18-6.22-3H5c.55 0 1-.45 1-1s-.45-1-1-1H1c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1s1-.45 1-1v-2.06C3.82 18.39 6.71 20 10 20c5.52 0 10-4.48 10-10 0-.55-.45-1-1-1z"],"regression-chart":["M19 16H3.1L19.31 3.39l-.61-.79L2 15.59V3c0-.55-.45-1-1-1s-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm-9-9c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm-5 4c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm10-2c0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2-2 .9-2 2zm-5 4c0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2-2 .9-2 2z"],remove:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm5-9H5c-.55 0-1 .45-1 1s.45 1 1 1h10c.55 0 1-.45 1-1s-.45-1-1-1z"],"remove-column":["M19 0H5c-.55 0-1 .45-1 1v4h2V2h5v16H6v-3H4v4c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18h-5V2h5v16zM6.29 13.71a1.003 1.003 0 001.42-1.42L5.41 10 7.7 7.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L4 8.59l-2.29-2.3A1.003 1.003 0 00.29 7.71L2.59 10 .3 12.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L4 11.41l2.29 2.3z"],"remove-column-left":["M4 11h6c.55 0 1-.45 1-1s-.45-1-1-1H4c-.55 0-1 .45-1 1s.45 1 1 1zM19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-7 18H2V2h10v16zm6 0h-5V2h5v16z"],"remove-column-right":["M19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zM7 18H2V2h5v16zm11 0H8V2h10v16zm-8-7h6c.55 0 1-.45 1-1s-.45-1-1-1h-6c-.55 0-1 .45-1 1s.45 1 1 1z"],"remove-row-bottom":["M7 14h6c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1s.45 1 1 1zM19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2V8h16v10zm0-11H2V2h16v5z"],"remove-row-top":["M7 8h6c.55 0 1-.45 1-1s-.45-1-1-1H7c-.55 0-1 .45-1 1s.45 1 1 1zm12-8H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2v-5h16v5zm0-6H2V2h16v10z"],repeat:["M14 6c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1s-1 .45-1 1v2.05C16.18 1.6 13.29 0 10 0 4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10c0-.55-.45-1-1-1s-1 .45-1 1c0 4.42-3.58 8-8 8s-8-3.58-8-8 3.58-8 8-8c2.53 0 4.77 1.17 6.24 3H15c-.55 0-1 .45-1 1z"],reset:["M6 6c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V2c0-.55.45-1 1-1s1 .45 1 1v2.05C3.82 1.6 6.71 0 10 0c5.52 0 10 4.48 10 10s-4.48 10-10 10S0 15.52 0 10c0-.55.45-1 1-1s1 .45 1 1c0 4.42 3.58 8 8 8s8-3.58 8-8-3.58-8-8-8C7.47 2 5.23 3.17 3.76 5H5c.55 0 1 .45 1 1z"],resolve:["M8.7 4.7C7.9 4.2 7 4 6 4c-3.3 0-6 2.7-6 6s2.7 6 6 6c1 0 1.9-.2 2.7-.7C7.3 14 6.5 12.1 6.5 10s.9-4 2.2-5.3zM14 4c-1 0-1.9.2-2.7.7 1.4 1.4 2.2 3.2 2.2 5.3s-.9 4-2.2 5.3c.8.5 1.7.7 2.7.7 3.3 0 6-2.7 6-6s-2.7-6-6-6zm-4 1.5C8.8 6.7 8 8.2 8 10s.8 3.3 2 4.4c1.2-1.1 2-2.7 2-4.5s-.8-3.3-2-4.4z"],rig:["M7 4.2C7 5.75 8.34 7 10 7s3-1.46 3-2.8C13 1.45 10.94 0 10 0H6c0 2.74 3.76 1.96 1 4.2zm11.71 14.09L13 12.59V9.01c0-.55-.45-1-1-1H8c-.55 0-1 .45-1 1v3.58l-5.71 5.7a1.003 1.003 0 001.42 1.42L7 15.42V19c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-3.58l4.29 4.29a1.003 1.003 0 001.42-1.42zM10.21 8c.01 0 .01.01 0 0 .01.01.01 0 0 0z"],"right-join":["M8.7 4.7C7.4 6 6.5 7.9 6.5 10s.8 4 2.2 5.3c-.8.5-1.7.7-2.7.7-3.3 0-6-2.7-6-6s2.7-6 6-6c1 0 1.9.2 2.7.7zm-3.34 9.25c-.55-1.2-.86-2.54-.86-3.95s.31-2.75.86-3.95a4.001 4.001 0 000 7.9zM14 4c3.3 0 6 2.7 6 6s-2.7 6-6 6c-1 0-1.9-.2-2.7-.7 1.3-1.3 2.2-3.2 2.2-5.3s-.8-3.9-2.2-5.3C12.1 4.2 13 4 14 4zm-4 1.5C8.8 6.7 8 8.2 8 10s.8 3.3 2 4.4c1.2-1.1 2-2.7 2-4.5s-.8-3.3-2-4.4z"],ring:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 15c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"],rocket:["M7 7.5c0-3 1.857-6.25 3-7.5 1.143 1.25 3 4.5 3 7.5s-.714 6.25-1 7.5H8c-.286-1.25-1-4.5-1-7.5zm6.84 2.5c-.139 1.62-.47 3.405-.84 5.01l4 .99-1-4-2.16-2zm-4.832 6C9 16.139 9 16.284 9 16.429 9 17.143 9 17.5 10 20c1-2.5 1-2.857 1-3.571 0-.145 0-.29-.008-.429H9.008zM7 15.011c-.37-1.605-.701-3.39-.84-5.011L4 12l-1 4 4-.989zM10 5a1 1 0 100 2 1 1 0 000-2z"],"rocket-slant":["M10 5c2.121-2.121 6.308-2.924 8-3-.076 1.692-.879 5.879-3 8-1.192 1.192-2.543 1.823-3.748 2.384-.442.207-.865.404-1.252.616-.203.111-.597.302-.986.49-.444.215-.88.426-1.014.51l-2-2c.158-.252 1-2 1-2s1.37-3.37 3-5zm5 1a1 1 0 11-2 0 1 1 0 012 0zM3 17s0-2 2-4l2 2c-2 2-4 2-4 2zm11-2l-4 4-1.298-4.233c1.033-.56 1.881-.962 2.643-1.322 1.275-.604 2.307-1.092 3.554-2.015L14 15zM1 10l4-4 3.557-.899c-.923 1.247-1.412 2.28-2.015 3.554-.36.762-.762 1.61-1.322 2.643L1 10z"],"rotate-document":["M8.71 6.29A.997.997 0 008 6H3c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h9c.55 0 1-.45 1-1v-8c0-.28-.11-.53-.29-.71l-4-4zM11 18H4V8h3v3c0 .55.45 1 1 1h3v6zm3-16h-1.59l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C9.11 2.47 9 2.72 9 3c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H14c1.1 0 2 .9 2 2v3c0 .55.45 1 1 1s1-.45 1-1V6c0-2.21-1.79-4-4-4z"],"rotate-page":["M14 2h-1.59l.29-.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-2 2C9.11 2.47 9 2.72 9 3c0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42l-.3-.29H14c1.1 0 2 .9 2 2v3c0 .55.45 1 1 1s1-.45 1-1V6c0-2.21-1.79-4-4-4zm-2 5H3c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm-1 11H4V9h7v9z"],route:["M14.028 6.016c.146.275.31.57.485.872.304.524.628 1.047.952 1.545l.118.178-.208-.006-.577-.005c-2.093.004-2.841.303-2.841.895 0 .069.271.248 1.245.567l1.008.313c2.671.831 3.99 1.827 3.99 4.167 0 2.76-1.928 4.059-4.832 4.376-.782.085-1.52.098-2.452.066l-1.15-.046H6.221l.535-.811a67.46 67.46 0 001.122-1.787h2.04l.686.03c1.028.046 1.77.043 2.523-.039 1.832-.2 2.673-.767 2.673-1.789 0-.69-.483-1.09-1.992-1.585l-.83-.257c-1.192-.364-2.037-.7-2.59-1.165.399-1 .612-1.844.612-2.538a6.018 6.018 0 00-.382-2.098c.745-.573 1.884-.822 3.41-.883zM5 4.2c2.648 0 4.791 2.151 4.8 4.797C9.8 11.652 5 18.6 5 18.6l-.5-.744C3.273 15.993.2 11.121.2 8.997A4.802 4.802 0 015 4.2zm0 2.4a2.4 2.4 0 10.002 4.802A2.4 2.4 0 005 6.6zM17 .333a2.671 2.671 0 012.667 2.665C19.667 4.473 17 8.333 17 8.333l-.391-.587c-.741-1.137-2.276-3.629-2.276-4.748A2.668 2.668 0 0117 .333z"],satellite:["M9 18c.6 0 1 .4 1 1s-.4 1-1 1c-5 0-9-4-9-9 0-.6.4-1 1-1s1 .4 1 1c0 3.9 3.1 7 7 7zm0-4c.6 0 1 .4 1 1s-.4 1-1 1c-2.8 0-5-2.2-5-5 0-.6.4-1 1-1s1 .4 1 1c0 1.7 1.3 3 3 3zm5.7-3.7c.4-.4 1-.4 1.4 0l3.6 3.6c.4.4.4 1 0 1.4l-1.4 1.4c-.4.4-1 .4-1.4 0l-3.6-3.6c-.4-.4-.4-1 0-1.4l1.4-1.4zM4.7.3c.4-.4 1-.4 1.4 0l3.6 3.6c.4.4.4 1 0 1.4L8.3 6.7c-.4.4-1 .4-1.4 0L3.3 3.1c-.4-.4-.4-1 0-1.4L4.7.3zm11.1 1c.4-.4 1-.4 1.4 0l1.6 1.6c.4.4.4 1 0 1.4l-6.5 6.5c-.4.4-1 .4-1.4 0L9.3 9.2c-.4-.4-.4-1 0-1.4l6.5-6.5zM9 12c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1z"],saved:["M12 0H4c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h13c.55 0 1-.45 1-1V6l-6-6zm4 18H5V2h6v5h5v11zm-8.29-6.71a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29.32 0 .59-.16.77-.38l.01.01 4-5-.01-.01c.14-.18.23-.38.23-.62 0-.55-.45-1-1-1-.32 0-.59.16-.77.38l-.01-.01-3.3 4.13-2.21-2.21z"],"scatter-plot":["M9 9c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm5 2c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm4-5c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm1 10H2V3c0-.55-.45-1-1-1s-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM5 15c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2z"],search:["M19.56 17.44l-4.94-4.94A8.004 8.004 0 0016 8c0-4.42-3.58-8-8-8S0 3.58 0 8s3.58 8 8 8c1.67 0 3.21-.51 4.5-1.38l4.94 4.94a1.498 1.498 0 102.12-2.12zM8 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],"search-around":["M9.9 6.9a3 3 0 100 6 3 3 0 100-6zM3 14c-1.7 0-3 1.3-3 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3zm0 5c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zM3 0C1.3 0 0 1.3 0 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3zm0 5c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zM17 14c-1.7 0-3 1.3-3 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3zm0 5c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zM17 0c-1.7 0-3 1.3-3 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3zm0 5c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zM10 10L5 5","M5.379 4.671l5.02 5.02-.707.708-5.02-5.02zM10 10l5-5","M14.621 4.671l.707.708-5.02 5.02-.707-.707z","M10 10l5 5M10.379 9.671l5.02 5.02-.707.708-5.02-5.02z","M10 10l-5 5M9.621 9.671l.707.708-5.02 5.02-.707-.707z"],"search-template":["M13 8H5c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1zm0 3H5c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1zm0-6H5c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1zm6.56 12.44l-3.23-3.23A8.939 8.939 0 0018 9a9 9 0 10-9 9c1.94 0 3.74-.62 5.21-1.67l3.23 3.23a1.498 1.498 0 102.12-2.12zM9 16c-3.87 0-7-3.13-7-7s3.13-7 7-7 7 3.13 7 7-3.13 7-7 7z"],"search-text":["M19.56 17.44l-3.23-3.23A8.939 8.939 0 0018 9a9 9 0 10-9 9c1.94 0 3.74-.62 5.21-1.67l3.23 3.23a1.498 1.498 0 102.12-2.12zM9 16c-3.87 0-7-3.13-7-7s3.13-7 7-7 7 3.13 7 7-3.13 7-7 7zm3.5-11h-7c-.28 0-.5.22-.5.5v2c0 .28.22.5.5.5s.5-.22.5-.5V7h2v6h-.5c-.28 0-.5.22-.5.5s.22.5.5.5h3c.28 0 .5-.22.5-.5s-.22-.5-.5-.5H10V7h2v.5c0 .28.22.5.5.5s.5-.22.5-.5v-2c0-.28-.22-.5-.5-.5z"],"segmented-control":["M19 5H1c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-1 8h-8V7h8v6z"],select:["M19.71 18.29l-4.25-4.25L20 12.91 9.93 9.33c.04-.1.07-.21.07-.33V3c0-.55-.45-1-1-1H4V1c0-.55-.45-1-1-1S2 .45 2 1v1H1c-.55 0-1 .45-1 1s.45 1 1 1h1v5c0 .55.45 1 1 1h6c.12 0 .23-.03.34-.07L12.91 20l1.14-4.54 4.25 4.25c.17.18.42.29.7.29a1.003 1.003 0 00.71-1.71zM8 8H4V4h4v4z"],selection:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z","M10 6a4 4 0 100 8 4 4 0 100-8z"],"send-message":["M1.754.135L19.393 9.06c.57.288.775.943.458 1.462-.107.176-.266.32-.458.418l-17.64 8.925c-.57.288-1.288.1-1.604-.418C.05 19.287 0 19.183 0 19v-7l11-2L0 8V1.075C0 .481.529 0 1.18 0c.201 0 .399.047.574.135z"],"send-to":["M19 0h-5c-.6 0-1 .4-1 1s.4 1 1 1h2.6l-4.3 4.3c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3L18 3.4V6c0 .5.5 1 1 1s1-.5 1-1V1c0-.6-.5-1-1-1zm0 9c-1 0-1.9-.5-2.5-1.3l-1.4 1.4c-.5.6-1.3.9-2.1.9-1.7 0-3-1.3-3-3 0-.8.3-1.6.9-2.1l1.4-1.4C11.5 2.9 11 2 11 1c0-.3.1-.6.2-.9-.4-.1-.8-.1-1.2-.1C4.5 0 0 4.5 0 10s4.5 10 10 10 10-4.5 10-10c0-.4 0-.8-.1-1.2-.3.1-.6.2-.9.2z"],"send-to-graph":["M8 11H3c-.55 0-1 .45-1 1s.45 1 1 1h2.59L.3 18.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L7 14.41V17c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1zm10 2c-.53 0-1.01.21-1.37.55L11.9 10.6c.06-.19.1-.39.1-.6 0-.21-.04-.41-.1-.6l4.72-2.95c.37.34.85.55 1.38.55 1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2c0 .21.04.41.1.6l-4.73 2.96c-.24-.23-.54-.4-.87-.48V3.93c.86-.22 1.5-1 1.5-1.93 0-1.1-.9-2-2-2S8 .9 8 2c0 .93.64 1.71 1.5 1.93v4.14c-.33.09-.63.26-.87.48L7.6 7.91 5.42 6.55 3.9 5.6c.06-.19.1-.39.1-.6 0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2c.53 0 1.01-.21 1.37-.55L9 9.96V10h.06L12 11.84l.4.25 1.51.94 2.19 1.37c-.06.19-.1.39-.1.6 0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2zm-7-2.96l-.06-.04H11v.04z"],"send-to-map":["M8 11H3c-.55 0-1 .45-1 1s.45 1 1 1h2.59L.3 18.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71L7 14.41V17c0 .55.45 1 1 1s1-.45 1-1v-5c0-.55-.45-1-1-1zm11.54-6.82l.01-.02-6-4-.01.02C13.39.08 13.21 0 13 0s-.39.08-.54.18l-.01-.02L7 3.8 1.55.17l-.01.01A.969.969 0 001 0C.45 0 0 .45 0 1v9c0-.55.45-1 1-1h1V2.87l4 2.67V9h2V5.54l4-2.67v11.6l-1 .67v2.4l2-1.33 5.45 3.63.01-.02c.15.1.33.18.54.18.55 0 1-.45 1-1V5c0-.35-.19-.64-.46-.82zM18 17.13l-4-2.67V2.87l4 2.67v11.59z"],"series-add":["M13.29 9.29c.3.62.8 1.12 1.42 1.42l-3 3c-.18.18-.43.29-.71.29s-.53-.11-.71-.3L7 10.41l-5 5V17h17c.55 0 1 .45 1 1s-.45 1-1 1H1a.998.998 0 01-1-1V4c0-.55.45-1 1-1s1 .45 1 1v8.59l4.29-4.3C6.47 8.11 6.72 8 7 8s.53.11.71.29l3.29 3.3 2.29-2.3zM12 5c0-.5.4-1 1-1h2V2c0-.6.4-1 1-1 .5 0 1 .4 1 1v2h2c.5 0 1 .4 1 1s-.5 1-1 1h-2v2c0 .6-.5 1-1 1-.6 0-1-.4-1-1V6h-2c-.6 0-1-.4-1-1z"],"series-configuration":["M11.91 10.67c.52.45 1.13.8 1.8 1.03l-2.01 2.01c-.18.18-.43.29-.71.29-.28 0-.53-.11-.71-.3L7 10.41l-5 5V17h16.99c.55 0 1 .45 1 1s-.45 1-1 1H1a.998.998 0 01-1-1V4c0-.55.45-1 1-1s1 .45 1 1v8.59l4.29-4.3C6.47 8.11 6.72 8 7 8c.28 0 .53.11.71.29l3.29 3.3.91-.92zM18.5 4.6h1.04c.25 0 .45.2.46.44v.9c0 .25-.2.45-.45.45h-1.04c-.07.22-.16.42-.27.62l.73.73c.17.17.17.44 0 .61l-.61.61c-.17.17-.44.17-.61 0l-.73-.73c-.2.11-.4.2-.62.26v1.05c0 .25-.2.45-.45.45h-.9c-.25 0-.45-.2-.45-.45V8.51c-.21-.06-.4-.15-.58-.25l-.76.77c-.17.17-.46.17-.64 0l-.64-.64a.465.465 0 010-.64l.76-.77c-.1-.19-.19-.38-.25-.59h-1.04c-.25 0-.45-.2-.45-.45v-.9c0-.25.2-.45.45-.45h1.04c.07-.22.16-.42.27-.61l-.73-.73a.429.429 0 010-.61l.61-.61c.17-.17.44-.17.61 0l.73.73c.2-.11.4-.2.62-.26V1.45a.44.44 0 01.44-.45h.9c.25 0 .45.2.45.45V2.5c.21.06.4.15.58.25l.76-.77c.17-.17.46-.17.64 0l.64.64c.17.17.17.46 0 .64l-.76.77c.1.17.19.36.25.57zm-4.69.9c0 .93.75 1.69 1.69 1.69.93 0 1.69-.75 1.69-1.69s-.75-1.69-1.69-1.69-1.69.76-1.69 1.69z"],"series-derived":["M18.82 6.58c-.03.05-.07.09-.11.13 0 0 0-.01-.01-.01l-2 2c-.2.2-.4.3-.7.3-.6 0-1-.4-1-1 0-.3.1-.5.3-.7L16.6 6H11c-.6 0-1-.4-1-1s.4-1 1-1h5.6l-1.3-1.3c-.2-.2-.3-.4-.3-.7 0-.6.4-1 1-1 .3 0 .5.1.7.3l3 3c.2.2.3.4.3.7s-.1.5-.3.7l-.88.88zm-5.53 2.71c.3.62.8 1.12 1.42 1.42l-3 3c-.18.18-.43.29-.71.29s-.53-.11-.71-.3L7 10.41l-5 5V17h17c.55 0 1 .45 1 1s-.45 1-1 1H1a.998.998 0 01-1-1V4c0-.55.45-1 1-1s1 .45 1 1v8.59l4.29-4.3C6.47 8.11 6.72 8 7 8s.53.11.71.29l3.29 3.3 2.29-2.3z"],"series-filtered":["M12.14 10.45c.21.67.65 1.23 1.22 1.61l-1.65 1.65c-.18.18-.43.29-.71.29s-.53-.11-.71-.3L7 10.41l-5 5V17h17c.55 0 1 .45 1 1s-.45 1-1 1H1a.998.998 0 01-1-1V4c0-.55.45-1 1-1s1 .45 1 1v8.59l4.29-4.3C6.47 8.11 6.72 8 7 8s.53.11.71.29l3.29 3.3 1.14-1.14zM19.35 1a.642.642 0 01.46 1.1l-3.03 3.03v2.95c0 .18-.07.34-.19.46l-1.28 1.29c-.11.1-.27.17-.45.17-.35 0-.64-.29-.64-.64V5.13L11.19 2.1a.642.642 0 01.45-1.1h7.71z"],"series-search":["M11.28 11.31l-.28.28-3.29-3.3C7.53 8.11 7.28 8 7 8s-.53.11-.71.29L2 12.59V4c0-.55-.45-1-1-1s-1 .45-1 1v14a.998.998 0 001 1h18c.55 0 1-.45 1-1s-.45-1-1-1H2v-1.59l5-5 3.29 3.29c.18.19.43.3.71.3s.53-.11.71-.29l2.09-2.09c-.17.02-.34.02-.51.02-.7 0-1.38-.12-2.01-.33zm-.93-6c0-1.62 1.31-2.93 2.93-2.93s2.93 1.31 2.93 2.93-1.31 2.93-2.93 2.93-2.93-1.31-2.93-2.93zm6.47 2.43c.11-.17.21-.33.29-.51.01-.03.03-.06.04-.09.08-.18.16-.35.21-.54.06-.2.1-.38.14-.58.01-.05.01-.09.02-.14.03-.2.05-.39.05-.6 0-2.37-1.93-4.3-4.3-4.3-2.37.01-4.3 1.93-4.3 4.31s1.93 4.3 4.3 4.3c.21 0 .4-.02.6-.05.04 0 .09-.01.14-.02.2-.03.38-.08.57-.14.2-.06.37-.14.55-.21.03-.01.06-.03.09-.04.18-.09.34-.19.51-.29l2.87 2.87c.14.14.33.22.56.22.43 0 .78-.35.78-.78a.938.938 0 00-.23-.56l-2.89-2.85z"],settings:["M4 1c0-.55-.45-1-1-1S2 .45 2 1v5h2V1zM2 19c0 .55.45 1 1 1s1-.45 1-1v-6H2v6zm9-18c0-.55-.45-1-1-1S9 .45 9 1v8h2V1zm7 0c0-.55-.45-1-1-1s-1 .45-1 1v3h2V1zM9 19c0 .55.45 1 1 1s1-.45 1-1v-3H9v3zm9-14h-2c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1zm-2 14c0 .55.45 1 1 1s1-.45 1-1v-8h-2v8zM4 7H2c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm7 3H9c-.55 0-1 .45-1 1v3c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-3c0-.55-.45-1-1-1z"],shapes:["M7.88 11.12a.958.958 0 011.277.33l3.719 6.207c.081.136.124.29.124.447 0 .495-.419.896-.936.896H4.936a.969.969 0 01-.436-.103.878.878 0 01-.392-1.21l3.409-6.208a.915.915 0 01.362-.36zM15 5a4 4 0 110 8 4 4 0 010-8zM8 1a1 1 0 011 1v6a1 1 0 01-1 1H2a1 1 0 01-1-1V2a1 1 0 011-1h6z"],share:["M15 18H2V5h8.76l2-2H1c-.55 0-1 .45-1 1v15c0 .55.45 1 1 1h15c.55 0 1-.45 1-1V7.24l-2 2V18zm4-18h-7c-.55 0-1 .45-1 1s.45 1 1 1h4.59l-7.3 7.29a1.003 1.003 0 001.42 1.42L18 3.41V8c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1z"],"shared-filter":["M13.917 17.209c1.01.454 2.543.928 2.873 1.643.31.722.186 1.148.186 1.148H6.026s-.13-.426.186-1.148 1.842-1.203 2.86-1.65c1.017-.447.914-.722.948-1.093 0-.048.007-.097.007-.145a3.067 3.067 0 01-.839-1.237l-.007-.007c0-.007-.006-.014-.006-.02a1.757 1.757 0 01-.11-.337c-.234-.042-.372-.296-.426-.537a1.045 1.045 0 01-.138-.598c.034-.35.179-.509.337-.57v-.056c0-.44.034-1.065.117-1.478a2.508 2.508 0 01.962-1.623c.426-.33 1.038-.501 1.58-.501.544 0 1.155.172 1.588.502a2.496 2.496 0 01.963 1.622c.075.413.117 1.045.117 1.478v.062c.15.062.288.22.323.564.02.268-.083.502-.138.598-.048.234-.185.488-.42.537a2.635 2.635 0 01-.116.364 3.094 3.094 0 01-.818 1.224c0 .055 0 .11.007.158.034.378-.103.653.914 1.1z","M14.976 16.57c-.24-.099-.455-.186-.65-.273l-.007-.004a3.801 3.801 0 01-.194-.091c.224-.288.41-.609.554-.946l.001-.002.013-.033c.018-.043.036-.087.052-.13l.011-.027.016-.04c.105-.092.19-.19.256-.284.129-.184.213-.38.265-.563.105-.226.225-.592.192-1.026l-.001-.011-.002-.011a1.854 1.854 0 00-.325-.91 9.924 9.924 0 00-.12-1.246 3.09 3.09 0 00-.106-.475l-.001-.006a3.543 3.543 0 00-.763-1.353c.27-.092.56-.139.83-.139.495 0 1.05.156 1.444.456a2.269 2.269 0 01.875 1.475c.069.375.106.95.106 1.344v.056c.138.056.263.2.294.513.019.244-.075.456-.125.543-.044.213-.169.444-.381.488-.025.1-.056.206-.094.3a2.815 2.815 0 01-.756 1.144c0 .05 0 .1.006.144.004.043.006.086.007.127.01.283.018.518.824.872.192.087.404.173.623.263.83.34 1.752.717 1.99 1.231.28.657.168 1.044.168 1.044h-2.081a3.864 3.864 0 00-.188-.542l-.005-.013-.006-.012c-.183-.397-.491-.681-.76-.88a5.614 5.614 0 00-.896-.522 17.36 17.36 0 00-.916-.4l-.15-.061zM14 1c.55 0 1 .45 1 1 0 .28-.11.53-.29.7L10 7.41v.897a3.182 3.182 0 00-.69.4 3.508 3.508 0 00-1.343 2.259c-.07.37-.107.836-.122 1.237a1.836 1.836 0 00-.339.926c-.046.458.09.84.195 1.06.053.178.138.376.27.56.055.08.125.162.21.242v.143l.053.052L6.71 16.71A1.003 1.003 0 015 16V7.41L.29 2.71A1.003 1.003 0 011 1h13z","M9.059 14.361c-.23-.044-.366-.296-.42-.535a1.045 1.045 0 01-.138-.598c.034-.35.179-.509.337-.57v-.056c0-.44.034-1.065.117-1.478A2.508 2.508 0 0110 9.441V13c0 .28-.11.53-.29.71l-.651.651z"],shield:["M10 20c6-3.81 9-9.048 9-15.714-2 0-5-1.429-9-4.286-4 2.857-7 4.286-9 4.286C1 10.952 4 16.19 10 20zm0-17.348c2.577 1.734 4.776 2.88 6.667 3.419-.44 4.627-2.636 8.353-6.667 11.297V2.652z"],ship:["M6.84.804L6.5 2.5h-3a1 1 0 00-1 1v4.893l-1.58.451a.99.99 0 00-.691 1.192c.46 1.82 1.163 4.356 1.701 5.571-.218.012-.445.018-.68.018a.625.625 0 100 1.25c2.583 0 4.268-.68 5.202-1.146.687.466 1.88 1.146 3.548 1.146 1.65 0 2.837-.666 3.528-1.132l.005.003c.244.131.6.3 1.07.468.938.335 2.321.661 4.147.661a.625.625 0 100-1.25c-.323 0-.63-.011-.922-.031a.996.996 0 00.184-.334l1.67-5.168a1 1 0 00-.677-1.27l-1.505-.43V3.5a1 1 0 00-1-1h-3L13.16.804A1 1 0 0012.18 0H7.82a1 1 0 00-.98.804zM5 7.679l3.75-1.072V5H5v2.679zm6.25-1.072L15 7.68V5h-3.75v1.607zM6.205 16.95a.625.625 0 01.658.042c.569.407 1.597 1.134 3.137 1.134s2.568-.727 3.137-1.134a.625.625 0 01.724-.001l.007.005.045.029c.044.027.114.069.21.12.194.104.493.247.9.392.811.29 2.053.589 3.727.589a.625.625 0 110 1.25c-1.826 0-3.21-.326-4.148-.661a7.894 7.894 0 01-1.069-.468l-.005-.003c-.691.466-1.878 1.132-3.528 1.132-1.667 0-2.861-.68-3.548-1.146-.934.467-2.619 1.146-5.202 1.146a.625.625 0 110-1.25c2.66 0 4.23-.787 4.955-1.176z"],shop:["M17.94 3.63c-.01-.02-.01-.03-.02-.04l-.03-.09h-.01c-.18-.3-.49-.5-.86-.5h-14c-.42 0-.77.25-.92.61L0 8.5h.02a2.5 2.5 0 005 0 2.5 2.5 0 005 0 2.5 2.5 0 005 0 2.5 2.5 0 005 0l-2.08-4.87zM3.02 2h14c.55 0 1-.45 1-1s-.45-1-1-1h-14c-.55 0-1 .45-1 1s.44 1 1 1zm13 14h-12v-4h-2v7c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-7h-2v4z"],"shopping-cart":["M18 14H8.72l-.67-2H17c.44 0 .8-.29.94-.69h.01l2-6h-.01c.03-.1.06-.2.06-.31 0-.55-.45-1-1-1H5.39l-.44-1.32h-.01C4.8 2.29 4.44 2 4 2H1c-.55 0-1 .45-1 1s.45 1 1 1h2.28l3.33 10H5c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2h9c0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2zM6.05 6h11.56l-1.33 4H7.39L6.05 6z"],"signal-search":["M7.15 10.33c.888.8 1.999 1.36 3.228 1.574l2.326 6.98a.846.846 0 01-.535 1.07.844.844 0 01-1.072-.535l-1.225-3.671H7.125L5.9 19.419a.85.85 0 01-1.072.536.85.85 0 01-.536-1.071l2.857-8.555zm1.353 1.305l-.808 2.413h1.607l-.8-2.413zM5 5.5c0 .76.13 1.49.37 2.17-.496 1.056-.313 2.356.704 3.29.385.353.404.94.038 1.311a.982.982 0 01-1.356.038c-2.183-2.01-2-5.125.01-6.94a.95.95 0 01.24-.156A6.421 6.421 0 005 5.5z","M3.874 13.185c-1.346-.918-2.187-2.67-2.187-4.34 0-1.752.757-3.254 2.187-4.339.42-.25.42-.834.168-1.168-.252-.418-.84-.418-1.177-.167C1.014 4.59-.08 6.509.005 8.846c.084 2.253 1.177 4.423 2.86 5.675.168.083.336.166.504.166.253 0 .505-.083.673-.333.337-.418.253-.918-.168-1.169zM12.246 12.309a.98.98 0 01-1.354-.037.917.917 0 01-.206-.324 6.54 6.54 0 001.959-.049 5.125 5.125 0 01-.399.41zM14.631 11.476l1.228 1.229a6.6 6.6 0 01-1.723 1.816c-.169.083-.337.166-.505.166-.253 0-.505-.083-.673-.333-.337-.418-.253-.918.168-1.169.62-.422 1.133-1.022 1.505-1.709z","M11.5 0C14.54 0 17 2.46 17 5.5c0 .26-.02.51-.06.75l-.03.17c-.04.25-.1.49-.17.73v.01c-.08.24-.17.47-.28.69-.01.04-.03.07-.05.11-.11.23-.24.44-.38.65l3.68 3.68A1.003 1.003 0 0119 14c-.28 0-.53-.11-.7-.29l-3.68-3.68c-.21.14-.42.27-.65.38-.04.01-.07.03-.11.05-.22.11-.45.2-.69.28h-.01c-.24.07-.48.13-.73.17l-.17.03c-.25.04-.5.06-.76.06C8.46 11 6 8.54 6 5.5S8.46 0 11.5 0zm0 1.5c-2.21 0-4 1.79-4 4s1.79 4 4 4 4-1.79 4-4-1.79-4-4-4z"],"sim-card":["M16.71 5.29l-5-5A.997.997 0 0011 0H4c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V6c0-.28-.11-.53-.29-.71zM9 7h2v3H9V7zM6 7h2v3H6V7zm2 11H6v-3h2v3zm3 0H9v-3h2v3zm3 0h-2v-3h2v3zm0-4H6v-3h8v3zm0-4h-2V7h2v3z"],slash:["M12 2c-.46 0-.85.32-.97.74L7.04 16.7c-.02.1-.04.2-.04.3 0 .55.45 1 1 1 .46 0 .85-.32.97-.74L12.96 3.3c.02-.1.04-.2.04-.3 0-.55-.45-1-1-1z"],"small-cross":["M11.41 10l3.29-3.29c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71L10 8.59l-3.29-3.3a1.003 1.003 0 00-1.42 1.42L8.59 10 5.3 13.29c-.19.18-.3.43-.3.71a1.003 1.003 0 001.71.71l3.29-3.3 3.29 3.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71L11.41 10z"],"small-minus":["M14 9H6c-.55 0-1 .45-1 1s.45 1 1 1h8c.55 0 1-.45 1-1s-.45-1-1-1z"],"small-plus":["M14 9h-3V6c0-.55-.45-1-1-1s-1 .45-1 1v3H6c-.55 0-1 .45-1 1s.45 1 1 1h3v3c0 .55.45 1 1 1s1-.45 1-1v-3h3c.55 0 1-.45 1-1s-.45-1-1-1z"],"small-square":["M5 5v10h10V5H5zM4 3a1 1 0 00-1 1v12a1 1 0 001 1h12a1 1 0 001-1V4a1 1 0 00-1-1H4z"],"small-tick":["M15 5c-.28 0-.53.11-.71.29L8 11.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l7-7A1.003 1.003 0 0015 5z"],snowflake:["M11 11.776v2.81l2.31 2.242a.987.987 0 010 1.415c-.399.39-1.044.39-1.442 0L11 17.414V19a.99.99 0 01-.996 1A.996.996 0 019 19v-1.636l-.912.879c-.398.39-1.043.39-1.441 0a.987.987 0 010-1.415L9 14.536v-2.79l-2.548 1.435-.837 3.063c-.146.534-.705.85-1.248.707a.998.998 0 01-.721-1.224l.309-1.132-1.4.793a1.03 1.03 0 01-1.393-.366.99.99 0 01.373-1.366l1.445-.818-1.224-.322a.998.998 0 01-.72-1.225c.145-.533.704-.85 1.248-.707l3.193.84 2.462-1.395-2.532-1.434-3.123.82a1.022 1.022 0 01-1.249-.706.998.998 0 01.721-1.225L2.91 7.18l-1.4-.793a.99.99 0 01-.373-1.366 1.03 1.03 0 011.392-.366l1.445.818-.328-1.2a.998.998 0 01.72-1.225 1.022 1.022 0 011.25.707l.855 3.132L9 8.311V5.414L6.647 3.121a.987.987 0 010-1.414 1.033 1.033 0 011.441 0L9 2.586V1c0-.552.44-1 1.004-1A.99.99 0 0111 1l-.007 1.536.875-.829a1.033 1.033 0 011.441 0 .987.987 0 010 1.414L11 5.364v2.918l2.53-1.42.855-3.131c.146-.534.705-.85 1.249-.707a.998.998 0 01.72 1.224l-.327 1.2 1.4-.792a1.03 1.03 0 011.392.366.99.99 0 01-.373 1.366l-1.355.768 1.153.303a.998.998 0 01.721 1.225c-.146.533-.705.85-1.249.707l-3.123-.821-2.576 1.459 2.506 1.42 3.193-.84a1.022 1.022 0 011.249.707.998.998 0 01-.72 1.225l-1.224.322 1.4.793a.99.99 0 01.373 1.366 1.03 1.03 0 01-1.393.366l-1.356-.768.31 1.132a.998.998 0 01-.721 1.224 1.022 1.022 0 01-1.249-.707l-.837-3.063L11 11.776z"],"social-media":["M11.5 5c.8 0 1.6-.4 2-1 2 1.2 3.3 3.3 3.5 5.7 0 .5.5.9 1 .9.6 0 1-.5 1-1v-.1c-.2-3.3-2.2-6.2-5.1-7.6C13.7.8 12.7 0 11.5 0 10.1 0 9 1.1 9 2.5S10.1 5 11.5 5zm5 7c-1.4 0-2.5 1.1-2.5 2.5 0 .4.1.7.2 1.1-1.1.9-2.6 1.4-4.2 1.4-1.9 0-3.6-.8-4.9-2-.2-.2-.5-.4-.8-.4-.5 0-1 .5-1 1 0 .3.1.5.3.7C5.3 18 7.5 19 10 19c2.2 0 4.2-.8 5.8-2.1.2.1.5.1.7.1 1.4 0 2.5-1.1 2.5-2.5S17.9 12 16.5 12zM5 10.5c0-1.1-.7-2.1-1.7-2.4.5-1.9 1.9-3.5 3.6-4.4.3-.2.6-.5.6-.9 0-.5-.4-1-1-1-.2 0-.4.1-.6.2-2.4 1.2-4.2 3.6-4.7 6.4C.5 8.9 0 9.6 0 10.5 0 11.9 1.1 13 2.5 13S5 11.9 5 10.5z"],sort:["M19 16h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm0-5h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zM7 15c-.28 0-.53.11-.71.29L5 16.59V11c0-.55-.45-1-1-1s-1 .45-1 1v5.59L1.71 15.3A.965.965 0 001 15a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 007 15zM19 1h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1zm0 5h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V7c0-.55-.45-1-1-1z"],"sort-alphabetical":["M8 15c-.28 0-.53.11-.71.29L6 16.59v-5.58c0-.55-.45-1-1-1s-1 .45-1 1v5.58L2.71 15.3c-.18-.18-.43-.3-.71-.3a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 008 15zm8.89-.79v-1.22H11.3v1.3h3.51L11 18.78V20h5.99v-1.3h-3.91l3.81-4.49zM14.97 0h-1.95L9.01 11.01h1.89l.98-2.92h4.17l.98 2.92h1.96L14.97 0zm-2.59 6.63l1.58-4.74H14l1.57 4.74h-3.19z"],"sort-alphabetical-desc":["M8.01 15c-.28 0-.53.11-.71.29L6 16.59v-5.58c0-.55-.45-1-1-1s-1 .45-1 1v5.58L2.71 15.3c-.18-.18-.43-.3-.71-.3a1.003 1.003 0 00-.71 1.71l3 3a1.014 1.014 0 001.42 0l3-3c.18-.18.29-.43.29-.71.01-.55-.44-1-.99-1zm4.44-5.65l6.4-7.88V0H10.5v1.67h5.91L10 9.44v1.57h9V9.35h-6.55zm1.27 3.64L11 20h1.59l.56-1.56h2.68l.55 1.56h1.64l-2.68-7.01h-1.62zm-.16 4.3l.93-2.57h.02l.9 2.57h-1.85z"],"sort-asc":["M10 8h5c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1h-5c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm0 5h7c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1h-7c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm0-10h3c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1h-3c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm9 12h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zM7 14c-.28 0-.53.11-.71.29L5 15.59V10c0-.55-.45-1-1-1s-1 .45-1 1v5.59L1.71 14.3A.965.965 0 001 14a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 007 14z"],"sort-desc":["M13 15h-3c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h3c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm-6-1c-.28 0-.53.11-.71.29L5 15.59V10c0-.55-.45-1-1-1s-1 .45-1 1v5.59L1.71 14.3A.965.965 0 001 14a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29s.53-.11.71-.29l3-3A1.003 1.003 0 007 14zM19 0h-9c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h9c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-4 10h-5c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h5c.55 0 1-.45 1-1v-1c0-.55-.45-1-1-1zm2-5h-7c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1h7c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1z"],"sort-numerical":["M9 14.99c-.28 0-.53.11-.71.29L7 16.58v-5.59c0-.55-.45-1-1-1s-1 .45-1 1v5.59l-1.29-1.29a.965.965 0 00-.71-.3 1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29.28 0 .53-.11.71-.29l3-3c.18-.18.29-.43.29-.71a.99.99 0 00-1-1zm8.88.23c-.08-.42-.22-.79-.42-1.12-.2-.33-.47-.6-.8-.8-.33-.2-.76-.3-1.28-.3a2.333 2.333 0 00-1.72.71c-.21.22-.37.48-.49.78-.11.3-.17.62-.17.97 0 .27.04.54.13.8.08.26.22.5.4.7.19.21.43.38.71.5a2.142 2.142 0 001.72.02c.25-.12.47-.31.66-.58l.02.02c-.01.19-.04.4-.08.63-.04.24-.11.46-.21.67-.1.21-.23.38-.39.53a.92.92 0 01-.62.22c-.24 0-.44-.08-.6-.25-.16-.17-.27-.36-.31-.59h-1.31c.04.29.12.56.24.79.12.23.28.43.48.59.19.16.42.28.67.36.25.08.52.12.82.12.49 0 .9-.1 1.23-.31.34-.21.61-.48.82-.82.21-.34.37-.71.47-1.13.1-.42.15-.83.15-1.25 0-.43-.04-.85-.12-1.26zm-1.42.63c-.05.15-.11.28-.2.4-.09.12-.2.21-.34.27s-.3.1-.49.1c-.17 0-.33-.04-.46-.11s-.24-.17-.33-.29c-.08-.12-.15-.25-.19-.4-.04-.15-.06-.31-.06-.47 0-.15.02-.3.07-.45.05-.15.11-.28.2-.39.09-.12.2-.21.33-.28.13-.07.27-.11.44-.11.17 0 .33.04.47.11.14.07.25.17.34.28a1.387 1.387 0 01.28.86c.01.17-.02.33-.06.48zM15.32 11H17V0h-1.25c-.05.34-.17.62-.34.85-.17.23-.39.42-.63.57-.25.15-.52.25-.83.31-.3.06-.62.09-.94.09v1.41h2.31V11z"],"sort-numerical-desc":["M9 15c-.28 0-.53.11-.71.29L7 16.59v-5.58c0-.55-.45-1-1-1s-1 .45-1 1v5.58L3.71 15.3c-.18-.18-.43-.3-.71-.3a1.003 1.003 0 00-.71 1.71l3 3c.18.18.43.29.71.29.28 0 .53-.11.71-.29l3-3A1.003 1.003 0 009 15zm6.7-1.33a1.5 1.5 0 01-.44.43c-.17.11-.37.19-.58.23-.22.04-.44.06-.67.05v1.07h1.66V20H17v-6.99h-1.06c-.04.26-.12.48-.24.66zm3.15-10.3c-.11-.68-.29-1.26-.55-1.76-.26-.5-.62-.89-1.08-1.18C16.75.14 16.17 0 15.46 0c-.54 0-1.03.09-1.46.27-.43.18-.79.44-1.09.76-.3.33-.52.71-.67 1.15-.16.44-.24.92-.24 1.43 0 .54.08 1.04.23 1.47.15.44.37.81.65 1.12.28.31.61.55 1 .72.39.17.82.26 1.3.26.46 0 .88-.11 1.26-.33.38-.22.68-.53.9-.94l.03.03c-.03.35-.07.74-.12 1.16-.05.42-.15.81-.29 1.18-.14.37-.35.68-.61.92-.26.25-.62.37-1.06.37-.43 0-.77-.13-1.03-.4-.25-.27-.4-.62-.44-1.05h-1.64c.02.43.11.83.29 1.18.17.35.39.66.67.91a3.027 3.027 0 002.07.8c.71 0 1.3-.17 1.79-.5.48-.33.87-.76 1.17-1.29.3-.53.51-1.12.64-1.76.13-.64.19-1.28.19-1.92.01-.77-.05-1.49-.15-2.17zM17.1 4.44c-.08.27-.19.5-.34.71-.15.21-.34.37-.57.49-.23.12-.5.18-.8.18-.3 0-.56-.06-.78-.19-.22-.13-.4-.29-.55-.49-.14-.2-.25-.44-.32-.7-.07-.27-.11-.55-.11-.84 0-.28.04-.55.11-.82.07-.26.18-.49.32-.7.14-.2.33-.36.55-.48.22-.12.48-.17.78-.17.31 0 .57.06.8.18.23.12.42.28.57.48.15.2.26.43.34.69.08.26.11.53.11.82 0 .29-.04.57-.11.84z"],"split-columns":["M15 13a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-3-3a1.003 1.003 0 00-1.42 1.42L16.59 9H11V2h5v2c.77 0 1.47.3 2 .78V1c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v3.78C2.53 4.3 3.23 4 4 4V2h5v7H3.41L4.7 7.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-3 3C.11 9.47 0 9.72 0 10c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L3.41 11H9v7H4v-2c-.77 0-1.47-.3-2-.78V19c0 .55.45 1 1 1h14c.55 0 1-.45 1-1v-3.78c-.53.48-1.23.78-2 .78v2h-5v-7h5.59l-1.29 1.29c-.19.18-.3.43-.3.71z"],square:["M19 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H2V2h16v16z"],"stacked-chart":["M12 2c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v4h4V2zm3 14h2c.55 0 1-.45 1-1v-5h-4v5c0 .55.45 1 1 1zm3-10c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1v3h4V6zm-6 1H8v5h4V7zm-9 9h2c.55 0 1-.45 1-1v-3H2v3c0 .55.45 1 1 1zm16 1H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM6 9c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v2h4V9zm3 7h2c.55 0 1-.45 1-1v-2H8v2c0 .55.45 1 1 1z"],"stadium-geometry":["M15 7H5a3 3 0 000 6h10a3 3 0 100-6zM5 5a5 5 0 000 10h10a5 5 0 000-10H5z"],star:["M10 0l3.1 6.6 6.9 1-5 5.1 1.2 7.3-6.2-3.4L3.8 20 5 12.7 0 7.6l6.9-1z"],"star-empty":["M20 7.6l-6.9-1.1L10 0 6.9 6.6 0 7.6l5 5.1L3.8 20l6.2-3.4 6.2 3.4-1.2-7.2 5-5.2zM10 15l-4.5 2.4.9-5.2-3.6-3.6 5-.8L10 3.1l2.2 4.7 5 .8-3.6 3.7.9 5.2L10 15z"],"step-backward":["M15 3c-.23 0-.42.09-.59.21l-.01-.01L8 8V4c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-4l6.4 4.8.01-.01c.17.12.36.21.59.21.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"step-chart":["M19 16H2v-3h4c.55 0 1-.45 1-1V8h3v2c0 .55.45 1 1 1h5c.55 0 1-.45 1-1V6h2c.55 0 1-.45 1-1s-.45-1-1-1h-3c-.55 0-1 .45-1 1v4h-3V7c0-.55-.45-1-1-1H6c-.55 0-1 .45-1 1v4H2V3c0-.55-.45-1-1-1s-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],"step-forward":["M15 3h-2c-.55 0-1 .45-1 1v4L5.6 3.2l-.01.01C5.42 3.09 5.23 3 5 3c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1 .23 0 .42-.09.59-.21l.01.01L12 12v4c0 .55.45 1 1 1h2c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],stop:["M16 3H4c-.55 0-1 .45-1 1v12c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],stopwatch:["M10 6a6 6 0 106 6h-6V6zm-.998-1.938A1.015 1.015 0 019 4V2H7a1 1 0 110-2h6a1 1 0 010 2h-2v2c0 .02 0 .041-.002.062A8.001 8.001 0 0110 20a8 8 0 01-.998-15.938z"],strikethrough:["M18 9h-4.46a4.7 4.7 0 00-.4-.14c-.19-.05-.51-.14-.96-.25-.45-.11-.9-.23-1.37-.35-.47-.12-.89-.23-1.27-.33s-.6-.16-.65-.17c-.53-.15-.95-.37-1.27-.66-.32-.28-.49-.68-.49-1.19 0-.36.09-.66.26-.9s.39-.43.65-.57c.26-.14.55-.24.87-.3s.63-.09.93-.09c.89 0 1.63.19 2.21.57.45.3.75.76.89 1.38h2.63c-.06-.52-.2-.98-.42-1.4-.3-.57-.71-1.05-1.23-1.43a5.33 5.33 0 00-1.79-.87c-.7-.2-1.42-.3-2.19-.3-.66 0-1.31.08-1.96.25s-1.22.43-1.73.77-.92.79-1.23 1.32c-.31.52-.46 1.15-.46 1.87 0 .37.05.74.15 1.1.1.36.28.7.53 1.02.18.24.41.47.69.67H2c-.55 0-1 .45-1 1s.45 1 1 1h10.14c.02.01.05.02.07.02.3.11.58.29.84.55.25.26.38.67.38 1.21 0 .27-.06.53-.17.79-.11.26-.29.49-.54.69-.25.2-.57.36-.97.49s-.88.19-1.44.19c-.52 0-1.01-.06-1.45-.17-.45-.11-.84-.29-1.19-.54s-.61-.56-.8-.95c-.05-.08-.09-.18-.12-.28H4.11c.09.43.22.82.4 1.18.33.65.77 1.18 1.32 1.59.55.41 1.2.72 1.94.92.74.2 1.53.3 2.37.3.73 0 1.44-.08 2.14-.25.7-.17 1.33-.43 1.88-.79.55-.36.99-.83 1.33-1.39.34-.56.51-1.25.51-2.05 0-.37-.06-.75-.18-1.12a3.12 3.12 0 00-.15-.39H18c.55 0 1-.45 1-1s-.45-1-1-1z"],style:["M18 18H2V2h12.3l2-2H1C.4 0 0 .4 0 1v18c0 .6.4 1 1 1h18c.6 0 1-.4 1-1V7.7l-2 2V18zm1.2-18l-7.6 7.6 2.8 2.8L20 4.8V0h-.8zM4 15.9c3.1.2 5.9.2 8.2-2 1.1-1.1 1.1-3 0-4.1-.6-.5-1.3-.8-2-.8s-1.4.3-1.9.8C7.2 11 6.6 14.3 4 15.9z"],"swap-horizontal":["M16.02 10c-.01 0-.01 0 0 0H16h.02zM2 6h13.58l-2.29 2.29a1 1 0 00-.3.71 1.003 1.003 0 001.71.71l4-4c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-4-4a1.003 1.003 0 00-1.42 1.42L15.58 4H2c-.55 0-1 .45-1 1s.45 1 1 1zm2 4h-.02H4zm14 4H4.42l2.29-2.29a1 1 0 00.3-.71 1.003 1.003 0 00-1.71-.71l-4 4c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L4.42 16H18c.55 0 1-.45 1-1s-.45-1-1-1z"],"swap-vertical":["M9.71 5.3l-4-4A.997.997 0 005 1.01c-.28 0-.53.11-.71.29l-4 4a1.003 1.003 0 001.42 1.42L4 4.42V18c0 .55.45 1 1 1s1-.45 1-1V4.42l2.29 2.29a1 1 0 00.71.3 1.003 1.003 0 00.71-1.71zM10 3.98c0 .01 0 .01 0 0V4v-.02zm0 12.04c0-.01 0-.01 0 0V16v.02zm9-3.03c-.28 0-.53.11-.71.29L16 15.58V2c0-.55-.45-1-1-1s-1 .45-1 1v13.58l-2.29-2.29a1.003 1.003 0 00-1.42 1.42l4 4c.18.18.43.29.71.29.28 0 .53-.11.71-.29l4-4c.18-.18.29-.43.29-.71 0-.56-.45-1.01-1-1.01z"],switch:["M12.293 2.293l1.414 1.414-7.127 7.129a3.5 3.5 0 11-1.415-1.415l7.128-7.128zM16.5 9a3.5 3.5 0 110 7 3.5 3.5 0 010-7zm-13 2a1.5 1.5 0 100 3 1.5 1.5 0 000-3zm13 0a1.5 1.5 0 100 3 1.5 1.5 0 000-3z"],"symbol-circle":["M10 4.01a6 6 0 100 12 6 6 0 100-12z"],"symbol-cross":["M15 8.01h-3v-3c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v3H5c-.55 0-1 .45-1 1v2c0 .55.45 1 1 1h3v3c0 .55.45 1 1 1h2c.55 0 1-.45 1-1v-3h3c.55 0 1-.45 1-1v-2c0-.56-.45-1-1-1z"],"symbol-diamond":["M15 10.01c0-.21-.08-.39-.18-.54l.02-.01-4-6-.02.01c-.18-.28-.47-.46-.82-.46s-.64.18-.82.45l-.01-.01-4 6 .02.01c-.11.16-.19.34-.19.55s.08.39.18.54l-.02.01 4 6 .02-.01c.18.27.47.46.82.46s.64-.19.82-.46l.02.01 4-6-.02-.01c.1-.16.18-.34.18-.54z"],"symbol-square":["M15 4.01H5c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h10c.55 0 1-.45 1-1v-10c0-.56-.45-1-1-1z"],"symbol-triangle-down":["M16 5c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1 0 .16.05.31.11.44H4.1l5 10h.01c.17.33.5.56.89.56s.72-.23.89-.56h.01l5-10h-.01c.06-.13.11-.28.11-.44z"],"symbol-triangle-up":["M15.89 14.56l-4.99-10h-.01c-.17-.33-.5-.56-.89-.56s-.72.23-.89.56H9.1l-5 10h.01c-.06.13-.11.28-.11.44 0 .55.45 1 1 1h10c.55 0 1-.45 1-1 0-.16-.05-.31-.11-.44z"],syringe:["M15.146.854a.5.5 0 01.708-.708l4 4a.5.5 0 01-.708.708l-.646-.647L17.207 5.5l1.647 1.646a.5.5 0 01-.708.708l-.646-.647-1.146 1.146-7.5 7.5a.5.5 0 01-.708 0l-.646-.646-2.646 2.647a.5.5 0 01-.708 0l-.646-.647-2.646 2.647a.5.5 0 01-.708-.708L2.793 16.5l-.647-.646a.5.5 0 010-.708L4.793 12.5l-.647-.646a.5.5 0 010-.708l7.5-7.5L12.794 2.5l-.647-.646a.5.5 0 01.708-.708L14.5 2.793 15.793 1.5l-.647-.646zM12.707 4l.793-.793L16.793 6.5 16 7.293 12.707 4zm2.586 4l-.793.793-1.646-1.647a.5.5 0 00-.708.708L13.793 9.5 12.5 10.793l-1.646-1.647a.5.5 0 00-.708.708l1.647 1.646-1.293 1.293-1.646-1.647a.5.5 0 00-.708.708L9.793 13.5 8.5 14.793 5.207 11.5 12 4.707 15.293 8zM3.207 15.5L5.5 13.207 6.793 14.5 4.5 16.793 3.207 15.5zM16.5 2.207L17.793 3.5 16.5 4.793 15.207 3.5 16.5 2.207z"],tag:["M2 4a2 2 0 012-2h4.588a2 2 0 011.414.586l7.41 7.41a2 2 0 010 2.828l-4.588 4.588a2 2 0 01-2.829 0l-7.41-7.41A2 2 0 012 8.588V4zm3.489-.006a1.495 1.495 0 100 2.99 1.495 1.495 0 000-2.99z"],"take-action":["M5 7c.28 0 .53-.11.71-.29l5-5A1.003 1.003 0 009.29.29l-5 5A1.003 1.003 0 005 7zm6 6a1.003 1.003 0 001.71.71l5-5a1.003 1.003 0 00-1.42-1.42l-5 5c-.18.18-.29.43-.29.71zm8 5h-1c0-.55-.45-1-1-1h-7c-.55 0-1 .45-1 1H8c-.55 0-1 .45-1 1s.45 1 1 1h11c.55 0 1-.45 1-1s-.45-1-1-1zm-9-6l6-6-1.29-1.29a1.003 1.003 0 00-1.42-1.42L12 2 6 8l1.29 1.29-7 7a1.003 1.003 0 001.42 1.42l7-7L10 12z"],tank:["M3.956 4.47A1 1 0 014.804 4h6.392a1 1 0 01.848.47L13 6h5a1 1 0 010 2h-5v1h4a3 3 0 110 6H3a3 3 0 010-6V6.287a1 1 0 01.152-.53l.804-1.287zM3 11h14a1 1 0 110 2H3a1 1 0 110-2z"],target:["M9 5a1 1 0 012 0v3a1 1 0 01-2 0V5zM12 9a1 1 0 000 2h3a1 1 0 000-2h-3zM4 10a1 1 0 011-1h3a1 1 0 010 2H5a1 1 0 01-1-1zM10 11a1 1 0 00-1 1v3a1 1 0 002 0v-3a1 1 0 00-1-1z","M10 20c5.523 0 10-4.477 10-10S15.523 0 10 0 0 4.477 0 10s4.477 10 10 10zm0-2a8 8 0 100-16 8 8 0 000 16z"],taxi:["M19 9h-.33l.33 1v.5c0 .15-.03.3-.07.44h.01L17 17.23v.27c0 .83-.67 1.5-1.5 1.5s-1.5-.67-1.5-1.5V17H6v.5c0 .83-.67 1.5-1.5 1.5S3 18.33 3 17.5v-.27l-1.93-6.28h.01c-.05-.15-.08-.3-.08-.45V10s.02-.06.05-.16c.06-.17.16-.47.28-.84H1c-.55 0-1-.45-1-1s.45-1 1-1h1l1-3h-.01v-.01c.25-.64 1-1.31 1.67-1.5 0 0 .78-.21 2.33-.36V1c0-.55.45-1 1-1h4c.55 0 1 .45 1 1v1.13c1.55.14 2.33.36 2.33.36.67.19 1.42.86 1.67 1.5V4H17l1 3h1c.55 0 1 .45 1 1s-.45 1-1 1zM3 11.5c0 .83.67 1.5 1.5 1.5S6 12.33 6 11.5 5.33 10 4.5 10 3 10.67 3 11.5zM16 7l-1-3H5L4 7v1h12V7zm-.5 3c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z"],temperature:["M11 0a2 2 0 00-2 2v10.535a4 4 0 104 0V2a2 2 0 00-2-2zM3 2.5a.5.5 0 01.5-.5h4a.5.5 0 010 1h-4a.5.5 0 01-.5-.5zM3.5 8a.5.5 0 000 1h4a.5.5 0 000-1h-4zM5 5.5a.5.5 0 01.5-.5h2a.5.5 0 010 1h-2a.5.5 0 01-.5-.5zm.5 5.5a.5.5 0 000 1h2a.5.5 0 000-1h-2z"],"text-highlight":["M16 17c-.55 0-1-.45-1-1V4c0-.55.45-1 1-1s1-.45 1-1-.45-1-1-1c-.77 0-1.47.3-2 .78-.53-.48-1.23-.78-2-.78-.55 0-1 .45-1 1s.45 1 1 1 1 .45 1 1v12c0 .55-.45 1-1 1s-1 .45-1 1 .45 1 1 1c.77 0 1.47-.3 2-.78.53.48 1.23.78 2 .78.55 0 1-.45 1-1s-.45-1-1-1zm-4-4H2V7h10V5H1c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h11v-2zm7-8h-3v2h2v6h-2v2h3c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1z"],th:["M19 1H1c-.6 0-1 .5-1 1v16c0 .5.4 1 1 1h18c.5 0 1-.5 1-1V2c0-.5-.5-1-1-1zM7 17H2v-3h5v3zm0-4H2v-3h5v3zm0-4H2V6h5v3zm11 8H8v-3h10v3zm0-4H8v-3h10v3zm0-4H8V6h10v3z"],"th-derived":["M5.3 13.3c-.2.2-.3.4-.3.7 0 .6.4 1 1 1 .3 0 .5-.1.7-.3l3-3c.2-.2.3-.4.3-.7s-.1-.5-.3-.7l-3-3C6.5 7.1 6.3 7 6 7c-.6 0-1 .4-1 1 0 .3.1.5.3.7L6.6 10H1c-.6 0-1 .4-1 1s.4 1 1 1h5.6l-1.3 1.3zM19 1H3c-.5 0-1 .5-1 1v6h1c0-1.7 1.3-3 3-3 .8 0 1.6.3 2.1.9l.1.1H9v.8l1 1V6h8v3h-6.8c.3.3.5.6.6 1H18v3h-6.8l-.1.1-.9.9H18v3h-8v-2.8l-1 1V17H4v-.8c-.6-.5-1-1.3-1-2.2H2v4c0 .5.5 1 1 1h16c.6 0 1-.5 1-1V2c0-.5-.5-1-1-1z"],"th-disconnect":["M14.25 1H19c.5 0 1 .5 1 1v16c0 .5-.5 1-1 1h-7.221l.278-2H18v-3h-5.527l.14-1H18v-3h-4.971l.139-1H18V6h-4.416l.637-4.587c.02-.139.03-.277.03-.413zM8.221 1l-.694 5H2v3h5.11l-.139 1H2v3h4.555l-.14 1H2v3h3.999l-.22 1.587c-.02.139-.03.277-.03.413H1c-.6 0-1-.5-1-1V2c0-.5.4-1 1-1h7.221zM10.26.862a1 1 0 011.98.276l-2.5 18a1 1 0 01-1.98-.276l2.5-18z"],"th-filtered":["M17.333 10l1.435-1.722a1 1 0 00.232-.64V4.85l1-.9V18c0 .5-.5 1-1 1H1c-.6 0-1-.5-1-1V2c0-.5.4-1 1-1h6.722L12 4.85V6H8v3h4v1H8v3h10v-3h-.667zM7 17v-3H2v3h5zm0-4v-3H2v3h5zm0-4V6H2v3h5zm11 8v-3H8v3h10z","M19.35 0a.642.642 0 01.46 1.1l-3.03 3.03v2.95c0 .18-.07.34-.19.46l-1.28 1.29c-.11.1-.27.17-.45.17-.35 0-.64-.29-.64-.64V4.13L11.19 1.1a.642.642 0 01.45-1.1h7.71z"],"th-list":["M19 1H1c-.6 0-1 .5-1 1v16c0 .5.4 1 1 1h18c.5 0 1-.5 1-1V2c0-.5-.5-1-1-1zm-1 16H2v-3h16v3zm0-4H2v-3h16v3zm0-4H2V6h16v3z"],"third-party":["M8 0C3.58 0 0 3.58 0 8a8 8 0 005.856 7.71c.064-.057.129-.109.19-.156.278-.209.595-.383.896-.53.358-.174.81-.358 1.193-.515.206-.084.393-.16.534-.223a3.93 3.93 0 00.203-.095 4.1 4.1 0 01-.305-.45C8.382 13.911 8.19 14 8 14c-.67 0-1.36-1.1-1.73-3h1.252c.047-.296.153-.571.323-.797l.01-.203H6.12C6.05 9.39 6 8.73 6 8s.05-1.39.12-2h3.76l.037.344c.315-.145.65-.242.979-.295L10.89 6h2.76c.027.077.052.155.076.233l.118-.04A3.62 3.62 0 0114.998 6c.247 0 .51.028.772.086A8 8 0 008 0zm5.17 5h-2.44c-.21-1.11-.51-2.03-.91-2.69 1.43.46 2.61 1.43 3.35 2.69zM8 2c.67 0 1.36 1.1 1.73 3H6.27C6.64 3.1 7.33 2 8 2zm-1.82.31c-.4.66-.71 1.58-.91 2.69H2.83a6.025 6.025 0 013.35-2.69zM2 8c0-.7.13-1.37.35-2h2.76C5.04 6.62 5 7.28 5 8s.04 1.38.11 2H2.35C2.13 9.37 2 8.7 2 8zm.83 3h2.44c.21 1.11.51 2.03.91 2.69A6.025 6.025 0 012.83 11z","M13.917 15.209c.21.094.444.19.685.288.912.374 1.927.789 2.188 1.355.31.722.186 1.148.186 1.148H6.026s-.13-.426.186-1.148c.256-.584 1.305-1.011 2.234-1.39.22-.088.432-.175.626-.26.909-.4.923-.662.94-.978.002-.037.004-.076.008-.115l.003-.072c.002-.025.004-.049.004-.073a3.067 3.067 0 01-.839-1.237l-.007-.007a.024.024 0 00-.003-.01 1.757 1.757 0 01-.113-.347c-.234-.042-.372-.296-.427-.537a1.045 1.045 0 01-.137-.598c.034-.35.179-.509.337-.57v-.056c0-.44.034-1.065.117-1.478a2.508 2.508 0 01.962-1.623c.426-.33 1.038-.501 1.58-.501.544 0 1.155.172 1.588.502a2.496 2.496 0 01.963 1.622c.075.413.117 1.045.117 1.478v.062c.15.062.288.22.323.564.02.268-.083.502-.138.598-.048.234-.185.488-.42.537a2.635 2.635 0 01-.116.364 3.094 3.094 0 01-.818 1.224c0 .055 0 .11.007.158.004.048.006.095.007.14.011.311.02.57.907.96z","M14.976 14.57c-.24-.098-.455-.186-.65-.274l-.007-.003a3.801 3.801 0 01-.194-.091c.224-.288.41-.609.554-.946l.001-.002.013-.033c.018-.043.036-.087.052-.13l.011-.027.016-.04c.105-.092.19-.19.256-.284.129-.184.213-.38.265-.563.105-.226.225-.592.192-1.026l-.001-.011-.002-.011a1.855 1.855 0 00-.325-.91 9.924 9.924 0 00-.12-1.246 3.088 3.088 0 00-.106-.474l-.001-.007a3.543 3.543 0 00-.763-1.353c.27-.092.56-.139.83-.139.495 0 1.05.156 1.444.456a2.269 2.269 0 01.875 1.475c.069.375.106.95.106 1.344v.056c.138.056.263.2.294.513.019.244-.075.456-.125.543-.044.213-.169.444-.381.488-.025.1-.056.206-.094.3a2.815 2.815 0 01-.756 1.144c0 .05 0 .1.006.144.004.043.006.086.007.127.01.283.018.518.824.873.192.086.404.172.623.262.83.34 1.752.717 1.99 1.231.28.657.168 1.044.168 1.044h-2.081a3.864 3.864 0 00-.188-.542l-.005-.013-.006-.012c-.183-.397-.491-.681-.76-.88a5.614 5.614 0 00-.896-.522 17.36 17.36 0 00-.916-.4l-.15-.061z"],"thumbs-down":["M18.55 6.56c-.31-.01-.65-.03-1.02-.06.03 0 .06-.01.09-.01.88-.12 1.68-.63 1.76-1.37.08-.75-.58-1.25-1.46-1.33-.32-.03-.65-.05-.99-.08.59-.19 1.05-.54 1.09-1.2.05-.75-.99-1.32-1.87-1.41-.34-.03-.64-.05-.91-.07h-.11c-.28-.02-.54-.02-.77-.02-3.92-.08-7.29.6-9.36 1.93v7.72c2.67 1.66 5.95 4.61 5.26 7.08-.21.76.39 1.35 1.23 1.26 1.01-.11 1.71-1.18 1.75-2.28.05-1.29-.19-2.59-.62-3.74-.05-.32.01-.65.47-.68.61-.04 1.39-.08 1.99-.1.32 0 .64-.01.94-.03h.01c.52-.03 1-.07 1.42-.12.88-.11 1.69-.6 1.79-1.35.1-.75-.55-1.25-1.44-1.35-.07-.01-.13-.02-.2-.02.21-.02.42-.04.61-.06.88-.11 1.69-.6 1.79-1.35.09-.75-.56-1.31-1.45-1.36zM3 3H0v8h3c.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"thumbs-up":["M3 9H0v8h3c.55 0 1-.45 1-1v-6c0-.55-.45-1-1-1zm16.99 3.09c-.1-.75-.91-1.24-1.79-1.35-.19-.02-.4-.05-.61-.06.07-.01.14-.01.2-.02.88-.1 1.53-.61 1.44-1.35-.1-.74-.91-1.24-1.79-1.35-.42-.05-.9-.09-1.42-.12h-.01l-.94-.03c-.6-.02-1.39-.05-1.99-.1-.45-.03-.51-.36-.47-.68.43-1.15.67-2.45.62-3.74-.04-1.11-.74-2.17-1.75-2.28-.84-.09-1.45.5-1.23 1.26.7 2.47-2.58 5.43-5.25 7.08v7.72c2.08 1.33 5.44 2.01 9.35 1.93.24 0 .49-.01.77-.02h.11c.27-.02.57-.04.91-.07.88-.08 1.92-.66 1.87-1.41-.04-.65-.5-1.01-1.09-1.2.34-.03.67-.05.99-.08.89-.08 1.55-.58 1.46-1.33-.08-.75-.88-1.25-1.76-1.37-.03 0-.06-.01-.09-.01.37-.02.71-.04 1.02-.06.91-.05 1.55-.61 1.45-1.36z"],tick:["M17 4c-.28 0-.53.11-.71.29L7 13.59 3.71 10.3A.965.965 0 003 10a1.003 1.003 0 00-.71 1.71l4 4c.18.18.43.29.71.29s.53-.11.71-.29l10-10A1.003 1.003 0 0017 4z"],"tick-circle":["M10 20C4.48 20 0 15.52 0 10S4.48 0 10 0s10 4.48 10 10-4.48 10-10 10zm5-14c-.28 0-.53.11-.71.29L8 12.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29.28 0 .53-.11.71-.29l7-7A1.003 1.003 0 0015 6z"],time:["M11 9.59V4c0-.55-.45-1-1-1s-1 .45-1 1v6c0 .28.11.53.29.71l3 3a1.003 1.003 0 001.42-1.42L11 9.59zM10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm0 18c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"],"timeline-area-chart":["M19 16H2V3c0-.55-.45-1-1-1s-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zm0-13.41l-7.07 7.07-4.3-3.44-.01.01A.987.987 0 007 6c-.24 0-.46.1-.63.24l-.01-.01L3 9.03V15h16V2.59z"],"timeline-bar-chart":["M19 17H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1zM9 16h2c.55 0 1-.45 1-1V2c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1v13c0 .55.45 1 1 1zm6 0h2c.55 0 1-.45 1-1V6c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1zM3 16h2c.55 0 1-.45 1-1V9c0-.55-.45-1-1-1H3c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1z"],"timeline-events":["M5 5c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1s-1 .5-1 1v2c0 .6.4 1 1 1zm10 0c.6 0 1-.4 1-1V2c0-.5-.4-1-1-1s-1 .5-1 1v2c0 .6.4 1 1 1zm-9 9H4v2h2v-2zM17 3v1c0 1.1-.9 2-2 2s-2-.9-2-2V3H7v1c0 1.1-.9 2-2 2s-2-.9-2-2V3H2c-.5 0-1 .5-1 1v14c0 .5.5 1 1 1h16c.5 0 1-.5 1-1V4c0-.5-.5-1-1-1h-1zM7 17H3v-4h4v4zm0-5H3V8h4v4zm5 5H8v-4h4v4zm0-5H8V8h4v4zm5 5h-4v-4h4v4zm0-5h-4V8h4v4zm-6 2H9v2h2v-2zm5-5h-2v2h2V9z"],"timeline-line-chart":["M19 16H2v-1.59l5-5 3.29 3.29c.18.19.43.3.71.3s.53-.11.71-.29l7-7a1.003 1.003 0 00-1.42-1.42L11 10.59l-3.29-3.3C7.53 7.11 7.28 7 7 7s-.53.11-.71.29L2 11.59V3c0-.55-.45-1-1-1s-1 .45-1 1v14a.998.998 0 001 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],tint:["M9.86 2S3.98 9.18 3.98 12.17C3.99 15.4 6.78 18 9.96 18c3.18-.01 6.04-2.63 6.03-5.86C15.99 9.05 9.86 2 9.86 2z"],torch:["M6.97 19c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-2h-6v2zm-3-15l3 4v8h6V8l3-4h-12zm5 5c0-.55.45-1 1-1s1 .45 1 1v2c0 .55-.45 1-1 1s-1-.45-1-1V9zm6-9h-10c-.55 0-1 .45-1 1v2h12V1c0-.55-.45-1-1-1z"],tractor:["M4.5 11a4.5 4.5 0 110 9 4.5 4.5 0 010-9zm11.499 1a4 4 0 110 8 4 4 0 010-8zm-11.5 1.571a1.928 1.928 0 100 3.857 1.928 1.928 0 000-3.857zM16 14.667a1.333 1.333 0 100 2.666 1.333 1.333 0 000-2.666zM5.999 0C7.46 0 8.527.668 9 2l.851 4.256c1.433.096 2.82.217 4.147.362V2h2L16 6.862c.962.13 1.886.275 2.767.435.779.141 1.232.614 1.232 1.284L20 13a4.995 4.995 0 00-4-1.997A5.001 5.001 0 0011.099 15h-1.12a5.499 5.499 0 00-5.478-4.994 5.482 5.482 0 00-3.377 1.157H.004v-1.18L0 7.327c-.002-.597.37-1.18.999-1.302V1a1 1 0 011-1h4zm1 2H3v4h.75c1.386.027 2.749.073 4.079.139L6.999 2z"],train:["M16 18h-2l2 2H4l.12-.12L6 18H4c-1.1 0-2-.9-2-2V2c0-1.1 3.58-2 8-2s8 .9 8 2v14c0 1.1-.9 2-2 2zM5.5 15c.83 0 1.5-.67 1.5-1.5S6.33 12 5.5 12 4 12.67 4 13.5 4.67 15 5.5 15zM9 3H4v6h5V3zm7 0h-5v6h5V3zm-1.5 9c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z"],translate:["M19.89 18.56l-4.99-10h-.01c-.17-.33-.5-.56-.89-.56s-.72.23-.89.56h-.01l-1.73 3.46-2.8-2.3 1.99-1.64C11.44 7.34 12 6.23 12 5V4h1c.55 0 1-.45 1-1s-.45-1-1-1H8V1c0-.55-.45-1-1-1S6 .45 6 1v1H1c-.55 0-1 .45-1 1s.45 1 1 1h9v1c0 .62-.28 1.18-.73 1.54L7 8.42 4.73 6.54C4.28 6.18 4 5.62 4 5H2c0 1.23.56 2.34 1.44 3.07l1.99 1.64-3.06 2.52.01.01c-.23.18-.38.45-.38.76 0 .55.45 1 1 1 .24 0 .45-.1.63-.24l.01.01L7 11l3.36 2.77.01-.01c.02.02.05.03.08.05.01 0 .01.01.02.02l-2.36 4.73h.01c-.07.13-.12.28-.12.44 0 .55.45 1 1 1 .39 0 .72-.23.89-.56h.01L11.12 17h5.76l1.22 2.45h.01c.17.32.5.55.89.55.55 0 1-.45 1-1 0-.16-.05-.31-.11-.44zM12.12 15L14 11.24 15.88 15h-3.76z"],trash:["M17 1h-5c0-.55-.45-1-1-1H9c-.55 0-1 .45-1 1H3c-.55 0-1 .45-1 1v1h16V2c0-.55-.45-1-1-1zm.5 3h-15c-.28 0-.5.22-.5.5s.22.5.5.5H3v14c0 .55.45 1 1 1h12c.55 0 1-.45 1-1V5h.5c.28 0 .5-.22.5-.5s-.22-.5-.5-.5zM7 16c0 .55-.45 1-1 1s-1-.45-1-1V8c0-.55.45-1 1-1s1 .45 1 1v8zm4 0c0 .55-.45 1-1 1s-1-.45-1-1V8c0-.55.45-1 1-1s1 .45 1 1v8zm4 0c0 .55-.45 1-1 1s-1-.45-1-1V8c0-.55.45-1 1-1s1 .45 1 1v8z"],tree:["M11 15.542V20H9v-4.458L2 17l4.5-5.625L4 12l3.655-5.483L6 7l4-7 4 7-1.655-.483L16 12l-2.5-.625L18 17l-7-1.458z"],"trending-down":["M19 10c-.55 0-1 .45-1 1v1.37l-6.25-7.03-.01.01A.971.971 0 0011 5c-.23 0-.42.09-.59.21l-.01-.01-3.43 2.58-5.42-3.61-.01.01A.969.969 0 001 4c-.55 0-1 .45-1 1 0 .35.19.64.46.82l-.01.01 6 4 .01-.02c.15.11.33.19.54.19.23 0 .42-.09.59-.21l.01.01 3.26-2.45L16.77 14H15c-.55 0-1 .45-1 1s.45 1 1 1h4c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1z"],"trending-up":["M19 4h-4c-.55 0-1 .45-1 1s.45 1 1 1h1.77l-5.91 6.65L7.6 10.2l-.01.01C7.42 10.09 7.23 10 7 10c-.21 0-.39.08-.54.18l-.01-.02-6 4 .01.02c-.27.18-.46.47-.46.82 0 .55.45 1 1 1 .21 0 .39-.08.54-.18l.01.02 5.41-3.61 3.43 2.58.01-.01c.18.11.37.2.6.2.3 0 .56-.14.74-.34l.01.01L18 7.63V9c0 .55.45 1 1 1s1-.45 1-1V5c0-.55-.45-1-1-1z"],truck:["M16 0a1 1 0 011 1v11a1 1 0 011 1v3h.5a.5.5 0 01.5.5v1a.5.5 0 01-.5.5H17v1a1 1 0 01-1 1h-1a1 1 0 01-1-1v-1H6v1a1 1 0 01-1 1H4a1 1 0 01-1-1v-1H1.5a.5.5 0 01-.5-.5v-1a.5.5 0 01.5-.5H2v-3a1 1 0 011-1V1a1 1 0 112 0v3a2 2 0 012-2h6a2 2 0 012 2V1a1 1 0 011-1zm-4 10H8a1 1 0 00-1 1v4a1 1 0 001 1h4a1 1 0 001-1v-4a1 1 0 00-1-1zm-7 4H4a1 1 0 000 2h1a1 1 0 000-2zm11 0h-1a1 1 0 000 2h1a1 1 0 000-2zm-4.5 0a.5.5 0 110 1h-3l-.09-.008A.5.5 0 018.5 14zm0-1.5a.5.5 0 110 1h-3l-.09-.008a.5.5 0 01.09-.992zm0-1.5a.5.5 0 110 1h-3l-.09-.008A.5.5 0 018.5 11zM14 5H6v3h8V5z"],"two-columns":["M5 0H1C.45 0 0 .45 0 1v18c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm14.71 9.29l-3-3A1.003 1.003 0 0015 7v6a1.003 1.003 0 001.71.71l3-3c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71zM12 0H8c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h4c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],unarchive:["M16.434 0a1 1 0 01.857.486L20 5v14a1 1 0 01-1 1H1a1 1 0 01-1-1V5L2.709.486A1 1 0 013.566 0h12.868zM10 8c-.28 0-.53.11-.71.29l-3 3-.084.096A1.003 1.003 0 007.71 12.71L9 11.41v4.58l.007.116c.058.496.482.884.993.884.55 0 1-.45 1-1v-4.58l1.29 1.29.081.073c.171.139.389.227.629.227a1.003 1.003 0 00.71-1.71l-3-3-.096-.084A1.002 1.002 0 0010 8zm6-6H4L2 5.002h16L16 2z"],underline:["M10 17c3.3 0 6-2.7 6-6V3.5c0-.8-.7-1.5-1.5-1.5S13 2.7 13 3.5V11c0 1.7-1.3 3-3 3s-3-1.3-3-3V3.5C7 2.7 6.3 2 5.5 2S4 2.7 4 3.5V11c0 3.3 2.7 6 6 6zM16.5 19h-13c-.3 0-.5.2-.5.5s.2.5.5.5h13c.3 0 .5-.2.5-.5s-.2-.5-.5-.5z"],undo:["M5 14c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm9-9H3.41L5.7 2.71c.19-.18.3-.43.3-.71a1.003 1.003 0 00-1.71-.71l-4 4C.11 5.47 0 5.72 0 6c0 .28.11.53.29.71l4 4a1.003 1.003 0 001.42-1.42L3.41 7H14c2.21 0 4 1.79 4 4s-1.79 4-4 4H9v2h5c3.31 0 6-2.69 6-6s-2.69-6-6-6z"],"ungroup-objects":["M4.5 6C2.01 6 0 8.01 0 10.5S2.01 15 4.5 15 9 12.99 9 10.5 6.99 6 4.5 6zm11 0C13.01 6 11 8.01 11 10.5s2.01 4.5 4.5 4.5 4.5-2.01 4.5-4.5S17.99 6 15.5 6z"],"unknown-vehicle":["M13 11.988v-4H4v-1l1-3h6V2.003a35.867 35.867 0 00-1-.015c-3.593 0-5.332.488-5.332.488-.67.188-1.424.864-1.674 1.503l-.004.009H3l-1 3H1a1 1 0 100 2h.333l-.28.84-.053.16v7.5a1.5 1.5 0 103 0v-.5h12v.5a1.5 1.5 0 103 0v-4.5h-5a1 1 0 01-1-1zm-8.5 1a1.5 1.5 0 110-3 1.5 1.5 0 010 3zM19.83 2.782a2.392 2.392 0 00-.592-.853c-.276-.264-.64-.485-1.09-.663C17.695 1.09 17.132 1 16.457 1c-.523 0-.996.084-1.418.253a3.157 3.157 0 00-1.084.703c-.299.3-.532.656-.698 1.065-.166.41-.254.861-.264 1.353h2.096c0-.246.028-.476.085-.69.057-.214.145-.4.264-.56.119-.16.27-.287.456-.383.185-.095.406-.143.663-.143.38 0 .677.1.89.3.215.2.321.51.321.93.01.245-.035.45-.135.614-.1.164-.23.314-.392.45a8.598 8.598 0 01-.527.41 3.53 3.53 0 00-.542.485c-.171.187-.32.412-.45.676-.127.265-.206.592-.234.984v.614h1.924v-.519c.038-.273.13-.5.278-.683.147-.182.316-.343.506-.484a13.5 13.5 0 01.606-.424c.214-.14.408-.312.584-.512s.323-.442.442-.724.178-.642.178-1.079c0-.264-.059-.548-.178-.854zm-4.54 6.099v2.103h2.237V8.881H15.29z"],unlock:["M14 1c-2.21 0-4 1.79-4 4v4H2c-.55 0-1 .45-1 1v8c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-8c0-.55-.45-1-1-1h-2V5c0-1.1.9-2 2-2s2 .9 2 2v2c0 .55.45 1 1 1s1-.45 1-1V5c0-2.21-1.79-4-4-4z"],unpin:["M11.77 1.16c-.81.81-.74 2.28.02 3.76L6.1 8.71c-2.17-1.46-4.12-2-4.94-1.18l4.95 4.95-2.12 3.54 3.54-2.12 4.95 4.95c.82-.82.27-2.77-1.19-4.94l3.8-5.69c1.47.76 2.94.84 3.76.02l-7.08-7.08z"],unresolve:["M11.47 12.46c.16-.36.29-.74.38-1.14 0-.02.01-.04.01-.06.09-.4.14-.82.14-1.26 0-.44-.05-.86-.14-1.27 0-.02-.01-.04-.01-.06-.09-.4-.22-.78-.38-1.14-.01-.02-.02-.03-.02-.05a5.94 5.94 0 00-.61-1.03c0-.01-.01-.01-.01-.02a6.308 6.308 0 00-2.1-1.77c-.19-.1-.39-.18-.59-.26-.03-.01-.06-.02-.1-.03-.17-.07-.34-.12-.52-.17-.05-.01-.1-.03-.15-.04a4.34 4.34 0 00-.52-.09c-.05-.01-.11-.02-.17-.03C6.46 4.02 6.23 4 6 4c-3.31 0-6 2.69-6 6s2.69 6 6 6c.23 0 .46-.02.68-.04l.17-.03c.17-.02.34-.06.51-.09.05-.01.1-.03.15-.04.18-.05.36-.1.53-.17l.09-.03a5.973 5.973 0 002.68-2.04c0-.01.01-.01.01-.02.24-.32.44-.66.61-1.03.02-.01.03-.03.04-.05zM14 4c-.99 0-1.91.24-2.73.66a7.51 7.51 0 010 10.68c.82.42 1.74.66 2.73.66 3.31 0 6-2.69 6-6s-2.69-6-6-6z"],updated:["M10 0C6.71 0 3.82 1.6 2 4.05V2c0-.55-.45-1-1-1s-1 .45-1 1v4c0 .55.45 1 1 1h4c.55 0 1-.45 1-1s-.45-1-1-1H3.76C5.22 3.17 7.47 2 10 2c4.42 0 8 3.58 8 8s-3.58 8-8 8-8-3.58-8-8c0-.55-.45-1-1-1s-1 .45-1 1c0 5.52 4.48 10 10 10s10-4.48 10-10S15.52 0 10 0zm4 7c-.28 0-.53.11-.71.29L9 11.58 6.71 9.29a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29.28 0 .53-.11.71-.29l5-5A1.003 1.003 0 0014 7z"],upload:["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zm4 10c-.28 0-.53-.11-.71-.29L11 7.41V15c0 .55-.45 1-1 1s-1-.45-1-1V7.41l-2.29 2.3a1.003 1.003 0 01-1.42-1.42l4-4c.18-.18.43-.29.71-.29s.53.11.71.29l4 4A1.003 1.003 0 0114 10z"],user:["M10 0C4.48 0 0 4.48 0 10c0 .33.02.65.05.97.01.12.03.23.05.35.03.2.05.4.09.59.03.14.06.28.1.42l.12.48c.05.16.1.31.15.46.05.13.09.27.15.4.06.16.13.32.21.48.05.11.1.22.16.33.09.17.17.34.27.5.05.09.1.17.15.25.11.18.22.35.34.52.04.06.08.11.12.17 1.19 1.62 2.85 2.86 4.78 3.53l.09.03c.46.15.93.27 1.42.36.08.01.17.03.25.04.49.07.99.12 1.5.12s1.01-.05 1.5-.12c.08-.01.17-.02.25-.04.49-.09.96-.21 1.42-.36l.09-.03c1.93-.67 3.59-1.91 4.78-3.53.04-.05.08-.1.12-.16.12-.17.23-.35.34-.53.05-.08.1-.16.15-.25.1-.17.19-.34.27-.51.05-.11.1-.21.15-.32.07-.16.14-.32.21-.49.05-.13.1-.26.14-.39.05-.15.11-.31.15-.46.05-.16.08-.32.12-.48.03-.14.07-.28.1-.42.04-.19.06-.39.09-.59.02-.12.04-.23.05-.35.05-.32.07-.64.07-.97 0-5.52-4.48-10-10-10zm0 18a7.94 7.94 0 01-6.15-2.89c.84-.44 1.86-.82 2.67-1.19 1.45-.65 1.3-1.05 1.35-1.59.01-.07.01-.14.01-.21-.51-.45-.93-1.08-1.2-1.8l-.01-.01c0-.01-.01-.02-.01-.03a4.42 4.42 0 01-.15-.48c-.33-.07-.53-.44-.61-.79-.08-.14-.23-.48-.2-.87.05-.51.26-.74.49-.83v-.08c0-.63.06-1.55.17-2.15.02-.17.06-.33.11-.5.21-.73.66-1.4 1.26-1.86.62-.47 1.5-.72 2.28-.72.78 0 1.65.25 2.27.73.6.46 1.05 1.12 1.26 1.86.05.16.08.33.11.5.11.6.17 1.51.17 2.15v.09c.22.1.42.33.46.82.04.39-.12.73-.2.87-.07.34-.27.71-.6.78-.04.16-.09.33-.15.48 0 .01-.02.05-.02.05-.26.71-.67 1.33-1.17 1.78 0 .08.01.16.01.23.05.54-.15.94 1.31 1.59.81.36 1.84.74 2.68 1.19A7.958 7.958 0 0110 18z"],variable:["M4.93 3.79a9.1 9.1 0 012.2-2.27L7.29 1c-1.38.59-2.57 1.33-3.55 2.22C2.46 4.39 1.49 5.72.83 7.23.28 8.51 0 9.81 0 11.12c0 2.28.83 4.57 2.49 6.86l.16-.55c-.49-1.23-.73-2.38-.73-3.44 0-1.67.28-3.46.84-5.36.55-1.9 1.28-3.51 2.17-4.84zm9.38 8.39l-.33-.2c-.37.54-.65.87-.82 1a.74.74 0 01-.42.12c-.19 0-.38-.12-.57-.37-.31-.42-.73-1.59-1.26-3.5.47-.85.86-1.41 1.19-1.67.23-.19.48-.29.74-.29.1 0 .28.04.53.11.26.07.48.11.68.11.27 0 .5-.1.68-.29.18-.19.27-.44.27-.75 0-.33-.09-.58-.27-.77-.18-.19-.44-.29-.78-.29-.3 0-.59.07-.86.22s-.61.47-1.02.97c-.31.37-.77 1.02-1.37 1.94a9.683 9.683 0 00-1.24-3.14l-3.24.59-.06.36c.24-.05.44-.07.61-.07.32 0 .59.14.8.43.33.45.8 1.8 1.39 4.07-.47.64-.78 1.06-.96 1.26-.28.32-.52.53-.7.62-.14.08-.3.11-.48.11-.14 0-.36-.08-.67-.23-.21-.1-.4-.15-.57-.15-.31 0-.57.11-.78.32s-.31.48-.31.8c0 .31.09.55.28.75.19.19.44.29.76.29.31 0 .6-.07.87-.2s.61-.42 1.02-.86c.41-.44.98-1.13 1.7-2.08.28.9.52 1.56.72 1.97.2.41.44.71.7.89.26.18.59.27.99.27.38 0 .77-.14 1.17-.43.54-.36 1.07-1 1.61-1.91zM17.51 1l-.15.54c.49 1.24.73 2.39.73 3.45 0 1.43-.21 2.96-.63 4.6-.33 1.26-.75 2.45-1.27 3.55-.52 1.11-1.02 1.97-1.51 2.6-.49.62-1.09 1.2-1.8 1.72l-.17.53c1.38-.59 2.57-1.34 3.55-2.23 1.29-1.17 2.26-2.5 2.91-4 .55-1.28.83-2.59.83-3.91 0-2.27-.83-4.56-2.49-6.85z"],"vertical-bar-chart-asc":["M8 7H7c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zM3 9H2c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-9c0-.55-.45-1-1-1zm10-5h-1c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm5-4h-1c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1z"],"vertical-bar-chart-desc":["M3 0H2c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm5 4H7c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm5 3h-1c-.55 0-1 .45-1 1v11c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1zm5 2h-1c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h1c.55 0 1-.45 1-1v-9c0-.55-.45-1-1-1z"],"vertical-distribution":["M1 2h18c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1s.45 1 1 1zm2 5c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V8c0-.55-.45-1-1-1H3zm16 11H1c-.55 0-1 .45-1 1s.45 1 1 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],video:["M19 2H1c-.55 0-1 .45-1 1v14c0 .55.45 1 1 1h18c.55 0 1-.45 1-1V3c0-.55-.45-1-1-1zM7 14V6l6 4-6 4z"],virus:["M15.249 13.835l1.251 1.251.354-.354.087-.077a1 1 0 011.327 1.491l-2.122 2.122-.087.077a1 1 0 01-1.327-1.491l.354-.354-1.251-1.251A6.466 6.466 0 0111 16.424L10.999 18h.501a1 1 0 01.117 1.993L11.5 20h-3a1 1 0 01-.117-1.993L8.5 18h.499v-1.577a6.46 6.46 0 01-2.538-.97L5.414 16.5l.354.354a1 1 0 01-1.327 1.491l-.087-.077-2.122-2.122a1 1 0 011.327-1.491l.087.077.354.354.97-.97a6.472 6.472 0 01-1.384-3.057l-.025.002L2 11.06v.44a1 1 0 01-1.993.117L0 11.5v-3a1 1 0 011.993-.117L2 8.5v.56h1.567A6.471 6.471 0 014.97 5.883l-.971-.969-.353.354-.087.077a1 1 0 01-1.327-1.491l2.122-2.122.087-.077a1 1 0 011.327 1.491l-.354.353 1.047 1.048A6.46 6.46 0 019 3.577L9 2h-.5A1 1 0 018.383.007L8.5 0h3a1 1 0 01.117 1.993L11.5 2H11v1.577a6.466 6.466 0 012.838 1.176l.04-.046L15.086 3.5l-.353-.353a1 1 0 011.327-1.491l.087.077 2.122 2.122a1 1 0 01-1.327 1.491l-.087-.077-.354-.354-1.207 1.207-.046.041a6.467 6.467 0 011.16 2.733H18V8.5a1 1 0 011.993-.117L20 8.5v3a1 1 0 01-1.993.117L18 11.5v-.605h-1.561a6.466 6.466 0 01-1.19 2.94zM12.5 11a1.5 1.5 0 100 3 1.5 1.5 0 000-3zM8 6a2 2 0 100 4 2 2 0 000-4z"],"volume-down":["M15.92 3.93l-1.6 1.18A7.948 7.948 0 0116 10c0 1.84-.63 3.54-1.68 4.89l1.6 1.18A9.878 9.878 0 0018 10c0-2.29-.78-4.39-2.08-6.07zM11 3c-.28 0-.53.11-.71.29L7.59 6H3c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h4.59l2.71 2.71c.17.18.42.29.7.29.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"volume-off":["M14 3c-.28 0-.53.11-.71.29L10.59 6H6c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h4.59l2.71 2.71c.17.18.42.29.7.29.55 0 1-.45 1-1V4c0-.55-.45-1-1-1z"],"volume-up":["M9 3.43c-.28 0-.53.11-.71.29l-2.7 2.71H1c-.55 0-1 .45-1 1v6c0 .55.45 1 1 1h4.59l2.71 2.71a1.003 1.003 0 001.71-.71v-12c-.01-.55-.46-1-1.01-1zm8.31-1.56l-1.62 1.2C17.14 5.16 18 7.69 18 10.43s-.86 5.27-2.31 7.37l1.62 1.2C19 16.57 20 13.62 20 10.43c0-3.18-1-6.13-2.69-8.56zm-3.39 2.49l-1.6 1.18A7.948 7.948 0 0114 10.43c0 1.84-.63 3.54-1.68 4.89l1.6 1.18A9.94 9.94 0 0016 10.43c0-2.28-.78-4.38-2.08-6.07z"],walk:["M16 10h-2c-.23 0-.42-.09-.59-.21l-.01.01-1.69-1.27-.63 3.14 2.62 2.62c.19.18.3.43.3.71v4c0 .55-.45 1-1 1s-1-.45-1-1v-3.59L9.39 12.8l-2.45 6.55h-.01c-.14.38-.5.65-.93.65-.55 0-1-.45-1-1 0-.12.03-.24.07-.35h-.01L9.43 7h-2.9l-1.7 2.55-.01-.01c-.18.27-.47.46-.82.46-.55 0-1-.45-1-1 0-.21.08-.39.18-.54l-.01-.01 2-3 .02.01C5.36 5.19 5.65 5 6 5h4.18l.36-.96c-.33-.43-.54-.96-.54-1.54a2.5 2.5 0 015 0A2.5 2.5 0 0112.5 5c-.06 0-.12-.01-.18-.02l-.44 1.18L14.33 8H16c.55 0 1 .45 1 1s-.45 1-1 1z"],"warning-sign":["M19.86 17.52l.01-.01-9-16-.01.01C10.69 1.21 10.37 1 10 1s-.69.21-.86.52l-.01-.01-9 16 .01.01c-.08.14-.14.3-.14.48 0 .55.45 1 1 1h18c.55 0 1-.45 1-1 0-.18-.06-.34-.14-.48zM11 17H9v-2h2v2zm0-3H9V6h2v8z"],"waterfall-chart":["M13 7h2c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1h-2c-.55 0-1 .45-1 1v1c0 .55.45 1 1 1zm-9 8h1c.55 0 1-.45 1-1v-4c0-.55-.45-1-1-1H4c-.55 0-1 .45-1 1v4c0 .55.45 1 1 1zm4-6h2c.55 0 1-.45 1-1s-.45-1-1-1H8c-.55 0-1 .45-1 1s.45 1 1 1zm11-5h-1c-.55 0-1 .45-1 1v9c0 .55.45 1 1 1h1c.55 0 1-.45 1-1V5c0-.55-.45-1-1-1zm0 12H2V3c0-.55-.45-1-1-1s-1 .45-1 1v14a.998.998 0 001 1h18c.55 0 1-.45 1-1s-.45-1-1-1z"],waves:["M4.948 2.682a1 1 0 00-1.897.001l-.005.016-.027.074a6.05 6.05 0 01-.6 1.172C1.958 4.635 1.468 5 .999 5a1 1 0 000 2c1.457 0 2.442-1.027 3-1.825C4.558 5.973 5.543 7 7 7s2.442-1.027 3-1.825C10.558 5.973 11.543 7 13 7s2.442-1.027 3-1.825C16.558 5.973 17.544 7 19 7a1 1 0 100-2c-.47 0-.958-.365-1.418-1.055a6.048 6.048 0 01-.628-1.246l-.006-.016a1 1 0 00-1.896 0l-.006.016a5.868 5.868 0 01-.147.364c-.11.246-.272.568-.481.882C13.958 4.635 13.469 5 13 5c-.47 0-.958-.365-1.418-1.055a6.048 6.048 0 01-.628-1.246l-.006-.016a1 1 0 00-1.897 0l-.005.016-.027.074a6.05 6.05 0 01-.6 1.172C7.958 4.635 7.468 5 6.999 5c-.47 0-.958-.365-1.418-1.055A6.05 6.05 0 014.954 2.7l-.006-.016v-.001zm0 6a1 1 0 00-1.897.001l-.005.016-.027.074a6.05 6.05 0 01-.6 1.172c-.46.69-.95 1.055-1.419 1.055a1 1 0 100 2c1.457 0 2.442-1.027 3-1.825C4.558 11.973 5.543 13 7 13s2.442-1.027 3-1.825c.558.798 1.543 1.825 3 1.825s2.442-1.027 3-1.825c.558.798 1.544 1.825 3 1.825a1 1 0 100-2c-.47 0-.958-.365-1.418-1.055a6.048 6.048 0 01-.628-1.246l-.006-.016a1 1 0 00-1.896 0l-.006.016a5.868 5.868 0 01-.147.364c-.11.246-.272.568-.481.882-.46.69-.949 1.055-1.418 1.055-.47 0-.958-.365-1.418-1.055a6.048 6.048 0 01-.628-1.246l-.006-.016a1 1 0 00-1.897 0l-.005.016-.027.074a6.05 6.05 0 01-.6 1.172c-.46.69-.95 1.055-1.419 1.055-.47 0-.958-.365-1.418-1.055A6.05 6.05 0 014.954 8.7l-.006-.016zm-1.896-6zm1.896 12l.006.017.027.074a6.053 6.053 0 00.6 1.172c.46.69.95 1.055 1.419 1.055.47 0 .958-.365 1.418-1.055a6.053 6.053 0 00.628-1.246l.005-.016a1 1 0 011.897 0l.006.016.027.074a6.051 6.051 0 00.6 1.172c.46.69.95 1.055 1.419 1.055.47 0 .958-.365 1.418-1.055a6.051 6.051 0 00.628-1.246l.006-.016a1 1 0 011.896 0l.006.016.027.074a6.051 6.051 0 00.6 1.172c.46.69.95 1.055 1.419 1.055a1 1 0 110 2c-1.456 0-2.442-1.027-3-1.825-.558.798-1.543 1.825-3 1.825s-2.442-1.027-3-1.825C9.442 17.973 8.457 19 7 19s-2.442-1.027-3-1.825C3.442 17.973 2.457 19 1 19a1 1 0 110-2c.47 0 .958-.365 1.418-1.055a6.053 6.053 0 00.628-1.246l.005-.016a1 1 0 011.897-.001z"],widget:["M18 4c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zM2 16c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm15-1h2V5h-2v10zM3 5H1v10h2V5zM2 0C.9 0 0 .9 0 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm3 3h10V1H5v2zm13 13c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zM5 19h10v-2H5v2z"],"widget-button":["M1 4h18c.55 0 1 .45 1 1v10c0 .55-.45 1-1 1H1c-.55 0-1-.45-1-1V5c0-.55.45-1 1-1zm1 2v8h16V6H2zm4 5c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm4 0c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm4 0c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"],"widget-footer":["M17 0H3c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H4v-4h12v4zm0-5H4V2h12v11z"],"widget-header":["M17 0H3c-.55 0-1 .45-1 1v18c0 .55.45 1 1 1h14c.55 0 1-.45 1-1V1c0-.55-.45-1-1-1zm-1 18H4V7h12v11zm0-12H4V2h12v4z"],wind:["M12 6a3 3 0 113 3H4a1 1 0 000 2h11a5 5 0 10-5-5 1 1 0 102 0zM1 12a1 1 0 100 2h10a2 2 0 110 4c-.934 0-1.803-.614-2.057-1.333a1 1 0 10-1.886.666C7.627 18.944 9.321 20 11 20a4 4 0 000-8H1z"],wrench:["M19.8 4.44L16.13 8.1l-3.55-.71-.71-3.53L15.54.21c-2.01-.53-4.23-.03-5.8 1.53-1.86 1.85-2.23 4.6-1.14 6.83L.59 16.59C.22 16.95 0 17.45 0 18a2 2 0 002 2c.55 0 1.05-.22 1.41-.59l8.03-8.04c2.23 1.05 4.97.67 6.82-1.16 1.57-1.56 2.07-3.77 1.54-5.77z"],"zoom-in":["M19.56 17.44l-4.94-4.94A8.004 8.004 0 0016 8c0-4.42-3.58-8-8-8S0 3.58 0 8s3.58 8 8 8c1.67 0 3.21-.51 4.5-1.38l4.94 4.94a1.498 1.498 0 102.12-2.12zM8 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6zm3-7H9V5c0-.55-.45-1-1-1s-1 .45-1 1v2H5c-.55 0-1 .45-1 1s.45 1 1 1h2v2c0 .55.45 1 1 1s1-.45 1-1V9h2c.55 0 1-.45 1-1s-.45-1-1-1z"],"zoom-out":["M11 7H5c-.55 0-1 .45-1 1s.45 1 1 1h6c.55 0 1-.45 1-1s-.45-1-1-1zm8.56 10.44l-4.94-4.94A8.004 8.004 0 0016 8c0-4.42-3.58-8-8-8S0 3.58 0 8s3.58 8 8 8c1.67 0 3.21-.51 4.5-1.38l4.94 4.94a1.498 1.498 0 102.12-2.12zM8 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6z"],"zoom-to-fit":["M1 7c.55 0 1-.45 1-1V2h4c.55 0 1-.45 1-1s-.45-1-1-1H1C.45 0 0 .45 0 1v5c0 .55.45 1 1 1zm5 1a1.003 1.003 0 00-1.71-.71l-2 2c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l2 2a1.003 1.003 0 001.42-1.42L4.41 10 5.7 8.71c.19-.18.3-.43.3-.71zm2-2c.28 0 .53-.11.71-.29L10 4.41l1.29 1.29c.18.19.43.3.71.3a1.003 1.003 0 00.71-1.71l-2-2C10.53 2.11 10.28 2 10 2s-.53.11-.71.29l-2 2A1.003 1.003 0 008 6zM6 18H2v-4c0-.55-.45-1-1-1s-1 .45-1 1v5c0 .55.45 1 1 1h5c.55 0 1-.45 1-1s-.45-1-1-1zm8-6a1.003 1.003 0 001.71.71l2-2c.18-.18.29-.43.29-.71 0-.28-.11-.53-.29-.71l-2-2a1.003 1.003 0 00-1.42 1.42l1.3 1.29-1.29 1.29c-.19.18-.3.43-.3.71zm5-12h-5c-.55 0-1 .45-1 1s.45 1 1 1h4v4c0 .55.45 1 1 1s1-.45 1-1V1c0-.55-.45-1-1-1zm-7 14c-.28 0-.53.11-.71.29L10 15.59 8.71 14.3A.965.965 0 008 14a1.003 1.003 0 00-.71 1.71l2 2c.18.18.43.29.71.29s.53-.11.71-.29l2-2A1.003 1.003 0 0012 14zm7-1c-.55 0-1 .45-1 1v4h-4c-.55 0-1 .45-1 1s.45 1 1 1h5c.55 0 1-.45 1-1v-5c0-.55-.45-1-1-1z"]}},function(e,t,n){"use strict";var r=n(393);e.exports=function(){return r()&&!!Symbol.toStringTag}},function(e,t,n){"use strict";var r=n(732);e.exports=Function.prototype.bind||r},function(e,t,n){"use strict";var r=n(175),i=n(395),o=i("%Function.prototype.apply%"),a=i("%Function.prototype.call%"),s=i("%Reflect.apply%",!0)||r.call(a,o),l=i("%Object.getOwnPropertyDescriptor%",!0),c=i("%Object.defineProperty%",!0),u=i("%Math.max%");if(c)try{c({},"a",{value:1})}catch(e){c=null}e.exports=function(e){var t=s(r,a,arguments);if(l&&c){var n=l(t,"length");n.configurable&&c(t,"length",{value:1+u(0,e.length-(arguments.length-1))})}return t};var d=function(){return s(r,o,arguments)};c?c(e.exports,"apply",{value:d}):e.exports.apply=d},function(e,t,n){var r=n(94)(n(67),"Map");e.exports=r},function(e,t,n){var r=n(67).Symbol;e.exports=r},function(e,t){var n=Array.isArray;e.exports=n},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.retryAfter=t.handleRetriesFor=void 0,t.handleRetriesFor=function(e){return new Promise((function t(n,r){try{n(e())}catch(e){e.retry&&e.retry instanceof Promise?e.retry.then((function(){return t(n,r)})).catch((function(e){return r(e)})):e.restart&&e.restart.isCallback?MathJax.Callback.After((function(){return t(n,r)}),e.restart):r(e)}}))},t.retryAfter=function(e){var t=new Error("MathJax retry");throw t.retry=e,t}},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractFactory=void 0;var a=function(){function e(e){var t,n;void 0===e&&(e=null),this.defaultKind="unknown",this.nodeMap=new Map,this.node={},null===e&&(e=this.constructor.defaultNodes);try{for(var i=r(Object.keys(e)),o=i.next();!o.done;o=i.next()){var a=o.value;this.setNodeClass(a,e[a])}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}}return e.prototype.create=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return(this.node[e]||this.node[this.defaultKind]).apply(void 0,o([],i(t)))},e.prototype.setNodeClass=function(e,t){this.nodeMap.set(e,t);var n=this,r=this.nodeMap.get(e);this.node[e]=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return new(r.bind.apply(r,o([void 0,n],i(e))))}},e.prototype.getNodeClass=function(e){return this.nodeMap.get(e)},e.prototype.deleteNodeClass=function(e){this.nodeMap.delete(e),delete this.node[e]},e.prototype.nodeIsKind=function(e,t){return e instanceof this.getNodeClass(t)},e.prototype.getKinds=function(){return Array.from(this.nodeMap.keys())},e.defaultNodes={},e}();t.AbstractFactory=a},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.NodeFactory=void 0;var o=n(39),a=function(){function e(){this.mmlFactory=null,this.factory={node:e.createNode,token:e.createToken,text:e.createText,error:e.createError}}return e.createNode=function(e,t,n,r,i){void 0===n&&(n=[]),void 0===r&&(r={});var a=e.mmlFactory.create(t);return a.setChildren(n),i&&a.appendChild(i),o.default.setProperties(a,r),a},e.createToken=function(e,t,n,r){void 0===n&&(n={}),void 0===r&&(r="");var i=e.create("text",r);return e.create("node",t,[],n,i)},e.createText=function(e,t){return null==t?null:e.mmlFactory.create("text").setText(t)},e.createError=function(e,t){var n=e.create("text",t),r=e.create("node","mtext",[],{},n);return e.create("node","merror",[r],{"data-mjx-error":t})},e.prototype.setMmlFactory=function(e){this.mmlFactory=e},e.prototype.set=function(e,t){this.factory[e]=t},e.prototype.setCreators=function(e){for(var t in e)this.set(t,e[t])},e.prototype.create=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];var o=this.factory[e]||this.factory.node,a=o.apply(void 0,i([this,t[0]],r(t.slice(1))));return"node"===e&&this.configuration.addNode(t[0],a),a},e.prototype.get=function(e){return this.factory[e]},e}();t.NodeFactory=a},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.BaseConfiguration=t.BaseTags=t.Other=void 0;var s=n(29),l=n(136),c=n(31),u=n(39),d=n(28),h=n(68),p=n(72);n(827);var f=n(417);function m(e,t){var n=e.stack.env.font?{mathvariant:e.stack.env.font}:{},r=l.MapHandler.getMap("remap").lookup(t),i=f.getRange(t),o=i?i[3]:"mo",a=e.create("token",o,n,r?r.char:t);"mo"===o&&(u.default.setProperty(a,"fixStretchy",!0),e.configuration.addNode("fixStretchy",a)),e.Push(a)}new d.CharacterMap("remap",null,{"-":"−","*":"∗","`":"‘"}),t.Other=m;var g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(p.AbstractTags);t.BaseTags=g,t.BaseConfiguration=s.Configuration.create("base",{handler:{character:["command","special","letter","digit"],delimiter:["delimiter"],macro:["delimiter","macros","mathchar0mi","mathchar0mo","mathchar7"],environment:["environment"]},fallback:{character:m,macro:function(e,t){throw new c.default("UndefinedControlSequence","Undefined control sequence %1","\\"+t)},environment:function(e,t){throw new c.default("UnknownEnv","Unknown environment '%1'",t)}},items:(i={},i[h.StartItem.prototype.kind]=h.StartItem,i[h.StopItem.prototype.kind]=h.StopItem,i[h.OpenItem.prototype.kind]=h.OpenItem,i[h.CloseItem.prototype.kind]=h.CloseItem,i[h.PrimeItem.prototype.kind]=h.PrimeItem,i[h.SubsupItem.prototype.kind]=h.SubsupItem,i[h.OverItem.prototype.kind]=h.OverItem,i[h.LeftItem.prototype.kind]=h.LeftItem,i[h.Middle.prototype.kind]=h.Middle,i[h.RightItem.prototype.kind]=h.RightItem,i[h.BeginItem.prototype.kind]=h.BeginItem,i[h.EndItem.prototype.kind]=h.EndItem,i[h.StyleItem.prototype.kind]=h.StyleItem,i[h.PositionItem.prototype.kind]=h.PositionItem,i[h.CellItem.prototype.kind]=h.CellItem,i[h.MmlItem.prototype.kind]=h.MmlItem,i[h.FnItem.prototype.kind]=h.FnItem,i[h.NotItem.prototype.kind]=h.NotItem,i[h.NonscriptItem.prototype.kind]=h.NonscriptItem,i[h.DotsItem.prototype.kind]=h.DotsItem,i[h.ArrayItem.prototype.kind]=h.ArrayItem,i[h.EqnArrayItem.prototype.kind]=h.EqnArrayItem,i[h.EquationItem.prototype.kind]=h.EquationItem,i),options:{maxMacros:1e3,baseURL:"undefined"==typeof document||0===document.getElementsByTagName("base").length?"":String(document.location).replace(/#.*$/,"")},tags:{base:g},postprocessors:[[function(e){var t,n,r=e.data;try{for(var i=a(r.getList("nonscript")),o=i.next();!o.done;o=i.next()){var s=o.value;if(s.attributes.get("scriptlevel")>0){var l=s.parent;if(l.childNodes.splice(l.childIndex(s),1),r.removeFromList(s.kind,[s]),s.isKind("mrow")){var c=s.childNodes[0];r.removeFromList("mstyle",[c]),r.removeFromList("mspace",c.childNodes[0].childNodes)}}else s.isKind("mrow")&&(s.parent.replaceChild(s.childNodes[0],s),r.removeFromList("mrow",[s]))}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},-4]]})},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonArrow=t.CommonDiagonalArrow=t.CommonDiagonalStrike=t.CommonBorder2=t.CommonBorder=t.arrowBBox=t.diagonalArrowDef=t.arrowDef=t.arrowBBoxW=t.arrowBBoxHD=t.arrowHead=t.fullBorder=t.fullPadding=t.fullBBox=t.sideNames=t.sideIndex=t.SOLID=t.PADDING=t.THICKNESS=t.ARROWY=t.ARROWDX=t.ARROWX=void 0,t.ARROWX=4,t.ARROWDX=1,t.ARROWY=2,t.THICKNESS=.067,t.PADDING=.2,t.SOLID=t.THICKNESS+"em solid",t.sideIndex={top:0,right:1,bottom:2,left:3},t.sideNames=Object.keys(t.sideIndex),t.fullBBox=function(e){return new Array(4).fill(e.thickness+e.padding)},t.fullPadding=function(e){return new Array(4).fill(e.padding)},t.fullBorder=function(e){return new Array(4).fill(e.thickness)};t.arrowHead=function(e){return Math.max(e.padding,e.thickness*(e.arrowhead.x+e.arrowhead.dx+1))};t.arrowBBoxHD=function(e,t){if(e.childNodes[0]){var n=e.childNodes[0].getBBox(),r=n.h,i=n.d;t[0]=t[2]=Math.max(0,e.thickness*e.arrowhead.y-(r+i)/2)}return t};t.arrowBBoxW=function(e,t){if(e.childNodes[0]){var n=e.childNodes[0].getBBox().w;t[1]=t[3]=Math.max(0,e.thickness*e.arrowhead.y-n/2)}return t},t.arrowDef={up:[-Math.PI/2,!1,!0,"verticalstrike"],down:[Math.PI/2,!1,!0,"verticakstrike"],right:[0,!1,!1,"horizontalstrike"],left:[Math.PI,!1,!1,"horizontalstrike"],updown:[Math.PI/2,!0,!0,"verticalstrike uparrow downarrow"],leftright:[0,!0,!1,"horizontalstrike leftarrow rightarrow"]},t.diagonalArrowDef={updiagonal:[-1,0,!1,"updiagonalstrike northeastarrow"],northeast:[-1,0,!1,"updiagonalstrike updiagonalarrow"],southeast:[1,0,!1,"downdiagonalstrike"],northwest:[1,Math.PI,!1,"downdiagonalstrike"],southwest:[-1,Math.PI,!1,"updiagonalstrike"],northeastsouthwest:[-1,0,!0,"updiagonalstrike northeastarrow updiagonalarrow southwestarrow"],northwestsoutheast:[1,0,!0,"downdiagonalstrike northwestarrow southeastarrow"]},t.arrowBBox={up:function(e){return t.arrowBBoxW(e,[t.arrowHead(e),0,e.padding,0])},down:function(e){return t.arrowBBoxW(e,[e.padding,0,t.arrowHead(e),0])},right:function(e){return t.arrowBBoxHD(e,[0,t.arrowHead(e),0,e.padding])},left:function(e){return t.arrowBBoxHD(e,[0,e.padding,0,t.arrowHead(e)])},updown:function(e){return t.arrowBBoxW(e,[t.arrowHead(e),0,t.arrowHead(e),0])},leftright:function(e){return t.arrowBBoxHD(e,[0,t.arrowHead(e),0,t.arrowHead(e)])}};t.CommonBorder=function(e){return function(n){var r=t.sideIndex[n];return[n,{renderer:e,bbox:function(e){var t=[0,0,0,0];return t[r]=e.thickness+e.padding,t},border:function(e){var t=[0,0,0,0];return t[r]=e.thickness,t}}]}};t.CommonBorder2=function(e){return function(n,r,i){var o=t.sideIndex[r],a=t.sideIndex[i];return[n,{renderer:e,bbox:function(e){var t=e.thickness+e.padding,n=[0,0,0,0];return n[o]=n[a]=t,n},border:function(e){var t=[0,0,0,0];return t[o]=t[a]=e.thickness,t},remove:r+" "+i}]}};t.CommonDiagonalStrike=function(e){return function(n){var r="mjx-"+n.charAt(0)+"strike";return[n+"diagonalstrike",{renderer:e(r),bbox:t.fullBBox}]}};t.CommonDiagonalArrow=function(e){return function(n){var i=r(t.diagonalArrowDef[n],4),o=i[0],a=i[1],s=i[2];return[n+"arrow",{renderer:function(t,n){var i=r(t.arrowAW(),2),l=i[0],c=i[1],u=t.arrow(c,o*(l-a),s);e(t,u)},bbox:function(e){var t=e.arrowData(),n=t.a,i=t.x,o=t.y,a=r([e.arrowhead.x,e.arrowhead.y,e.arrowhead.dx],3),s=a[0],l=a[1],c=a[2],u=r(e.getArgMod(s+c,l),2),d=u[0],h=u[1],p=o+(d>n?e.thickness*h*Math.sin(d-n):0),f=i+(d>Math.PI/2-n?e.thickness*h*Math.sin(d+n-Math.PI/2):0);return[p,f,p,f]},remove:i[3]}]}};t.CommonArrow=function(e){return function(n){var i=r(t.arrowDef[n],4),o=i[0],a=i[1],s=i[2],l=i[3];return[n+"arrow",{renderer:function(t,n){var i=t.getBBox(),l=i.w,c=i.h,u=i.d,d=r(s?[c+u,"X"]:[l,"Y"],2),h=d[0],p=d[1],f=t.getOffset(p),m=t.arrow(h,o,a,p,f);e(t,m)},bbox:t.arrowBBox[n],remove:l}]}}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmsubsup=t.CHTMLmsup=t.CHTMLmsub=void 0;var a=n(862),s=n(186),l=n(186),c=n(186),u=n(187),d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=u.MmlMsub.prototype.kind,t}(s.CommonMsubMixin(a.CHTMLscriptbase));t.CHTMLmsub=d;var h=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=u.MmlMsup.prototype.kind,t}(l.CommonMsupMixin(a.CHTMLscriptbase));t.CHTMLmsup=h;var p=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.adaptor,n=this.standardCHTMLnode(e),r=o([this.baseChild,this.supChild,this.subChild],3),i=r[0],a=r[1],s=r[2],l=o(this.getUVQ(),3),c=l[1],u=l[2],d={"vertical-align":this.em(c)};i.toCHTML(n);var h=t.append(n,this.html("mjx-script",{style:d}));a.toCHTML(h),t.append(h,this.html("mjx-spacer",{style:{"margin-top":this.em(u)}})),s.toCHTML(h);var p=this.getAdjustedIc();p&&t.setStyle(a.chtml,"marginLeft",this.em(p/a.bbox.rscale)),this.baseRemoveIc&&t.setStyle(h,"marginLeft",this.em(-this.baseIc))},t.kind=u.MmlMsubsup.prototype.kind,t.styles={"mjx-script":{display:"inline-block","padding-right":".05em","padding-left":".033em"},"mjx-script > *":{display:"block"}},t}(c.CommonMsubsupMixin(a.CHTMLscriptbase));t.CHTMLmsubsup=p},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMsubsupMixin=t.CommonMsupMixin=t.CommonMsubMixin=void 0,t.CommonMsubMixin=function(e){var t;return(t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"scriptChild",{get:function(){return this.childNodes[this.node.sub]},enumerable:!1,configurable:!0}),t.prototype.getOffset=function(){return[0,-this.getV()]},t}(e)).useIC=!1,t},t.CommonMsupMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"scriptChild",{get:function(){return this.childNodes[this.node.sup]},enumerable:!1,configurable:!0}),t.prototype.getOffset=function(){return[this.getAdjustedIc()-(this.baseRemoveIc?0:this.baseIc),this.getU()]},t}(e)},t.CommonMsubsupMixin=function(e){var t;return(t=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.UVQ=null,t}return i(t,e),Object.defineProperty(t.prototype,"subChild",{get:function(){return this.childNodes[this.node.sub]},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"supChild",{get:function(){return this.childNodes[this.node.sup]},enumerable:!1,configurable:!0}),t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.baseChild.getBBox(),r=o([this.subChild.getBBox(),this.supChild.getBBox()],2),i=r[0],a=r[1];e.empty(),e.append(n);var s=this.getBaseWidth(),l=this.getAdjustedIc(),c=o(this.getUVQ(),2),u=c[0],d=c[1];e.combine(i,s,d),e.combine(a,s+l,u),e.w+=this.font.params.scriptspace,e.clean(),this.setChildPWidths(t)},t.prototype.getUVQ=function(e,t){void 0===e&&(e=this.subChild.getBBox()),void 0===t&&(t=this.supChild.getBBox());var n=this.baseCore.getBBox();if(this.UVQ)return this.UVQ;var r=this.font.params,i=3*r.rule_thickness,a=this.length2em(this.node.attributes.get("subscriptshift"),r.sub2),s=this.baseCharZero(n.d*this.baseScale+r.sub_drop*e.rscale),l=o([this.getU(),Math.max(s,a)],2),c=l[0],u=l[1],d=c-t.d*t.rscale-(e.h*e.rscale-u);if(d<i){u+=i-d;var h=.8*r.x_height-(c-t.d*t.rscale);h>0&&(c+=h,u-=h)}return c=Math.max(this.length2em(this.node.attributes.get("superscriptshift"),c),c),u=Math.max(this.length2em(this.node.attributes.get("subscriptshift"),u),u),d=c-t.d*t.rscale-(e.h*e.rscale-u),this.UVQ=[c,-u,d],this.UVQ},t}(e)).useIC=!1,t}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMsup=t.MmlMsub=t.MmlMsubsup=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"msubsup"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 3},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"base",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"sub",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"sup",{get:function(){return 2},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i=this.childNodes;i[0].setInheritedAttributes(e,t,n,r),i[1].setInheritedAttributes(e,!1,n+1,r||1===this.sub),i[2]&&i[2].setInheritedAttributes(e,!1,n+1,r||2===this.sub)},t.defaults=o(o({},a.AbstractMmlBaseNode.defaults),{subscriptshift:"",superscriptshift:""}),t}(a.AbstractMmlBaseNode);t.MmlMsubsup=s;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"msub"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),t.defaults=o({},s.defaults),t}(s);t.MmlMsub=l;var c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"msup"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"sup",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"sub",{get:function(){return 2},enumerable:!1,configurable:!0}),t.defaults=o({},s.defaults),t}(s);t.MmlMsup=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMunderoverMixin=t.CommonMoverMixin=t.CommonMunderMixin=void 0,t.CommonMunderMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.stretchChildren(),r}return i(t,e),Object.defineProperty(t.prototype,"scriptChild",{get:function(){return this.childNodes[this.node.under]},enumerable:!1,configurable:!0}),t.prototype.computeBBox=function(t,n){if(void 0===n&&(n=!1),this.hasMovableLimits())e.prototype.computeBBox.call(this,t,n);else{t.empty();var r=this.baseChild.getBBox(),i=this.scriptChild.getBBox(),a=this.getUnderKV(r,i)[1],s=this.isLineBelow?0:this.getDelta(!0),l=o(this.getDeltaW([r,i],[0,-s]),2),c=l[0],u=l[1];t.combine(r,c,0),t.combine(i,u,a),t.d+=this.font.params.big_op_spacing5,t.clean(),this.setChildPWidths(n)}},t}(e)},t.CommonMoverMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.stretchChildren(),r}return i(t,e),Object.defineProperty(t.prototype,"scriptChild",{get:function(){return this.childNodes[this.node.over]},enumerable:!1,configurable:!0}),t.prototype.computeBBox=function(t){if(this.hasMovableLimits())e.prototype.computeBBox.call(this,t);else{t.empty();var n=this.baseChild.getBBox(),r=this.scriptChild.getBBox(),i=this.getOverKU(n,r)[1],a=this.isLineAbove?0:this.getDelta(),s=o(this.getDeltaW([n,r],[0,a]),2),l=s[0],c=s[1];t.combine(n,l,0),t.combine(r,c,i),t.h+=this.font.params.big_op_spacing5,t.clean()}},t}(e)},t.CommonMunderoverMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.stretchChildren(),r}return i(t,e),Object.defineProperty(t.prototype,"underChild",{get:function(){return this.childNodes[this.node.under]},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"overChild",{get:function(){return this.childNodes[this.node.over]},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"subChild",{get:function(){return this.underChild},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"supChild",{get:function(){return this.overChild},enumerable:!1,configurable:!0}),t.prototype.computeBBox=function(t){if(this.hasMovableLimits())e.prototype.computeBBox.call(this,t);else{t.empty();var n=this.overChild.getBBox(),r=this.baseChild.getBBox(),i=this.underChild.getBBox(),a=this.getOverKU(r,n)[1],s=this.getUnderKV(r,i)[1],l=this.getDelta(),c=o(this.getDeltaW([r,i,n],[0,this.isLineBelow?0:-l,this.isLineAbove?0:l]),3),u=c[0],d=c[1],h=c[2];t.combine(r,u,0),t.combine(n,h,a),t.combine(i,d,s);var p=this.font.params.big_op_spacing5;t.h+=p,t.d+=p,t.clean()}},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.clearDocument=t.saveDocument=t.makeBsprAttributes=t.removeProperty=t.getProperty=t.setProperty=t.balanceRules=void 0;var a=n(39),s=n(37),l=null,c=null,u=function(e){return c.root=e,l.outputJax.getBBox(c,l).w},d=function(e){for(var t=0;e&&!a.default.isType(e,"mtable");){if(a.default.isType(e,"text"))return null;a.default.isType(e,"mrow")?(e=e.childNodes[0],t=0):(e=e.parent.childNodes[t],t++)}return e},h=function(e,t){return e.childNodes["up"===t?1:0].childNodes[0].childNodes[0].childNodes[0].childNodes[0]},p=function(e,t){return e.childNodes[t].childNodes[0].childNodes[0]},f=function(e){return p(e,0)},m=function(e){return p(e,e.childNodes.length-1)},g=function(e,t){return e.childNodes["up"===t?0:1].childNodes[0].childNodes[0].childNodes[0]},v=function(e){for(;e&&!a.default.isType(e,"mtd");)e=e.parent;return e},y=function(e){return e.parent.childNodes[e.parent.childNodes.indexOf(e)+1]},_=function(e){for(;e&&null==t.getProperty(e,"inference");)e=e.parent;return e},b=function(e,t,n){void 0===n&&(n=!1);var r=0;if(e===t)return r;if(e!==t.parent){var i=e.childNodes,o=n?i.length-1:0;a.default.isType(i[o],"mspace")&&(r+=u(i[o])),e=t.parent}if(e===t)return r;var s=e.childNodes,l=n?s.length-1:0;return s[l]!==t&&(r+=u(s[l])),r},M=function(e,n){void 0===n&&(n=!1);var r=d(e),i=g(r,t.getProperty(r,"inferenceRule"));return b(e,r,n)+(u(r)-u(i))/2},w=function(e,n,r,i){if(void 0===i&&(i=!1),t.getProperty(n,"inferenceRule")||t.getProperty(n,"labelledRule")){var o=e.nodeFactory.create("node","mrow");n.parent.replaceChild(o,n),o.setChildren([n]),A(n,o),n=o}var l=i?n.childNodes.length-1:0,c=n.childNodes[l];a.default.isType(c,"mspace")?a.default.setAttribute(c,"width",s.default.Em(s.default.dimen2em(a.default.getAttribute(c,"width"))+r)):(c=e.nodeFactory.create("node","mspace",[],{width:s.default.Em(r)}),i?n.appendChild(c):(c.parent=n,n.childNodes.unshift(c)))},A=function(e,n){["inference","proof","maxAdjust","labelledRule"].forEach((function(r){var i=t.getProperty(e,r);null!=i&&(t.setProperty(n,r,i),t.removeProperty(e,r))}))},C=function(e,n,r,i,o){var a=e.nodeFactory.create("node","mspace",[],{width:s.default.Em(o)});if("left"===i){var l=n.childNodes[r].childNodes[0];a.parent=l,l.childNodes.unshift(a)}else n.childNodes[r].appendChild(a);t.setProperty(n.parent,"sequentAdjust_"+i,o)},x=function(e,n){for(var r=n.pop();n.length;){var o=n.pop(),a=i(E(r,o),2),s=a[0],l=a[1];t.getProperty(r.parent,"axiom")&&(C(e,s<0?r:o,0,"left",Math.abs(s)),C(e,l<0?r:o,2,"right",Math.abs(l))),r=o}},E=function(e,t){var n=u(e.childNodes[2]),r=u(t.childNodes[2]);return[u(e.childNodes[0])-u(t.childNodes[0]),n-r]};t.balanceRules=function(e){var n,r;c=new e.document.options.MathItem("",null,e.math.display);var i=e.data;!function(e){var n=e.nodeLists.sequent;if(n)for(var r=n.length-1,i=void 0;i=n[r];r--)if(t.getProperty(i,"sequentProcessed"))t.removeProperty(i,"sequentProcessed");else{var o=[],a=_(i);if(1===t.getProperty(a,"inference")){for(o.push(i);1===t.getProperty(a,"inference");){a=d(a);var s=f(h(a,t.getProperty(a,"inferenceRule"))),l=t.getProperty(s,"inferenceRule")?g(s,t.getProperty(s,"inferenceRule")):s;t.getProperty(l,"sequent")&&(i=l.childNodes[0],o.push(i),t.setProperty(i,"sequentProcessed",!0)),a=s}x(e,o)}}}(i);var a=i.nodeLists.inference||[];try{for(var s=o(a),l=s.next();!l.done;l=s.next()){var u=l.value,p=t.getProperty(u,"proof"),A=d(u),C=h(A,t.getProperty(A,"inferenceRule")),E=f(C);if(t.getProperty(E,"inference")){var L=M(E);if(L){w(i,E,-L);var S=b(u,A,!1);w(i,u,L-S)}}var T=m(C);if(null!=t.getProperty(T,"inference")){var O=M(T,!0);w(i,T,-O,!0);var I=b(u,A,!0),k=t.getProperty(u,"maxAdjust");null!=k&&(O=Math.max(O,k));var D=void 0;if(!p&&(D=v(u))){var N=y(D);if(N){var j=i.nodeFactory.create("node","mspace",[],{width:O-I+"em"});N.appendChild(j),u.removeProperty("maxAdjust")}else{var P=_(D);P&&(O=t.getProperty(P,"maxAdjust")?Math.max(t.getProperty(P,"maxAdjust"),O):O,t.setProperty(P,"maxAdjust",O))}}else w(i,t.getProperty(u,"proof")?u:u.parent,O-I,!0)}}}catch(e){n={error:e}}finally{try{l&&!l.done&&(r=s.return)&&r.call(s)}finally{if(n)throw n.error}}};var L=((r={}).bspr_maxAdjust=!0,r);t.setProperty=function(e,t,n){a.default.setProperty(e,"bspr_"+t,n)};t.getProperty=function(e,t){return a.default.getProperty(e,"bspr_"+t)};t.removeProperty=function(e,t){e.removeProperty("bspr_"+t)};t.makeBsprAttributes=function(e){e.data.root.walkTree((function(e,t){var n=[];e.getPropertyNames().forEach((function(t){!L[t]&&t.match(RegExp("^bspr_"))&&n.push(t+":"+e.getProperty(t))})),n.length&&a.default.setAttribute(e,"semantics",n.join(";"))}))};t.saveDocument=function(e){if(!("getBBox"in(l=e.document).outputJax))throw Error("The bussproofs extension requires an output jax with a getBBox() method")};t.clearDocument=function(e){l=null}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(31),i=n(28),o=n(57),a=n(37),s=n(137),l={NewCommand:function(e,t){var n=s.default.GetCsNameArgument(e,t),r=s.default.GetArgCount(e,t),i=e.GetBrackets(t),o=e.GetArgument(t);s.default.addMacro(e,n,l.Macro,[o,r,i])},NewEnvironment:function(e,t){var n=a.default.trimSpaces(e.GetArgument(t)),r=s.default.GetArgCount(e,t),i=e.GetBrackets(t),o=e.GetArgument(t),c=e.GetArgument(t);s.default.addEnvironment(e,n,l.BeginEnv,[!0,o,c,r,i])},MacroDef:function(e,t){var n=s.default.GetCSname(e,t),r=s.default.GetTemplate(e,t,"\\"+n),i=e.GetArgument(t);r instanceof Array?s.default.addMacro(e,n,l.MacroWithTemplate,[i].concat(r)):s.default.addMacro(e,n,l.Macro,[i,r])},Let:function(e,t){var n=s.default.GetCSname(e,t),r=e.GetNext();"="===r&&(e.i++,r=e.GetNext());var o=e.configuration.handlers;if("\\"!==r){e.i++;var a=o.get("delimiter").lookup(r);a?s.default.addDelimiter(e,"\\"+n,a.char,a.attributes):s.default.addMacro(e,n,l.Macro,[r])}else{t=s.default.GetCSname(e,t);var c=o.get("delimiter").lookup("\\"+t);if(c)return void s.default.addDelimiter(e,"\\"+n,c.char,c.attributes);var u=o.get("macro").applicable(t);if(!u)return;if(u instanceof i.MacroMap){var d=u.lookup(t);return void s.default.addMacro(e,n,d.func,d.args,d.symbol)}c=u.lookup(t);var h=s.default.disassembleSymbol(n,c);s.default.addMacro(e,n,(function(e,t){for(var n=[],r=2;r<arguments.length;r++)n[r-2]=arguments[r];var i=s.default.assembleSymbol(n);return u.parser(e,i)}),h)}},MacroWithTemplate:function(e,t,n,i){for(var o=[],l=4;l<arguments.length;l++)o[l-4]=arguments[l];var c=parseInt(i,10);if(c){var u=[];if(e.GetNext(),o[0]&&!s.default.MatchParam(e,o[0]))throw new r.default("MismatchUseDef","Use of %1 doesn't match its definition",t);for(var d=0;d<c;d++)u.push(s.default.GetParameter(e,t,o[d+1]));n=a.default.substituteArgs(e,u,n)}e.string=a.default.addArgs(e,n,e.string.slice(e.i)),e.i=0,a.default.checkMaxMacros(e)},BeginEnv:function(e,t,n,r,i,o){if(t.getProperty("end")&&e.stack.env.closing===t.getName()){delete e.stack.env.closing;var s=e.string.slice(e.i);return e.string=r,e.i=0,e.Parse(),e.string=s,e.i=0,e.itemFactory.create("end").setProperty("name",t.getName())}if(i){var l=[];if(null!=o){var c=e.GetBrackets("\\begin{"+t.getName()+"}");l.push(null==c?o:c)}for(var u=l.length;u<i;u++)l.push(e.GetArgument("\\begin{"+t.getName()+"}"));n=a.default.substituteArgs(e,l,n),r=a.default.substituteArgs(e,[],r)}return e.string=a.default.addArgs(e,n,e.string.slice(e.i)),e.i=0,e.itemFactory.create("beginEnv").setProperty("name",t.getName())}};l.Macro=o.default.Macro,t.default=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TextMacrosMethods=void 0;var r=n(49),i=n(180),o=n(57);t.TextMacrosMethods={Comment:function(e,t){for(;e.i<e.string.length&&"\n"!==e.string.charAt(e.i);)e.i++;e.i++},Math:function(e,t){e.saveText();for(var n,i,o=e.i,a=0;i=e.GetNext();)switch(n=e.i++,i){case"\\":")"===e.GetCS()&&(i="\\(");case"$":if(0===a&&t===i){var s=e.texParser.configuration,l=new r.default(e.string.substr(o,n-o),e.stack.env,s).mml();return void e.PushMath(l)}break;case"{":a++;break;case"}":0===a&&e.Error("ExtraCloseMissingOpen","Extra close brace or missing open brace"),a--}e.Error("MathNotTerminated","Math-mode is not properly terminated")},MathModeOnly:function(e,t){e.Error("MathModeOnly","'%1' allowed only in math mode",t)},Misplaced:function(e,t){e.Error("Misplaced","'%1' can not be used here",t)},OpenBrace:function(e,t){var n=e.stack.env;e.envStack.push(n),e.stack.env=Object.assign({},n)},CloseBrace:function(e,t){e.envStack.length?(e.saveText(),e.stack.env=e.envStack.pop()):e.Error("ExtraCloseMissingOpen","Extra close brace or missing open brace")},OpenQuote:function(e,t){e.string.charAt(e.i)===t?(e.text+="“",e.i++):e.text+="‘"},CloseQuote:function(e,t){e.string.charAt(e.i)===t?(e.text+="”",e.i++):e.text+="’"},Tilde:function(e,t){e.text+=" "},Space:function(e,t){for(e.text+=" ";e.GetNext().match(/\s/);)e.i++},SelfQuote:function(e,t){e.text+=t.substr(1)},Insert:function(e,t,n){e.text+=n},Accent:function(e,t,n){var r=e.ParseArg(t),i=e.create("token","mo",{},n);e.addAttributes(i),e.Push(e.create("node","mover",[r,i]))},Emph:function(e,t){var n="-tex-mathit"===e.stack.env.mathvariant?"normal":"-tex-mathit";e.Push(e.ParseTextArg(t,{mathvariant:n}))},SetFont:function(e,t,n){e.saveText(),e.stack.env.mathvariant=n},SetSize:function(e,t,n){e.saveText(),e.stack.env.mathsize=n},CheckAutoload:function(e,t){var n=e.configuration.packageData.get("autoload"),r=e.texParser;t=t.slice(1);var o=r.lookup("macro",t);if(!o||n&&o._func===n.Autoload){if(r.parse("macro",[r,t]),!o)return;i.retryAfter(Promise.resolve())}r.parse("macro",[e,t])},Macro:o.default.Macro,Spacer:o.default.Spacer,Hskip:o.default.Hskip,rule:o.default.rule,Rule:o.default.Rule,HandleRef:o.default.HandleRef}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0}),t.KernelConnection=void 0;const a=n(12),s=n(6),l=n(4),c=n(38),u=n(626),d=o(n(120)),h=n(627),p=o(n(628)),f=o(n(153)),m=n(154),g=o(n(152));class v{constructor(e){var t,n,r,i;this._createSocket=()=>{this._errorIfDisposed(),this._clearSocket(),this._updateConnectionStatus("connecting");const e=this.serverSettings,t=a.URLExt.join(e.wsUrl,g.KERNEL_SERVICE_URL,encodeURIComponent(this._id)),n=t.replace(/^((?:\w+:)?\/\/)(?:[^@\/]+@)/,"$1");console.debug("Starting WebSocket: "+n);let r=a.URLExt.join(t,"channels?session_id="+encodeURIComponent(this._clientId));const i=e.token;e.appendToken&&""!==i&&(r=r+"&token="+encodeURIComponent(i)),this._ws=new e.WebSocket(r),this._ws.binaryType="arraybuffer",this._ws.onmessage=this._onWSMessage,this._ws.onopen=this._onWSOpen,this._ws.onclose=this._onWSClose,this._ws.onerror=this._onWSClose},this._onWSOpen=e=>{this._updateConnectionStatus("connected")},this._onWSMessage=e=>{let t;try{t=p.deserialize(e.data),f.validateMessage(t)}catch(e){throw e.message="Kernel message validation error: "+e.message,e}this._kernelSession=t.header.session,this._msgChain=this._msgChain.then(()=>this._handleMessage(t)).catch(e=>{e.message.startsWith("Canceled future for ")&&console.error(e)}),this._anyMessage.emit({msg:t,direction:"recv"})},this._onWSClose=e=>{this.isDisposed||this._reconnect()},this._id="",this._name="",this._status="unknown",this._connectionStatus="connecting",this._kernelSession="",this._isDisposed=!1,this._ws=null,this._username="",this._reconnectLimit=7,this._reconnectAttempt=0,this._reconnectTimeout=null,this._futures=new Map,this._comms=new Map,this._targetRegistry=Object.create(null),this._info=new s.PromiseDelegate,this._pendingMessages=[],this._statusChanged=new l.Signal(this),this._connectionStatusChanged=new l.Signal(this),this._disposed=new l.Signal(this),this._iopubMessage=new l.Signal(this),this._anyMessage=new l.Signal(this),this._pendingInput=new l.Signal(this),this._unhandledMessage=new l.Signal(this),this._displayIdToParentIds=new Map,this._msgIdToDisplayIds=new Map,this._msgChain=Promise.resolve(),this._hasPendingInput=!1,this._noOp=()=>{},this._name=e.model.name,this._id=e.model.id,this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:c.ServerConnection.makeSettings(),this._clientId=null!==(n=e.clientId)&&void 0!==n?n:s.UUID.uuid4(),this._username=null!==(r=e.username)&&void 0!==r?r:"",this.handleComms=null===(i=e.handleComms)||void 0===i||i,this._createSocket()}get disposed(){return this._disposed}get statusChanged(){return this._statusChanged}get connectionStatusChanged(){return this._connectionStatusChanged}get iopubMessage(){return this._iopubMessage}get unhandledMessage(){return this._unhandledMessage}get model(){return{id:this.id,name:this.name}}get anyMessage(){return this._anyMessage}get pendingInput(){return this._pendingInput}get id(){return this._id}get name(){return this._name}get username(){return this._username}get clientId(){return this._clientId}get status(){return this._status}get connectionStatus(){return this._connectionStatus}get isDisposed(){return this._isDisposed}get info(){return this._info.promise}get spec(){return this._specPromise||(this._specPromise=m.KernelSpecAPI.getSpecs(this.serverSettings).then(e=>e.kernelspecs[this._name])),this._specPromise}clone(e={}){return new v(Object.assign({model:this.model,username:this.username,serverSettings:this.serverSettings,handleComms:!1},e))}dispose(){this.isDisposed||(this._isDisposed=!0,this._disposed.emit(),this._updateConnectionStatus("disconnected"),this._clearKernelState(),this._pendingMessages=[],this._clearSocket(),l.Signal.clearData(this))}sendShellMessage(e,t=!1,n=!0){return this._sendKernelShellControl(h.KernelShellFutureHandler,e,t,n)}sendControlMessage(e,t=!1,n=!0){return this._sendKernelShellControl(h.KernelControlFutureHandler,e,t,n)}_sendKernelShellControl(e,t,n=!1,r=!0){this._sendMessage(t),this._anyMessage.emit({msg:t,direction:"send"});const i=new e(()=>{const e=t.header.msg_id;this._futures.delete(e);const n=this._msgIdToDisplayIds.get(e);n&&(n.forEach(t=>{const n=this._displayIdToParentIds.get(t);if(n){const r=n.indexOf(e);if(-1===r)return;1===n.length?this._displayIdToParentIds.delete(t):(n.splice(r,1),this._displayIdToParentIds.set(t,n))}}),this._msgIdToDisplayIds.delete(e))},t,n,r,this);return this._futures.set(t.header.msg_id,i),i}_sendMessage(e,t=!0){if("dead"===this.status)throw new Error("Kernel is dead");if((""===this._kernelSession||"_RESTARTING_"===this._kernelSession)&&d.isInfoRequestMsg(e)){if("connected"===this.connectionStatus)return void this._ws.send(p.serialize(e));throw new Error("Could not send message: status is not connected")}if(t&&this._pendingMessages.length>0)this._pendingMessages.push(e);else if("connected"===this.connectionStatus&&"_RESTARTING_"!==this._kernelSession)this._ws.send(p.serialize(e));else{if(!t)throw new Error("Could not send message");this._pendingMessages.push(e)}}async interrupt(){if(this.hasPendingInput=!1,"dead"===this.status)throw new Error("Kernel is dead");return g.interruptKernel(this.id,this.serverSettings)}async restart(){if("dead"===this.status)throw new Error("Kernel is dead");this._updateStatus("restarting"),this._clearKernelState(),this._kernelSession="_RESTARTING_",await g.restartKernel(this.id,this.serverSettings),await this.reconnect(),this.hasPendingInput=!1}reconnect(){this._errorIfDisposed();const e=new s.PromiseDelegate,t=(n,r)=>{"connected"===r?(e.resolve(),this.connectionStatusChanged.disconnect(t,this)):"disconnected"===r&&(e.reject(new Error("Kernel connection disconnected")),this.connectionStatusChanged.disconnect(t,this))};return this.connectionStatusChanged.connect(t,this),this._reconnectAttempt=0,this._reconnect(),e.promise}async shutdown(){"dead"!==this.status&&await g.shutdownKernel(this.id,this.serverSettings),this.handleShutdown()}handleShutdown(){this._updateStatus("dead"),this.dispose()}async requestKernelInfo(){const e=d.createMessage({msgType:"kernel_info_request",channel:"shell",username:this._username,session:this._clientId,content:{}});let t;try{t=await y.handleShellMessage(this,e)}catch(e){if(this.isDisposed)return;throw e}if(this._errorIfDisposed(),t)return void 0===t.content.status&&(t.content.status="ok"),"ok"!==t.content.status?(this._info.reject("Kernel info reply errored"),t):(this._info.resolve(t.content),this._kernelSession=t.header.session,t)}requestComplete(e){const t=d.createMessage({msgType:"complete_request",channel:"shell",username:this._username,session:this._clientId,content:e});return y.handleShellMessage(this,t)}requestInspect(e){const t=d.createMessage({msgType:"inspect_request",channel:"shell",username:this._username,session:this._clientId,content:e});return y.handleShellMessage(this,t)}requestHistory(e){const t=d.createMessage({msgType:"history_request",channel:"shell",username:this._username,session:this._clientId,content:e});return y.handleShellMessage(this,t)}requestExecute(e,t=!0,n){const r=d.createMessage({msgType:"execute_request",channel:"shell",username:this._username,session:this._clientId,content:Object.assign(Object.assign({},{silent:!1,store_history:!0,user_expressions:{},allow_stdin:!0,stop_on_error:!1}),e),metadata:n});return this.sendShellMessage(r,!0,t)}requestDebug(e,t=!0){const n=d.createMessage({msgType:"debug_request",channel:"control",username:this._username,session:this._clientId,content:e});return this.sendControlMessage(n,!0,t)}requestIsComplete(e){const t=d.createMessage({msgType:"is_complete_request",channel:"shell",username:this._username,session:this._clientId,content:e});return y.handleShellMessage(this,t)}requestCommInfo(e){const t=d.createMessage({msgType:"comm_info_request",channel:"shell",username:this._username,session:this._clientId,content:e});return y.handleShellMessage(this,t)}sendInputReply(e){const t=d.createMessage({msgType:"input_reply",channel:"stdin",username:this._username,session:this._clientId,content:e});this._sendMessage(t),this._anyMessage.emit({msg:t,direction:"send"}),this.hasPendingInput=!1}createComm(e,t=s.UUID.uuid4()){if(!this.handleComms)throw new Error("Comms are disabled on this kernel connection");if(this._comms.has(t))throw new Error("Comm is already created");const n=new u.CommHandler(e,t,this,()=>{this._unregisterComm(t)});return this._comms.set(t,n),n}hasComm(e){return this._comms.has(e)}registerCommTarget(e,t){this.handleComms&&(this._targetRegistry[e]=t)}removeCommTarget(e,t){this.handleComms&&(this.isDisposed||this._targetRegistry[e]!==t||delete this._targetRegistry[e])}registerMessageHook(e,t){var n;const r=null===(n=this._futures)||void 0===n?void 0:n.get(e);r&&r.registerMessageHook(t)}removeMessageHook(e,t){var n;const r=null===(n=this._futures)||void 0===n?void 0:n.get(e);r&&r.removeMessageHook(t)}removeInputGuard(){this.hasPendingInput=!1}async _handleDisplayId(e,t){var n,r;const i=t.parent_header.msg_id;let o=this._displayIdToParentIds.get(e);if(o){const e={header:s.JSONExt.deepCopy(t.header),parent_header:s.JSONExt.deepCopy(t.parent_header),metadata:s.JSONExt.deepCopy(t.metadata),content:s.JSONExt.deepCopy(t.content),channel:t.channel,buffers:t.buffers?t.buffers.slice():[]};e.header.msg_type="update_display_data",await Promise.all(o.map(async t=>{const n=this._futures&&this._futures.get(t);n&&await n.handleMsg(e)}))}if("update_display_data"===t.header.msg_type)return!0;o=null!==(n=this._displayIdToParentIds.get(e))&&void 0!==n?n:[],-1===o.indexOf(i)&&o.push(i),this._displayIdToParentIds.set(e,o);const a=null!==(r=this._msgIdToDisplayIds.get(i))&&void 0!==r?r:[];return-1===a.indexOf(i)&&a.push(i),this._msgIdToDisplayIds.set(i,a),!1}_clearSocket(){null!==this._ws&&(this._ws.onopen=this._noOp,this._ws.onclose=this._noOp,this._ws.onerror=this._noOp,this._ws.onmessage=this._noOp,this._ws.close(),this._ws=null)}_updateStatus(e){this._status!==e&&"dead"!==this._status&&(this._status=e,y.logKernelStatus(this),this._statusChanged.emit(e),"dead"===e&&this.dispose())}_sendPending(){for(;"connected"===this.connectionStatus&&"_RESTARTING_"!==this._kernelSession&&this._pendingMessages.length>0;)this._sendMessage(this._pendingMessages[0],!1),this._pendingMessages.shift()}_clearKernelState(){this._kernelSession="",this._pendingMessages=[],this._futures.forEach(e=>{e.dispose()}),this._comms.forEach(e=>{e.dispose()}),this._msgChain=Promise.resolve(),this._futures=new Map,this._comms=new Map,this._displayIdToParentIds.clear(),this._msgIdToDisplayIds.clear()}_assertCurrentMessage(e){if(this._errorIfDisposed(),e.header.session!==this._kernelSession)throw new Error("Canceling handling of old message: "+e.header.msg_type)}async _handleCommOpen(e){this._assertCurrentMessage(e);const t=e.content,n=new u.CommHandler(t.target_name,t.comm_id,this,()=>{this._unregisterComm(t.comm_id)});this._comms.set(t.comm_id,n);try{const r=await y.loadObject(t.target_name,t.target_module,this._targetRegistry);await r(n,e)}catch(e){throw n.close(),console.error("Exception opening new comm"),e}}async _handleCommClose(e){this._assertCurrentMessage(e);const t=e.content,n=this._comms.get(t.comm_id);if(!n)return void console.error("Comm not found for comm id "+t.comm_id);this._unregisterComm(n.commId);const r=n.onClose;r&&await r(e),n.dispose()}async _handleCommMsg(e){this._assertCurrentMessage(e);const t=e.content,n=this._comms.get(t.comm_id);if(!n)return;const r=n.onMsg;r&&await r(e)}_unregisterComm(e){this._comms.delete(e)}_updateConnectionStatus(e){if(this._connectionStatus!==e){if(this._connectionStatus=e,"connecting"!==e&&(this._reconnectAttempt=0,clearTimeout(this._reconnectTimeout)),"dead"!==this.status)if("connected"===e){let e="_RESTARTING_"===this._kernelSession,t=this.requestKernelInfo(),n=!1,r=()=>{n||(n=!0,e&&"_RESTARTING_"===this._kernelSession&&(this._kernelSession=""),clearTimeout(i),this._pendingMessages.length>0&&this._sendPending())};t.then(r);let i=setTimeout(r,3e3)}else this._updateStatus("unknown");this._connectionStatusChanged.emit(e)}}async _handleMessage(e){var t,n;let r=!1;if(e.parent_header&&"iopub"===e.channel&&(d.isDisplayDataMsg(e)||d.isUpdateDisplayDataMsg(e)||d.isExecuteResultMsg(e))){const n=(null!==(t=e.content.transient)&&void 0!==t?t:{}).display_id;n&&(r=await this._handleDisplayId(n,e),this._assertCurrentMessage(e))}if(!r&&e.parent_header){const t=e.parent_header,r=null===(n=this._futures)||void 0===n?void 0:n.get(t.msg_id);if(r)await r.handleMsg(e),this._assertCurrentMessage(e);else{const n=t.session===this.clientId;"iopub"!==e.channel&&n&&this._unhandledMessage.emit(e)}}if("iopub"===e.channel){switch(e.header.msg_type){case"status":{const t=e.content.execution_state;"restarting"===t&&Promise.resolve().then(async()=>{this._updateStatus("autorestarting"),this._clearKernelState(),await this.reconnect()}),this._updateStatus(t);break}case"comm_open":this.handleComms&&await this._handleCommOpen(e);break;case"comm_msg":this.handleComms&&await this._handleCommMsg(e);break;case"comm_close":this.handleComms&&await this._handleCommClose(e)}this.isDisposed||(this._assertCurrentMessage(e),this._iopubMessage.emit(e))}}_reconnect(){if(this._errorIfDisposed(),clearTimeout(this._reconnectTimeout),this._reconnectAttempt<this._reconnectLimit){this._updateConnectionStatus("connecting");const e=y.getRandomIntInclusive(0,1e3*(Math.pow(2,this._reconnectAttempt)-1));console.warn(`Connection lost, reconnecting in ${Math.floor(e/1e3)} seconds.`),this._reconnectTimeout=setTimeout(this._createSocket,e),this._reconnectAttempt+=1}else this._updateConnectionStatus("disconnected");this._clearSocket()}_errorIfDisposed(){if(this.isDisposed)throw new Error("Kernel connection is disposed")}get hasPendingInput(){return this._hasPendingInput}set hasPendingInput(e){this._hasPendingInput=e,this._pendingInput.emit(e)}}var y;t.KernelConnection=v,function(e){e.logKernelStatus=function(e){switch(e.status){case"idle":case"busy":case"unknown":return;default:console.debug(`Kernel: ${e.status} (${e.id})`)}},e.handleShellMessage=async function(e,t){return e.sendShellMessage(t,!0).done},e.loadObject=function(e,t,n){return new Promise((r,i)=>{if(t){if("undefined"==typeof requirejs)throw new Error("requirejs not found");requirejs([t],n=>{if(void 0===n[e]){i(new Error(`Object '${e}' not found in module '${t}'`))}else r(n[e])},i)}else(null==n?void 0:n[e])?r(n[e]):i(new Error(`Object '${e}' not found in registry`))})},e.getRandomIntInclusive=function(e,t){return e=Math.ceil(e),t=Math.floor(t),Math.floor(Math.random()*(t-e+1))+e}}(y||(y={}))},function(e,t,n){"use strict";var r=function(){};e.exports=r},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.TeXFont=void 0;var a=n(46),s=n(882),l=n(883),c=n(885),u=n(887),d=n(889),h=n(891),p=n(893),f=n(895),m=n(897),g=n(899),v=n(901),y=n(903),_=n(905),b=n(907),M=n(909),w=n(911),A=n(913),C=n(915),x=n(917),E=n(919),L=n(921),S=n(923),T=n(925),O=n(927),I=n(929),k=n(931),D=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.defaultCssFamilyPrefix="MJXZERO",t.defaultVariantClasses={normal:"mjx-n",bold:"mjx-b",italic:"mjx-i","bold-italic":"mjx-b mjx-i","double-struck":"mjx-ds mjx-b",fraktur:"mjx-fr","bold-fraktur":"mjx-fr mjx-b",script:"mjx-sc mjx-i","bold-script":"mjx-sc mjx-b mjx-i","sans-serif":"mjx-ss","bold-sans-serif":"mjx-ss mjx-b","sans-serif-italic":"mjx-ss mjx-i","sans-serif-bold-italic":"mjx-ss mjx-b mjx-i",monospace:"mjx-ty","-smallop":"mjx-sop","-largeop":"mjx-lop","-size3":"mjx-s3","-size4":"mjx-s4","-tex-calligraphic":"mjx-cal mjx-i","-tex-bold-calligraphic":"mjx-cal mjx-b","-tex-mathit":"mjx-mit mjx-i","-tex-oldstyle":"mjx-os","-tex-bold-oldstyle":"mjx-os mjx-b","-tex-variant":"mjx-var"},t.defaultVariantLetters={normal:"",bold:"B",italic:"MI","bold-italic":"BI","double-struck":"A",fraktur:"FR","bold-fraktur":"FRB",script:"SC","bold-script":"SCB","sans-serif":"SS","bold-sans-serif":"SSB","sans-serif-italic":"SSI","sans-serif-bold-italic":"SSBI",monospace:"T","-smallop":"S1","-largeop":"S2","-size3":"S3","-size4":"S4","-tex-calligraphic":"C","-tex-bold-calligraphic":"CB","-tex-mathit":"MI","-tex-oldstyle":"C","-tex-bold-oldstyle":"CB","-tex-variant":"A"},t.defaultDelimiters=k.delimiters,t.defaultChars={normal:g.normal,bold:c.bold,italic:p.italic,"bold-italic":l.boldItalic,"double-struck":u.doubleStruck,fraktur:h.fraktur,"bold-fraktur":d.frakturBold,script:w.script,"bold-script":M.scriptBold,"sans-serif":b.sansSerif,"bold-sans-serif":y.sansSerifBold,"sans-serif-italic":_.sansSerifItalic,"sans-serif-bold-italic":v.sansSerifBoldItalic,monospace:m.monospace,"-smallop":A.smallop,"-largeop":f.largeop,"-size3":T.texSize3,"-size4":O.texSize4,"-tex-calligraphic":x.texCalligraphic,"-tex-bold-calligraphic":C.texCalligraphicBold,"-tex-mathit":E.texMathit,"-tex-oldstyle":S.texOldstyle,"-tex-bold-oldstyle":L.texOldstyleBold,"-tex-variant":I.texVariant},t.defaultStyles=o(o({},a.CHTMLFontData.defaultStyles),{".MJX-TEX":{"font-family":"MJXZERO, MJXTEX"},".TEX-B":{"font-family":"MJXZERO, MJXTEX-B"},".TEX-I":{"font-family":"MJXZERO, MJXTEX-I"},".TEX-MI":{"font-family":"MJXZERO, MJXTEX-MI"},".TEX-BI":{"font-family":"MJXZERO, MJXTEX-BI"},".TEX-S1":{"font-family":"MJXZERO, MJXTEX-S1"},".TEX-S2":{"font-family":"MJXZERO, MJXTEX-S2"},".TEX-S3":{"font-family":"MJXZERO, MJXTEX-S3"},".TEX-S4":{"font-family":"MJXZERO, MJXTEX-S4"},".TEX-A":{"font-family":"MJXZERO, MJXTEX-A"},".TEX-C":{"font-family":"MJXZERO, MJXTEX-C"},".TEX-CB":{"font-family":"MJXZERO, MJXTEX-CB"},".TEX-FR":{"font-family":"MJXZERO, MJXTEX-FR"},".TEX-FRB":{"font-family":"MJXZERO, MJXTEX-FRB"},".TEX-SS":{"font-family":"MJXZERO, MJXTEX-SS"},".TEX-SSB":{"font-family":"MJXZERO, MJXTEX-SSB"},".TEX-SSI":{"font-family":"MJXZERO, MJXTEX-SSI"},".TEX-SC":{"font-family":"MJXZERO, MJXTEX-SC"},".TEX-T":{"font-family":"MJXZERO, MJXTEX-T"},".TEX-V":{"font-family":"MJXZERO, MJXTEX-V"},".TEX-VB":{"font-family":"MJXZERO, MJXTEX-VB"},"mjx-stretchy-v mjx-c, mjx-stretchy-h mjx-c":{"font-family":"MJXZERO, MJXTEX-S1, MJXTEX-S4, MJXTEX, MJXTEX-A ! important"}}),t.defaultFonts=o(o({},a.CHTMLFontData.defaultFonts),{"@font-face /* 1 */":{"font-family":"MJXTEX",src:'url("%%URL%%/MathJax_Main-Regular.woff") format("woff")'},"@font-face /* 2 */":{"font-family":"MJXTEX-B",src:'url("%%URL%%/MathJax_Main-Bold.woff") format("woff")'},"@font-face /* 3 */":{"font-family":"MJXTEX-I",src:'url("%%URL%%/MathJax_Math-Italic.woff") format("woff")'},"@font-face /* 4 */":{"font-family":"MJXTEX-MI",src:'url("%%URL%%/MathJax_Main-Italic.woff") format("woff")'},"@font-face /* 5 */":{"font-family":"MJXTEX-BI",src:'url("%%URL%%/MathJax_Math-BoldItalic.woff") format("woff")'},"@font-face /* 6 */":{"font-family":"MJXTEX-S1",src:'url("%%URL%%/MathJax_Size1-Regular.woff") format("woff")'},"@font-face /* 7 */":{"font-family":"MJXTEX-S2",src:'url("%%URL%%/MathJax_Size2-Regular.woff") format("woff")'},"@font-face /* 8 */":{"font-family":"MJXTEX-S3",src:'url("%%URL%%/MathJax_Size3-Regular.woff") format("woff")'},"@font-face /* 9 */":{"font-family":"MJXTEX-S4",src:'url("%%URL%%/MathJax_Size4-Regular.woff") format("woff")'},"@font-face /* 10 */":{"font-family":"MJXTEX-A",src:'url("%%URL%%/MathJax_AMS-Regular.woff") format("woff")'},"@font-face /* 11 */":{"font-family":"MJXTEX-C",src:'url("%%URL%%/MathJax_Calligraphic-Regular.woff") format("woff")'},"@font-face /* 12 */":{"font-family":"MJXTEX-CB",src:'url("%%URL%%/MathJax_Calligraphic-Bold.woff") format("woff")'},"@font-face /* 13 */":{"font-family":"MJXTEX-FR",src:'url("%%URL%%/MathJax_Fraktur-Regular.woff") format("woff")'},"@font-face /* 14 */":{"font-family":"MJXTEX-FRB",src:'url("%%URL%%/MathJax_Fraktur-Bold.woff") format("woff")'},"@font-face /* 15 */":{"font-family":"MJXTEX-SS",src:'url("%%URL%%/MathJax_SansSerif-Regular.woff") format("woff")'},"@font-face /* 16 */":{"font-family":"MJXTEX-SSB",src:'url("%%URL%%/MathJax_SansSerif-Bold.woff") format("woff")'},"@font-face /* 17 */":{"font-family":"MJXTEX-SSI",src:'url("%%URL%%/MathJax_SansSerif-Italic.woff") format("woff")'},"@font-face /* 18 */":{"font-family":"MJXTEX-SC",src:'url("%%URL%%/MathJax_Script-Regular.woff") format("woff")'},"@font-face /* 19 */":{"font-family":"MJXTEX-T",src:'url("%%URL%%/MathJax_Typewriter-Regular.woff") format("woff")'},"@font-face /* 20 */":{"font-family":"MJXTEX-V",src:'url("%%URL%%/MathJax_Vector-Regular.woff") format("woff")'},"@font-face /* 21 */":{"font-family":"MJXTEX-VB",src:'url("%%URL%%/MathJax_Vector-Bold.woff") format("woff")'}}),t}(s.CommonTeXFontMixin(a.CHTMLFontData));t.TeXFont=D},function(e,t,n){"use strict";var r=n(75),i=n.n(r),o=n(76),a=n.n(o),s=n(42),l=n.n(s),c=n(463),u=n.n(c),d=n(464),h=n.n(d),p=n(465),f=n.n(p),m=n(466),g=n.n(m),v=n(467),y=n.n(v),_=n(468),b=n.n(_),M=n(469),w=n.n(M),A=n(470),C=n.n(A),x=n(471),E=n.n(x),L=n(472),S=n.n(L),T=n(473),O=n.n(T),I=n(474),k=n.n(I),D=n(475),N=n.n(D),j=n(476),P=n.n(j),z=n(477),R=n.n(z),B=n(478),H=n.n(B),F=n(479),Y=n.n(F),V=n(480),U=n.n(V),W=n(481),G=n.n(W),q=n(482),K=n.n(q),X=n(483),J=n.n(X),Q=n(484),Z=n.n(Q),$=a()(i.a),ee=l()(u.a),te=l()(h.a),ne=l()(f.a),re=l()(g.a),ie=l()(y.a),oe=l()(b.a),ae=l()(w.a),se=l()(C.a),le=l()(E.a),ce=l()(S.a),ue=l()(O.a),de=l()(k.a),he=l()(N.a),pe=l()(P.a),fe=l()(R.a),me=l()(H.a),ge=l()(Y.a),ve=l()(U.a),ye=l()(G.a),_e=l()(K.a),be=l()(J.a),Me=l()(Z.a);$.push([e.i,"@font-face /* 0 */ {\n  font-family: MJXZERO;\n  src: url("+ee+")\n    format('woff');\n}\n\n@font-face /* 1 */ {\n  font-family: MJXTEX;\n  src: url("+te+")\n    format('woff');\n}\n\n@font-face /* 2 */ {\n  font-family: MJXTEX-B;\n  src: url("+ne+")\n    format('woff');\n}\n\n@font-face /* 3 */ {\n  font-family: MJXTEX-MI;\n  src: url("+re+")\n    format('woff');\n}\n\n@font-face /* 4 */ {\n  font-family: MJXTEX-I;\n  src: url("+ie+")\n    format('woff');\n}\n\n@font-face /* 5 */ {\n  font-family: MJXTEX-BI;\n  src: url("+oe+")\n    format('woff');\n}\n\n@font-face /* 6 */ {\n  font-family: MJXTEX-S1;\n  src: url("+ae+")\n    format('woff');\n}\n\n@font-face /* 7 */ {\n  font-family: MJXTEX-S2;\n  src: url("+se+")\n    format('woff');\n}\n\n@font-face /* 8 */ {\n  font-family: MJXTEX-S3;\n  src: url("+le+")\n    format('woff');\n}\n\n@font-face /* 9 */ {\n  font-family: MJXTEX-S4;\n  src: url("+ce+")\n    format('woff');\n}\n\n@font-face /* 10 */ {\n  font-family: MJXTEX-A;\n  src: url("+ue+")\n    format('woff');\n}\n\n@font-face /* 11 */ {\n  font-family: MJXTEX-C;\n  src: url("+de+")\n    format('woff');\n}\n\n@font-face /* 12 */ {\n  font-family: MJXTEX-C-B;\n  src: url("+he+")\n    format('woff');\n}\n\n@font-face /* 13 */ {\n  font-family: MJXTEX-FR;\n  src: url("+pe+")\n    format('woff');\n}\n\n@font-face /* 14 */ {\n  font-family: MJXTEX-FR-B;\n  src: url("+fe+")\n    format('woff');\n}\n\n@font-face /* 15 */ {\n  font-family: MJXTEX-SS;\n  src: url("+me+")\n    format('woff');\n}\n\n@font-face /* 16 */ {\n  font-family: MJXTEX-SS-B;\n  src: url("+ge+")\n    format('woff');\n}\n\n@font-face /* 17 */ {\n  font-family: MJXTEX-SS-I;\n  src: url("+ve+")\n    format('woff');\n}\n\n@font-face /* 18 */ {\n  font-family: MJXTEX-SC;\n  src: url("+ye+")\n    format('woff');\n}\n\n@font-face /* 19 */ {\n  font-family: MJXTEX-T;\n  src: url("+_e+")\n    format('woff');\n}\n\n@font-face /* 20 */ {\n  font-family: MJXTEX-V;\n  src: url("+be+")\n    format('woff');\n}\n\n@font-face /* 21 */ {\n  font-family: MJXTEX-VB;\n  src: url("+Me+")\n    format('woff');\n}\n","",{version:3,sources:["webpack://./style/index.css"],names:[],mappings:"AAAA;EACE,oBAAoB;EACpB;kBACgB;AAClB;;AAEA;EACE,mBAAmB;EACnB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,uBAAuB;EACvB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,wBAAwB;EACxB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,wBAAwB;EACxB;kBACgB;AAClB;;AAEA;EACE,wBAAwB;EACxB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,qBAAqB;EACrB;kBACgB;AAClB;;AAEA;EACE,sBAAsB;EACtB;kBACgB;AAClB",sourcesContent:["@font-face /* 0 */ {\n  font-family: MJXZERO;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Zero.woff')\n    format('woff');\n}\n\n@font-face /* 1 */ {\n  font-family: MJXTEX;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Main-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 2 */ {\n  font-family: MJXTEX-B;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Main-Bold.woff')\n    format('woff');\n}\n\n@font-face /* 3 */ {\n  font-family: MJXTEX-MI;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Main-Italic.woff')\n    format('woff');\n}\n\n@font-face /* 4 */ {\n  font-family: MJXTEX-I;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Math-Italic.woff')\n    format('woff');\n}\n\n@font-face /* 5 */ {\n  font-family: MJXTEX-BI;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Math-BoldItalic.woff')\n    format('woff');\n}\n\n@font-face /* 6 */ {\n  font-family: MJXTEX-S1;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Size1-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 7 */ {\n  font-family: MJXTEX-S2;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Size2-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 8 */ {\n  font-family: MJXTEX-S3;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Size3-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 9 */ {\n  font-family: MJXTEX-S4;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Size4-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 10 */ {\n  font-family: MJXTEX-A;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_AMS-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 11 */ {\n  font-family: MJXTEX-C;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Calligraphic-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 12 */ {\n  font-family: MJXTEX-C-B;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Calligraphic-Bold.woff')\n    format('woff');\n}\n\n@font-face /* 13 */ {\n  font-family: MJXTEX-FR;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Fraktur-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 14 */ {\n  font-family: MJXTEX-FR-B;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Fraktur-Bold.woff')\n    format('woff');\n}\n\n@font-face /* 15 */ {\n  font-family: MJXTEX-SS;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_SansSerif-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 16 */ {\n  font-family: MJXTEX-SS-B;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_SansSerif-Bold.woff')\n    format('woff');\n}\n\n@font-face /* 17 */ {\n  font-family: MJXTEX-SS-I;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_SansSerif-Italic.woff')\n    format('woff');\n}\n\n@font-face /* 18 */ {\n  font-family: MJXTEX-SC;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Script-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 19 */ {\n  font-family: MJXTEX-T;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Typewriter-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 20 */ {\n  font-family: MJXTEX-V;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Vector-Regular.woff')\n    format('woff');\n}\n\n@font-face /* 21 */ {\n  font-family: MJXTEX-VB;\n  src: url('~mathjax-full/es5/output/chtml/fonts/woff-v2/MathJax_Vector-Bold.woff')\n    format('woff');\n}\n"],sourceRoot:""}]),t.a=$},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));const r=e=>void 0===e?null:e},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.InputGroup=void 0;var r=n(1),i=r.__importDefault(n(5)),o=r.__importStar(n(0)),a=n(9),s=n(91),l=r.__importStar(n(172)),c=n(84),u=n(385),d=n(712),h=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={},t.leftElement=null,t.rightElement=null,t.refHandlers={leftElement:function(e){return t.leftElement=e},rightElement:function(e){return t.rightElement=e}},t}return r.__extends(t,e),t.prototype.render=function(){var e,t=this.props,n=t.asyncControl,a=void 0!==n&&n,l=t.className,u=t.disabled,h=t.fill,p=t.inputRef,f=t.intent,m=t.large,g=t.small,v=t.round,y=i.default(s.Classes.INPUT_GROUP,s.Classes.intentClass(f),((e={})[s.Classes.DISABLED]=u,e[s.Classes.FILL]=h,e[s.Classes.LARGE]=m,e[s.Classes.SMALL]=g,e[s.Classes.ROUND]=v,e),l),_=r.__assign(r.__assign({},this.props.style),{paddingLeft:this.state.leftElementWidth,paddingRight:this.state.rightElementWidth}),b=r.__assign(r.__assign({type:"text"},c.removeNonHTMLProps(this.props)),{className:s.Classes.INPUT,style:_});return o.createElement("div",{className:y},this.maybeRenderLeftElement(),a?o.createElement(d.AsyncControllableInput,r.__assign({},b,{inputRef:p})):o.createElement("input",r.__assign({},b,{ref:p})),this.maybeRenderRightElement())},t.prototype.componentDidMount=function(){this.updateInputWidth()},t.prototype.componentDidUpdate=function(e){var t=this.props,n=t.leftElement,r=t.rightElement;e.leftElement===n&&e.rightElement===r||this.updateInputWidth()},t.prototype.validateProps=function(e){null!=e.leftElement&&null!=e.leftIcon&&console.warn(l.INPUT_WARN_LEFT_ELEMENT_LEFT_ICON_MUTEX)},t.prototype.maybeRenderLeftElement=function(){var e=this.props,t=e.leftElement,n=e.leftIcon;return null!=t?o.createElement("span",{className:s.Classes.INPUT_LEFT_CONTAINER,ref:this.refHandlers.leftElement},t):null!=n?o.createElement(u.Icon,{icon:n}):void 0},t.prototype.maybeRenderRightElement=function(){var e=this.props.rightElement;if(null!=e)return o.createElement("span",{className:s.Classes.INPUT_ACTION,ref:this.refHandlers.rightElement},e)},t.prototype.updateInputWidth=function(){var e=this.state,t=e.leftElementWidth,n=e.rightElementWidth;if(null!=this.leftElement){var r=this.leftElement.clientWidth;(void 0===t||Math.abs(r-t)>2)&&this.setState({leftElementWidth:r})}else this.setState({leftElementWidth:void 0});if(null!=this.rightElement){r=this.rightElement.clientWidth;(void 0===n||Math.abs(r-n)>2)&&this.setState({rightElementWidth:r})}else this.setState({rightElementWidth:void 0})},t.displayName=c.DISPLAYNAME_PREFIX+".InputGroup",t=r.__decorate([a.polyfill],t)}(s.AbstractPureComponent2);t.InputGroup=h},function(e,t,n){"use strict";t.__esModule=!0;var r=o(n(0)),i=o(n(718));function o(e){return e&&e.__esModule?e:{default:e}}t.default=r.default.createContext||i.default,e.exports=t.default},function(e,t,n){"use strict";(function(e){
/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version 1.16.1
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var n="undefined"!=typeof window&&"undefined"!=typeof document&&"undefined"!=typeof navigator,r=function(){for(var e=["Edge","Trident","Firefox"],t=0;t<e.length;t+=1)if(n&&navigator.userAgent.indexOf(e[t])>=0)return 1;return 0}();var i=n&&window.Promise?function(e){var t=!1;return function(){t||(t=!0,window.Promise.resolve().then((function(){t=!1,e()})))}}:function(e){var t=!1;return function(){t||(t=!0,setTimeout((function(){t=!1,e()}),r))}};function o(e){return e&&"[object Function]"==={}.toString.call(e)}function a(e,t){if(1!==e.nodeType)return[];var n=e.ownerDocument.defaultView.getComputedStyle(e,null);return t?n[t]:n}function s(e){return"HTML"===e.nodeName?e:e.parentNode||e.host}function l(e){if(!e)return document.body;switch(e.nodeName){case"HTML":case"BODY":return e.ownerDocument.body;case"#document":return e.body}var t=a(e),n=t.overflow,r=t.overflowX,i=t.overflowY;return/(auto|scroll|overlay)/.test(n+i+r)?e:l(s(e))}function c(e){return e&&e.referenceNode?e.referenceNode:e}var u=n&&!(!window.MSInputMethodContext||!document.documentMode),d=n&&/MSIE 10/.test(navigator.userAgent);function h(e){return 11===e?u:10===e?d:u||d}function p(e){if(!e)return document.documentElement;for(var t=h(10)?document.body:null,n=e.offsetParent||null;n===t&&e.nextElementSibling;)n=(e=e.nextElementSibling).offsetParent;var r=n&&n.nodeName;return r&&"BODY"!==r&&"HTML"!==r?-1!==["TH","TD","TABLE"].indexOf(n.nodeName)&&"static"===a(n,"position")?p(n):n:e?e.ownerDocument.documentElement:document.documentElement}function f(e){return null!==e.parentNode?f(e.parentNode):e}function m(e,t){if(!(e&&e.nodeType&&t&&t.nodeType))return document.documentElement;var n=e.compareDocumentPosition(t)&Node.DOCUMENT_POSITION_FOLLOWING,r=n?e:t,i=n?t:e,o=document.createRange();o.setStart(r,0),o.setEnd(i,0);var a,s,l=o.commonAncestorContainer;if(e!==l&&t!==l||r.contains(i))return"BODY"===(s=(a=l).nodeName)||"HTML"!==s&&p(a.firstElementChild)!==a?p(l):l;var c=f(e);return c.host?m(c.host,t):m(e,f(t).host)}function g(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"top",n="top"===t?"scrollTop":"scrollLeft",r=e.nodeName;if("BODY"===r||"HTML"===r){var i=e.ownerDocument.documentElement,o=e.ownerDocument.scrollingElement||i;return o[n]}return e[n]}function v(e,t){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2],r=g(t,"top"),i=g(t,"left"),o=n?-1:1;return e.top+=r*o,e.bottom+=r*o,e.left+=i*o,e.right+=i*o,e}function y(e,t){var n="x"===t?"Left":"Top",r="Left"===n?"Right":"Bottom";return parseFloat(e["border"+n+"Width"])+parseFloat(e["border"+r+"Width"])}function _(e,t,n,r){return Math.max(t["offset"+e],t["scroll"+e],n["client"+e],n["offset"+e],n["scroll"+e],h(10)?parseInt(n["offset"+e])+parseInt(r["margin"+("Height"===e?"Top":"Left")])+parseInt(r["margin"+("Height"===e?"Bottom":"Right")]):0)}function b(e){var t=e.body,n=e.documentElement,r=h(10)&&getComputedStyle(n);return{height:_("Height",t,n,r),width:_("Width",t,n,r)}}var M=function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")},w=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),A=function(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e},C=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e};function x(e){return C({},e,{right:e.left+e.width,bottom:e.top+e.height})}function E(e){var t={};try{if(h(10)){t=e.getBoundingClientRect();var n=g(e,"top"),r=g(e,"left");t.top+=n,t.left+=r,t.bottom+=n,t.right+=r}else t=e.getBoundingClientRect()}catch(e){}var i={left:t.left,top:t.top,width:t.right-t.left,height:t.bottom-t.top},o="HTML"===e.nodeName?b(e.ownerDocument):{},s=o.width||e.clientWidth||i.width,l=o.height||e.clientHeight||i.height,c=e.offsetWidth-s,u=e.offsetHeight-l;if(c||u){var d=a(e);c-=y(d,"x"),u-=y(d,"y"),i.width-=c,i.height-=u}return x(i)}function L(e,t){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2],r=h(10),i="HTML"===t.nodeName,o=E(e),s=E(t),c=l(e),u=a(t),d=parseFloat(u.borderTopWidth),p=parseFloat(u.borderLeftWidth);n&&i&&(s.top=Math.max(s.top,0),s.left=Math.max(s.left,0));var f=x({top:o.top-s.top-d,left:o.left-s.left-p,width:o.width,height:o.height});if(f.marginTop=0,f.marginLeft=0,!r&&i){var m=parseFloat(u.marginTop),g=parseFloat(u.marginLeft);f.top-=d-m,f.bottom-=d-m,f.left-=p-g,f.right-=p-g,f.marginTop=m,f.marginLeft=g}return(r&&!n?t.contains(c):t===c&&"BODY"!==c.nodeName)&&(f=v(f,t)),f}function S(e){var t=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=e.ownerDocument.documentElement,r=L(e,n),i=Math.max(n.clientWidth,window.innerWidth||0),o=Math.max(n.clientHeight,window.innerHeight||0),a=t?0:g(n),s=t?0:g(n,"left"),l={top:a-r.top+r.marginTop,left:s-r.left+r.marginLeft,width:i,height:o};return x(l)}function T(e){var t=e.nodeName;if("BODY"===t||"HTML"===t)return!1;if("fixed"===a(e,"position"))return!0;var n=s(e);return!!n&&T(n)}function O(e){if(!e||!e.parentElement||h())return document.documentElement;for(var t=e.parentElement;t&&"none"===a(t,"transform");)t=t.parentElement;return t||document.documentElement}function I(e,t,n,r){var i=arguments.length>4&&void 0!==arguments[4]&&arguments[4],o={top:0,left:0},a=i?O(e):m(e,c(t));if("viewport"===r)o=S(a,i);else{var u=void 0;"scrollParent"===r?"BODY"===(u=l(s(t))).nodeName&&(u=e.ownerDocument.documentElement):u="window"===r?e.ownerDocument.documentElement:r;var d=L(u,a,i);if("HTML"!==u.nodeName||T(a))o=d;else{var h=b(e.ownerDocument),p=h.height,f=h.width;o.top+=d.top-d.marginTop,o.bottom=p+d.top,o.left+=d.left-d.marginLeft,o.right=f+d.left}}var g="number"==typeof(n=n||0);return o.left+=g?n:n.left||0,o.top+=g?n:n.top||0,o.right-=g?n:n.right||0,o.bottom-=g?n:n.bottom||0,o}function k(e){return e.width*e.height}function D(e,t,n,r,i){var o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:0;if(-1===e.indexOf("auto"))return e;var a=I(n,r,o,i),s={top:{width:a.width,height:t.top-a.top},right:{width:a.right-t.right,height:a.height},bottom:{width:a.width,height:a.bottom-t.bottom},left:{width:t.left-a.left,height:a.height}},l=Object.keys(s).map((function(e){return C({key:e},s[e],{area:k(s[e])})})).sort((function(e,t){return t.area-e.area})),c=l.filter((function(e){var t=e.width,r=e.height;return t>=n.clientWidth&&r>=n.clientHeight})),u=c.length>0?c[0].key:l[0].key,d=e.split("-")[1];return u+(d?"-"+d:"")}function N(e,t,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null,i=r?O(t):m(t,c(n));return L(n,i,r)}function j(e){var t=e.ownerDocument.defaultView.getComputedStyle(e),n=parseFloat(t.marginTop||0)+parseFloat(t.marginBottom||0),r=parseFloat(t.marginLeft||0)+parseFloat(t.marginRight||0);return{width:e.offsetWidth+r,height:e.offsetHeight+n}}function P(e){var t={left:"right",right:"left",bottom:"top",top:"bottom"};return e.replace(/left|right|bottom|top/g,(function(e){return t[e]}))}function z(e,t,n){n=n.split("-")[0];var r=j(e),i={width:r.width,height:r.height},o=-1!==["right","left"].indexOf(n),a=o?"top":"left",s=o?"left":"top",l=o?"height":"width",c=o?"width":"height";return i[a]=t[a]+t[l]/2-r[l]/2,i[s]=n===s?t[s]-r[c]:t[P(s)],i}function R(e,t){return Array.prototype.find?e.find(t):e.filter(t)[0]}function B(e,t,n){return(void 0===n?e:e.slice(0,function(e,t,n){if(Array.prototype.findIndex)return e.findIndex((function(e){return e[t]===n}));var r=R(e,(function(e){return e[t]===n}));return e.indexOf(r)}(e,"name",n))).forEach((function(e){e.function&&console.warn("`modifier.function` is deprecated, use `modifier.fn`!");var n=e.function||e.fn;e.enabled&&o(n)&&(t.offsets.popper=x(t.offsets.popper),t.offsets.reference=x(t.offsets.reference),t=n(t,e))})),t}function H(){if(!this.state.isDestroyed){var e={instance:this,styles:{},arrowStyles:{},attributes:{},flipped:!1,offsets:{}};e.offsets.reference=N(this.state,this.popper,this.reference,this.options.positionFixed),e.placement=D(this.options.placement,e.offsets.reference,this.popper,this.reference,this.options.modifiers.flip.boundariesElement,this.options.modifiers.flip.padding),e.originalPlacement=e.placement,e.positionFixed=this.options.positionFixed,e.offsets.popper=z(this.popper,e.offsets.reference,e.placement),e.offsets.popper.position=this.options.positionFixed?"fixed":"absolute",e=B(this.modifiers,e),this.state.isCreated?this.options.onUpdate(e):(this.state.isCreated=!0,this.options.onCreate(e))}}function F(e,t){return e.some((function(e){var n=e.name;return e.enabled&&n===t}))}function Y(e){for(var t=[!1,"ms","Webkit","Moz","O"],n=e.charAt(0).toUpperCase()+e.slice(1),r=0;r<t.length;r++){var i=t[r],o=i?""+i+n:e;if(void 0!==document.body.style[o])return o}return null}function V(){return this.state.isDestroyed=!0,F(this.modifiers,"applyStyle")&&(this.popper.removeAttribute("x-placement"),this.popper.style.position="",this.popper.style.top="",this.popper.style.left="",this.popper.style.right="",this.popper.style.bottom="",this.popper.style.willChange="",this.popper.style[Y("transform")]=""),this.disableEventListeners(),this.options.removeOnDestroy&&this.popper.parentNode.removeChild(this.popper),this}function U(e){var t=e.ownerDocument;return t?t.defaultView:window}function W(e,t,n,r){n.updateBound=r,U(e).addEventListener("resize",n.updateBound,{passive:!0});var i=l(e);return function e(t,n,r,i){var o="BODY"===t.nodeName,a=o?t.ownerDocument.defaultView:t;a.addEventListener(n,r,{passive:!0}),o||e(l(a.parentNode),n,r,i),i.push(a)}(i,"scroll",n.updateBound,n.scrollParents),n.scrollElement=i,n.eventsEnabled=!0,n}function G(){this.state.eventsEnabled||(this.state=W(this.reference,this.options,this.state,this.scheduleUpdate))}function q(){var e,t;this.state.eventsEnabled&&(cancelAnimationFrame(this.scheduleUpdate),this.state=(e=this.reference,t=this.state,U(e).removeEventListener("resize",t.updateBound),t.scrollParents.forEach((function(e){e.removeEventListener("scroll",t.updateBound)})),t.updateBound=null,t.scrollParents=[],t.scrollElement=null,t.eventsEnabled=!1,t))}function K(e){return""!==e&&!isNaN(parseFloat(e))&&isFinite(e)}function X(e,t){Object.keys(t).forEach((function(n){var r="";-1!==["width","height","top","right","bottom","left"].indexOf(n)&&K(t[n])&&(r="px"),e.style[n]=t[n]+r}))}var J=n&&/Firefox/i.test(navigator.userAgent);function Q(e,t,n){var r=R(e,(function(e){return e.name===t})),i=!!r&&e.some((function(e){return e.name===n&&e.enabled&&e.order<r.order}));if(!i){var o="`"+t+"`",a="`"+n+"`";console.warn(a+" modifier is required by "+o+" modifier in order to work, be sure to include it before "+o+"!")}return i}var Z=["auto-start","auto","auto-end","top-start","top","top-end","right-start","right","right-end","bottom-end","bottom","bottom-start","left-end","left","left-start"],$=Z.slice(3);function ee(e){var t=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=$.indexOf(e),r=$.slice(n+1).concat($.slice(0,n));return t?r.reverse():r}var te="flip",ne="clockwise",re="counterclockwise";function ie(e,t,n,r){var i=[0,0],o=-1!==["right","left"].indexOf(r),a=e.split(/(\+|\-)/).map((function(e){return e.trim()})),s=a.indexOf(R(a,(function(e){return-1!==e.search(/,|\s/)})));a[s]&&-1===a[s].indexOf(",")&&console.warn("Offsets separated by white space(s) are deprecated, use a comma (,) instead.");var l=/\s*,\s*|\s+/,c=-1!==s?[a.slice(0,s).concat([a[s].split(l)[0]]),[a[s].split(l)[1]].concat(a.slice(s+1))]:[a];return(c=c.map((function(e,r){var i=(1===r?!o:o)?"height":"width",a=!1;return e.reduce((function(e,t){return""===e[e.length-1]&&-1!==["+","-"].indexOf(t)?(e[e.length-1]=t,a=!0,e):a?(e[e.length-1]+=t,a=!1,e):e.concat(t)}),[]).map((function(e){return function(e,t,n,r){var i=e.match(/((?:\-|\+)?\d*\.?\d*)(.*)/),o=+i[1],a=i[2];if(!o)return e;if(0===a.indexOf("%")){var s=void 0;switch(a){case"%p":s=n;break;case"%":case"%r":default:s=r}return x(s)[t]/100*o}if("vh"===a||"vw"===a){return("vh"===a?Math.max(document.documentElement.clientHeight,window.innerHeight||0):Math.max(document.documentElement.clientWidth,window.innerWidth||0))/100*o}return o}(e,i,t,n)}))}))).forEach((function(e,t){e.forEach((function(n,r){K(n)&&(i[t]+=n*("-"===e[r-1]?-1:1))}))})),i}var oe={placement:"bottom",positionFixed:!1,eventsEnabled:!0,removeOnDestroy:!1,onCreate:function(){},onUpdate:function(){},modifiers:{shift:{order:100,enabled:!0,fn:function(e){var t=e.placement,n=t.split("-")[0],r=t.split("-")[1];if(r){var i=e.offsets,o=i.reference,a=i.popper,s=-1!==["bottom","top"].indexOf(n),l=s?"left":"top",c=s?"width":"height",u={start:A({},l,o[l]),end:A({},l,o[l]+o[c]-a[c])};e.offsets.popper=C({},a,u[r])}return e}},offset:{order:200,enabled:!0,fn:function(e,t){var n=t.offset,r=e.placement,i=e.offsets,o=i.popper,a=i.reference,s=r.split("-")[0],l=void 0;return l=K(+n)?[+n,0]:ie(n,o,a,s),"left"===s?(o.top+=l[0],o.left-=l[1]):"right"===s?(o.top+=l[0],o.left+=l[1]):"top"===s?(o.left+=l[0],o.top-=l[1]):"bottom"===s&&(o.left+=l[0],o.top+=l[1]),e.popper=o,e},offset:0},preventOverflow:{order:300,enabled:!0,fn:function(e,t){var n=t.boundariesElement||p(e.instance.popper);e.instance.reference===n&&(n=p(n));var r=Y("transform"),i=e.instance.popper.style,o=i.top,a=i.left,s=i[r];i.top="",i.left="",i[r]="";var l=I(e.instance.popper,e.instance.reference,t.padding,n,e.positionFixed);i.top=o,i.left=a,i[r]=s,t.boundaries=l;var c=t.priority,u=e.offsets.popper,d={primary:function(e){var n=u[e];return u[e]<l[e]&&!t.escapeWithReference&&(n=Math.max(u[e],l[e])),A({},e,n)},secondary:function(e){var n="right"===e?"left":"top",r=u[n];return u[e]>l[e]&&!t.escapeWithReference&&(r=Math.min(u[n],l[e]-("right"===e?u.width:u.height))),A({},n,r)}};return c.forEach((function(e){var t=-1!==["left","top"].indexOf(e)?"primary":"secondary";u=C({},u,d[t](e))})),e.offsets.popper=u,e},priority:["left","right","top","bottom"],padding:5,boundariesElement:"scrollParent"},keepTogether:{order:400,enabled:!0,fn:function(e){var t=e.offsets,n=t.popper,r=t.reference,i=e.placement.split("-")[0],o=Math.floor,a=-1!==["top","bottom"].indexOf(i),s=a?"right":"bottom",l=a?"left":"top",c=a?"width":"height";return n[s]<o(r[l])&&(e.offsets.popper[l]=o(r[l])-n[c]),n[l]>o(r[s])&&(e.offsets.popper[l]=o(r[s])),e}},arrow:{order:500,enabled:!0,fn:function(e,t){var n;if(!Q(e.instance.modifiers,"arrow","keepTogether"))return e;var r=t.element;if("string"==typeof r){if(!(r=e.instance.popper.querySelector(r)))return e}else if(!e.instance.popper.contains(r))return console.warn("WARNING: `arrow.element` must be child of its popper element!"),e;var i=e.placement.split("-")[0],o=e.offsets,s=o.popper,l=o.reference,c=-1!==["left","right"].indexOf(i),u=c?"height":"width",d=c?"Top":"Left",h=d.toLowerCase(),p=c?"left":"top",f=c?"bottom":"right",m=j(r)[u];l[f]-m<s[h]&&(e.offsets.popper[h]-=s[h]-(l[f]-m)),l[h]+m>s[f]&&(e.offsets.popper[h]+=l[h]+m-s[f]),e.offsets.popper=x(e.offsets.popper);var g=l[h]+l[u]/2-m/2,v=a(e.instance.popper),y=parseFloat(v["margin"+d]),_=parseFloat(v["border"+d+"Width"]),b=g-e.offsets.popper[h]-y-_;return b=Math.max(Math.min(s[u]-m,b),0),e.arrowElement=r,e.offsets.arrow=(A(n={},h,Math.round(b)),A(n,p,""),n),e},element:"[x-arrow]"},flip:{order:600,enabled:!0,fn:function(e,t){if(F(e.instance.modifiers,"inner"))return e;if(e.flipped&&e.placement===e.originalPlacement)return e;var n=I(e.instance.popper,e.instance.reference,t.padding,t.boundariesElement,e.positionFixed),r=e.placement.split("-")[0],i=P(r),o=e.placement.split("-")[1]||"",a=[];switch(t.behavior){case te:a=[r,i];break;case ne:a=ee(r);break;case re:a=ee(r,!0);break;default:a=t.behavior}return a.forEach((function(s,l){if(r!==s||a.length===l+1)return e;r=e.placement.split("-")[0],i=P(r);var c=e.offsets.popper,u=e.offsets.reference,d=Math.floor,h="left"===r&&d(c.right)>d(u.left)||"right"===r&&d(c.left)<d(u.right)||"top"===r&&d(c.bottom)>d(u.top)||"bottom"===r&&d(c.top)<d(u.bottom),p=d(c.left)<d(n.left),f=d(c.right)>d(n.right),m=d(c.top)<d(n.top),g=d(c.bottom)>d(n.bottom),v="left"===r&&p||"right"===r&&f||"top"===r&&m||"bottom"===r&&g,y=-1!==["top","bottom"].indexOf(r),_=!!t.flipVariations&&(y&&"start"===o&&p||y&&"end"===o&&f||!y&&"start"===o&&m||!y&&"end"===o&&g),b=!!t.flipVariationsByContent&&(y&&"start"===o&&f||y&&"end"===o&&p||!y&&"start"===o&&g||!y&&"end"===o&&m),M=_||b;(h||v||M)&&(e.flipped=!0,(h||v)&&(r=a[l+1]),M&&(o=function(e){return"end"===e?"start":"start"===e?"end":e}(o)),e.placement=r+(o?"-"+o:""),e.offsets.popper=C({},e.offsets.popper,z(e.instance.popper,e.offsets.reference,e.placement)),e=B(e.instance.modifiers,e,"flip"))})),e},behavior:"flip",padding:5,boundariesElement:"viewport",flipVariations:!1,flipVariationsByContent:!1},inner:{order:700,enabled:!1,fn:function(e){var t=e.placement,n=t.split("-")[0],r=e.offsets,i=r.popper,o=r.reference,a=-1!==["left","right"].indexOf(n),s=-1===["top","left"].indexOf(n);return i[a?"left":"top"]=o[n]-(s?i[a?"width":"height"]:0),e.placement=P(t),e.offsets.popper=x(i),e}},hide:{order:800,enabled:!0,fn:function(e){if(!Q(e.instance.modifiers,"hide","preventOverflow"))return e;var t=e.offsets.reference,n=R(e.instance.modifiers,(function(e){return"preventOverflow"===e.name})).boundaries;if(t.bottom<n.top||t.left>n.right||t.top>n.bottom||t.right<n.left){if(!0===e.hide)return e;e.hide=!0,e.attributes["x-out-of-boundaries"]=""}else{if(!1===e.hide)return e;e.hide=!1,e.attributes["x-out-of-boundaries"]=!1}return e}},computeStyle:{order:850,enabled:!0,fn:function(e,t){var n=t.x,r=t.y,i=e.offsets.popper,o=R(e.instance.modifiers,(function(e){return"applyStyle"===e.name})).gpuAcceleration;void 0!==o&&console.warn("WARNING: `gpuAcceleration` option moved to `computeStyle` modifier and will not be supported in future versions of Popper.js!");var a=void 0!==o?o:t.gpuAcceleration,s=p(e.instance.popper),l=E(s),c={position:i.position},u=function(e,t){var n=e.offsets,r=n.popper,i=n.reference,o=Math.round,a=Math.floor,s=function(e){return e},l=o(i.width),c=o(r.width),u=-1!==["left","right"].indexOf(e.placement),d=-1!==e.placement.indexOf("-"),h=t?u||d||l%2==c%2?o:a:s,p=t?o:s;return{left:h(l%2==1&&c%2==1&&!d&&t?r.left-1:r.left),top:p(r.top),bottom:p(r.bottom),right:h(r.right)}}(e,window.devicePixelRatio<2||!J),d="bottom"===n?"top":"bottom",h="right"===r?"left":"right",f=Y("transform"),m=void 0,g=void 0;if(g="bottom"===d?"HTML"===s.nodeName?-s.clientHeight+u.bottom:-l.height+u.bottom:u.top,m="right"===h?"HTML"===s.nodeName?-s.clientWidth+u.right:-l.width+u.right:u.left,a&&f)c[f]="translate3d("+m+"px, "+g+"px, 0)",c[d]=0,c[h]=0,c.willChange="transform";else{var v="bottom"===d?-1:1,y="right"===h?-1:1;c[d]=g*v,c[h]=m*y,c.willChange=d+", "+h}var _={"x-placement":e.placement};return e.attributes=C({},_,e.attributes),e.styles=C({},c,e.styles),e.arrowStyles=C({},e.offsets.arrow,e.arrowStyles),e},gpuAcceleration:!0,x:"bottom",y:"right"},applyStyle:{order:900,enabled:!0,fn:function(e){var t,n;return X(e.instance.popper,e.styles),t=e.instance.popper,n=e.attributes,Object.keys(n).forEach((function(e){!1!==n[e]?t.setAttribute(e,n[e]):t.removeAttribute(e)})),e.arrowElement&&Object.keys(e.arrowStyles).length&&X(e.arrowElement,e.arrowStyles),e},onLoad:function(e,t,n,r,i){var o=N(i,t,e,n.positionFixed),a=D(n.placement,o,t,e,n.modifiers.flip.boundariesElement,n.modifiers.flip.padding);return t.setAttribute("x-placement",a),X(t,{position:n.positionFixed?"fixed":"absolute"}),n},gpuAcceleration:void 0}}},ae=function(){function e(t,n){var r=this,a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};M(this,e),this.scheduleUpdate=function(){return requestAnimationFrame(r.update)},this.update=i(this.update.bind(this)),this.options=C({},e.Defaults,a),this.state={isDestroyed:!1,isCreated:!1,scrollParents:[]},this.reference=t&&t.jquery?t[0]:t,this.popper=n&&n.jquery?n[0]:n,this.options.modifiers={},Object.keys(C({},e.Defaults.modifiers,a.modifiers)).forEach((function(t){r.options.modifiers[t]=C({},e.Defaults.modifiers[t]||{},a.modifiers?a.modifiers[t]:{})})),this.modifiers=Object.keys(this.options.modifiers).map((function(e){return C({name:e},r.options.modifiers[e])})).sort((function(e,t){return e.order-t.order})),this.modifiers.forEach((function(e){e.enabled&&o(e.onLoad)&&e.onLoad(r.reference,r.popper,r.options,e,r.state)})),this.update();var s=this.options.eventsEnabled;s&&this.enableEventListeners(),this.state.eventsEnabled=s}return w(e,[{key:"update",value:function(){return H.call(this)}},{key:"destroy",value:function(){return V.call(this)}},{key:"enableEventListeners",value:function(){return G.call(this)}},{key:"disableEventListeners",value:function(){return q.call(this)}}]),e}();ae.Utils=("undefined"!=typeof window?window:e).PopperUtils,ae.placements=Z,ae.Defaults=oe,t.a=ae}).call(this,n(55))},function(e,t,n){e.exports=function(){"use strict";function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}function t(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function n(e,n){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(r)return(r=r.call(e)).next.bind(r);if(Array.isArray(e)||(r=function(e,n){if(e){if("string"==typeof e)return t(e,n);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?t(e,n):void 0}}(e))||n&&e&&"number"==typeof e.length){r&&(e=r);var i=0;return function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var r={exports:{}};function i(){return{baseUrl:null,breaks:!1,extensions:null,gfm:!0,headerIds:!0,headerPrefix:"",highlight:null,langPrefix:"language-",mangle:!0,pedantic:!1,renderer:null,sanitize:!1,sanitizer:null,silent:!1,smartLists:!1,smartypants:!1,tokenizer:null,walkTokens:null,xhtml:!1}}r.exports={defaults:{baseUrl:null,breaks:!1,extensions:null,gfm:!0,headerIds:!0,headerPrefix:"",highlight:null,langPrefix:"language-",mangle:!0,pedantic:!1,renderer:null,sanitize:!1,sanitizer:null,silent:!1,smartLists:!1,smartypants:!1,tokenizer:null,walkTokens:null,xhtml:!1},getDefaults:i,changeDefaults:function(e){r.exports.defaults=e}};var o=/[&<>"']/,a=/[&<>"']/g,s=/[<>"']|&(?!#?\w+;)/,l=/[<>"']|&(?!#?\w+;)/g,c={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},u=function(e){return c[e]},d=/&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/gi;function h(e){return e.replace(d,(function(e,t){return"colon"===(t=t.toLowerCase())?":":"#"===t.charAt(0)?"x"===t.charAt(1)?String.fromCharCode(parseInt(t.substring(2),16)):String.fromCharCode(+t.substring(1)):""}))}var p=/(^|[^\[])\^/g,f=/[^\w:]/g,m=/^$|^[a-z][a-z0-9+.-]*:|^[?#]/i,g={},v=/^[^:]+:\/*[^/]*$/,y=/^([^:]+:)[\s\S]*$/,_=/^([^:]+:\/*[^/]*)[\s\S]*$/;function b(e,t){g[" "+e]||(v.test(e)?g[" "+e]=e+"/":g[" "+e]=M(e,"/",!0));var n=-1===(e=g[" "+e]).indexOf(":");return"//"===t.substring(0,2)?n?t:e.replace(y,"$1")+t:"/"===t.charAt(0)?n?t:e.replace(_,"$1")+t:e+t}function M(e,t,n){var r=e.length;if(0===r)return"";for(var i=0;i<r;){var o=e.charAt(r-i-1);if(o!==t||n){if(o===t||!n)break;i++}else i++}return e.substr(0,r-i)}var w=function(e,t){if(t){if(o.test(e))return e.replace(a,u)}else if(s.test(e))return e.replace(l,u);return e},A=h,C=function(e,t){e=e.source||e,t=t||"";var n={replace:function(t,r){return r=(r=r.source||r).replace(p,"$1"),e=e.replace(t,r),n},getRegex:function(){return new RegExp(e,t)}};return n},x=function(e,t,n){if(e){var r;try{r=decodeURIComponent(h(n)).replace(f,"").toLowerCase()}catch(e){return null}if(0===r.indexOf("javascript:")||0===r.indexOf("vbscript:")||0===r.indexOf("data:"))return null}t&&!m.test(n)&&(n=b(t,n));try{n=encodeURI(n).replace(/%25/g,"%")}catch(e){return null}return n},E={exec:function(){}},L=function(e){for(var t,n,r=1;r<arguments.length;r++)for(n in t=arguments[r])Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e},S=function(e,t){var n=e.replace(/\|/g,(function(e,t,n){for(var r=!1,i=t;--i>=0&&"\\"===n[i];)r=!r;return r?"|":" |"})).split(/ \|/),r=0;if(n.length>t)n.splice(t);else for(;n.length<t;)n.push("");for(;r<n.length;r++)n[r]=n[r].trim().replace(/\\\|/g,"|");return n},T=M,O=function(e,t){if(-1===e.indexOf(t[1]))return-1;for(var n=e.length,r=0,i=0;i<n;i++)if("\\"===e[i])i++;else if(e[i]===t[0])r++;else if(e[i]===t[1]&&--r<0)return i;return-1},I=function(e){e&&e.sanitize&&!e.silent&&console.warn("marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options")},k=function(e,t){if(t<1)return"";for(var n="";t>1;)1&t&&(n+=e),t>>=1,e+=e;return n+e},D=r.exports.defaults,N=T,j=S,P=w,z=O;function R(e,t,n){var r=t.href,i=t.title?P(t.title):null,o=e[1].replace(/\\([\[\]])/g,"$1");return"!"!==e[0].charAt(0)?{type:"link",raw:n,href:r,title:i,text:o}:{type:"image",raw:n,href:r,title:i,text:P(o)}}var B=function(){function e(e){this.options=e||D}var t=e.prototype;return t.space=function(e){var t=this.rules.block.newline.exec(e);if(t)return t[0].length>1?{type:"space",raw:t[0]}:{raw:"\n"}},t.code=function(e){var t=this.rules.block.code.exec(e);if(t){var n=t[0].replace(/^ {1,4}/gm,"");return{type:"code",raw:t[0],codeBlockStyle:"indented",text:this.options.pedantic?n:N(n,"\n")}}},t.fences=function(e){var t=this.rules.block.fences.exec(e);if(t){var n=t[0],r=function(e,t){var n=e.match(/^(\s+)(?:```)/);if(null===n)return t;var r=n[1];return t.split("\n").map((function(e){var t=e.match(/^\s+/);return null===t?e:t[0].length>=r.length?e.slice(r.length):e})).join("\n")}(n,t[3]||"");return{type:"code",raw:n,lang:t[2]?t[2].trim():t[2],text:r}}},t.heading=function(e){var t=this.rules.block.heading.exec(e);if(t){var n=t[2].trim();if(/#$/.test(n)){var r=N(n,"#");this.options.pedantic?n=r.trim():r&&!/ $/.test(r)||(n=r.trim())}return{type:"heading",raw:t[0],depth:t[1].length,text:n}}},t.nptable=function(e){var t=this.rules.block.nptable.exec(e);if(t){var n={type:"table",header:j(t[1].replace(/^ *| *\| *$/g,"")),align:t[2].replace(/^ *|\| *$/g,"").split(/ *\| */),cells:t[3]?t[3].replace(/\n$/,"").split("\n"):[],raw:t[0]};if(n.header.length===n.align.length){var r,i=n.align.length;for(r=0;r<i;r++)/^ *-+: *$/.test(n.align[r])?n.align[r]="right":/^ *:-+: *$/.test(n.align[r])?n.align[r]="center":/^ *:-+ *$/.test(n.align[r])?n.align[r]="left":n.align[r]=null;for(i=n.cells.length,r=0;r<i;r++)n.cells[r]=j(n.cells[r],n.header.length);return n}}},t.hr=function(e){var t=this.rules.block.hr.exec(e);if(t)return{type:"hr",raw:t[0]}},t.blockquote=function(e){var t=this.rules.block.blockquote.exec(e);if(t){var n=t[0].replace(/^ *> ?/gm,"");return{type:"blockquote",raw:t[0],text:n}}},t.list=function(e){var t=this.rules.block.list.exec(e);if(t){var n,r,i,o,a,s,l,c,u,d=t[0],h=t[2],p=h.length>1,f={type:"list",raw:d,ordered:p,start:p?+h.slice(0,-1):"",loose:!1,items:[]},m=t[0].match(this.rules.block.item),g=!1,v=m.length;i=this.rules.block.listItemStart.exec(m[0]);for(var y=0;y<v;y++){if(d=n=m[y],this.options.pedantic||(u=n.match(new RegExp("\\n\\s*\\n {0,"+(i[0].length-1)+"}\\S")))&&(a=n.length-u.index+m.slice(y+1).join("\n").length,f.raw=f.raw.substring(0,f.raw.length-a),d=n=n.substring(0,u.index),v=y+1),y!==v-1){if(o=this.rules.block.listItemStart.exec(m[y+1]),this.options.pedantic?o[1].length>i[1].length:o[1].length>=i[0].length||o[1].length>3){m.splice(y,2,m[y]+(!this.options.pedantic&&o[1].length<i[0].length&&!m[y].match(/\n$/)?"":"\n")+m[y+1]),y--,v--;continue}(!this.options.pedantic||this.options.smartLists?o[2][o[2].length-1]!==h[h.length-1]:p===(1===o[2].length))&&(a=m.slice(y+1).join("\n").length,f.raw=f.raw.substring(0,f.raw.length-a),y=v-1),i=o}r=n.length,~(n=n.replace(/^ *([*+-]|\d+[.)]) ?/,"")).indexOf("\n ")&&(r-=n.length,n=this.options.pedantic?n.replace(/^ {1,4}/gm,""):n.replace(new RegExp("^ {1,"+r+"}","gm"),"")),n=N(n,"\n"),y!==v-1&&(d+="\n"),s=g||/\n\n(?!\s*$)/.test(d),y!==v-1&&(g="\n\n"===d.slice(-2),s||(s=g)),s&&(f.loose=!0),this.options.gfm&&(c=void 0,(l=/^\[[ xX]\] /.test(n))&&(c=" "!==n[1],n=n.replace(/^\[[ xX]\] +/,""))),f.items.push({type:"list_item",raw:d,task:l,checked:c,loose:s,text:n})}return f}},t.html=function(e){var t=this.rules.block.html.exec(e);if(t)return{type:this.options.sanitize?"paragraph":"html",raw:t[0],pre:!this.options.sanitizer&&("pre"===t[1]||"script"===t[1]||"style"===t[1]),text:this.options.sanitize?this.options.sanitizer?this.options.sanitizer(t[0]):P(t[0]):t[0]}},t.def=function(e){var t=this.rules.block.def.exec(e);if(t)return t[3]&&(t[3]=t[3].substring(1,t[3].length-1)),{type:"def",tag:t[1].toLowerCase().replace(/\s+/g," "),raw:t[0],href:t[2],title:t[3]}},t.table=function(e){var t=this.rules.block.table.exec(e);if(t){var n={type:"table",header:j(t[1].replace(/^ *| *\| *$/g,"")),align:t[2].replace(/^ *|\| *$/g,"").split(/ *\| */),cells:t[3]?t[3].replace(/\n$/,"").split("\n"):[]};if(n.header.length===n.align.length){n.raw=t[0];var r,i=n.align.length;for(r=0;r<i;r++)/^ *-+: *$/.test(n.align[r])?n.align[r]="right":/^ *:-+: *$/.test(n.align[r])?n.align[r]="center":/^ *:-+ *$/.test(n.align[r])?n.align[r]="left":n.align[r]=null;for(i=n.cells.length,r=0;r<i;r++)n.cells[r]=j(n.cells[r].replace(/^ *\| *| *\| *$/g,""),n.header.length);return n}}},t.lheading=function(e){var t=this.rules.block.lheading.exec(e);if(t)return{type:"heading",raw:t[0],depth:"="===t[2].charAt(0)?1:2,text:t[1]}},t.paragraph=function(e){var t=this.rules.block.paragraph.exec(e);if(t)return{type:"paragraph",raw:t[0],text:"\n"===t[1].charAt(t[1].length-1)?t[1].slice(0,-1):t[1]}},t.text=function(e){var t=this.rules.block.text.exec(e);if(t)return{type:"text",raw:t[0],text:t[0]}},t.escape=function(e){var t=this.rules.inline.escape.exec(e);if(t)return{type:"escape",raw:t[0],text:P(t[1])}},t.tag=function(e,t,n){var r=this.rules.inline.tag.exec(e);if(r)return!t&&/^<a /i.test(r[0])?t=!0:t&&/^<\/a>/i.test(r[0])&&(t=!1),!n&&/^<(pre|code|kbd|script)(\s|>)/i.test(r[0])?n=!0:n&&/^<\/(pre|code|kbd|script)(\s|>)/i.test(r[0])&&(n=!1),{type:this.options.sanitize?"text":"html",raw:r[0],inLink:t,inRawBlock:n,text:this.options.sanitize?this.options.sanitizer?this.options.sanitizer(r[0]):P(r[0]):r[0]}},t.link=function(e){var t=this.rules.inline.link.exec(e);if(t){var n=t[2].trim();if(!this.options.pedantic&&/^</.test(n)){if(!/>$/.test(n))return;var r=N(n.slice(0,-1),"\\");if((n.length-r.length)%2==0)return}else{var i=z(t[2],"()");if(i>-1){var o=(0===t[0].indexOf("!")?5:4)+t[1].length+i;t[2]=t[2].substring(0,i),t[0]=t[0].substring(0,o).trim(),t[3]=""}}var a=t[2],s="";if(this.options.pedantic){var l=/^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(a);l&&(a=l[1],s=l[3])}else s=t[3]?t[3].slice(1,-1):"";return a=a.trim(),/^</.test(a)&&(a=this.options.pedantic&&!/>$/.test(n)?a.slice(1):a.slice(1,-1)),R(t,{href:a?a.replace(this.rules.inline._escapes,"$1"):a,title:s?s.replace(this.rules.inline._escapes,"$1"):s},t[0])}},t.reflink=function(e,t){var n;if((n=this.rules.inline.reflink.exec(e))||(n=this.rules.inline.nolink.exec(e))){var r=(n[2]||n[1]).replace(/\s+/g," ");if(!(r=t[r.toLowerCase()])||!r.href){var i=n[0].charAt(0);return{type:"text",raw:i,text:i}}return R(n,r,n[0])}},t.emStrong=function(e,t,n){void 0===n&&(n="");var r=this.rules.inline.emStrong.lDelim.exec(e);if(r&&(!r[3]||!n.match(/(?:[0-9A-Za-z\xAA\xB2\xB3\xB5\xB9\xBA\xBC-\xBE\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u0660-\u0669\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07C0-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08C7\u0904-\u0939\u093D\u0950\u0958-\u0961\u0966-\u096F\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09E6-\u09F1\u09F4-\u09F9\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A66-\u0A6F\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AE6-\u0AEF\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B66-\u0B6F\u0B71-\u0B77\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0BE6-\u0BF2\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C66-\u0C6F\u0C78-\u0C7E\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CE6-\u0CEF\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D58-\u0D61\u0D66-\u0D78\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DE6-\u0DEF\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F20-\u0F33\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F-\u1049\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u1090-\u1099\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1369-\u137C\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1820-\u1878\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A16\u1A20-\u1A54\u1A80-\u1A89\u1A90-\u1A99\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B50-\u1B59\u1B83-\u1BA0\u1BAE-\u1BE5\u1C00-\u1C23\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2070\u2071\u2074-\u2079\u207F-\u2089\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2150-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2CFD\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u3192-\u3195\u31A0-\u31BF\u31F0-\u31FF\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\u3400-\u4DBF\u4E00-\u9FFC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7BF\uA7C2-\uA7CA\uA7F5-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA830-\uA835\uA840-\uA873\uA882-\uA8B3\uA8D0-\uA8D9\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA900-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF-\uA9D9\uA9E0-\uA9E4\uA9E6-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA50-\uAA59\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD07-\uDD33\uDD40-\uDD78\uDD8A\uDD8B\uDE80-\uDE9C\uDEA0-\uDED0\uDEE1-\uDEFB\uDF00-\uDF23\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC58-\uDC76\uDC79-\uDC9E\uDCA7-\uDCAF\uDCE0-\uDCF2\uDCF4\uDCF5\uDCFB-\uDD1B\uDD20-\uDD39\uDD80-\uDDB7\uDDBC-\uDDCF\uDDD2-\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE35\uDE40-\uDE48\uDE60-\uDE7E\uDE80-\uDE9F\uDEC0-\uDEC7\uDEC9-\uDEE4\uDEEB-\uDEEF\uDF00-\uDF35\uDF40-\uDF55\uDF58-\uDF72\uDF78-\uDF91\uDFA9-\uDFAF]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2\uDCFA-\uDD23\uDD30-\uDD39\uDE60-\uDE7E\uDE80-\uDEA9\uDEB0\uDEB1\uDF00-\uDF27\uDF30-\uDF45\uDF51-\uDF54\uDFB0-\uDFCB\uDFE0-\uDFF6]|\uD804[\uDC03-\uDC37\uDC52-\uDC6F\uDC83-\uDCAF\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD03-\uDD26\uDD36-\uDD3F\uDD44\uDD47\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDD0-\uDDDA\uDDDC\uDDE1-\uDDF4\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDEF0-\uDEF9\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC50-\uDC59\uDC5F-\uDC61\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE50-\uDE59\uDE80-\uDEAA\uDEB8\uDEC0-\uDEC9\uDF00-\uDF1A\uDF30-\uDF3B]|\uD806[\uDC00-\uDC2B\uDCA0-\uDCF2\uDCFF-\uDD06\uDD09\uDD0C-\uDD13\uDD15\uDD16\uDD18-\uDD2F\uDD3F\uDD41\uDD50-\uDD59\uDDA0-\uDDA7\uDDAA-\uDDD0\uDDE1\uDDE3\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE89\uDE9D\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC50-\uDC6C\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46\uDD50-\uDD59\uDD60-\uDD65\uDD67\uDD68\uDD6A-\uDD89\uDD98\uDDA0-\uDDA9\uDEE0-\uDEF2\uDFB0\uDFC0-\uDFD4]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD822\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879\uD880-\uD883][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF50-\uDF59\uDF5B-\uDF61\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDE40-\uDE96\uDF00-\uDF4A\uDF50\uDF93-\uDF9F\uDFE0\uDFE1\uDFE3]|\uD821[\uDC00-\uDFF7]|\uD823[\uDC00-\uDCD5\uDD00-\uDD08]|\uD82C[\uDC00-\uDD1E\uDD50-\uDD52\uDD64-\uDD67\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD834[\uDEE0-\uDEF3\uDF60-\uDF78]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD838[\uDD00-\uDD2C\uDD37-\uDD3D\uDD40-\uDD49\uDD4E\uDEC0-\uDEEB\uDEF0-\uDEF9]|\uD83A[\uDC00-\uDCC4\uDCC7-\uDCCF\uDD00-\uDD43\uDD4B\uDD50-\uDD59]|\uD83B[\uDC71-\uDCAB\uDCAD-\uDCAF\uDCB1-\uDCB4\uDD01-\uDD2D\uDD2F-\uDD3D\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD83C[\uDD00-\uDD0C]|\uD83E[\uDFF0-\uDFF9]|\uD869[\uDC00-\uDEDD\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uD884[\uDC00-\uDF4A])/))){var i=r[1]||r[2]||"";if(!i||i&&(""===n||this.rules.inline.punctuation.exec(n))){var o,a,s=r[0].length-1,l=s,c=0,u="*"===r[0][0]?this.rules.inline.emStrong.rDelimAst:this.rules.inline.emStrong.rDelimUnd;for(u.lastIndex=0,t=t.slice(-1*e.length+s);null!=(r=u.exec(t));)if(o=r[1]||r[2]||r[3]||r[4]||r[5]||r[6])if(a=o.length,r[3]||r[4])l+=a;else if(!((r[5]||r[6])&&s%3)||(s+a)%3){if(!((l-=a)>0))return a=Math.min(a,a+l+c),Math.min(s,a)%2?{type:"em",raw:e.slice(0,s+r.index+a+1),text:e.slice(1,s+r.index+a)}:{type:"strong",raw:e.slice(0,s+r.index+a+1),text:e.slice(2,s+r.index+a-1)}}else c+=a}}},t.codespan=function(e){var t=this.rules.inline.code.exec(e);if(t){var n=t[2].replace(/\n/g," "),r=/[^ ]/.test(n),i=/^ /.test(n)&&/ $/.test(n);return r&&i&&(n=n.substring(1,n.length-1)),n=P(n,!0),{type:"codespan",raw:t[0],text:n}}},t.br=function(e){var t=this.rules.inline.br.exec(e);if(t)return{type:"br",raw:t[0]}},t.del=function(e){var t=this.rules.inline.del.exec(e);if(t)return{type:"del",raw:t[0],text:t[2]}},t.autolink=function(e,t){var n,r,i=this.rules.inline.autolink.exec(e);if(i)return r="@"===i[2]?"mailto:"+(n=P(this.options.mangle?t(i[1]):i[1])):n=P(i[1]),{type:"link",raw:i[0],text:n,href:r,tokens:[{type:"text",raw:n,text:n}]}},t.url=function(e,t){var n;if(n=this.rules.inline.url.exec(e)){var r,i;if("@"===n[2])i="mailto:"+(r=P(this.options.mangle?t(n[0]):n[0]));else{var o;do{o=n[0],n[0]=this.rules.inline._backpedal.exec(n[0])[0]}while(o!==n[0]);r=P(n[0]),i="www."===n[1]?"http://"+r:r}return{type:"link",raw:n[0],text:r,href:i,tokens:[{type:"text",raw:r,text:r}]}}},t.inlineText=function(e,t,n){var r,i=this.rules.inline.text.exec(e);if(i)return r=t?this.options.sanitize?this.options.sanitizer?this.options.sanitizer(i[0]):P(i[0]):i[0]:P(this.options.smartypants?n(i[0]):i[0]),{type:"text",raw:i[0],text:r}},e}(),H=E,F=C,Y=L,V={newline:/^(?: *(?:\n|$))+/,code:/^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/,fences:/^ {0,3}(`{3,}(?=[^`\n]*\n)|~{3,})([^\n]*)\n(?:|([\s\S]*?)\n)(?: {0,3}\1[~`]* *(?:\n+|$)|$)/,hr:/^ {0,3}((?:- *){3,}|(?:_ *){3,}|(?:\* *){3,})(?:\n+|$)/,heading:/^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/,blockquote:/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/,list:/^( {0,3})(bull) [\s\S]+?(?:hr|def|\n{2,}(?! )(?! {0,3}bull )\n*|\s*$)/,html:"^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))",def:/^ {0,3}\[(label)\]: *\n? *<?([^\s>]+)>?(?:(?: +\n? *| *\n *)(title))? *(?:\n+|$)/,nptable:H,table:H,lheading:/^([^\n]+)\n {0,3}(=+|-+) *(?:\n+|$)/,_paragraph:/^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html| +\n)[^\n]+)*)/,text:/^[^\n]+/,_label:/(?!\s*\])(?:\\[\[\]]|[^\[\]])+/,_title:/(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/};V.def=F(V.def).replace("label",V._label).replace("title",V._title).getRegex(),V.bullet=/(?:[*+-]|\d{1,9}[.)])/,V.item=/^( *)(bull) ?[^\n]*(?:\n(?! *bull ?)[^\n]*)*/,V.item=F(V.item,"gm").replace(/bull/g,V.bullet).getRegex(),V.listItemStart=F(/^( *)(bull) */).replace("bull",V.bullet).getRegex(),V.list=F(V.list).replace(/bull/g,V.bullet).replace("hr","\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))").replace("def","\\n+(?="+V.def.source+")").getRegex(),V._tag="address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul",V._comment=/<!--(?!-?>)[\s\S]*?(?:-->|$)/,V.html=F(V.html,"i").replace("comment",V._comment).replace("tag",V._tag).replace("attribute",/ +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(),V.paragraph=F(V._paragraph).replace("hr",V.hr).replace("heading"," {0,3}#{1,6} ").replace("|lheading","").replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",V._tag).getRegex(),V.blockquote=F(V.blockquote).replace("paragraph",V.paragraph).getRegex(),V.normal=Y({},V),V.gfm=Y({},V.normal,{nptable:"^ *([^|\\n ].*\\|.*)\\n {0,3}([-:]+ *\\|[-| :]*)(?:\\n((?:(?!\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)",table:"^ *\\|(.+)\\n {0,3}\\|?( *[-:]+[-| :]*)(?:\\n *((?:(?!\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)"}),V.gfm.nptable=F(V.gfm.nptable).replace("hr",V.hr).replace("heading"," {0,3}#{1,6} ").replace("blockquote"," {0,3}>").replace("code"," {4}[^\\n]").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",V._tag).getRegex(),V.gfm.table=F(V.gfm.table).replace("hr",V.hr).replace("heading"," {0,3}#{1,6} ").replace("blockquote"," {0,3}>").replace("code"," {4}[^\\n]").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",V._tag).getRegex(),V.pedantic=Y({},V.normal,{html:F("^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:\"[^\"]*\"|'[^']*'|\\s[^'\"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))").replace("comment",V._comment).replace(/tag/g,"(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),def:/^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,heading:/^(#{1,6})(.*)(?:\n+|$)/,fences:H,paragraph:F(V.normal._paragraph).replace("hr",V.hr).replace("heading"," *#{1,6} *[^\n]").replace("lheading",V.lheading).replace("blockquote"," {0,3}>").replace("|fences","").replace("|list","").replace("|html","").getRegex()});var U={escape:/^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/,autolink:/^<(scheme:[^\s\x00-\x1f<>]*|email)>/,url:H,tag:"^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>",link:/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/,reflink:/^!?\[(label)\]\[(?!\s*\])((?:\\[\[\]]?|[^\[\]\\])+)\]/,nolink:/^!?\[(?!\s*\])((?:\[[^\[\]]*\]|\\[\[\]]|[^\[\]])*)\](?:\[\])?/,reflinkSearch:"reflink|nolink(?!\\()",emStrong:{lDelim:/^(?:\*+(?:([punct_])|[^\s*]))|^_+(?:([punct*])|([^\s_]))/,rDelimAst:/\_\_[^_*]*?\*[^_*]*?\_\_|[punct_](\*+)(?=[\s]|$)|[^punct*_\s](\*+)(?=[punct_\s]|$)|[punct_\s](\*+)(?=[^punct*_\s])|[\s](\*+)(?=[punct_])|[punct_](\*+)(?=[punct_])|[^punct*_\s](\*+)(?=[^punct*_\s])/,rDelimUnd:/\*\*[^_*]*?\_[^_*]*?\*\*|[punct*](\_+)(?=[\s]|$)|[^punct*_\s](\_+)(?=[punct*\s]|$)|[punct*\s](\_+)(?=[^punct*_\s])|[\s](\_+)(?=[punct*])|[punct*](\_+)(?=[punct*])/},code:/^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/,br:/^( {2,}|\\)\n(?!\s*$)/,del:H,text:/^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/,punctuation:/^([\spunctuation])/,_punctuation:"!\"#$%&'()+\\-.,/:;<=>?@\\[\\]`^{|}~"};U.punctuation=F(U.punctuation).replace(/punctuation/g,U._punctuation).getRegex(),U.blockSkip=/\[[^\]]*?\]\([^\)]*?\)|`[^`]*?`|<[^>]*?>/g,U.escapedEmSt=/\\\*|\\_/g,U._comment=F(V._comment).replace("(?:--\x3e|$)","--\x3e").getRegex(),U.emStrong.lDelim=F(U.emStrong.lDelim).replace(/punct/g,U._punctuation).getRegex(),U.emStrong.rDelimAst=F(U.emStrong.rDelimAst,"g").replace(/punct/g,U._punctuation).getRegex(),U.emStrong.rDelimUnd=F(U.emStrong.rDelimUnd,"g").replace(/punct/g,U._punctuation).getRegex(),U._escapes=/\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g,U._scheme=/[a-zA-Z][a-zA-Z0-9+.-]{1,31}/,U._email=/[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/,U.autolink=F(U.autolink).replace("scheme",U._scheme).replace("email",U._email).getRegex(),U._attribute=/\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/,U.tag=F(U.tag).replace("comment",U._comment).replace("attribute",U._attribute).getRegex(),U._label=/(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/,U._href=/<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/,U._title=/"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/,U.link=F(U.link).replace("label",U._label).replace("href",U._href).replace("title",U._title).getRegex(),U.reflink=F(U.reflink).replace("label",U._label).getRegex(),U.reflinkSearch=F(U.reflinkSearch,"g").replace("reflink",U.reflink).replace("nolink",U.nolink).getRegex(),U.normal=Y({},U),U.pedantic=Y({},U.normal,{strong:{start:/^__|\*\*/,middle:/^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,endAst:/\*\*(?!\*)/g,endUnd:/__(?!_)/g},em:{start:/^_|\*/,middle:/^()\*(?=\S)([\s\S]*?\S)\*(?!\*)|^_(?=\S)([\s\S]*?\S)_(?!_)/,endAst:/\*(?!\*)/g,endUnd:/_(?!_)/g},link:F(/^!?\[(label)\]\((.*?)\)/).replace("label",U._label).getRegex(),reflink:F(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label",U._label).getRegex()}),U.gfm=Y({},U.normal,{escape:F(U.escape).replace("])","~|])").getRegex(),_extended_email:/[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/,url:/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/,_backpedal:/(?:[^?!.,:;*_~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_~)]+(?!$))+/,del:/^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,text:/^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/}),U.gfm.url=F(U.gfm.url,"i").replace("email",U.gfm._extended_email).getRegex(),U.breaks=Y({},U.gfm,{br:F(U.br).replace("{2,}","*").getRegex(),text:F(U.gfm.text).replace("\\b_","\\b_| {2,}\\n").replace(/\{2,\}/g,"*").getRegex()});var W={block:V,inline:U},G=B,q=r.exports.defaults,K=W.block,X=W.inline,J=k;function Q(e){return e.replace(/---/g,"—").replace(/--/g,"–").replace(/(^|[-\u2014/(\[{"\s])'/g,"$1‘").replace(/'/g,"’").replace(/(^|[-\u2014/(\[{\u2018\s])"/g,"$1“").replace(/"/g,"”").replace(/\.{3}/g,"…")}function Z(e){var t,n,r="",i=e.length;for(t=0;t<i;t++)n=e.charCodeAt(t),Math.random()>.5&&(n="x"+n.toString(16)),r+="&#"+n+";";return r}var $=function(){function t(e){this.tokens=[],this.tokens.links=Object.create(null),this.options=e||q,this.options.tokenizer=this.options.tokenizer||new G,this.tokenizer=this.options.tokenizer,this.tokenizer.options=this.options;var t={block:K.normal,inline:X.normal};this.options.pedantic?(t.block=K.pedantic,t.inline=X.pedantic):this.options.gfm&&(t.block=K.gfm,this.options.breaks?t.inline=X.breaks:t.inline=X.gfm),this.tokenizer.rules=t}t.lex=function(e,n){return new t(n).lex(e)},t.lexInline=function(e,n){return new t(n).inlineTokens(e)};var n,r,i,o=t.prototype;return o.lex=function(e){return e=e.replace(/\r\n|\r/g,"\n").replace(/\t/g,"    "),this.blockTokens(e,this.tokens,!0),this.inline(this.tokens),this.tokens},o.blockTokens=function(e,t,n){var r,i,o,a,s,l,c=this;for(void 0===t&&(t=[]),void 0===n&&(n=!0),this.options.pedantic&&(e=e.replace(/^ +$/gm,""));e;)if(!(this.options.extensions&&this.options.extensions.block&&this.options.extensions.block.some((function(n){return!!(r=n.call(c,e,t))&&(e=e.substring(r.raw.length),t.push(r),!0)}))))if(r=this.tokenizer.space(e))e=e.substring(r.raw.length),r.type&&t.push(r);else if(r=this.tokenizer.code(e))e=e.substring(r.raw.length),(a=t[t.length-1])&&"paragraph"===a.type?(a.raw+="\n"+r.raw,a.text+="\n"+r.text):t.push(r);else if(r=this.tokenizer.fences(e))e=e.substring(r.raw.length),t.push(r);else if(r=this.tokenizer.heading(e))e=e.substring(r.raw.length),t.push(r);else if(r=this.tokenizer.nptable(e))e=e.substring(r.raw.length),t.push(r);else if(r=this.tokenizer.hr(e))e=e.substring(r.raw.length),t.push(r);else if(r=this.tokenizer.blockquote(e))e=e.substring(r.raw.length),r.tokens=this.blockTokens(r.text,[],n),t.push(r);else if(r=this.tokenizer.list(e)){for(e=e.substring(r.raw.length),o=r.items.length,i=0;i<o;i++)r.items[i].tokens=this.blockTokens(r.items[i].text,[],!1);t.push(r)}else if(r=this.tokenizer.html(e))e=e.substring(r.raw.length),t.push(r);else if(n&&(r=this.tokenizer.def(e)))e=e.substring(r.raw.length),this.tokens.links[r.tag]||(this.tokens.links[r.tag]={href:r.href,title:r.title});else if(r=this.tokenizer.table(e))e=e.substring(r.raw.length),t.push(r);else if(r=this.tokenizer.lheading(e))e=e.substring(r.raw.length),t.push(r);else if(s=e,this.options.extensions&&this.options.extensions.startBlock&&function(){var t=1/0,n=e.slice(1),r=void 0;c.options.extensions.startBlock.forEach((function(e){"number"==typeof(r=e.call(this,n))&&r>=0&&(t=Math.min(t,r))})),t<1/0&&t>=0&&(s=e.substring(0,t+1))}(),n&&(r=this.tokenizer.paragraph(s)))a=t[t.length-1],l&&"paragraph"===a.type?(a.raw+="\n"+r.raw,a.text+="\n"+r.text):t.push(r),l=s.length!==e.length,e=e.substring(r.raw.length);else if(r=this.tokenizer.text(e))e=e.substring(r.raw.length),(a=t[t.length-1])&&"text"===a.type?(a.raw+="\n"+r.raw,a.text+="\n"+r.text):t.push(r);else if(e){var u="Infinite loop on byte: "+e.charCodeAt(0);if(this.options.silent){console.error(u);break}throw new Error(u)}return t},o.inline=function(e){var t,n,r,i,o,a,s=e.length;for(t=0;t<s;t++)switch((a=e[t]).type){case"paragraph":case"text":case"heading":a.tokens=[],this.inlineTokens(a.text,a.tokens);break;case"table":for(a.tokens={header:[],cells:[]},i=a.header.length,n=0;n<i;n++)a.tokens.header[n]=[],this.inlineTokens(a.header[n],a.tokens.header[n]);for(i=a.cells.length,n=0;n<i;n++)for(o=a.cells[n],a.tokens.cells[n]=[],r=0;r<o.length;r++)a.tokens.cells[n][r]=[],this.inlineTokens(o[r],a.tokens.cells[n][r]);break;case"blockquote":this.inline(a.tokens);break;case"list":for(i=a.items.length,n=0;n<i;n++)this.inline(a.items[n].tokens)}return e},o.inlineTokens=function(e,t,n,r){var i,o,a,s=this;void 0===t&&(t=[]),void 0===n&&(n=!1),void 0===r&&(r=!1);var l,c,u,d=e;if(this.tokens.links){var h=Object.keys(this.tokens.links);if(h.length>0)for(;null!=(l=this.tokenizer.rules.inline.reflinkSearch.exec(d));)h.includes(l[0].slice(l[0].lastIndexOf("[")+1,-1))&&(d=d.slice(0,l.index)+"["+J("a",l[0].length-2)+"]"+d.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex))}for(;null!=(l=this.tokenizer.rules.inline.blockSkip.exec(d));)d=d.slice(0,l.index)+"["+J("a",l[0].length-2)+"]"+d.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);for(;null!=(l=this.tokenizer.rules.inline.escapedEmSt.exec(d));)d=d.slice(0,l.index)+"++"+d.slice(this.tokenizer.rules.inline.escapedEmSt.lastIndex);for(;e;)if(c||(u=""),c=!1,!(this.options.extensions&&this.options.extensions.inline&&this.options.extensions.inline.some((function(n){return!!(i=n.call(s,e,t))&&(e=e.substring(i.raw.length),t.push(i),!0)}))))if(i=this.tokenizer.escape(e))e=e.substring(i.raw.length),t.push(i);else if(i=this.tokenizer.tag(e,n,r))e=e.substring(i.raw.length),n=i.inLink,r=i.inRawBlock,(o=t[t.length-1])&&"text"===i.type&&"text"===o.type?(o.raw+=i.raw,o.text+=i.text):t.push(i);else if(i=this.tokenizer.link(e))e=e.substring(i.raw.length),"link"===i.type&&(i.tokens=this.inlineTokens(i.text,[],!0,r)),t.push(i);else if(i=this.tokenizer.reflink(e,this.tokens.links))e=e.substring(i.raw.length),o=t[t.length-1],"link"===i.type?(i.tokens=this.inlineTokens(i.text,[],!0,r),t.push(i)):o&&"text"===i.type&&"text"===o.type?(o.raw+=i.raw,o.text+=i.text):t.push(i);else if(i=this.tokenizer.emStrong(e,d,u))e=e.substring(i.raw.length),i.tokens=this.inlineTokens(i.text,[],n,r),t.push(i);else if(i=this.tokenizer.codespan(e))e=e.substring(i.raw.length),t.push(i);else if(i=this.tokenizer.br(e))e=e.substring(i.raw.length),t.push(i);else if(i=this.tokenizer.del(e))e=e.substring(i.raw.length),i.tokens=this.inlineTokens(i.text,[],n,r),t.push(i);else if(i=this.tokenizer.autolink(e,Z))e=e.substring(i.raw.length),t.push(i);else if(n||!(i=this.tokenizer.url(e,Z))){if(a=e,this.options.extensions&&this.options.extensions.startInline&&function(){var t=1/0,n=e.slice(1),r=void 0;s.options.extensions.startInline.forEach((function(e){"number"==typeof(r=e.call(this,n))&&r>=0&&(t=Math.min(t,r))})),t<1/0&&t>=0&&(a=e.substring(0,t+1))}(),i=this.tokenizer.inlineText(a,r,Q))e=e.substring(i.raw.length),"_"!==i.raw.slice(-1)&&(u=i.raw.slice(-1)),c=!0,(o=t[t.length-1])&&"text"===o.type?(o.raw+=i.raw,o.text+=i.text):t.push(i);else if(e){var p="Infinite loop on byte: "+e.charCodeAt(0);if(this.options.silent){console.error(p);break}throw new Error(p)}}else e=e.substring(i.raw.length),t.push(i);return t},n=t,i=[{key:"rules",get:function(){return{block:K,inline:X}}}],(r=null)&&e(n.prototype,r),i&&e(n,i),t}(),ee=r.exports.defaults,te=x,ne=w,re=function(){function e(e){this.options=e||ee}var t=e.prototype;return t.code=function(e,t,n){var r=(t||"").match(/\S*/)[0];if(this.options.highlight){var i=this.options.highlight(e,r);null!=i&&i!==e&&(n=!0,e=i)}return e=e.replace(/\n$/,"")+"\n",r?'<pre><code class="'+this.options.langPrefix+ne(r,!0)+'">'+(n?e:ne(e,!0))+"</code></pre>\n":"<pre><code>"+(n?e:ne(e,!0))+"</code></pre>\n"},t.blockquote=function(e){return"<blockquote>\n"+e+"</blockquote>\n"},t.html=function(e){return e},t.heading=function(e,t,n,r){return this.options.headerIds?"<h"+t+' id="'+this.options.headerPrefix+r.slug(n)+'">'+e+"</h"+t+">\n":"<h"+t+">"+e+"</h"+t+">\n"},t.hr=function(){return this.options.xhtml?"<hr/>\n":"<hr>\n"},t.list=function(e,t,n){var r=t?"ol":"ul";return"<"+r+(t&&1!==n?' start="'+n+'"':"")+">\n"+e+"</"+r+">\n"},t.listitem=function(e){return"<li>"+e+"</li>\n"},t.checkbox=function(e){return"<input "+(e?'checked="" ':"")+'disabled="" type="checkbox"'+(this.options.xhtml?" /":"")+"> "},t.paragraph=function(e){return"<p>"+e+"</p>\n"},t.table=function(e,t){return t&&(t="<tbody>"+t+"</tbody>"),"<table>\n<thead>\n"+e+"</thead>\n"+t+"</table>\n"},t.tablerow=function(e){return"<tr>\n"+e+"</tr>\n"},t.tablecell=function(e,t){var n=t.header?"th":"td";return(t.align?"<"+n+' align="'+t.align+'">':"<"+n+">")+e+"</"+n+">\n"},t.strong=function(e){return"<strong>"+e+"</strong>"},t.em=function(e){return"<em>"+e+"</em>"},t.codespan=function(e){return"<code>"+e+"</code>"},t.br=function(){return this.options.xhtml?"<br/>":"<br>"},t.del=function(e){return"<del>"+e+"</del>"},t.link=function(e,t,n){if(null===(e=te(this.options.sanitize,this.options.baseUrl,e)))return n;var r='<a href="'+ne(e)+'"';return t&&(r+=' title="'+t+'"'),r+=">"+n+"</a>"},t.image=function(e,t,n){if(null===(e=te(this.options.sanitize,this.options.baseUrl,e)))return n;var r='<img src="'+e+'" alt="'+n+'"';return t&&(r+=' title="'+t+'"'),r+=this.options.xhtml?"/>":">"},t.text=function(e){return e},e}(),ie=function(){function e(){}var t=e.prototype;return t.strong=function(e){return e},t.em=function(e){return e},t.codespan=function(e){return e},t.del=function(e){return e},t.html=function(e){return e},t.text=function(e){return e},t.link=function(e,t,n){return""+n},t.image=function(e,t,n){return""+n},t.br=function(){return""},e}(),oe=function(){function e(){this.seen={}}var t=e.prototype;return t.serialize=function(e){return e.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi,"").replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g,"").replace(/\s/g,"-")},t.getNextSafeSlug=function(e,t){var n=e,r=0;if(this.seen.hasOwnProperty(n)){r=this.seen[e];do{n=e+"-"+ ++r}while(this.seen.hasOwnProperty(n))}return t||(this.seen[e]=r,this.seen[n]=0),n},t.slug=function(e,t){void 0===t&&(t={});var n=this.serialize(e);return this.getNextSafeSlug(n,t.dryrun)},e}(),ae=re,se=ie,le=oe,ce=r.exports.defaults,ue=A,de=$,he=function(){function e(e){this.options=e||ce,this.options.renderer=this.options.renderer||new ae,this.renderer=this.options.renderer,this.renderer.options=this.options,this.textRenderer=new se,this.slugger=new le}e.parse=function(t,n){return new e(n).parse(t)},e.parseInline=function(t,n){return new e(n).parseInline(t)};var t=e.prototype;return t.parse=function(e,t){void 0===t&&(t=!0);var n,r,i,o,a,s,l,c,u,d,h,p,f,m,g,v,y,_,b,M="",w=e.length;for(n=0;n<w;n++)if(d=e[n],!(this.options.extensions&&this.options.extensions.renderers&&this.options.extensions.renderers[d.type])||!1===(b=this.options.extensions.renderers[d.type].call(this,d))&&["space","hr","heading","code","table","blockquote","list","html","paragraph","text"].includes(d.type))switch(d.type){case"space":continue;case"hr":M+=this.renderer.hr();continue;case"heading":M+=this.renderer.heading(this.parseInline(d.tokens),d.depth,ue(this.parseInline(d.tokens,this.textRenderer)),this.slugger);continue;case"code":M+=this.renderer.code(d.text,d.lang,d.escaped);continue;case"table":for(c="",l="",o=d.header.length,r=0;r<o;r++)l+=this.renderer.tablecell(this.parseInline(d.tokens.header[r]),{header:!0,align:d.align[r]});for(c+=this.renderer.tablerow(l),u="",o=d.cells.length,r=0;r<o;r++){for(l="",a=(s=d.tokens.cells[r]).length,i=0;i<a;i++)l+=this.renderer.tablecell(this.parseInline(s[i]),{header:!1,align:d.align[i]});u+=this.renderer.tablerow(l)}M+=this.renderer.table(c,u);continue;case"blockquote":u=this.parse(d.tokens),M+=this.renderer.blockquote(u);continue;case"list":for(h=d.ordered,p=d.start,f=d.loose,o=d.items.length,u="",r=0;r<o;r++)v=(g=d.items[r]).checked,y=g.task,m="",g.task&&(_=this.renderer.checkbox(v),f?g.tokens.length>0&&"text"===g.tokens[0].type?(g.tokens[0].text=_+" "+g.tokens[0].text,g.tokens[0].tokens&&g.tokens[0].tokens.length>0&&"text"===g.tokens[0].tokens[0].type&&(g.tokens[0].tokens[0].text=_+" "+g.tokens[0].tokens[0].text)):g.tokens.unshift({type:"text",text:_}):m+=_),m+=this.parse(g.tokens,f),u+=this.renderer.listitem(m,y,v);M+=this.renderer.list(u,h,p);continue;case"html":M+=this.renderer.html(d.text);continue;case"paragraph":M+=this.renderer.paragraph(this.parseInline(d.tokens));continue;case"text":for(u=d.tokens?this.parseInline(d.tokens):d.text;n+1<w&&"text"===e[n+1].type;)u+="\n"+((d=e[++n]).tokens?this.parseInline(d.tokens):d.text);M+=t?this.renderer.paragraph(u):u;continue;default:var A='Token with "'+d.type+'" type was not found.';if(this.options.silent)return void console.error(A);throw new Error(A)}else M+=b||"";return M},t.parseInline=function(e,t){t=t||this.renderer;var n,r,i,o="",a=e.length;for(n=0;n<a;n++)if(r=e[n],!(this.options.extensions&&this.options.extensions.renderers&&this.options.extensions.renderers[r.type])||!1===(i=this.options.extensions.renderers[r.type].call(this,r))&&["escape","html","link","image","strong","em","codespan","br","del","text"].includes(r.type))switch(r.type){case"escape":o+=t.text(r.text);break;case"html":o+=t.html(r.text);break;case"link":o+=t.link(r.href,r.title,this.parseInline(r.tokens,t));break;case"image":o+=t.image(r.href,r.title,r.text);break;case"strong":o+=t.strong(this.parseInline(r.tokens,t));break;case"em":o+=t.em(this.parseInline(r.tokens,t));break;case"codespan":o+=t.codespan(r.text);break;case"br":o+=t.br();break;case"del":o+=t.del(this.parseInline(r.tokens,t));break;case"text":o+=t.text(r.text);break;default:var s='Token with "'+r.type+'" type was not found.';if(this.options.silent)return void console.error(s);throw new Error(s)}else o+=i||"";return o},e}(),pe=B,fe=re,me=ie,ge=oe,ve=L,ye=I,_e=w,be=r.exports.getDefaults,Me=r.exports.changeDefaults,we=r.exports.defaults;function Ae(e,t,n){if(null==e)throw new Error("marked(): input parameter is undefined or null");if("string"!=typeof e)throw new Error("marked(): input parameter is of type "+Object.prototype.toString.call(e)+", string expected");if("function"==typeof t&&(n=t,t=null),t=ve({},Ae.defaults,t||{}),ye(t),n){var r,i=t.highlight;try{r=de.lex(e,t)}catch(e){return n(e)}var o=function(e){var o;if(!e)try{t.walkTokens&&Ae.walkTokens(r,t.walkTokens),o=he.parse(r,t)}catch(t){e=t}return t.highlight=i,e?n(e):n(null,o)};if(!i||i.length<3)return o();if(delete t.highlight,!r.length)return o();var a=0;return Ae.walkTokens(r,(function(e){"code"===e.type&&(a++,setTimeout((function(){i(e.text,e.lang,(function(t,n){if(t)return o(t);null!=n&&n!==e.text&&(e.text=n,e.escaped=!0),0==--a&&o()}))}),0))})),void(0===a&&o())}try{var s=de.lex(e,t);return t.walkTokens&&Ae.walkTokens(s,t.walkTokens),he.parse(s,t)}catch(e){if(e.message+="\nPlease report this to https://github.com/markedjs/marked.",t.silent)return"<p>An error occurred:</p><pre>"+_e(e.message+"",!0)+"</pre>";throw e}}return Ae.options=Ae.setOptions=function(e){return ve(Ae.defaults,e),Me(Ae.defaults),Ae},Ae.getDefaults=be,Ae.defaults=we,Ae.use=function(){for(var e=this,t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];var i,o=ve.apply(void 0,[{}].concat(n)),a=Ae.defaults.extensions||{renderers:{},childTokens:{}};n.forEach((function(t){if(t.extensions&&(i=!0,t.extensions.forEach((function(e){if(!e.name)throw new Error("extension name required");if(e.renderer){var t=a.renderers?a.renderers[e.name]:null;a.renderers[e.name]=t?function(){for(var n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];var o=e.renderer.apply(this,r);return!1===o&&(o=t.apply(this,r)),o}:e.renderer}if(e.tokenizer){if(!e.level||"block"!==e.level&&"inline"!==e.level)throw new Error("extension level must be 'block' or 'inline'");a[e.level]?a[e.level].unshift(e.tokenizer):a[e.level]=[e.tokenizer],e.start&&("block"===e.level?a.startBlock?a.startBlock.push(e.start):a.startBlock=[e.start]:"inline"===e.level&&(a.startInline?a.startInline.push(e.start):a.startInline=[e.start]))}e.childTokens&&(a.childTokens[e.name]=e.childTokens)}))),t.renderer&&function(){var e=Ae.defaults.renderer||new fe,n=function(n){var r=e[n];e[n]=function(){for(var i=arguments.length,o=new Array(i),a=0;a<i;a++)o[a]=arguments[a];var s=t.renderer[n].apply(e,o);return!1===s&&(s=r.apply(e,o)),s}};for(var r in t.renderer)n(r);o.renderer=e}(),t.tokenizer&&function(){var e=Ae.defaults.tokenizer||new pe,n=function(n){var r=e[n];e[n]=function(){for(var i=arguments.length,o=new Array(i),a=0;a<i;a++)o[a]=arguments[a];var s=t.tokenizer[n].apply(e,o);return!1===s&&(s=r.apply(e,o)),s}};for(var r in t.tokenizer)n(r);o.tokenizer=e}(),t.walkTokens){var n=Ae.defaults.walkTokens;o.walkTokens=function(r){t.walkTokens.call(e,r),n&&n(r)}}i&&(o.extensions=a),Ae.setOptions(o)}))},Ae.walkTokens=function(e,t){for(var r,i=function(){var e=r.value;switch(t(e),e.type){case"table":for(var i,o=n(e.tokens.header);!(i=o()).done;){var a=i.value;Ae.walkTokens(a,t)}for(var s,l=n(e.tokens.cells);!(s=l()).done;)for(var c,u=n(s.value);!(c=u()).done;){var d=c.value;Ae.walkTokens(d,t)}break;case"list":Ae.walkTokens(e.items,t);break;default:Ae.defaults.extensions&&Ae.defaults.extensions.childTokens&&Ae.defaults.extensions.childTokens[e.type]?Ae.defaults.extensions.childTokens[e.type].forEach((function(n){Ae.walkTokens(e[n],t)})):e.tokens&&Ae.walkTokens(e.tokens,t)}},o=n(e);!(r=o()).done;)i()},Ae.parseInline=function(e,t){if(null==e)throw new Error("marked.parseInline(): input parameter is undefined or null");if("string"!=typeof e)throw new Error("marked.parseInline(): input parameter is of type "+Object.prototype.toString.call(e)+", string expected");t=ve({},Ae.defaults,t||{}),ye(t);try{var n=de.lexInline(e,t);return t.walkTokens&&Ae.walkTokens(n,t.walkTokens),he.parseInline(n,t)}catch(e){if(e.message+="\nPlease report this to https://github.com/markedjs/marked.",t.silent)return"<p>An error occurred:</p><pre>"+_e(e.message+"",!0)+"</pre>";throw e}},Ae.Parser=he,Ae.parser=he.parse,Ae.Renderer=fe,Ae.TextRenderer=me,Ae.Lexer=de,Ae.lexer=de.lex,Ae.Tokenizer=pe,Ae.Slugger=ge,Ae.parse=Ae,Ae}()},function(e,t,n){"use strict";var r=n(75),i=n.n(r),o=n(76),a=n.n(o)()(i.a);a.push([e.i,'/* Copyright (c) Jupyter Development Team.\n * Distributed under the terms of the Modified BSD License.\n */\n\n .jupyter-widgets-disconnected::before {\n    content: "\\f127"; /* chain-broken */\n    display: inline-block;\n    font: normal normal normal 14px/1 FontAwesome;\n    font-size: inherit;\n    text-rendering: auto;\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n    color: #d9534f;\n    padding: 3px;\n    align-self: flex-start;\n}\n',"",{version:3,sources:["webpack://./../../node_modules/@jupyter-widgets/base/css/index.css"],names:[],mappings:"AAAA;;EAEE;;CAED;IACG,gBAAgB,EAAE,iBAAiB;IACnC,qBAAqB;IACrB,6CAA6C;IAC7C,kBAAkB;IAClB,oBAAoB;IACpB,mCAAmC;IACnC,kCAAkC;IAClC,cAAc;IACd,YAAY;IACZ,sBAAsB;AAC1B",sourcesContent:['/* Copyright (c) Jupyter Development Team.\n * Distributed under the terms of the Modified BSD License.\n */\n\n .jupyter-widgets-disconnected::before {\n    content: "\\f127"; /* chain-broken */\n    display: inline-block;\n    font: normal normal normal 14px/1 FontAwesome;\n    font-size: inherit;\n    text-rendering: auto;\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n    color: #d9534f;\n    padding: 3px;\n    align-self: flex-start;\n}\n'],sourceRoot:""}]),t.a=a},function(e,t,n){"use strict";var r=n(75),i=n.n(r),o=n(76),a=n.n(o),s=n(580),l=a()(i.a);l.i(s.a),l.push([e.i,'/* Copyright (c) Jupyter Development Team.\n * Distributed under the terms of the Modified BSD License.\n */\n\n/*\n * We assume that the CSS variables in\n * https://github.com/jupyterlab/jupyterlab/blob/master/src/default-theme/variables.css\n * have been defined.\n */\n\n:root {\n    --jp-widgets-color: var(--jp-content-font-color1);\n    --jp-widgets-label-color: var(--jp-widgets-color);\n    --jp-widgets-readout-color: var(--jp-widgets-color);\n    --jp-widgets-font-size: var(--jp-ui-font-size1);\n    --jp-widgets-margin: 2px;\n    --jp-widgets-inline-height: 28px;\n    --jp-widgets-inline-width: 300px;\n    --jp-widgets-inline-width-short: calc(var(--jp-widgets-inline-width) / 2 - var(--jp-widgets-margin));\n    --jp-widgets-inline-width-tiny: calc(var(--jp-widgets-inline-width-short) / 2 - var(--jp-widgets-margin));\n    --jp-widgets-inline-margin: 4px; /* margin between inline elements */\n    --jp-widgets-inline-label-width: 80px;\n    --jp-widgets-border-width: var(--jp-border-width);\n    --jp-widgets-vertical-height: 200px;\n    --jp-widgets-horizontal-tab-height: 24px;\n    --jp-widgets-horizontal-tab-width: 144px;\n    --jp-widgets-horizontal-tab-top-border: 2px;\n    --jp-widgets-progress-thickness: 20px;\n    --jp-widgets-container-padding: 15px;\n    --jp-widgets-input-padding: 4px;\n    --jp-widgets-radio-item-height-adjustment: 8px;\n    --jp-widgets-radio-item-height: calc(var(--jp-widgets-inline-height) - var(--jp-widgets-radio-item-height-adjustment));\n    --jp-widgets-slider-track-thickness: 4px;\n    --jp-widgets-slider-border-width: var(--jp-widgets-border-width);\n    --jp-widgets-slider-handle-size: 16px;\n    --jp-widgets-slider-handle-border-color: var(--jp-border-color1);\n    --jp-widgets-slider-handle-background-color: var(--jp-layout-color1);\n    --jp-widgets-slider-active-handle-color: var(--jp-brand-color1);\n    --jp-widgets-menu-item-height: 24px;\n    --jp-widgets-dropdown-arrow: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCEtLSBHZW5lcmF0b3I6IEFkb2JlIElsbHVzdHJhdG9yIDE5LjIuMSwgU1ZHIEV4cG9ydCBQbHVnLUluIC4gU1ZHIFZlcnNpb246IDYuMDAgQnVpbGQgMCkgIC0tPgo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4IgoJIHZpZXdCb3g9IjAgMCAxOCAxOCIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgMTggMTg7IiB4bWw6c3BhY2U9InByZXNlcnZlIj4KPHN0eWxlIHR5cGU9InRleHQvY3NzIj4KCS5zdDB7ZmlsbDpub25lO30KPC9zdHlsZT4KPHBhdGggZD0iTTUuMiw1LjlMOSw5LjdsMy44LTMuOGwxLjIsMS4ybC00LjksNWwtNC45LTVMNS4yLDUuOXoiLz4KPHBhdGggY2xhc3M9InN0MCIgZD0iTTAtMC42aDE4djE4SDBWLTAuNnoiLz4KPC9zdmc+Cg");\n    --jp-widgets-input-color: var(--jp-ui-font-color1);\n    --jp-widgets-input-background-color: var(--jp-layout-color1);\n    --jp-widgets-input-border-color: var(--jp-border-color1);\n    --jp-widgets-input-focus-border-color: var(--jp-brand-color2);\n    --jp-widgets-input-border-width: var(--jp-widgets-border-width);\n    --jp-widgets-disabled-opacity: 0.6;\n\n    /* From Material Design Lite */\n    --md-shadow-key-umbra-opacity: 0.2;\n    --md-shadow-key-penumbra-opacity: 0.14;\n    --md-shadow-ambient-shadow-opacity: 0.12;\n}\n\n.jupyter-widgets {\n    margin: var(--jp-widgets-margin);\n    box-sizing: border-box;\n    color: var(--jp-widgets-color);\n    overflow: visible;\n}\n\n.jupyter-widgets.jupyter-widgets-disconnected::before {\n    line-height: var(--jp-widgets-inline-height);\n    height: var(--jp-widgets-inline-height);\n}\n\n.jp-Output-result > .jupyter-widgets {\n    margin-left: 0;\n    margin-right: 0;\n}\n\n/* vbox and hbox */\n\n.widget-inline-hbox {\n    /* Horizontal widgets */\n    box-sizing: border-box;\n    display: flex;\n    flex-direction: row;\n    align-items: baseline;\n}\n\n.widget-inline-vbox {\n    /* Vertical Widgets */\n    box-sizing: border-box;\n    display: flex;\n    flex-direction: column;\n    align-items: center;\n}\n\n.widget-box {\n    box-sizing: border-box;\n    display: flex;\n    margin: 0;\n    overflow: auto;\n}\n\n.widget-gridbox {\n    box-sizing: border-box;\n    display: grid;\n    margin: 0;\n    overflow: auto;\n}\n\n.widget-hbox {\n    flex-direction: row;\n}\n\n.widget-vbox {\n    flex-direction: column;\n}\n\n/* General Button Styling */\n\n.jupyter-button {\n    padding-left: 10px;\n    padding-right: 10px;\n    padding-top: 0px;\n    padding-bottom: 0px;\n    display: inline-block;\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    text-align: center;\n    font-size: var(--jp-widgets-font-size);\n    cursor: pointer;\n\n    height: var(--jp-widgets-inline-height);\n    border: 0px solid;\n    line-height: var(--jp-widgets-inline-height);\n    box-shadow: none;\n\n    color: var(--jp-ui-font-color1);\n    background-color: var(--jp-layout-color2);\n    border-color: var(--jp-border-color2);\n    border: none;\n    user-select: none;\n}\n\n.jupyter-button i.fa {\n    margin-right: var(--jp-widgets-inline-margin);\n    pointer-events: none;\n}\n\n.jupyter-button:empty:before {\n    content: "\\200b"; /* zero-width space */\n}\n\n.jupyter-widgets.jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n.jupyter-button i.fa.center {\n    margin-right: 0;\n}\n\n.jupyter-button:hover:enabled, .jupyter-button:focus:enabled {\n    /* MD Lite 2dp shadow */\n    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, var(--md-shadow-key-penumbra-opacity)),\n                0 3px 1px -2px rgba(0, 0, 0, var(--md-shadow-key-umbra-opacity)),\n                0 1px 5px 0 rgba(0, 0, 0, var(--md-shadow-ambient-shadow-opacity));\n}\n\n.jupyter-button:active, .jupyter-button.mod-active {\n    /* MD Lite 4dp shadow */\n    box-shadow: 0 4px 5px 0 rgba(0, 0, 0, var(--md-shadow-key-penumbra-opacity)),\n                0 1px 10px 0 rgba(0, 0, 0, var(--md-shadow-ambient-shadow-opacity)),\n                0 2px 4px -1px rgba(0, 0, 0, var(--md-shadow-key-umbra-opacity));\n    color: var(--jp-ui-font-color1);\n    background-color: var(--jp-layout-color3);\n}\n\n.jupyter-button:focus:enabled {\n    outline: 1px solid var(--jp-widgets-input-focus-border-color);\n}\n\n/* Button "Primary" Styling */\n\n.jupyter-button.mod-primary {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-brand-color1);\n}\n\n.jupyter-button.mod-primary.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-brand-color0);\n}\n\n.jupyter-button.mod-primary:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-brand-color0);\n}\n\n/* Button "Success" Styling */\n\n.jupyter-button.mod-success {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-success-color1);\n}\n\n.jupyter-button.mod-success.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-success-color0);\n}\n\n.jupyter-button.mod-success:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-success-color0);\n}\n\n /* Button "Info" Styling */\n\n.jupyter-button.mod-info {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-info-color1);\n}\n\n.jupyter-button.mod-info.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-info-color0);\n}\n\n.jupyter-button.mod-info:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-info-color0);\n}\n\n/* Button "Warning" Styling */\n\n.jupyter-button.mod-warning {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-warn-color1);\n}\n\n.jupyter-button.mod-warning.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-warn-color0);\n}\n\n.jupyter-button.mod-warning:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-warn-color0);\n}\n\n/* Button "Danger" Styling */\n\n.jupyter-button.mod-danger {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-error-color1);\n}\n\n.jupyter-button.mod-danger.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-error-color0);\n}\n\n.jupyter-button.mod-danger:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-error-color0);\n}\n\n/* Widget Button, Widget Toggle Button, Widget Upload */\n\n.widget-button, .widget-toggle-button, .widget-upload {\n    width: var(--jp-widgets-inline-width-short);\n}\n\n/* Widget Label Styling */\n\n/* Override Bootstrap label css */\n.jupyter-widgets label {\n    margin-bottom: initial;\n}\n\n.widget-label-basic {\n    /* Basic Label */\n    color: var(--jp-widgets-label-color);\n    font-size: var(--jp-widgets-font-size);\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-label {\n    /* Label */\n    color: var(--jp-widgets-label-color);\n    font-size: var(--jp-widgets-font-size);\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-inline-hbox .widget-label {\n    /* Horizontal Widget Label */\n    color: var(--jp-widgets-label-color);\n    text-align: right;\n    margin-right: calc( var(--jp-widgets-inline-margin) * 2 );\n    width: var(--jp-widgets-inline-label-width);\n    flex-shrink: 0;\n}\n\n.widget-inline-vbox .widget-label {\n    /* Vertical Widget Label */\n    color: var(--jp-widgets-label-color);\n    text-align: center;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n/* Widget Readout Styling */\n\n.widget-readout {\n    color: var(--jp-widgets-readout-color);\n    font-size: var(--jp-widgets-font-size);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    overflow: hidden;\n    white-space: nowrap;\n    text-align: center;\n}\n\n.widget-readout.overflow {\n    /* Overflowing Readout */\n\n    /* From Material Design Lite\n        shadow-key-umbra-opacity: 0.2;\n        shadow-key-penumbra-opacity: 0.14;\n        shadow-ambient-shadow-opacity: 0.12;\n     */\n    -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                        0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                        0 1px 5px 0 rgba(0, 0, 0, 0.12);\n\n    -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                     0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                     0 1px 5px 0 rgba(0, 0, 0, 0.12);\n\n    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                0 1px 5px 0 rgba(0, 0, 0, 0.12);\n}\n\n.widget-inline-hbox .widget-readout {\n    /* Horizontal Readout */\n    text-align: center;\n    max-width: var(--jp-widgets-inline-width-short);\n    min-width: var(--jp-widgets-inline-width-tiny);\n    margin-left: var(--jp-widgets-inline-margin);\n}\n\n.widget-inline-vbox .widget-readout {\n    /* Vertical Readout */\n    margin-top: var(--jp-widgets-inline-margin);\n    /* as wide as the widget */\n    width: inherit;\n}\n\n/* Widget Checkbox Styling */\n\n.widget-checkbox {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-checkbox input[type="checkbox"] {\n    margin: 0px calc( var(--jp-widgets-inline-margin) * 2 ) 0px 0px;\n    line-height: var(--jp-widgets-inline-height);\n    font-size: large;\n    flex-grow: 1;\n    flex-shrink: 0;\n    align-self: center;\n}\n\n/* Widget Valid Styling */\n\n.widget-valid {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width-short);\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-valid i:before {\n    line-height: var(--jp-widgets-inline-height);\n    margin-right: var(--jp-widgets-inline-margin);\n    margin-left: var(--jp-widgets-inline-margin);\n}\n\n.widget-valid.mod-valid i:before {\n    color: green;\n}\n\n.widget-valid.mod-invalid i:before {\n    color: red;\n}\n\n.widget-valid.mod-valid .widget-valid-readout {\n    display: none;\n}\n\n/* Widget Text and TextArea Stying */\n\n.widget-textarea, .widget-text {\n    width: var(--jp-widgets-inline-width);\n}\n\n.widget-text input[type="text"], .widget-text input[type="number"], .widget-text input[type="password"] {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-text input[type="text"]:disabled, .widget-text input[type="number"]:disabled, .widget-text input[type="password"]:disabled, .widget-textarea textarea:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n.widget-text input[type="text"], .widget-text input[type="number"], .widget-text input[type="password"], .widget-textarea textarea {\n    box-sizing: border-box;\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    flex-grow: 1;\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    flex-shrink: 1;\n    outline: none !important;\n}\n    \n.widget-text input[type="text"], .widget-text input[type="password"], .widget-textarea textarea {\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2);\n}\n\n.widget-text input[type="number"] {\n    padding: var(--jp-widgets-input-padding) 0 var(--jp-widgets-input-padding) calc(var(--jp-widgets-input-padding) *  2);\n}\n\n.widget-textarea textarea {\n    height: inherit;\n    width: inherit;\n}\n\n.widget-text input:focus, .widget-textarea textarea:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n/* Widget Slider */\n\n.widget-slider .ui-slider {\n    /* Slider Track */\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-layout-color3);\n    background: var(--jp-layout-color3);\n    box-sizing: border-box;\n    position: relative;\n    border-radius: 0px;\n}\n\n.widget-slider .ui-slider .ui-slider-handle {\n    /* Slider Handle */\n    outline: none !important; /* focused slider handles are colored - see below */\n    position: absolute;\n    background-color: var(--jp-widgets-slider-handle-background-color);\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-widgets-slider-handle-border-color);\n    box-sizing: border-box;\n    z-index: 1;\n    background-image: none; /* Override jquery-ui */\n}\n\n/* Override jquery-ui */\n.widget-slider .ui-slider .ui-slider-handle:hover, .widget-slider .ui-slider .ui-slider-handle:focus {\n    background-color: var(--jp-widgets-slider-active-handle-color);\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-widgets-slider-active-handle-color);\n}\n\n.widget-slider .ui-slider .ui-slider-handle:active {\n    background-color: var(--jp-widgets-slider-active-handle-color);\n    border-color: var(--jp-widgets-slider-active-handle-color);\n    z-index: 2;\n    transform: scale(1.2);\n}\n\n.widget-slider  .ui-slider .ui-slider-range {\n    /* Interval between the two specified value of a double slider */\n    position: absolute;\n    background: var(--jp-widgets-slider-active-handle-color);\n    z-index: 0;\n}\n\n/* Shapes of Slider Handles */\n\n.widget-hslider .ui-slider .ui-slider-handle {\n    width: var(--jp-widgets-slider-handle-size);\n    height: var(--jp-widgets-slider-handle-size);\n    margin-top: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-handle-size)) / 2 - var(--jp-widgets-slider-border-width));\n    margin-left: calc(var(--jp-widgets-slider-handle-size) / -2 + var(--jp-widgets-slider-border-width));\n    border-radius: 50%;\n    top: 0;\n}\n\n.widget-vslider .ui-slider .ui-slider-handle {\n    width: var(--jp-widgets-slider-handle-size);\n    height: var(--jp-widgets-slider-handle-size);\n    margin-bottom: calc(var(--jp-widgets-slider-handle-size) / -2 + var(--jp-widgets-slider-border-width));\n    margin-left: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-handle-size)) / 2 - var(--jp-widgets-slider-border-width));\n    border-radius: 50%;\n    left: 0;\n}\n\n.widget-hslider .ui-slider .ui-slider-range {\n    height: calc( var(--jp-widgets-slider-track-thickness) * 2 );\n    margin-top: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-track-thickness) * 2 ) / 2 - var(--jp-widgets-slider-border-width));\n}\n\n.widget-vslider .ui-slider .ui-slider-range {\n    width: calc( var(--jp-widgets-slider-track-thickness) * 2 );\n    margin-left: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-track-thickness) * 2 ) / 2 - var(--jp-widgets-slider-border-width));\n}\n\n/* Horizontal Slider */\n\n.widget-hslider {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n\n    /* Override the align-items baseline. This way, the description and readout\n    still seem to align their baseline properly, and we don\'t have to have\n    align-self: stretch in the .slider-container. */\n    align-items: center;\n}\n\n.widgets-slider .slider-container {\n    overflow: visible;\n}\n\n.widget-hslider .slider-container {\n    height: var(--jp-widgets-inline-height);\n    margin-left: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    margin-right: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n}\n\n.widget-hslider .ui-slider {\n    /* Inner, invisible slide div */\n    height: var(--jp-widgets-slider-track-thickness);\n    margin-top: calc((var(--jp-widgets-inline-height) - var(--jp-widgets-slider-track-thickness)) / 2);\n    width: 100%;\n}\n\n/* Vertical Slider */\n\n.widget-vbox .widget-label {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-vslider {\n    /* Vertical Slider */\n    height: var(--jp-widgets-vertical-height);\n    width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-vslider .slider-container {\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    margin-left: auto;\n    margin-right: auto;\n    margin-bottom: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    margin-top: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    display: flex;\n    flex-direction: column;\n}\n\n.widget-vslider .ui-slider-vertical {\n    /* Inner, invisible slide div */\n    width: var(--jp-widgets-slider-track-thickness);\n    flex-grow: 1;\n    margin-left: auto;\n    margin-right: auto;\n}\n\n/* Widget Progress Styling */\n\n.progress-bar {\n    -webkit-transition: none;\n    -moz-transition: none;\n    -ms-transition: none;\n    -o-transition: none;\n    transition: none;\n}\n\n.progress-bar {\n    height: var(--jp-widgets-inline-height);\n}\n\n.progress-bar {\n    background-color: var(--jp-brand-color1);\n}\n\n.progress-bar-success {\n    background-color: var(--jp-success-color1);\n}\n\n.progress-bar-info {\n    background-color: var(--jp-info-color1);\n}\n\n.progress-bar-warning {\n    background-color: var(--jp-warn-color1);\n}\n\n.progress-bar-danger {\n    background-color: var(--jp-error-color1);\n}\n\n.progress {\n    background-color: var(--jp-layout-color2);\n    border: none;\n    box-shadow: none;\n}\n\n/* Horisontal Progress */\n\n.widget-hprogress {\n    /* Progress Bar */\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width);\n    align-items: center;\n\n}\n\n.widget-hprogress .progress {\n    flex-grow: 1;\n    margin-top: var(--jp-widgets-input-padding);\n    margin-bottom: var(--jp-widgets-input-padding);\n    align-self: stretch;\n    /* Override bootstrap style */\n    height: initial;\n}\n\n/* Vertical Progress */\n\n.widget-vprogress {\n    height: var(--jp-widgets-vertical-height);\n    width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-vprogress .progress {\n    flex-grow: 1;\n    width: var(--jp-widgets-progress-thickness);\n    margin-left: auto;\n    margin-right: auto;\n    margin-bottom: 0;\n}\n\n/* Select Widget Styling */\n\n.widget-dropdown {\n    height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-dropdown > select {\n    padding-right: 20px;\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    border-radius: 0;\n    height: inherit;\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    box-sizing: border-box;\n    outline: none !important;\n    box-shadow: none;\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    vertical-align: top;\n    padding-left: calc( var(--jp-widgets-input-padding) * 2);\n\tappearance: none;\n\t-webkit-appearance: none;\n\t-moz-appearance: none;\n    background-repeat: no-repeat;\n\tbackground-size: 20px;\n\tbackground-position: right center;\n    background-image: var(--jp-widgets-dropdown-arrow);\n}\n.widget-dropdown > select:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-dropdown > select:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* To disable the dotted border in Firefox around select controls.\n   See http://stackoverflow.com/a/18853002 */\n.widget-dropdown > select:-moz-focusring {\n    color: transparent;\n    text-shadow: 0 0 0 #000;\n}\n\n/* Select and SelectMultiple */\n\n.widget-select {\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n\n    /* Because Firefox defines the baseline of a select as the bottom of the\n    control, we align the entire control to the top and add padding to the\n    select to get an approximate first line baseline alignment. */\n    align-items: flex-start;\n}\n\n.widget-select > select {\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    outline: none !important;\n    overflow: auto;\n    height: inherit;\n\n    /* Because Firefox defines the baseline of a select as the bottom of the\n    control, we align the entire control to the top and add padding to the\n    select to get an approximate first line baseline alignment. */\n    padding-top: 5px;\n}\n\n.widget-select > select:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.wiget-select > select > option {\n    padding-left: var(--jp-widgets-input-padding);\n    line-height: var(--jp-widgets-inline-height);\n    /* line-height doesn\'t work on some browsers for select options */\n    padding-top: calc(var(--jp-widgets-inline-height)-var(--jp-widgets-font-size)/2);\n    padding-bottom: calc(var(--jp-widgets-inline-height)-var(--jp-widgets-font-size)/2);\n}\n\n\n\n/* Toggle Buttons Styling */\n\n.widget-toggle-buttons {\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-toggle-buttons .widget-toggle-button {\n    margin-left: var(--jp-widgets-margin);\n    margin-right: var(--jp-widgets-margin);\n}\n\n.widget-toggle-buttons .jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Radio Buttons Styling */\n\n.widget-radio {\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-radio-box {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n    box-sizing: border-box;\n    flex-grow: 1;\n    margin-bottom: var(--jp-widgets-radio-item-height-adjustment);\n}\n\n.widget-radio-box label {\n    height: var(--jp-widgets-radio-item-height);\n    line-height: var(--jp-widgets-radio-item-height);\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-radio-box input {\n    height: var(--jp-widgets-radio-item-height);\n    line-height: var(--jp-widgets-radio-item-height);\n    margin: 0 calc( var(--jp-widgets-input-padding) * 2 ) 0 1px;\n    float: left;\n}\n\n/* Color Picker Styling */\n\n.widget-colorpicker {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-colorpicker > .widget-colorpicker-input {\n    flex-grow: 1;\n    flex-shrink: 1;\n    min-width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-colorpicker input[type="color"] {\n    width: var(--jp-widgets-inline-height);\n    height: var(--jp-widgets-inline-height);\n    padding: 0 2px; /* make the color square actually square on Chrome on OS X */\n    background: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    border-left: none;\n    flex-grow: 0;\n    flex-shrink: 0;\n    box-sizing: border-box;\n    align-self: stretch;\n    outline: none !important;\n}\n\n.widget-colorpicker.concise input[type="color"] {\n    border-left: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n}\n\n.widget-colorpicker input[type="color"]:focus, .widget-colorpicker input[type="text"]:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-colorpicker input[type="text"] {\n    flex-grow: 1;\n    outline: none !important;\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    background: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    font-size: var(--jp-widgets-font-size);\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2 );\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    flex-shrink: 1;\n    box-sizing: border-box;\n}\n\n.widget-colorpicker input[type="text"]:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Date Picker Styling */\n\n.widget-datepicker {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-datepicker input[type="date"] {\n    flex-grow: 1;\n    flex-shrink: 1;\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    outline: none !important;\n    height: var(--jp-widgets-inline-height);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2 );\n    box-sizing: border-box;\n}\n\n.widget-datepicker input[type="date"]:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-datepicker input[type="date"]:invalid {\n    border-color: var(--jp-warn-color1);\n}\n\n.widget-datepicker input[type="date"]:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Play Widget */\n\n.widget-play {\n    width: var(--jp-widgets-inline-width-short);\n    display: flex;\n    align-items: stretch;\n}\n\n.widget-play .jupyter-button {\n    flex-grow: 1;\n    height: auto;\n}\n\n.widget-play .jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Tab Widget */\n\n.jupyter-widgets.widget-tab {\n    display: flex;\n    flex-direction: column;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n    /* Necessary so that a tab can be shifted down to overlay the border of the box below. */\n    overflow-x: visible;\n    overflow-y: visible;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar > .p-TabBar-content {\n    /* Make sure that the tab grows from bottom up */\n    align-items: flex-end;\n    min-width: 0;\n    min-height: 0;\n}\n\n.jupyter-widgets.widget-tab > .widget-tab-contents {\n    width: 100%;\n    box-sizing: border-box;\n    margin: 0;\n    background: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n    border: var(--jp-border-width) solid var(--jp-border-color1);\n    padding: var(--jp-widgets-container-padding);\n    flex-grow: 1;\n    overflow: auto;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n    font: var(--jp-widgets-font-size) Helvetica, Arial, sans-serif;\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + var(--jp-border-width));\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab {\n    flex: 0 1 var(--jp-widgets-horizontal-tab-width);\n    min-width: 35px;\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + var(--jp-border-width));\n    line-height: var(--jp-widgets-horizontal-tab-height);\n    margin-left: calc(-1 * var(--jp-border-width));\n    padding: 0px 10px;\n    background: var(--jp-layout-color2);\n    color: var(--jp-ui-font-color2);\n    border: var(--jp-border-width) solid var(--jp-border-color1);\n    border-bottom: none;\n    position: relative;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-current {\n    color: var(--jp-ui-font-color0);\n    /* We want the background to match the tab content background */\n    background: var(--jp-layout-color1);\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + 2 * var(--jp-border-width));\n    transform: translateY(var(--jp-border-width));\n    overflow: visible;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-current:before {\n    position: absolute;\n    top: calc(-1 * var(--jp-border-width));\n    left: calc(-1 * var(--jp-border-width));\n    content: \'\';\n    height: var(--jp-widgets-horizontal-tab-top-border);\n    width: calc(100% + 2 * var(--jp-border-width));\n    background: var(--jp-brand-color1);\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab:first-child {\n    margin-left: 0;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab:hover:not(.p-mod-current) {\n    background: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-mod-closable > .p-TabBar-tabCloseIcon {\n    margin-left: 4px;\n}\n\n/* This font-awesome strategy may not work across FA4 and FA5, but we don\'t\nactually support closable tabs, so it really doesn\'t matter */\n.jupyter-widgets.widget-tab > .p-TabBar .p-mod-closable > .p-TabBar-tabCloseIcon:before {\n    font-family: FontAwesome;\n    content: \'\\f00d\'; /* close */\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabIcon,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabLabel,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabCloseIcon {\n    line-height: var(--jp-widgets-horizontal-tab-height);\n}\n\n/* Accordion Widget */\n\n.p-Collapse {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n}\n\n.p-Collapse-header {\n    padding: var(--jp-widgets-input-padding);\n    cursor: pointer;\n    color: var(--jp-ui-font-color2);\n    background-color: var(--jp-layout-color2);\n    border: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    padding: calc(var(--jp-widgets-container-padding) * 2 / 3) var(--jp-widgets-container-padding);\n    font-weight: bold;\n}\n\n.p-Collapse-header:hover {\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n}\n\n.p-Collapse-open > .p-Collapse-header {\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color0);\n    cursor: default;\n    border-bottom: none;\n}\n\n.p-Collapse-contents {\n    padding: var(--jp-widgets-container-padding);\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n    border-left: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    border-right: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    border-bottom: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    overflow: auto;\n}\n\n.p-Accordion {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n}\n\n.p-Accordion .p-Collapse {\n    margin-bottom: 0;\n}\n\n.p-Accordion .p-Collapse + .p-Collapse {\n    margin-top: 4px;\n}\n\n\n\n/* HTML widget */\n\n.widget-html, .widget-htmlmath {\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-html > .widget-html-content, .widget-htmlmath > .widget-html-content {\n    /* Fill out the area in the HTML widget */\n    align-self: stretch;\n    flex-grow: 1;\n    flex-shrink: 1;\n    /* Makes sure the baseline is still aligned with other elements */\n    line-height: var(--jp-widgets-inline-height);\n    /* Make it possible to have absolutely-positioned elements in the html */\n    position: relative;\n}\n\n\n/* Image widget  */\n\n.widget-image {\n    max-width: 100%;\n    height: auto;\n}\n',"",{version:3,sources:["webpack://./../../node_modules/@jupyter-widgets/controls/css/widgets-base.css"],names:[],mappings:"AAAA;;EAEE;;AAEF;;;;EAIE;;AAIF;IACI,iDAAiD;IACjD,iDAAiD;IACjD,mDAAmD;IACnD,+CAA+C;IAC/C,wBAAwB;IACxB,gCAAgC;IAChC,gCAAgC;IAChC,oGAAoG;IACpG,yGAAyG;IACzG,+BAA+B,EAAE,mCAAmC;IACpE,qCAAqC;IACrC,iDAAiD;IACjD,mCAAmC;IACnC,wCAAwC;IACxC,wCAAwC;IACxC,2CAA2C;IAC3C,qCAAqC;IACrC,oCAAoC;IACpC,+BAA+B;IAC/B,8CAA8C;IAC9C,sHAAsH;IACtH,wCAAwC;IACxC,gEAAgE;IAChE,qCAAqC;IACrC,gEAAgE;IAChE,oEAAoE;IACpE,+DAA+D;IAC/D,mCAAmC;IACnC,4uBAA4uB;IAC5uB,kDAAkD;IAClD,4DAA4D;IAC5D,wDAAwD;IACxD,6DAA6D;IAC7D,+DAA+D;IAC/D,kCAAkC;;IAElC,8BAA8B;IAC9B,kCAAkC;IAClC,sCAAsC;IACtC,wCAAwC;AAC5C;;AAEA;IACI,gCAAgC;IAChC,sBAAsB;IACtB,8BAA8B;IAC9B,iBAAiB;AACrB;;AAEA;IACI,4CAA4C;IAC5C,uCAAuC;AAC3C;;AAEA;IACI,cAAc;IACd,eAAe;AACnB;;AAEA,kBAAkB;;AAElB;IACI,uBAAuB;IACvB,sBAAsB;IACtB,aAAa;IACb,mBAAmB;IACnB,qBAAqB;AACzB;;AAEA;IACI,qBAAqB;IACrB,sBAAsB;IACtB,aAAa;IACb,sBAAsB;IACtB,mBAAmB;AACvB;;AAEA;IACI,sBAAsB;IACtB,aAAa;IACb,SAAS;IACT,cAAc;AAClB;;AAEA;IACI,sBAAsB;IACtB,aAAa;IACb,SAAS;IACT,cAAc;AAClB;;AAEA;IACI,mBAAmB;AACvB;;AAEA;IACI,sBAAsB;AAC1B;;AAEA,2BAA2B;;AAE3B;IACI,kBAAkB;IAClB,mBAAmB;IACnB,gBAAgB;IAChB,mBAAmB;IACnB,qBAAqB;IACrB,mBAAmB;IACnB,gBAAgB;IAChB,uBAAuB;IACvB,kBAAkB;IAClB,sCAAsC;IACtC,eAAe;;IAEf,uCAAuC;IACvC,iBAAiB;IACjB,4CAA4C;IAC5C,gBAAgB;;IAEhB,+BAA+B;IAC/B,yCAAyC;IACzC,qCAAqC;IACrC,YAAY;IACZ,iBAAiB;AACrB;;AAEA;IACI,6CAA6C;IAC7C,oBAAoB;AACxB;;AAEA;IACI,gBAAgB,EAAE,qBAAqB;AAC3C;;AAEA;IACI,2CAA2C;AAC/C;;AAEA;IACI,eAAe;AACnB;;AAEA;IACI,uBAAuB;IACvB;;kFAE8E;AAClF;;AAEA;IACI,uBAAuB;IACvB;;gFAE4E;IAC5E,+BAA+B;IAC/B,yCAAyC;AAC7C;;AAEA;IACI,6DAA6D;AACjE;;AAEA,6BAA6B;;AAE7B;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA,6BAA6B;;AAE7B;IACI,yEAAyE;IACzE,0CAA0C;AAC9C;;AAEA;IACI,yEAAyE;IACzE,0CAA0C;AAC9C;;AAEA;IACI,yEAAyE;IACzE,0CAA0C;AAC9C;;CAEC,0BAA0B;;AAE3B;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA,6BAA6B;;AAE7B;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA;IACI,yEAAyE;IACzE,uCAAuC;AAC3C;;AAEA,4BAA4B;;AAE5B;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA;IACI,yEAAyE;IACzE,wCAAwC;AAC5C;;AAEA,uDAAuD;;AAEvD;IACI,2CAA2C;AAC/C;;AAEA,yBAAyB;;AAEzB,iCAAiC;AACjC;IACI,sBAAsB;AAC1B;;AAEA;IACI,gBAAgB;IAChB,oCAAoC;IACpC,sCAAsC;IACtC,gBAAgB;IAChB,uBAAuB;IACvB,mBAAmB;IACnB,4CAA4C;AAChD;;AAEA;IACI,UAAU;IACV,oCAAoC;IACpC,sCAAsC;IACtC,gBAAgB;IAChB,uBAAuB;IACvB,mBAAmB;IACnB,4CAA4C;AAChD;;AAEA;IACI,4BAA4B;IAC5B,oCAAoC;IACpC,iBAAiB;IACjB,yDAAyD;IACzD,2CAA2C;IAC3C,cAAc;AAClB;;AAEA;IACI,0BAA0B;IAC1B,oCAAoC;IACpC,kBAAkB;IAClB,4CAA4C;AAChD;;AAEA,2BAA2B;;AAE3B;IACI,sCAAsC;IACtC,sCAAsC;IACtC,uCAAuC;IACvC,4CAA4C;IAC5C,gBAAgB;IAChB,mBAAmB;IACnB,kBAAkB;AACtB;;AAEA;IACI,wBAAwB;;IAExB;;;;MAIE;IACF;;uDAEmD;;IAEnD;;oDAEgD;;IAEhD;;+CAE2C;AAC/C;;AAEA;IACI,uBAAuB;IACvB,kBAAkB;IAClB,+CAA+C;IAC/C,8CAA8C;IAC9C,4CAA4C;AAChD;;AAEA;IACI,qBAAqB;IACrB,2CAA2C;IAC3C,0BAA0B;IAC1B,cAAc;AAClB;;AAEA,4BAA4B;;AAE5B;IACI,qCAAqC;IACrC,uCAAuC;IACvC,4CAA4C;AAChD;;AAEA;IACI,+DAA+D;IAC/D,4CAA4C;IAC5C,gBAAgB;IAChB,YAAY;IACZ,cAAc;IACd,kBAAkB;AACtB;;AAEA,yBAAyB;;AAEzB;IACI,uCAAuC;IACvC,4CAA4C;IAC5C,2CAA2C;IAC3C,sCAAsC;AAC1C;;AAEA;IACI,4CAA4C;IAC5C,6CAA6C;IAC7C,4CAA4C;AAChD;;AAEA;IACI,YAAY;AAChB;;AAEA;IACI,UAAU;AACd;;AAEA;IACI,aAAa;AACjB;;AAEA,oCAAoC;;AAEpC;IACI,qCAAqC;AACzC;;AAEA;IACI,uCAAuC;IACvC,4CAA4C;AAChD;;AAEA;IACI,2CAA2C;AAC/C;;AAEA;IACI,sBAAsB;IACtB,uFAAuF;IACvF,0DAA0D;IAC1D,oCAAoC;IACpC,sCAAsC;IACtC,YAAY;IACZ,YAAY,EAAE,gEAAgE;IAC9E,cAAc;IACd,wBAAwB;AAC5B;;AAEA;IACI,oFAAoF;AACxF;;AAEA;IACI,qHAAqH;AACzH;;AAEA;IACI,eAAe;IACf,cAAc;AAClB;;AAEA;IACI,wDAAwD;AAC5D;;AAEA,kBAAkB;;AAElB;IACI,iBAAiB;IACjB,2EAA2E;IAC3E,mCAAmC;IACnC,sBAAsB;IACtB,kBAAkB;IAClB,kBAAkB;AACtB;;AAEA;IACI,kBAAkB;IAClB,wBAAwB,EAAE,mDAAmD;IAC7E,kBAAkB;IAClB,kEAAkE;IAClE,gGAAgG;IAChG,sBAAsB;IACtB,UAAU;IACV,sBAAsB,EAAE,uBAAuB;AACnD;;AAEA,uBAAuB;AACvB;IACI,8DAA8D;IAC9D,gGAAgG;AACpG;;AAEA;IACI,8DAA8D;IAC9D,0DAA0D;IAC1D,UAAU;IACV,qBAAqB;AACzB;;AAEA;IACI,gEAAgE;IAChE,kBAAkB;IAClB,wDAAwD;IACxD,UAAU;AACd;;AAEA,6BAA6B;;AAE7B;IACI,2CAA2C;IAC3C,4CAA4C;IAC5C,+IAA+I;IAC/I,oGAAoG;IACpG,kBAAkB;IAClB,MAAM;AACV;;AAEA;IACI,2CAA2C;IAC3C,4CAA4C;IAC5C,sGAAsG;IACtG,gJAAgJ;IAChJ,kBAAkB;IAClB,OAAO;AACX;;AAEA;IACI,4DAA4D;IAC5D,wJAAwJ;AAC5J;;AAEA;IACI,2DAA2D;IAC3D,yJAAyJ;AAC7J;;AAEA,sBAAsB;;AAEtB;IACI,qCAAqC;IACrC,uCAAuC;IACvC,4CAA4C;;IAE5C;;mDAE+C;IAC/C,mBAAmB;AACvB;;AAEA;IACI,iBAAiB;AACrB;;AAEA;IACI,uCAAuC;IACvC,uGAAuG;IACvG,wGAAwG;IACxG,8CAA8C;AAClD;;AAEA;IACI,+BAA+B;IAC/B,gDAAgD;IAChD,kGAAkG;IAClG,WAAW;AACf;;AAEA,oBAAoB;;AAEpB;IACI,uCAAuC;IACvC,4CAA4C;AAChD;;AAEA;IACI,oBAAoB;IACpB,yCAAyC;IACzC,0CAA0C;AAC9C;;AAEA;IACI,8CAA8C;IAC9C,iBAAiB;IACjB,kBAAkB;IAClB,yGAAyG;IACzG,sGAAsG;IACtG,aAAa;IACb,sBAAsB;AAC1B;;AAEA;IACI,+BAA+B;IAC/B,+CAA+C;IAC/C,YAAY;IACZ,iBAAiB;IACjB,kBAAkB;AACtB;;AAEA,4BAA4B;;AAE5B;IACI,wBAAwB;IACxB,qBAAqB;IACrB,oBAAoB;IACpB,mBAAmB;IACnB,gBAAgB;AACpB;;AAEA;IACI,uCAAuC;AAC3C;;AAEA;IACI,wCAAwC;AAC5C;;AAEA;IACI,0CAA0C;AAC9C;;AAEA;IACI,uCAAuC;AAC3C;;AAEA;IACI,uCAAuC;AAC3C;;AAEA;IACI,wCAAwC;AAC5C;;AAEA;IACI,yCAAyC;IACzC,YAAY;IACZ,gBAAgB;AACpB;;AAEA,wBAAwB;;AAExB;IACI,iBAAiB;IACjB,uCAAuC;IACvC,4CAA4C;IAC5C,qCAAqC;IACrC,mBAAmB;;AAEvB;;AAEA;IACI,YAAY;IACZ,2CAA2C;IAC3C,8CAA8C;IAC9C,mBAAmB;IACnB,6BAA6B;IAC7B,eAAe;AACnB;;AAEA,sBAAsB;;AAEtB;IACI,yCAAyC;IACzC,0CAA0C;AAC9C;;AAEA;IACI,YAAY;IACZ,2CAA2C;IAC3C,iBAAiB;IACjB,kBAAkB;IAClB,gBAAgB;AACpB;;AAEA,0BAA0B;;AAE1B;IACI,uCAAuC;IACvC,qCAAqC;IACrC,4CAA4C;AAChD;;AAEA;IACI,mBAAmB;IACnB,uFAAuF;IACvF,gBAAgB;IAChB,eAAe;IACf,8CAA8C;IAC9C,YAAY,EAAE,gEAAgE;IAC9E,sBAAsB;IACtB,wBAAwB;IACxB,gBAAgB;IAChB,0DAA0D;IAC1D,oCAAoC;IACpC,sCAAsC;IACtC,mBAAmB;IACnB,wDAAwD;CAC3D,gBAAgB;CAChB,wBAAwB;CACxB,qBAAqB;IAClB,4BAA4B;CAC/B,qBAAqB;CACrB,iCAAiC;IAC9B,kDAAkD;AACtD;AACA;IACI,wDAAwD;AAC5D;;AAEA;IACI,2CAA2C;AAC/C;;AAEA;4CAC4C;AAC5C;IACI,kBAAkB;IAClB,uBAAuB;AAC3B;;AAEA,8BAA8B;;AAE9B;IACI,qCAAqC;IACrC,4CAA4C;;IAE5C;;iEAE6D;IAC7D,uBAAuB;AAC3B;;AAEA;IACI,uFAAuF;IACvF,0DAA0D;IAC1D,oCAAoC;IACpC,sCAAsC;IACtC,8CAA8C;IAC9C,wBAAwB;IACxB,cAAc;IACd,eAAe;;IAEf;;iEAE6D;IAC7D,gBAAgB;AACpB;;AAEA;IACI,wDAAwD;AAC5D;;AAEA;IACI,6CAA6C;IAC7C,4CAA4C;IAC5C,iEAAiE;IACjE,gFAAgF;IAChF,mFAAmF;AACvF;;;;AAIA,2BAA2B;;AAE3B;IACI,4CAA4C;AAChD;;AAEA;IACI,qCAAqC;IACrC,sCAAsC;AAC1C;;AAEA;IACI,2CAA2C;AAC/C;;AAEA,0BAA0B;;AAE1B;IACI,qCAAqC;IACrC,4CAA4C;AAChD;;AAEA;IACI,aAAa;IACb,sBAAsB;IACtB,oBAAoB;IACpB,sBAAsB;IACtB,YAAY;IACZ,6DAA6D;AACjE;;AAEA;IACI,2CAA2C;IAC3C,gDAAgD;IAChD,sCAAsC;AAC1C;;AAEA;IACI,2CAA2C;IAC3C,gDAAgD;IAChD,2DAA2D;IAC3D,WAAW;AACf;;AAEA,yBAAyB;;AAEzB;IACI,qCAAqC;IACrC,uCAAuC;IACvC,4CAA4C;AAChD;;AAEA;IACI,YAAY;IACZ,cAAc;IACd,8CAA8C;AAClD;;AAEA;IACI,sCAAsC;IACtC,uCAAuC;IACvC,cAAc,EAAE,4DAA4D;IAC5E,oDAAoD;IACpD,oCAAoC;IACpC,uFAAuF;IACvF,iBAAiB;IACjB,YAAY;IACZ,cAAc;IACd,sBAAsB;IACtB,mBAAmB;IACnB,wBAAwB;AAC5B;;AAEA;IACI,4FAA4F;AAChG;;AAEA;IACI,wDAAwD;AAC5D;;AAEA;IACI,YAAY;IACZ,wBAAwB;IACxB,uCAAuC;IACvC,4CAA4C;IAC5C,oDAAoD;IACpD,oCAAoC;IACpC,uFAAuF;IACvF,sCAAsC;IACtC,qFAAqF;IACrF,YAAY,EAAE,gEAAgE;IAC9E,cAAc;IACd,sBAAsB;AAC1B;;AAEA;IACI,2CAA2C;AAC/C;;AAEA,wBAAwB;;AAExB;IACI,qCAAqC;IACrC,uCAAuC;IACvC,4CAA4C;AAChD;;AAEA;IACI,YAAY;IACZ,cAAc;IACd,YAAY,EAAE,gEAAgE;IAC9E,wBAAwB;IACxB,uCAAuC;IACvC,uFAAuF;IACvF,0DAA0D;IAC1D,oCAAoC;IACpC,sCAAsC;IACtC,qFAAqF;IACrF,sBAAsB;AAC1B;;AAEA;IACI,wDAAwD;AAC5D;;AAEA;IACI,mCAAmC;AACvC;;AAEA;IACI,2CAA2C;AAC/C;;AAEA,gBAAgB;;AAEhB;IACI,2CAA2C;IAC3C,aAAa;IACb,oBAAoB;AACxB;;AAEA;IACI,YAAY;IACZ,YAAY;AAChB;;AAEA;IACI,2CAA2C;AAC/C;;AAEA,eAAe;;AAEf;IACI,aAAa;IACb,sBAAsB;AAC1B;;AAEA;IACI,wFAAwF;IACxF,mBAAmB;IACnB,mBAAmB;AACvB;;AAEA;IACI,gDAAgD;IAChD,qBAAqB;IACrB,YAAY;IACZ,aAAa;AACjB;;AAEA;IACI,WAAW;IACX,sBAAsB;IACtB,SAAS;IACT,mCAAmC;IACnC,+BAA+B;IAC/B,4DAA4D;IAC5D,4CAA4C;IAC5C,YAAY;IACZ,cAAc;AAClB;;AAEA;IACI,8DAA8D;IAC9D,kFAAkF;AACtF;;AAEA;IACI,gDAAgD;IAChD,eAAe;IACf,kFAAkF;IAClF,oDAAoD;IACpD,8CAA8C;IAC9C,iBAAiB;IACjB,mCAAmC;IACnC,+BAA+B;IAC/B,4DAA4D;IAC5D,mBAAmB;IACnB,kBAAkB;AACtB;;AAEA;IACI,+BAA+B;IAC/B,+DAA+D;IAC/D,mCAAmC;IACnC,sFAAsF;IACtF,6CAA6C;IAC7C,iBAAiB;AACrB;;AAEA;IACI,kBAAkB;IAClB,sCAAsC;IACtC,uCAAuC;IACvC,WAAW;IACX,mDAAmD;IACnD,8CAA8C;IAC9C,kCAAkC;AACtC;;AAEA;IACI,cAAc;AAClB;;AAEA;IACI,mCAAmC;IACnC,+BAA+B;AACnC;;AAEA;IACI,gBAAgB;AACpB;;AAEA;6DAC6D;AAC7D;IACI,wBAAwB;IACxB,gBAAgB,EAAE,UAAU;AAChC;;AAEA;;;IAGI,oDAAoD;AACxD;;AAEA,qBAAqB;;AAErB;IACI,aAAa;IACb,sBAAsB;IACtB,oBAAoB;AACxB;;AAEA;IACI,wCAAwC;IACxC,eAAe;IACf,+BAA+B;IAC/B,yCAAyC;IACzC,oEAAoE;IACpE,8FAA8F;IAC9F,iBAAiB;AACrB;;AAEA;IACI,yCAAyC;IACzC,+BAA+B;AACnC;;AAEA;IACI,yCAAyC;IACzC,+BAA+B;IAC/B,eAAe;IACf,mBAAmB;AACvB;;AAEA;IACI,4CAA4C;IAC5C,yCAAyC;IACzC,+BAA+B;IAC/B,yEAAyE;IACzE,0EAA0E;IAC1E,2EAA2E;IAC3E,cAAc;AAClB;;AAEA;IACI,aAAa;IACb,sBAAsB;IACtB,oBAAoB;AACxB;;AAEA;IACI,gBAAgB;AACpB;;AAEA;IACI,eAAe;AACnB;;;;AAIA,gBAAgB;;AAEhB;IACI,sCAAsC;AAC1C;;AAEA;IACI,yCAAyC;IACzC,mBAAmB;IACnB,YAAY;IACZ,cAAc;IACd,iEAAiE;IACjE,4CAA4C;IAC5C,wEAAwE;IACxE,kBAAkB;AACtB;;;AAGA,kBAAkB;;AAElB;IACI,eAAe;IACf,YAAY;AAChB",sourcesContent:['/* Copyright (c) Jupyter Development Team.\n * Distributed under the terms of the Modified BSD License.\n */\n\n/*\n * We assume that the CSS variables in\n * https://github.com/jupyterlab/jupyterlab/blob/master/src/default-theme/variables.css\n * have been defined.\n */\n\n@import "./phosphor.css";\n\n:root {\n    --jp-widgets-color: var(--jp-content-font-color1);\n    --jp-widgets-label-color: var(--jp-widgets-color);\n    --jp-widgets-readout-color: var(--jp-widgets-color);\n    --jp-widgets-font-size: var(--jp-ui-font-size1);\n    --jp-widgets-margin: 2px;\n    --jp-widgets-inline-height: 28px;\n    --jp-widgets-inline-width: 300px;\n    --jp-widgets-inline-width-short: calc(var(--jp-widgets-inline-width) / 2 - var(--jp-widgets-margin));\n    --jp-widgets-inline-width-tiny: calc(var(--jp-widgets-inline-width-short) / 2 - var(--jp-widgets-margin));\n    --jp-widgets-inline-margin: 4px; /* margin between inline elements */\n    --jp-widgets-inline-label-width: 80px;\n    --jp-widgets-border-width: var(--jp-border-width);\n    --jp-widgets-vertical-height: 200px;\n    --jp-widgets-horizontal-tab-height: 24px;\n    --jp-widgets-horizontal-tab-width: 144px;\n    --jp-widgets-horizontal-tab-top-border: 2px;\n    --jp-widgets-progress-thickness: 20px;\n    --jp-widgets-container-padding: 15px;\n    --jp-widgets-input-padding: 4px;\n    --jp-widgets-radio-item-height-adjustment: 8px;\n    --jp-widgets-radio-item-height: calc(var(--jp-widgets-inline-height) - var(--jp-widgets-radio-item-height-adjustment));\n    --jp-widgets-slider-track-thickness: 4px;\n    --jp-widgets-slider-border-width: var(--jp-widgets-border-width);\n    --jp-widgets-slider-handle-size: 16px;\n    --jp-widgets-slider-handle-border-color: var(--jp-border-color1);\n    --jp-widgets-slider-handle-background-color: var(--jp-layout-color1);\n    --jp-widgets-slider-active-handle-color: var(--jp-brand-color1);\n    --jp-widgets-menu-item-height: 24px;\n    --jp-widgets-dropdown-arrow: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCEtLSBHZW5lcmF0b3I6IEFkb2JlIElsbHVzdHJhdG9yIDE5LjIuMSwgU1ZHIEV4cG9ydCBQbHVnLUluIC4gU1ZHIFZlcnNpb246IDYuMDAgQnVpbGQgMCkgIC0tPgo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4IgoJIHZpZXdCb3g9IjAgMCAxOCAxOCIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgMTggMTg7IiB4bWw6c3BhY2U9InByZXNlcnZlIj4KPHN0eWxlIHR5cGU9InRleHQvY3NzIj4KCS5zdDB7ZmlsbDpub25lO30KPC9zdHlsZT4KPHBhdGggZD0iTTUuMiw1LjlMOSw5LjdsMy44LTMuOGwxLjIsMS4ybC00LjksNWwtNC45LTVMNS4yLDUuOXoiLz4KPHBhdGggY2xhc3M9InN0MCIgZD0iTTAtMC42aDE4djE4SDBWLTAuNnoiLz4KPC9zdmc+Cg");\n    --jp-widgets-input-color: var(--jp-ui-font-color1);\n    --jp-widgets-input-background-color: var(--jp-layout-color1);\n    --jp-widgets-input-border-color: var(--jp-border-color1);\n    --jp-widgets-input-focus-border-color: var(--jp-brand-color2);\n    --jp-widgets-input-border-width: var(--jp-widgets-border-width);\n    --jp-widgets-disabled-opacity: 0.6;\n\n    /* From Material Design Lite */\n    --md-shadow-key-umbra-opacity: 0.2;\n    --md-shadow-key-penumbra-opacity: 0.14;\n    --md-shadow-ambient-shadow-opacity: 0.12;\n}\n\n.jupyter-widgets {\n    margin: var(--jp-widgets-margin);\n    box-sizing: border-box;\n    color: var(--jp-widgets-color);\n    overflow: visible;\n}\n\n.jupyter-widgets.jupyter-widgets-disconnected::before {\n    line-height: var(--jp-widgets-inline-height);\n    height: var(--jp-widgets-inline-height);\n}\n\n.jp-Output-result > .jupyter-widgets {\n    margin-left: 0;\n    margin-right: 0;\n}\n\n/* vbox and hbox */\n\n.widget-inline-hbox {\n    /* Horizontal widgets */\n    box-sizing: border-box;\n    display: flex;\n    flex-direction: row;\n    align-items: baseline;\n}\n\n.widget-inline-vbox {\n    /* Vertical Widgets */\n    box-sizing: border-box;\n    display: flex;\n    flex-direction: column;\n    align-items: center;\n}\n\n.widget-box {\n    box-sizing: border-box;\n    display: flex;\n    margin: 0;\n    overflow: auto;\n}\n\n.widget-gridbox {\n    box-sizing: border-box;\n    display: grid;\n    margin: 0;\n    overflow: auto;\n}\n\n.widget-hbox {\n    flex-direction: row;\n}\n\n.widget-vbox {\n    flex-direction: column;\n}\n\n/* General Button Styling */\n\n.jupyter-button {\n    padding-left: 10px;\n    padding-right: 10px;\n    padding-top: 0px;\n    padding-bottom: 0px;\n    display: inline-block;\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    text-align: center;\n    font-size: var(--jp-widgets-font-size);\n    cursor: pointer;\n\n    height: var(--jp-widgets-inline-height);\n    border: 0px solid;\n    line-height: var(--jp-widgets-inline-height);\n    box-shadow: none;\n\n    color: var(--jp-ui-font-color1);\n    background-color: var(--jp-layout-color2);\n    border-color: var(--jp-border-color2);\n    border: none;\n    user-select: none;\n}\n\n.jupyter-button i.fa {\n    margin-right: var(--jp-widgets-inline-margin);\n    pointer-events: none;\n}\n\n.jupyter-button:empty:before {\n    content: "\\200b"; /* zero-width space */\n}\n\n.jupyter-widgets.jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n.jupyter-button i.fa.center {\n    margin-right: 0;\n}\n\n.jupyter-button:hover:enabled, .jupyter-button:focus:enabled {\n    /* MD Lite 2dp shadow */\n    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, var(--md-shadow-key-penumbra-opacity)),\n                0 3px 1px -2px rgba(0, 0, 0, var(--md-shadow-key-umbra-opacity)),\n                0 1px 5px 0 rgba(0, 0, 0, var(--md-shadow-ambient-shadow-opacity));\n}\n\n.jupyter-button:active, .jupyter-button.mod-active {\n    /* MD Lite 4dp shadow */\n    box-shadow: 0 4px 5px 0 rgba(0, 0, 0, var(--md-shadow-key-penumbra-opacity)),\n                0 1px 10px 0 rgba(0, 0, 0, var(--md-shadow-ambient-shadow-opacity)),\n                0 2px 4px -1px rgba(0, 0, 0, var(--md-shadow-key-umbra-opacity));\n    color: var(--jp-ui-font-color1);\n    background-color: var(--jp-layout-color3);\n}\n\n.jupyter-button:focus:enabled {\n    outline: 1px solid var(--jp-widgets-input-focus-border-color);\n}\n\n/* Button "Primary" Styling */\n\n.jupyter-button.mod-primary {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-brand-color1);\n}\n\n.jupyter-button.mod-primary.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-brand-color0);\n}\n\n.jupyter-button.mod-primary:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-brand-color0);\n}\n\n/* Button "Success" Styling */\n\n.jupyter-button.mod-success {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-success-color1);\n}\n\n.jupyter-button.mod-success.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-success-color0);\n}\n\n.jupyter-button.mod-success:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-success-color0);\n}\n\n /* Button "Info" Styling */\n\n.jupyter-button.mod-info {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-info-color1);\n}\n\n.jupyter-button.mod-info.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-info-color0);\n}\n\n.jupyter-button.mod-info:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-info-color0);\n}\n\n/* Button "Warning" Styling */\n\n.jupyter-button.mod-warning {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-warn-color1);\n}\n\n.jupyter-button.mod-warning.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-warn-color0);\n}\n\n.jupyter-button.mod-warning:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-warn-color0);\n}\n\n/* Button "Danger" Styling */\n\n.jupyter-button.mod-danger {\n    color: var(--jp-ui-inverse-font-color1, var(--jp-inverse-ui-font-color1));\n    background-color: var(--jp-error-color1);\n}\n\n.jupyter-button.mod-danger.mod-active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-error-color0);\n}\n\n.jupyter-button.mod-danger:active {\n    color: var(--jp-ui-inverse-font-color0, var(--jp-inverse-ui-font-color0));\n    background-color: var(--jp-error-color0);\n}\n\n/* Widget Button, Widget Toggle Button, Widget Upload */\n\n.widget-button, .widget-toggle-button, .widget-upload {\n    width: var(--jp-widgets-inline-width-short);\n}\n\n/* Widget Label Styling */\n\n/* Override Bootstrap label css */\n.jupyter-widgets label {\n    margin-bottom: initial;\n}\n\n.widget-label-basic {\n    /* Basic Label */\n    color: var(--jp-widgets-label-color);\n    font-size: var(--jp-widgets-font-size);\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-label {\n    /* Label */\n    color: var(--jp-widgets-label-color);\n    font-size: var(--jp-widgets-font-size);\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-inline-hbox .widget-label {\n    /* Horizontal Widget Label */\n    color: var(--jp-widgets-label-color);\n    text-align: right;\n    margin-right: calc( var(--jp-widgets-inline-margin) * 2 );\n    width: var(--jp-widgets-inline-label-width);\n    flex-shrink: 0;\n}\n\n.widget-inline-vbox .widget-label {\n    /* Vertical Widget Label */\n    color: var(--jp-widgets-label-color);\n    text-align: center;\n    line-height: var(--jp-widgets-inline-height);\n}\n\n/* Widget Readout Styling */\n\n.widget-readout {\n    color: var(--jp-widgets-readout-color);\n    font-size: var(--jp-widgets-font-size);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    overflow: hidden;\n    white-space: nowrap;\n    text-align: center;\n}\n\n.widget-readout.overflow {\n    /* Overflowing Readout */\n\n    /* From Material Design Lite\n        shadow-key-umbra-opacity: 0.2;\n        shadow-key-penumbra-opacity: 0.14;\n        shadow-ambient-shadow-opacity: 0.12;\n     */\n    -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                        0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                        0 1px 5px 0 rgba(0, 0, 0, 0.12);\n\n    -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                     0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                     0 1px 5px 0 rgba(0, 0, 0, 0.12);\n\n    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.2),\n                0 3px 1px -2px rgba(0, 0, 0, 0.14),\n                0 1px 5px 0 rgba(0, 0, 0, 0.12);\n}\n\n.widget-inline-hbox .widget-readout {\n    /* Horizontal Readout */\n    text-align: center;\n    max-width: var(--jp-widgets-inline-width-short);\n    min-width: var(--jp-widgets-inline-width-tiny);\n    margin-left: var(--jp-widgets-inline-margin);\n}\n\n.widget-inline-vbox .widget-readout {\n    /* Vertical Readout */\n    margin-top: var(--jp-widgets-inline-margin);\n    /* as wide as the widget */\n    width: inherit;\n}\n\n/* Widget Checkbox Styling */\n\n.widget-checkbox {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-checkbox input[type="checkbox"] {\n    margin: 0px calc( var(--jp-widgets-inline-margin) * 2 ) 0px 0px;\n    line-height: var(--jp-widgets-inline-height);\n    font-size: large;\n    flex-grow: 1;\n    flex-shrink: 0;\n    align-self: center;\n}\n\n/* Widget Valid Styling */\n\n.widget-valid {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width-short);\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-valid i:before {\n    line-height: var(--jp-widgets-inline-height);\n    margin-right: var(--jp-widgets-inline-margin);\n    margin-left: var(--jp-widgets-inline-margin);\n}\n\n.widget-valid.mod-valid i:before {\n    color: green;\n}\n\n.widget-valid.mod-invalid i:before {\n    color: red;\n}\n\n.widget-valid.mod-valid .widget-valid-readout {\n    display: none;\n}\n\n/* Widget Text and TextArea Stying */\n\n.widget-textarea, .widget-text {\n    width: var(--jp-widgets-inline-width);\n}\n\n.widget-text input[type="text"], .widget-text input[type="number"], .widget-text input[type="password"] {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-text input[type="text"]:disabled, .widget-text input[type="number"]:disabled, .widget-text input[type="password"]:disabled, .widget-textarea textarea:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n.widget-text input[type="text"], .widget-text input[type="number"], .widget-text input[type="password"], .widget-textarea textarea {\n    box-sizing: border-box;\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    flex-grow: 1;\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    flex-shrink: 1;\n    outline: none !important;\n}\n    \n.widget-text input[type="text"], .widget-text input[type="password"], .widget-textarea textarea {\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2);\n}\n\n.widget-text input[type="number"] {\n    padding: var(--jp-widgets-input-padding) 0 var(--jp-widgets-input-padding) calc(var(--jp-widgets-input-padding) *  2);\n}\n\n.widget-textarea textarea {\n    height: inherit;\n    width: inherit;\n}\n\n.widget-text input:focus, .widget-textarea textarea:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n/* Widget Slider */\n\n.widget-slider .ui-slider {\n    /* Slider Track */\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-layout-color3);\n    background: var(--jp-layout-color3);\n    box-sizing: border-box;\n    position: relative;\n    border-radius: 0px;\n}\n\n.widget-slider .ui-slider .ui-slider-handle {\n    /* Slider Handle */\n    outline: none !important; /* focused slider handles are colored - see below */\n    position: absolute;\n    background-color: var(--jp-widgets-slider-handle-background-color);\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-widgets-slider-handle-border-color);\n    box-sizing: border-box;\n    z-index: 1;\n    background-image: none; /* Override jquery-ui */\n}\n\n/* Override jquery-ui */\n.widget-slider .ui-slider .ui-slider-handle:hover, .widget-slider .ui-slider .ui-slider-handle:focus {\n    background-color: var(--jp-widgets-slider-active-handle-color);\n    border: var(--jp-widgets-slider-border-width) solid var(--jp-widgets-slider-active-handle-color);\n}\n\n.widget-slider .ui-slider .ui-slider-handle:active {\n    background-color: var(--jp-widgets-slider-active-handle-color);\n    border-color: var(--jp-widgets-slider-active-handle-color);\n    z-index: 2;\n    transform: scale(1.2);\n}\n\n.widget-slider  .ui-slider .ui-slider-range {\n    /* Interval between the two specified value of a double slider */\n    position: absolute;\n    background: var(--jp-widgets-slider-active-handle-color);\n    z-index: 0;\n}\n\n/* Shapes of Slider Handles */\n\n.widget-hslider .ui-slider .ui-slider-handle {\n    width: var(--jp-widgets-slider-handle-size);\n    height: var(--jp-widgets-slider-handle-size);\n    margin-top: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-handle-size)) / 2 - var(--jp-widgets-slider-border-width));\n    margin-left: calc(var(--jp-widgets-slider-handle-size) / -2 + var(--jp-widgets-slider-border-width));\n    border-radius: 50%;\n    top: 0;\n}\n\n.widget-vslider .ui-slider .ui-slider-handle {\n    width: var(--jp-widgets-slider-handle-size);\n    height: var(--jp-widgets-slider-handle-size);\n    margin-bottom: calc(var(--jp-widgets-slider-handle-size) / -2 + var(--jp-widgets-slider-border-width));\n    margin-left: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-handle-size)) / 2 - var(--jp-widgets-slider-border-width));\n    border-radius: 50%;\n    left: 0;\n}\n\n.widget-hslider .ui-slider .ui-slider-range {\n    height: calc( var(--jp-widgets-slider-track-thickness) * 2 );\n    margin-top: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-track-thickness) * 2 ) / 2 - var(--jp-widgets-slider-border-width));\n}\n\n.widget-vslider .ui-slider .ui-slider-range {\n    width: calc( var(--jp-widgets-slider-track-thickness) * 2 );\n    margin-left: calc((var(--jp-widgets-slider-track-thickness) - var(--jp-widgets-slider-track-thickness) * 2 ) / 2 - var(--jp-widgets-slider-border-width));\n}\n\n/* Horizontal Slider */\n\n.widget-hslider {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n\n    /* Override the align-items baseline. This way, the description and readout\n    still seem to align their baseline properly, and we don\'t have to have\n    align-self: stretch in the .slider-container. */\n    align-items: center;\n}\n\n.widgets-slider .slider-container {\n    overflow: visible;\n}\n\n.widget-hslider .slider-container {\n    height: var(--jp-widgets-inline-height);\n    margin-left: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    margin-right: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n}\n\n.widget-hslider .ui-slider {\n    /* Inner, invisible slide div */\n    height: var(--jp-widgets-slider-track-thickness);\n    margin-top: calc((var(--jp-widgets-inline-height) - var(--jp-widgets-slider-track-thickness)) / 2);\n    width: 100%;\n}\n\n/* Vertical Slider */\n\n.widget-vbox .widget-label {\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-vslider {\n    /* Vertical Slider */\n    height: var(--jp-widgets-vertical-height);\n    width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-vslider .slider-container {\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    margin-left: auto;\n    margin-right: auto;\n    margin-bottom: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    margin-top: calc(var(--jp-widgets-slider-handle-size) / 2 - 2 * var(--jp-widgets-slider-border-width));\n    display: flex;\n    flex-direction: column;\n}\n\n.widget-vslider .ui-slider-vertical {\n    /* Inner, invisible slide div */\n    width: var(--jp-widgets-slider-track-thickness);\n    flex-grow: 1;\n    margin-left: auto;\n    margin-right: auto;\n}\n\n/* Widget Progress Styling */\n\n.progress-bar {\n    -webkit-transition: none;\n    -moz-transition: none;\n    -ms-transition: none;\n    -o-transition: none;\n    transition: none;\n}\n\n.progress-bar {\n    height: var(--jp-widgets-inline-height);\n}\n\n.progress-bar {\n    background-color: var(--jp-brand-color1);\n}\n\n.progress-bar-success {\n    background-color: var(--jp-success-color1);\n}\n\n.progress-bar-info {\n    background-color: var(--jp-info-color1);\n}\n\n.progress-bar-warning {\n    background-color: var(--jp-warn-color1);\n}\n\n.progress-bar-danger {\n    background-color: var(--jp-error-color1);\n}\n\n.progress {\n    background-color: var(--jp-layout-color2);\n    border: none;\n    box-shadow: none;\n}\n\n/* Horisontal Progress */\n\n.widget-hprogress {\n    /* Progress Bar */\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width);\n    align-items: center;\n\n}\n\n.widget-hprogress .progress {\n    flex-grow: 1;\n    margin-top: var(--jp-widgets-input-padding);\n    margin-bottom: var(--jp-widgets-input-padding);\n    align-self: stretch;\n    /* Override bootstrap style */\n    height: initial;\n}\n\n/* Vertical Progress */\n\n.widget-vprogress {\n    height: var(--jp-widgets-vertical-height);\n    width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-vprogress .progress {\n    flex-grow: 1;\n    width: var(--jp-widgets-progress-thickness);\n    margin-left: auto;\n    margin-right: auto;\n    margin-bottom: 0;\n}\n\n/* Select Widget Styling */\n\n.widget-dropdown {\n    height: var(--jp-widgets-inline-height);\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-dropdown > select {\n    padding-right: 20px;\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    border-radius: 0;\n    height: inherit;\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    box-sizing: border-box;\n    outline: none !important;\n    box-shadow: none;\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    vertical-align: top;\n    padding-left: calc( var(--jp-widgets-input-padding) * 2);\n\tappearance: none;\n\t-webkit-appearance: none;\n\t-moz-appearance: none;\n    background-repeat: no-repeat;\n\tbackground-size: 20px;\n\tbackground-position: right center;\n    background-image: var(--jp-widgets-dropdown-arrow);\n}\n.widget-dropdown > select:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-dropdown > select:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* To disable the dotted border in Firefox around select controls.\n   See http://stackoverflow.com/a/18853002 */\n.widget-dropdown > select:-moz-focusring {\n    color: transparent;\n    text-shadow: 0 0 0 #000;\n}\n\n/* Select and SelectMultiple */\n\n.widget-select {\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n\n    /* Because Firefox defines the baseline of a select as the bottom of the\n    control, we align the entire control to the top and add padding to the\n    select to get an approximate first line baseline alignment. */\n    align-items: flex-start;\n}\n\n.widget-select > select {\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    flex: 1 1 var(--jp-widgets-inline-width-short);\n    outline: none !important;\n    overflow: auto;\n    height: inherit;\n\n    /* Because Firefox defines the baseline of a select as the bottom of the\n    control, we align the entire control to the top and add padding to the\n    select to get an approximate first line baseline alignment. */\n    padding-top: 5px;\n}\n\n.widget-select > select:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.wiget-select > select > option {\n    padding-left: var(--jp-widgets-input-padding);\n    line-height: var(--jp-widgets-inline-height);\n    /* line-height doesn\'t work on some browsers for select options */\n    padding-top: calc(var(--jp-widgets-inline-height)-var(--jp-widgets-font-size)/2);\n    padding-bottom: calc(var(--jp-widgets-inline-height)-var(--jp-widgets-font-size)/2);\n}\n\n\n\n/* Toggle Buttons Styling */\n\n.widget-toggle-buttons {\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-toggle-buttons .widget-toggle-button {\n    margin-left: var(--jp-widgets-margin);\n    margin-right: var(--jp-widgets-margin);\n}\n\n.widget-toggle-buttons .jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Radio Buttons Styling */\n\n.widget-radio {\n    width: var(--jp-widgets-inline-width);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-radio-box {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n    box-sizing: border-box;\n    flex-grow: 1;\n    margin-bottom: var(--jp-widgets-radio-item-height-adjustment);\n}\n\n.widget-radio-box label {\n    height: var(--jp-widgets-radio-item-height);\n    line-height: var(--jp-widgets-radio-item-height);\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-radio-box input {\n    height: var(--jp-widgets-radio-item-height);\n    line-height: var(--jp-widgets-radio-item-height);\n    margin: 0 calc( var(--jp-widgets-input-padding) * 2 ) 0 1px;\n    float: left;\n}\n\n/* Color Picker Styling */\n\n.widget-colorpicker {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-colorpicker > .widget-colorpicker-input {\n    flex-grow: 1;\n    flex-shrink: 1;\n    min-width: var(--jp-widgets-inline-width-tiny);\n}\n\n.widget-colorpicker input[type="color"] {\n    width: var(--jp-widgets-inline-height);\n    height: var(--jp-widgets-inline-height);\n    padding: 0 2px; /* make the color square actually square on Chrome on OS X */\n    background: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    border-left: none;\n    flex-grow: 0;\n    flex-shrink: 0;\n    box-sizing: border-box;\n    align-self: stretch;\n    outline: none !important;\n}\n\n.widget-colorpicker.concise input[type="color"] {\n    border-left: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n}\n\n.widget-colorpicker input[type="color"]:focus, .widget-colorpicker input[type="text"]:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-colorpicker input[type="text"] {\n    flex-grow: 1;\n    outline: none !important;\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n    background: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    font-size: var(--jp-widgets-font-size);\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2 );\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    flex-shrink: 1;\n    box-sizing: border-box;\n}\n\n.widget-colorpicker input[type="text"]:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Date Picker Styling */\n\n.widget-datepicker {\n    width: var(--jp-widgets-inline-width);\n    height: var(--jp-widgets-inline-height);\n    line-height: var(--jp-widgets-inline-height);\n}\n\n.widget-datepicker input[type="date"] {\n    flex-grow: 1;\n    flex-shrink: 1;\n    min-width: 0; /* This makes it possible for the flexbox to shrink this input */\n    outline: none !important;\n    height: var(--jp-widgets-inline-height);\n    border: var(--jp-widgets-input-border-width) solid var(--jp-widgets-input-border-color);\n    background-color: var(--jp-widgets-input-background-color);\n    color: var(--jp-widgets-input-color);\n    font-size: var(--jp-widgets-font-size);\n    padding: var(--jp-widgets-input-padding) calc( var(--jp-widgets-input-padding) *  2 );\n    box-sizing: border-box;\n}\n\n.widget-datepicker input[type="date"]:focus {\n    border-color: var(--jp-widgets-input-focus-border-color);\n}\n\n.widget-datepicker input[type="date"]:invalid {\n    border-color: var(--jp-warn-color1);\n}\n\n.widget-datepicker input[type="date"]:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Play Widget */\n\n.widget-play {\n    width: var(--jp-widgets-inline-width-short);\n    display: flex;\n    align-items: stretch;\n}\n\n.widget-play .jupyter-button {\n    flex-grow: 1;\n    height: auto;\n}\n\n.widget-play .jupyter-button:disabled {\n    opacity: var(--jp-widgets-disabled-opacity);\n}\n\n/* Tab Widget */\n\n.jupyter-widgets.widget-tab {\n    display: flex;\n    flex-direction: column;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n    /* Necessary so that a tab can be shifted down to overlay the border of the box below. */\n    overflow-x: visible;\n    overflow-y: visible;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar > .p-TabBar-content {\n    /* Make sure that the tab grows from bottom up */\n    align-items: flex-end;\n    min-width: 0;\n    min-height: 0;\n}\n\n.jupyter-widgets.widget-tab > .widget-tab-contents {\n    width: 100%;\n    box-sizing: border-box;\n    margin: 0;\n    background: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n    border: var(--jp-border-width) solid var(--jp-border-color1);\n    padding: var(--jp-widgets-container-padding);\n    flex-grow: 1;\n    overflow: auto;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n    font: var(--jp-widgets-font-size) Helvetica, Arial, sans-serif;\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + var(--jp-border-width));\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab {\n    flex: 0 1 var(--jp-widgets-horizontal-tab-width);\n    min-width: 35px;\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + var(--jp-border-width));\n    line-height: var(--jp-widgets-horizontal-tab-height);\n    margin-left: calc(-1 * var(--jp-border-width));\n    padding: 0px 10px;\n    background: var(--jp-layout-color2);\n    color: var(--jp-ui-font-color2);\n    border: var(--jp-border-width) solid var(--jp-border-color1);\n    border-bottom: none;\n    position: relative;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-current {\n    color: var(--jp-ui-font-color0);\n    /* We want the background to match the tab content background */\n    background: var(--jp-layout-color1);\n    min-height: calc(var(--jp-widgets-horizontal-tab-height) + 2 * var(--jp-border-width));\n    transform: translateY(var(--jp-border-width));\n    overflow: visible;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-current:before {\n    position: absolute;\n    top: calc(-1 * var(--jp-border-width));\n    left: calc(-1 * var(--jp-border-width));\n    content: \'\';\n    height: var(--jp-widgets-horizontal-tab-top-border);\n    width: calc(100% + 2 * var(--jp-border-width));\n    background: var(--jp-brand-color1);\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab:first-child {\n    margin-left: 0;\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab:hover:not(.p-mod-current) {\n    background: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-mod-closable > .p-TabBar-tabCloseIcon {\n    margin-left: 4px;\n}\n\n/* This font-awesome strategy may not work across FA4 and FA5, but we don\'t\nactually support closable tabs, so it really doesn\'t matter */\n.jupyter-widgets.widget-tab > .p-TabBar .p-mod-closable > .p-TabBar-tabCloseIcon:before {\n    font-family: FontAwesome;\n    content: \'\\f00d\'; /* close */\n}\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabIcon,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabLabel,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabCloseIcon {\n    line-height: var(--jp-widgets-horizontal-tab-height);\n}\n\n/* Accordion Widget */\n\n.p-Collapse {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n}\n\n.p-Collapse-header {\n    padding: var(--jp-widgets-input-padding);\n    cursor: pointer;\n    color: var(--jp-ui-font-color2);\n    background-color: var(--jp-layout-color2);\n    border: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    padding: calc(var(--jp-widgets-container-padding) * 2 / 3) var(--jp-widgets-container-padding);\n    font-weight: bold;\n}\n\n.p-Collapse-header:hover {\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n}\n\n.p-Collapse-open > .p-Collapse-header {\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color0);\n    cursor: default;\n    border-bottom: none;\n}\n\n.p-Collapse-contents {\n    padding: var(--jp-widgets-container-padding);\n    background-color: var(--jp-layout-color1);\n    color: var(--jp-ui-font-color1);\n    border-left: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    border-right: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    border-bottom: var(--jp-widgets-border-width) solid var(--jp-border-color1);\n    overflow: auto;\n}\n\n.p-Accordion {\n    display: flex;\n    flex-direction: column;\n    align-items: stretch;\n}\n\n.p-Accordion .p-Collapse {\n    margin-bottom: 0;\n}\n\n.p-Accordion .p-Collapse + .p-Collapse {\n    margin-top: 4px;\n}\n\n\n\n/* HTML widget */\n\n.widget-html, .widget-htmlmath {\n    font-size: var(--jp-widgets-font-size);\n}\n\n.widget-html > .widget-html-content, .widget-htmlmath > .widget-html-content {\n    /* Fill out the area in the HTML widget */\n    align-self: stretch;\n    flex-grow: 1;\n    flex-shrink: 1;\n    /* Makes sure the baseline is still aligned with other elements */\n    line-height: var(--jp-widgets-inline-height);\n    /* Make it possible to have absolutely-positioned elements in the html */\n    position: relative;\n}\n\n\n/* Image widget  */\n\n.widget-image {\n    max-width: 100%;\n    height: auto;\n}\n'],sourceRoot:""}]),t.a=l},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r,i=n(30),o=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var i=0;for(r=Object.getOwnPropertySymbols(e);i<r.length;i++)t.indexOf(r[i])<0&&Object.prototype.propertyIsEnumerable.call(e,r[i])&&(n[r[i]]=e[r[i]])}return n};!function(e){const t={breadCrumb:{container:{$nest:{"&:first-child svg":{bottom:"1px",marginLeft:"0px",position:"relative"},"&:hover":{backgroundColor:"var(--jp-layout-color2)"},".jp-mod-dropTarget&":{backgroundColor:"var(--jp-brand-color2)",opacity:.7}}},element:{borderRadius:"var(--jp-border-radius)",cursor:"pointer",margin:"0px 2px",padding:"0px 2px",height:"16px",width:"16px",verticalAlign:"middle"}},commandPaletteHeader:{container:{height:"14px",margin:"0 14px 0 auto"},element:{height:"14px",width:"14px"},options:{elementPosition:"center"}},commandPaletteItem:{element:{height:"16px",width:"16px"},options:{elementPosition:"center"}},launcherCard:{container:{height:"52px",width:"52px"},element:{height:"52px",width:"52px"},options:{elementPosition:"center"}},launcherSection:{container:{boxSizing:"border-box",marginRight:"12px",height:"32px",width:"32px"},element:{height:"32px",width:"32px"},options:{elementPosition:"center"}},listing:{container:{flex:"0 0 20px",marginRight:"4px",position:"relative"},element:{height:"16px",width:"16px"},options:{elementPosition:"center"}},listingHeaderItem:{container:{display:"inline",height:"16px",width:"16px"},element:{height:"auto",margin:"-2px 0 0 0",width:"20px"},options:{elementPosition:"center"}},mainAreaTab:{container:{$nest:{".lm-DockPanel-tabBar &":{marginRight:"4px"},"#tab-manager &":{marginRight:"2px",position:"relative"}}},element:{$nest:{".lm-DockPanel-tabBar &":{height:"14px",width:"14px"},"#tab-manager &":{height:"16px",width:"16px"}}},options:{elementPosition:"center"}},menuItem:{container:{display:"inline-block",verticalAlign:"middle"},element:{height:"16px",width:"16px"},options:{elementPosition:"center"}},runningItem:{container:{margin:"0px 4px 0px 4px"},element:{height:"16px",width:"16px"},options:{elementPosition:"center"}},select:{container:{pointerEvents:"none"},element:{position:"absolute",height:"auto",width:"16px"}},settingsEditor:{container:{display:"inline-block",flex:"0 0 20px",margin:"0 3px 0 0",position:"relative",height:"20px",width:"20px"},element:{height:"16px",width:"16px"},options:{elementPosition:"center"}},sideBar:{container:{$nest:{".jp-SideBar.jp-mod-left .lm-TabBar-tab &":{transform:"rotate(90deg)"},".jp-SideBar.jp-mod-left .lm-TabBar-tab.lm-mod-current &":{transform:"rotate(90deg)\n    translate(\n      calc(-0.5 * var(--jp-border-width)),\n      calc(-0.5 * var(--jp-border-width))\n    )"},".jp-SideBar.jp-mod-right .lm-TabBar-tab &":{transform:"rotate(-90deg)"},".jp-SideBar.jp-mod-right .lm-TabBar-tab.lm-mod-current &":{transform:"rotate(-90deg)\n    translate(\n      calc(0.5 * var(--jp-border-width)),\n      calc(-0.5 * var(--jp-border-width))\n    )"}}},element:{height:"auto",width:"20px"},options:{elementPosition:"center"}},splash:{container:{animation:"0.3s fade-in linear forwards",height:"100%",width:"100%",zIndex:1},element:{width:"100px"},options:{elementPosition:"center"}},statusBar:{element:{left:"0px",top:"0px",height:"18px",width:"20px",position:"relative"}},toolbarButton:{container:{display:"inline-block",verticalAlign:"middle"},element:{height:"16px",width:"16px"},options:{elementPosition:"center"}}};function n(e){return{container:{alignItems:"center",display:"flex"},element:Object.assign({display:"block"},e)}}const r={center:n({margin:"0 auto",width:"100%"}),top:n({margin:"0 0 auto 0"}),right:n({margin:"0 0 0 auto"}),bottom:n({margin:"auto 0 0 0"}),left:n({margin:"0 auto 0 0"}),"top right":n({margin:"0 0 auto auto"}),"bottom right":n({margin:"auto 0 0 auto"}),"bottom left":n({margin:"auto auto 0 0"}),"top left":n({margin:"0 auto 0 auto"})};function a(e){return{element:{height:e,width:e}}}const s={small:a("14px"),normal:a("16px"),large:a("20px"),xlarge:a("24px")};function l(e){const t=Object.assign({},...e.map(e=>e.options));return t.elementPosition&&e.unshift(r[t.elementPosition]),t.elementSize&&e.unshift(s[t.elementSize]),function(e){return{container:Object.assign({},...e.map(e=>e.container)),element:Object.assign({},...e.map(e=>e.element))}}(e)}const c=new Map;e.styleClass=function(e){if(!e||0===Object.keys(e).length)return"";let{elementPosition:n,elementSize:r,stylesheet:a,kind:s,justify:u}=e,d=o(e,["elementPosition","elementSize","stylesheet","kind","justify"]);a||(a=s),n||(n=u);const h=Object.assign(Object.assign({},n&&{elementPosition:n}),r&&{elementSize:r}),p="string"==typeof a&&0===Object.keys(d).length,f=p?[a,n,r].join(","):"";if(p&&c.has(f))return c.get(f);const m=function(e){return e?(Array.isArray(e)||(e=[e]),e.map(e=>"string"==typeof e?t[e]:e)):[]}(a);m.push({element:d,options:h});const g=function(e){var t;return Object(i.style)(Object.assign(Object.assign({},e.container),{$nest:Object.assign(Object.assign({},null===(t=e.container)||void 0===t?void 0:t.$nest),{svg:e.element})}))}(l(m));return p&&c.set(f,g),g}}(r||(r={}))},function(e,t,n){!function(e){"use strict";e.defineMode("javascript",(function(t,n){var r,i,o=t.indentUnit,a=n.statementIndent,s=n.jsonld,l=n.json||s,c=!1!==n.trackScope,u=n.typescript,d=n.wordCharacters||/[\w$\xa1-\uffff]/,h=function(){function e(e){return{type:e,style:"keyword"}}var t=e("keyword a"),n=e("keyword b"),r=e("keyword c"),i=e("keyword d"),o=e("operator"),a={type:"atom",style:"atom"};return{if:e("if"),while:t,with:t,else:n,do:n,try:n,finally:n,return:i,break:i,continue:i,new:e("new"),delete:r,void:r,throw:r,debugger:e("debugger"),var:e("var"),const:e("var"),let:e("var"),function:e("function"),catch:e("catch"),for:e("for"),switch:e("switch"),case:e("case"),default:e("default"),in:o,typeof:o,instanceof:o,true:a,false:a,null:a,undefined:a,NaN:a,Infinity:a,this:e("this"),class:e("class"),super:e("atom"),yield:r,export:e("export"),import:e("import"),extends:r,await:r}}(),p=/[+\-*&%=<>!?|~^@]/,f=/^@(context|id|value|language|type|container|list|set|reverse|index|base|vocab|graph)"/;function m(e,t,n){return r=e,i=n,t}function g(e,t){var n,r=e.next();if('"'==r||"'"==r)return t.tokenize=(n=r,function(e,t){var r,i=!1;if(s&&"@"==e.peek()&&e.match(f))return t.tokenize=g,m("jsonld-keyword","meta");for(;null!=(r=e.next())&&(r!=n||i);)i=!i&&"\\"==r;return i||(t.tokenize=g),m("string","string")}),t.tokenize(e,t);if("."==r&&e.match(/^\d[\d_]*(?:[eE][+\-]?[\d_]+)?/))return m("number","number");if("."==r&&e.match(".."))return m("spread","meta");if(/[\[\]{}\(\),;\:\.]/.test(r))return m(r);if("="==r&&e.eat(">"))return m("=>","operator");if("0"==r&&e.match(/^(?:x[\dA-Fa-f_]+|o[0-7_]+|b[01_]+)n?/))return m("number","number");if(/\d/.test(r))return e.match(/^[\d_]*(?:n|(?:\.[\d_]*)?(?:[eE][+\-]?[\d_]+)?)?/),m("number","number");if("/"==r)return e.eat("*")?(t.tokenize=v,v(e,t)):e.eat("/")?(e.skipToEnd(),m("comment","comment")):Ze(e,t,1)?(function(e){for(var t,n=!1,r=!1;null!=(t=e.next());){if(!n){if("/"==t&&!r)return;"["==t?r=!0:r&&"]"==t&&(r=!1)}n=!n&&"\\"==t}}(e),e.match(/^\b(([gimyus])(?![gimyus]*\2))+\b/),m("regexp","string-2")):(e.eat("="),m("operator","operator",e.current()));if("`"==r)return t.tokenize=y,y(e,t);if("#"==r&&"!"==e.peek())return e.skipToEnd(),m("meta","meta");if("#"==r&&e.eatWhile(d))return m("variable","property");if("<"==r&&e.match("!--")||"-"==r&&e.match("->")&&!/\S/.test(e.string.slice(0,e.start)))return e.skipToEnd(),m("comment","comment");if(p.test(r))return">"==r&&t.lexical&&">"==t.lexical.type||(e.eat("=")?"!"!=r&&"="!=r||e.eat("="):/[<>*+\-|&?]/.test(r)&&(e.eat(r),">"==r&&e.eat(r))),"?"==r&&e.eat(".")?m("."):m("operator","operator",e.current());if(d.test(r)){e.eatWhile(d);var i=e.current();if("."!=t.lastType){if(h.propertyIsEnumerable(i)){var o=h[i];return m(o.type,o.style,i)}if("async"==i&&e.match(/^(\s|\/\*([^*]|\*(?!\/))*?\*\/)*[\[\(\w]/,!1))return m("async","keyword",i)}return m("variable","variable",i)}}function v(e,t){for(var n,r=!1;n=e.next();){if("/"==n&&r){t.tokenize=g;break}r="*"==n}return m("comment","comment")}function y(e,t){for(var n,r=!1;null!=(n=e.next());){if(!r&&("`"==n||"$"==n&&e.eat("{"))){t.tokenize=g;break}r=!r&&"\\"==n}return m("quasi","string-2",e.current())}function _(e,t){t.fatArrowAt&&(t.fatArrowAt=null);var n=e.string.indexOf("=>",e.start);if(!(n<0)){if(u){var r=/:\s*(?:\w+(?:<[^>]*>|\[\])?|\{[^}]*\})\s*$/.exec(e.string.slice(e.start,n));r&&(n=r.index)}for(var i=0,o=!1,a=n-1;a>=0;--a){var s=e.string.charAt(a),l="([{}])".indexOf(s);if(l>=0&&l<3){if(!i){++a;break}if(0==--i){"("==s&&(o=!0);break}}else if(l>=3&&l<6)++i;else if(d.test(s))o=!0;else if(/["'\/`]/.test(s))for(;;--a){if(0==a)return;if(e.string.charAt(a-1)==s&&"\\"!=e.string.charAt(a-2)){a--;break}}else if(o&&!i){++a;break}}o&&!i&&(t.fatArrowAt=a)}}var b={atom:!0,number:!0,variable:!0,string:!0,regexp:!0,this:!0,import:!0,"jsonld-keyword":!0};function M(e,t,n,r,i,o){this.indented=e,this.column=t,this.type=n,this.prev=i,this.info=o,null!=r&&(this.align=r)}function w(e,t){if(!c)return!1;for(var n=e.localVars;n;n=n.next)if(n.name==t)return!0;for(var r=e.context;r;r=r.prev)for(n=r.vars;n;n=n.next)if(n.name==t)return!0}function A(e,t,n,r,i){var o=e.cc;for(C.state=e,C.stream=i,C.marked=null,C.cc=o,C.style=t,e.lexical.hasOwnProperty("align")||(e.lexical.align=!0);;)if((o.length?o.pop():l?F:B)(n,r)){for(;o.length&&o[o.length-1].lex;)o.pop()();return C.marked?C.marked:"variable"==n&&w(e,r)?"variable-2":t}}var C={state:null,column:null,marked:null,cc:null};function x(){for(var e=arguments.length-1;e>=0;e--)C.cc.push(arguments[e])}function E(){return x.apply(null,arguments),!0}function L(e,t){for(var n=t;n;n=n.next)if(n.name==e)return!0;return!1}function S(e){var t=C.state;if(C.marked="def",c){if(t.context)if("var"==t.lexical.info&&t.context&&t.context.block){var r=function e(t,n){if(n){if(n.block){var r=e(t,n.prev);return r?r==n.prev?n:new O(r,n.vars,!0):null}return L(t,n.vars)?n:new O(n.prev,new I(t,n.vars),!1)}return null}(e,t.context);if(null!=r)return void(t.context=r)}else if(!L(e,t.localVars))return void(t.localVars=new I(e,t.localVars));n.globalVars&&!L(e,t.globalVars)&&(t.globalVars=new I(e,t.globalVars))}}function T(e){return"public"==e||"private"==e||"protected"==e||"abstract"==e||"readonly"==e}function O(e,t,n){this.prev=e,this.vars=t,this.block=n}function I(e,t){this.name=e,this.next=t}var k=new I("this",new I("arguments",null));function D(){C.state.context=new O(C.state.context,C.state.localVars,!1),C.state.localVars=k}function N(){C.state.context=new O(C.state.context,C.state.localVars,!0),C.state.localVars=null}function j(){C.state.localVars=C.state.context.vars,C.state.context=C.state.context.prev}function P(e,t){var n=function(){var n=C.state,r=n.indented;if("stat"==n.lexical.type)r=n.lexical.indented;else for(var i=n.lexical;i&&")"==i.type&&i.align;i=i.prev)r=i.indented;n.lexical=new M(r,C.stream.column(),e,null,n.lexical,t)};return n.lex=!0,n}function z(){var e=C.state;e.lexical.prev&&(")"==e.lexical.type&&(e.indented=e.lexical.indented),e.lexical=e.lexical.prev)}function R(e){return function t(n){return n==e?E():";"==e||"}"==n||")"==n||"]"==n?x():E(t)}}function B(e,t){return"var"==e?E(P("vardef",t),Ae,R(";"),z):"keyword a"==e?E(P("form"),V,B,z):"keyword b"==e?E(P("form"),B,z):"keyword d"==e?C.stream.match(/^\s*$/,!1)?E():E(P("stat"),W,R(";"),z):"debugger"==e?E(R(";")):"{"==e?E(P("}"),N,se,z,j):";"==e?E():"if"==e?("else"==C.state.lexical.info&&C.state.cc[C.state.cc.length-1]==z&&C.state.cc.pop()(),E(P("form"),V,B,z,Te)):"function"==e?E(De):"for"==e?E(P("form"),N,Oe,B,j,z):"class"==e||u&&"interface"==t?(C.marked="keyword",E(P("form","class"==e?e:t),Re,z)):"variable"==e?u&&"declare"==t?(C.marked="keyword",E(B)):u&&("module"==t||"enum"==t||"type"==t)&&C.stream.match(/^\s*\w/,!1)?(C.marked="keyword","enum"==t?E(Je):"type"==t?E(je,R("operator"),he,R(";")):E(P("form"),Ce,R("{"),P("}"),se,z,z)):u&&"namespace"==t?(C.marked="keyword",E(P("form"),F,B,z)):u&&"abstract"==t?(C.marked="keyword",E(B)):E(P("stat"),ee):"switch"==e?E(P("form"),V,R("{"),P("}","switch"),N,se,z,z,j):"case"==e?E(F,R(":")):"default"==e?E(R(":")):"catch"==e?E(P("form"),D,H,B,z,j):"export"==e?E(P("stat"),Ye,z):"import"==e?E(P("stat"),Ue,z):"async"==e?E(B):"@"==t?E(F,B):x(P("stat"),F,R(";"),z)}function H(e){if("("==e)return E(Pe,R(")"))}function F(e,t){return U(e,t,!1)}function Y(e,t){return U(e,t,!0)}function V(e){return"("!=e?x():E(P(")"),W,R(")"),z)}function U(e,t,n){if(C.state.fatArrowAt==C.stream.start){var r=n?Q:J;if("("==e)return E(D,P(")"),oe(Pe,")"),z,R("=>"),r,j);if("variable"==e)return x(D,Ce,R("=>"),r,j)}var i=n?q:G;return b.hasOwnProperty(e)?E(i):"function"==e?E(De,i):"class"==e||u&&"interface"==t?(C.marked="keyword",E(P("form"),ze,z)):"keyword c"==e||"async"==e?E(n?Y:F):"("==e?E(P(")"),W,R(")"),z,i):"operator"==e||"spread"==e?E(n?Y:F):"["==e?E(P("]"),Xe,z,i):"{"==e?ae(ne,"}",null,i):"quasi"==e?x(K,i):"new"==e?E(function(e){return function(t){return"."==t?E(e?$:Z):"variable"==t&&u?E(be,e?q:G):x(e?Y:F)}}(n)):E()}function W(e){return e.match(/[;\}\)\],]/)?x():x(F)}function G(e,t){return","==e?E(W):q(e,t,!1)}function q(e,t,n){var r=0==n?G:q,i=0==n?F:Y;return"=>"==e?E(D,n?Q:J,j):"operator"==e?/\+\+|--/.test(t)||u&&"!"==t?E(r):u&&"<"==t&&C.stream.match(/^([^<>]|<[^<>]*>)*>\s*\(/,!1)?E(P(">"),oe(he,">"),z,r):"?"==t?E(F,R(":"),i):E(i):"quasi"==e?x(K,r):";"!=e?"("==e?ae(Y,")","call",r):"."==e?E(te,r):"["==e?E(P("]"),W,R("]"),z,r):u&&"as"==t?(C.marked="keyword",E(he,r)):"regexp"==e?(C.state.lastType=C.marked="operator",C.stream.backUp(C.stream.pos-C.stream.start-1),E(i)):void 0:void 0}function K(e,t){return"quasi"!=e?x():"${"!=t.slice(t.length-2)?E(K):E(F,X)}function X(e){if("}"==e)return C.marked="string-2",C.state.tokenize=y,E(K)}function J(e){return _(C.stream,C.state),x("{"==e?B:F)}function Q(e){return _(C.stream,C.state),x("{"==e?B:Y)}function Z(e,t){if("target"==t)return C.marked="keyword",E(G)}function $(e,t){if("target"==t)return C.marked="keyword",E(q)}function ee(e){return":"==e?E(z,B):x(G,R(";"),z)}function te(e){if("variable"==e)return C.marked="property",E()}function ne(e,t){return"async"==e?(C.marked="property",E(ne)):"variable"==e||"keyword"==C.style?(C.marked="property","get"==t||"set"==t?E(re):(u&&C.state.fatArrowAt==C.stream.start&&(n=C.stream.match(/^\s*:\s*/,!1))&&(C.state.fatArrowAt=C.stream.pos+n[0].length),E(ie))):"number"==e||"string"==e?(C.marked=s?"property":C.style+" property",E(ie)):"jsonld-keyword"==e?E(ie):u&&T(t)?(C.marked="keyword",E(ne)):"["==e?E(F,le,R("]"),ie):"spread"==e?E(Y,ie):"*"==t?(C.marked="keyword",E(ne)):":"==e?x(ie):void 0;var n}function re(e){return"variable"!=e?x(ie):(C.marked="property",E(De))}function ie(e){return":"==e?E(Y):"("==e?x(De):void 0}function oe(e,t,n){function r(i,o){if(n?n.indexOf(i)>-1:","==i){var a=C.state.lexical;return"call"==a.info&&(a.pos=(a.pos||0)+1),E((function(n,r){return n==t||r==t?x():x(e)}),r)}return i==t||o==t?E():n&&n.indexOf(";")>-1?x(e):E(R(t))}return function(n,i){return n==t||i==t?E():x(e,r)}}function ae(e,t,n){for(var r=3;r<arguments.length;r++)C.cc.push(arguments[r]);return E(P(t,n),oe(e,t),z)}function se(e){return"}"==e?E():x(B,se)}function le(e,t){if(u){if(":"==e)return E(he);if("?"==t)return E(le)}}function ce(e,t){if(u&&(":"==e||"in"==t))return E(he)}function ue(e){if(u&&":"==e)return C.stream.match(/^\s*\w+\s+is\b/,!1)?E(F,de,he):E(he)}function de(e,t){if("is"==t)return C.marked="keyword",E()}function he(e,t){return"keyof"==t||"typeof"==t||"infer"==t||"readonly"==t?(C.marked="keyword",E("typeof"==t?Y:he)):"variable"==e||"void"==t?(C.marked="type",E(_e)):"|"==t||"&"==t?E(he):"string"==e||"number"==e||"atom"==e?E(_e):"["==e?E(P("]"),oe(he,"]",","),z,_e):"{"==e?E(P("}"),fe,z,_e):"("==e?E(oe(ye,")"),pe,_e):"<"==e?E(oe(he,">"),he):"quasi"==e?x(ge,_e):void 0}function pe(e){if("=>"==e)return E(he)}function fe(e){return e.match(/[\}\)\]]/)?E():","==e||";"==e?E(fe):x(me,fe)}function me(e,t){return"variable"==e||"keyword"==C.style?(C.marked="property",E(me)):"?"==t||"number"==e||"string"==e?E(me):":"==e?E(he):"["==e?E(R("variable"),ce,R("]"),me):"("==e?x(Ne,me):e.match(/[;\}\)\],]/)?void 0:E()}function ge(e,t){return"quasi"!=e?x():"${"!=t.slice(t.length-2)?E(ge):E(he,ve)}function ve(e){if("}"==e)return C.marked="string-2",C.state.tokenize=y,E(ge)}function ye(e,t){return"variable"==e&&C.stream.match(/^\s*[?:]/,!1)||"?"==t?E(ye):":"==e?E(he):"spread"==e?E(ye):x(he)}function _e(e,t){return"<"==t?E(P(">"),oe(he,">"),z,_e):"|"==t||"."==e||"&"==t?E(he):"["==e?E(he,R("]"),_e):"extends"==t||"implements"==t?(C.marked="keyword",E(he)):"?"==t?E(he,R(":"),he):void 0}function be(e,t){if("<"==t)return E(P(">"),oe(he,">"),z,_e)}function Me(){return x(he,we)}function we(e,t){if("="==t)return E(he)}function Ae(e,t){return"enum"==t?(C.marked="keyword",E(Je)):x(Ce,le,Le,Se)}function Ce(e,t){return u&&T(t)?(C.marked="keyword",E(Ce)):"variable"==e?(S(t),E()):"spread"==e?E(Ce):"["==e?ae(Ee,"]"):"{"==e?ae(xe,"}"):void 0}function xe(e,t){return"variable"!=e||C.stream.match(/^\s*:/,!1)?("variable"==e&&(C.marked="property"),"spread"==e?E(Ce):"}"==e?x():"["==e?E(F,R("]"),R(":"),xe):E(R(":"),Ce,Le)):(S(t),E(Le))}function Ee(){return x(Ce,Le)}function Le(e,t){if("="==t)return E(Y)}function Se(e){if(","==e)return E(Ae)}function Te(e,t){if("keyword b"==e&&"else"==t)return E(P("form","else"),B,z)}function Oe(e,t){return"await"==t?E(Oe):"("==e?E(P(")"),Ie,z):void 0}function Ie(e){return"var"==e?E(Ae,ke):"variable"==e?E(ke):x(ke)}function ke(e,t){return")"==e?E():";"==e?E(ke):"in"==t||"of"==t?(C.marked="keyword",E(F,ke)):x(F,ke)}function De(e,t){return"*"==t?(C.marked="keyword",E(De)):"variable"==e?(S(t),E(De)):"("==e?E(D,P(")"),oe(Pe,")"),z,ue,B,j):u&&"<"==t?E(P(">"),oe(Me,">"),z,De):void 0}function Ne(e,t){return"*"==t?(C.marked="keyword",E(Ne)):"variable"==e?(S(t),E(Ne)):"("==e?E(D,P(")"),oe(Pe,")"),z,ue,j):u&&"<"==t?E(P(">"),oe(Me,">"),z,Ne):void 0}function je(e,t){return"keyword"==e||"variable"==e?(C.marked="type",E(je)):"<"==t?E(P(">"),oe(Me,">"),z):void 0}function Pe(e,t){return"@"==t&&E(F,Pe),"spread"==e?E(Pe):u&&T(t)?(C.marked="keyword",E(Pe)):u&&"this"==e?E(le,Le):x(Ce,le,Le)}function ze(e,t){return"variable"==e?Re(e,t):Be(e,t)}function Re(e,t){if("variable"==e)return S(t),E(Be)}function Be(e,t){return"<"==t?E(P(">"),oe(Me,">"),z,Be):"extends"==t||"implements"==t||u&&","==e?("implements"==t&&(C.marked="keyword"),E(u?he:F,Be)):"{"==e?E(P("}"),He,z):void 0}function He(e,t){return"async"==e||"variable"==e&&("static"==t||"get"==t||"set"==t||u&&T(t))&&C.stream.match(/^\s+[\w$\xa1-\uffff]/,!1)?(C.marked="keyword",E(He)):"variable"==e||"keyword"==C.style?(C.marked="property",E(Fe,He)):"number"==e||"string"==e?E(Fe,He):"["==e?E(F,le,R("]"),Fe,He):"*"==t?(C.marked="keyword",E(He)):u&&"("==e?x(Ne,He):";"==e||","==e?E(He):"}"==e?E():"@"==t?E(F,He):void 0}function Fe(e,t){if("!"==t)return E(Fe);if("?"==t)return E(Fe);if(":"==e)return E(he,Le);if("="==t)return E(Y);var n=C.state.lexical.prev;return x(n&&"interface"==n.info?Ne:De)}function Ye(e,t){return"*"==t?(C.marked="keyword",E(Ke,R(";"))):"default"==t?(C.marked="keyword",E(F,R(";"))):"{"==e?E(oe(Ve,"}"),Ke,R(";")):x(B)}function Ve(e,t){return"as"==t?(C.marked="keyword",E(R("variable"))):"variable"==e?x(Y,Ve):void 0}function Ue(e){return"string"==e?E():"("==e?x(F):"."==e?x(G):x(We,Ge,Ke)}function We(e,t){return"{"==e?ae(We,"}"):("variable"==e&&S(t),"*"==t&&(C.marked="keyword"),E(qe))}function Ge(e){if(","==e)return E(We,Ge)}function qe(e,t){if("as"==t)return C.marked="keyword",E(We)}function Ke(e,t){if("from"==t)return C.marked="keyword",E(F)}function Xe(e){return"]"==e?E():x(oe(Y,"]"))}function Je(){return x(P("form"),Ce,R("{"),P("}"),oe(Qe,"}"),z,z)}function Qe(){return x(Ce,Le)}function Ze(e,t,n){return t.tokenize==g&&/^(?:operator|sof|keyword [bcd]|case|new|export|default|spread|[\[{}\(,;:]|=>)$/.test(t.lastType)||"quasi"==t.lastType&&/\{\s*$/.test(e.string.slice(0,e.pos-(n||0)))}return j.lex=!0,z.lex=!0,{startState:function(e){var t={tokenize:g,lastType:"sof",cc:[],lexical:new M((e||0)-o,0,"block",!1),localVars:n.localVars,context:n.localVars&&new O(null,null,!1),indented:e||0};return n.globalVars&&"object"==typeof n.globalVars&&(t.globalVars=n.globalVars),t},token:function(e,t){if(e.sol()&&(t.lexical.hasOwnProperty("align")||(t.lexical.align=!1),t.indented=e.indentation(),_(e,t)),t.tokenize!=v&&e.eatSpace())return null;var n=t.tokenize(e,t);return"comment"==r?n:(t.lastType="operator"!=r||"++"!=i&&"--"!=i?r:"incdec",A(t,n,r,i,e))},indent:function(t,r){if(t.tokenize==v||t.tokenize==y)return e.Pass;if(t.tokenize!=g)return 0;var i,s=r&&r.charAt(0),l=t.lexical;if(!/^\s*else\b/.test(r))for(var c=t.cc.length-1;c>=0;--c){var u=t.cc[c];if(u==z)l=l.prev;else if(u!=Te&&u!=j)break}for(;("stat"==l.type||"form"==l.type)&&("}"==s||(i=t.cc[t.cc.length-1])&&(i==G||i==q)&&!/^[,\.=+\-*:?[\(]/.test(r));)l=l.prev;a&&")"==l.type&&"stat"==l.prev.type&&(l=l.prev);var d=l.type,h=s==d;return"vardef"==d?l.indented+("operator"==t.lastType||","==t.lastType?l.info.length+1:0):"form"==d&&"{"==s?l.indented:"form"==d?l.indented+o:"stat"==d?l.indented+(function(e,t){return"operator"==e.lastType||","==e.lastType||p.test(t.charAt(0))||/[,.]/.test(t.charAt(0))}(t,r)?a||o:0):"switch"!=l.info||h||0==n.doubleIndentSwitch?l.align?l.column+(h?0:1):l.indented+(h?0:o):l.indented+(/^(?:case|default)\b/.test(r)?o:2*o)},electricInput:/^\s*(?:case .*?:|default:|\{|\})$/,blockCommentStart:l?null:"/*",blockCommentEnd:l?null:"*/",blockCommentContinue:l?null:" * ",lineComment:l?null:"//",fold:"brace",closeBrackets:"()[]{}''\"\"``",helperType:l?"json":"javascript",jsonldMode:s,jsonMode:l,expressionAllowed:Ze,skipExpression:function(t){A(t,"atom","atom","true",new e.StringStream("",2,null))}}})),e.registerHelper("wordChars","javascript",/[\w$]/),e.defineMIME("text/javascript","javascript"),e.defineMIME("text/ecmascript","javascript"),e.defineMIME("application/javascript","javascript"),e.defineMIME("application/x-javascript","javascript"),e.defineMIME("application/ecmascript","javascript"),e.defineMIME("application/json",{name:"javascript",json:!0}),e.defineMIME("application/x-json",{name:"javascript",json:!0}),e.defineMIME("application/manifest+json",{name:"javascript",json:!0}),e.defineMIME("application/ld+json",{name:"javascript",jsonld:!0}),e.defineMIME("text/typescript",{name:"javascript",typescript:!0}),e.defineMIME("application/typescript",{name:"javascript",typescript:!0})}(n(14))},function(e,t,n){!function(e){"use strict";var t={autoSelfClosers:{area:!0,base:!0,br:!0,col:!0,command:!0,embed:!0,frame:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0,menuitem:!0},implicitlyClosed:{dd:!0,li:!0,optgroup:!0,option:!0,p:!0,rp:!0,rt:!0,tbody:!0,td:!0,tfoot:!0,th:!0,tr:!0},contextGrabbers:{dd:{dd:!0,dt:!0},dt:{dd:!0,dt:!0},li:{li:!0},option:{option:!0,optgroup:!0},optgroup:{optgroup:!0},p:{address:!0,article:!0,aside:!0,blockquote:!0,dir:!0,div:!0,dl:!0,fieldset:!0,footer:!0,form:!0,h1:!0,h2:!0,h3:!0,h4:!0,h5:!0,h6:!0,header:!0,hgroup:!0,hr:!0,menu:!0,nav:!0,ol:!0,p:!0,pre:!0,section:!0,table:!0,ul:!0},rp:{rp:!0,rt:!0},rt:{rp:!0,rt:!0},tbody:{tbody:!0,tfoot:!0},td:{td:!0,th:!0},tfoot:{tbody:!0},th:{td:!0,th:!0},thead:{tbody:!0,tfoot:!0},tr:{tr:!0}},doNotIndent:{pre:!0},allowUnquoted:!0,allowMissing:!0,caseFold:!0},n={autoSelfClosers:{},implicitlyClosed:{},contextGrabbers:{},doNotIndent:{},allowUnquoted:!1,allowMissing:!1,allowMissingTagName:!1,caseFold:!1};e.defineMode("xml",(function(r,i){var o,a,s=r.indentUnit,l={},c=i.htmlMode?t:n;for(var u in c)l[u]=c[u];for(var u in i)l[u]=i[u];function d(e,t){function n(n){return t.tokenize=n,n(e,t)}var r=e.next();return"<"==r?e.eat("!")?e.eat("[")?e.match("CDATA[")?n(p("atom","]]>")):null:e.match("--")?n(p("comment","--\x3e")):e.match("DOCTYPE",!0,!0)?(e.eatWhile(/[\w\._\-]/),n(function e(t){return function(n,r){for(var i;null!=(i=n.next());){if("<"==i)return r.tokenize=e(t+1),r.tokenize(n,r);if(">"==i){if(1==t){r.tokenize=d;break}return r.tokenize=e(t-1),r.tokenize(n,r)}}return"meta"}}(1))):null:e.eat("?")?(e.eatWhile(/[\w\._\-]/),t.tokenize=p("meta","?>"),"meta"):(o=e.eat("/")?"closeTag":"openTag",t.tokenize=h,"tag bracket"):"&"==r?(e.eat("#")?e.eat("x")?e.eatWhile(/[a-fA-F\d]/)&&e.eat(";"):e.eatWhile(/[\d]/)&&e.eat(";"):e.eatWhile(/[\w\.\-:]/)&&e.eat(";"))?"atom":"error":(e.eatWhile(/[^&<]/),null)}function h(e,t){var n,r,i=e.next();if(">"==i||"/"==i&&e.eat(">"))return t.tokenize=d,o=">"==i?"endTag":"selfcloseTag","tag bracket";if("="==i)return o="equals",null;if("<"==i){t.tokenize=d,t.state=v,t.tagName=t.tagStart=null;var a=t.tokenize(e,t);return a?a+" tag error":"tag error"}return/[\'\"]/.test(i)?(t.tokenize=(n=i,(r=function(e,t){for(;!e.eol();)if(e.next()==n){t.tokenize=h;break}return"string"}).isInAttribute=!0,r),t.stringStartCol=e.column(),t.tokenize(e,t)):(e.match(/^[^\s\u00a0=<>\"\']*[^\s\u00a0=<>\"\'\/]/),"word")}function p(e,t){return function(n,r){for(;!n.eol();){if(n.match(t)){r.tokenize=d;break}n.next()}return e}}function f(e,t,n){this.prev=e.context,this.tagName=t||"",this.indent=e.indented,this.startOfLine=n,(l.doNotIndent.hasOwnProperty(t)||e.context&&e.context.noIndent)&&(this.noIndent=!0)}function m(e){e.context&&(e.context=e.context.prev)}function g(e,t){for(var n;;){if(!e.context)return;if(n=e.context.tagName,!l.contextGrabbers.hasOwnProperty(n)||!l.contextGrabbers[n].hasOwnProperty(t))return;m(e)}}function v(e,t,n){return"openTag"==e?(n.tagStart=t.column(),y):"closeTag"==e?_:v}function y(e,t,n){return"word"==e?(n.tagName=t.current(),a="tag",w):l.allowMissingTagName&&"endTag"==e?(a="tag bracket",w(e,0,n)):(a="error",y)}function _(e,t,n){if("word"==e){var r=t.current();return n.context&&n.context.tagName!=r&&l.implicitlyClosed.hasOwnProperty(n.context.tagName)&&m(n),n.context&&n.context.tagName==r||!1===l.matchClosing?(a="tag",b):(a="tag error",M)}return l.allowMissingTagName&&"endTag"==e?(a="tag bracket",b(e,0,n)):(a="error",M)}function b(e,t,n){return"endTag"!=e?(a="error",b):(m(n),v)}function M(e,t,n){return a="error",b(e,0,n)}function w(e,t,n){if("word"==e)return a="attribute",A;if("endTag"==e||"selfcloseTag"==e){var r=n.tagName,i=n.tagStart;return n.tagName=n.tagStart=null,"selfcloseTag"==e||l.autoSelfClosers.hasOwnProperty(r)?g(n,r):(g(n,r),n.context=new f(n,r,i==n.indented)),v}return a="error",w}function A(e,t,n){return"equals"==e?C:(l.allowMissing||(a="error"),w(e,0,n))}function C(e,t,n){return"string"==e?x:"word"==e&&l.allowUnquoted?(a="string",w):(a="error",w(e,0,n))}function x(e,t,n){return"string"==e?x:w(e,0,n)}return d.isInText=!0,{startState:function(e){var t={tokenize:d,state:v,indented:e||0,tagName:null,tagStart:null,context:null};return null!=e&&(t.baseIndent=e),t},token:function(e,t){if(!t.tagName&&e.sol()&&(t.indented=e.indentation()),e.eatSpace())return null;o=null;var n=t.tokenize(e,t);return(n||o)&&"comment"!=n&&(a=null,t.state=t.state(o||n,e,t),a&&(n="error"==a?n+" error":a)),n},indent:function(t,n,r){var i=t.context;if(t.tokenize.isInAttribute)return t.tagStart==t.indented?t.stringStartCol+1:t.indented+s;if(i&&i.noIndent)return e.Pass;if(t.tokenize!=h&&t.tokenize!=d)return r?r.match(/^(\s*)/)[0].length:0;if(t.tagName)return!1!==l.multilineTagIndentPastTag?t.tagStart+t.tagName.length+2:t.tagStart+s*(l.multilineTagIndentFactor||1);if(l.alignCDATA&&/<!\[CDATA\[/.test(n))return 0;var o=n&&/^<(\/)?([\w_:\.-]*)/.exec(n);if(o&&o[1])for(;i;){if(i.tagName==o[2]){i=i.prev;break}if(!l.implicitlyClosed.hasOwnProperty(i.tagName))break;i=i.prev}else if(o)for(;i;){var a=l.contextGrabbers[i.tagName];if(!a||!a.hasOwnProperty(o[2]))break;i=i.prev}for(;i&&i.prev&&!i.startOfLine;)i=i.prev;return i?i.indent+s:t.baseIndent||0},electricInput:/<\/[\s\w:]+>$/,blockCommentStart:"\x3c!--",blockCommentEnd:"--\x3e",configuration:l.htmlMode?"html":"xml",helperType:l.htmlMode?"html":"xml",skipAttribute:function(e){e.state==C&&(e.state=w)},xmlCurrentTag:function(e){return e.tagName?{name:e.tagName,close:"closeTag"==e.type}:null},xmlCurrentContext:function(e){for(var t=[],n=e.context;n;n=n.prev)t.push(n.tagName);return t.reverse()}}})),e.defineMIME("text/xml","xml"),e.defineMIME("application/xml","xml"),e.mimeModes.hasOwnProperty("text/html")||e.defineMIME("text/html",{name:"xml",htmlMode:!0})}(n(14))},function(e,t,n){!function(e){"use strict";e.defineMode("markdown",(function(t,n){var r=e.getMode(t,"text/html"),i="null"==r.name;void 0===n.highlightFormatting&&(n.highlightFormatting=!1),void 0===n.maxBlockquoteDepth&&(n.maxBlockquoteDepth=0),void 0===n.taskLists&&(n.taskLists=!1),void 0===n.strikethrough&&(n.strikethrough=!1),void 0===n.emoji&&(n.emoji=!1),void 0===n.fencedCodeBlockHighlighting&&(n.fencedCodeBlockHighlighting=!0),void 0===n.fencedCodeBlockDefaultMode&&(n.fencedCodeBlockDefaultMode="text/plain"),void 0===n.xml&&(n.xml=!0),void 0===n.tokenTypeOverrides&&(n.tokenTypeOverrides={});var o={header:"header",code:"comment",quote:"quote",list1:"variable-2",list2:"variable-3",list3:"keyword",hr:"hr",image:"image",imageAltText:"image-alt-text",imageMarker:"image-marker",formatting:"formatting",linkInline:"link",linkEmail:"link",linkText:"link",linkHref:"string",em:"em",strong:"strong",strikethrough:"strikethrough",emoji:"builtin"};for(var a in o)o.hasOwnProperty(a)&&n.tokenTypeOverrides[a]&&(o[a]=n.tokenTypeOverrides[a]);var s=/^([*\-_])(?:\s*\1){2,}\s*$/,l=/^(?:[*\-+]|^[0-9]+([.)]))\s+/,c=/^\[(x| )\](?=\s)/i,u=n.allowAtxHeaderWithoutSpace?/^(#+)/:/^(#+)(?: |$)/,d=/^ {0,3}(?:\={1,}|-{2,})\s*$/,h=/^[^#!\[\]*_\\<>` "'(~:]+/,p=/^(~~~+|```+)[ \t]*([\w\/+#-]*)[^\n`]*$/,f=/^\s*\[[^\]]+?\]:.*$/,m=/[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061E\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u0AF0\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166D\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E42\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]|\uD800[\uDD00-\uDD02\uDF9F\uDFD0]|\uD801\uDD6F|\uD802[\uDC57\uDD1F\uDD3F\uDE50-\uDE58\uDE7F\uDEF0-\uDEF6\uDF39-\uDF3F\uDF99-\uDF9C]|\uD804[\uDC47-\uDC4D\uDCBB\uDCBC\uDCBE-\uDCC1\uDD40-\uDD43\uDD74\uDD75\uDDC5-\uDDC9\uDDCD\uDDDB\uDDDD-\uDDDF\uDE38-\uDE3D\uDEA9]|\uD805[\uDCC6\uDDC1-\uDDD7\uDE41-\uDE43\uDF3C-\uDF3E]|\uD809[\uDC70-\uDC74]|\uD81A[\uDE6E\uDE6F\uDEF5\uDF37-\uDF3B\uDF44]|\uD82F\uDC9F|\uD836[\uDE87-\uDE8B]/;function g(e,t,n){return t.f=t.inline=n,n(e,t)}function v(e,t,n){return t.f=t.block=n,n(e,t)}function y(t){if(t.linkTitle=!1,t.linkHref=!1,t.linkText=!1,t.em=!1,t.strong=!1,t.strikethrough=!1,t.quote=0,t.indentedCode=!1,t.f==b){var n=i;if(!n){var o=e.innerMode(r,t.htmlState);n="xml"==o.mode.name&&null===o.state.tagStart&&!o.state.context&&o.state.tokenize.isInText}n&&(t.f=C,t.block=_,t.htmlState=null)}return t.trailingSpace=0,t.trailingSpaceNewLine=!1,t.prevLine=t.thisLine,t.thisLine={stream:null},null}function _(r,i){var a,h=r.column()===i.indentation,m=!(a=i.prevLine.stream)||!/\S/.test(a.string),v=i.indentedCode,y=i.prevLine.hr,_=!1!==i.list,b=(i.listStack[i.listStack.length-1]||0)+3;i.indentedCode=!1;var A=i.indentation;if(null===i.indentationDiff&&(i.indentationDiff=i.indentation,_)){for(i.list=null;A<i.listStack[i.listStack.length-1];)i.listStack.pop(),i.listStack.length?i.indentation=i.listStack[i.listStack.length-1]:i.list=!1;!1!==i.list&&(i.indentationDiff=A-i.listStack[i.listStack.length-1])}var C=!(m||y||i.prevLine.header||_&&v||i.prevLine.fencedCodeEnd),x=(!1===i.list||y||m)&&i.indentation<=b&&r.match(s),E=null;if(i.indentationDiff>=4&&(v||i.prevLine.fencedCodeEnd||i.prevLine.header||m))return r.skipToEnd(),i.indentedCode=!0,o.code;if(r.eatSpace())return null;if(h&&i.indentation<=b&&(E=r.match(u))&&E[1].length<=6)return i.quote=0,i.header=E[1].length,i.thisLine.header=!0,n.highlightFormatting&&(i.formatting="header"),i.f=i.inline,w(i);if(i.indentation<=b&&r.eat(">"))return i.quote=h?1:i.quote+1,n.highlightFormatting&&(i.formatting="quote"),r.eatSpace(),w(i);if(!x&&!i.setext&&h&&i.indentation<=b&&(E=r.match(l))){var L=E[1]?"ol":"ul";return i.indentation=A+r.current().length,i.list=!0,i.quote=0,i.listStack.push(i.indentation),i.em=!1,i.strong=!1,i.code=!1,i.strikethrough=!1,n.taskLists&&r.match(c,!1)&&(i.taskList=!0),i.f=i.inline,n.highlightFormatting&&(i.formatting=["list","list-"+L]),w(i)}return h&&i.indentation<=b&&(E=r.match(p,!0))?(i.quote=0,i.fencedEndRE=new RegExp(E[1]+"+ *$"),i.localMode=n.fencedCodeBlockHighlighting&&function(n){if(e.findModeByName){var r=e.findModeByName(n);r&&(n=r.mime||r.mimes[0])}var i=e.getMode(t,n);return"null"==i.name?null:i}(E[2]||n.fencedCodeBlockDefaultMode),i.localMode&&(i.localState=e.startState(i.localMode)),i.f=i.block=M,n.highlightFormatting&&(i.formatting="code-block"),i.code=-1,w(i)):i.setext||!(C&&_||i.quote||!1!==i.list||i.code||x||f.test(r.string))&&(E=r.lookAhead(1))&&(E=E.match(d))?(i.setext?(i.header=i.setext,i.setext=0,r.skipToEnd(),n.highlightFormatting&&(i.formatting="header")):(i.header="="==E[0].charAt(0)?1:2,i.setext=i.header),i.thisLine.header=!0,i.f=i.inline,w(i)):x?(r.skipToEnd(),i.hr=!0,i.thisLine.hr=!0,o.hr):"["===r.peek()?g(r,i,S):g(r,i,i.inline)}function b(t,n){var o=r.token(t,n.htmlState);if(!i){var a=e.innerMode(r,n.htmlState);("xml"==a.mode.name&&null===a.state.tagStart&&!a.state.context&&a.state.tokenize.isInText||n.md_inside&&t.current().indexOf(">")>-1)&&(n.f=C,n.block=_,n.htmlState=null)}return o}function M(e,t){var r,i=t.listStack[t.listStack.length-1]||0,a=t.indentation<i,s=i+3;return t.fencedEndRE&&t.indentation<=s&&(a||e.match(t.fencedEndRE))?(n.highlightFormatting&&(t.formatting="code-block"),a||(r=w(t)),t.localMode=t.localState=null,t.block=_,t.f=C,t.fencedEndRE=null,t.code=0,t.thisLine.fencedCodeEnd=!0,a?v(e,t,t.block):r):t.localMode?t.localMode.token(e,t.localState):(e.skipToEnd(),o.code)}function w(e){var t=[];if(e.formatting){t.push(o.formatting),"string"==typeof e.formatting&&(e.formatting=[e.formatting]);for(var r=0;r<e.formatting.length;r++)t.push(o.formatting+"-"+e.formatting[r]),"header"===e.formatting[r]&&t.push(o.formatting+"-"+e.formatting[r]+"-"+e.header),"quote"===e.formatting[r]&&(!n.maxBlockquoteDepth||n.maxBlockquoteDepth>=e.quote?t.push(o.formatting+"-"+e.formatting[r]+"-"+e.quote):t.push("error"))}if(e.taskOpen)return t.push("meta"),t.length?t.join(" "):null;if(e.taskClosed)return t.push("property"),t.length?t.join(" "):null;if(e.linkHref?t.push(o.linkHref,"url"):(e.strong&&t.push(o.strong),e.em&&t.push(o.em),e.strikethrough&&t.push(o.strikethrough),e.emoji&&t.push(o.emoji),e.linkText&&t.push(o.linkText),e.code&&t.push(o.code),e.image&&t.push(o.image),e.imageAltText&&t.push(o.imageAltText,"link"),e.imageMarker&&t.push(o.imageMarker)),e.header&&t.push(o.header,o.header+"-"+e.header),e.quote&&(t.push(o.quote),!n.maxBlockquoteDepth||n.maxBlockquoteDepth>=e.quote?t.push(o.quote+"-"+e.quote):t.push(o.quote+"-"+n.maxBlockquoteDepth)),!1!==e.list){var i=(e.listStack.length-1)%3;i?1===i?t.push(o.list2):t.push(o.list3):t.push(o.list1)}return e.trailingSpaceNewLine?t.push("trailing-space-new-line"):e.trailingSpace&&t.push("trailing-space-"+(e.trailingSpace%2?"a":"b")),t.length?t.join(" "):null}function A(e,t){if(e.match(h,!0))return w(t)}function C(t,i){var a=i.text(t,i);if(void 0!==a)return a;if(i.list)return i.list=null,w(i);if(i.taskList)return" "===t.match(c,!0)[1]?i.taskOpen=!0:i.taskClosed=!0,n.highlightFormatting&&(i.formatting="task"),i.taskList=!1,w(i);if(i.taskOpen=!1,i.taskClosed=!1,i.header&&t.match(/^#+$/,!0))return n.highlightFormatting&&(i.formatting="header"),w(i);var s=t.next();if(i.linkTitle){i.linkTitle=!1;var l=s;"("===s&&(l=")");var u="^\\s*(?:[^"+(l=(l+"").replace(/([.?*+^\[\]\\(){}|-])/g,"\\$1"))+"\\\\]+|\\\\\\\\|\\\\.)"+l;if(t.match(new RegExp(u),!0))return o.linkHref}if("`"===s){var d=i.formatting;n.highlightFormatting&&(i.formatting="code"),t.eatWhile("`");var h=t.current().length;if(0!=i.code||i.quote&&1!=h){if(h==i.code){var p=w(i);return i.code=0,p}return i.formatting=d,w(i)}return i.code=h,w(i)}if(i.code)return w(i);if("\\"===s&&(t.next(),n.highlightFormatting)){var f=w(i),g=o.formatting+"-escape";return f?f+" "+g:g}if("!"===s&&t.match(/\[[^\]]*\] ?(?:\(|\[)/,!1))return i.imageMarker=!0,i.image=!0,n.highlightFormatting&&(i.formatting="image"),w(i);if("["===s&&i.imageMarker&&t.match(/[^\]]*\](\(.*?\)| ?\[.*?\])/,!1))return i.imageMarker=!1,i.imageAltText=!0,n.highlightFormatting&&(i.formatting="image"),w(i);if("]"===s&&i.imageAltText){n.highlightFormatting&&(i.formatting="image");var f=w(i);return i.imageAltText=!1,i.image=!1,i.inline=i.f=E,f}if("["===s&&!i.image)return i.linkText&&t.match(/^.*?\]/)||(i.linkText=!0,n.highlightFormatting&&(i.formatting="link")),w(i);if("]"===s&&i.linkText){n.highlightFormatting&&(i.formatting="link");var f=w(i);return i.linkText=!1,i.inline=i.f=t.match(/\(.*?\)| ?\[.*?\]/,!1)?E:C,f}if("<"===s&&t.match(/^(https?|ftps?):\/\/(?:[^\\>]|\\.)+>/,!1))return i.f=i.inline=x,n.highlightFormatting&&(i.formatting="link"),(f=w(i))?f+=" ":f="",f+o.linkInline;if("<"===s&&t.match(/^[^> \\]+@(?:[^\\>]|\\.)+>/,!1))return i.f=i.inline=x,n.highlightFormatting&&(i.formatting="link"),(f=w(i))?f+=" ":f="",f+o.linkEmail;if(n.xml&&"<"===s&&t.match(/^(!--|\?|!\[CDATA\[|[a-z][a-z0-9-]*(?:\s+[a-z_:.\-]+(?:\s*=\s*[^>]+)?)*\s*(?:>|$))/i,!1)){var y=t.string.indexOf(">",t.pos);if(-1!=y){var _=t.string.substring(t.start,y);/markdown\s*=\s*('|"){0,1}1('|"){0,1}/.test(_)&&(i.md_inside=!0)}return t.backUp(1),i.htmlState=e.startState(r),v(t,i,b)}if(n.xml&&"<"===s&&t.match(/^\/\w*?>/))return i.md_inside=!1,"tag";if("*"===s||"_"===s){for(var M=1,A=1==t.pos?" ":t.string.charAt(t.pos-2);M<3&&t.eat(s);)M++;var L=t.peek()||" ",S=!/\s/.test(L)&&(!m.test(L)||/\s/.test(A)||m.test(A)),T=!/\s/.test(A)&&(!m.test(A)||/\s/.test(L)||m.test(L)),O=null,I=null;if(M%2&&(i.em||!S||"*"!==s&&T&&!m.test(A)?i.em!=s||!T||"*"!==s&&S&&!m.test(L)||(O=!1):O=!0),M>1&&(i.strong||!S||"*"!==s&&T&&!m.test(A)?i.strong!=s||!T||"*"!==s&&S&&!m.test(L)||(I=!1):I=!0),null!=I||null!=O)return n.highlightFormatting&&(i.formatting=null==O?"strong":null==I?"em":"strong em"),!0===O&&(i.em=s),!0===I&&(i.strong=s),p=w(i),!1===O&&(i.em=!1),!1===I&&(i.strong=!1),p}else if(" "===s&&(t.eat("*")||t.eat("_"))){if(" "===t.peek())return w(i);t.backUp(1)}if(n.strikethrough)if("~"===s&&t.eatWhile(s)){if(i.strikethrough)return n.highlightFormatting&&(i.formatting="strikethrough"),p=w(i),i.strikethrough=!1,p;if(t.match(/^[^\s]/,!1))return i.strikethrough=!0,n.highlightFormatting&&(i.formatting="strikethrough"),w(i)}else if(" "===s&&t.match("~~",!0)){if(" "===t.peek())return w(i);t.backUp(2)}if(n.emoji&&":"===s&&t.match(/^(?:[a-z_\d+][a-z_\d+-]*|\-[a-z_\d+][a-z_\d+-]*):/)){i.emoji=!0,n.highlightFormatting&&(i.formatting="emoji");var k=w(i);return i.emoji=!1,k}return" "===s&&(t.match(/^ +$/,!1)?i.trailingSpace++:i.trailingSpace&&(i.trailingSpaceNewLine=!0)),w(i)}function x(e,t){if(">"===e.next()){t.f=t.inline=C,n.highlightFormatting&&(t.formatting="link");var r=w(t);return r?r+=" ":r="",r+o.linkInline}return e.match(/^[^>]+/,!0),o.linkInline}function E(e,t){if(e.eatSpace())return null;var r,i=e.next();return"("===i||"["===i?(t.f=t.inline=(r="("===i?")":"]",function(e,t){if(e.next()===r){t.f=t.inline=C,n.highlightFormatting&&(t.formatting="link-string");var i=w(t);return t.linkHref=!1,i}return e.match(L[r]),t.linkHref=!0,w(t)}),n.highlightFormatting&&(t.formatting="link-string"),t.linkHref=!0,w(t)):"error"}var L={")":/^(?:[^\\\(\)]|\\.|\((?:[^\\\(\)]|\\.)*\))*?(?=\))/,"]":/^(?:[^\\\[\]]|\\.|\[(?:[^\\\[\]]|\\.)*\])*?(?=\])/};function S(e,t){return e.match(/^([^\]\\]|\\.)*\]:/,!1)?(t.f=T,e.next(),n.highlightFormatting&&(t.formatting="link"),t.linkText=!0,w(t)):g(e,t,C)}function T(e,t){if(e.match("]:",!0)){t.f=t.inline=O,n.highlightFormatting&&(t.formatting="link");var r=w(t);return t.linkText=!1,r}return e.match(/^([^\]\\]|\\.)+/,!0),o.linkText}function O(e,t){return e.eatSpace()?null:(e.match(/^[^\s]+/,!0),void 0===e.peek()?t.linkTitle=!0:e.match(/^(?:\s+(?:"(?:[^"\\]|\\.)+"|'(?:[^'\\]|\\.)+'|\((?:[^)\\]|\\.)+\)))?/,!0),t.f=t.inline=C,o.linkHref+" url")}var I={startState:function(){return{f:_,prevLine:{stream:null},thisLine:{stream:null},block:_,htmlState:null,indentation:0,inline:C,text:A,formatting:!1,linkText:!1,linkHref:!1,linkTitle:!1,code:0,em:!1,strong:!1,header:0,setext:0,hr:!1,taskList:!1,list:!1,listStack:[],quote:0,trailingSpace:0,trailingSpaceNewLine:!1,strikethrough:!1,emoji:!1,fencedEndRE:null}},copyState:function(t){return{f:t.f,prevLine:t.prevLine,thisLine:t.thisLine,block:t.block,htmlState:t.htmlState&&e.copyState(r,t.htmlState),indentation:t.indentation,localMode:t.localMode,localState:t.localMode?e.copyState(t.localMode,t.localState):null,inline:t.inline,text:t.text,formatting:!1,linkText:t.linkText,linkTitle:t.linkTitle,linkHref:t.linkHref,code:t.code,em:t.em,strong:t.strong,strikethrough:t.strikethrough,emoji:t.emoji,header:t.header,setext:t.setext,hr:t.hr,taskList:t.taskList,list:t.list,listStack:t.listStack.slice(0),quote:t.quote,indentedCode:t.indentedCode,trailingSpace:t.trailingSpace,trailingSpaceNewLine:t.trailingSpaceNewLine,md_inside:t.md_inside,fencedEndRE:t.fencedEndRE}},token:function(e,t){if(t.formatting=!1,e!=t.thisLine.stream){if(t.header=0,t.hr=!1,e.match(/^\s*$/,!0))return y(t),null;if(t.prevLine=t.thisLine,t.thisLine={stream:e},t.taskList=!1,t.trailingSpace=0,t.trailingSpaceNewLine=!1,!t.localState&&(t.f=t.block,t.f!=b)){var n=e.match(/^\s*/,!0)[0].replace(/\t/g,"    ").length;if(t.indentation=n,t.indentationDiff=null,n>0)return null}}return t.f(e,t)},innerMode:function(e){return e.block==b?{state:e.htmlState,mode:r}:e.localState?{state:e.localState,mode:e.localMode}:{state:e,mode:I}},indent:function(t,n,i){return t.block==b&&r.indent?r.indent(t.htmlState,n,i):t.localState&&t.localMode.indent?t.localMode.indent(t.localState,n,i):e.Pass},blankLine:y,getType:w,blockCommentStart:"\x3c!--",blockCommentEnd:"--\x3e",closeBrackets:"()[]{}''\"\"``",fold:"markdown"};return I}),"xml"),e.defineMIME("text/markdown","markdown"),e.defineMIME("text/x-markdown","markdown")}(n(14),n(205),n(169))},,,,function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.URLExt=void 0;const i=n(150),o=r(n(614));!function(e){function t(e){if("undefined"!=typeof document&&document){const t=document.createElement("a");return t.href=e,t}return o.default(e)}function n(...e){const t=o.default(e[0],{}),n=`${t.protocol}${t.slashes?"//":""}${t.auth}${t.auth?"@":""}${t.host}`,r=i.posix.join(`${n&&"/"!==t.pathname[0]?"/":""}${t.pathname}`,...e.slice(1));return`${n}${"."===r?"":r}`}e.parse=t,e.getHostName=function(e){return o.default(e).hostname},e.normalize=function(e){return e&&t(e).toString()},e.join=n,e.encodeParts=function(e){return n(...e.split("/").map(encodeURIComponent))},e.objectToQueryString=function(e){const t=Object.keys(e).filter(e=>e.length>0);return t.length?"?"+t.map(t=>{const n=encodeURIComponent(String(e[t]));return t+(n?"="+n:"")}).join("&"):""},e.queryStringToObject=function(e){return e.replace(/^\?/,"").split("&").reduce((e,t)=>{const[n,r]=t.split("=");return n.length>0&&(e[n]=decodeURIComponent(r||"")),e},{})},e.isLocal=function(e){const{protocol:n}=t(e);return(!n||0!==e.toLowerCase().indexOf(n))&&0!==e.indexOf("/")}}(t.URLExt||(t.URLExt={}))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("af",{months:"Januarie_Februarie_Maart_April_Mei_Junie_Julie_Augustus_September_Oktober_November_Desember".split("_"),monthsShort:"Jan_Feb_Mrt_Apr_Mei_Jun_Jul_Aug_Sep_Okt_Nov_Des".split("_"),weekdays:"Sondag_Maandag_Dinsdag_Woensdag_Donderdag_Vrydag_Saterdag".split("_"),weekdaysShort:"Son_Maa_Din_Woe_Don_Vry_Sat".split("_"),weekdaysMin:"So_Ma_Di_Wo_Do_Vr_Sa".split("_"),meridiemParse:/vm|nm/i,isPM:function(e){return/^nm$/i.test(e)},meridiem:function(e,t,n){return e<12?n?"vm":"VM":n?"nm":"NM"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Vandag om] LT",nextDay:"[Môre om] LT",nextWeek:"dddd [om] LT",lastDay:"[Gister om] LT",lastWeek:"[Laas] dddd [om] LT",sameElse:"L"},relativeTime:{future:"oor %s",past:"%s gelede",s:"'n paar sekondes",ss:"%d sekondes",m:"'n minuut",mm:"%d minute",h:"'n uur",hh:"%d ure",d:"'n dag",dd:"%d dae",M:"'n maand",MM:"%d maande",y:"'n jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||e>=20?"ste":"de")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"},n={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},r=function(e){return 0===e?0:1===e?1:2===e?2:e%100>=3&&e%100<=10?3:e%100>=11?4:5},i={s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]},o=function(e){return function(t,n,o,a){var s=r(t),l=i[e][r(t)];return 2===s&&(l=l[n?0:1]),l.replace(/%d/i,t)}},a=["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"];e.defineLocale("ar",{months:a,monthsShort:a,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/ص|م/,isPM:function(e){return"م"===e},meridiem:function(e,t,n){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:o("s"),ss:o("s"),m:o("m"),mm:o("m"),h:o("h"),hh:o("h"),d:o("d"),dd:o("d"),M:o("M"),MM:o("M"),y:o("y"),yy:o("y")},preparse:function(e){return e.replace(/[١٢٣٤٥٦٧٨٩٠]/g,(function(e){return n[e]})).replace(/،/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t=function(e){return 0===e?0:1===e?1:2===e?2:e%100>=3&&e%100<=10?3:e%100>=11?4:5},n={s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]},r=function(e){return function(r,i,o,a){var s=t(r),l=n[e][t(r)];return 2===s&&(l=l[i?0:1]),l.replace(/%d/i,r)}},i=["جانفي","فيفري","مارس","أفريل","ماي","جوان","جويلية","أوت","سبتمبر","أكتوبر","نوفمبر","ديسمبر"];e.defineLocale("ar-dz",{months:i,monthsShort:i,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/ص|م/,isPM:function(e){return"م"===e},meridiem:function(e,t,n){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:r("s"),ss:r("s"),m:r("m"),mm:r("m"),h:r("h"),hh:r("h"),d:r("d"),dd:r("d"),M:r("M"),MM:r("M"),y:r("y"),yy:r("y")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:0,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ar-kw",{months:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),weekdays:"الأحد_الإتنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"احد_اتنين_ثلاثاء_اربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:0,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"1",2:"2",3:"3",4:"4",5:"5",6:"6",7:"7",8:"8",9:"9",0:"0"},n=function(e){return 0===e?0:1===e?1:2===e?2:e%100>=3&&e%100<=10?3:e%100>=11?4:5},r={s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]},i=function(e){return function(t,i,o,a){var s=n(t),l=r[e][n(t)];return 2===s&&(l=l[i?0:1]),l.replace(/%d/i,t)}},o=["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"];e.defineLocale("ar-ly",{months:o,monthsShort:o,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/ص|م/,isPM:function(e){return"م"===e},meridiem:function(e,t,n){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:i("s"),ss:i("s"),m:i("m"),mm:i("m"),h:i("h"),hh:i("h"),d:i("d"),dd:i("d"),M:i("M"),MM:i("M"),y:i("y"),yy:i("y")},preparse:function(e){return e.replace(/،/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ar-ma",{months:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"احد_اثنين_ثلاثاء_اربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"},n={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"};e.defineLocale("ar-sa",{months:"يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/ص|م/,isPM:function(e){return"م"===e},meridiem:function(e,t,n){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},preparse:function(e){return e.replace(/[١٢٣٤٥٦٧٨٩٠]/g,(function(e){return n[e]})).replace(/،/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]})).replace(/,/g,"،")},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ar-tn",{months:"جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),monthsShort:"جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"-inci",5:"-inci",8:"-inci",70:"-inci",80:"-inci",2:"-nci",7:"-nci",20:"-nci",50:"-nci",3:"-üncü",4:"-üncü",100:"-üncü",6:"-ncı",9:"-uncu",10:"-uncu",30:"-uncu",60:"-ıncı",90:"-ıncı"};e.defineLocale("az",{months:"yanvar_fevral_mart_aprel_may_iyun_iyul_avqust_sentyabr_oktyabr_noyabr_dekabr".split("_"),monthsShort:"yan_fev_mar_apr_may_iyn_iyl_avq_sen_okt_noy_dek".split("_"),weekdays:"Bazar_Bazar ertəsi_Çərşənbə axşamı_Çərşənbə_Cümə axşamı_Cümə_Şənbə".split("_"),weekdaysShort:"Baz_BzE_ÇAx_Çər_CAx_Cüm_Şən".split("_"),weekdaysMin:"Bz_BE_ÇA_Çə_CA_Cü_Şə".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün saat] LT",nextDay:"[sabah saat] LT",nextWeek:"[gələn həftə] dddd [saat] LT",lastDay:"[dünən] LT",lastWeek:"[keçən həftə] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s sonra",past:"%s əvvəl",s:"bir neçə saniyə",ss:"%d saniyə",m:"bir dəqiqə",mm:"%d dəqiqə",h:"bir saat",hh:"%d saat",d:"bir gün",dd:"%d gün",M:"bir ay",MM:"%d ay",y:"bir il",yy:"%d il"},meridiemParse:/gecə|səhər|gündüz|axşam/,isPM:function(e){return/^(gündüz|axşam)$/.test(e)},meridiem:function(e,t,n){return e<4?"gecə":e<12?"səhər":e<17?"gündüz":"axşam"},dayOfMonthOrdinalParse:/\d{1,2}-(ıncı|inci|nci|üncü|ncı|uncu)/,ordinal:function(e){if(0===e)return e+"-ıncı";var n=e%10;return e+(t[n]||t[e%100-n]||t[e>=100?100:null])},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r,i;return"m"===n?t?"хвіліна":"хвіліну":"h"===n?t?"гадзіна":"гадзіну":e+" "+(r=+e,i={ss:t?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:t?"хвіліна_хвіліны_хвілін":"хвіліну_хвіліны_хвілін",hh:t?"гадзіна_гадзіны_гадзін":"гадзіну_гадзіны_гадзін",dd:"дзень_дні_дзён",MM:"месяц_месяцы_месяцаў",yy:"год_гады_гадоў"}[n].split("_"),r%10==1&&r%100!=11?i[0]:r%10>=2&&r%10<=4&&(r%100<10||r%100>=20)?i[1]:i[2])}e.defineLocale("be",{months:{format:"студзеня_лютага_сакавіка_красавіка_траўня_чэрвеня_ліпеня_жніўня_верасня_кастрычніка_лістапада_снежня".split("_"),standalone:"студзень_люты_сакавік_красавік_травень_чэрвень_ліпень_жнівень_верасень_кастрычнік_лістапад_снежань".split("_")},monthsShort:"студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж".split("_"),weekdays:{format:"нядзелю_панядзелак_аўторак_сераду_чацвер_пятніцу_суботу".split("_"),standalone:"нядзеля_панядзелак_аўторак_серада_чацвер_пятніца_субота".split("_"),isFormat:/\[ ?[Ууў] ?(?:мінулую|наступную)? ?\] ?dddd/},weekdaysShort:"нд_пн_ат_ср_чц_пт_сб".split("_"),weekdaysMin:"нд_пн_ат_ср_чц_пт_сб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., HH:mm",LLLL:"dddd, D MMMM YYYY г., HH:mm"},calendar:{sameDay:"[Сёння ў] LT",nextDay:"[Заўтра ў] LT",lastDay:"[Учора ў] LT",nextWeek:function(){return"[У] dddd [ў] LT"},lastWeek:function(){switch(this.day()){case 0:case 3:case 5:case 6:return"[У мінулую] dddd [ў] LT";case 1:case 2:case 4:return"[У мінулы] dddd [ў] LT"}},sameElse:"L"},relativeTime:{future:"праз %s",past:"%s таму",s:"некалькі секунд",m:t,mm:t,h:t,hh:t,d:"дзень",dd:t,M:"месяц",MM:t,y:"год",yy:t},meridiemParse:/ночы|раніцы|дня|вечара/,isPM:function(e){return/^(дня|вечара)$/.test(e)},meridiem:function(e,t,n){return e<4?"ночы":e<12?"раніцы":e<17?"дня":"вечара"},dayOfMonthOrdinalParse:/\d{1,2}-(і|ы|га)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":case"w":case"W":return e%10!=2&&e%10!=3||e%100==12||e%100==13?e+"-ы":e+"-і";case"D":return e+"-га";default:return e}},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("bg",{months:"януари_февруари_март_април_май_юни_юли_август_септември_октомври_ноември_декември".split("_"),monthsShort:"яну_фев_мар_апр_май_юни_юли_авг_сеп_окт_ное_дек".split("_"),weekdays:"неделя_понеделник_вторник_сряда_четвъртък_петък_събота".split("_"),weekdaysShort:"нед_пон_вто_сря_чет_пет_съб".split("_"),weekdaysMin:"нд_пн_вт_ср_чт_пт_сб".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[Днес в] LT",nextDay:"[Утре в] LT",nextWeek:"dddd [в] LT",lastDay:"[Вчера в] LT",lastWeek:function(){switch(this.day()){case 0:case 3:case 6:return"[Миналата] dddd [в] LT";case 1:case 2:case 4:case 5:return"[Миналия] dddd [в] LT"}},sameElse:"L"},relativeTime:{future:"след %s",past:"преди %s",s:"няколко секунди",ss:"%d секунди",m:"минута",mm:"%d минути",h:"час",hh:"%d часа",d:"ден",dd:"%d дена",w:"седмица",ww:"%d седмици",M:"месец",MM:"%d месеца",y:"година",yy:"%d години"},dayOfMonthOrdinalParse:/\d{1,2}-(ев|ен|ти|ви|ри|ми)/,ordinal:function(e){var t=e%10,n=e%100;return 0===e?e+"-ев":0===n?e+"-ен":n>10&&n<20?e+"-ти":1===t?e+"-ви":2===t?e+"-ри":7===t||8===t?e+"-ми":e+"-ти"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("bm",{months:"Zanwuyekalo_Fewuruyekalo_Marisikalo_Awirilikalo_Mɛkalo_Zuwɛnkalo_Zuluyekalo_Utikalo_Sɛtanburukalo_ɔkutɔburukalo_Nowanburukalo_Desanburukalo".split("_"),monthsShort:"Zan_Few_Mar_Awi_Mɛ_Zuw_Zul_Uti_Sɛt_ɔku_Now_Des".split("_"),weekdays:"Kari_Ntɛnɛn_Tarata_Araba_Alamisa_Juma_Sibiri".split("_"),weekdaysShort:"Kar_Ntɛ_Tar_Ara_Ala_Jum_Sib".split("_"),weekdaysMin:"Ka_Nt_Ta_Ar_Al_Ju_Si".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"MMMM [tile] D [san] YYYY",LLL:"MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm",LLLL:"dddd MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm"},calendar:{sameDay:"[Bi lɛrɛ] LT",nextDay:"[Sini lɛrɛ] LT",nextWeek:"dddd [don lɛrɛ] LT",lastDay:"[Kunu lɛrɛ] LT",lastWeek:"dddd [tɛmɛnen lɛrɛ] LT",sameElse:"L"},relativeTime:{future:"%s kɔnɔ",past:"a bɛ %s bɔ",s:"sanga dama dama",ss:"sekondi %d",m:"miniti kelen",mm:"miniti %d",h:"lɛrɛ kelen",hh:"lɛrɛ %d",d:"tile kelen",dd:"tile %d",M:"kalo kelen",MM:"kalo %d",y:"san kelen",yy:"san %d"},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"১",2:"২",3:"৩",4:"৪",5:"৫",6:"৬",7:"৭",8:"৮",9:"৯",0:"০"},n={"১":"1","২":"2","৩":"3","৪":"4","৫":"5","৬":"6","৭":"7","৮":"8","৯":"9","০":"0"};e.defineLocale("bn",{months:"জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর".split("_"),monthsShort:"জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে".split("_"),weekdays:"রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার".split("_"),weekdaysShort:"রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি".split("_"),weekdaysMin:"রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি".split("_"),longDateFormat:{LT:"A h:mm সময়",LTS:"A h:mm:ss সময়",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm সময়",LLLL:"dddd, D MMMM YYYY, A h:mm সময়"},calendar:{sameDay:"[আজ] LT",nextDay:"[আগামীকাল] LT",nextWeek:"dddd, LT",lastDay:"[গতকাল] LT",lastWeek:"[গত] dddd, LT",sameElse:"L"},relativeTime:{future:"%s পরে",past:"%s আগে",s:"কয়েক সেকেন্ড",ss:"%d সেকেন্ড",m:"এক মিনিট",mm:"%d মিনিট",h:"এক ঘন্টা",hh:"%d ঘন্টা",d:"এক দিন",dd:"%d দিন",M:"এক মাস",MM:"%d মাস",y:"এক বছর",yy:"%d বছর"},preparse:function(e){return e.replace(/[১২৩৪৫৬৭৮৯০]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/রাত|সকাল|দুপুর|বিকাল|রাত/,meridiemHour:function(e,t){return 12===e&&(e=0),"রাত"===t&&e>=4||"দুপুর"===t&&e<5||"বিকাল"===t?e+12:e},meridiem:function(e,t,n){return e<4?"রাত":e<10?"সকাল":e<17?"দুপুর":e<20?"বিকাল":"রাত"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"১",2:"২",3:"৩",4:"৪",5:"৫",6:"৬",7:"৭",8:"৮",9:"৯",0:"০"},n={"১":"1","২":"2","৩":"3","৪":"4","৫":"5","৬":"6","৭":"7","৮":"8","৯":"9","০":"0"};e.defineLocale("bn-bd",{months:"জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর".split("_"),monthsShort:"জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে".split("_"),weekdays:"রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার".split("_"),weekdaysShort:"রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি".split("_"),weekdaysMin:"রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি".split("_"),longDateFormat:{LT:"A h:mm সময়",LTS:"A h:mm:ss সময়",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm সময়",LLLL:"dddd, D MMMM YYYY, A h:mm সময়"},calendar:{sameDay:"[আজ] LT",nextDay:"[আগামীকাল] LT",nextWeek:"dddd, LT",lastDay:"[গতকাল] LT",lastWeek:"[গত] dddd, LT",sameElse:"L"},relativeTime:{future:"%s পরে",past:"%s আগে",s:"কয়েক সেকেন্ড",ss:"%d সেকেন্ড",m:"এক মিনিট",mm:"%d মিনিট",h:"এক ঘন্টা",hh:"%d ঘন্টা",d:"এক দিন",dd:"%d দিন",M:"এক মাস",MM:"%d মাস",y:"এক বছর",yy:"%d বছর"},preparse:function(e){return e.replace(/[১২৩৪৫৬৭৮৯০]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/রাত|ভোর|সকাল|দুপুর|বিকাল|সন্ধ্যা|রাত/,meridiemHour:function(e,t){return 12===e&&(e=0),"রাত"===t?e<4?e:e+12:"ভোর"===t||"সকাল"===t?e:"দুপুর"===t?e>=3?e:e+12:"বিকাল"===t||"সন্ধ্যা"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"রাত":e<6?"ভোর":e<12?"সকাল":e<15?"দুপুর":e<18?"বিকাল":e<20?"সন্ধ্যা":"রাত"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"༡",2:"༢",3:"༣",4:"༤",5:"༥",6:"༦",7:"༧",8:"༨",9:"༩",0:"༠"},n={"༡":"1","༢":"2","༣":"3","༤":"4","༥":"5","༦":"6","༧":"7","༨":"8","༩":"9","༠":"0"};e.defineLocale("bo",{months:"ཟླ་བ་དང་པོ_ཟླ་བ་གཉིས་པ_ཟླ་བ་གསུམ་པ_ཟླ་བ་བཞི་པ_ཟླ་བ་ལྔ་པ_ཟླ་བ་དྲུག་པ_ཟླ་བ་བདུན་པ_ཟླ་བ་བརྒྱད་པ_ཟླ་བ་དགུ་པ_ཟླ་བ་བཅུ་པ_ཟླ་བ་བཅུ་གཅིག་པ_ཟླ་བ་བཅུ་གཉིས་པ".split("_"),monthsShort:"ཟླ་1_ཟླ་2_ཟླ་3_ཟླ་4_ཟླ་5_ཟླ་6_ཟླ་7_ཟླ་8_ཟླ་9_ཟླ་10_ཟླ་11_ཟླ་12".split("_"),monthsShortRegex:/^(ཟླ་\d{1,2})/,monthsParseExact:!0,weekdays:"གཟའ་ཉི་མ་_གཟའ་ཟླ་བ་_གཟའ་མིག་དམར་_གཟའ་ལྷག་པ་_གཟའ་ཕུར་བུ_གཟའ་པ་སངས་_གཟའ་སྤེན་པ་".split("_"),weekdaysShort:"ཉི་མ་_ཟླ་བ་_མིག་དམར་_ལྷག་པ་_ཕུར་བུ_པ་སངས་_སྤེན་པ་".split("_"),weekdaysMin:"ཉི_ཟླ_མིག_ལྷག_ཕུར_སངས_སྤེན".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[དི་རིང] LT",nextDay:"[སང་ཉིན] LT",nextWeek:"[བདུན་ཕྲག་རྗེས་མ], LT",lastDay:"[ཁ་སང] LT",lastWeek:"[བདུན་ཕྲག་མཐའ་མ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ལ་",past:"%s སྔན་ལ",s:"ལམ་སང",ss:"%d སྐར་ཆ།",m:"སྐར་མ་གཅིག",mm:"%d སྐར་མ",h:"ཆུ་ཚོད་གཅིག",hh:"%d ཆུ་ཚོད",d:"ཉིན་གཅིག",dd:"%d ཉིན་",M:"ཟླ་བ་གཅིག",MM:"%d ཟླ་བ",y:"ལོ་གཅིག",yy:"%d ལོ"},preparse:function(e){return e.replace(/[༡༢༣༤༥༦༧༨༩༠]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/མཚན་མོ|ཞོགས་ཀས|ཉིན་གུང|དགོང་དག|མཚན་མོ/,meridiemHour:function(e,t){return 12===e&&(e=0),"མཚན་མོ"===t&&e>=4||"ཉིན་གུང"===t&&e<5||"དགོང་དག"===t?e+12:e},meridiem:function(e,t,n){return e<4?"མཚན་མོ":e<10?"ཞོགས་ཀས":e<17?"ཉིན་གུང":e<20?"དགོང་དག":"མཚན་མོ"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){return e+" "+function(e,t){return 2===t?function(e){var t={m:"v",b:"v",d:"z"};return void 0===t[e.charAt(0)]?e:t[e.charAt(0)]+e.substring(1)}(e):e}({mm:"munutenn",MM:"miz",dd:"devezh"}[n],e)}var n=[/^gen/i,/^c[ʼ\']hwe/i,/^meu/i,/^ebr/i,/^mae/i,/^(mez|eve)/i,/^gou/i,/^eos/i,/^gwe/i,/^her/i,/^du/i,/^ker/i],r=/^(genver|c[ʼ\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu|gen|c[ʼ\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,i=[/^Su/i,/^Lu/i,/^Me([^r]|$)/i,/^Mer/i,/^Ya/i,/^Gw/i,/^Sa/i];e.defineLocale("br",{months:"Genver_Cʼhwevrer_Meurzh_Ebrel_Mae_Mezheven_Gouere_Eost_Gwengolo_Here_Du_Kerzu".split("_"),monthsShort:"Gen_Cʼhwe_Meu_Ebr_Mae_Eve_Gou_Eos_Gwe_Her_Du_Ker".split("_"),weekdays:"Sul_Lun_Meurzh_Mercʼher_Yaou_Gwener_Sadorn".split("_"),weekdaysShort:"Sul_Lun_Meu_Mer_Yao_Gwe_Sad".split("_"),weekdaysMin:"Su_Lu_Me_Mer_Ya_Gw_Sa".split("_"),weekdaysParse:i,fullWeekdaysParse:[/^sul/i,/^lun/i,/^meurzh/i,/^merc[ʼ\']her/i,/^yaou/i,/^gwener/i,/^sadorn/i],shortWeekdaysParse:[/^Sul/i,/^Lun/i,/^Meu/i,/^Mer/i,/^Yao/i,/^Gwe/i,/^Sad/i],minWeekdaysParse:i,monthsRegex:r,monthsShortRegex:r,monthsStrictRegex:/^(genver|c[ʼ\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu)/i,monthsShortStrictRegex:/^(gen|c[ʼ\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,monthsParse:n,longMonthsParse:n,shortMonthsParse:n,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [a viz] MMMM YYYY",LLL:"D [a viz] MMMM YYYY HH:mm",LLLL:"dddd, D [a viz] MMMM YYYY HH:mm"},calendar:{sameDay:"[Hiziv da] LT",nextDay:"[Warcʼhoazh da] LT",nextWeek:"dddd [da] LT",lastDay:"[Decʼh da] LT",lastWeek:"dddd [paset da] LT",sameElse:"L"},relativeTime:{future:"a-benn %s",past:"%s ʼzo",s:"un nebeud segondennoù",ss:"%d eilenn",m:"ur vunutenn",mm:t,h:"un eur",hh:"%d eur",d:"un devezh",dd:t,M:"ur miz",MM:t,y:"ur bloaz",yy:function(e){switch(function e(t){return t>9?e(t%10):t}(e)){case 1:case 3:case 4:case 5:case 9:return e+" bloaz";default:return e+" vloaz"}}},dayOfMonthOrdinalParse:/\d{1,2}(añ|vet)/,ordinal:function(e){return e+(1===e?"añ":"vet")},week:{dow:1,doy:4},meridiemParse:/a.m.|g.m./,isPM:function(e){return"g.m."===e},meridiem:function(e,t,n){return e<12?"a.m.":"g.m."}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r=e+" ";switch(n){case"ss":return r+=1===e?"sekunda":2===e||3===e||4===e?"sekunde":"sekundi";case"m":return t?"jedna minuta":"jedne minute";case"mm":return r+=1===e?"minuta":2===e||3===e||4===e?"minute":"minuta";case"h":return t?"jedan sat":"jednog sata";case"hh":return r+=1===e?"sat":2===e||3===e||4===e?"sata":"sati";case"dd":return r+=1===e?"dan":"dana";case"MM":return r+=1===e?"mjesec":2===e||3===e||4===e?"mjeseca":"mjeseci";case"yy":return r+=1===e?"godina":2===e||3===e||4===e?"godine":"godina"}}e.defineLocale("bs",{months:"januar_februar_mart_april_maj_juni_juli_august_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj._jun._jul._aug._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[jučer u] LT",lastWeek:function(){switch(this.day()){case 0:case 3:return"[prošlu] dddd [u] LT";case 6:return"[prošle] [subote] [u] LT";case 1:case 2:case 4:case 5:return"[prošli] dddd [u] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"par sekundi",ss:t,m:t,mm:t,h:t,hh:t,d:"dan",dd:t,M:"mjesec",MM:t,y:"godinu",yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ca",{months:{standalone:"gener_febrer_març_abril_maig_juny_juliol_agost_setembre_octubre_novembre_desembre".split("_"),format:"de gener_de febrer_de març_d'abril_de maig_de juny_de juliol_d'agost_de setembre_d'octubre_de novembre_de desembre".split("_"),isFormat:/D[oD]?(\s)+MMMM/},monthsShort:"gen._febr._març_abr._maig_juny_jul._ag._set._oct._nov._des.".split("_"),monthsParseExact:!0,weekdays:"diumenge_dilluns_dimarts_dimecres_dijous_divendres_dissabte".split("_"),weekdaysShort:"dg._dl._dt._dc._dj._dv._ds.".split("_"),weekdaysMin:"dg_dl_dt_dc_dj_dv_ds".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [de] YYYY",ll:"D MMM YYYY",LLL:"D MMMM [de] YYYY [a les] H:mm",lll:"D MMM YYYY, H:mm",LLLL:"dddd D MMMM [de] YYYY [a les] H:mm",llll:"ddd D MMM YYYY, H:mm"},calendar:{sameDay:function(){return"[avui a "+(1!==this.hours()?"les":"la")+"] LT"},nextDay:function(){return"[demà a "+(1!==this.hours()?"les":"la")+"] LT"},nextWeek:function(){return"dddd [a "+(1!==this.hours()?"les":"la")+"] LT"},lastDay:function(){return"[ahir a "+(1!==this.hours()?"les":"la")+"] LT"},lastWeek:function(){return"[el] dddd [passat a "+(1!==this.hours()?"les":"la")+"] LT"},sameElse:"L"},relativeTime:{future:"d'aquí %s",past:"fa %s",s:"uns segons",ss:"%d segons",m:"un minut",mm:"%d minuts",h:"una hora",hh:"%d hores",d:"un dia",dd:"%d dies",M:"un mes",MM:"%d mesos",y:"un any",yy:"%d anys"},dayOfMonthOrdinalParse:/\d{1,2}(r|n|t|è|a)/,ordinal:function(e,t){var n=1===e?"r":2===e?"n":3===e?"r":4===e?"t":"è";return"w"!==t&&"W"!==t||(n="a"),e+n},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="leden_únor_březen_duben_květen_červen_červenec_srpen_září_říjen_listopad_prosinec".split("_"),n="led_úno_bře_dub_kvě_čvn_čvc_srp_zář_říj_lis_pro".split("_"),r=[/^led/i,/^úno/i,/^bře/i,/^dub/i,/^kvě/i,/^(čvn|červen$|června)/i,/^(čvc|červenec|července)/i,/^srp/i,/^zář/i,/^říj/i,/^lis/i,/^pro/i],i=/^(leden|únor|březen|duben|květen|červenec|července|červen|června|srpen|září|říjen|listopad|prosinec|led|úno|bře|dub|kvě|čvn|čvc|srp|zář|říj|lis|pro)/i;function o(e){return e>1&&e<5&&1!=~~(e/10)}function a(e,t,n,r){var i=e+" ";switch(n){case"s":return t||r?"pár sekund":"pár sekundami";case"ss":return t||r?i+(o(e)?"sekundy":"sekund"):i+"sekundami";case"m":return t?"minuta":r?"minutu":"minutou";case"mm":return t||r?i+(o(e)?"minuty":"minut"):i+"minutami";case"h":return t?"hodina":r?"hodinu":"hodinou";case"hh":return t||r?i+(o(e)?"hodiny":"hodin"):i+"hodinami";case"d":return t||r?"den":"dnem";case"dd":return t||r?i+(o(e)?"dny":"dní"):i+"dny";case"M":return t||r?"měsíc":"měsícem";case"MM":return t||r?i+(o(e)?"měsíce":"měsíců"):i+"měsíci";case"y":return t||r?"rok":"rokem";case"yy":return t||r?i+(o(e)?"roky":"let"):i+"lety"}}e.defineLocale("cs",{months:t,monthsShort:n,monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(leden|ledna|února|únor|březen|března|duben|dubna|květen|května|červenec|července|červen|června|srpen|srpna|září|říjen|října|listopadu|listopad|prosinec|prosince)/i,monthsShortStrictRegex:/^(led|úno|bře|dub|kvě|čvn|čvc|srp|zář|říj|lis|pro)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"neděle_pondělí_úterý_středa_čtvrtek_pátek_sobota".split("_"),weekdaysShort:"ne_po_út_st_čt_pá_so".split("_"),weekdaysMin:"ne_po_út_st_čt_pá_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm",l:"D. M. YYYY"},calendar:{sameDay:"[dnes v] LT",nextDay:"[zítra v] LT",nextWeek:function(){switch(this.day()){case 0:return"[v neděli v] LT";case 1:case 2:return"[v] dddd [v] LT";case 3:return"[ve středu v] LT";case 4:return"[ve čtvrtek v] LT";case 5:return"[v pátek v] LT";case 6:return"[v sobotu v] LT"}},lastDay:"[včera v] LT",lastWeek:function(){switch(this.day()){case 0:return"[minulou neděli v] LT";case 1:case 2:return"[minulé] dddd [v] LT";case 3:return"[minulou středu v] LT";case 4:case 5:return"[minulý] dddd [v] LT";case 6:return"[minulou sobotu v] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"před %s",s:a,ss:a,m:a,mm:a,h:a,hh:a,d:a,dd:a,M:a,MM:a,y:a,yy:a},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("cv",{months:"кӑрлач_нарӑс_пуш_ака_май_ҫӗртме_утӑ_ҫурла_авӑн_юпа_чӳк_раштав".split("_"),monthsShort:"кӑр_нар_пуш_ака_май_ҫӗр_утӑ_ҫур_авн_юпа_чӳк_раш".split("_"),weekdays:"вырсарникун_тунтикун_ытларикун_юнкун_кӗҫнерникун_эрнекун_шӑматкун".split("_"),weekdaysShort:"выр_тун_ытл_юн_кӗҫ_эрн_шӑм".split("_"),weekdaysMin:"вр_тн_ыт_юн_кҫ_эр_шм".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ]",LLL:"YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm",LLLL:"dddd, YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm"},calendar:{sameDay:"[Паян] LT [сехетре]",nextDay:"[Ыран] LT [сехетре]",lastDay:"[Ӗнер] LT [сехетре]",nextWeek:"[Ҫитес] dddd LT [сехетре]",lastWeek:"[Иртнӗ] dddd LT [сехетре]",sameElse:"L"},relativeTime:{future:function(e){return e+(/сехет$/i.exec(e)?"рен":/ҫул$/i.exec(e)?"тан":"ран")},past:"%s каялла",s:"пӗр-ик ҫеккунт",ss:"%d ҫеккунт",m:"пӗр минут",mm:"%d минут",h:"пӗр сехет",hh:"%d сехет",d:"пӗр кун",dd:"%d кун",M:"пӗр уйӑх",MM:"%d уйӑх",y:"пӗр ҫул",yy:"%d ҫул"},dayOfMonthOrdinalParse:/\d{1,2}-мӗш/,ordinal:"%d-мӗш",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("cy",{months:"Ionawr_Chwefror_Mawrth_Ebrill_Mai_Mehefin_Gorffennaf_Awst_Medi_Hydref_Tachwedd_Rhagfyr".split("_"),monthsShort:"Ion_Chwe_Maw_Ebr_Mai_Meh_Gor_Aws_Med_Hyd_Tach_Rhag".split("_"),weekdays:"Dydd Sul_Dydd Llun_Dydd Mawrth_Dydd Mercher_Dydd Iau_Dydd Gwener_Dydd Sadwrn".split("_"),weekdaysShort:"Sul_Llun_Maw_Mer_Iau_Gwe_Sad".split("_"),weekdaysMin:"Su_Ll_Ma_Me_Ia_Gw_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Heddiw am] LT",nextDay:"[Yfory am] LT",nextWeek:"dddd [am] LT",lastDay:"[Ddoe am] LT",lastWeek:"dddd [diwethaf am] LT",sameElse:"L"},relativeTime:{future:"mewn %s",past:"%s yn ôl",s:"ychydig eiliadau",ss:"%d eiliad",m:"munud",mm:"%d munud",h:"awr",hh:"%d awr",d:"diwrnod",dd:"%d diwrnod",M:"mis",MM:"%d mis",y:"blwyddyn",yy:"%d flynedd"},dayOfMonthOrdinalParse:/\d{1,2}(fed|ain|af|il|ydd|ed|eg)/,ordinal:function(e){var t="";return e>20?t=40===e||50===e||60===e||80===e||100===e?"fed":"ain":e>0&&(t=["","af","il","ydd","ydd","ed","ed","ed","fed","fed","fed","eg","fed","eg","eg","fed","eg","eg","fed","eg","fed"][e]),e+t},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("da",{months:"januar_februar_marts_april_maj_juni_juli_august_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec".split("_"),weekdays:"søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag".split("_"),weekdaysShort:"søn_man_tir_ons_tor_fre_lør".split("_"),weekdaysMin:"sø_ma_ti_on_to_fr_lø".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd [d.] D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[i dag kl.] LT",nextDay:"[i morgen kl.] LT",nextWeek:"på dddd [kl.] LT",lastDay:"[i går kl.] LT",lastWeek:"[i] dddd[s kl.] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s siden",s:"få sekunder",ss:"%d sekunder",m:"et minut",mm:"%d minutter",h:"en time",hh:"%d timer",d:"en dag",dd:"%d dage",M:"en måned",MM:"%d måneder",y:"et år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]};return t?i[n][0]:i[n][1]}e.defineLocale("de",{months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:t,mm:"%d Minuten",h:t,hh:"%d Stunden",d:t,dd:t,w:t,ww:"%d Wochen",M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]};return t?i[n][0]:i[n][1]}e.defineLocale("de-at",{months:"Jänner_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jän._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:t,mm:"%d Minuten",h:t,hh:"%d Stunden",d:t,dd:t,w:t,ww:"%d Wochen",M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]};return t?i[n][0]:i[n][1]}e.defineLocale("de-ch",{months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:t,mm:"%d Minuten",h:t,hh:"%d Stunden",d:t,dd:t,w:t,ww:"%d Wochen",M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t=["ޖެނުއަރީ","ފެބްރުއަރީ","މާރިޗު","އޭޕްރީލު","މޭ","ޖޫން","ޖުލައި","އޯގަސްޓު","ސެޕްޓެމްބަރު","އޮކްޓޯބަރު","ނޮވެމްބަރު","ޑިސެމްބަރު"],n=["އާދިއްތަ","ހޯމަ","އަންގާރަ","ބުދަ","ބުރާސްފަތި","ހުކުރު","ހޮނިހިރު"];e.defineLocale("dv",{months:t,monthsShort:t,weekdays:n,weekdaysShort:n,weekdaysMin:"އާދި_ހޯމަ_އަން_ބުދަ_ބުރާ_ހުކު_ހޮނި".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/M/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/މކ|މފ/,isPM:function(e){return"މފ"===e},meridiem:function(e,t,n){return e<12?"މކ":"މފ"},calendar:{sameDay:"[މިއަދު] LT",nextDay:"[މާދަމާ] LT",nextWeek:"dddd LT",lastDay:"[އިއްޔެ] LT",lastWeek:"[ފާއިތުވި] dddd LT",sameElse:"L"},relativeTime:{future:"ތެރޭގައި %s",past:"ކުރިން %s",s:"ސިކުންތުކޮޅެއް",ss:"d% ސިކުންތު",m:"މިނިޓެއް",mm:"މިނިޓު %d",h:"ގަޑިއިރެއް",hh:"ގަޑިއިރު %d",d:"ދުވަހެއް",dd:"ދުވަސް %d",M:"މަހެއް",MM:"މަސް %d",y:"އަހަރެއް",yy:"އަހަރު %d"},preparse:function(e){return e.replace(/،/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:7,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("el",{monthsNominativeEl:"Ιανουάριος_Φεβρουάριος_Μάρτιος_Απρίλιος_Μάιος_Ιούνιος_Ιούλιος_Αύγουστος_Σεπτέμβριος_Οκτώβριος_Νοέμβριος_Δεκέμβριος".split("_"),monthsGenitiveEl:"Ιανουαρίου_Φεβρουαρίου_Μαρτίου_Απριλίου_Μαΐου_Ιουνίου_Ιουλίου_Αυγούστου_Σεπτεμβρίου_Οκτωβρίου_Νοεμβρίου_Δεκεμβρίου".split("_"),months:function(e,t){return e?"string"==typeof t&&/D/.test(t.substring(0,t.indexOf("MMMM")))?this._monthsGenitiveEl[e.month()]:this._monthsNominativeEl[e.month()]:this._monthsNominativeEl},monthsShort:"Ιαν_Φεβ_Μαρ_Απρ_Μαϊ_Ιουν_Ιουλ_Αυγ_Σεπ_Οκτ_Νοε_Δεκ".split("_"),weekdays:"Κυριακή_Δευτέρα_Τρίτη_Τετάρτη_Πέμπτη_Παρασκευή_Σάββατο".split("_"),weekdaysShort:"Κυρ_Δευ_Τρι_Τετ_Πεμ_Παρ_Σαβ".split("_"),weekdaysMin:"Κυ_Δε_Τρ_Τε_Πε_Πα_Σα".split("_"),meridiem:function(e,t,n){return e>11?n?"μμ":"ΜΜ":n?"πμ":"ΠΜ"},isPM:function(e){return"μ"===(e+"").toLowerCase()[0]},meridiemParse:/[ΠΜ]\.?Μ?\.?/i,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendarEl:{sameDay:"[Σήμερα {}] LT",nextDay:"[Αύριο {}] LT",nextWeek:"dddd [{}] LT",lastDay:"[Χθες {}] LT",lastWeek:function(){switch(this.day()){case 6:return"[το προηγούμενο] dddd [{}] LT";default:return"[την προηγούμενη] dddd [{}] LT"}},sameElse:"L"},calendar:function(e,t){var n,r=this._calendarEl[e],i=t&&t.hours();return n=r,("undefined"!=typeof Function&&n instanceof Function||"[object Function]"===Object.prototype.toString.call(n))&&(r=r.apply(t)),r.replace("{}",i%12==1?"στη":"στις")},relativeTime:{future:"σε %s",past:"%s πριν",s:"λίγα δευτερόλεπτα",ss:"%d δευτερόλεπτα",m:"ένα λεπτό",mm:"%d λεπτά",h:"μία ώρα",hh:"%d ώρες",d:"μία μέρα",dd:"%d μέρες",M:"ένας μήνας",MM:"%d μήνες",y:"ένας χρόνος",yy:"%d χρόνια"},dayOfMonthOrdinalParse:/\d{1,2}η/,ordinal:"%dη",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-au",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:0,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-ca",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"YYYY-MM-DD",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-gb",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-ie",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-il",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-in",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-nz",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("en-sg",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("eo",{months:"januaro_februaro_marto_aprilo_majo_junio_julio_aŭgusto_septembro_oktobro_novembro_decembro".split("_"),monthsShort:"jan_feb_mart_apr_maj_jun_jul_aŭg_sept_okt_nov_dec".split("_"),weekdays:"dimanĉo_lundo_mardo_merkredo_ĵaŭdo_vendredo_sabato".split("_"),weekdaysShort:"dim_lun_mard_merk_ĵaŭ_ven_sab".split("_"),weekdaysMin:"di_lu_ma_me_ĵa_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"[la] D[-an de] MMMM, YYYY",LLL:"[la] D[-an de] MMMM, YYYY HH:mm",LLLL:"dddd[n], [la] D[-an de] MMMM, YYYY HH:mm",llll:"ddd, [la] D[-an de] MMM, YYYY HH:mm"},meridiemParse:/[ap]\.t\.m/i,isPM:function(e){return"p"===e.charAt(0).toLowerCase()},meridiem:function(e,t,n){return e>11?n?"p.t.m.":"P.T.M.":n?"a.t.m.":"A.T.M."},calendar:{sameDay:"[Hodiaŭ je] LT",nextDay:"[Morgaŭ je] LT",nextWeek:"dddd[n je] LT",lastDay:"[Hieraŭ je] LT",lastWeek:"[pasintan] dddd[n je] LT",sameElse:"L"},relativeTime:{future:"post %s",past:"antaŭ %s",s:"kelkaj sekundoj",ss:"%d sekundoj",m:"unu minuto",mm:"%d minutoj",h:"unu horo",hh:"%d horoj",d:"unu tago",dd:"%d tagoj",M:"unu monato",MM:"%d monatoj",y:"unu jaro",yy:"%d jaroj"},dayOfMonthOrdinalParse:/\d{1,2}a/,ordinal:"%da",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),n="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),r=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],i=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;e.defineLocale("es",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4},invalidDate:"Fecha inválida"})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),n="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),r=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],i=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;e.defineLocale("es-do",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY h:mm A",LLLL:"dddd, D [de] MMMM [de] YYYY h:mm A"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),n="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),r=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],i=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;e.defineLocale("es-mx",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:0,doy:4},invalidDate:"Fecha inválida"})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),n="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),r=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],i=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;e.defineLocale("es-us",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"MM/DD/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY h:mm A",LLLL:"dddd, D [de] MMMM [de] YYYY h:mm A"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={s:["mõne sekundi","mõni sekund","paar sekundit"],ss:[e+"sekundi",e+"sekundit"],m:["ühe minuti","üks minut"],mm:[e+" minuti",e+" minutit"],h:["ühe tunni","tund aega","üks tund"],hh:[e+" tunni",e+" tundi"],d:["ühe päeva","üks päev"],M:["kuu aja","kuu aega","üks kuu"],MM:[e+" kuu",e+" kuud"],y:["ühe aasta","aasta","üks aasta"],yy:[e+" aasta",e+" aastat"]};return t?i[n][2]?i[n][2]:i[n][1]:r?i[n][0]:i[n][1]}e.defineLocale("et",{months:"jaanuar_veebruar_märts_aprill_mai_juuni_juuli_august_september_oktoober_november_detsember".split("_"),monthsShort:"jaan_veebr_märts_apr_mai_juuni_juuli_aug_sept_okt_nov_dets".split("_"),weekdays:"pühapäev_esmaspäev_teisipäev_kolmapäev_neljapäev_reede_laupäev".split("_"),weekdaysShort:"P_E_T_K_N_R_L".split("_"),weekdaysMin:"P_E_T_K_N_R_L".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[Täna,] LT",nextDay:"[Homme,] LT",nextWeek:"[Järgmine] dddd LT",lastDay:"[Eile,] LT",lastWeek:"[Eelmine] dddd LT",sameElse:"L"},relativeTime:{future:"%s pärast",past:"%s tagasi",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:"%d päeva",M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("eu",{months:"urtarrila_otsaila_martxoa_apirila_maiatza_ekaina_uztaila_abuztua_iraila_urria_azaroa_abendua".split("_"),monthsShort:"urt._ots._mar._api._mai._eka._uzt._abu._ira._urr._aza._abe.".split("_"),monthsParseExact:!0,weekdays:"igandea_astelehena_asteartea_asteazkena_osteguna_ostirala_larunbata".split("_"),weekdaysShort:"ig._al._ar._az._og._ol._lr.".split("_"),weekdaysMin:"ig_al_ar_az_og_ol_lr".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY[ko] MMMM[ren] D[a]",LLL:"YYYY[ko] MMMM[ren] D[a] HH:mm",LLLL:"dddd, YYYY[ko] MMMM[ren] D[a] HH:mm",l:"YYYY-M-D",ll:"YYYY[ko] MMM D[a]",lll:"YYYY[ko] MMM D[a] HH:mm",llll:"ddd, YYYY[ko] MMM D[a] HH:mm"},calendar:{sameDay:"[gaur] LT[etan]",nextDay:"[bihar] LT[etan]",nextWeek:"dddd LT[etan]",lastDay:"[atzo] LT[etan]",lastWeek:"[aurreko] dddd LT[etan]",sameElse:"L"},relativeTime:{future:"%s barru",past:"duela %s",s:"segundo batzuk",ss:"%d segundo",m:"minutu bat",mm:"%d minutu",h:"ordu bat",hh:"%d ordu",d:"egun bat",dd:"%d egun",M:"hilabete bat",MM:"%d hilabete",y:"urte bat",yy:"%d urte"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"۱",2:"۲",3:"۳",4:"۴",5:"۵",6:"۶",7:"۷",8:"۸",9:"۹",0:"۰"},n={"۱":"1","۲":"2","۳":"3","۴":"4","۵":"5","۶":"6","۷":"7","۸":"8","۹":"9","۰":"0"};e.defineLocale("fa",{months:"ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر".split("_"),monthsShort:"ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر".split("_"),weekdays:"یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه".split("_"),weekdaysShort:"یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه".split("_"),weekdaysMin:"ی_د_س_چ_پ_ج_ش".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/قبل از ظهر|بعد از ظهر/,isPM:function(e){return/بعد از ظهر/.test(e)},meridiem:function(e,t,n){return e<12?"قبل از ظهر":"بعد از ظهر"},calendar:{sameDay:"[امروز ساعت] LT",nextDay:"[فردا ساعت] LT",nextWeek:"dddd [ساعت] LT",lastDay:"[دیروز ساعت] LT",lastWeek:"dddd [پیش] [ساعت] LT",sameElse:"L"},relativeTime:{future:"در %s",past:"%s پیش",s:"چند ثانیه",ss:"%d ثانیه",m:"یک دقیقه",mm:"%d دقیقه",h:"یک ساعت",hh:"%d ساعت",d:"یک روز",dd:"%d روز",M:"یک ماه",MM:"%d ماه",y:"یک سال",yy:"%d سال"},preparse:function(e){return e.replace(/[۰-۹]/g,(function(e){return n[e]})).replace(/،/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]})).replace(/,/g,"،")},dayOfMonthOrdinalParse:/\d{1,2}م/,ordinal:"%dم",week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="nolla yksi kaksi kolme neljä viisi kuusi seitsemän kahdeksan yhdeksän".split(" "),n=["nolla","yhden","kahden","kolmen","neljän","viiden","kuuden",t[7],t[8],t[9]];function r(e,r,i,o){var a="";switch(i){case"s":return o?"muutaman sekunnin":"muutama sekunti";case"ss":a=o?"sekunnin":"sekuntia";break;case"m":return o?"minuutin":"minuutti";case"mm":a=o?"minuutin":"minuuttia";break;case"h":return o?"tunnin":"tunti";case"hh":a=o?"tunnin":"tuntia";break;case"d":return o?"päivän":"päivä";case"dd":a=o?"päivän":"päivää";break;case"M":return o?"kuukauden":"kuukausi";case"MM":a=o?"kuukauden":"kuukautta";break;case"y":return o?"vuoden":"vuosi";case"yy":a=o?"vuoden":"vuotta"}return a=function(e,r){return e<10?r?n[e]:t[e]:e}(e,o)+" "+a}e.defineLocale("fi",{months:"tammikuu_helmikuu_maaliskuu_huhtikuu_toukokuu_kesäkuu_heinäkuu_elokuu_syyskuu_lokakuu_marraskuu_joulukuu".split("_"),monthsShort:"tammi_helmi_maalis_huhti_touko_kesä_heinä_elo_syys_loka_marras_joulu".split("_"),weekdays:"sunnuntai_maanantai_tiistai_keskiviikko_torstai_perjantai_lauantai".split("_"),weekdaysShort:"su_ma_ti_ke_to_pe_la".split("_"),weekdaysMin:"su_ma_ti_ke_to_pe_la".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD.MM.YYYY",LL:"Do MMMM[ta] YYYY",LLL:"Do MMMM[ta] YYYY, [klo] HH.mm",LLLL:"dddd, Do MMMM[ta] YYYY, [klo] HH.mm",l:"D.M.YYYY",ll:"Do MMM YYYY",lll:"Do MMM YYYY, [klo] HH.mm",llll:"ddd, Do MMM YYYY, [klo] HH.mm"},calendar:{sameDay:"[tänään] [klo] LT",nextDay:"[huomenna] [klo] LT",nextWeek:"dddd [klo] LT",lastDay:"[eilen] [klo] LT",lastWeek:"[viime] dddd[na] [klo] LT",sameElse:"L"},relativeTime:{future:"%s päästä",past:"%s sitten",s:r,ss:r,m:r,mm:r,h:r,hh:r,d:r,dd:r,M:r,MM:r,y:r,yy:r},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("fil",{months:"Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre".split("_"),monthsShort:"Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis".split("_"),weekdays:"Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado".split("_"),weekdaysShort:"Lin_Lun_Mar_Miy_Huw_Biy_Sab".split("_"),weekdaysMin:"Li_Lu_Ma_Mi_Hu_Bi_Sab".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"MM/D/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY HH:mm",LLLL:"dddd, MMMM DD, YYYY HH:mm"},calendar:{sameDay:"LT [ngayong araw]",nextDay:"[Bukas ng] LT",nextWeek:"LT [sa susunod na] dddd",lastDay:"LT [kahapon]",lastWeek:"LT [noong nakaraang] dddd",sameElse:"L"},relativeTime:{future:"sa loob ng %s",past:"%s ang nakalipas",s:"ilang segundo",ss:"%d segundo",m:"isang minuto",mm:"%d minuto",h:"isang oras",hh:"%d oras",d:"isang araw",dd:"%d araw",M:"isang buwan",MM:"%d buwan",y:"isang taon",yy:"%d taon"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("fo",{months:"januar_februar_mars_apríl_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des".split("_"),weekdays:"sunnudagur_mánadagur_týsdagur_mikudagur_hósdagur_fríggjadagur_leygardagur".split("_"),weekdaysShort:"sun_mán_týs_mik_hós_frí_ley".split("_"),weekdaysMin:"su_má_tý_mi_hó_fr_le".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D. MMMM, YYYY HH:mm"},calendar:{sameDay:"[Í dag kl.] LT",nextDay:"[Í morgin kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[Í gjár kl.] LT",lastWeek:"[síðstu] dddd [kl] LT",sameElse:"L"},relativeTime:{future:"um %s",past:"%s síðani",s:"fá sekund",ss:"%d sekundir",m:"ein minuttur",mm:"%d minuttir",h:"ein tími",hh:"%d tímar",d:"ein dagur",dd:"%d dagar",M:"ein mánaður",MM:"%d mánaðir",y:"eitt ár",yy:"%d ár"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t=/(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?|janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,n=[/^janv/i,/^févr/i,/^mars/i,/^avr/i,/^mai/i,/^juin/i,/^juil/i,/^août/i,/^sept/i,/^oct/i,/^nov/i,/^déc/i];e.defineLocale("fr",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsRegex:t,monthsShortRegex:t,monthsStrictRegex:/^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,monthsShortStrictRegex:/(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?)/i,monthsParse:n,longMonthsParse:n,shortMonthsParse:n,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",w:"une semaine",ww:"%d semaines",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|)/,ordinal:function(e,t){switch(t){case"D":return e+(1===e?"er":"");default:case"M":case"Q":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("fr-ca",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsParseExact:!0,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|e)/,ordinal:function(e,t){switch(t){default:case"M":case"Q":case"D":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("fr-ch",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsParseExact:!0,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|e)/,ordinal:function(e,t){switch(t){default:case"M":case"Q":case"D":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="jan._feb._mrt._apr._mai_jun._jul._aug._sep._okt._nov._des.".split("_"),n="jan_feb_mrt_apr_mai_jun_jul_aug_sep_okt_nov_des".split("_");e.defineLocale("fy",{months:"jannewaris_febrewaris_maart_april_maaie_juny_july_augustus_septimber_oktober_novimber_desimber".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsParseExact:!0,weekdays:"snein_moandei_tiisdei_woansdei_tongersdei_freed_sneon".split("_"),weekdaysShort:"si._mo._ti._wo._to._fr._so.".split("_"),weekdaysMin:"Si_Mo_Ti_Wo_To_Fr_So".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[hjoed om] LT",nextDay:"[moarn om] LT",nextWeek:"dddd [om] LT",lastDay:"[juster om] LT",lastWeek:"[ôfrûne] dddd [om] LT",sameElse:"L"},relativeTime:{future:"oer %s",past:"%s lyn",s:"in pear sekonden",ss:"%d sekonden",m:"ien minút",mm:"%d minuten",h:"ien oere",hh:"%d oeren",d:"ien dei",dd:"%d dagen",M:"ien moanne",MM:"%d moannen",y:"ien jier",yy:"%d jierren"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||e>=20?"ste":"de")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ga",{months:["Eanáir","Feabhra","Márta","Aibreán","Bealtaine","Meitheamh","Iúil","Lúnasa","Meán Fómhair","Deireadh Fómhair","Samhain","Nollaig"],monthsShort:["Ean","Feabh","Márt","Aib","Beal","Meith","Iúil","Lún","M.F.","D.F.","Samh","Noll"],monthsParseExact:!0,weekdays:["Dé Domhnaigh","Dé Luain","Dé Máirt","Dé Céadaoin","Déardaoin","Dé hAoine","Dé Sathairn"],weekdaysShort:["Domh","Luan","Máirt","Céad","Déar","Aoine","Sath"],weekdaysMin:["Do","Lu","Má","Cé","Dé","A","Sa"],longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Inniu ag] LT",nextDay:"[Amárach ag] LT",nextWeek:"dddd [ag] LT",lastDay:"[Inné ag] LT",lastWeek:"dddd [seo caite] [ag] LT",sameElse:"L"},relativeTime:{future:"i %s",past:"%s ó shin",s:"cúpla soicind",ss:"%d soicind",m:"nóiméad",mm:"%d nóiméad",h:"uair an chloig",hh:"%d uair an chloig",d:"lá",dd:"%d lá",M:"mí",MM:"%d míonna",y:"bliain",yy:"%d bliain"},dayOfMonthOrdinalParse:/\d{1,2}(d|na|mh)/,ordinal:function(e){return e+(1===e?"d":e%10==2?"na":"mh")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("gd",{months:["Am Faoilleach","An Gearran","Am Màrt","An Giblean","An Cèitean","An t-Ògmhios","An t-Iuchar","An Lùnastal","An t-Sultain","An Dàmhair","An t-Samhain","An Dùbhlachd"],monthsShort:["Faoi","Gear","Màrt","Gibl","Cèit","Ògmh","Iuch","Lùn","Sult","Dàmh","Samh","Dùbh"],monthsParseExact:!0,weekdays:["Didòmhnaich","Diluain","Dimàirt","Diciadain","Diardaoin","Dihaoine","Disathairne"],weekdaysShort:["Did","Dil","Dim","Dic","Dia","Dih","Dis"],weekdaysMin:["Dò","Lu","Mà","Ci","Ar","Ha","Sa"],longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[An-diugh aig] LT",nextDay:"[A-màireach aig] LT",nextWeek:"dddd [aig] LT",lastDay:"[An-dè aig] LT",lastWeek:"dddd [seo chaidh] [aig] LT",sameElse:"L"},relativeTime:{future:"ann an %s",past:"bho chionn %s",s:"beagan diogan",ss:"%d diogan",m:"mionaid",mm:"%d mionaidean",h:"uair",hh:"%d uairean",d:"latha",dd:"%d latha",M:"mìos",MM:"%d mìosan",y:"bliadhna",yy:"%d bliadhna"},dayOfMonthOrdinalParse:/\d{1,2}(d|na|mh)/,ordinal:function(e){return e+(1===e?"d":e%10==2?"na":"mh")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("gl",{months:"xaneiro_febreiro_marzo_abril_maio_xuño_xullo_agosto_setembro_outubro_novembro_decembro".split("_"),monthsShort:"xan._feb._mar._abr._mai._xuñ._xul._ago._set._out._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"domingo_luns_martes_mércores_xoves_venres_sábado".split("_"),weekdaysShort:"dom._lun._mar._mér._xov._ven._sáb.".split("_"),weekdaysMin:"do_lu_ma_mé_xo_ve_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoxe "+(1!==this.hours()?"ás":"á")+"] LT"},nextDay:function(){return"[mañá "+(1!==this.hours()?"ás":"á")+"] LT"},nextWeek:function(){return"dddd ["+(1!==this.hours()?"ás":"a")+"] LT"},lastDay:function(){return"[onte "+(1!==this.hours()?"á":"a")+"] LT"},lastWeek:function(){return"[o] dddd [pasado "+(1!==this.hours()?"ás":"a")+"] LT"},sameElse:"L"},relativeTime:{future:function(e){return 0===e.indexOf("un")?"n"+e:"en "+e},past:"hai %s",s:"uns segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"unha hora",hh:"%d horas",d:"un día",dd:"%d días",M:"un mes",MM:"%d meses",y:"un ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={s:["थोडया सॅकंडांनी","थोडे सॅकंड"],ss:[e+" सॅकंडांनी",e+" सॅकंड"],m:["एका मिणटान","एक मिनूट"],mm:[e+" मिणटांनी",e+" मिणटां"],h:["एका वरान","एक वर"],hh:[e+" वरांनी",e+" वरां"],d:["एका दिसान","एक दीस"],dd:[e+" दिसांनी",e+" दीस"],M:["एका म्हयन्यान","एक म्हयनो"],MM:[e+" म्हयन्यानी",e+" म्हयने"],y:["एका वर्सान","एक वर्स"],yy:[e+" वर्सांनी",e+" वर्सां"]};return r?i[n][0]:i[n][1]}e.defineLocale("gom-deva",{months:{standalone:"जानेवारी_फेब्रुवारी_मार्च_एप्रील_मे_जून_जुलय_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर".split("_"),format:"जानेवारीच्या_फेब्रुवारीच्या_मार्चाच्या_एप्रीलाच्या_मेयाच्या_जूनाच्या_जुलयाच्या_ऑगस्टाच्या_सप्टेंबराच्या_ऑक्टोबराच्या_नोव्हेंबराच्या_डिसेंबराच्या".split("_"),isFormat:/MMMM(\s)+D[oD]?/},monthsShort:"जाने._फेब्रु._मार्च_एप्री._मे_जून_जुल._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.".split("_"),monthsParseExact:!0,weekdays:"आयतार_सोमार_मंगळार_बुधवार_बिरेस्तार_सुक्रार_शेनवार".split("_"),weekdaysShort:"आयत._सोम._मंगळ._बुध._ब्रेस्त._सुक्र._शेन.".split("_"),weekdaysMin:"आ_सो_मं_बु_ब्रे_सु_शे".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"A h:mm [वाजतां]",LTS:"A h:mm:ss [वाजतां]",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY A h:mm [वाजतां]",LLLL:"dddd, MMMM Do, YYYY, A h:mm [वाजतां]",llll:"ddd, D MMM YYYY, A h:mm [वाजतां]"},calendar:{sameDay:"[आयज] LT",nextDay:"[फाल्यां] LT",nextWeek:"[फुडलो] dddd[,] LT",lastDay:"[काल] LT",lastWeek:"[फाटलो] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%s",past:"%s आदीं",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:t,M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}(वेर)/,ordinal:function(e,t){switch(t){case"D":return e+"वेर";default:case"M":case"Q":case"DDD":case"d":case"w":case"W":return e}},week:{dow:0,doy:3},meridiemParse:/राती|सकाळीं|दनपारां|सांजे/,meridiemHour:function(e,t){return 12===e&&(e=0),"राती"===t?e<4?e:e+12:"सकाळीं"===t?e:"दनपारां"===t?e>12?e:e+12:"सांजे"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"राती":e<12?"सकाळीं":e<16?"दनपारां":e<20?"सांजे":"राती"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={s:["thoddea sekondamni","thodde sekond"],ss:[e+" sekondamni",e+" sekond"],m:["eka mintan","ek minut"],mm:[e+" mintamni",e+" mintam"],h:["eka voran","ek vor"],hh:[e+" voramni",e+" voram"],d:["eka disan","ek dis"],dd:[e+" disamni",e+" dis"],M:["eka mhoinean","ek mhoino"],MM:[e+" mhoineamni",e+" mhoine"],y:["eka vorsan","ek voros"],yy:[e+" vorsamni",e+" vorsam"]};return r?i[n][0]:i[n][1]}e.defineLocale("gom-latn",{months:{standalone:"Janer_Febrer_Mars_Abril_Mai_Jun_Julai_Agost_Setembr_Otubr_Novembr_Dezembr".split("_"),format:"Janerachea_Febrerachea_Marsachea_Abrilachea_Maiachea_Junachea_Julaiachea_Agostachea_Setembrachea_Otubrachea_Novembrachea_Dezembrachea".split("_"),isFormat:/MMMM(\s)+D[oD]?/},monthsShort:"Jan._Feb._Mars_Abr._Mai_Jun_Jul._Ago._Set._Otu._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Aitar_Somar_Mongllar_Budhvar_Birestar_Sukrar_Son'var".split("_"),weekdaysShort:"Ait._Som._Mon._Bud._Bre._Suk._Son.".split("_"),weekdaysMin:"Ai_Sm_Mo_Bu_Br_Su_Sn".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"A h:mm [vazta]",LTS:"A h:mm:ss [vazta]",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY A h:mm [vazta]",LLLL:"dddd, MMMM Do, YYYY, A h:mm [vazta]",llll:"ddd, D MMM YYYY, A h:mm [vazta]"},calendar:{sameDay:"[Aiz] LT",nextDay:"[Faleam] LT",nextWeek:"[Fuddlo] dddd[,] LT",lastDay:"[Kal] LT",lastWeek:"[Fattlo] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%s",past:"%s adim",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:t,M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}(er)/,ordinal:function(e,t){switch(t){case"D":return e+"er";default:case"M":case"Q":case"DDD":case"d":case"w":case"W":return e}},week:{dow:0,doy:3},meridiemParse:/rati|sokallim|donparam|sanje/,meridiemHour:function(e,t){return 12===e&&(e=0),"rati"===t?e<4?e:e+12:"sokallim"===t?e:"donparam"===t?e>12?e:e+12:"sanje"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"rati":e<12?"sokallim":e<16?"donparam":e<20?"sanje":"rati"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"૧",2:"૨",3:"૩",4:"૪",5:"૫",6:"૬",7:"૭",8:"૮",9:"૯",0:"૦"},n={"૧":"1","૨":"2","૩":"3","૪":"4","૫":"5","૬":"6","૭":"7","૮":"8","૯":"9","૦":"0"};e.defineLocale("gu",{months:"જાન્યુઆરી_ફેબ્રુઆરી_માર્ચ_એપ્રિલ_મે_જૂન_જુલાઈ_ઑગસ્ટ_સપ્ટેમ્બર_ઑક્ટ્બર_નવેમ્બર_ડિસેમ્બર".split("_"),monthsShort:"જાન્યુ._ફેબ્રુ._માર્ચ_એપ્રિ._મે_જૂન_જુલા._ઑગ._સપ્ટે._ઑક્ટ્._નવે._ડિસે.".split("_"),monthsParseExact:!0,weekdays:"રવિવાર_સોમવાર_મંગળવાર_બુધ્વાર_ગુરુવાર_શુક્રવાર_શનિવાર".split("_"),weekdaysShort:"રવિ_સોમ_મંગળ_બુધ્_ગુરુ_શુક્ર_શનિ".split("_"),weekdaysMin:"ર_સો_મં_બુ_ગુ_શુ_શ".split("_"),longDateFormat:{LT:"A h:mm વાગ્યે",LTS:"A h:mm:ss વાગ્યે",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm વાગ્યે",LLLL:"dddd, D MMMM YYYY, A h:mm વાગ્યે"},calendar:{sameDay:"[આજ] LT",nextDay:"[કાલે] LT",nextWeek:"dddd, LT",lastDay:"[ગઇકાલે] LT",lastWeek:"[પાછલા] dddd, LT",sameElse:"L"},relativeTime:{future:"%s મા",past:"%s પહેલા",s:"અમુક પળો",ss:"%d સેકંડ",m:"એક મિનિટ",mm:"%d મિનિટ",h:"એક કલાક",hh:"%d કલાક",d:"એક દિવસ",dd:"%d દિવસ",M:"એક મહિનો",MM:"%d મહિનો",y:"એક વર્ષ",yy:"%d વર્ષ"},preparse:function(e){return e.replace(/[૧૨૩૪૫૬૭૮૯૦]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/રાત|બપોર|સવાર|સાંજ/,meridiemHour:function(e,t){return 12===e&&(e=0),"રાત"===t?e<4?e:e+12:"સવાર"===t?e:"બપોર"===t?e>=10?e:e+12:"સાંજ"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"રાત":e<10?"સવાર":e<17?"બપોર":e<20?"સાંજ":"રાત"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("he",{months:"ינואר_פברואר_מרץ_אפריל_מאי_יוני_יולי_אוגוסט_ספטמבר_אוקטובר_נובמבר_דצמבר".split("_"),monthsShort:"ינו׳_פבר׳_מרץ_אפר׳_מאי_יוני_יולי_אוג׳_ספט׳_אוק׳_נוב׳_דצמ׳".split("_"),weekdays:"ראשון_שני_שלישי_רביעי_חמישי_שישי_שבת".split("_"),weekdaysShort:"א׳_ב׳_ג׳_ד׳_ה׳_ו׳_ש׳".split("_"),weekdaysMin:"א_ב_ג_ד_ה_ו_ש".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [ב]MMMM YYYY",LLL:"D [ב]MMMM YYYY HH:mm",LLLL:"dddd, D [ב]MMMM YYYY HH:mm",l:"D/M/YYYY",ll:"D MMM YYYY",lll:"D MMM YYYY HH:mm",llll:"ddd, D MMM YYYY HH:mm"},calendar:{sameDay:"[היום ב־]LT",nextDay:"[מחר ב־]LT",nextWeek:"dddd [בשעה] LT",lastDay:"[אתמול ב־]LT",lastWeek:"[ביום] dddd [האחרון בשעה] LT",sameElse:"L"},relativeTime:{future:"בעוד %s",past:"לפני %s",s:"מספר שניות",ss:"%d שניות",m:"דקה",mm:"%d דקות",h:"שעה",hh:function(e){return 2===e?"שעתיים":e+" שעות"},d:"יום",dd:function(e){return 2===e?"יומיים":e+" ימים"},M:"חודש",MM:function(e){return 2===e?"חודשיים":e+" חודשים"},y:"שנה",yy:function(e){return 2===e?"שנתיים":e%10==0&&10!==e?e+" שנה":e+" שנים"}},meridiemParse:/אחה"צ|לפנה"צ|אחרי הצהריים|לפני הצהריים|לפנות בוקר|בבוקר|בערב/i,isPM:function(e){return/^(אחה"צ|אחרי הצהריים|בערב)$/.test(e)},meridiem:function(e,t,n){return e<5?"לפנות בוקר":e<10?"בבוקר":e<12?n?'לפנה"צ':"לפני הצהריים":e<18?n?'אחה"צ':"אחרי הצהריים":"בערב"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"},n={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"},r=[/^जन/i,/^फ़र|फर/i,/^मार्च/i,/^अप्रै/i,/^मई/i,/^जून/i,/^जुल/i,/^अग/i,/^सितं|सित/i,/^अक्टू/i,/^नव|नवं/i,/^दिसं|दिस/i];e.defineLocale("hi",{months:{format:"जनवरी_फ़रवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितम्बर_अक्टूबर_नवम्बर_दिसम्बर".split("_"),standalone:"जनवरी_फरवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितंबर_अक्टूबर_नवंबर_दिसंबर".split("_")},monthsShort:"जन._फ़र._मार्च_अप्रै._मई_जून_जुल._अग._सित._अक्टू._नव._दिस.".split("_"),weekdays:"रविवार_सोमवार_मंगलवार_बुधवार_गुरूवार_शुक्रवार_शनिवार".split("_"),weekdaysShort:"रवि_सोम_मंगल_बुध_गुरू_शुक्र_शनि".split("_"),weekdaysMin:"र_सो_मं_बु_गु_शु_श".split("_"),longDateFormat:{LT:"A h:mm बजे",LTS:"A h:mm:ss बजे",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm बजे",LLLL:"dddd, D MMMM YYYY, A h:mm बजे"},monthsParse:r,longMonthsParse:r,shortMonthsParse:[/^जन/i,/^फ़र/i,/^मार्च/i,/^अप्रै/i,/^मई/i,/^जून/i,/^जुल/i,/^अग/i,/^सित/i,/^अक्टू/i,/^नव/i,/^दिस/i],monthsRegex:/^(जनवरी|जन\.?|फ़रवरी|फरवरी|फ़र\.?|मार्च?|अप्रैल|अप्रै\.?|मई?|जून?|जुलाई|जुल\.?|अगस्त|अग\.?|सितम्बर|सितंबर|सित\.?|अक्टूबर|अक्टू\.?|नवम्बर|नवंबर|नव\.?|दिसम्बर|दिसंबर|दिस\.?)/i,monthsShortRegex:/^(जनवरी|जन\.?|फ़रवरी|फरवरी|फ़र\.?|मार्च?|अप्रैल|अप्रै\.?|मई?|जून?|जुलाई|जुल\.?|अगस्त|अग\.?|सितम्बर|सितंबर|सित\.?|अक्टूबर|अक्टू\.?|नवम्बर|नवंबर|नव\.?|दिसम्बर|दिसंबर|दिस\.?)/i,monthsStrictRegex:/^(जनवरी?|फ़रवरी|फरवरी?|मार्च?|अप्रैल?|मई?|जून?|जुलाई?|अगस्त?|सितम्बर|सितंबर|सित?\.?|अक्टूबर|अक्टू\.?|नवम्बर|नवंबर?|दिसम्बर|दिसंबर?)/i,monthsShortStrictRegex:/^(जन\.?|फ़र\.?|मार्च?|अप्रै\.?|मई?|जून?|जुल\.?|अग\.?|सित\.?|अक्टू\.?|नव\.?|दिस\.?)/i,calendar:{sameDay:"[आज] LT",nextDay:"[कल] LT",nextWeek:"dddd, LT",lastDay:"[कल] LT",lastWeek:"[पिछले] dddd, LT",sameElse:"L"},relativeTime:{future:"%s में",past:"%s पहले",s:"कुछ ही क्षण",ss:"%d सेकंड",m:"एक मिनट",mm:"%d मिनट",h:"एक घंटा",hh:"%d घंटे",d:"एक दिन",dd:"%d दिन",M:"एक महीने",MM:"%d महीने",y:"एक वर्ष",yy:"%d वर्ष"},preparse:function(e){return e.replace(/[१२३४५६७८९०]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/रात|सुबह|दोपहर|शाम/,meridiemHour:function(e,t){return 12===e&&(e=0),"रात"===t?e<4?e:e+12:"सुबह"===t?e:"दोपहर"===t?e>=10?e:e+12:"शाम"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"रात":e<10?"सुबह":e<17?"दोपहर":e<20?"शाम":"रात"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r=e+" ";switch(n){case"ss":return r+=1===e?"sekunda":2===e||3===e||4===e?"sekunde":"sekundi";case"m":return t?"jedna minuta":"jedne minute";case"mm":return r+=1===e?"minuta":2===e||3===e||4===e?"minute":"minuta";case"h":return t?"jedan sat":"jednog sata";case"hh":return r+=1===e?"sat":2===e||3===e||4===e?"sata":"sati";case"dd":return r+=1===e?"dan":"dana";case"MM":return r+=1===e?"mjesec":2===e||3===e||4===e?"mjeseca":"mjeseci";case"yy":return r+=1===e?"godina":2===e||3===e||4===e?"godine":"godina"}}e.defineLocale("hr",{months:{format:"siječnja_veljače_ožujka_travnja_svibnja_lipnja_srpnja_kolovoza_rujna_listopada_studenoga_prosinca".split("_"),standalone:"siječanj_veljača_ožujak_travanj_svibanj_lipanj_srpanj_kolovoz_rujan_listopad_studeni_prosinac".split("_")},monthsShort:"sij._velj._ožu._tra._svi._lip._srp._kol._ruj._lis._stu._pro.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"Do MMMM YYYY",LLL:"Do MMMM YYYY H:mm",LLLL:"dddd, Do MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[jučer u] LT",lastWeek:function(){switch(this.day()){case 0:return"[prošlu] [nedjelju] [u] LT";case 3:return"[prošlu] [srijedu] [u] LT";case 6:return"[prošle] [subote] [u] LT";case 1:case 2:case 4:case 5:return"[prošli] dddd [u] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"par sekundi",ss:t,m:t,mm:t,h:t,hh:t,d:"dan",dd:t,M:"mjesec",MM:t,y:"godinu",yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="vasárnap hétfőn kedden szerdán csütörtökön pénteken szombaton".split(" ");function n(e,t,n,r){var i=e;switch(n){case"s":return r||t?"néhány másodperc":"néhány másodperce";case"ss":return i+(r||t)?" másodperc":" másodperce";case"m":return"egy"+(r||t?" perc":" perce");case"mm":return i+(r||t?" perc":" perce");case"h":return"egy"+(r||t?" óra":" órája");case"hh":return i+(r||t?" óra":" órája");case"d":return"egy"+(r||t?" nap":" napja");case"dd":return i+(r||t?" nap":" napja");case"M":return"egy"+(r||t?" hónap":" hónapja");case"MM":return i+(r||t?" hónap":" hónapja");case"y":return"egy"+(r||t?" év":" éve");case"yy":return i+(r||t?" év":" éve")}return""}function r(e){return(e?"":"[múlt] ")+"["+t[this.day()]+"] LT[-kor]"}e.defineLocale("hu",{months:"január_február_március_április_május_június_július_augusztus_szeptember_október_november_december".split("_"),monthsShort:"jan._feb._márc._ápr._máj._jún._júl._aug._szept._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"vasárnap_hétfő_kedd_szerda_csütörtök_péntek_szombat".split("_"),weekdaysShort:"vas_hét_kedd_sze_csüt_pén_szo".split("_"),weekdaysMin:"v_h_k_sze_cs_p_szo".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"YYYY.MM.DD.",LL:"YYYY. MMMM D.",LLL:"YYYY. MMMM D. H:mm",LLLL:"YYYY. MMMM D., dddd H:mm"},meridiemParse:/de|du/i,isPM:function(e){return"u"===e.charAt(1).toLowerCase()},meridiem:function(e,t,n){return e<12?!0===n?"de":"DE":!0===n?"du":"DU"},calendar:{sameDay:"[ma] LT[-kor]",nextDay:"[holnap] LT[-kor]",nextWeek:function(){return r.call(this,!0)},lastDay:"[tegnap] LT[-kor]",lastWeek:function(){return r.call(this,!1)},sameElse:"L"},relativeTime:{future:"%s múlva",past:"%s",s:n,ss:n,m:n,mm:n,h:n,hh:n,d:n,dd:n,M:n,MM:n,y:n,yy:n},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("hy-am",{months:{format:"հունվարի_փետրվարի_մարտի_ապրիլի_մայիսի_հունիսի_հուլիսի_օգոստոսի_սեպտեմբերի_հոկտեմբերի_նոյեմբերի_դեկտեմբերի".split("_"),standalone:"հունվար_փետրվար_մարտ_ապրիլ_մայիս_հունիս_հուլիս_օգոստոս_սեպտեմբեր_հոկտեմբեր_նոյեմբեր_դեկտեմբեր".split("_")},monthsShort:"հնվ_փտր_մրտ_ապր_մյս_հնս_հլս_օգս_սպտ_հկտ_նմբ_դկտ".split("_"),weekdays:"կիրակի_երկուշաբթի_երեքշաբթի_չորեքշաբթի_հինգշաբթի_ուրբաթ_շաբաթ".split("_"),weekdaysShort:"կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ".split("_"),weekdaysMin:"կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY թ.",LLL:"D MMMM YYYY թ., HH:mm",LLLL:"dddd, D MMMM YYYY թ., HH:mm"},calendar:{sameDay:"[այսօր] LT",nextDay:"[վաղը] LT",lastDay:"[երեկ] LT",nextWeek:function(){return"dddd [օրը ժամը] LT"},lastWeek:function(){return"[անցած] dddd [օրը ժամը] LT"},sameElse:"L"},relativeTime:{future:"%s հետո",past:"%s առաջ",s:"մի քանի վայրկյան",ss:"%d վայրկյան",m:"րոպե",mm:"%d րոպե",h:"ժամ",hh:"%d ժամ",d:"օր",dd:"%d օր",M:"ամիս",MM:"%d ամիս",y:"տարի",yy:"%d տարի"},meridiemParse:/գիշերվա|առավոտվա|ցերեկվա|երեկոյան/,isPM:function(e){return/^(ցերեկվա|երեկոյան)$/.test(e)},meridiem:function(e){return e<4?"գիշերվա":e<12?"առավոտվա":e<17?"ցերեկվա":"երեկոյան"},dayOfMonthOrdinalParse:/\d{1,2}|\d{1,2}-(ին|րդ)/,ordinal:function(e,t){switch(t){case"DDD":case"w":case"W":case"DDDo":return 1===e?e+"-ին":e+"-րդ";default:return e}},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("id",{months:"Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_November_Desember".split("_"),monthsShort:"Jan_Feb_Mar_Apr_Mei_Jun_Jul_Agt_Sep_Okt_Nov_Des".split("_"),weekdays:"Minggu_Senin_Selasa_Rabu_Kamis_Jumat_Sabtu".split("_"),weekdaysShort:"Min_Sen_Sel_Rab_Kam_Jum_Sab".split("_"),weekdaysMin:"Mg_Sn_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|siang|sore|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"siang"===t?e>=11?e:e+12:"sore"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,n){return e<11?"pagi":e<15?"siang":e<19?"sore":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Besok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kemarin pukul] LT",lastWeek:"dddd [lalu pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lalu",s:"beberapa detik",ss:"%d detik",m:"semenit",mm:"%d menit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e){return e%100==11||e%10!=1}function n(e,n,r,i){var o=e+" ";switch(r){case"s":return n||i?"nokkrar sekúndur":"nokkrum sekúndum";case"ss":return t(e)?o+(n||i?"sekúndur":"sekúndum"):o+"sekúnda";case"m":return n?"mínúta":"mínútu";case"mm":return t(e)?o+(n||i?"mínútur":"mínútum"):n?o+"mínúta":o+"mínútu";case"hh":return t(e)?o+(n||i?"klukkustundir":"klukkustundum"):o+"klukkustund";case"d":return n?"dagur":i?"dag":"degi";case"dd":return t(e)?n?o+"dagar":o+(i?"daga":"dögum"):n?o+"dagur":o+(i?"dag":"degi");case"M":return n?"mánuður":i?"mánuð":"mánuði";case"MM":return t(e)?n?o+"mánuðir":o+(i?"mánuði":"mánuðum"):n?o+"mánuður":o+(i?"mánuð":"mánuði");case"y":return n||i?"ár":"ári";case"yy":return t(e)?o+(n||i?"ár":"árum"):o+(n||i?"ár":"ári")}}e.defineLocale("is",{months:"janúar_febrúar_mars_apríl_maí_júní_júlí_ágúst_september_október_nóvember_desember".split("_"),monthsShort:"jan_feb_mar_apr_maí_jún_júl_ágú_sep_okt_nóv_des".split("_"),weekdays:"sunnudagur_mánudagur_þriðjudagur_miðvikudagur_fimmtudagur_föstudagur_laugardagur".split("_"),weekdaysShort:"sun_mán_þri_mið_fim_fös_lau".split("_"),weekdaysMin:"Su_Má_Þr_Mi_Fi_Fö_La".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] H:mm",LLLL:"dddd, D. MMMM YYYY [kl.] H:mm"},calendar:{sameDay:"[í dag kl.] LT",nextDay:"[á morgun kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[í gær kl.] LT",lastWeek:"[síðasta] dddd [kl.] LT",sameElse:"L"},relativeTime:{future:"eftir %s",past:"fyrir %s síðan",s:n,ss:n,m:n,mm:n,h:"klukkustund",hh:n,d:n,dd:n,M:n,MM:n,y:n,yy:n},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("it",{months:"gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre".split("_"),monthsShort:"gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic".split("_"),weekdays:"domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato".split("_"),weekdaysShort:"dom_lun_mar_mer_gio_ven_sab".split("_"),weekdaysMin:"do_lu_ma_me_gi_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:function(){return"[Oggi a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextDay:function(){return"[Domani a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextWeek:function(){return"dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastDay:function(){return"[Ieri a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastWeek:function(){switch(this.day()){case 0:return"[La scorsa] dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT";default:return"[Lo scorso] dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"}},sameElse:"L"},relativeTime:{future:"tra %s",past:"%s fa",s:"alcuni secondi",ss:"%d secondi",m:"un minuto",mm:"%d minuti",h:"un'ora",hh:"%d ore",d:"un giorno",dd:"%d giorni",w:"una settimana",ww:"%d settimane",M:"un mese",MM:"%d mesi",y:"un anno",yy:"%d anni"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("it-ch",{months:"gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre".split("_"),monthsShort:"gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic".split("_"),weekdays:"domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato".split("_"),weekdaysShort:"dom_lun_mar_mer_gio_ven_sab".split("_"),weekdaysMin:"do_lu_ma_me_gi_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Oggi alle] LT",nextDay:"[Domani alle] LT",nextWeek:"dddd [alle] LT",lastDay:"[Ieri alle] LT",lastWeek:function(){switch(this.day()){case 0:return"[la scorsa] dddd [alle] LT";default:return"[lo scorso] dddd [alle] LT"}},sameElse:"L"},relativeTime:{future:function(e){return(/^[0-9].+$/.test(e)?"tra":"in")+" "+e},past:"%s fa",s:"alcuni secondi",ss:"%d secondi",m:"un minuto",mm:"%d minuti",h:"un'ora",hh:"%d ore",d:"un giorno",dd:"%d giorni",M:"un mese",MM:"%d mesi",y:"un anno",yy:"%d anni"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ja",{eras:[{since:"2019-05-01",offset:1,name:"令和",narrow:"㋿",abbr:"R"},{since:"1989-01-08",until:"2019-04-30",offset:1,name:"平成",narrow:"㍻",abbr:"H"},{since:"1926-12-25",until:"1989-01-07",offset:1,name:"昭和",narrow:"㍼",abbr:"S"},{since:"1912-07-30",until:"1926-12-24",offset:1,name:"大正",narrow:"㍽",abbr:"T"},{since:"1873-01-01",until:"1912-07-29",offset:6,name:"明治",narrow:"㍾",abbr:"M"},{since:"0001-01-01",until:"1873-12-31",offset:1,name:"西暦",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"紀元前",narrow:"BC",abbr:"BC"}],eraYearOrdinalRegex:/(元|\d+)年/,eraYearOrdinalParse:function(e,t){return"元"===t[1]?1:parseInt(t[1]||e,10)},months:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日".split("_"),weekdaysShort:"日_月_火_水_木_金_土".split("_"),weekdaysMin:"日_月_火_水_木_金_土".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日 dddd HH:mm",l:"YYYY/MM/DD",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日(ddd) HH:mm"},meridiemParse:/午前|午後/i,isPM:function(e){return"午後"===e},meridiem:function(e,t,n){return e<12?"午前":"午後"},calendar:{sameDay:"[今日] LT",nextDay:"[明日] LT",nextWeek:function(e){return e.week()!==this.week()?"[来週]dddd LT":"dddd LT"},lastDay:"[昨日] LT",lastWeek:function(e){return this.week()!==e.week()?"[先週]dddd LT":"dddd LT"},sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}日/,ordinal:function(e,t){switch(t){case"y":return 1===e?"元年":e+"年";case"d":case"D":case"DDD":return e+"日";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"数秒",ss:"%d秒",m:"1分",mm:"%d分",h:"1時間",hh:"%d時間",d:"1日",dd:"%d日",M:"1ヶ月",MM:"%dヶ月",y:"1年",yy:"%d年"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("jv",{months:"Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_Nopember_Desember".split("_"),monthsShort:"Jan_Feb_Mar_Apr_Mei_Jun_Jul_Ags_Sep_Okt_Nop_Des".split("_"),weekdays:"Minggu_Senen_Seloso_Rebu_Kemis_Jemuwah_Septu".split("_"),weekdaysShort:"Min_Sen_Sel_Reb_Kem_Jem_Sep".split("_"),weekdaysMin:"Mg_Sn_Sl_Rb_Km_Jm_Sp".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/enjing|siyang|sonten|ndalu/,meridiemHour:function(e,t){return 12===e&&(e=0),"enjing"===t?e:"siyang"===t?e>=11?e:e+12:"sonten"===t||"ndalu"===t?e+12:void 0},meridiem:function(e,t,n){return e<11?"enjing":e<15?"siyang":e<19?"sonten":"ndalu"},calendar:{sameDay:"[Dinten puniko pukul] LT",nextDay:"[Mbenjang pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kala wingi pukul] LT",lastWeek:"dddd [kepengker pukul] LT",sameElse:"L"},relativeTime:{future:"wonten ing %s",past:"%s ingkang kepengker",s:"sawetawis detik",ss:"%d detik",m:"setunggal menit",mm:"%d menit",h:"setunggal jam",hh:"%d jam",d:"sedinten",dd:"%d dinten",M:"sewulan",MM:"%d wulan",y:"setaun",yy:"%d taun"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ka",{months:"იანვარი_თებერვალი_მარტი_აპრილი_მაისი_ივნისი_ივლისი_აგვისტო_სექტემბერი_ოქტომბერი_ნოემბერი_დეკემბერი".split("_"),monthsShort:"იან_თებ_მარ_აპრ_მაი_ივნ_ივლ_აგვ_სექ_ოქტ_ნოე_დეკ".split("_"),weekdays:{standalone:"კვირა_ორშაბათი_სამშაბათი_ოთხშაბათი_ხუთშაბათი_პარასკევი_შაბათი".split("_"),format:"კვირას_ორშაბათს_სამშაბათს_ოთხშაბათს_ხუთშაბათს_პარასკევს_შაბათს".split("_"),isFormat:/(წინა|შემდეგ)/},weekdaysShort:"კვი_ორშ_სამ_ოთხ_ხუთ_პარ_შაბ".split("_"),weekdaysMin:"კვ_ორ_სა_ოთ_ხუ_პა_შა".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[დღეს] LT[-ზე]",nextDay:"[ხვალ] LT[-ზე]",lastDay:"[გუშინ] LT[-ზე]",nextWeek:"[შემდეგ] dddd LT[-ზე]",lastWeek:"[წინა] dddd LT-ზე",sameElse:"L"},relativeTime:{future:function(e){return e.replace(/(წამ|წუთ|საათ|წელ|დღ|თვ)(ი|ე)/,(function(e,t,n){return"ი"===n?t+"ში":t+n+"ში"}))},past:function(e){return/(წამი|წუთი|საათი|დღე|თვე)/.test(e)?e.replace(/(ი|ე)$/,"ის წინ"):/წელი/.test(e)?e.replace(/წელი$/,"წლის წინ"):e},s:"რამდენიმე წამი",ss:"%d წამი",m:"წუთი",mm:"%d წუთი",h:"საათი",hh:"%d საათი",d:"დღე",dd:"%d დღე",M:"თვე",MM:"%d თვე",y:"წელი",yy:"%d წელი"},dayOfMonthOrdinalParse:/0|1-ლი|მე-\d{1,2}|\d{1,2}-ე/,ordinal:function(e){return 0===e?e:1===e?e+"-ლი":e<20||e<=100&&e%20==0||e%100==0?"მე-"+e:e+"-ე"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={0:"-ші",1:"-ші",2:"-ші",3:"-ші",4:"-ші",5:"-ші",6:"-шы",7:"-ші",8:"-ші",9:"-шы",10:"-шы",20:"-шы",30:"-шы",40:"-шы",50:"-ші",60:"-шы",70:"-ші",80:"-ші",90:"-шы",100:"-ші"};e.defineLocale("kk",{months:"қаңтар_ақпан_наурыз_сәуір_мамыр_маусым_шілде_тамыз_қыркүйек_қазан_қараша_желтоқсан".split("_"),monthsShort:"қаң_ақп_нау_сәу_мам_мау_шіл_там_қыр_қаз_қар_жел".split("_"),weekdays:"жексенбі_дүйсенбі_сейсенбі_сәрсенбі_бейсенбі_жұма_сенбі".split("_"),weekdaysShort:"жек_дүй_сей_сәр_бей_жұм_сен".split("_"),weekdaysMin:"жк_дй_сй_ср_бй_жм_сн".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Бүгін сағат] LT",nextDay:"[Ертең сағат] LT",nextWeek:"dddd [сағат] LT",lastDay:"[Кеше сағат] LT",lastWeek:"[Өткен аптаның] dddd [сағат] LT",sameElse:"L"},relativeTime:{future:"%s ішінде",past:"%s бұрын",s:"бірнеше секунд",ss:"%d секунд",m:"бір минут",mm:"%d минут",h:"бір сағат",hh:"%d сағат",d:"бір күн",dd:"%d күн",M:"бір ай",MM:"%d ай",y:"бір жыл",yy:"%d жыл"},dayOfMonthOrdinalParse:/\d{1,2}-(ші|шы)/,ordinal:function(e){return e+(t[e]||t[e%10]||t[e>=100?100:null])},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"១",2:"២",3:"៣",4:"៤",5:"៥",6:"៦",7:"៧",8:"៨",9:"៩",0:"០"},n={"១":"1","២":"2","៣":"3","៤":"4","៥":"5","៦":"6","៧":"7","៨":"8","៩":"9","០":"0"};e.defineLocale("km",{months:"មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ".split("_"),monthsShort:"មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ".split("_"),weekdays:"អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍".split("_"),weekdaysShort:"អា_ច_អ_ព_ព្រ_សុ_ស".split("_"),weekdaysMin:"អា_ច_អ_ព_ព្រ_សុ_ស".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/ព្រឹក|ល្ងាច/,isPM:function(e){return"ល្ងាច"===e},meridiem:function(e,t,n){return e<12?"ព្រឹក":"ល្ងាច"},calendar:{sameDay:"[ថ្ងៃនេះ ម៉ោង] LT",nextDay:"[ស្អែក ម៉ោង] LT",nextWeek:"dddd [ម៉ោង] LT",lastDay:"[ម្សិលមិញ ម៉ោង] LT",lastWeek:"dddd [សប្តាហ៍មុន] [ម៉ោង] LT",sameElse:"L"},relativeTime:{future:"%sទៀត",past:"%sមុន",s:"ប៉ុន្មានវិនាទី",ss:"%d វិនាទី",m:"មួយនាទី",mm:"%d នាទី",h:"មួយម៉ោង",hh:"%d ម៉ោង",d:"មួយថ្ងៃ",dd:"%d ថ្ងៃ",M:"មួយខែ",MM:"%d ខែ",y:"មួយឆ្នាំ",yy:"%d ឆ្នាំ"},dayOfMonthOrdinalParse:/ទី\d{1,2}/,ordinal:"ទី%d",preparse:function(e){return e.replace(/[១២៣៤៥៦៧៨៩០]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"೧",2:"೨",3:"೩",4:"೪",5:"೫",6:"೬",7:"೭",8:"೮",9:"೯",0:"೦"},n={"೧":"1","೨":"2","೩":"3","೪":"4","೫":"5","೬":"6","೭":"7","೮":"8","೯":"9","೦":"0"};e.defineLocale("kn",{months:"ಜನವರಿ_ಫೆಬ್ರವರಿ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂಬರ್_ಅಕ್ಟೋಬರ್_ನವೆಂಬರ್_ಡಿಸೆಂಬರ್".split("_"),monthsShort:"ಜನ_ಫೆಬ್ರ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂ_ಅಕ್ಟೋ_ನವೆಂ_ಡಿಸೆಂ".split("_"),monthsParseExact:!0,weekdays:"ಭಾನುವಾರ_ಸೋಮವಾರ_ಮಂಗಳವಾರ_ಬುಧವಾರ_ಗುರುವಾರ_ಶುಕ್ರವಾರ_ಶನಿವಾರ".split("_"),weekdaysShort:"ಭಾನು_ಸೋಮ_ಮಂಗಳ_ಬುಧ_ಗುರು_ಶುಕ್ರ_ಶನಿ".split("_"),weekdaysMin:"ಭಾ_ಸೋ_ಮಂ_ಬು_ಗು_ಶು_ಶ".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[ಇಂದು] LT",nextDay:"[ನಾಳೆ] LT",nextWeek:"dddd, LT",lastDay:"[ನಿನ್ನೆ] LT",lastWeek:"[ಕೊನೆಯ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ನಂತರ",past:"%s ಹಿಂದೆ",s:"ಕೆಲವು ಕ್ಷಣಗಳು",ss:"%d ಸೆಕೆಂಡುಗಳು",m:"ಒಂದು ನಿಮಿಷ",mm:"%d ನಿಮಿಷ",h:"ಒಂದು ಗಂಟೆ",hh:"%d ಗಂಟೆ",d:"ಒಂದು ದಿನ",dd:"%d ದಿನ",M:"ಒಂದು ತಿಂಗಳು",MM:"%d ತಿಂಗಳು",y:"ಒಂದು ವರ್ಷ",yy:"%d ವರ್ಷ"},preparse:function(e){return e.replace(/[೧೨೩೪೫೬೭೮೯೦]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/ರಾತ್ರಿ|ಬೆಳಿಗ್ಗೆ|ಮಧ್ಯಾಹ್ನ|ಸಂಜೆ/,meridiemHour:function(e,t){return 12===e&&(e=0),"ರಾತ್ರಿ"===t?e<4?e:e+12:"ಬೆಳಿಗ್ಗೆ"===t?e:"ಮಧ್ಯಾಹ್ನ"===t?e>=10?e:e+12:"ಸಂಜೆ"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"ರಾತ್ರಿ":e<10?"ಬೆಳಿಗ್ಗೆ":e<17?"ಮಧ್ಯಾಹ್ನ":e<20?"ಸಂಜೆ":"ರಾತ್ರಿ"},dayOfMonthOrdinalParse:/\d{1,2}(ನೇ)/,ordinal:function(e){return e+"ನೇ"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ko",{months:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),monthsShort:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),weekdays:"일요일_월요일_화요일_수요일_목요일_금요일_토요일".split("_"),weekdaysShort:"일_월_화_수_목_금_토".split("_"),weekdaysMin:"일_월_화_수_목_금_토".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"YYYY.MM.DD.",LL:"YYYY년 MMMM D일",LLL:"YYYY년 MMMM D일 A h:mm",LLLL:"YYYY년 MMMM D일 dddd A h:mm",l:"YYYY.MM.DD.",ll:"YYYY년 MMMM D일",lll:"YYYY년 MMMM D일 A h:mm",llll:"YYYY년 MMMM D일 dddd A h:mm"},calendar:{sameDay:"오늘 LT",nextDay:"내일 LT",nextWeek:"dddd LT",lastDay:"어제 LT",lastWeek:"지난주 dddd LT",sameElse:"L"},relativeTime:{future:"%s 후",past:"%s 전",s:"몇 초",ss:"%d초",m:"1분",mm:"%d분",h:"한 시간",hh:"%d시간",d:"하루",dd:"%d일",M:"한 달",MM:"%d달",y:"일 년",yy:"%d년"},dayOfMonthOrdinalParse:/\d{1,2}(일|월|주)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"일";case"M":return e+"월";case"w":case"W":return e+"주";default:return e}},meridiemParse:/오전|오후/,isPM:function(e){return"오후"===e},meridiem:function(e,t,n){return e<12?"오전":"오후"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"},n={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},r=["کانونی دووەم","شوبات","ئازار","نیسان","ئایار","حوزەیران","تەمموز","ئاب","ئەیلوول","تشرینی یەكەم","تشرینی دووەم","كانونی یەکەم"];e.defineLocale("ku",{months:r,monthsShort:r,weekdays:"یه‌كشه‌ممه‌_دووشه‌ممه‌_سێشه‌ممه‌_چوارشه‌ممه‌_پێنجشه‌ممه‌_هه‌ینی_شه‌ممه‌".split("_"),weekdaysShort:"یه‌كشه‌م_دووشه‌م_سێشه‌م_چوارشه‌م_پێنجشه‌م_هه‌ینی_شه‌ممه‌".split("_"),weekdaysMin:"ی_د_س_چ_پ_ه_ش".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/ئێواره‌|به‌یانی/,isPM:function(e){return/ئێواره‌/.test(e)},meridiem:function(e,t,n){return e<12?"به‌یانی":"ئێواره‌"},calendar:{sameDay:"[ئه‌مرۆ كاتژمێر] LT",nextDay:"[به‌یانی كاتژمێر] LT",nextWeek:"dddd [كاتژمێر] LT",lastDay:"[دوێنێ كاتژمێر] LT",lastWeek:"dddd [كاتژمێر] LT",sameElse:"L"},relativeTime:{future:"له‌ %s",past:"%s",s:"چه‌ند چركه‌یه‌ك",ss:"چركه‌ %d",m:"یه‌ك خوله‌ك",mm:"%d خوله‌ك",h:"یه‌ك كاتژمێر",hh:"%d كاتژمێر",d:"یه‌ك ڕۆژ",dd:"%d ڕۆژ",M:"یه‌ك مانگ",MM:"%d مانگ",y:"یه‌ك ساڵ",yy:"%d ساڵ"},preparse:function(e){return e.replace(/[١٢٣٤٥٦٧٨٩٠]/g,(function(e){return n[e]})).replace(/،/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={0:"-чү",1:"-чи",2:"-чи",3:"-чү",4:"-чү",5:"-чи",6:"-чы",7:"-чи",8:"-чи",9:"-чу",10:"-чу",20:"-чы",30:"-чу",40:"-чы",50:"-чү",60:"-чы",70:"-чи",80:"-чи",90:"-чу",100:"-чү"};e.defineLocale("ky",{months:"январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь".split("_"),monthsShort:"янв_фев_март_апр_май_июнь_июль_авг_сен_окт_ноя_дек".split("_"),weekdays:"Жекшемби_Дүйшөмбү_Шейшемби_Шаршемби_Бейшемби_Жума_Ишемби".split("_"),weekdaysShort:"Жек_Дүй_Шей_Шар_Бей_Жум_Ише".split("_"),weekdaysMin:"Жк_Дй_Шй_Шр_Бй_Жм_Иш".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Бүгүн саат] LT",nextDay:"[Эртең саат] LT",nextWeek:"dddd [саат] LT",lastDay:"[Кечээ саат] LT",lastWeek:"[Өткөн аптанын] dddd [күнү] [саат] LT",sameElse:"L"},relativeTime:{future:"%s ичинде",past:"%s мурун",s:"бирнече секунд",ss:"%d секунд",m:"бир мүнөт",mm:"%d мүнөт",h:"бир саат",hh:"%d саат",d:"бир күн",dd:"%d күн",M:"бир ай",MM:"%d ай",y:"бир жыл",yy:"%d жыл"},dayOfMonthOrdinalParse:/\d{1,2}-(чи|чы|чү|чу)/,ordinal:function(e){return e+(t[e]||t[e%10]||t[e>=100?100:null])},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={m:["eng Minutt","enger Minutt"],h:["eng Stonn","enger Stonn"],d:["een Dag","engem Dag"],M:["ee Mount","engem Mount"],y:["ee Joer","engem Joer"]};return t?i[n][0]:i[n][1]}function n(e){if(e=parseInt(e,10),isNaN(e))return!1;if(e<0)return!0;if(e<10)return 4<=e&&e<=7;if(e<100){var t=e%10;return n(0===t?e/10:t)}if(e<1e4){for(;e>=10;)e/=10;return n(e)}return n(e/=1e3)}e.defineLocale("lb",{months:"Januar_Februar_Mäerz_Abrëll_Mee_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Febr._Mrz._Abr._Mee_Jun._Jul._Aug._Sept._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonndeg_Méindeg_Dënschdeg_Mëttwoch_Donneschdeg_Freideg_Samschdeg".split("_"),weekdaysShort:"So._Mé._Dë._Më._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mé_Dë_Më_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm [Auer]",LTS:"H:mm:ss [Auer]",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm [Auer]",LLLL:"dddd, D. MMMM YYYY H:mm [Auer]"},calendar:{sameDay:"[Haut um] LT",sameElse:"L",nextDay:"[Muer um] LT",nextWeek:"dddd [um] LT",lastDay:"[Gëschter um] LT",lastWeek:function(){switch(this.day()){case 2:case 4:return"[Leschten] dddd [um] LT";default:return"[Leschte] dddd [um] LT"}}},relativeTime:{future:function(e){return n(e.substr(0,e.indexOf(" ")))?"a "+e:"an "+e},past:function(e){return n(e.substr(0,e.indexOf(" ")))?"viru "+e:"virun "+e},s:"e puer Sekonnen",ss:"%d Sekonnen",m:t,mm:"%d Minutten",h:t,hh:"%d Stonnen",d:t,dd:"%d Deeg",M:t,MM:"%d Méint",y:t,yy:"%d Joer"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("lo",{months:"ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ".split("_"),monthsShort:"ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ".split("_"),weekdays:"ອາທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ".split("_"),weekdaysShort:"ທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ".split("_"),weekdaysMin:"ທ_ຈ_ອຄ_ພ_ພຫ_ສກ_ສ".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"ວັນdddd D MMMM YYYY HH:mm"},meridiemParse:/ຕອນເຊົ້າ|ຕອນແລງ/,isPM:function(e){return"ຕອນແລງ"===e},meridiem:function(e,t,n){return e<12?"ຕອນເຊົ້າ":"ຕອນແລງ"},calendar:{sameDay:"[ມື້ນີ້ເວລາ] LT",nextDay:"[ມື້ອື່ນເວລາ] LT",nextWeek:"[ວັນ]dddd[ໜ້າເວລາ] LT",lastDay:"[ມື້ວານນີ້ເວລາ] LT",lastWeek:"[ວັນ]dddd[ແລ້ວນີ້ເວລາ] LT",sameElse:"L"},relativeTime:{future:"ອີກ %s",past:"%sຜ່ານມາ",s:"ບໍ່ເທົ່າໃດວິນາທີ",ss:"%d ວິນາທີ",m:"1 ນາທີ",mm:"%d ນາທີ",h:"1 ຊົ່ວໂມງ",hh:"%d ຊົ່ວໂມງ",d:"1 ມື້",dd:"%d ມື້",M:"1 ເດືອນ",MM:"%d ເດືອນ",y:"1 ປີ",yy:"%d ປີ"},dayOfMonthOrdinalParse:/(ທີ່)\d{1,2}/,ordinal:function(e){return"ທີ່"+e}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={ss:"sekundė_sekundžių_sekundes",m:"minutė_minutės_minutę",mm:"minutės_minučių_minutes",h:"valanda_valandos_valandą",hh:"valandos_valandų_valandas",d:"diena_dienos_dieną",dd:"dienos_dienų_dienas",M:"mėnuo_mėnesio_mėnesį",MM:"mėnesiai_mėnesių_mėnesius",y:"metai_metų_metus",yy:"metai_metų_metus"};function n(e,t,n,r){return t?i(n)[0]:r?i(n)[1]:i(n)[2]}function r(e){return e%10==0||e>10&&e<20}function i(e){return t[e].split("_")}function o(e,t,o,a){var s=e+" ";return 1===e?s+n(0,t,o[0],a):t?s+(r(e)?i(o)[1]:i(o)[0]):a?s+i(o)[1]:s+(r(e)?i(o)[1]:i(o)[2])}e.defineLocale("lt",{months:{format:"sausio_vasario_kovo_balandžio_gegužės_birželio_liepos_rugpjūčio_rugsėjo_spalio_lapkričio_gruodžio".split("_"),standalone:"sausis_vasaris_kovas_balandis_gegužė_birželis_liepa_rugpjūtis_rugsėjis_spalis_lapkritis_gruodis".split("_"),isFormat:/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?|MMMM?(\[[^\[\]]*\]|\s)+D[oD]?/},monthsShort:"sau_vas_kov_bal_geg_bir_lie_rgp_rgs_spa_lap_grd".split("_"),weekdays:{format:"sekmadienį_pirmadienį_antradienį_trečiadienį_ketvirtadienį_penktadienį_šeštadienį".split("_"),standalone:"sekmadienis_pirmadienis_antradienis_trečiadienis_ketvirtadienis_penktadienis_šeštadienis".split("_"),isFormat:/dddd HH:mm/},weekdaysShort:"Sek_Pir_Ant_Tre_Ket_Pen_Šeš".split("_"),weekdaysMin:"S_P_A_T_K_Pn_Š".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY [m.] MMMM D [d.]",LLL:"YYYY [m.] MMMM D [d.], HH:mm [val.]",LLLL:"YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]",l:"YYYY-MM-DD",ll:"YYYY [m.] MMMM D [d.]",lll:"YYYY [m.] MMMM D [d.], HH:mm [val.]",llll:"YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]"},calendar:{sameDay:"[Šiandien] LT",nextDay:"[Rytoj] LT",nextWeek:"dddd LT",lastDay:"[Vakar] LT",lastWeek:"[Praėjusį] dddd LT",sameElse:"L"},relativeTime:{future:"po %s",past:"prieš %s",s:function(e,t,n,r){return t?"kelios sekundės":r?"kelių sekundžių":"kelias sekundes"},ss:o,m:n,mm:o,h:n,hh:o,d:n,dd:o,M:n,MM:o,y:n,yy:o},dayOfMonthOrdinalParse:/\d{1,2}-oji/,ordinal:function(e){return e+"-oji"},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={ss:"sekundes_sekundēm_sekunde_sekundes".split("_"),m:"minūtes_minūtēm_minūte_minūtes".split("_"),mm:"minūtes_minūtēm_minūte_minūtes".split("_"),h:"stundas_stundām_stunda_stundas".split("_"),hh:"stundas_stundām_stunda_stundas".split("_"),d:"dienas_dienām_diena_dienas".split("_"),dd:"dienas_dienām_diena_dienas".split("_"),M:"mēneša_mēnešiem_mēnesis_mēneši".split("_"),MM:"mēneša_mēnešiem_mēnesis_mēneši".split("_"),y:"gada_gadiem_gads_gadi".split("_"),yy:"gada_gadiem_gads_gadi".split("_")};function n(e,t,n){return n?t%10==1&&t%100!=11?e[2]:e[3]:t%10==1&&t%100!=11?e[0]:e[1]}function r(e,r,i){return e+" "+n(t[i],e,r)}function i(e,r,i){return n(t[i],e,r)}e.defineLocale("lv",{months:"janvāris_februāris_marts_aprīlis_maijs_jūnijs_jūlijs_augusts_septembris_oktobris_novembris_decembris".split("_"),monthsShort:"jan_feb_mar_apr_mai_jūn_jūl_aug_sep_okt_nov_dec".split("_"),weekdays:"svētdiena_pirmdiena_otrdiena_trešdiena_ceturtdiena_piektdiena_sestdiena".split("_"),weekdaysShort:"Sv_P_O_T_C_Pk_S".split("_"),weekdaysMin:"Sv_P_O_T_C_Pk_S".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY.",LL:"YYYY. [gada] D. MMMM",LLL:"YYYY. [gada] D. MMMM, HH:mm",LLLL:"YYYY. [gada] D. MMMM, dddd, HH:mm"},calendar:{sameDay:"[Šodien pulksten] LT",nextDay:"[Rīt pulksten] LT",nextWeek:"dddd [pulksten] LT",lastDay:"[Vakar pulksten] LT",lastWeek:"[Pagājušā] dddd [pulksten] LT",sameElse:"L"},relativeTime:{future:"pēc %s",past:"pirms %s",s:function(e,t){return t?"dažas sekundes":"dažām sekundēm"},ss:r,m:i,mm:r,h:i,hh:r,d:i,dd:r,M:i,MM:r,y:i,yy:r},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={words:{ss:["sekund","sekunda","sekundi"],m:["jedan minut","jednog minuta"],mm:["minut","minuta","minuta"],h:["jedan sat","jednog sata"],hh:["sat","sata","sati"],dd:["dan","dana","dana"],MM:["mjesec","mjeseca","mjeseci"],yy:["godina","godine","godina"]},correctGrammaticalCase:function(e,t){return 1===e?t[0]:e>=2&&e<=4?t[1]:t[2]},translate:function(e,n,r){var i=t.words[r];return 1===r.length?n?i[0]:i[1]:e+" "+t.correctGrammaticalCase(e,i)}};e.defineLocale("me",{months:"januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sjutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[juče u] LT",lastWeek:function(){return["[prošle] [nedjelje] [u] LT","[prošlog] [ponedjeljka] [u] LT","[prošlog] [utorka] [u] LT","[prošle] [srijede] [u] LT","[prošlog] [četvrtka] [u] LT","[prošlog] [petka] [u] LT","[prošle] [subote] [u] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"nekoliko sekundi",ss:t.translate,m:t.translate,mm:t.translate,h:t.translate,hh:t.translate,d:"dan",dd:t.translate,M:"mjesec",MM:t.translate,y:"godinu",yy:t.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("mi",{months:"Kohi-tāte_Hui-tanguru_Poutū-te-rangi_Paenga-whāwhā_Haratua_Pipiri_Hōngoingoi_Here-turi-kōkā_Mahuru_Whiringa-ā-nuku_Whiringa-ā-rangi_Hakihea".split("_"),monthsShort:"Kohi_Hui_Pou_Pae_Hara_Pipi_Hōngoi_Here_Mahu_Whi-nu_Whi-ra_Haki".split("_"),monthsRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsStrictRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsShortRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsShortStrictRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,2}/i,weekdays:"Rātapu_Mane_Tūrei_Wenerei_Tāite_Paraire_Hātarei".split("_"),weekdaysShort:"Ta_Ma_Tū_We_Tāi_Pa_Hā".split("_"),weekdaysMin:"Ta_Ma_Tū_We_Tāi_Pa_Hā".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [i] HH:mm",LLLL:"dddd, D MMMM YYYY [i] HH:mm"},calendar:{sameDay:"[i teie mahana, i] LT",nextDay:"[apopo i] LT",nextWeek:"dddd [i] LT",lastDay:"[inanahi i] LT",lastWeek:"dddd [whakamutunga i] LT",sameElse:"L"},relativeTime:{future:"i roto i %s",past:"%s i mua",s:"te hēkona ruarua",ss:"%d hēkona",m:"he meneti",mm:"%d meneti",h:"te haora",hh:"%d haora",d:"he ra",dd:"%d ra",M:"he marama",MM:"%d marama",y:"he tau",yy:"%d tau"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("mk",{months:"јануари_февруари_март_април_мај_јуни_јули_август_септември_октомври_ноември_декември".split("_"),monthsShort:"јан_фев_мар_апр_мај_јун_јул_авг_сеп_окт_ное_дек".split("_"),weekdays:"недела_понеделник_вторник_среда_четврток_петок_сабота".split("_"),weekdaysShort:"нед_пон_вто_сре_чет_пет_саб".split("_"),weekdaysMin:"нe_пo_вт_ср_че_пе_сa".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[Денес во] LT",nextDay:"[Утре во] LT",nextWeek:"[Во] dddd [во] LT",lastDay:"[Вчера во] LT",lastWeek:function(){switch(this.day()){case 0:case 3:case 6:return"[Изминатата] dddd [во] LT";case 1:case 2:case 4:case 5:return"[Изминатиот] dddd [во] LT"}},sameElse:"L"},relativeTime:{future:"за %s",past:"пред %s",s:"неколку секунди",ss:"%d секунди",m:"една минута",mm:"%d минути",h:"еден час",hh:"%d часа",d:"еден ден",dd:"%d дена",M:"еден месец",MM:"%d месеци",y:"една година",yy:"%d години"},dayOfMonthOrdinalParse:/\d{1,2}-(ев|ен|ти|ви|ри|ми)/,ordinal:function(e){var t=e%10,n=e%100;return 0===e?e+"-ев":0===n?e+"-ен":n>10&&n<20?e+"-ти":1===t?e+"-ви":2===t?e+"-ри":7===t||8===t?e+"-ми":e+"-ти"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ml",{months:"ജനുവരി_ഫെബ്രുവരി_മാർച്ച്_ഏപ്രിൽ_മേയ്_ജൂൺ_ജൂലൈ_ഓഗസ്റ്റ്_സെപ്റ്റംബർ_ഒക്ടോബർ_നവംബർ_ഡിസംബർ".split("_"),monthsShort:"ജനു._ഫെബ്രു._മാർ._ഏപ്രി._മേയ്_ജൂൺ_ജൂലൈ._ഓഗ._സെപ്റ്റ._ഒക്ടോ._നവം._ഡിസം.".split("_"),monthsParseExact:!0,weekdays:"ഞായറാഴ്ച_തിങ്കളാഴ്ച_ചൊവ്വാഴ്ച_ബുധനാഴ്ച_വ്യാഴാഴ്ച_വെള്ളിയാഴ്ച_ശനിയാഴ്ച".split("_"),weekdaysShort:"ഞായർ_തിങ്കൾ_ചൊവ്വ_ബുധൻ_വ്യാഴം_വെള്ളി_ശനി".split("_"),weekdaysMin:"ഞാ_തി_ചൊ_ബു_വ്യാ_വെ_ശ".split("_"),longDateFormat:{LT:"A h:mm -നു",LTS:"A h:mm:ss -നു",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm -നു",LLLL:"dddd, D MMMM YYYY, A h:mm -നു"},calendar:{sameDay:"[ഇന്ന്] LT",nextDay:"[നാളെ] LT",nextWeek:"dddd, LT",lastDay:"[ഇന്നലെ] LT",lastWeek:"[കഴിഞ്ഞ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s കഴിഞ്ഞ്",past:"%s മുൻപ്",s:"അൽപ നിമിഷങ്ങൾ",ss:"%d സെക്കൻഡ്",m:"ഒരു മിനിറ്റ്",mm:"%d മിനിറ്റ്",h:"ഒരു മണിക്കൂർ",hh:"%d മണിക്കൂർ",d:"ഒരു ദിവസം",dd:"%d ദിവസം",M:"ഒരു മാസം",MM:"%d മാസം",y:"ഒരു വർഷം",yy:"%d വർഷം"},meridiemParse:/രാത്രി|രാവിലെ|ഉച്ച കഴിഞ്ഞ്|വൈകുന്നേരം|രാത്രി/i,meridiemHour:function(e,t){return 12===e&&(e=0),"രാത്രി"===t&&e>=4||"ഉച്ച കഴിഞ്ഞ്"===t||"വൈകുന്നേരം"===t?e+12:e},meridiem:function(e,t,n){return e<4?"രാത്രി":e<12?"രാവിലെ":e<17?"ഉച്ച കഴിഞ്ഞ്":e<20?"വൈകുന്നേരം":"രാത്രി"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){switch(n){case"s":return t?"хэдхэн секунд":"хэдхэн секундын";case"ss":return e+(t?" секунд":" секундын");case"m":case"mm":return e+(t?" минут":" минутын");case"h":case"hh":return e+(t?" цаг":" цагийн");case"d":case"dd":return e+(t?" өдөр":" өдрийн");case"M":case"MM":return e+(t?" сар":" сарын");case"y":case"yy":return e+(t?" жил":" жилийн");default:return e}}e.defineLocale("mn",{months:"Нэгдүгээр сар_Хоёрдугаар сар_Гуравдугаар сар_Дөрөвдүгээр сар_Тавдугаар сар_Зургадугаар сар_Долдугаар сар_Наймдугаар сар_Есдүгээр сар_Аравдугаар сар_Арван нэгдүгээр сар_Арван хоёрдугаар сар".split("_"),monthsShort:"1 сар_2 сар_3 сар_4 сар_5 сар_6 сар_7 сар_8 сар_9 сар_10 сар_11 сар_12 сар".split("_"),monthsParseExact:!0,weekdays:"Ням_Даваа_Мягмар_Лхагва_Пүрэв_Баасан_Бямба".split("_"),weekdaysShort:"Ням_Дав_Мяг_Лха_Пүр_Баа_Бям".split("_"),weekdaysMin:"Ня_Да_Мя_Лх_Пү_Ба_Бя".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY оны MMMMын D",LLL:"YYYY оны MMMMын D HH:mm",LLLL:"dddd, YYYY оны MMMMын D HH:mm"},meridiemParse:/ҮӨ|ҮХ/i,isPM:function(e){return"ҮХ"===e},meridiem:function(e,t,n){return e<12?"ҮӨ":"ҮХ"},calendar:{sameDay:"[Өнөөдөр] LT",nextDay:"[Маргааш] LT",nextWeek:"[Ирэх] dddd LT",lastDay:"[Өчигдөр] LT",lastWeek:"[Өнгөрсөн] dddd LT",sameElse:"L"},relativeTime:{future:"%s дараа",past:"%s өмнө",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:t,M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2} өдөр/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+" өдөр";default:return e}}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"},n={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"};function r(e,t,n,r){var i="";if(t)switch(n){case"s":i="काही सेकंद";break;case"ss":i="%d सेकंद";break;case"m":i="एक मिनिट";break;case"mm":i="%d मिनिटे";break;case"h":i="एक तास";break;case"hh":i="%d तास";break;case"d":i="एक दिवस";break;case"dd":i="%d दिवस";break;case"M":i="एक महिना";break;case"MM":i="%d महिने";break;case"y":i="एक वर्ष";break;case"yy":i="%d वर्षे"}else switch(n){case"s":i="काही सेकंदां";break;case"ss":i="%d सेकंदां";break;case"m":i="एका मिनिटा";break;case"mm":i="%d मिनिटां";break;case"h":i="एका तासा";break;case"hh":i="%d तासां";break;case"d":i="एका दिवसा";break;case"dd":i="%d दिवसां";break;case"M":i="एका महिन्या";break;case"MM":i="%d महिन्यां";break;case"y":i="एका वर्षा";break;case"yy":i="%d वर्षां"}return i.replace(/%d/i,e)}e.defineLocale("mr",{months:"जानेवारी_फेब्रुवारी_मार्च_एप्रिल_मे_जून_जुलै_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर".split("_"),monthsShort:"जाने._फेब्रु._मार्च._एप्रि._मे._जून._जुलै._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.".split("_"),monthsParseExact:!0,weekdays:"रविवार_सोमवार_मंगळवार_बुधवार_गुरूवार_शुक्रवार_शनिवार".split("_"),weekdaysShort:"रवि_सोम_मंगळ_बुध_गुरू_शुक्र_शनि".split("_"),weekdaysMin:"र_सो_मं_बु_गु_शु_श".split("_"),longDateFormat:{LT:"A h:mm वाजता",LTS:"A h:mm:ss वाजता",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm वाजता",LLLL:"dddd, D MMMM YYYY, A h:mm वाजता"},calendar:{sameDay:"[आज] LT",nextDay:"[उद्या] LT",nextWeek:"dddd, LT",lastDay:"[काल] LT",lastWeek:"[मागील] dddd, LT",sameElse:"L"},relativeTime:{future:"%sमध्ये",past:"%sपूर्वी",s:r,ss:r,m:r,mm:r,h:r,hh:r,d:r,dd:r,M:r,MM:r,y:r,yy:r},preparse:function(e){return e.replace(/[१२३४५६७८९०]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/पहाटे|सकाळी|दुपारी|सायंकाळी|रात्री/,meridiemHour:function(e,t){return 12===e&&(e=0),"पहाटे"===t||"सकाळी"===t?e:"दुपारी"===t||"सायंकाळी"===t||"रात्री"===t?e>=12?e:e+12:void 0},meridiem:function(e,t,n){return e>=0&&e<6?"पहाटे":e<12?"सकाळी":e<17?"दुपारी":e<20?"सायंकाळी":"रात्री"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ms",{months:"Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis".split("_"),weekdays:"Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu".split("_"),weekdaysShort:"Ahd_Isn_Sel_Rab_Kha_Jum_Sab".split("_"),weekdaysMin:"Ah_Is_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|tengahari|petang|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"tengahari"===t?e>=11?e:e+12:"petang"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,n){return e<11?"pagi":e<15?"tengahari":e<19?"petang":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Esok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kelmarin pukul] LT",lastWeek:"dddd [lepas pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lepas",s:"beberapa saat",ss:"%d saat",m:"seminit",mm:"%d minit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ms-my",{months:"Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis".split("_"),weekdays:"Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu".split("_"),weekdaysShort:"Ahd_Isn_Sel_Rab_Kha_Jum_Sab".split("_"),weekdaysMin:"Ah_Is_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|tengahari|petang|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"tengahari"===t?e>=11?e:e+12:"petang"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,n){return e<11?"pagi":e<15?"tengahari":e<19?"petang":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Esok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kelmarin pukul] LT",lastWeek:"dddd [lepas pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lepas",s:"beberapa saat",ss:"%d saat",m:"seminit",mm:"%d minit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("mt",{months:"Jannar_Frar_Marzu_April_Mejju_Ġunju_Lulju_Awwissu_Settembru_Ottubru_Novembru_Diċembru".split("_"),monthsShort:"Jan_Fra_Mar_Apr_Mej_Ġun_Lul_Aww_Set_Ott_Nov_Diċ".split("_"),weekdays:"Il-Ħadd_It-Tnejn_It-Tlieta_L-Erbgħa_Il-Ħamis_Il-Ġimgħa_Is-Sibt".split("_"),weekdaysShort:"Ħad_Tne_Tli_Erb_Ħam_Ġim_Sib".split("_"),weekdaysMin:"Ħa_Tn_Tl_Er_Ħa_Ġi_Si".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Illum fil-]LT",nextDay:"[Għada fil-]LT",nextWeek:"dddd [fil-]LT",lastDay:"[Il-bieraħ fil-]LT",lastWeek:"dddd [li għadda] [fil-]LT",sameElse:"L"},relativeTime:{future:"f’ %s",past:"%s ilu",s:"ftit sekondi",ss:"%d sekondi",m:"minuta",mm:"%d minuti",h:"siegħa",hh:"%d siegħat",d:"ġurnata",dd:"%d ġranet",M:"xahar",MM:"%d xhur",y:"sena",yy:"%d sni"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"၁",2:"၂",3:"၃",4:"၄",5:"၅",6:"၆",7:"၇",8:"၈",9:"၉",0:"၀"},n={"၁":"1","၂":"2","၃":"3","၄":"4","၅":"5","၆":"6","၇":"7","၈":"8","၉":"9","၀":"0"};e.defineLocale("my",{months:"ဇန်နဝါရီ_ဖေဖော်ဝါရီ_မတ်_ဧပြီ_မေ_ဇွန်_ဇူလိုင်_သြဂုတ်_စက်တင်ဘာ_အောက်တိုဘာ_နိုဝင်ဘာ_ဒီဇင်ဘာ".split("_"),monthsShort:"ဇန်_ဖေ_မတ်_ပြီ_မေ_ဇွန်_လိုင်_သြ_စက်_အောက်_နို_ဒီ".split("_"),weekdays:"တနင်္ဂနွေ_တနင်္လာ_အင်္ဂါ_ဗုဒ္ဓဟူး_ကြာသပတေး_သောကြာ_စနေ".split("_"),weekdaysShort:"နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ".split("_"),weekdaysMin:"နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[ယနေ.] LT [မှာ]",nextDay:"[မနက်ဖြန်] LT [မှာ]",nextWeek:"dddd LT [မှာ]",lastDay:"[မနေ.က] LT [မှာ]",lastWeek:"[ပြီးခဲ့သော] dddd LT [မှာ]",sameElse:"L"},relativeTime:{future:"လာမည့် %s မှာ",past:"လွန်ခဲ့သော %s က",s:"စက္ကန်.အနည်းငယ်",ss:"%d စက္ကန့်",m:"တစ်မိနစ်",mm:"%d မိနစ်",h:"တစ်နာရီ",hh:"%d နာရီ",d:"တစ်ရက်",dd:"%d ရက်",M:"တစ်လ",MM:"%d လ",y:"တစ်နှစ်",yy:"%d နှစ်"},preparse:function(e){return e.replace(/[၁၂၃၄၅၆၇၈၉၀]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("nb",{months:"januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.".split("_"),monthsParseExact:!0,weekdays:"søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag".split("_"),weekdaysShort:"sø._ma._ti._on._to._fr._lø.".split("_"),weekdaysMin:"sø_ma_ti_on_to_fr_lø".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] HH:mm",LLLL:"dddd D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[i dag kl.] LT",nextDay:"[i morgen kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[i går kl.] LT",lastWeek:"[forrige] dddd [kl.] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s siden",s:"noen sekunder",ss:"%d sekunder",m:"ett minutt",mm:"%d minutter",h:"en time",hh:"%d timer",d:"en dag",dd:"%d dager",w:"en uke",ww:"%d uker",M:"en måned",MM:"%d måneder",y:"ett år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"},n={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"};e.defineLocale("ne",{months:"जनवरी_फेब्रुवरी_मार्च_अप्रिल_मई_जुन_जुलाई_अगष्ट_सेप्टेम्बर_अक्टोबर_नोभेम्बर_डिसेम्बर".split("_"),monthsShort:"जन._फेब्रु._मार्च_अप्रि._मई_जुन_जुलाई._अग._सेप्ट._अक्टो._नोभे._डिसे.".split("_"),monthsParseExact:!0,weekdays:"आइतबार_सोमबार_मङ्गलबार_बुधबार_बिहिबार_शुक्रबार_शनिबार".split("_"),weekdaysShort:"आइत._सोम._मङ्गल._बुध._बिहि._शुक्र._शनि.".split("_"),weekdaysMin:"आ._सो._मं._बु._बि._शु._श.".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"Aको h:mm बजे",LTS:"Aको h:mm:ss बजे",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, Aको h:mm बजे",LLLL:"dddd, D MMMM YYYY, Aको h:mm बजे"},preparse:function(e){return e.replace(/[१२३४५६७८९०]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/राति|बिहान|दिउँसो|साँझ/,meridiemHour:function(e,t){return 12===e&&(e=0),"राति"===t?e<4?e:e+12:"बिहान"===t?e:"दिउँसो"===t?e>=10?e:e+12:"साँझ"===t?e+12:void 0},meridiem:function(e,t,n){return e<3?"राति":e<12?"बिहान":e<16?"दिउँसो":e<20?"साँझ":"राति"},calendar:{sameDay:"[आज] LT",nextDay:"[भोलि] LT",nextWeek:"[आउँदो] dddd[,] LT",lastDay:"[हिजो] LT",lastWeek:"[गएको] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%sमा",past:"%s अगाडि",s:"केही क्षण",ss:"%d सेकेण्ड",m:"एक मिनेट",mm:"%d मिनेट",h:"एक घण्टा",hh:"%d घण्टा",d:"एक दिन",dd:"%d दिन",M:"एक महिना",MM:"%d महिना",y:"एक बर्ष",yy:"%d बर्ष"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.".split("_"),n="jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),r=[/^jan/i,/^feb/i,/^maart|mrt.?$/i,/^apr/i,/^mei$/i,/^jun[i.]?$/i,/^jul[i.]?$/i,/^aug/i,/^sep/i,/^okt/i,/^nov/i,/^dec/i],i=/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i;e.defineLocale("nl",{months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,monthsShortStrictRegex:/^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[vandaag om] LT",nextDay:"[morgen om] LT",nextWeek:"dddd [om] LT",lastDay:"[gisteren om] LT",lastWeek:"[afgelopen] dddd [om] LT",sameElse:"L"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",ss:"%d seconden",m:"één minuut",mm:"%d minuten",h:"één uur",hh:"%d uur",d:"één dag",dd:"%d dagen",w:"één week",ww:"%d weken",M:"één maand",MM:"%d maanden",y:"één jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||e>=20?"ste":"de")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.".split("_"),n="jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),r=[/^jan/i,/^feb/i,/^maart|mrt.?$/i,/^apr/i,/^mei$/i,/^jun[i.]?$/i,/^jul[i.]?$/i,/^aug/i,/^sep/i,/^okt/i,/^nov/i,/^dec/i],i=/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i;e.defineLocale("nl-be",{months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:function(e,r){return e?/-MMM-/.test(r)?n[e.month()]:t[e.month()]:t},monthsRegex:i,monthsShortRegex:i,monthsStrictRegex:/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,monthsShortStrictRegex:/^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[vandaag om] LT",nextDay:"[morgen om] LT",nextWeek:"dddd [om] LT",lastDay:"[gisteren om] LT",lastWeek:"[afgelopen] dddd [om] LT",sameElse:"L"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",ss:"%d seconden",m:"één minuut",mm:"%d minuten",h:"één uur",hh:"%d uur",d:"één dag",dd:"%d dagen",M:"één maand",MM:"%d maanden",y:"één jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||e>=20?"ste":"de")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("nn",{months:"januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.".split("_"),monthsParseExact:!0,weekdays:"sundag_måndag_tysdag_onsdag_torsdag_fredag_laurdag".split("_"),weekdaysShort:"su._må._ty._on._to._fr._lau.".split("_"),weekdaysMin:"su_må_ty_on_to_fr_la".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] H:mm",LLLL:"dddd D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[I dag klokka] LT",nextDay:"[I morgon klokka] LT",nextWeek:"dddd [klokka] LT",lastDay:"[I går klokka] LT",lastWeek:"[Føregåande] dddd [klokka] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s sidan",s:"nokre sekund",ss:"%d sekund",m:"eit minutt",mm:"%d minutt",h:"ein time",hh:"%d timar",d:"ein dag",dd:"%d dagar",w:"ei veke",ww:"%d veker",M:"ein månad",MM:"%d månader",y:"eit år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("oc-lnc",{months:{standalone:"genièr_febrièr_març_abril_mai_junh_julhet_agost_setembre_octòbre_novembre_decembre".split("_"),format:"de genièr_de febrièr_de març_d'abril_de mai_de junh_de julhet_d'agost_de setembre_d'octòbre_de novembre_de decembre".split("_"),isFormat:/D[oD]?(\s)+MMMM/},monthsShort:"gen._febr._març_abr._mai_junh_julh._ago._set._oct._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"dimenge_diluns_dimars_dimècres_dijòus_divendres_dissabte".split("_"),weekdaysShort:"dg._dl._dm._dc._dj._dv._ds.".split("_"),weekdaysMin:"dg_dl_dm_dc_dj_dv_ds".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [de] YYYY",ll:"D MMM YYYY",LLL:"D MMMM [de] YYYY [a] H:mm",lll:"D MMM YYYY, H:mm",LLLL:"dddd D MMMM [de] YYYY [a] H:mm",llll:"ddd D MMM YYYY, H:mm"},calendar:{sameDay:"[uèi a] LT",nextDay:"[deman a] LT",nextWeek:"dddd [a] LT",lastDay:"[ièr a] LT",lastWeek:"dddd [passat a] LT",sameElse:"L"},relativeTime:{future:"d'aquí %s",past:"fa %s",s:"unas segondas",ss:"%d segondas",m:"una minuta",mm:"%d minutas",h:"una ora",hh:"%d oras",d:"un jorn",dd:"%d jorns",M:"un mes",MM:"%d meses",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(r|n|t|è|a)/,ordinal:function(e,t){var n=1===e?"r":2===e?"n":3===e?"r":4===e?"t":"è";return"w"!==t&&"W"!==t||(n="a"),e+n},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"੧",2:"੨",3:"੩",4:"੪",5:"੫",6:"੬",7:"੭",8:"੮",9:"੯",0:"੦"},n={"੧":"1","੨":"2","੩":"3","੪":"4","੫":"5","੬":"6","੭":"7","੮":"8","੯":"9","੦":"0"};e.defineLocale("pa-in",{months:"ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ".split("_"),monthsShort:"ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ".split("_"),weekdays:"ਐਤਵਾਰ_ਸੋਮਵਾਰ_ਮੰਗਲਵਾਰ_ਬੁਧਵਾਰ_ਵੀਰਵਾਰ_ਸ਼ੁੱਕਰਵਾਰ_ਸ਼ਨੀਚਰਵਾਰ".split("_"),weekdaysShort:"ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ".split("_"),weekdaysMin:"ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ".split("_"),longDateFormat:{LT:"A h:mm ਵਜੇ",LTS:"A h:mm:ss ਵਜੇ",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm ਵਜੇ",LLLL:"dddd, D MMMM YYYY, A h:mm ਵਜੇ"},calendar:{sameDay:"[ਅਜ] LT",nextDay:"[ਕਲ] LT",nextWeek:"[ਅਗਲਾ] dddd, LT",lastDay:"[ਕਲ] LT",lastWeek:"[ਪਿਛਲੇ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ਵਿੱਚ",past:"%s ਪਿਛਲੇ",s:"ਕੁਝ ਸਕਿੰਟ",ss:"%d ਸਕਿੰਟ",m:"ਇਕ ਮਿੰਟ",mm:"%d ਮਿੰਟ",h:"ਇੱਕ ਘੰਟਾ",hh:"%d ਘੰਟੇ",d:"ਇੱਕ ਦਿਨ",dd:"%d ਦਿਨ",M:"ਇੱਕ ਮਹੀਨਾ",MM:"%d ਮਹੀਨੇ",y:"ਇੱਕ ਸਾਲ",yy:"%d ਸਾਲ"},preparse:function(e){return e.replace(/[੧੨੩੪੫੬੭੮੯੦]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/ਰਾਤ|ਸਵੇਰ|ਦੁਪਹਿਰ|ਸ਼ਾਮ/,meridiemHour:function(e,t){return 12===e&&(e=0),"ਰਾਤ"===t?e<4?e:e+12:"ਸਵੇਰ"===t?e:"ਦੁਪਹਿਰ"===t?e>=10?e:e+12:"ਸ਼ਾਮ"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"ਰਾਤ":e<10?"ਸਵੇਰ":e<17?"ਦੁਪਹਿਰ":e<20?"ਸ਼ਾਮ":"ਰਾਤ"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień".split("_"),n="stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia".split("_"),r=[/^sty/i,/^lut/i,/^mar/i,/^kwi/i,/^maj/i,/^cze/i,/^lip/i,/^sie/i,/^wrz/i,/^paź/i,/^lis/i,/^gru/i];function i(e){return e%10<5&&e%10>1&&~~(e/10)%10!=1}function o(e,t,n){var r=e+" ";switch(n){case"ss":return r+(i(e)?"sekundy":"sekund");case"m":return t?"minuta":"minutę";case"mm":return r+(i(e)?"minuty":"minut");case"h":return t?"godzina":"godzinę";case"hh":return r+(i(e)?"godziny":"godzin");case"ww":return r+(i(e)?"tygodnie":"tygodni");case"MM":return r+(i(e)?"miesiące":"miesięcy");case"yy":return r+(i(e)?"lata":"lat")}}e.defineLocale("pl",{months:function(e,r){return e?/D MMMM/.test(r)?n[e.month()]:t[e.month()]:t},monthsShort:"sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru".split("_"),monthsParse:r,longMonthsParse:r,shortMonthsParse:r,weekdays:"niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota".split("_"),weekdaysShort:"ndz_pon_wt_śr_czw_pt_sob".split("_"),weekdaysMin:"Nd_Pn_Wt_Śr_Cz_Pt_So".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Dziś o] LT",nextDay:"[Jutro o] LT",nextWeek:function(){switch(this.day()){case 0:return"[W niedzielę o] LT";case 2:return"[We wtorek o] LT";case 3:return"[W środę o] LT";case 6:return"[W sobotę o] LT";default:return"[W] dddd [o] LT"}},lastDay:"[Wczoraj o] LT",lastWeek:function(){switch(this.day()){case 0:return"[W zeszłą niedzielę o] LT";case 3:return"[W zeszłą środę o] LT";case 6:return"[W zeszłą sobotę o] LT";default:return"[W zeszły] dddd [o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"%s temu",s:"kilka sekund",ss:o,m:o,mm:o,h:o,hh:o,d:"1 dzień",dd:"%d dni",w:"tydzień",ww:o,M:"miesiąc",MM:o,y:"rok",yy:o},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("pt",{months:"janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro".split("_"),monthsShort:"jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez".split("_"),weekdays:"Domingo_Segunda-feira_Terça-feira_Quarta-feira_Quinta-feira_Sexta-feira_Sábado".split("_"),weekdaysShort:"Dom_Seg_Ter_Qua_Qui_Sex_Sáb".split("_"),weekdaysMin:"Do_2ª_3ª_4ª_5ª_6ª_Sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY HH:mm",LLLL:"dddd, D [de] MMMM [de] YYYY HH:mm"},calendar:{sameDay:"[Hoje às] LT",nextDay:"[Amanhã às] LT",nextWeek:"dddd [às] LT",lastDay:"[Ontem às] LT",lastWeek:function(){return 0===this.day()||6===this.day()?"[Último] dddd [às] LT":"[Última] dddd [às] LT"},sameElse:"L"},relativeTime:{future:"em %s",past:"há %s",s:"segundos",ss:"%d segundos",m:"um minuto",mm:"%d minutos",h:"uma hora",hh:"%d horas",d:"um dia",dd:"%d dias",w:"uma semana",ww:"%d semanas",M:"um mês",MM:"%d meses",y:"um ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("pt-br",{months:"janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro".split("_"),monthsShort:"jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez".split("_"),weekdays:"domingo_segunda-feira_terça-feira_quarta-feira_quinta-feira_sexta-feira_sábado".split("_"),weekdaysShort:"dom_seg_ter_qua_qui_sex_sáb".split("_"),weekdaysMin:"do_2ª_3ª_4ª_5ª_6ª_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY [às] HH:mm",LLLL:"dddd, D [de] MMMM [de] YYYY [às] HH:mm"},calendar:{sameDay:"[Hoje às] LT",nextDay:"[Amanhã às] LT",nextWeek:"dddd [às] LT",lastDay:"[Ontem às] LT",lastWeek:function(){return 0===this.day()||6===this.day()?"[Último] dddd [às] LT":"[Última] dddd [às] LT"},sameElse:"L"},relativeTime:{future:"em %s",past:"há %s",s:"poucos segundos",ss:"%d segundos",m:"um minuto",mm:"%d minutos",h:"uma hora",hh:"%d horas",d:"um dia",dd:"%d dias",M:"um mês",MM:"%d meses",y:"um ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",invalidDate:"Data inválida"})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r=" ";return(e%100>=20||e>=100&&e%100==0)&&(r=" de "),e+r+{ss:"secunde",mm:"minute",hh:"ore",dd:"zile",ww:"săptămâni",MM:"luni",yy:"ani"}[n]}e.defineLocale("ro",{months:"ianuarie_februarie_martie_aprilie_mai_iunie_iulie_august_septembrie_octombrie_noiembrie_decembrie".split("_"),monthsShort:"ian._feb._mart._apr._mai_iun._iul._aug._sept._oct._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"duminică_luni_marți_miercuri_joi_vineri_sâmbătă".split("_"),weekdaysShort:"Dum_Lun_Mar_Mie_Joi_Vin_Sâm".split("_"),weekdaysMin:"Du_Lu_Ma_Mi_Jo_Vi_Sâ".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[azi la] LT",nextDay:"[mâine la] LT",nextWeek:"dddd [la] LT",lastDay:"[ieri la] LT",lastWeek:"[fosta] dddd [la] LT",sameElse:"L"},relativeTime:{future:"peste %s",past:"%s în urmă",s:"câteva secunde",ss:t,m:"un minut",mm:t,h:"o oră",hh:t,d:"o zi",dd:t,w:"o săptămână",ww:t,M:"o lună",MM:t,y:"un an",yy:t},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r,i;return"m"===n?t?"минута":"минуту":e+" "+(r=+e,i={ss:t?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:t?"минута_минуты_минут":"минуту_минуты_минут",hh:"час_часа_часов",dd:"день_дня_дней",ww:"неделя_недели_недель",MM:"месяц_месяца_месяцев",yy:"год_года_лет"}[n].split("_"),r%10==1&&r%100!=11?i[0]:r%10>=2&&r%10<=4&&(r%100<10||r%100>=20)?i[1]:i[2])}var n=[/^янв/i,/^фев/i,/^мар/i,/^апр/i,/^ма[йя]/i,/^июн/i,/^июл/i,/^авг/i,/^сен/i,/^окт/i,/^ноя/i,/^дек/i];e.defineLocale("ru",{months:{format:"января_февраля_марта_апреля_мая_июня_июля_августа_сентября_октября_ноября_декабря".split("_"),standalone:"январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь".split("_")},monthsShort:{format:"янв._февр._мар._апр._мая_июня_июля_авг._сент._окт._нояб._дек.".split("_"),standalone:"янв._февр._март_апр._май_июнь_июль_авг._сент._окт._нояб._дек.".split("_")},weekdays:{standalone:"воскресенье_понедельник_вторник_среда_четверг_пятница_суббота".split("_"),format:"воскресенье_понедельник_вторник_среду_четверг_пятницу_субботу".split("_"),isFormat:/\[ ?[Вв] ?(?:прошлую|следующую|эту)? ?] ?dddd/},weekdaysShort:"вс_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"вс_пн_вт_ср_чт_пт_сб".split("_"),monthsParse:n,longMonthsParse:n,shortMonthsParse:n,monthsRegex:/^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,monthsShortRegex:/^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,monthsStrictRegex:/^(январ[яь]|феврал[яь]|марта?|апрел[яь]|ма[яй]|июн[яь]|июл[яь]|августа?|сентябр[яь]|октябр[яь]|ноябр[яь]|декабр[яь])/i,monthsShortStrictRegex:/^(янв\.|февр?\.|мар[т.]|апр\.|ма[яй]|июн[ья.]|июл[ья.]|авг\.|сент?\.|окт\.|нояб?\.|дек\.)/i,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., H:mm",LLLL:"dddd, D MMMM YYYY г., H:mm"},calendar:{sameDay:"[Сегодня, в] LT",nextDay:"[Завтра, в] LT",lastDay:"[Вчера, в] LT",nextWeek:function(e){if(e.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В следующее] dddd, [в] LT";case 1:case 2:case 4:return"[В следующий] dddd, [в] LT";case 3:case 5:case 6:return"[В следующую] dddd, [в] LT"}},lastWeek:function(e){if(e.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В прошлое] dddd, [в] LT";case 1:case 2:case 4:return"[В прошлый] dddd, [в] LT";case 3:case 5:case 6:return"[В прошлую] dddd, [в] LT"}},sameElse:"L"},relativeTime:{future:"через %s",past:"%s назад",s:"несколько секунд",ss:t,m:t,mm:t,h:"час",hh:t,d:"день",dd:t,w:"неделя",ww:t,M:"месяц",MM:t,y:"год",yy:t},meridiemParse:/ночи|утра|дня|вечера/i,isPM:function(e){return/^(дня|вечера)$/.test(e)},meridiem:function(e,t,n){return e<4?"ночи":e<12?"утра":e<17?"дня":"вечера"},dayOfMonthOrdinalParse:/\d{1,2}-(й|го|я)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":return e+"-й";case"D":return e+"-го";case"w":case"W":return e+"-я";default:return e}},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t=["جنوري","فيبروري","مارچ","اپريل","مئي","جون","جولاءِ","آگسٽ","سيپٽمبر","آڪٽوبر","نومبر","ڊسمبر"],n=["آچر","سومر","اڱارو","اربع","خميس","جمع","ڇنڇر"];e.defineLocale("sd",{months:t,monthsShort:t,weekdays:n,weekdaysShort:n,weekdaysMin:n,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd، D MMMM YYYY HH:mm"},meridiemParse:/صبح|شام/,isPM:function(e){return"شام"===e},meridiem:function(e,t,n){return e<12?"صبح":"شام"},calendar:{sameDay:"[اڄ] LT",nextDay:"[سڀاڻي] LT",nextWeek:"dddd [اڳين هفتي تي] LT",lastDay:"[ڪالهه] LT",lastWeek:"[گزريل هفتي] dddd [تي] LT",sameElse:"L"},relativeTime:{future:"%s پوء",past:"%s اڳ",s:"چند سيڪنڊ",ss:"%d سيڪنڊ",m:"هڪ منٽ",mm:"%d منٽ",h:"هڪ ڪلاڪ",hh:"%d ڪلاڪ",d:"هڪ ڏينهن",dd:"%d ڏينهن",M:"هڪ مهينو",MM:"%d مهينا",y:"هڪ سال",yy:"%d سال"},preparse:function(e){return e.replace(/،/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("se",{months:"ođđajagemánnu_guovvamánnu_njukčamánnu_cuoŋománnu_miessemánnu_geassemánnu_suoidnemánnu_borgemánnu_čakčamánnu_golggotmánnu_skábmamánnu_juovlamánnu".split("_"),monthsShort:"ođđj_guov_njuk_cuo_mies_geas_suoi_borg_čakč_golg_skáb_juov".split("_"),weekdays:"sotnabeaivi_vuossárga_maŋŋebárga_gaskavahkku_duorastat_bearjadat_lávvardat".split("_"),weekdaysShort:"sotn_vuos_maŋ_gask_duor_bear_láv".split("_"),weekdaysMin:"s_v_m_g_d_b_L".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"MMMM D. [b.] YYYY",LLL:"MMMM D. [b.] YYYY [ti.] HH:mm",LLLL:"dddd, MMMM D. [b.] YYYY [ti.] HH:mm"},calendar:{sameDay:"[otne ti] LT",nextDay:"[ihttin ti] LT",nextWeek:"dddd [ti] LT",lastDay:"[ikte ti] LT",lastWeek:"[ovddit] dddd [ti] LT",sameElse:"L"},relativeTime:{future:"%s geažes",past:"maŋit %s",s:"moadde sekunddat",ss:"%d sekunddat",m:"okta minuhta",mm:"%d minuhtat",h:"okta diimmu",hh:"%d diimmut",d:"okta beaivi",dd:"%d beaivvit",M:"okta mánnu",MM:"%d mánut",y:"okta jahki",yy:"%d jagit"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("si",{months:"ජනවාරි_පෙබරවාරි_මාර්තු_අප්‍රේල්_මැයි_ජූනි_ජූලි_අගෝස්තු_සැප්තැම්බර්_ඔක්තෝබර්_නොවැම්බර්_දෙසැම්බර්".split("_"),monthsShort:"ජන_පෙබ_මාර්_අප්_මැයි_ජූනි_ජූලි_අගෝ_සැප්_ඔක්_නොවැ_දෙසැ".split("_"),weekdays:"ඉරිදා_සඳුදා_අඟහරුවාදා_බදාදා_බ්‍රහස්පතින්දා_සිකුරාදා_සෙනසුරාදා".split("_"),weekdaysShort:"ඉරි_සඳු_අඟ_බදා_බ්‍රහ_සිකු_සෙන".split("_"),weekdaysMin:"ඉ_ස_අ_බ_බ්‍ර_සි_සෙ".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"a h:mm",LTS:"a h:mm:ss",L:"YYYY/MM/DD",LL:"YYYY MMMM D",LLL:"YYYY MMMM D, a h:mm",LLLL:"YYYY MMMM D [වැනි] dddd, a h:mm:ss"},calendar:{sameDay:"[අද] LT[ට]",nextDay:"[හෙට] LT[ට]",nextWeek:"dddd LT[ට]",lastDay:"[ඊයේ] LT[ට]",lastWeek:"[පසුගිය] dddd LT[ට]",sameElse:"L"},relativeTime:{future:"%sකින්",past:"%sකට පෙර",s:"තත්පර කිහිපය",ss:"තත්පර %d",m:"මිනිත්තුව",mm:"මිනිත්තු %d",h:"පැය",hh:"පැය %d",d:"දිනය",dd:"දින %d",M:"මාසය",MM:"මාස %d",y:"වසර",yy:"වසර %d"},dayOfMonthOrdinalParse:/\d{1,2} වැනි/,ordinal:function(e){return e+" වැනි"},meridiemParse:/පෙර වරු|පස් වරු|පෙ.ව|ප.ව./,isPM:function(e){return"ප.ව."===e||"පස් වරු"===e},meridiem:function(e,t,n){return e>11?n?"ප.ව.":"පස් වරු":n?"පෙ.ව.":"පෙර වරු"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="január_február_marec_apríl_máj_jún_júl_august_september_október_november_december".split("_"),n="jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec".split("_");function r(e){return e>1&&e<5}function i(e,t,n,i){var o=e+" ";switch(n){case"s":return t||i?"pár sekúnd":"pár sekundami";case"ss":return t||i?o+(r(e)?"sekundy":"sekúnd"):o+"sekundami";case"m":return t?"minúta":i?"minútu":"minútou";case"mm":return t||i?o+(r(e)?"minúty":"minút"):o+"minútami";case"h":return t?"hodina":i?"hodinu":"hodinou";case"hh":return t||i?o+(r(e)?"hodiny":"hodín"):o+"hodinami";case"d":return t||i?"deň":"dňom";case"dd":return t||i?o+(r(e)?"dni":"dní"):o+"dňami";case"M":return t||i?"mesiac":"mesiacom";case"MM":return t||i?o+(r(e)?"mesiace":"mesiacov"):o+"mesiacmi";case"y":return t||i?"rok":"rokom";case"yy":return t||i?o+(r(e)?"roky":"rokov"):o+"rokmi"}}e.defineLocale("sk",{months:t,monthsShort:n,weekdays:"nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota".split("_"),weekdaysShort:"ne_po_ut_st_št_pi_so".split("_"),weekdaysMin:"ne_po_ut_st_št_pi_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm"},calendar:{sameDay:"[dnes o] LT",nextDay:"[zajtra o] LT",nextWeek:function(){switch(this.day()){case 0:return"[v nedeľu o] LT";case 1:case 2:return"[v] dddd [o] LT";case 3:return"[v stredu o] LT";case 4:return"[vo štvrtok o] LT";case 5:return"[v piatok o] LT";case 6:return"[v sobotu o] LT"}},lastDay:"[včera o] LT",lastWeek:function(){switch(this.day()){case 0:return"[minulú nedeľu o] LT";case 1:case 2:return"[minulý] dddd [o] LT";case 3:return"[minulú stredu o] LT";case 4:case 5:return"[minulý] dddd [o] LT";case 6:return"[minulú sobotu o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"pred %s",s:i,ss:i,m:i,mm:i,h:i,hh:i,d:i,dd:i,M:i,MM:i,y:i,yy:i},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i=e+" ";switch(n){case"s":return t||r?"nekaj sekund":"nekaj sekundami";case"ss":return i+=1===e?t?"sekundo":"sekundi":2===e?t||r?"sekundi":"sekundah":e<5?t||r?"sekunde":"sekundah":"sekund";case"m":return t?"ena minuta":"eno minuto";case"mm":return i+=1===e?t?"minuta":"minuto":2===e?t||r?"minuti":"minutama":e<5?t||r?"minute":"minutami":t||r?"minut":"minutami";case"h":return t?"ena ura":"eno uro";case"hh":return i+=1===e?t?"ura":"uro":2===e?t||r?"uri":"urama":e<5?t||r?"ure":"urami":t||r?"ur":"urami";case"d":return t||r?"en dan":"enim dnem";case"dd":return i+=1===e?t||r?"dan":"dnem":2===e?t||r?"dni":"dnevoma":t||r?"dni":"dnevi";case"M":return t||r?"en mesec":"enim mesecem";case"MM":return i+=1===e?t||r?"mesec":"mesecem":2===e?t||r?"meseca":"mesecema":e<5?t||r?"mesece":"meseci":t||r?"mesecev":"meseci";case"y":return t||r?"eno leto":"enim letom";case"yy":return i+=1===e?t||r?"leto":"letom":2===e?t||r?"leti":"letoma":e<5?t||r?"leta":"leti":t||r?"let":"leti"}}e.defineLocale("sl",{months:"januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december".split("_"),monthsShort:"jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota".split("_"),weekdaysShort:"ned._pon._tor._sre._čet._pet._sob.".split("_"),weekdaysMin:"ne_po_to_sr_če_pe_so".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD. MM. YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danes ob] LT",nextDay:"[jutri ob] LT",nextWeek:function(){switch(this.day()){case 0:return"[v] [nedeljo] [ob] LT";case 3:return"[v] [sredo] [ob] LT";case 6:return"[v] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[v] dddd [ob] LT"}},lastDay:"[včeraj ob] LT",lastWeek:function(){switch(this.day()){case 0:return"[prejšnjo] [nedeljo] [ob] LT";case 3:return"[prejšnjo] [sredo] [ob] LT";case 6:return"[prejšnjo] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[prejšnji] dddd [ob] LT"}},sameElse:"L"},relativeTime:{future:"čez %s",past:"pred %s",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:t,M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("sq",{months:"Janar_Shkurt_Mars_Prill_Maj_Qershor_Korrik_Gusht_Shtator_Tetor_Nëntor_Dhjetor".split("_"),monthsShort:"Jan_Shk_Mar_Pri_Maj_Qer_Kor_Gus_Sht_Tet_Nën_Dhj".split("_"),weekdays:"E Diel_E Hënë_E Martë_E Mërkurë_E Enjte_E Premte_E Shtunë".split("_"),weekdaysShort:"Die_Hën_Mar_Mër_Enj_Pre_Sht".split("_"),weekdaysMin:"D_H_Ma_Më_E_P_Sh".split("_"),weekdaysParseExact:!0,meridiemParse:/PD|MD/,isPM:function(e){return"M"===e.charAt(0)},meridiem:function(e,t,n){return e<12?"PD":"MD"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Sot në] LT",nextDay:"[Nesër në] LT",nextWeek:"dddd [në] LT",lastDay:"[Dje në] LT",lastWeek:"dddd [e kaluar në] LT",sameElse:"L"},relativeTime:{future:"në %s",past:"%s më parë",s:"disa sekonda",ss:"%d sekonda",m:"një minutë",mm:"%d minuta",h:"një orë",hh:"%d orë",d:"një ditë",dd:"%d ditë",M:"një muaj",MM:"%d muaj",y:"një vit",yy:"%d vite"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={words:{ss:["sekunda","sekunde","sekundi"],m:["jedan minut","jedne minute"],mm:["minut","minute","minuta"],h:["jedan sat","jednog sata"],hh:["sat","sata","sati"],dd:["dan","dana","dana"],MM:["mesec","meseca","meseci"],yy:["godina","godine","godina"]},correctGrammaticalCase:function(e,t){return 1===e?t[0]:e>=2&&e<=4?t[1]:t[2]},translate:function(e,n,r){var i=t.words[r];return 1===r.length?n?i[0]:i[1]:e+" "+t.correctGrammaticalCase(e,i)}};e.defineLocale("sr",{months:"januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedelja_ponedeljak_utorak_sreda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sre._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D. M. YYYY.",LL:"D. MMMM YYYY.",LLL:"D. MMMM YYYY. H:mm",LLLL:"dddd, D. MMMM YYYY. H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedelju] [u] LT";case 3:return"[u] [sredu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[juče u] LT",lastWeek:function(){return["[prošle] [nedelje] [u] LT","[prošlog] [ponedeljka] [u] LT","[prošlog] [utorka] [u] LT","[prošle] [srede] [u] LT","[prošlog] [četvrtka] [u] LT","[prošlog] [petka] [u] LT","[prošle] [subote] [u] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"za %s",past:"pre %s",s:"nekoliko sekundi",ss:t.translate,m:t.translate,mm:t.translate,h:t.translate,hh:t.translate,d:"dan",dd:t.translate,M:"mesec",MM:t.translate,y:"godinu",yy:t.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={words:{ss:["секунда","секунде","секунди"],m:["један минут","једне минуте"],mm:["минут","минуте","минута"],h:["један сат","једног сата"],hh:["сат","сата","сати"],dd:["дан","дана","дана"],MM:["месец","месеца","месеци"],yy:["година","године","година"]},correctGrammaticalCase:function(e,t){return 1===e?t[0]:e>=2&&e<=4?t[1]:t[2]},translate:function(e,n,r){var i=t.words[r];return 1===r.length?n?i[0]:i[1]:e+" "+t.correctGrammaticalCase(e,i)}};e.defineLocale("sr-cyrl",{months:"јануар_фебруар_март_април_мај_јун_јул_август_септембар_октобар_новембар_децембар".split("_"),monthsShort:"јан._феб._мар._апр._мај_јун_јул_авг._сеп._окт._нов._дец.".split("_"),monthsParseExact:!0,weekdays:"недеља_понедељак_уторак_среда_четвртак_петак_субота".split("_"),weekdaysShort:"нед._пон._уто._сре._чет._пет._суб.".split("_"),weekdaysMin:"не_по_ут_ср_че_пе_су".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D. M. YYYY.",LL:"D. MMMM YYYY.",LLL:"D. MMMM YYYY. H:mm",LLLL:"dddd, D. MMMM YYYY. H:mm"},calendar:{sameDay:"[данас у] LT",nextDay:"[сутра у] LT",nextWeek:function(){switch(this.day()){case 0:return"[у] [недељу] [у] LT";case 3:return"[у] [среду] [у] LT";case 6:return"[у] [суботу] [у] LT";case 1:case 2:case 4:case 5:return"[у] dddd [у] LT"}},lastDay:"[јуче у] LT",lastWeek:function(){return["[прошле] [недеље] [у] LT","[прошлог] [понедељка] [у] LT","[прошлог] [уторка] [у] LT","[прошле] [среде] [у] LT","[прошлог] [четвртка] [у] LT","[прошлог] [петка] [у] LT","[прошле] [суботе] [у] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"за %s",past:"пре %s",s:"неколико секунди",ss:t.translate,m:t.translate,mm:t.translate,h:t.translate,hh:t.translate,d:"дан",dd:t.translate,M:"месец",MM:t.translate,y:"годину",yy:t.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ss",{months:"Bhimbidvwane_Indlovana_Indlov'lenkhulu_Mabasa_Inkhwekhweti_Inhlaba_Kholwane_Ingci_Inyoni_Imphala_Lweti_Ingongoni".split("_"),monthsShort:"Bhi_Ina_Inu_Mab_Ink_Inh_Kho_Igc_Iny_Imp_Lwe_Igo".split("_"),weekdays:"Lisontfo_Umsombuluko_Lesibili_Lesitsatfu_Lesine_Lesihlanu_Umgcibelo".split("_"),weekdaysShort:"Lis_Umb_Lsb_Les_Lsi_Lsh_Umg".split("_"),weekdaysMin:"Li_Us_Lb_Lt_Ls_Lh_Ug".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Namuhla nga] LT",nextDay:"[Kusasa nga] LT",nextWeek:"dddd [nga] LT",lastDay:"[Itolo nga] LT",lastWeek:"dddd [leliphelile] [nga] LT",sameElse:"L"},relativeTime:{future:"nga %s",past:"wenteka nga %s",s:"emizuzwana lomcane",ss:"%d mzuzwana",m:"umzuzu",mm:"%d emizuzu",h:"lihora",hh:"%d emahora",d:"lilanga",dd:"%d emalanga",M:"inyanga",MM:"%d tinyanga",y:"umnyaka",yy:"%d iminyaka"},meridiemParse:/ekuseni|emini|entsambama|ebusuku/,meridiem:function(e,t,n){return e<11?"ekuseni":e<15?"emini":e<19?"entsambama":"ebusuku"},meridiemHour:function(e,t){return 12===e&&(e=0),"ekuseni"===t?e:"emini"===t?e>=11?e:e+12:"entsambama"===t||"ebusuku"===t?0===e?0:e+12:void 0},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:"%d",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("sv",{months:"januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec".split("_"),weekdays:"söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag".split("_"),weekdaysShort:"sön_mån_tis_ons_tor_fre_lör".split("_"),weekdaysMin:"sö_må_ti_on_to_fr_lö".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [kl.] HH:mm",LLLL:"dddd D MMMM YYYY [kl.] HH:mm",lll:"D MMM YYYY HH:mm",llll:"ddd D MMM YYYY HH:mm"},calendar:{sameDay:"[Idag] LT",nextDay:"[Imorgon] LT",lastDay:"[Igår] LT",nextWeek:"[På] dddd LT",lastWeek:"[I] dddd[s] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"för %s sedan",s:"några sekunder",ss:"%d sekunder",m:"en minut",mm:"%d minuter",h:"en timme",hh:"%d timmar",d:"en dag",dd:"%d dagar",M:"en månad",MM:"%d månader",y:"ett år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}(\:e|\:a)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?":e":1===t||2===t?":a":":e")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("sw",{months:"Januari_Februari_Machi_Aprili_Mei_Juni_Julai_Agosti_Septemba_Oktoba_Novemba_Desemba".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ago_Sep_Okt_Nov_Des".split("_"),weekdays:"Jumapili_Jumatatu_Jumanne_Jumatano_Alhamisi_Ijumaa_Jumamosi".split("_"),weekdaysShort:"Jpl_Jtat_Jnne_Jtan_Alh_Ijm_Jmos".split("_"),weekdaysMin:"J2_J3_J4_J5_Al_Ij_J1".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"hh:mm A",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[leo saa] LT",nextDay:"[kesho saa] LT",nextWeek:"[wiki ijayo] dddd [saat] LT",lastDay:"[jana] LT",lastWeek:"[wiki iliyopita] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s baadaye",past:"tokea %s",s:"hivi punde",ss:"sekunde %d",m:"dakika moja",mm:"dakika %d",h:"saa limoja",hh:"masaa %d",d:"siku moja",dd:"siku %d",M:"mwezi mmoja",MM:"miezi %d",y:"mwaka mmoja",yy:"miaka %d"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"௧",2:"௨",3:"௩",4:"௪",5:"௫",6:"௬",7:"௭",8:"௮",9:"௯",0:"௦"},n={"௧":"1","௨":"2","௩":"3","௪":"4","௫":"5","௬":"6","௭":"7","௮":"8","௯":"9","௦":"0"};e.defineLocale("ta",{months:"ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்".split("_"),monthsShort:"ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்".split("_"),weekdays:"ஞாயிற்றுக்கிழமை_திங்கட்கிழமை_செவ்வாய்கிழமை_புதன்கிழமை_வியாழக்கிழமை_வெள்ளிக்கிழமை_சனிக்கிழமை".split("_"),weekdaysShort:"ஞாயிறு_திங்கள்_செவ்வாய்_புதன்_வியாழன்_வெள்ளி_சனி".split("_"),weekdaysMin:"ஞா_தி_செ_பு_வி_வெ_ச".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, HH:mm",LLLL:"dddd, D MMMM YYYY, HH:mm"},calendar:{sameDay:"[இன்று] LT",nextDay:"[நாளை] LT",nextWeek:"dddd, LT",lastDay:"[நேற்று] LT",lastWeek:"[கடந்த வாரம்] dddd, LT",sameElse:"L"},relativeTime:{future:"%s இல்",past:"%s முன்",s:"ஒரு சில விநாடிகள்",ss:"%d விநாடிகள்",m:"ஒரு நிமிடம்",mm:"%d நிமிடங்கள்",h:"ஒரு மணி நேரம்",hh:"%d மணி நேரம்",d:"ஒரு நாள்",dd:"%d நாட்கள்",M:"ஒரு மாதம்",MM:"%d மாதங்கள்",y:"ஒரு வருடம்",yy:"%d ஆண்டுகள்"},dayOfMonthOrdinalParse:/\d{1,2}வது/,ordinal:function(e){return e+"வது"},preparse:function(e){return e.replace(/[௧௨௩௪௫௬௭௮௯௦]/g,(function(e){return n[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return t[e]}))},meridiemParse:/யாமம்|வைகறை|காலை|நண்பகல்|எற்பாடு|மாலை/,meridiem:function(e,t,n){return e<2?" யாமம்":e<6?" வைகறை":e<10?" காலை":e<14?" நண்பகல்":e<18?" எற்பாடு":e<22?" மாலை":" யாமம்"},meridiemHour:function(e,t){return 12===e&&(e=0),"யாமம்"===t?e<2?e:e+12:"வைகறை"===t||"காலை"===t||"நண்பகல்"===t&&e>=10?e:e+12},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("te",{months:"జనవరి_ఫిబ్రవరి_మార్చి_ఏప్రిల్_మే_జూన్_జులై_ఆగస్టు_సెప్టెంబర్_అక్టోబర్_నవంబర్_డిసెంబర్".split("_"),monthsShort:"జన._ఫిబ్ర._మార్చి_ఏప్రి._మే_జూన్_జులై_ఆగ._సెప్._అక్టో._నవ._డిసె.".split("_"),monthsParseExact:!0,weekdays:"ఆదివారం_సోమవారం_మంగళవారం_బుధవారం_గురువారం_శుక్రవారం_శనివారం".split("_"),weekdaysShort:"ఆది_సోమ_మంగళ_బుధ_గురు_శుక్ర_శని".split("_"),weekdaysMin:"ఆ_సో_మం_బు_గు_శు_శ".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[నేడు] LT",nextDay:"[రేపు] LT",nextWeek:"dddd, LT",lastDay:"[నిన్న] LT",lastWeek:"[గత] dddd, LT",sameElse:"L"},relativeTime:{future:"%s లో",past:"%s క్రితం",s:"కొన్ని క్షణాలు",ss:"%d సెకన్లు",m:"ఒక నిమిషం",mm:"%d నిమిషాలు",h:"ఒక గంట",hh:"%d గంటలు",d:"ఒక రోజు",dd:"%d రోజులు",M:"ఒక నెల",MM:"%d నెలలు",y:"ఒక సంవత్సరం",yy:"%d సంవత్సరాలు"},dayOfMonthOrdinalParse:/\d{1,2}వ/,ordinal:"%dవ",meridiemParse:/రాత్రి|ఉదయం|మధ్యాహ్నం|సాయంత్రం/,meridiemHour:function(e,t){return 12===e&&(e=0),"రాత్రి"===t?e<4?e:e+12:"ఉదయం"===t?e:"మధ్యాహ్నం"===t?e>=10?e:e+12:"సాయంత్రం"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"రాత్రి":e<10?"ఉదయం":e<17?"మధ్యాహ్నం":e<20?"సాయంత్రం":"రాత్రి"},week:{dow:0,doy:6}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("tet",{months:"Janeiru_Fevereiru_Marsu_Abril_Maiu_Juñu_Jullu_Agustu_Setembru_Outubru_Novembru_Dezembru".split("_"),monthsShort:"Jan_Fev_Mar_Abr_Mai_Jun_Jul_Ago_Set_Out_Nov_Dez".split("_"),weekdays:"Domingu_Segunda_Tersa_Kuarta_Kinta_Sesta_Sabadu".split("_"),weekdaysShort:"Dom_Seg_Ters_Kua_Kint_Sest_Sab".split("_"),weekdaysMin:"Do_Seg_Te_Ku_Ki_Ses_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Ohin iha] LT",nextDay:"[Aban iha] LT",nextWeek:"dddd [iha] LT",lastDay:"[Horiseik iha] LT",lastWeek:"dddd [semana kotuk] [iha] LT",sameElse:"L"},relativeTime:{future:"iha %s",past:"%s liuba",s:"segundu balun",ss:"segundu %d",m:"minutu ida",mm:"minutu %d",h:"oras ida",hh:"oras %d",d:"loron ida",dd:"loron %d",M:"fulan ida",MM:"fulan %d",y:"tinan ida",yy:"tinan %d"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={0:"-ум",1:"-ум",2:"-юм",3:"-юм",4:"-ум",5:"-ум",6:"-ум",7:"-ум",8:"-ум",9:"-ум",10:"-ум",12:"-ум",13:"-ум",20:"-ум",30:"-юм",40:"-ум",50:"-ум",60:"-ум",70:"-ум",80:"-ум",90:"-ум",100:"-ум"};e.defineLocale("tg",{months:{format:"январи_феврали_марти_апрели_майи_июни_июли_августи_сентябри_октябри_ноябри_декабри".split("_"),standalone:"январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр".split("_")},monthsShort:"янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек".split("_"),weekdays:"якшанбе_душанбе_сешанбе_чоршанбе_панҷшанбе_ҷумъа_шанбе".split("_"),weekdaysShort:"яшб_дшб_сшб_чшб_пшб_ҷум_шнб".split("_"),weekdaysMin:"яш_дш_сш_чш_пш_ҷм_шб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Имрӯз соати] LT",nextDay:"[Фардо соати] LT",lastDay:"[Дирӯз соати] LT",nextWeek:"dddd[и] [ҳафтаи оянда соати] LT",lastWeek:"dddd[и] [ҳафтаи гузашта соати] LT",sameElse:"L"},relativeTime:{future:"баъди %s",past:"%s пеш",s:"якчанд сония",m:"як дақиқа",mm:"%d дақиқа",h:"як соат",hh:"%d соат",d:"як рӯз",dd:"%d рӯз",M:"як моҳ",MM:"%d моҳ",y:"як сол",yy:"%d сол"},meridiemParse:/шаб|субҳ|рӯз|бегоҳ/,meridiemHour:function(e,t){return 12===e&&(e=0),"шаб"===t?e<4?e:e+12:"субҳ"===t?e:"рӯз"===t?e>=11?e:e+12:"бегоҳ"===t?e+12:void 0},meridiem:function(e,t,n){return e<4?"шаб":e<11?"субҳ":e<16?"рӯз":e<19?"бегоҳ":"шаб"},dayOfMonthOrdinalParse:/\d{1,2}-(ум|юм)/,ordinal:function(e){return e+(t[e]||t[e%10]||t[e>=100?100:null])},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("th",{months:"มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม".split("_"),monthsShort:"ม.ค._ก.พ._มี.ค._เม.ย._พ.ค._มิ.ย._ก.ค._ส.ค._ก.ย._ต.ค._พ.ย._ธ.ค.".split("_"),monthsParseExact:!0,weekdays:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์".split("_"),weekdaysShort:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์".split("_"),weekdaysMin:"อา._จ._อ._พ._พฤ._ศ._ส.".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY เวลา H:mm",LLLL:"วันddddที่ D MMMM YYYY เวลา H:mm"},meridiemParse:/ก่อนเที่ยง|หลังเที่ยง/,isPM:function(e){return"หลังเที่ยง"===e},meridiem:function(e,t,n){return e<12?"ก่อนเที่ยง":"หลังเที่ยง"},calendar:{sameDay:"[วันนี้ เวลา] LT",nextDay:"[พรุ่งนี้ เวลา] LT",nextWeek:"dddd[หน้า เวลา] LT",lastDay:"[เมื่อวานนี้ เวลา] LT",lastWeek:"[วัน]dddd[ที่แล้ว เวลา] LT",sameElse:"L"},relativeTime:{future:"อีก %s",past:"%sที่แล้ว",s:"ไม่กี่วินาที",ss:"%d วินาที",m:"1 นาที",mm:"%d นาที",h:"1 ชั่วโมง",hh:"%d ชั่วโมง",d:"1 วัน",dd:"%d วัน",w:"1 สัปดาห์",ww:"%d สัปดาห์",M:"1 เดือน",MM:"%d เดือน",y:"1 ปี",yy:"%d ปี"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"'inji",5:"'inji",8:"'inji",70:"'inji",80:"'inji",2:"'nji",7:"'nji",20:"'nji",50:"'nji",3:"'ünji",4:"'ünji",100:"'ünji",6:"'njy",9:"'unjy",10:"'unjy",30:"'unjy",60:"'ynjy",90:"'ynjy"};e.defineLocale("tk",{months:"Ýanwar_Fewral_Mart_Aprel_Maý_Iýun_Iýul_Awgust_Sentýabr_Oktýabr_Noýabr_Dekabr".split("_"),monthsShort:"Ýan_Few_Mar_Apr_Maý_Iýn_Iýl_Awg_Sen_Okt_Noý_Dek".split("_"),weekdays:"Ýekşenbe_Duşenbe_Sişenbe_Çarşenbe_Penşenbe_Anna_Şenbe".split("_"),weekdaysShort:"Ýek_Duş_Siş_Çar_Pen_Ann_Şen".split("_"),weekdaysMin:"Ýk_Dş_Sş_Çr_Pn_An_Şn".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün sagat] LT",nextDay:"[ertir sagat] LT",nextWeek:"[indiki] dddd [sagat] LT",lastDay:"[düýn] LT",lastWeek:"[geçen] dddd [sagat] LT",sameElse:"L"},relativeTime:{future:"%s soň",past:"%s öň",s:"birnäçe sekunt",m:"bir minut",mm:"%d minut",h:"bir sagat",hh:"%d sagat",d:"bir gün",dd:"%d gün",M:"bir aý",MM:"%d aý",y:"bir ýyl",yy:"%d ýyl"},ordinal:function(e,n){switch(n){case"d":case"D":case"Do":case"DD":return e;default:if(0===e)return e+"'unjy";var r=e%10;return e+(t[r]||t[e%100-r]||t[e>=100?100:null])}},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("tl-ph",{months:"Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre".split("_"),monthsShort:"Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis".split("_"),weekdays:"Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado".split("_"),weekdaysShort:"Lin_Lun_Mar_Miy_Huw_Biy_Sab".split("_"),weekdaysMin:"Li_Lu_Ma_Mi_Hu_Bi_Sab".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"MM/D/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY HH:mm",LLLL:"dddd, MMMM DD, YYYY HH:mm"},calendar:{sameDay:"LT [ngayong araw]",nextDay:"[Bukas ng] LT",nextWeek:"LT [sa susunod na] dddd",lastDay:"LT [kahapon]",lastWeek:"LT [noong nakaraang] dddd",sameElse:"L"},relativeTime:{future:"sa loob ng %s",past:"%s ang nakalipas",s:"ilang segundo",ss:"%d segundo",m:"isang minuto",mm:"%d minuto",h:"isang oras",hh:"%d oras",d:"isang araw",dd:"%d araw",M:"isang buwan",MM:"%d buwan",y:"isang taon",yy:"%d taon"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t="pagh_wa’_cha’_wej_loS_vagh_jav_Soch_chorgh_Hut".split("_");function n(e,n,r,i){var o=function(e){var n=Math.floor(e%1e3/100),r=Math.floor(e%100/10),i=e%10,o="";return n>0&&(o+=t[n]+"vatlh"),r>0&&(o+=(""!==o?" ":"")+t[r]+"maH"),i>0&&(o+=(""!==o?" ":"")+t[i]),""===o?"pagh":o}(e);switch(r){case"ss":return o+" lup";case"mm":return o+" tup";case"hh":return o+" rep";case"dd":return o+" jaj";case"MM":return o+" jar";case"yy":return o+" DIS"}}e.defineLocale("tlh",{months:"tera’ jar wa’_tera’ jar cha’_tera’ jar wej_tera’ jar loS_tera’ jar vagh_tera’ jar jav_tera’ jar Soch_tera’ jar chorgh_tera’ jar Hut_tera’ jar wa’maH_tera’ jar wa’maH wa’_tera’ jar wa’maH cha’".split("_"),monthsShort:"jar wa’_jar cha’_jar wej_jar loS_jar vagh_jar jav_jar Soch_jar chorgh_jar Hut_jar wa’maH_jar wa’maH wa’_jar wa’maH cha’".split("_"),monthsParseExact:!0,weekdays:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysShort:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysMin:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[DaHjaj] LT",nextDay:"[wa’leS] LT",nextWeek:"LLL",lastDay:"[wa’Hu’] LT",lastWeek:"LLL",sameElse:"L"},relativeTime:{future:function(e){var t=e;return t=-1!==e.indexOf("jaj")?t.slice(0,-3)+"leS":-1!==e.indexOf("jar")?t.slice(0,-3)+"waQ":-1!==e.indexOf("DIS")?t.slice(0,-3)+"nem":t+" pIq"},past:function(e){var t=e;return t=-1!==e.indexOf("jaj")?t.slice(0,-3)+"Hu’":-1!==e.indexOf("jar")?t.slice(0,-3)+"wen":-1!==e.indexOf("DIS")?t.slice(0,-3)+"ben":t+" ret"},s:"puS lup",ss:n,m:"wa’ tup",mm:n,h:"wa’ rep",hh:n,d:"wa’ jaj",dd:n,M:"wa’ jar",MM:n,y:"wa’ DIS",yy:n},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t={1:"'inci",5:"'inci",8:"'inci",70:"'inci",80:"'inci",2:"'nci",7:"'nci",20:"'nci",50:"'nci",3:"'üncü",4:"'üncü",100:"'üncü",6:"'ncı",9:"'uncu",10:"'uncu",30:"'uncu",60:"'ıncı",90:"'ıncı"};e.defineLocale("tr",{months:"Ocak_Şubat_Mart_Nisan_Mayıs_Haziran_Temmuz_Ağustos_Eylül_Ekim_Kasım_Aralık".split("_"),monthsShort:"Oca_Şub_Mar_Nis_May_Haz_Tem_Ağu_Eyl_Eki_Kas_Ara".split("_"),weekdays:"Pazar_Pazartesi_Salı_Çarşamba_Perşembe_Cuma_Cumartesi".split("_"),weekdaysShort:"Paz_Pts_Sal_Çar_Per_Cum_Cts".split("_"),weekdaysMin:"Pz_Pt_Sa_Ça_Pe_Cu_Ct".split("_"),meridiem:function(e,t,n){return e<12?n?"öö":"ÖÖ":n?"ös":"ÖS"},meridiemParse:/öö|ÖÖ|ös|ÖS/,isPM:function(e){return"ös"===e||"ÖS"===e},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün saat] LT",nextDay:"[yarın saat] LT",nextWeek:"[gelecek] dddd [saat] LT",lastDay:"[dün] LT",lastWeek:"[geçen] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s sonra",past:"%s önce",s:"birkaç saniye",ss:"%d saniye",m:"bir dakika",mm:"%d dakika",h:"bir saat",hh:"%d saat",d:"bir gün",dd:"%d gün",w:"bir hafta",ww:"%d hafta",M:"bir ay",MM:"%d ay",y:"bir yıl",yy:"%d yıl"},ordinal:function(e,n){switch(n){case"d":case"D":case"Do":case"DD":return e;default:if(0===e)return e+"'ıncı";var r=e%10;return e+(t[r]||t[e%100-r]||t[e>=100?100:null])}},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n,r){var i={s:["viensas secunds","'iensas secunds"],ss:[e+" secunds",e+" secunds"],m:["'n míut","'iens míut"],mm:[e+" míuts",e+" míuts"],h:["'n þora","'iensa þora"],hh:[e+" þoras",e+" þoras"],d:["'n ziua","'iensa ziua"],dd:[e+" ziuas",e+" ziuas"],M:["'n mes","'iens mes"],MM:[e+" mesen",e+" mesen"],y:["'n ar","'iens ar"],yy:[e+" ars",e+" ars"]};return r||t?i[n][0]:i[n][1]}e.defineLocale("tzl",{months:"Januar_Fevraglh_Març_Avrïu_Mai_Gün_Julia_Guscht_Setemvar_Listopäts_Noemvar_Zecemvar".split("_"),monthsShort:"Jan_Fev_Mar_Avr_Mai_Gün_Jul_Gus_Set_Lis_Noe_Zec".split("_"),weekdays:"Súladi_Lúneçi_Maitzi_Márcuri_Xhúadi_Viénerçi_Sáturi".split("_"),weekdaysShort:"Súl_Lún_Mai_Már_Xhú_Vié_Sát".split("_"),weekdaysMin:"Sú_Lú_Ma_Má_Xh_Vi_Sá".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD.MM.YYYY",LL:"D. MMMM [dallas] YYYY",LLL:"D. MMMM [dallas] YYYY HH.mm",LLLL:"dddd, [li] D. MMMM [dallas] YYYY HH.mm"},meridiemParse:/d\'o|d\'a/i,isPM:function(e){return"d'o"===e.toLowerCase()},meridiem:function(e,t,n){return e>11?n?"d'o":"D'O":n?"d'a":"D'A"},calendar:{sameDay:"[oxhi à] LT",nextDay:"[demà à] LT",nextWeek:"dddd [à] LT",lastDay:"[ieiri à] LT",lastWeek:"[sür el] dddd [lasteu à] LT",sameElse:"L"},relativeTime:{future:"osprei %s",past:"ja%s",s:t,ss:t,m:t,mm:t,h:t,hh:t,d:t,dd:t,M:t,MM:t,y:t,yy:t},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("tzm",{months:"ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ".split("_"),monthsShort:"ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ".split("_"),weekdays:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),weekdaysShort:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),weekdaysMin:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[ⴰⵙⴷⵅ ⴴ] LT",nextDay:"[ⴰⵙⴽⴰ ⴴ] LT",nextWeek:"dddd [ⴴ] LT",lastDay:"[ⴰⵚⴰⵏⵜ ⴴ] LT",lastWeek:"dddd [ⴴ] LT",sameElse:"L"},relativeTime:{future:"ⴷⴰⴷⵅ ⵙ ⵢⴰⵏ %s",past:"ⵢⴰⵏ %s",s:"ⵉⵎⵉⴽ",ss:"%d ⵉⵎⵉⴽ",m:"ⵎⵉⵏⵓⴺ",mm:"%d ⵎⵉⵏⵓⴺ",h:"ⵙⴰⵄⴰ",hh:"%d ⵜⴰⵙⵙⴰⵄⵉⵏ",d:"ⴰⵙⵙ",dd:"%d oⵙⵙⴰⵏ",M:"ⴰⵢoⵓⵔ",MM:"%d ⵉⵢⵢⵉⵔⵏ",y:"ⴰⵙⴳⴰⵙ",yy:"%d ⵉⵙⴳⴰⵙⵏ"},week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("tzm-latn",{months:"innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir".split("_"),monthsShort:"innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir".split("_"),weekdays:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),weekdaysShort:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),weekdaysMin:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[asdkh g] LT",nextDay:"[aska g] LT",nextWeek:"dddd [g] LT",lastDay:"[assant g] LT",lastWeek:"dddd [g] LT",sameElse:"L"},relativeTime:{future:"dadkh s yan %s",past:"yan %s",s:"imik",ss:"%d imik",m:"minuḍ",mm:"%d minuḍ",h:"saɛa",hh:"%d tassaɛin",d:"ass",dd:"%d ossan",M:"ayowr",MM:"%d iyyirn",y:"asgas",yy:"%d isgasn"},week:{dow:6,doy:12}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("ug-cn",{months:"يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر".split("_"),monthsShort:"يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر".split("_"),weekdays:"يەكشەنبە_دۈشەنبە_سەيشەنبە_چارشەنبە_پەيشەنبە_جۈمە_شەنبە".split("_"),weekdaysShort:"يە_دۈ_سە_چا_پە_جۈ_شە".split("_"),weekdaysMin:"يە_دۈ_سە_چا_پە_جۈ_شە".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY-يىلىM-ئاينىڭD-كۈنى",LLL:"YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm",LLLL:"dddd، YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm"},meridiemParse:/يېرىم كېچە|سەھەر|چۈشتىن بۇرۇن|چۈش|چۈشتىن كېيىن|كەچ/,meridiemHour:function(e,t){return 12===e&&(e=0),"يېرىم كېچە"===t||"سەھەر"===t||"چۈشتىن بۇرۇن"===t?e:"چۈشتىن كېيىن"===t||"كەچ"===t?e+12:e>=11?e:e+12},meridiem:function(e,t,n){var r=100*e+t;return r<600?"يېرىم كېچە":r<900?"سەھەر":r<1130?"چۈشتىن بۇرۇن":r<1230?"چۈش":r<1800?"چۈشتىن كېيىن":"كەچ"},calendar:{sameDay:"[بۈگۈن سائەت] LT",nextDay:"[ئەتە سائەت] LT",nextWeek:"[كېلەركى] dddd [سائەت] LT",lastDay:"[تۆنۈگۈن] LT",lastWeek:"[ئالدىنقى] dddd [سائەت] LT",sameElse:"L"},relativeTime:{future:"%s كېيىن",past:"%s بۇرۇن",s:"نەچچە سېكونت",ss:"%d سېكونت",m:"بىر مىنۇت",mm:"%d مىنۇت",h:"بىر سائەت",hh:"%d سائەت",d:"بىر كۈن",dd:"%d كۈن",M:"بىر ئاي",MM:"%d ئاي",y:"بىر يىل",yy:"%d يىل"},dayOfMonthOrdinalParse:/\d{1,2}(-كۈنى|-ئاي|-ھەپتە)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"-كۈنى";case"w":case"W":return e+"-ھەپتە";default:return e}},preparse:function(e){return e.replace(/،/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
function t(e,t,n){var r,i;return"m"===n?t?"хвилина":"хвилину":"h"===n?t?"година":"годину":e+" "+(r=+e,i={ss:t?"секунда_секунди_секунд":"секунду_секунди_секунд",mm:t?"хвилина_хвилини_хвилин":"хвилину_хвилини_хвилин",hh:t?"година_години_годин":"годину_години_годин",dd:"день_дні_днів",MM:"місяць_місяці_місяців",yy:"рік_роки_років"}[n].split("_"),r%10==1&&r%100!=11?i[0]:r%10>=2&&r%10<=4&&(r%100<10||r%100>=20)?i[1]:i[2])}function n(e){return function(){return e+"о"+(11===this.hours()?"б":"")+"] LT"}}e.defineLocale("uk",{months:{format:"січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня".split("_"),standalone:"січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень".split("_")},monthsShort:"січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд".split("_"),weekdays:function(e,t){var n={nominative:"неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота".split("_"),accusative:"неділю_понеділок_вівторок_середу_четвер_п’ятницю_суботу".split("_"),genitive:"неділі_понеділка_вівторка_середи_четверга_п’ятниці_суботи".split("_")};return!0===e?n.nominative.slice(1,7).concat(n.nominative.slice(0,1)):e?n[/(\[[ВвУу]\]) ?dddd/.test(t)?"accusative":/\[?(?:минулої|наступної)? ?\] ?dddd/.test(t)?"genitive":"nominative"][e.day()]:n.nominative},weekdaysShort:"нд_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"нд_пн_вт_ср_чт_пт_сб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY р.",LLL:"D MMMM YYYY р., HH:mm",LLLL:"dddd, D MMMM YYYY р., HH:mm"},calendar:{sameDay:n("[Сьогодні "),nextDay:n("[Завтра "),lastDay:n("[Вчора "),nextWeek:n("[У] dddd ["),lastWeek:function(){switch(this.day()){case 0:case 3:case 5:case 6:return n("[Минулої] dddd [").call(this);case 1:case 2:case 4:return n("[Минулого] dddd [").call(this)}},sameElse:"L"},relativeTime:{future:"за %s",past:"%s тому",s:"декілька секунд",ss:t,m:t,mm:t,h:"годину",hh:t,d:"день",dd:t,M:"місяць",MM:t,y:"рік",yy:t},meridiemParse:/ночі|ранку|дня|вечора/,isPM:function(e){return/^(дня|вечора)$/.test(e)},meridiem:function(e,t,n){return e<4?"ночі":e<12?"ранку":e<17?"дня":"вечора"},dayOfMonthOrdinalParse:/\d{1,2}-(й|го)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":case"w":case"W":return e+"-й";case"D":return e+"-го";default:return e}},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
var t=["جنوری","فروری","مارچ","اپریل","مئی","جون","جولائی","اگست","ستمبر","اکتوبر","نومبر","دسمبر"],n=["اتوار","پیر","منگل","بدھ","جمعرات","جمعہ","ہفتہ"];e.defineLocale("ur",{months:t,monthsShort:t,weekdays:n,weekdaysShort:n,weekdaysMin:n,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd، D MMMM YYYY HH:mm"},meridiemParse:/صبح|شام/,isPM:function(e){return"شام"===e},meridiem:function(e,t,n){return e<12?"صبح":"شام"},calendar:{sameDay:"[آج بوقت] LT",nextDay:"[کل بوقت] LT",nextWeek:"dddd [بوقت] LT",lastDay:"[گذشتہ روز بوقت] LT",lastWeek:"[گذشتہ] dddd [بوقت] LT",sameElse:"L"},relativeTime:{future:"%s بعد",past:"%s قبل",s:"چند سیکنڈ",ss:"%d سیکنڈ",m:"ایک منٹ",mm:"%d منٹ",h:"ایک گھنٹہ",hh:"%d گھنٹے",d:"ایک دن",dd:"%d دن",M:"ایک ماہ",MM:"%d ماہ",y:"ایک سال",yy:"%d سال"},preparse:function(e){return e.replace(/،/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("uz",{months:"январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр".split("_"),monthsShort:"янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек".split("_"),weekdays:"Якшанба_Душанба_Сешанба_Чоршанба_Пайшанба_Жума_Шанба".split("_"),weekdaysShort:"Якш_Душ_Сеш_Чор_Пай_Жум_Шан".split("_"),weekdaysMin:"Як_Ду_Се_Чо_Па_Жу_Ша".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"D MMMM YYYY, dddd HH:mm"},calendar:{sameDay:"[Бугун соат] LT [да]",nextDay:"[Эртага] LT [да]",nextWeek:"dddd [куни соат] LT [да]",lastDay:"[Кеча соат] LT [да]",lastWeek:"[Утган] dddd [куни соат] LT [да]",sameElse:"L"},relativeTime:{future:"Якин %s ичида",past:"Бир неча %s олдин",s:"фурсат",ss:"%d фурсат",m:"бир дакика",mm:"%d дакика",h:"бир соат",hh:"%d соат",d:"бир кун",dd:"%d кун",M:"бир ой",MM:"%d ой",y:"бир йил",yy:"%d йил"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("uz-latn",{months:"Yanvar_Fevral_Mart_Aprel_May_Iyun_Iyul_Avgust_Sentabr_Oktabr_Noyabr_Dekabr".split("_"),monthsShort:"Yan_Fev_Mar_Apr_May_Iyun_Iyul_Avg_Sen_Okt_Noy_Dek".split("_"),weekdays:"Yakshanba_Dushanba_Seshanba_Chorshanba_Payshanba_Juma_Shanba".split("_"),weekdaysShort:"Yak_Dush_Sesh_Chor_Pay_Jum_Shan".split("_"),weekdaysMin:"Ya_Du_Se_Cho_Pa_Ju_Sha".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"D MMMM YYYY, dddd HH:mm"},calendar:{sameDay:"[Bugun soat] LT [da]",nextDay:"[Ertaga] LT [da]",nextWeek:"dddd [kuni soat] LT [da]",lastDay:"[Kecha soat] LT [da]",lastWeek:"[O'tgan] dddd [kuni soat] LT [da]",sameElse:"L"},relativeTime:{future:"Yaqin %s ichida",past:"Bir necha %s oldin",s:"soniya",ss:"%d soniya",m:"bir daqiqa",mm:"%d daqiqa",h:"bir soat",hh:"%d soat",d:"bir kun",dd:"%d kun",M:"bir oy",MM:"%d oy",y:"bir yil",yy:"%d yil"},week:{dow:1,doy:7}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("vi",{months:"tháng 1_tháng 2_tháng 3_tháng 4_tháng 5_tháng 6_tháng 7_tháng 8_tháng 9_tháng 10_tháng 11_tháng 12".split("_"),monthsShort:"Thg 01_Thg 02_Thg 03_Thg 04_Thg 05_Thg 06_Thg 07_Thg 08_Thg 09_Thg 10_Thg 11_Thg 12".split("_"),monthsParseExact:!0,weekdays:"chủ nhật_thứ hai_thứ ba_thứ tư_thứ năm_thứ sáu_thứ bảy".split("_"),weekdaysShort:"CN_T2_T3_T4_T5_T6_T7".split("_"),weekdaysMin:"CN_T2_T3_T4_T5_T6_T7".split("_"),weekdaysParseExact:!0,meridiemParse:/sa|ch/i,isPM:function(e){return/^ch$/i.test(e)},meridiem:function(e,t,n){return e<12?n?"sa":"SA":n?"ch":"CH"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [năm] YYYY",LLL:"D MMMM [năm] YYYY HH:mm",LLLL:"dddd, D MMMM [năm] YYYY HH:mm",l:"DD/M/YYYY",ll:"D MMM YYYY",lll:"D MMM YYYY HH:mm",llll:"ddd, D MMM YYYY HH:mm"},calendar:{sameDay:"[Hôm nay lúc] LT",nextDay:"[Ngày mai lúc] LT",nextWeek:"dddd [tuần tới lúc] LT",lastDay:"[Hôm qua lúc] LT",lastWeek:"dddd [tuần trước lúc] LT",sameElse:"L"},relativeTime:{future:"%s tới",past:"%s trước",s:"vài giây",ss:"%d giây",m:"một phút",mm:"%d phút",h:"một giờ",hh:"%d giờ",d:"một ngày",dd:"%d ngày",w:"một tuần",ww:"%d tuần",M:"một tháng",MM:"%d tháng",y:"một năm",yy:"%d năm"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("x-pseudo",{months:"J~áñúá~rý_F~ébrú~árý_~Márc~h_Áp~ríl_~Máý_~Júñé~_Júl~ý_Áú~gúst~_Sép~témb~ér_Ó~ctób~ér_Ñ~óvém~bér_~Décé~mbér".split("_"),monthsShort:"J~áñ_~Féb_~Már_~Ápr_~Máý_~Júñ_~Júl_~Áúg_~Sép_~Óct_~Ñóv_~Déc".split("_"),monthsParseExact:!0,weekdays:"S~úñdá~ý_Mó~ñdáý~_Túé~sdáý~_Wéd~ñésd~áý_T~húrs~dáý_~Fríd~áý_S~átúr~dáý".split("_"),weekdaysShort:"S~úñ_~Móñ_~Túé_~Wéd_~Thú_~Frí_~Sát".split("_"),weekdaysMin:"S~ú_Mó~_Tú_~Wé_T~h_Fr~_Sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[T~ódá~ý át] LT",nextDay:"[T~ómó~rró~w át] LT",nextWeek:"dddd [át] LT",lastDay:"[Ý~ést~érdá~ý át] LT",lastWeek:"[L~ást] dddd [át] LT",sameElse:"L"},relativeTime:{future:"í~ñ %s",past:"%s á~gó",s:"á ~féw ~sécó~ñds",ss:"%d s~écóñ~ds",m:"á ~míñ~úté",mm:"%d m~íñú~tés",h:"á~ñ hó~úr",hh:"%d h~óúrs",d:"á ~dáý",dd:"%d d~áýs",M:"á ~móñ~th",MM:"%d m~óñt~hs",y:"á ~ýéár",yy:"%d ý~éárs"},dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1===t?"st":2===t?"nd":3===t?"rd":"th")},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("yo",{months:"Sẹ́rẹ́_Èrèlè_Ẹrẹ̀nà_Ìgbé_Èbibi_Òkùdu_Agẹmo_Ògún_Owewe_Ọ̀wàrà_Bélú_Ọ̀pẹ̀̀".split("_"),monthsShort:"Sẹ́r_Èrl_Ẹrn_Ìgb_Èbi_Òkù_Agẹ_Ògú_Owe_Ọ̀wà_Bél_Ọ̀pẹ̀̀".split("_"),weekdays:"Àìkú_Ajé_Ìsẹ́gun_Ọjọ́rú_Ọjọ́bọ_Ẹtì_Àbámẹ́ta".split("_"),weekdaysShort:"Àìk_Ajé_Ìsẹ́_Ọjr_Ọjb_Ẹtì_Àbá".split("_"),weekdaysMin:"Àì_Aj_Ìs_Ọr_Ọb_Ẹt_Àb".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Ònì ni] LT",nextDay:"[Ọ̀la ni] LT",nextWeek:"dddd [Ọsẹ̀ tón'bọ] [ni] LT",lastDay:"[Àna ni] LT",lastWeek:"dddd [Ọsẹ̀ tólọ́] [ni] LT",sameElse:"L"},relativeTime:{future:"ní %s",past:"%s kọjá",s:"ìsẹjú aayá die",ss:"aayá %d",m:"ìsẹjú kan",mm:"ìsẹjú %d",h:"wákati kan",hh:"wákati %d",d:"ọjọ́ kan",dd:"ọjọ́ %d",M:"osù kan",MM:"osù %d",y:"ọdún kan",yy:"ọdún %d"},dayOfMonthOrdinalParse:/ọjọ́\s\d{1,2}/,ordinal:"ọjọ́ %d",week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("zh-cn",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"周日_周一_周二_周三_周四_周五_周六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日Ah点mm分",LLLL:"YYYY年M月D日ddddAh点mm分",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/凌晨|早上|上午|中午|下午|晚上/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"下午"===t||"晚上"===t?e+12:e>=11?e:e+12},meridiem:function(e,t,n){var r=100*e+t;return r<600?"凌晨":r<900?"早上":r<1130?"上午":r<1230?"中午":r<1800?"下午":"晚上"},calendar:{sameDay:"[今天]LT",nextDay:"[明天]LT",nextWeek:function(e){return e.week()!==this.week()?"[下]dddLT":"[本]dddLT"},lastDay:"[昨天]LT",lastWeek:function(e){return this.week()!==e.week()?"[上]dddLT":"[本]dddLT"},sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(日|月|周)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"周";default:return e}},relativeTime:{future:"%s后",past:"%s前",s:"几秒",ss:"%d 秒",m:"1 分钟",mm:"%d 分钟",h:"1 小时",hh:"%d 小时",d:"1 天",dd:"%d 天",w:"1 周",ww:"%d 周",M:"1 个月",MM:"%d 个月",y:"1 年",yy:"%d 年"},week:{dow:1,doy:4}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("zh-hk",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/凌晨|早上|上午|中午|下午|晚上/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?e>=11?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,n){var r=100*e+t;return r<600?"凌晨":r<900?"早上":r<1200?"上午":1200===r?"中午":r<1800?"下午":"晚上"},calendar:{sameDay:"[今天]LT",nextDay:"[明天]LT",nextWeek:"[下]ddddLT",lastDay:"[昨天]LT",lastWeek:"[上]ddddLT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(日|月|週)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("zh-mo",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"D/M/YYYY",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/凌晨|早上|上午|中午|下午|晚上/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?e>=11?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,n){var r=100*e+t;return r<600?"凌晨":r<900?"早上":r<1130?"上午":r<1230?"中午":r<1800?"下午":"晚上"},calendar:{sameDay:"[今天] LT",nextDay:"[明天] LT",nextWeek:"[下]dddd LT",lastDay:"[昨天] LT",lastWeek:"[上]dddd LT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(日|月|週)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s內",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}})}(n(7))},function(e,t,n){!function(e){"use strict";
//! moment.js locale configuration
e.defineLocale("zh-tw",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/凌晨|早上|上午|中午|下午|晚上/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?e>=11?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,n){var r=100*e+t;return r<600?"凌晨":r<900?"早上":r<1130?"上午":r<1230?"中午":r<1800?"下午":"晚上"},calendar:{sameDay:"[今天] LT",nextDay:"[明天] LT",nextWeek:"[下]dddd LT",lastDay:"[昨天] LT",lastWeek:"[上]dddd LT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(日|月|週)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}})}(n(7))},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0}),t.Drive=t.ContentsManager=t.Contents=void 0;const a=n(12),s=n(2),l=n(4),c=n(38),u=o(n(621));var d;!function(e){e.validateContentsModel=function(e){u.validateContentsModel(e)},e.validateCheckpointModel=function(e){u.validateCheckpointModel(e)}}(t.Contents||(t.Contents={}));t.ContentsManager=class{constructor(e={}){var t,n;this._isDisposed=!1,this._additionalDrives=new Map,this._fileChanged=new l.Signal(this);const r=this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:c.ServerConnection.makeSettings();this._defaultDrive=null!==(n=e.defaultDrive)&&void 0!==n?n:new h({serverSettings:r}),this._defaultDrive.fileChanged.connect(this._onFileChanged,this)}get fileChanged(){return this._fileChanged}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,l.Signal.clearData(this))}addDrive(e){this._additionalDrives.set(e.name,e),e.fileChanged.connect(this._onFileChanged,this)}getModelDBFactory(e){var t;const[n]=this._driveForPath(e);return null!==(t=null==n?void 0:n.modelDBFactory)&&void 0!==t?t:null}localPath(e){const t=e.split("/"),n=t[0].split(":");return 1!==n.length&&this._additionalDrives.has(n[0])?a.PathExt.join(n.slice(1).join(":"),...t.slice(1)):a.PathExt.removeSlash(e)}normalize(e){const t=e.split(":");return 1===t.length?a.PathExt.normalize(e):`${t[0]}:${a.PathExt.normalize(t.slice(1).join(":"))}`}resolvePath(e,t){const n=this.driveName(e),r=this.localPath(e),i=a.PathExt.resolve("/",r,t);return n?`${n}:${i}`:i}driveName(e){const t=e.split("/")[0].split(":");return 1===t.length?"":this._additionalDrives.has(t[0])?t[0]:""}get(e,t){const[n,r]=this._driveForPath(e);return n.get(r,t).then(e=>{const t=[];return"directory"===e.type&&e.content?(s.each(e.content,e=>{t.push(Object.assign(Object.assign({},e),{path:this._toGlobalPath(n,e.path)}))}),Object.assign(Object.assign({},e),{path:this._toGlobalPath(n,r),content:t})):Object.assign(Object.assign({},e),{path:this._toGlobalPath(n,r)})})}getDownloadUrl(e){const[t,n]=this._driveForPath(e);return t.getDownloadUrl(n)}newUntitled(e={}){if(e.path){const t=this.normalize(e.path),[n,r]=this._driveForPath(t);return n.newUntitled(Object.assign(Object.assign({},e),{path:r})).then(e=>Object.assign(Object.assign({},e),{path:a.PathExt.join(t,e.name)}))}return this._defaultDrive.newUntitled(e)}delete(e){const[t,n]=this._driveForPath(e);return t.delete(n)}rename(e,t){const[n,r]=this._driveForPath(e),[i,o]=this._driveForPath(t);if(n!==i)throw Error("ContentsManager: renaming files must occur within a Drive");return n.rename(r,o).then(e=>Object.assign(Object.assign({},e),{path:this._toGlobalPath(n,o)}))}save(e,t={}){const n=this.normalize(e),[r,i]=this._driveForPath(e);return r.save(i,Object.assign(Object.assign({},t),{path:i})).then(e=>Object.assign(Object.assign({},e),{path:n}))}copy(e,t){const[n,r]=this._driveForPath(e),[i,o]=this._driveForPath(t);if(n===i)return n.copy(r,o).then(e=>Object.assign(Object.assign({},e),{path:this._toGlobalPath(n,e.path)}));throw Error("Copying files between drives is not currently implemented")}createCheckpoint(e){const[t,n]=this._driveForPath(e);return t.createCheckpoint(n)}listCheckpoints(e){const[t,n]=this._driveForPath(e);return t.listCheckpoints(n)}restoreCheckpoint(e,t){const[n,r]=this._driveForPath(e);return n.restoreCheckpoint(r,t)}deleteCheckpoint(e,t){const[n,r]=this._driveForPath(e);return n.deleteCheckpoint(r,t)}_toGlobalPath(e,t){return e===this._defaultDrive?a.PathExt.removeSlash(t):`${e.name}:${a.PathExt.removeSlash(t)}`}_driveForPath(e){const t=this.driveName(e),n=this.localPath(e);return t?[this._additionalDrives.get(t),n]:[this._defaultDrive,n]}_onFileChanged(e,t){var n,r;if(e===this._defaultDrive)this._fileChanged.emit(t);else{let i=null,o=null;(null===(n=t.newValue)||void 0===n?void 0:n.path)&&(i=Object.assign(Object.assign({},t.newValue),{path:this._toGlobalPath(e,t.newValue.path)})),(null===(r=t.oldValue)||void 0===r?void 0:r.path)&&(o=Object.assign(Object.assign({},t.oldValue),{path:this._toGlobalPath(e,t.oldValue.path)})),this._fileChanged.emit({type:t.type,newValue:i,oldValue:o})}}};class h{constructor(e={}){var t,n,r;this._isDisposed=!1,this._fileChanged=new l.Signal(this),this.name=null!==(t=e.name)&&void 0!==t?t:"Default",this._apiEndpoint=null!==(n=e.apiEndpoint)&&void 0!==n?n:"api/contents",this.serverSettings=null!==(r=e.serverSettings)&&void 0!==r?r:c.ServerConnection.makeSettings()}get fileChanged(){return this._fileChanged}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,l.Signal.clearData(this))}async get(e,t){let n=this._getUrl(e);if(t){"notebook"===t.type&&delete t.format;const e=t.content?"1":"0",r=Object.assign(Object.assign({},t),{content:e});n+=a.URLExt.objectToQueryString(r)}const r=this.serverSettings,i=await c.ServerConnection.makeRequest(n,{},r);if(200!==i.status){throw await c.ServerConnection.ResponseError.create(i)}const o=await i.json();return u.validateContentsModel(o),o}getDownloadUrl(e){const t=this.serverSettings.baseUrl;let n=a.URLExt.join(t,"files",a.URLExt.encodeParts(e));const r=document.cookie.match("\\b_xsrf=([^;]*)\\b");if(r){const e=new URL(n);e.searchParams.append("_xsrf",r[1]),n=e.toString()}return Promise.resolve(n)}async newUntitled(e={}){var t;let n="{}";e&&(e.ext&&(e.ext=d.normalizeExtension(e.ext)),n=JSON.stringify(e));const r=this.serverSettings,i=this._getUrl(null!==(t=e.path)&&void 0!==t?t:""),o={method:"POST",body:n},a=await c.ServerConnection.makeRequest(i,o,r);if(201!==a.status){throw await c.ServerConnection.ResponseError.create(a)}const s=await a.json();return u.validateContentsModel(s),this._fileChanged.emit({type:"new",oldValue:null,newValue:s}),s}async delete(e){const t=this._getUrl(e),n=this.serverSettings,r=await c.ServerConnection.makeRequest(t,{method:"DELETE"},n);if(204!==r.status){throw await c.ServerConnection.ResponseError.create(r)}this._fileChanged.emit({type:"delete",oldValue:{path:e},newValue:null})}async rename(e,t){const n=this.serverSettings,r=this._getUrl(e),i={method:"PATCH",body:JSON.stringify({path:t})},o=await c.ServerConnection.makeRequest(r,i,n);if(200!==o.status){throw await c.ServerConnection.ResponseError.create(o)}const a=await o.json();return u.validateContentsModel(a),this._fileChanged.emit({type:"rename",oldValue:{path:e},newValue:a}),a}async save(e,t={}){const n=this.serverSettings,r=this._getUrl(e),i={method:"PUT",body:JSON.stringify(t)},o=await c.ServerConnection.makeRequest(r,i,n);if(200!==o.status&&201!==o.status){throw await c.ServerConnection.ResponseError.create(o)}const a=await o.json();return u.validateContentsModel(a),this._fileChanged.emit({type:"save",oldValue:null,newValue:a}),a}async copy(e,t){const n=this.serverSettings,r=this._getUrl(t),i={method:"POST",body:JSON.stringify({copy_from:e})},o=await c.ServerConnection.makeRequest(r,i,n);if(201!==o.status){throw await c.ServerConnection.ResponseError.create(o)}const a=await o.json();return u.validateContentsModel(a),this._fileChanged.emit({type:"new",oldValue:null,newValue:a}),a}async createCheckpoint(e){const t=this._getUrl(e,"checkpoints"),n=await c.ServerConnection.makeRequest(t,{method:"POST"},this.serverSettings);if(201!==n.status){throw await c.ServerConnection.ResponseError.create(n)}const r=await n.json();return u.validateCheckpointModel(r),r}async listCheckpoints(e){const t=this._getUrl(e,"checkpoints"),n=await c.ServerConnection.makeRequest(t,{},this.serverSettings);if(200!==n.status){throw await c.ServerConnection.ResponseError.create(n)}const r=await n.json();if(!Array.isArray(r))throw new Error("Invalid Checkpoint list");for(let e=0;e<r.length;e++)u.validateCheckpointModel(r[e]);return r}async restoreCheckpoint(e,t){const n=this._getUrl(e,"checkpoints",t),r=await c.ServerConnection.makeRequest(n,{method:"POST"},this.serverSettings);if(204!==r.status){throw await c.ServerConnection.ResponseError.create(r)}}async deleteCheckpoint(e,t){const n=this._getUrl(e,"checkpoints",t),r=await c.ServerConnection.makeRequest(n,{method:"DELETE"},this.serverSettings);if(204!==r.status){throw await c.ServerConnection.ResponseError.create(r)}}_getUrl(...e){const t=e.map(e=>a.URLExt.encodeParts(e)),n=this.serverSettings.baseUrl;return a.URLExt.join(n,this._apiEndpoint,...t)}}t.Drive=h,function(e){e.normalizeExtension=function(e){return e.length>0&&0!==e.indexOf(".")&&(e="."+e),e}}(d||(d={}))},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t},a=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.KernelAPI=t.KernelMessage=t.Kernel=void 0;const s=o(n(622));t.Kernel=s;const l=o(n(120));t.KernelMessage=l;const c=o(n(152));t.KernelAPI=c,a(n(625),t)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getSpecs=void 0;const r=n(56),i=n(630),o=n(12);t.getSpecs=async function(e=r.ServerConnection.makeSettings()){const t=o.URLExt.join(e.baseUrl,"api/kernelspecs"),n=await r.ServerConnection.makeRequest(t,{},e);if(200!==n.status){throw await r.ServerConnection.ResponseError.create(n)}const a=await n.json();return i.validateSpecModels(a)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.NbConvertManager=void 0;const r=n(12),i=n(56);t.NbConvertManager=class{constructor(e={}){var t;this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:i.ServerConnection.makeSettings()}async getExportFormats(){const e=this.serverSettings.baseUrl,t=r.URLExt.join(e,"api/nbconvert"),{serverSettings:n}=this,o=await i.ServerConnection.makeRequest(t,{},n);if(200!==o.status){throw await i.ServerConnection.ResponseError.create(o)}const a=await o.json(),s={};return Object.keys(a).forEach((function(e){const t=a[e].output_mimetype;s[e]={output_mimetype:t}})),s}}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t},a=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.SessionAPI=t.Session=void 0;const s=o(n(634));t.Session=s;const l=o(n(155));t.SessionAPI=l,a(n(636),t)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.SettingManager=void 0;const r=n(12),i=n(97),o=n(56);class a extends i.DataConnector{constructor(e={}){var t;super(),this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:o.ServerConnection.makeSettings()}async fetch(e){if(!e)throw new Error("Plugin `id` parameter is required for settings fetch.");const{serverSettings:t}=this,{baseUrl:n,appUrl:r}=t,{makeRequest:i,ResponseError:a}=o.ServerConnection,l=n+r,c=s.url(l,e),u=await i(c,{},t);if(200!==u.status){throw await a.create(u)}return u.json()}async list(){var e,t;const{serverSettings:n}=this,{baseUrl:r,appUrl:i}=n,{makeRequest:a,ResponseError:l}=o.ServerConnection,c=r+i,u=s.url(c,""),d=await a(u,{},n);if(200!==d.status)throw new l(d);const h=await d.json(),p=null!==(t=null===(e=null==h?void 0:h.settings)||void 0===e?void 0:e.map(e=>(e.data={composite:{},user:{}},e)))&&void 0!==t?t:[];return{ids:p.map(e=>e.id),values:p}}async save(e,t){const{serverSettings:n}=this,{baseUrl:r,appUrl:i}=n,{makeRequest:a,ResponseError:l}=o.ServerConnection,c=r+i,u=s.url(c,e),d={body:JSON.stringify({raw:t}),method:"PUT"},h=await a(u,d,n);if(204!==h.status)throw new l(h)}}var s;t.SettingManager=a,function(e){e.url=function(e,t){return r.URLExt.join(e,"api/settings",t)}}(s||(s={}))},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t},a=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.TerminalAPI=t.Terminal=void 0;const s=o(n(643));t.Terminal=s;const l=o(n(122));t.TerminalAPI=l,a(n(644),t)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.WorkspaceManager=void 0;const r=n(12),i=n(97),o=n(56);class a extends i.DataConnector{constructor(e={}){var t;super(),this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:o.ServerConnection.makeSettings()}async fetch(e){const{serverSettings:t}=this,{baseUrl:n,appUrl:r}=t,{makeRequest:i,ResponseError:a}=o.ServerConnection,l=n+r,c=s.url(l,e),u=await i(c,{},t);if(200!==u.status){throw await a.create(u)}return u.json()}async list(){const{serverSettings:e}=this,{baseUrl:t,appUrl:n}=e,{makeRequest:r,ResponseError:i}=o.ServerConnection,a=t+n,l=s.url(a,""),c=await r(l,{},e);if(200!==c.status){throw await i.create(c)}return(await c.json()).workspaces}async remove(e){const{serverSettings:t}=this,{baseUrl:n,appUrl:r}=t,{makeRequest:i,ResponseError:a}=o.ServerConnection,l=n+r,c=s.url(l,e),u=await i(c,{method:"DELETE"},t);if(204!==u.status){throw await a.create(u)}}async save(e,t){const{serverSettings:n}=this,{baseUrl:r,appUrl:i}=n,{makeRequest:a,ResponseError:l}=o.ServerConnection,c=r+i,u=s.url(c,e),d={body:JSON.stringify(t),method:"PUT"},h=await a(u,d,n);if(204!==h.status){throw await l.create(h)}}}var s;t.WorkspaceManager=a,function(e){e.url=function(e,t){return r.URLExt.join(e,"api/workspaces",t)}}(s||(s={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return a})),n.d(t,"b",(function(){return s}));var r=n(118),i=n.n(r);class o{static reg(e){return new RegExp("^"+e+"$","i")}}o.N={integer:"[+-]?[0-9]+",integer_pos:"[+]?[0-9]+",integer_zero_ff:"([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])",number:"[+-]?([0-9]*[.])?[0-9]+(e-?[0-9]*)?",number_pos:"[+]?([0-9]*[.])?[0-9]+(e-?[0-9]*)?",number_zero_hundred:"[+]?(([0-9]|[1-9][0-9])([.][0-9]+)?|100)",number_zero_one:"[+]?(1([.][0]+)?|0([.][0-9]+)?)"},o.B={angle:`(${o.N.number}(deg|rad|grad|turn)|0)`,frequency:o.N.number+"(Hz|kHz)",ident:String.raw`-?([_a-z]|[\xA0-\xFF]|\\[0-9a-f]{1,6}(\r\n|[ \t\r\n\f])?|\\[^\r\n\f0-9a-f])([_a-z0-9-]|[\xA0-\xFF]|\\[0-9a-f]{1,6}(\r\n|[ \t\r\n\f])?|\\[^\r\n\f0-9a-f])*`,len_or_perc:`(0|${o.N.number}(px|em|rem|ex|in|cm|mm|pt|pc|%))`,length:`(${o.N.number}(px|em|rem|ex|in|cm|mm|pt|pc)|0)`,length_pos:`(${o.N.number_pos}(px|em|rem|ex|in|cm|mm|pt|pc)|0)`,percentage:o.N.number+"%",percentage_pos:o.N.number_pos+"%",percentage_zero_hundred:o.N.number_zero_hundred+"%",string:String.raw`(\"([^\n\r\f\\"]|\\\n|\r\n|\r|\f|\\[0-9a-f]{1,6}(\r\n|[ \t\r\n\f])?|\\[^\r\n\f0-9a-f])*\")|(\'([^\n\r\f\\']|\\\n|\r\n|\r|\f|\\[0-9a-f]{1,6}(\r\n|[ \t\r\n\f])?|\\[^\r\n\f0-9a-f])*\')`,time:o.N.number+"(s|ms)",url:"url\\(.*?\\)",z_index:"[+-]?[0-9]{1,7}"},o.A={absolute_size:"xx-small|x-small|small|medium|large|x-large|xx-large",attachment:"scroll|fixed|local",bg_origin:"border-box|padding-box|content-box",border_style:"none|hidden|dotted|dashed|solid|double|groove|ridge|inset|outset",box:"border-box|padding-box|content-box",display_inside:"auto|block|table|flex|grid",display_outside:"block-level|inline-level|none|table-row-group|table-header-group|table-footer-group|table-row|table-cell|table-column-group|table-column|table-caption",ending_shape:"circle|ellipse",generic_family:"serif|sans-serif|cursive|fantasy|monospace",generic_voice:"male|female|child",relative_size:"smaller|larger",repeat_style:"repeat-x|repeat-y|((?:repeat|space|round|no-repeat)(?:\\s*(?:repeat|space|round|no-repeat))?)",side_or_corner:"(left|right)?\\s*(top|bottom)?",single_animation_direction:"normal|reverse|alternate|alternate-reverse",single_animation_fill_mode:"none|forwards|backwards|both",single_animation_play_state:"running|paused"},o._COLOR={hex:"\\#(0x)?[0-9a-f]+",name:"aliceblue|antiquewhite|aqua|aquamarine|azure|beige|bisque|black|blanchedalmond|blue|blueviolet|brown|burlywood|cadetblue|chartreuse|chocolate|coral|cornflowerblue|cornsilk|crimson|cyan|darkblue|darkcyan|darkgoldenrod|darkgray|darkgreen|darkkhaki|darkmagenta|darkolivegreen|darkorange|darkorchid|darkred|darksalmon|darkseagreen|darkslateblue|darkslategray|darkturquoise|darkviolet|deeppink|deepskyblue|dimgray|dodgerblue|firebrick|floralwhite|forestgreen|fuchsia|gainsboro|ghostwhite|gold|goldenrod|gray|green|greenyellow|honeydew|hotpink|indianred|indigo|ivory|khaki|lavender|lavenderblush|lawngreen|lemonchiffon|lightblue|lightcoral|lightcyan|lightgoldenrodyellow|lightgreen|lightgrey|lightpink|lightsalmon|lightseagreen|lightskyblue|lightslategray|lightsteelblue|lightyellow|lime|limegreen|linen|magenta|maroon|mediumaquamarine|mediumblue|mediumorchid|mediumpurple|mediumseagreen|mediumslateblue|mediumspringgreen|mediumturquoise|mediumvioletred|midnightblue|mintcream|mistyrose|moccasin|navajowhite|navy|oldlace|olive|olivedrab|orange|orangered|orchid|palegoldenrod|palegreen|paleturquoise|palevioletred|papayawhip|peachpuff|peru|pink|plum|powderblue|purple|red|rosybrown|royalblue|saddlebrown|salmon|sandybrown|seagreen|seashell|sienna|silver|skyblue|slateblue|slategray|snow|springgreen|steelblue|tan|teal|thistle|tomato|turquoise|transparent|violet|wheat|white|whitesmoke|yellow|yellowgreen",rgb:String.raw`rgb\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*\)`,rgba:String.raw`rgba\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(${o.N.integer_zero_ff}|${o.N.number_zero_one}|${o.B.percentage_zero_hundred})\s*\)`},o._C={alpha:`${o.N.integer_zero_ff}|${o.N.number_zero_one}|${o.B.percentage_zero_hundred}`,alphavalue:o.N.number_zero_one,bg_position:`((${o.B.len_or_perc}|left|center|right|top|bottom)\\s*){1,4}`,bg_size:`(${o.B.length_pos}|${o.B.percentage}|auto){1,2}|cover|contain`,border_width:"thin|medium|thick|"+o.B.length,bottom:o.B.length+"|auto",color:`${o._COLOR.hex}|${o._COLOR.rgb}|${o._COLOR.rgba}|${o._COLOR.name}`,family_name:`${o.B.string}|(${o.B.ident}\\s*)+`,image_decl:o.B.url,left:o.B.length+"|auto",loose_quotable_words:`(${o.B.ident})+`,margin_width:o.B.len_or_perc+"|auto",padding_width:`${o.B.length_pos}|${o.B.percentage_pos}`,page_url:o.B.url,position:`((${o.B.len_or_perc}|left|center|right|top|bottom)\\s*){1,4}`,right:o.B.length+"|auto",shadow:"",size:`closest-side|farthest-side|closest-corner|farthest-corner|${o.B.length}|(${o.B.len_or_perc})\\s+(${o.B.len_or_perc})`,top:o.B.length+"|auto"},o._C1={image_list:`image\\(\\s*(${o.B.url})*\\s*(${o.B.url}|${o._C.color})\\s*\\)`,shadow:`((${o._C.color})\\s+((${o.B.length})\\s*){2,4}(s+inset)?)|((inset\\s+)?((${o.B.length})\\s*){2,4}\\s*(${o._C.color})?)`},o._C2={bg_image:`(${o.B.url}|${o._C1.image_list})|none`,image:`${o.B.url}|${o._C1.image_list}`,shape:`rect\\(\\s*(${o._C.top})\\s*,\\s*(${o._C.right})\\s*,\\s*(${o._C.bottom})\\s*,\\s*(${o._C.left})\\s*\\)`},o.C=Object.assign(Object.assign(Object.assign({},o._C),o._C1),o._C2),o.AP={border_collapse:"collapse|separate",box:"normal|none|contents",box_sizing:"content-box|padding-box|border-box",caption_side:"top|bottom",clear:"none|left|right|both",direction:"ltr|rtl",empty_cells:"show|hide",float:"left|right|none",font_stretch:"normal|wider|narrower|ultra-condensed|extra-condensed|condensed|semi-condensed|semi-expanded|expanded|extra-expanded|ultra-expanded",font_style:"normal|italic|oblique",font_variant:"normal|small-caps",font_weight:"normal|bold|bolder|lighter|100|200|300|400|500|600|700|800|900",list_style_position:"inside|outside",list_style_type:"disc|circle|square|decimal|decimal-leading-zero|lower-roman|upper-roman|lower-greek|lower-latin|upper-latin|armenian|georgian|lower-alpha|upper-alpha|none",overflow:"visible|hidden|scroll|auto",overflow_wrap:"normal|break-word",overflow_x:"visible|hidden|scroll|auto|no-display|no-content",page_break_after:"auto|always|avoid|left|right",page_break_before:"auto|always|avoid|left|right",page_break_inside:"avoid|auto",position:"static|relative|absolute",resize:"none|both|horizontal|vertical",speak:"normal|none|spell-out",speak_header:"once|always",speak_numeral:"digits|continuous",speak_punctuation:"code|none",table_layout:"auto|fixed",text_align:"left|right|center|justify",text_decoration:"none|((underline|overline|line-through|blink)\\s*)+",text_transform:"capitalize|uppercase|lowercase|none",text_wrap:"normal|unrestricted|none|suppress",unicode_bidi:"normal|embed|bidi-override",visibility:"visible|hidden|collapse",white_space:"normal|pre|nowrap|pre-wrap|pre-line",word_break:"normal|keep-all|break-all"},o._CP={background_attachment:`${o.A.attachment}(,\\s*${o.A.attachment})*`,background_color:o.C.color,background_origin:`${o.A.box}(,\\s*${o.A.box})*`,background_repeat:`${o.A.repeat_style}(,\\s*${o.A.repeat_style})*`,border:`((${o.C.border_width}|${o.A.border_style}|${o.C.color})\\s*){1,3}`,border_radius:`((${o.B.len_or_perc})\\s*){1,4}(\\/\\s*((${o.B.len_or_perc})\\s*){1,4})?`,border_spacing:`${o.B.length}\\s*(${o.B.length})?`,border_top_color:o.C.color,border_top_style:o.A.border_style,border_width:`((${o.C.border_width})\\s*){1,4}`,color:o.C.color,cursor:`(${o.B.url}(\\s*,\\s*)?)*(auto|crosshair|default|pointer|move|e-resize|ne-resize|nw-resize|n-resize|se-resize|sw-resize|s-resize|w-resize|text|wait|help|progress|all-scroll|col-resize|hand|no-drop|not-allowed|row-resize|vertical-text)`,display:`inline|block|list-item|run-in|inline-list-item|inline-block|table|inline-table|table-cell|table-caption|flex|inline-flex|grid|inline-grid|${o.A.display_inside}|${o.A.display_outside}|inherit|inline-box|inline-stack`,display_outside:o.A.display_outside,elevation:o.B.angle+"|below|level|above|higher|lower",font_family:`(${o.C.family_name}|${o.A.generic_family})(,\\s*(${o.C.family_name}|${o.A.generic_family}))*`,height:`${o.B.length}|${o.B.percentage}|auto`,letter_spacing:"normal|"+o.B.length,list_style_image:o.C.image+"|none",margin_right:o.C.margin_width,max_height:`${o.B.length_pos}|${o.B.percentage_pos}|none|auto`,min_height:`${o.B.length_pos}|${o.B.percentage_pos}|auto`,opacity:o.C.alphavalue,outline_color:o.C.color+"|invert",outline_width:o.C.border_width,padding:`((${o.C.padding_width})\\s*){1,4}`,padding_top:o.C.padding_width,pitch_range:o.N.number,right:`${o.B.length}|${o.B.percentage}|auto`,stress:o.N.number,text_indent:`${o.B.length}|${o.B.percentage}`,text_shadow:`none|${o.C.shadow}(,\\s*(${o.C.shadow}))*`,volume:`${o.N.number_pos}|${o.B.percentage_pos}|silent|x-soft|soft|medium|loud|x-loud`,word_wrap:o.AP.overflow_wrap,zoom:`normal|${o.N.number_pos}|${o.B.percentage_pos}`,backface_visibility:o.AP.visibility,background_clip:`${o.A.box}(,\\s*(${o.A.box}))*`,background_position:`${o.C.bg_position}(,\\s*(${o.C.bg_position}))*`,border_bottom_color:o.C.color,border_bottom_style:o.A.border_style,border_color:`((${o.C.color})\\s*){1,4}`,border_left_color:o.C.color,border_right_color:o.C.color,border_style:`((${o.A.border_style})\\s*){1,4}`,border_top_left_radius:`(${o.B.length}|${o.B.percentage})(\\s*(${o.B.length}|${o.B.percentage}))?`,border_top_width:o.C.border_width,box_shadow:`none|${o.C.shadow}(,\\s*(${o.C.shadow}))*`,clip:o.C.shape+"|auto",display_inside:o.A.display_inside,font_size:`${o.A.absolute_size}|${o.A.relative_size}|${o.B.length_pos}|${o.B.percentage_pos}`,line_height:`normal|${o.N.number_pos}|${o.B.length_pos}|${o.B.percentage_pos}`,margin_left:o.C.margin_width,max_width:`${o.B.length_pos}|${o.B.percentage_pos}|none|auto`,outline_style:o.A.border_style,padding_bottom:o.C.padding_width,padding_right:o.C.padding_width,perspective:"none|"+o.B.length,richness:o.N.number,text_overflow:`((clip|ellipsis|${o.B.string})\\s*){1,2}`,top:`${o.B.length}|${o.B.percentage}|auto`,width:`${o.B.length_pos}|${o.B.percentage_pos}|auto`,z_index:"auto|"+o.B.z_index,background:`(((${o.C.bg_position}\\s*(\\/\\s*${o.C.bg_size})?)|(${o.A.repeat_style})|(${o.A.attachment})|(${o.A.bg_origin})|(${o.C.bg_image})|(${o.C.color}))\\s*)+`,background_size:`${o.C.bg_size}(,\\s*${o.C.bg_size})*`,border_bottom_left_radius:`(${o.B.length}|${o.B.percentage})(\\s*(${o.B.length}|${o.B.percentage}))?`,border_bottom_width:o.C.border_width,border_left_style:o.A.border_style,border_right_style:o.A.border_style,border_top:`((${o.C.border_width}|${o.A.border_style}|${o.C.color})\\s*){1,3}`,bottom:o.B.len_or_perc+"|auto",list_style:`((${o.AP.list_style_type}|${o.AP.list_style_position}|${o.C.image}|none})\\s*){1,3}`,margin_top:o.C.margin_width,outline:`((${o.C.color}|invert|${o.A.border_style}|${o.C.border_width})\\s*){1,3}`,overflow_y:o.AP.overflow_x,pitch:o.B.frequency+"|x-low|low|medium|high|x-high",vertical_align:"baseline|sub|super|top|text-top|middle|bottom|text-bottom|"+o.B.len_or_perc,word_spacing:"normal|"+o.B.length,background_image:`${o.C.bg_image}(,\\s*${o.C.bg_image})*`,border_bottom_right_radius:`(${o.B.length}|${o.B.percentage})(\\s*(${o.B.length}|${o.B.percentage}))?`,border_left_width:o.C.border_width,border_right_width:o.C.border_width,left:o.B.len_or_perc+"|auto",margin_bottom:o.C.margin_width,pause_after:`${o.B.time}|${o.B.percentage}`,speech_rate:o.N.number+"|x-slow|slow|medium|fast|x-fast|faster|slower",transition_duration:`${o.B.time}(,\\s*${o.B.time})*`,border_bottom:`((${o.C.border_width}|${o.A.border_style}|${o.C.color})\\s*){1,3}`,border_right:`((${o.C.border_width}|${o.A.border_style}|${o.C.color})\\s*){1,3}`,margin:`((${o.C.margin_width})\\s*){1,4}`,padding_left:o.C.padding_width,border_left:`((${o.C.border_width}|${o.A.border_style}|${o.C.color})\\s*){1,3}`,quotes:`(${o.B.string}\\s*${o.B.string})+|none`,border_top_right_radius:`(${o.B.length}|${o.B.percentage})(\\s*(${o.B.length}|${o.B.percentage}))?`,min_width:`${o.B.length_pos}|${o.B.percentage_pos}|auto`},o._CP1={font:`(((((${o.AP.font_style}|${o.AP.font_variant}|${o.AP.font_weight})\\s*){1,3})?\\s*(${o._CP.font_size})\\s*(\\/\\s*(${o._CP.line_height}))?\\s+(${o._CP.font_family}))|caption|icon|menu|message-box|small-caption|status-bar)`},o.CP=Object.assign(Object.assign({},o._CP),o._CP1),o.BORDER_COLLAPSE=o.reg(o.AP.border_collapse),o.BOX=o.reg(o.AP.box),o.BOX_SIZING=o.reg(o.AP.box_sizing),o.CAPTION_SIDE=o.reg(o.AP.caption_side),o.CLEAR=o.reg(o.AP.clear),o.DIRECTION=o.reg(o.AP.direction),o.EMPTY_CELLS=o.reg(o.AP.empty_cells),o.FLOAT=o.reg(o.AP.float),o.FONT_STRETCH=o.reg(o.AP.font_stretch),o.FONT_STYLE=o.reg(o.AP.font_style),o.FONT_VARIANT=o.reg(o.AP.font_variant),o.FONT_WEIGHT=o.reg(o.AP.font_weight),o.LIST_STYLE_POSITION=o.reg(o.AP.list_style_position),o.LIST_STYLE_TYPE=o.reg(o.AP.list_style_type),o.OVERFLOW=o.reg(o.AP.overflow),o.OVERFLOW_WRAP=o.reg(o.AP.overflow_wrap),o.OVERFLOW_X=o.reg(o.AP.overflow_x),o.PAGE_BREAK_AFTER=o.reg(o.AP.page_break_after),o.PAGE_BREAK_BEFORE=o.reg(o.AP.page_break_before),o.PAGE_BREAK_INSIDE=o.reg(o.AP.page_break_inside),o.POSITION=o.reg(o.AP.position),o.RESIZE=o.reg(o.AP.resize),o.SPEAK=o.reg(o.AP.speak),o.SPEAK_HEADER=o.reg(o.AP.speak_header),o.SPEAK_NUMERAL=o.reg(o.AP.speak_numeral),o.SPEAK_PUNCTUATION=o.reg(o.AP.speak_punctuation),o.TABLE_LAYOUT=o.reg(o.AP.table_layout),o.TEXT_ALIGN=o.reg(o.AP.text_align),o.TEXT_DECORATION=o.reg(o.AP.text_decoration),o.TEXT_TRANSFORM=o.reg(o.AP.text_transform),o.TEXT_WRAP=o.reg(o.AP.text_wrap),o.UNICODE_BIDI=o.reg(o.AP.unicode_bidi),o.VISIBILITY=o.reg(o.AP.visibility),o.WHITE_SPACE=o.reg(o.AP.white_space),o.WORD_BREAK=o.reg(o.AP.word_break),o.BACKGROUND_ATTACHMENT=o.reg(o.CP.background_attachment),o.BACKGROUND_COLOR=o.reg(o.CP.background_color),o.BACKGROUND_ORIGIN=o.reg(o.CP.background_origin),o.BACKGROUND_REPEAT=o.reg(o.CP.background_repeat),o.BORDER=o.reg(o.CP.border),o.BORDER_RADIUS=o.reg(o.CP.border_radius),o.BORDER_SPACING=o.reg(o.CP.border_spacing),o.BORDER_TOP_COLOR=o.reg(o.CP.border_top_color),o.BORDER_TOP_STYLE=o.reg(o.CP.border_top_style),o.BORDER_WIDTH=o.reg(o.CP.border_width),o.COLOR=o.reg(o.CP.color),o.CURSOR=o.reg(o.CP.cursor),o.DISPLAY=o.reg(o.CP.display),o.DISPLAY_OUTSIDE=o.reg(o.CP.display_outside),o.ELEVATION=o.reg(o.CP.elevation),o.FONT_FAMILY=o.reg(o.CP.font_family),o.HEIGHT=o.reg(o.CP.height),o.LETTER_SPACING=o.reg(o.CP.letter_spacing),o.LIST_STYLE_IMAGE=o.reg(o.CP.list_style_image),o.MARGIN_RIGHT=o.reg(o.CP.margin_right),o.MAX_HEIGHT=o.reg(o.CP.max_height),o.MIN_HEIGHT=o.reg(o.CP.min_height),o.OPACITY=o.reg(o.CP.opacity),o.OUTLINE_COLOR=o.reg(o.CP.outline_color),o.OUTLINE_WIDTH=o.reg(o.CP.outline_width),o.PADDING=o.reg(o.CP.padding),o.PADDING_TOP=o.reg(o.CP.padding_top),o.PITCH_RANGE=o.reg(o.CP.pitch_range),o.RIGHT=o.reg(o.CP.right),o.STRESS=o.reg(o.CP.stress),o.TEXT_INDENT=o.reg(o.CP.text_indent),o.TEXT_SHADOW=o.reg(o.CP.text_shadow),o.VOLUME=o.reg(o.CP.volume),o.WORD_WRAP=o.reg(o.CP.word_wrap),o.ZOOM=o.reg(o.CP.zoom),o.BACKFACE_VISIBILITY=o.reg(o.CP.backface_visibility),o.BACKGROUND_CLIP=o.reg(o.CP.background_clip),o.BACKGROUND_POSITION=o.reg(o.CP.background_position),o.BORDER_BOTTOM_COLOR=o.reg(o.CP.border_bottom_color),o.BORDER_BOTTOM_STYLE=o.reg(o.CP.border_bottom_style),o.BORDER_COLOR=o.reg(o.CP.border_color),o.BORDER_LEFT_COLOR=o.reg(o.CP.border_left_color),o.BORDER_RIGHT_COLOR=o.reg(o.CP.border_right_color),o.BORDER_STYLE=o.reg(o.CP.border_style),o.BORDER_TOP_LEFT_RADIUS=o.reg(o.CP.border_top_left_radius),o.BORDER_TOP_WIDTH=o.reg(o.CP.border_top_width),o.BOX_SHADOW=o.reg(o.CP.box_shadow),o.CLIP=o.reg(o.CP.clip),o.DISPLAY_INSIDE=o.reg(o.CP.display_inside),o.FONT_SIZE=o.reg(o.CP.font_size),o.LINE_HEIGHT=o.reg(o.CP.line_height),o.MARGIN_LEFT=o.reg(o.CP.margin_left),o.MAX_WIDTH=o.reg(o.CP.max_width),o.OUTLINE_STYLE=o.reg(o.CP.outline_style),o.PADDING_BOTTOM=o.reg(o.CP.padding_bottom),o.PADDING_RIGHT=o.reg(o.CP.padding_right),o.PERSPECTIVE=o.reg(o.CP.perspective),o.RICHNESS=o.reg(o.CP.richness),o.TEXT_OVERFLOW=o.reg(o.CP.text_overflow),o.TOP=o.reg(o.CP.top),o.WIDTH=o.reg(o.CP.width),o.Z_INDEX=o.reg(o.CP.z_index),o.BACKGROUND=o.reg(o.CP.background),o.BACKGROUND_SIZE=o.reg(o.CP.background_size),o.BORDER_BOTTOM_LEFT_RADIUS=o.reg(o.CP.border_bottom_left_radius),o.BORDER_BOTTOM_WIDTH=o.reg(o.CP.border_bottom_width),o.BORDER_LEFT_STYLE=o.reg(o.CP.border_left_style),o.BORDER_RIGHT_STYLE=o.reg(o.CP.border_right_style),o.BORDER_TOP=o.reg(o.CP.border_top),o.BOTTOM=o.reg(o.CP.bottom),o.LIST_STYLE=o.reg(o.CP.list_style),o.MARGIN_TOP=o.reg(o.CP.margin_top),o.OUTLINE=o.reg(o.CP.outline),o.OVERFLOW_Y=o.reg(o.CP.overflow_y),o.PITCH=o.reg(o.CP.pitch),o.VERTICAL_ALIGN=o.reg(o.CP.vertical_align),o.WORD_SPACING=o.reg(o.CP.word_spacing),o.BACKGROUND_IMAGE=o.reg(o.CP.background_image),o.BORDER_BOTTOM_RIGHT_RADIUS=o.reg(o.CP.border_bottom_right_radius),o.BORDER_LEFT_WIDTH=o.reg(o.CP.border_left_width),o.BORDER_RIGHT_WIDTH=o.reg(o.CP.border_right_width),o.LEFT=o.reg(o.CP.left),o.MARGIN_BOTTOM=o.reg(o.CP.margin_bottom),o.PAUSE_AFTER=o.reg(o.CP.pause_after),o.SPEECH_RATE=o.reg(o.CP.speech_rate),o.TRANSITION_DURATION=o.reg(o.CP.transition_duration),o.BORDER_BOTTOM=o.reg(o.CP.border_bottom),o.BORDER_RIGHT=o.reg(o.CP.border_right),o.MARGIN=o.reg(o.CP.margin),o.PADDING_LEFT=o.reg(o.CP.padding_left),o.BORDER_LEFT=o.reg(o.CP.border_left),o.FONT=o.reg(o.CP.font),o.QUOTES=o.reg(o.CP.quotes),o.BORDER_TOP_RIGHT_RADIUS=o.reg(o.CP.border_top_right_radius),o.MIN_WIDTH=o.reg(o.CP.min_width);class a{constructor(){this._options={allowedTags:["a","abbr","acronym","address","area","article","aside","audio","b","bdi","bdo","big","blockquote","br","button","canvas","caption","center","cite","code","col","colgroup","colspan","command","data","datalist","dd","del","details","dfn","dir","div","dl","dt","em","fieldset","figcaption","figure","font","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","hr","i","img","input","ins","kbd","label","legend","li","map","mark","menu","meter","nav","nobr","ol","optgroup","option","output","p","pre","progress","q","rowspan","s","samp","section","select","small","source","span","strike","strong","sub","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","track","tt","u","ul","var","video","wbr"],allowedAttributes:{"*":["class","dir","draggable","hidden","id","inert","itemprop","itemref","itemscope","lang","spellcheck","style","title","translate"],a:["accesskey","coords","href","hreflang","name","rel","shape","tabindex","target","type"],area:["accesskey","alt","coords","href","nohref","shape","tabindex"],audio:["autoplay","controls","loop","mediagroup","muted","preload","src"],bdo:["dir"],blockquote:["cite"],br:["clear"],button:["accesskey","data-commandlinker-args","data-commandlinker-command","disabled","name","tabindex","type","value"],canvas:["height","width"],caption:["align"],col:["align","char","charoff","span","valign","width"],colgroup:["align","char","charoff","span","valign","width"],command:["checked","command","disabled","icon","label","radiogroup","type"],data:["value"],del:["cite","datetime"],details:["open"],dir:["compact"],div:["align"],dl:["compact"],fieldset:["disabled"],font:["color","face","size"],form:["accept","autocomplete","enctype","method","name","novalidate"],h1:["align"],h2:["align"],h3:["align"],h4:["align"],h5:["align"],h6:["align"],hr:["align","noshade","size","width"],iframe:["align","frameborder","height","marginheight","marginwidth","width"],img:["align","alt","border","height","hspace","ismap","name","src","usemap","vspace","width"],input:["accept","accesskey","align","alt","autocomplete","checked","disabled","inputmode","ismap","list","max","maxlength","min","multiple","name","placeholder","readonly","required","size","src","step","tabindex","type","usemap","value"],ins:["cite","datetime"],label:["accesskey","for"],legend:["accesskey","align"],li:["type","value"],map:["name"],menu:["compact","label","type"],meter:["high","low","max","min","value"],ol:["compact","reversed","start","type"],optgroup:["disabled","label"],option:["disabled","label","selected","value"],output:["for","name"],p:["align"],pre:["width"],progress:["max","min","value"],q:["cite"],select:["autocomplete","disabled","multiple","name","required","size","tabindex"],source:["type"],table:["align","bgcolor","border","cellpadding","cellspacing","frame","rules","summary","width"],tbody:["align","char","charoff","valign"],td:["abbr","align","axis","bgcolor","char","charoff","colspan","headers","height","nowrap","rowspan","scope","valign","width"],textarea:["accesskey","autocomplete","cols","disabled","inputmode","name","placeholder","readonly","required","rows","tabindex","wrap"],tfoot:["align","char","charoff","valign"],th:["abbr","align","axis","bgcolor","char","charoff","colspan","headers","height","nowrap","rowspan","scope","valign","width"],thead:["align","char","charoff","valign"],tr:["align","bgcolor","char","charoff","valign"],track:["default","kind","label","srclang"],ul:["compact","type"],video:["autoplay","controls","height","loop","mediagroup","muted","poster","preload","src","width"]},allowedStyles:{"*":{"backface-visibility":[o.BACKFACE_VISIBILITY],background:[o.BACKGROUND],"background-attachment":[o.BACKGROUND_ATTACHMENT],"background-clip":[o.BACKGROUND_CLIP],"background-color":[o.BACKGROUND_COLOR],"background-image":[o.BACKGROUND_IMAGE],"background-origin":[o.BACKGROUND_ORIGIN],"background-position":[o.BACKGROUND_POSITION],"background-repeat":[o.BACKGROUND_REPEAT],"background-size":[o.BACKGROUND_SIZE],border:[o.BORDER],"border-bottom":[o.BORDER_BOTTOM],"border-bottom-color":[o.BORDER_BOTTOM_COLOR],"border-bottom-left-radius":[o.BORDER_BOTTOM_LEFT_RADIUS],"border-bottom-right-radius":[o.BORDER_BOTTOM_RIGHT_RADIUS],"border-bottom-style":[o.BORDER_BOTTOM_STYLE],"border-bottom-width":[o.BORDER_BOTTOM_WIDTH],"border-collapse":[o.BORDER_COLLAPSE],"border-color":[o.BORDER_COLOR],"border-left":[o.BORDER_LEFT],"border-left-color":[o.BORDER_LEFT_COLOR],"border-left-style":[o.BORDER_LEFT_STYLE],"border-left-width":[o.BORDER_LEFT_WIDTH],"border-radius":[o.BORDER_RADIUS],"border-right":[o.BORDER_RIGHT],"border-right-color":[o.BORDER_RIGHT_COLOR],"border-right-style":[o.BORDER_RIGHT_STYLE],"border-right-width":[o.BORDER_RIGHT_WIDTH],"border-spacing":[o.BORDER_SPACING],"border-style":[o.BORDER_STYLE],"border-top":[o.BORDER_TOP],"border-top-color":[o.BORDER_TOP_COLOR],"border-top-left-radius":[o.BORDER_TOP_LEFT_RADIUS],"border-top-right-radius":[o.BORDER_TOP_RIGHT_RADIUS],"border-top-style":[o.BORDER_TOP_STYLE],"border-top-width":[o.BORDER_TOP_WIDTH],"border-width":[o.BORDER_WIDTH],bottom:[o.BOTTOM],box:[o.BOX],"box-shadow":[o.BOX_SHADOW],"box-sizing":[o.BOX_SIZING],"caption-side":[o.CAPTION_SIDE],clear:[o.CLEAR],clip:[o.CLIP],color:[o.COLOR],cursor:[o.CURSOR],direction:[o.DIRECTION],display:[o.DISPLAY],"display-inside":[o.DISPLAY_INSIDE],"display-outside":[o.DISPLAY_OUTSIDE],elevation:[o.ELEVATION],"empty-cells":[o.EMPTY_CELLS],float:[o.FLOAT],font:[o.FONT],"font-family":[o.FONT_FAMILY],"font-size":[o.FONT_SIZE],"font-stretch":[o.FONT_STRETCH],"font-style":[o.FONT_STYLE],"font-variant":[o.FONT_VARIANT],"font-weight":[o.FONT_WEIGHT],height:[o.HEIGHT],left:[o.LEFT],"letter-spacing":[o.LETTER_SPACING],"line-height":[o.LINE_HEIGHT],"list-style":[o.LIST_STYLE],"list-style-image":[o.LIST_STYLE_IMAGE],"list-style-position":[o.LIST_STYLE_POSITION],"list-style-type":[o.LIST_STYLE_TYPE],margin:[o.MARGIN],"margin-bottom":[o.MARGIN_BOTTOM],"margin-left":[o.MARGIN_LEFT],"margin-right":[o.MARGIN_RIGHT],"margin-top":[o.MARGIN_TOP],"max-height":[o.MAX_HEIGHT],"max-width":[o.MAX_WIDTH],"min-height":[o.MIN_HEIGHT],"min-width":[o.MIN_WIDTH],opacity:[o.OPACITY],outline:[o.OUTLINE],"outline-color":[o.OUTLINE_COLOR],"outline-style":[o.OUTLINE_STYLE],"outline-width":[o.OUTLINE_WIDTH],overflow:[o.OVERFLOW],"overflow-wrap":[o.OVERFLOW_WRAP],"overflow-x":[o.OVERFLOW_X],"overflow-y":[o.OVERFLOW_Y],padding:[o.PADDING],"padding-bottom":[o.PADDING_BOTTOM],"padding-left":[o.PADDING_LEFT],"padding-right":[o.PADDING_RIGHT],"padding-top":[o.PADDING_TOP],"page-break-after":[o.PAGE_BREAK_AFTER],"page-break-before":[o.PAGE_BREAK_BEFORE],"page-break-inside":[o.PAGE_BREAK_INSIDE],"pause-after":[o.PAUSE_AFTER],perspective:[o.PERSPECTIVE],pitch:[o.PITCH],"pitch-range":[o.PITCH_RANGE],position:[o.POSITION],quotes:[o.QUOTES],resize:[o.RESIZE],richness:[o.RICHNESS],right:[o.RIGHT],speak:[o.SPEAK],"speak-header":[o.SPEAK_HEADER],"speak-numeral":[o.SPEAK_NUMERAL],"speak-punctuation":[o.SPEAK_PUNCTUATION],"speech-rate":[o.SPEECH_RATE],stress:[o.STRESS],"table-layout":[o.TABLE_LAYOUT],"text-align":[o.TEXT_ALIGN],"text-decoration":[o.TEXT_DECORATION],"text-indent":[o.TEXT_INDENT],"text-overflow":[o.TEXT_OVERFLOW],"text-shadow":[o.TEXT_SHADOW],"text-transform":[o.TEXT_TRANSFORM],"text-wrap":[o.TEXT_WRAP],top:[o.TOP],"unicode-bidi":[o.UNICODE_BIDI],"vertical-align":[o.VERTICAL_ALIGN],visibility:[o.VISIBILITY],volume:[o.VOLUME],"white-space":[o.WHITE_SPACE],width:[o.WIDTH],"word-break":[o.WORD_BREAK],"word-spacing":[o.WORD_SPACING],"word-wrap":[o.WORD_WRAP],"z-index":[o.Z_INDEX],zoom:[o.ZOOM]}},transformTags:{a:i.a.simpleTransform("a",{rel:"nofollow"}),input:i.a.simpleTransform("input",{disabled:"disabled"})},allowedSchemesByTag:{img:i.a.defaults.allowedSchemes.concat(["attachment"])},allowedSchemesAppliedToAttributes:["href","cite"]}}sanitize(e,t){return i()(e,Object.assign(Object.assign({},this._options),t||{}))}}const s=new a},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.Parser=void 0;var i=r(n(356)),o=new Set(["input","option","optgroup","select","button","datalist","textarea"]),a=new Set(["p"]),s={tr:new Set(["tr","th","td"]),th:new Set(["th"]),td:new Set(["thead","th","td"]),body:new Set(["head","link","script"]),li:new Set(["li"]),p:a,h1:a,h2:a,h3:a,h4:a,h5:a,h6:a,select:o,input:o,output:o,button:o,datalist:o,textarea:o,option:new Set(["option"]),optgroup:new Set(["optgroup","option"]),dd:new Set(["dt","dd"]),dt:new Set(["dt","dd"]),address:a,article:a,aside:a,blockquote:a,details:a,div:a,dl:a,fieldset:a,figcaption:a,figure:a,footer:a,form:a,header:a,hr:a,main:a,nav:a,ol:a,pre:a,section:a,table:a,ul:a,rt:new Set(["rt","rp"]),rp:new Set(["rt","rp"]),tbody:new Set(["thead","tbody"]),tfoot:new Set(["thead","tbody"])},l=new Set(["area","base","basefont","br","col","command","embed","frame","hr","img","input","isindex","keygen","link","meta","param","source","track","wbr"]),c=new Set(["math","svg"]),u=new Set(["mi","mo","mn","ms","mtext","annotation-xml","foreignObject","desc","title"]),d=/\s|\//,h=function(){function e(e,t){var n,r,o,a,s;void 0===t&&(t={}),this.startIndex=0,this.endIndex=null,this.tagname="",this.attribname="",this.attribvalue="",this.attribs=null,this.stack=[],this.foreignContext=[],this.options=t,this.cbs=null!=e?e:{},this.lowerCaseTagNames=null!==(n=t.lowerCaseTags)&&void 0!==n?n:!t.xmlMode,this.lowerCaseAttributeNames=null!==(r=t.lowerCaseAttributeNames)&&void 0!==r?r:!t.xmlMode,this.tokenizer=new(null!==(o=t.Tokenizer)&&void 0!==o?o:i.default)(this.options,this),null===(s=(a=this.cbs).onparserinit)||void 0===s||s.call(a,this)}return e.prototype.updatePosition=function(e){null===this.endIndex?this.tokenizer.sectionStart<=e?this.startIndex=0:this.startIndex=this.tokenizer.sectionStart-e:this.startIndex=this.endIndex+1,this.endIndex=this.tokenizer.getAbsoluteIndex()},e.prototype.ontext=function(e){var t,n;this.updatePosition(1),this.endIndex--,null===(n=(t=this.cbs).ontext)||void 0===n||n.call(t,e)},e.prototype.onopentagname=function(e){var t,n;if(this.lowerCaseTagNames&&(e=e.toLowerCase()),this.tagname=e,!this.options.xmlMode&&Object.prototype.hasOwnProperty.call(s,e))for(var r=void 0;this.stack.length>0&&s[e].has(r=this.stack[this.stack.length-1]);)this.onclosetag(r);!this.options.xmlMode&&l.has(e)||(this.stack.push(e),c.has(e)?this.foreignContext.push(!0):u.has(e)&&this.foreignContext.push(!1)),null===(n=(t=this.cbs).onopentagname)||void 0===n||n.call(t,e),this.cbs.onopentag&&(this.attribs={})},e.prototype.onopentagend=function(){var e,t;this.updatePosition(1),this.attribs&&(null===(t=(e=this.cbs).onopentag)||void 0===t||t.call(e,this.tagname,this.attribs),this.attribs=null),!this.options.xmlMode&&this.cbs.onclosetag&&l.has(this.tagname)&&this.cbs.onclosetag(this.tagname),this.tagname=""},e.prototype.onclosetag=function(e){if(this.updatePosition(1),this.lowerCaseTagNames&&(e=e.toLowerCase()),(c.has(e)||u.has(e))&&this.foreignContext.pop(),!this.stack.length||!this.options.xmlMode&&l.has(e))this.options.xmlMode||"br"!==e&&"p"!==e||(this.onopentagname(e),this.closeCurrentTag());else{var t=this.stack.lastIndexOf(e);if(-1!==t)if(this.cbs.onclosetag)for(t=this.stack.length-t;t--;)this.cbs.onclosetag(this.stack.pop());else this.stack.length=t;else"p"!==e||this.options.xmlMode||(this.onopentagname(e),this.closeCurrentTag())}},e.prototype.onselfclosingtag=function(){this.options.xmlMode||this.options.recognizeSelfClosing||this.foreignContext[this.foreignContext.length-1]?this.closeCurrentTag():this.onopentagend()},e.prototype.closeCurrentTag=function(){var e,t,n=this.tagname;this.onopentagend(),this.stack[this.stack.length-1]===n&&(null===(t=(e=this.cbs).onclosetag)||void 0===t||t.call(e,n),this.stack.pop())},e.prototype.onattribname=function(e){this.lowerCaseAttributeNames&&(e=e.toLowerCase()),this.attribname=e},e.prototype.onattribdata=function(e){this.attribvalue+=e},e.prototype.onattribend=function(e){var t,n;null===(n=(t=this.cbs).onattribute)||void 0===n||n.call(t,this.attribname,this.attribvalue,e),this.attribs&&!Object.prototype.hasOwnProperty.call(this.attribs,this.attribname)&&(this.attribs[this.attribname]=this.attribvalue),this.attribname="",this.attribvalue=""},e.prototype.getInstructionName=function(e){var t=e.search(d),n=t<0?e:e.substr(0,t);return this.lowerCaseTagNames&&(n=n.toLowerCase()),n},e.prototype.ondeclaration=function(e){if(this.cbs.onprocessinginstruction){var t=this.getInstructionName(e);this.cbs.onprocessinginstruction("!"+t,"!"+e)}},e.prototype.onprocessinginstruction=function(e){if(this.cbs.onprocessinginstruction){var t=this.getInstructionName(e);this.cbs.onprocessinginstruction("?"+t,"?"+e)}},e.prototype.oncomment=function(e){var t,n,r,i;this.updatePosition(4),null===(n=(t=this.cbs).oncomment)||void 0===n||n.call(t,e),null===(i=(r=this.cbs).oncommentend)||void 0===i||i.call(r)},e.prototype.oncdata=function(e){var t,n,r,i,o,a;this.updatePosition(1),this.options.xmlMode||this.options.recognizeCDATA?(null===(n=(t=this.cbs).oncdatastart)||void 0===n||n.call(t),null===(i=(r=this.cbs).ontext)||void 0===i||i.call(r,e),null===(a=(o=this.cbs).oncdataend)||void 0===a||a.call(o)):this.oncomment("[CDATA["+e+"]]")},e.prototype.onerror=function(e){var t,n;null===(n=(t=this.cbs).onerror)||void 0===n||n.call(t,e)},e.prototype.onend=function(){var e,t;if(this.cbs.onclosetag)for(var n=this.stack.length;n>0;this.cbs.onclosetag(this.stack[--n]));null===(t=(e=this.cbs).onend)||void 0===t||t.call(e)},e.prototype.reset=function(){var e,t,n,r;null===(t=(e=this.cbs).onreset)||void 0===t||t.call(e),this.tokenizer.reset(),this.tagname="",this.attribname="",this.attribs=null,this.stack=[],null===(r=(n=this.cbs).onparserinit)||void 0===r||r.call(n,this)},e.prototype.parseComplete=function(e){this.reset(),this.end(e)},e.prototype.write=function(e){this.tokenizer.write(e)},e.prototype.end=function(e){this.tokenizer.end(e)},e.prototype.pause=function(){this.tokenizer.pause()},e.prototype.resume=function(){this.tokenizer.resume()},e.prototype.parseChunk=function(e){this.write(e)},e.prototype.done=function(e){this.end(e)},e}();t.Parser=h},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0});var i=r(n(357)),o=r(n(156)),a=r(n(358)),s=r(n(157));function l(e){return" "===e||"\n"===e||"\t"===e||"\f"===e||"\r"===e}function c(e){return e>="a"&&e<="z"||e>="A"&&e<="Z"}function u(e,t,n){var r=e.toLowerCase();return e===r?function(e,i){i===r?e._state=t:(e._state=n,e._index--)}:function(i,o){o===r||o===e?i._state=t:(i._state=n,i._index--)}}function d(e,t){var n=e.toLowerCase();return function(r,i){i===n||i===e?r._state=t:(r._state=3,r._index--)}}var h=u("C",24,16),p=u("D",25,16),f=u("A",26,16),m=u("T",27,16),g=u("A",28,16),v=d("R",35),y=d("I",36),_=d("P",37),b=d("T",38),M=u("R",40,1),w=u("I",41,1),A=u("P",42,1),C=u("T",43,1),x=d("Y",45),E=d("L",46),L=d("E",47),S=u("Y",49,1),T=u("L",50,1),O=u("E",51,1),I=d("I",54),k=d("T",55),D=d("L",56),N=d("E",57),j=u("I",58,1),P=u("T",59,1),z=u("L",60,1),R=u("E",61,1),B=u("#",63,64),H=u("X",66,65),F=function(){function e(e,t){var n;this._state=1,this.buffer="",this.sectionStart=0,this._index=0,this.bufferOffset=0,this.baseState=1,this.special=1,this.running=!0,this.ended=!1,this.cbs=t,this.xmlMode=!!(null==e?void 0:e.xmlMode),this.decodeEntities=null===(n=null==e?void 0:e.decodeEntities)||void 0===n||n}return e.prototype.reset=function(){this._state=1,this.buffer="",this.sectionStart=0,this._index=0,this.bufferOffset=0,this.baseState=1,this.special=1,this.running=!0,this.ended=!1},e.prototype.write=function(e){this.ended&&this.cbs.onerror(Error(".write() after done!")),this.buffer+=e,this.parse()},e.prototype.end=function(e){this.ended&&this.cbs.onerror(Error(".end() after done!")),e&&this.write(e),this.ended=!0,this.running&&this.finish()},e.prototype.pause=function(){this.running=!1},e.prototype.resume=function(){this.running=!0,this._index<this.buffer.length&&this.parse(),this.ended&&this.finish()},e.prototype.getAbsoluteIndex=function(){return this.bufferOffset+this._index},e.prototype.stateText=function(e){"<"===e?(this._index>this.sectionStart&&this.cbs.ontext(this.getSection()),this._state=2,this.sectionStart=this._index):!this.decodeEntities||"&"!==e||1!==this.special&&4!==this.special||(this._index>this.sectionStart&&this.cbs.ontext(this.getSection()),this.baseState=1,this._state=62,this.sectionStart=this._index)},e.prototype.isTagStartChar=function(e){return c(e)||this.xmlMode&&!l(e)&&"/"!==e&&">"!==e},e.prototype.stateBeforeTagName=function(e){"/"===e?this._state=5:"<"===e?(this.cbs.ontext(this.getSection()),this.sectionStart=this._index):">"===e||1!==this.special||l(e)?this._state=1:"!"===e?(this._state=15,this.sectionStart=this._index+1):"?"===e?(this._state=17,this.sectionStart=this._index+1):this.isTagStartChar(e)?(this._state=this.xmlMode||"s"!==e&&"S"!==e?this.xmlMode||"t"!==e&&"T"!==e?3:52:32,this.sectionStart=this._index):this._state=1},e.prototype.stateInTagName=function(e){("/"===e||">"===e||l(e))&&(this.emitToken("onopentagname"),this._state=8,this._index--)},e.prototype.stateBeforeClosingTagName=function(e){l(e)||(">"===e?this._state=1:1!==this.special?4===this.special||"s"!==e&&"S"!==e?4!==this.special||"t"!==e&&"T"!==e?(this._state=1,this._index--):this._state=53:this._state=33:this.isTagStartChar(e)?(this._state=6,this.sectionStart=this._index):(this._state=20,this.sectionStart=this._index))},e.prototype.stateInClosingTagName=function(e){(">"===e||l(e))&&(this.emitToken("onclosetag"),this._state=7,this._index--)},e.prototype.stateAfterClosingTagName=function(e){">"===e&&(this._state=1,this.sectionStart=this._index+1)},e.prototype.stateBeforeAttributeName=function(e){">"===e?(this.cbs.onopentagend(),this._state=1,this.sectionStart=this._index+1):"/"===e?this._state=4:l(e)||(this._state=9,this.sectionStart=this._index)},e.prototype.stateInSelfClosingTag=function(e){">"===e?(this.cbs.onselfclosingtag(),this._state=1,this.sectionStart=this._index+1,this.special=1):l(e)||(this._state=8,this._index--)},e.prototype.stateInAttributeName=function(e){("="===e||"/"===e||">"===e||l(e))&&(this.cbs.onattribname(this.getSection()),this.sectionStart=-1,this._state=10,this._index--)},e.prototype.stateAfterAttributeName=function(e){"="===e?this._state=11:"/"===e||">"===e?(this.cbs.onattribend(void 0),this._state=8,this._index--):l(e)||(this.cbs.onattribend(void 0),this._state=9,this.sectionStart=this._index)},e.prototype.stateBeforeAttributeValue=function(e){'"'===e?(this._state=12,this.sectionStart=this._index+1):"'"===e?(this._state=13,this.sectionStart=this._index+1):l(e)||(this._state=14,this.sectionStart=this._index,this._index--)},e.prototype.handleInAttributeValue=function(e,t){e===t?(this.emitToken("onattribdata"),this.cbs.onattribend(t),this._state=8):this.decodeEntities&&"&"===e&&(this.emitToken("onattribdata"),this.baseState=this._state,this._state=62,this.sectionStart=this._index)},e.prototype.stateInAttributeValueDoubleQuotes=function(e){this.handleInAttributeValue(e,'"')},e.prototype.stateInAttributeValueSingleQuotes=function(e){this.handleInAttributeValue(e,"'")},e.prototype.stateInAttributeValueNoQuotes=function(e){l(e)||">"===e?(this.emitToken("onattribdata"),this.cbs.onattribend(null),this._state=8,this._index--):this.decodeEntities&&"&"===e&&(this.emitToken("onattribdata"),this.baseState=this._state,this._state=62,this.sectionStart=this._index)},e.prototype.stateBeforeDeclaration=function(e){this._state="["===e?23:"-"===e?18:16},e.prototype.stateInDeclaration=function(e){">"===e&&(this.cbs.ondeclaration(this.getSection()),this._state=1,this.sectionStart=this._index+1)},e.prototype.stateInProcessingInstruction=function(e){">"===e&&(this.cbs.onprocessinginstruction(this.getSection()),this._state=1,this.sectionStart=this._index+1)},e.prototype.stateBeforeComment=function(e){"-"===e?(this._state=19,this.sectionStart=this._index+1):this._state=16},e.prototype.stateInComment=function(e){"-"===e&&(this._state=21)},e.prototype.stateInSpecialComment=function(e){">"===e&&(this.cbs.oncomment(this.buffer.substring(this.sectionStart,this._index)),this._state=1,this.sectionStart=this._index+1)},e.prototype.stateAfterComment1=function(e){this._state="-"===e?22:19},e.prototype.stateAfterComment2=function(e){">"===e?(this.cbs.oncomment(this.buffer.substring(this.sectionStart,this._index-2)),this._state=1,this.sectionStart=this._index+1):"-"!==e&&(this._state=19)},e.prototype.stateBeforeCdata6=function(e){"["===e?(this._state=29,this.sectionStart=this._index+1):(this._state=16,this._index--)},e.prototype.stateInCdata=function(e){"]"===e&&(this._state=30)},e.prototype.stateAfterCdata1=function(e){this._state="]"===e?31:29},e.prototype.stateAfterCdata2=function(e){">"===e?(this.cbs.oncdata(this.buffer.substring(this.sectionStart,this._index-2)),this._state=1,this.sectionStart=this._index+1):"]"!==e&&(this._state=29)},e.prototype.stateBeforeSpecialS=function(e){"c"===e||"C"===e?this._state=34:"t"===e||"T"===e?this._state=44:(this._state=3,this._index--)},e.prototype.stateBeforeSpecialSEnd=function(e){2!==this.special||"c"!==e&&"C"!==e?3!==this.special||"t"!==e&&"T"!==e?this._state=1:this._state=48:this._state=39},e.prototype.stateBeforeSpecialLast=function(e,t){("/"===e||">"===e||l(e))&&(this.special=t),this._state=3,this._index--},e.prototype.stateAfterSpecialLast=function(e,t){">"===e||l(e)?(this.special=1,this._state=6,this.sectionStart=this._index-t,this._index--):this._state=1},e.prototype.parseFixedEntity=function(e){if(void 0===e&&(e=this.xmlMode?s.default:o.default),this.sectionStart+1<this._index){var t=this.buffer.substring(this.sectionStart+1,this._index);Object.prototype.hasOwnProperty.call(e,t)&&(this.emitPartial(e[t]),this.sectionStart=this._index+1)}},e.prototype.parseLegacyEntity=function(){for(var e=this.sectionStart+1,t=Math.min(this._index-e,6);t>=2;){var n=this.buffer.substr(e,t);if(Object.prototype.hasOwnProperty.call(a.default,n))return this.emitPartial(a.default[n]),void(this.sectionStart+=t+1);t--}},e.prototype.stateInNamedEntity=function(e){";"===e?(this.parseFixedEntity(),1===this.baseState&&this.sectionStart+1<this._index&&!this.xmlMode&&this.parseLegacyEntity(),this._state=this.baseState):(e<"0"||e>"9")&&!c(e)&&(this.xmlMode||this.sectionStart+1===this._index||(1!==this.baseState?"="!==e&&this.parseFixedEntity(a.default):this.parseLegacyEntity()),this._state=this.baseState,this._index--)},e.prototype.decodeNumericEntity=function(e,t,n){var r=this.sectionStart+e;if(r!==this._index){var o=this.buffer.substring(r,this._index),a=parseInt(o,t);this.emitPartial(i.default(a)),this.sectionStart=n?this._index+1:this._index}this._state=this.baseState},e.prototype.stateInNumericEntity=function(e){";"===e?this.decodeNumericEntity(2,10,!0):(e<"0"||e>"9")&&(this.xmlMode?this._state=this.baseState:this.decodeNumericEntity(2,10,!1),this._index--)},e.prototype.stateInHexEntity=function(e){";"===e?this.decodeNumericEntity(3,16,!0):(e<"a"||e>"f")&&(e<"A"||e>"F")&&(e<"0"||e>"9")&&(this.xmlMode?this._state=this.baseState:this.decodeNumericEntity(3,16,!1),this._index--)},e.prototype.cleanup=function(){this.sectionStart<0?(this.buffer="",this.bufferOffset+=this._index,this._index=0):this.running&&(1===this._state?(this.sectionStart!==this._index&&this.cbs.ontext(this.buffer.substr(this.sectionStart)),this.buffer="",this.bufferOffset+=this._index,this._index=0):this.sectionStart===this._index?(this.buffer="",this.bufferOffset+=this._index,this._index=0):(this.buffer=this.buffer.substr(this.sectionStart),this._index-=this.sectionStart,this.bufferOffset+=this.sectionStart),this.sectionStart=0)},e.prototype.parse=function(){for(;this._index<this.buffer.length&&this.running;){var e=this.buffer.charAt(this._index);1===this._state?this.stateText(e):12===this._state?this.stateInAttributeValueDoubleQuotes(e):9===this._state?this.stateInAttributeName(e):19===this._state?this.stateInComment(e):20===this._state?this.stateInSpecialComment(e):8===this._state?this.stateBeforeAttributeName(e):3===this._state?this.stateInTagName(e):6===this._state?this.stateInClosingTagName(e):2===this._state?this.stateBeforeTagName(e):10===this._state?this.stateAfterAttributeName(e):13===this._state?this.stateInAttributeValueSingleQuotes(e):11===this._state?this.stateBeforeAttributeValue(e):5===this._state?this.stateBeforeClosingTagName(e):7===this._state?this.stateAfterClosingTagName(e):32===this._state?this.stateBeforeSpecialS(e):21===this._state?this.stateAfterComment1(e):14===this._state?this.stateInAttributeValueNoQuotes(e):4===this._state?this.stateInSelfClosingTag(e):16===this._state?this.stateInDeclaration(e):15===this._state?this.stateBeforeDeclaration(e):22===this._state?this.stateAfterComment2(e):18===this._state?this.stateBeforeComment(e):33===this._state?this.stateBeforeSpecialSEnd(e):53===this._state?j(this,e):39===this._state?M(this,e):40===this._state?w(this,e):41===this._state?A(this,e):34===this._state?v(this,e):35===this._state?y(this,e):36===this._state?_(this,e):37===this._state?b(this,e):38===this._state?this.stateBeforeSpecialLast(e,2):42===this._state?C(this,e):43===this._state?this.stateAfterSpecialLast(e,6):44===this._state?x(this,e):29===this._state?this.stateInCdata(e):45===this._state?E(this,e):46===this._state?L(this,e):47===this._state?this.stateBeforeSpecialLast(e,3):48===this._state?S(this,e):49===this._state?T(this,e):50===this._state?O(this,e):51===this._state?this.stateAfterSpecialLast(e,5):52===this._state?I(this,e):54===this._state?k(this,e):55===this._state?D(this,e):56===this._state?N(this,e):57===this._state?this.stateBeforeSpecialLast(e,4):58===this._state?P(this,e):59===this._state?z(this,e):60===this._state?R(this,e):61===this._state?this.stateAfterSpecialLast(e,5):17===this._state?this.stateInProcessingInstruction(e):64===this._state?this.stateInNamedEntity(e):23===this._state?h(this,e):62===this._state?B(this,e):24===this._state?p(this,e):25===this._state?f(this,e):30===this._state?this.stateAfterCdata1(e):31===this._state?this.stateAfterCdata2(e):26===this._state?m(this,e):27===this._state?g(this,e):28===this._state?this.stateBeforeCdata6(e):66===this._state?this.stateInHexEntity(e):65===this._state?this.stateInNumericEntity(e):63===this._state?H(this,e):this.cbs.onerror(Error("unknown _state"),this._state),this._index++}this.cleanup()},e.prototype.finish=function(){this.sectionStart<this._index&&this.handleTrailingData(),this.cbs.onend()},e.prototype.handleTrailingData=function(){var e=this.buffer.substr(this.sectionStart);29===this._state||30===this._state||31===this._state?this.cbs.oncdata(e):19===this._state||21===this._state||22===this._state?this.cbs.oncomment(e):64!==this._state||this.xmlMode?65!==this._state||this.xmlMode?66!==this._state||this.xmlMode?3!==this._state&&8!==this._state&&11!==this._state&&10!==this._state&&9!==this._state&&13!==this._state&&12!==this._state&&14!==this._state&&6!==this._state&&this.cbs.ontext(e):(this.decodeNumericEntity(3,16,!1),this.sectionStart<this._index&&(this._state=this.baseState,this.handleTrailingData())):(this.decodeNumericEntity(2,10,!1),this.sectionStart<this._index&&(this._state=this.baseState,this.handleTrailingData())):(this.parseLegacyEntity(),this.sectionStart<this._index&&(this._state=this.baseState,this.handleTrailingData()))},e.prototype.getSection=function(){return this.buffer.substring(this.sectionStart,this._index)},e.prototype.emitToken=function(e){this.cbs[e](this.getSection()),this.sectionStart=-1},e.prototype.emitPartial=function(e){1!==this.baseState?this.cbs.onattribdata(e):this.cbs.ontext(e)},e}();t.default=F},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0});var i=r(n(647)),o=String.fromCodePoint||function(e){var t="";return e>65535&&(e-=65536,t+=String.fromCharCode(e>>>10&1023|55296),e=56320|1023&e),t+=String.fromCharCode(e)};t.default=function(e){return e>=55296&&e<=57343||e>1114111?"�":(e in i.default&&(e=i.default[e]),o(e))}},function(e){e.exports=JSON.parse('{"Aacute":"Á","aacute":"á","Acirc":"Â","acirc":"â","acute":"´","AElig":"Æ","aelig":"æ","Agrave":"À","agrave":"à","amp":"&","AMP":"&","Aring":"Å","aring":"å","Atilde":"Ã","atilde":"ã","Auml":"Ä","auml":"ä","brvbar":"¦","Ccedil":"Ç","ccedil":"ç","cedil":"¸","cent":"¢","copy":"©","COPY":"©","curren":"¤","deg":"°","divide":"÷","Eacute":"É","eacute":"é","Ecirc":"Ê","ecirc":"ê","Egrave":"È","egrave":"è","ETH":"Ð","eth":"ð","Euml":"Ë","euml":"ë","frac12":"½","frac14":"¼","frac34":"¾","gt":">","GT":">","Iacute":"Í","iacute":"í","Icirc":"Î","icirc":"î","iexcl":"¡","Igrave":"Ì","igrave":"ì","iquest":"¿","Iuml":"Ï","iuml":"ï","laquo":"«","lt":"<","LT":"<","macr":"¯","micro":"µ","middot":"·","nbsp":" ","not":"¬","Ntilde":"Ñ","ntilde":"ñ","Oacute":"Ó","oacute":"ó","Ocirc":"Ô","ocirc":"ô","Ograve":"Ò","ograve":"ò","ordf":"ª","ordm":"º","Oslash":"Ø","oslash":"ø","Otilde":"Õ","otilde":"õ","Ouml":"Ö","ouml":"ö","para":"¶","plusmn":"±","pound":"£","quot":"\\"","QUOT":"\\"","raquo":"»","reg":"®","REG":"®","sect":"§","shy":"­","sup1":"¹","sup2":"²","sup3":"³","szlig":"ß","THORN":"Þ","thorn":"þ","times":"×","Uacute":"Ú","uacute":"ú","Ucirc":"Û","ucirc":"û","Ugrave":"Ù","ugrave":"ù","uml":"¨","Uuml":"Ü","uuml":"ü","Yacute":"Ý","yacute":"ý","yen":"¥","yuml":"ÿ"}')},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.cloneNode=t.hasChildren=t.isDocument=t.isDirective=t.isComment=t.isText=t.isCDATA=t.isTag=t.Element=t.Document=t.NodeWithChildren=t.ProcessingInstruction=t.Comment=t.Text=t.DataNode=t.Node=void 0;var a=n(102),s=new Map([[a.ElementType.Tag,1],[a.ElementType.Script,1],[a.ElementType.Style,1],[a.ElementType.Directive,1],[a.ElementType.Text,3],[a.ElementType.CDATA,4],[a.ElementType.Comment,8],[a.ElementType.Root,9]]),l=function(){function e(e){this.type=e,this.parent=null,this.prev=null,this.next=null,this.startIndex=null,this.endIndex=null}return Object.defineProperty(e.prototype,"nodeType",{get:function(){var e;return null!==(e=s.get(this.type))&&void 0!==e?e:1},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"parentNode",{get:function(){return this.parent},set:function(e){this.parent=e},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"previousSibling",{get:function(){return this.prev},set:function(e){this.prev=e},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"nextSibling",{get:function(){return this.next},set:function(e){this.next=e},enumerable:!1,configurable:!0}),e.prototype.cloneNode=function(e){return void 0===e&&(e=!1),w(this,e)},e}();t.Node=l;var c=function(e){function t(t,n){var r=e.call(this,t)||this;return r.data=n,r}return i(t,e),Object.defineProperty(t.prototype,"nodeValue",{get:function(){return this.data},set:function(e){this.data=e},enumerable:!1,configurable:!0}),t}(l);t.DataNode=c;var u=function(e){function t(t){return e.call(this,a.ElementType.Text,t)||this}return i(t,e),t}(c);t.Text=u;var d=function(e){function t(t){return e.call(this,a.ElementType.Comment,t)||this}return i(t,e),t}(c);t.Comment=d;var h=function(e){function t(t,n){var r=e.call(this,a.ElementType.Directive,n)||this;return r.name=t,r}return i(t,e),t}(c);t.ProcessingInstruction=h;var p=function(e){function t(t,n){var r=e.call(this,t)||this;return r.children=n,r}return i(t,e),Object.defineProperty(t.prototype,"firstChild",{get:function(){var e;return null!==(e=this.children[0])&&void 0!==e?e:null},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"lastChild",{get:function(){return this.children.length>0?this.children[this.children.length-1]:null},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"childNodes",{get:function(){return this.children},set:function(e){this.children=e},enumerable:!1,configurable:!0}),t}(l);t.NodeWithChildren=p;var f=function(e){function t(t){return e.call(this,a.ElementType.Root,t)||this}return i(t,e),t}(p);t.Document=f;var m=function(e){function t(t,n,r,i){void 0===r&&(r=[]),void 0===i&&(i="script"===t?a.ElementType.Script:"style"===t?a.ElementType.Style:a.ElementType.Tag);var o=e.call(this,i,r)||this;return o.name=t,o.attribs=n,o}return i(t,e),Object.defineProperty(t.prototype,"tagName",{get:function(){return this.name},set:function(e){this.name=e},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"attributes",{get:function(){var e=this;return Object.keys(this.attribs).map((function(t){var n,r;return{name:t,value:e.attribs[t],namespace:null===(n=e["x-attribsNamespace"])||void 0===n?void 0:n[t],prefix:null===(r=e["x-attribsPrefix"])||void 0===r?void 0:r[t]}}))},enumerable:!1,configurable:!0}),t}(p);function g(e){return(0,a.isTag)(e)}function v(e){return e.type===a.ElementType.CDATA}function y(e){return e.type===a.ElementType.Text}function _(e){return e.type===a.ElementType.Comment}function b(e){return e.type===a.ElementType.Directive}function M(e){return e.type===a.ElementType.Root}function w(e,t){var n;if(void 0===t&&(t=!1),y(e))n=new u(e.data);else if(_(e))n=new d(e.data);else if(g(e)){var r=t?A(e.children):[],i=new m(e.name,o({},e.attribs),r);r.forEach((function(e){return e.parent=i})),null!=e.namespace&&(i.namespace=e.namespace),e["x-attribsNamespace"]&&(i["x-attribsNamespace"]=o({},e["x-attribsNamespace"])),e["x-attribsPrefix"]&&(i["x-attribsPrefix"]=o({},e["x-attribsPrefix"])),n=i}else if(v(e)){r=t?A(e.children):[];var s=new p(a.ElementType.CDATA,r);r.forEach((function(e){return e.parent=s})),n=s}else if(M(e)){r=t?A(e.children):[];var l=new f(r);r.forEach((function(e){return e.parent=l})),e["x-mode"]&&(l["x-mode"]=e["x-mode"]),n=l}else{if(!b(e))throw new Error("Not implemented yet: ".concat(e.type));var c=new h(e.name,e.data);null!=e["x-name"]&&(c["x-name"]=e["x-name"],c["x-publicId"]=e["x-publicId"],c["x-systemId"]=e["x-systemId"]),n=c}return n.startIndex=e.startIndex,n.endIndex=e.endIndex,null!=e.sourceCodeLocation&&(n.sourceCodeLocation=e.sourceCodeLocation),n}function A(e){for(var t=e.map((function(e){return w(e,!0)})),n=1;n<t.length;n++)t[n].prev=t[n-1],t[n-1].next=t[n];return t}t.Element=m,t.isTag=g,t.isCDATA=v,t.isText=y,t.isComment=_,t.isDirective=b,t.isDocument=M,t.hasChildren=function(e){return Object.prototype.hasOwnProperty.call(e,"children")},t.cloneNode=w},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),a=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),s=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&o(t,e,n);return a(t,e),t},l=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.parseFeed=t.FeedHandler=void 0;var c,u,d=l(n(71)),h=s(n(361)),p=n(355);!function(e){e[e.image=0]="image",e[e.audio=1]="audio",e[e.video=2]="video",e[e.document=3]="document",e[e.executable=4]="executable"}(c||(c={})),function(e){e[e.sample=0]="sample",e[e.full=1]="full",e[e.nonstop=2]="nonstop"}(u||(u={}));var f=function(e){function t(t,n){return"object"==typeof t&&(n=t=void 0),e.call(this,t,n)||this}return i(t,e),t.prototype.onend=function(){var e,t,n=v(M,this.dom);if(n){var r={};if("feed"===n.name){var i=n.children;r.type="atom",b(r,"id","id",i),b(r,"title","title",i);var o=_("href",v("link",i));o&&(r.link=o),b(r,"description","subtitle",i),(a=y("updated",i))&&(r.updated=new Date(a)),b(r,"author","email",i,!0),r.items=g("entry",i).map((function(e){var t={},n=e.children;b(t,"id","id",n),b(t,"title","title",n);var r=_("href",v("link",n));r&&(t.link=r);var i=y("summary",n)||y("content",n);i&&(t.description=i);var o=y("updated",n);return o&&(t.pubDate=new Date(o)),t.media=m(n),t}))}else{var a;i=null!==(t=null===(e=v("channel",n.children))||void 0===e?void 0:e.children)&&void 0!==t?t:[];r.type=n.name.substr(0,3),r.id="",b(r,"title","title",i),b(r,"link","link",i),b(r,"description","description",i),(a=y("lastBuildDate",i))&&(r.updated=new Date(a)),b(r,"author","managingEditor",i,!0),r.items=g("item",n.children).map((function(e){var t={},n=e.children;b(t,"id","guid",n),b(t,"title","title",n),b(t,"link","link",n),b(t,"description","description",n);var r=y("pubDate",n);return r&&(t.pubDate=new Date(r)),t.media=m(n),t}))}this.feed=r,this.handleCallback(null)}else this.handleCallback(new Error("couldn't find root of feed"))},t}(d.default);function m(e){return g("media:content",e).map((function(e){var t={medium:e.attribs.medium,isDefault:!!e.attribs.isDefault};return e.attribs.url&&(t.url=e.attribs.url),e.attribs.fileSize&&(t.fileSize=parseInt(e.attribs.fileSize,10)),e.attribs.type&&(t.type=e.attribs.type),e.attribs.expression&&(t.expression=e.attribs.expression),e.attribs.bitrate&&(t.bitrate=parseInt(e.attribs.bitrate,10)),e.attribs.framerate&&(t.framerate=parseInt(e.attribs.framerate,10)),e.attribs.samplingrate&&(t.samplingrate=parseInt(e.attribs.samplingrate,10)),e.attribs.channels&&(t.channels=parseInt(e.attribs.channels,10)),e.attribs.duration&&(t.duration=parseInt(e.attribs.duration,10)),e.attribs.height&&(t.height=parseInt(e.attribs.height,10)),e.attribs.width&&(t.width=parseInt(e.attribs.width,10)),e.attribs.lang&&(t.lang=e.attribs.lang),t}))}function g(e,t){return h.getElementsByTagName(e,t,!0)}function v(e,t){return h.getElementsByTagName(e,t,!0,1)[0]}function y(e,t,n){return void 0===n&&(n=!1),h.getText(h.getElementsByTagName(e,t,n,1)).trim()}function _(e,t){return t?t.attribs[e]:null}function b(e,t,n,r,i){void 0===i&&(i=!1);var o=y(n,r,i);o&&(e[t]=o)}function M(e){return"rss"===e||"feed"===e||"rdf:RDF"===e}t.FeedHandler=f,t.parseFeed=function(e,t){void 0===t&&(t={xmlMode:!0});var n=new f(t);return new p.Parser(n,t).end(e),n.feed}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)};Object.defineProperty(t,"__esModule",{value:!0}),t.hasChildren=t.isDocument=t.isComment=t.isText=t.isCDATA=t.isTag=void 0,i(n(362),t),i(n(651),t),i(n(652),t),i(n(365),t),i(n(366),t),i(n(653),t),i(n(654),t);var o=n(71);Object.defineProperty(t,"isTag",{enumerable:!0,get:function(){return o.isTag}}),Object.defineProperty(t,"isCDATA",{enumerable:!0,get:function(){return o.isCDATA}}),Object.defineProperty(t,"isText",{enumerable:!0,get:function(){return o.isText}}),Object.defineProperty(t,"isComment",{enumerable:!0,get:function(){return o.isComment}}),Object.defineProperty(t,"isDocument",{enumerable:!0,get:function(){return o.isDocument}}),Object.defineProperty(t,"hasChildren",{enumerable:!0,get:function(){return o.hasChildren}})},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.innerText=t.textContent=t.getText=t.getInnerHTML=t.getOuterHTML=void 0;var i=n(71),o=r(n(648)),a=n(102);function s(e,t){return(0,o.default)(e,t)}t.getOuterHTML=s,t.getInnerHTML=function(e,t){return(0,i.hasChildren)(e)?e.children.map((function(e){return s(e,t)})).join(""):""},t.getText=function e(t){return Array.isArray(t)?t.map(e).join(""):(0,i.isTag)(t)?"br"===t.name?"\n":e(t.children):(0,i.isCDATA)(t)?e(t.children):(0,i.isText)(t)?t.data:""},t.textContent=function e(t){return Array.isArray(t)?t.map(e).join(""):(0,i.hasChildren)(t)&&!(0,i.isComment)(t)?e(t.children):(0,i.isText)(t)?t.data:""},t.innerText=function e(t){return Array.isArray(t)?t.map(e).join(""):(0,i.hasChildren)(t)&&(t.type===a.ElementType.Tag||(0,i.isCDATA)(t))?e(t.children):(0,i.isText)(t)?t.data:""}},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.decodeHTML=t.decodeHTMLStrict=t.decodeXML=void 0;var i=r(n(156)),o=r(n(358)),a=r(n(157)),s=r(n(357)),l=/&(?:[a-zA-Z0-9]+|#[xX][\da-fA-F]+|#\d+);/g;function c(e){var t=d(e);return function(e){return String(e).replace(l,t)}}t.decodeXML=c(a.default),t.decodeHTMLStrict=c(i.default);var u=function(e,t){return e<t?1:-1};function d(e){return function(t){if("#"===t.charAt(1)){var n=t.charAt(2);return"X"===n||"x"===n?s.default(parseInt(t.substr(3),16)):s.default(parseInt(t.substr(2),10))}return e[t.slice(1,-1)]||t}}t.decodeHTML=function(){for(var e=Object.keys(o.default).sort(u),t=Object.keys(i.default).sort(u),n=0,r=0;n<t.length;n++)e[r]===t[n]?(t[n]+=";?",r++):t[n]+=";";var a=new RegExp("&(?:"+t.join("|")+"|#[xX][\\da-fA-F]+;?|#\\d+;?)","g"),s=d(i.default);function l(e){return";"!==e.substr(-1)&&(e+=";"),s(e)}return function(e){return String(e).replace(a,l)}}()},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.escapeUTF8=t.escape=t.encodeNonAsciiHTML=t.encodeHTML=t.encodeXML=void 0;var i=u(r(n(157)).default),o=d(i);t.encodeXML=g(i);var a,s,l=u(r(n(156)).default),c=d(l);function u(e){return Object.keys(e).sort().reduce((function(t,n){return t[e[n]]="&"+n+";",t}),{})}function d(e){for(var t=[],n=[],r=0,i=Object.keys(e);r<i.length;r++){var o=i[r];1===o.length?t.push("\\"+o):n.push(o)}t.sort();for(var a=0;a<t.length-1;a++){for(var s=a;s<t.length-1&&t[s].charCodeAt(1)+1===t[s+1].charCodeAt(1);)s+=1;var l=1+s-a;l<3||t.splice(a,l,t[a]+"-"+t[s])}return n.unshift("["+t.join("")+"]"),new RegExp(n.join("|"),"g")}t.encodeHTML=(a=l,s=c,function(e){return e.replace(s,(function(e){return a[e]})).replace(h,f)}),t.encodeNonAsciiHTML=g(l);var h=/(?:[\x80-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/g,p=null!=String.prototype.codePointAt?function(e){return e.codePointAt(0)}:function(e){return 1024*(e.charCodeAt(0)-55296)+e.charCodeAt(1)-56320+65536};function f(e){return"&#x"+(e.length>1?p(e):e.charCodeAt(0)).toString(16).toUpperCase()+";"}var m=new RegExp(o.source+"|"+h.source,"g");function g(e){return function(t){return t.replace(m,(function(t){return e[t]||f(t)}))}}t.escape=function(e){return e.replace(m,f)},t.escapeUTF8=function(e){return e.replace(o,f)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.findAll=t.existsOne=t.findOne=t.findOneChild=t.find=t.filter=void 0;var r=n(71);function i(e,t,n,o){for(var a=[],s=0,l=t;s<l.length;s++){var c=l[s];if(e(c)&&(a.push(c),--o<=0))break;if(n&&(0,r.hasChildren)(c)&&c.children.length>0){var u=i(e,c.children,n,o);if(a.push.apply(a,u),(o-=u.length)<=0)break}}return a}t.filter=function(e,t,n,r){return void 0===n&&(n=!0),void 0===r&&(r=1/0),Array.isArray(t)||(t=[t]),i(e,t,n,r)},t.find=i,t.findOneChild=function(e,t){return t.find(e)},t.findOne=function e(t,n,i){void 0===i&&(i=!0);for(var o=null,a=0;a<n.length&&!o;a++){var s=n[a];(0,r.isTag)(s)&&(t(s)?o=s:i&&s.children.length>0&&(o=e(t,s.children)))}return o},t.existsOne=function e(t,n){return n.some((function(n){return(0,r.isTag)(n)&&(t(n)||n.children.length>0&&e(t,n.children))}))},t.findAll=function(e,t){for(var n,i,o=[],a=t.filter(r.isTag);i=a.shift();){var s=null===(n=i.children)||void 0===n?void 0:n.filter(r.isTag);s&&s.length>0&&a.unshift.apply(a,s),e(i)&&o.push(i)}return o}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getElementsByTagType=t.getElementsByTagName=t.getElementById=t.getElements=t.testElement=void 0;var r=n(71),i=n(365),o={tag_name:function(e){return"function"==typeof e?function(t){return(0,r.isTag)(t)&&e(t.name)}:"*"===e?r.isTag:function(t){return(0,r.isTag)(t)&&t.name===e}},tag_type:function(e){return"function"==typeof e?function(t){return e(t.type)}:function(t){return t.type===e}},tag_contains:function(e){return"function"==typeof e?function(t){return(0,r.isText)(t)&&e(t.data)}:function(t){return(0,r.isText)(t)&&t.data===e}}};function a(e,t){return"function"==typeof t?function(n){return(0,r.isTag)(n)&&t(n.attribs[e])}:function(n){return(0,r.isTag)(n)&&n.attribs[e]===t}}function s(e,t){return function(n){return e(n)||t(n)}}function l(e){var t=Object.keys(e).map((function(t){var n=e[t];return Object.prototype.hasOwnProperty.call(o,t)?o[t](n):a(t,n)}));return 0===t.length?null:t.reduce(s)}t.testElement=function(e,t){var n=l(e);return!n||n(t)},t.getElements=function(e,t,n,r){void 0===r&&(r=1/0);var o=l(e);return o?(0,i.filter)(o,t,n,r):[]},t.getElementById=function(e,t,n){return void 0===n&&(n=!0),Array.isArray(t)||(t=[t]),(0,i.findOne)(a("id",e),t,n)},t.getElementsByTagName=function(e,t,n,r){return void 0===n&&(n=!0),void 0===r&&(r=1/0),(0,i.filter)(o.tag_name(e),t,n,r)},t.getElementsByTagType=function(e,t,n,r){return void 0===n&&(n=!0),void 0===r&&(r=1/0),(0,i.filter)(o.tag_type(e),t,n,r)}},function(e,t){},function(e,t,n){"use strict";const r={colon:": ",indent:"    ",beforeDecl:"\n",beforeRule:"\n",beforeOpen:" ",beforeClose:"\n",beforeComment:"\n",after:"\n",emptyBody:"",commentLeft:" ",commentRight:" ",semicolon:!1};class i{constructor(e){this.builder=e}stringify(e,t){if(!this[e.type])throw new Error("Unknown AST node type "+e.type+". Maybe you need to change PostCSS stringifier.");this[e.type](e,t)}document(e){this.body(e)}root(e){this.body(e),e.raws.after&&this.builder(e.raws.after)}comment(e){let t=this.raw(e,"left","commentLeft"),n=this.raw(e,"right","commentRight");this.builder("/*"+t+e.text+n+"*/",e)}decl(e,t){let n=this.raw(e,"between","colon"),r=e.prop+n+this.rawValue(e,"value");e.important&&(r+=e.raws.important||" !important"),t&&(r+=";"),this.builder(r,e)}rule(e){this.block(e,this.rawValue(e,"selector")),e.raws.ownSemicolon&&this.builder(e.raws.ownSemicolon,e,"end")}atrule(e,t){let n="@"+e.name,r=e.params?this.rawValue(e,"params"):"";if(void 0!==e.raws.afterName?n+=e.raws.afterName:r&&(n+=" "),e.nodes)this.block(e,n+r);else{let i=(e.raws.between||"")+(t?";":"");this.builder(n+r+i,e)}}body(e){let t=e.nodes.length-1;for(;t>0&&"comment"===e.nodes[t].type;)t-=1;let n=this.raw(e,"semicolon");for(let r=0;r<e.nodes.length;r++){let i=e.nodes[r],o=this.raw(i,"before");o&&this.builder(o),this.stringify(i,t!==r||n)}}block(e,t){let n,r=this.raw(e,"between","beforeOpen");this.builder(t+r+"{",e,"start"),e.nodes&&e.nodes.length?(this.body(e),n=this.raw(e,"after")):n=this.raw(e,"after","emptyBody"),n&&this.builder(n),this.builder("}",e,"end")}raw(e,t,n){let i;if(n||(n=t),t&&(i=e.raws[t],void 0!==i))return i;let o=e.parent;if("before"===n){if(!o||"root"===o.type&&o.first===e)return"";if(o&&"document"===o.type)return""}if(!o)return r[n];let a=e.root();if(a.rawCache||(a.rawCache={}),void 0!==a.rawCache[n])return a.rawCache[n];if("before"===n||"after"===n)return this.beforeAfter(e,n);{let r="raw"+((s=n)[0].toUpperCase()+s.slice(1));this[r]?i=this[r](a,e):a.walk(e=>{if(i=e.raws[t],void 0!==i)return!1})}var s;return void 0===i&&(i=r[n]),a.rawCache[n]=i,i}rawSemicolon(e){let t;return e.walk(e=>{if(e.nodes&&e.nodes.length&&"decl"===e.last.type&&(t=e.raws.semicolon,void 0!==t))return!1}),t}rawEmptyBody(e){let t;return e.walk(e=>{if(e.nodes&&0===e.nodes.length&&(t=e.raws.after,void 0!==t))return!1}),t}rawIndent(e){if(e.raws.indent)return e.raws.indent;let t;return e.walk(n=>{let r=n.parent;if(r&&r!==e&&r.parent&&r.parent===e&&void 0!==n.raws.before){let e=n.raws.before.split("\n");return t=e[e.length-1],t=t.replace(/\S/g,""),!1}}),t}rawBeforeComment(e,t){let n;return e.walkComments(e=>{if(void 0!==e.raws.before)return n=e.raws.before,n.includes("\n")&&(n=n.replace(/[^\n]+$/,"")),!1}),void 0===n?n=this.raw(t,null,"beforeDecl"):n&&(n=n.replace(/\S/g,"")),n}rawBeforeDecl(e,t){let n;return e.walkDecls(e=>{if(void 0!==e.raws.before)return n=e.raws.before,n.includes("\n")&&(n=n.replace(/[^\n]+$/,"")),!1}),void 0===n?n=this.raw(t,null,"beforeRule"):n&&(n=n.replace(/\S/g,"")),n}rawBeforeRule(e){let t;return e.walk(n=>{if(n.nodes&&(n.parent!==e||e.first!==n)&&void 0!==n.raws.before)return t=n.raws.before,t.includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t}rawBeforeClose(e){let t;return e.walk(e=>{if(e.nodes&&e.nodes.length>0&&void 0!==e.raws.after)return t=e.raws.after,t.includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t}rawBeforeOpen(e){let t;return e.walk(e=>{if("decl"!==e.type&&(t=e.raws.between,void 0!==t))return!1}),t}rawColon(e){let t;return e.walkDecls(e=>{if(void 0!==e.raws.between)return t=e.raws.between.replace(/[^\s:]/g,""),!1}),t}beforeAfter(e,t){let n;n="decl"===e.type?this.raw(e,null,"beforeDecl"):"comment"===e.type?this.raw(e,null,"beforeComment"):"before"===t?this.raw(e,null,"beforeRule"):this.raw(e,null,"beforeClose");let r=e.parent,i=0;for(;r&&"root"!==r.type;)i+=1,r=r.parent;if(n.includes("\n")){let t=this.raw(e,null,"indent");if(t.length)for(let e=0;e<i;e++)n+=t}return n}rawValue(e,t){let n=e[t],r=e.raws[t];return r&&r.value===n?r.raw:n}}e.exports=i,i.default=i},function(e,t,n){"use strict";let{isClean:r,my:i}=n(159),o=n(370),a=n(125),s=n(83),l=n(163),c=(n(373),n(164)),u=n(165),d=n(103);const h={document:"Document",root:"Root",atrule:"AtRule",rule:"Rule",decl:"Declaration",comment:"Comment"},p={postcssPlugin:!0,prepare:!0,Once:!0,Document:!0,Root:!0,Declaration:!0,Rule:!0,AtRule:!0,Comment:!0,DeclarationExit:!0,RuleExit:!0,AtRuleExit:!0,CommentExit:!0,RootExit:!0,DocumentExit:!0,OnceExit:!0},f={postcssPlugin:!0,prepare:!0,Once:!0};function m(e){return"object"==typeof e&&"function"==typeof e.then}function g(e){let t=!1,n=h[e.type];return"decl"===e.type?t=e.prop.toLowerCase():"atrule"===e.type&&(t=e.name.toLowerCase()),t&&e.append?[n,n+"-"+t,0,n+"Exit",n+"Exit-"+t]:t?[n,n+"-"+t,n+"Exit",n+"Exit-"+t]:e.append?[n,0,n+"Exit"]:[n,n+"Exit"]}function v(e){let t;return t="document"===e.type?["Document",0,"DocumentExit"]:"root"===e.type?["Root",0,"RootExit"]:g(e),{node:e,events:t,eventIndex:0,visitors:[],visitorIndex:0,iterator:0}}function y(e){return e[r]=!1,e.nodes&&e.nodes.forEach(e=>y(e)),e}let _={};class b{constructor(e,t,n){let r;if(this.stringified=!1,this.processed=!1,"object"!=typeof t||null===t||"root"!==t.type&&"document"!==t.type)if(t instanceof b||t instanceof c)r=y(t.root),t.map&&(void 0===n.map&&(n.map={}),n.map.inline||(n.map.inline=!1),n.map.prev=t.map);else{let e=u;n.syntax&&(e=n.syntax.parse),n.parser&&(e=n.parser),e.parse&&(e=e.parse);try{r=e(t,n)}catch(e){this.processed=!0,this.error=e}r&&!r[i]&&s.rebuild(r)}else r=y(t);this.result=new c(e,r,n),this.helpers={..._,result:this.result,postcss:_},this.plugins=this.processor.plugins.map(e=>"object"==typeof e&&e.prepare?{...e,...e.prepare(this.result)}:e)}get[Symbol.toStringTag](){return"LazyResult"}get processor(){return this.result.processor}get opts(){return this.result.opts}get css(){return this.stringify().css}get content(){return this.stringify().content}get map(){return this.stringify().map}get root(){return this.sync().root}get messages(){return this.sync().messages}warnings(){return this.sync().warnings()}toString(){return this.css}then(e,t){return this.async().then(e,t)}catch(e){return this.async().catch(e)}finally(e){return this.async().then(e,e)}async(){return this.error?Promise.reject(this.error):this.processed?Promise.resolve(this.result):(this.processing||(this.processing=this.runAsync()),this.processing)}sync(){if(this.error)throw this.error;if(this.processed)return this.result;if(this.processed=!0,this.processing)throw this.getAsyncError();for(let e of this.plugins){if(m(this.runOnRoot(e)))throw this.getAsyncError()}if(this.prepareVisitors(),this.hasListener){let e=this.result.root;for(;!e[r];)e[r]=!0,this.walkSync(e);if(this.listeners.OnceExit)if("document"===e.type)for(let t of e.nodes)this.visitSync(this.listeners.OnceExit,t);else this.visitSync(this.listeners.OnceExit,e)}return this.result}stringify(){if(this.error)throw this.error;if(this.stringified)return this.result;this.stringified=!0,this.sync();let e=this.result.opts,t=a;e.syntax&&(t=e.syntax.stringify),e.stringifier&&(t=e.stringifier),t.stringify&&(t=t.stringify);let n=new o(t,this.result.root,this.result.opts).generate();return this.result.css=n[0],this.result.map=n[1],this.result}walkSync(e){e[r]=!0;let t=g(e);for(let n of t)if(0===n)e.nodes&&e.each(e=>{e[r]||this.walkSync(e)});else{let t=this.listeners[n];if(t&&this.visitSync(t,e.toProxy()))return}}visitSync(e,t){for(let[n,r]of e){let e;this.result.lastPlugin=n;try{e=r(t,this.helpers)}catch(e){throw this.handleError(e,t.proxyOf)}if("root"!==t.type&&"document"!==t.type&&!t.parent)return!0;if(m(e))throw this.getAsyncError()}}runOnRoot(e){this.result.lastPlugin=e;try{if("object"==typeof e&&e.Once){if("document"===this.result.root.type){let t=this.result.root.nodes.map(t=>e.Once(t,this.helpers));return m(t[0])?Promise.all(t):t}return e.Once(this.result.root,this.helpers)}if("function"==typeof e)return e(this.result.root,this.result)}catch(e){throw this.handleError(e)}}getAsyncError(){throw new Error("Use process(css).then(cb) to work with async plugins")}handleError(e,t){let n=this.result.lastPlugin;try{t&&t.addToError(e),this.error=e,"CssSyntaxError"!==e.name||e.plugin?n.postcssVersion:(e.plugin=n.postcssPlugin,e.setMessage())}catch(e){console&&console.error&&console.error(e)}return e}async runAsync(){this.plugin=0;for(let e=0;e<this.plugins.length;e++){let t=this.plugins[e],n=this.runOnRoot(t);if(m(n))try{await n}catch(e){throw this.handleError(e)}}if(this.prepareVisitors(),this.hasListener){let e=this.result.root;for(;!e[r];){e[r]=!0;let t=[v(e)];for(;t.length>0;){let e=this.visitTick(t);if(m(e))try{await e}catch(e){let n=t[t.length-1].node;throw this.handleError(e,n)}}}if(this.listeners.OnceExit)for(let[t,n]of this.listeners.OnceExit){this.result.lastPlugin=t;try{if("document"===e.type){let t=e.nodes.map(e=>n(e,this.helpers));await Promise.all(t)}else await n(e,this.helpers)}catch(e){throw this.handleError(e)}}}return this.processed=!0,this.stringify()}prepareVisitors(){this.listeners={};let e=(e,t,n)=>{this.listeners[t]||(this.listeners[t]=[]),this.listeners[t].push([e,n])};for(let t of this.plugins)if("object"==typeof t)for(let n in t){if(!p[n]&&/^[A-Z]/.test(n))throw new Error(`Unknown event ${n} in ${t.postcssPlugin}. Try to update PostCSS (${this.processor.version} now).`);if(!f[n])if("object"==typeof t[n])for(let r in t[n])e(t,"*"===r?n:n+"-"+r.toLowerCase(),t[n][r]);else"function"==typeof t[n]&&e(t,n,t[n])}this.hasListener=Object.keys(this.listeners).length>0}visitTick(e){let t=e[e.length-1],{node:n,visitors:i}=t;if("root"!==n.type&&"document"!==n.type&&!n.parent)return void e.pop();if(i.length>0&&t.visitorIndex<i.length){let[e,r]=i[t.visitorIndex];t.visitorIndex+=1,t.visitorIndex===i.length&&(t.visitors=[],t.visitorIndex=0),this.result.lastPlugin=e;try{return r(n.toProxy(),this.helpers)}catch(e){throw this.handleError(e,n)}}if(0!==t.iterator){let i,o=t.iterator;for(;i=n.nodes[n.indexes[o]];)if(n.indexes[o]+=1,!i[r])return i[r]=!0,void e.push(v(i));t.iterator=0,delete n.indexes[o]}let o=t.events;for(;t.eventIndex<o.length;){let e=o[t.eventIndex];if(t.eventIndex+=1,0===e)return void(n.nodes&&n.nodes.length&&(n[r]=!0,t.iterator=n.getIterator()));if(this.listeners[e])return void(t.visitors=this.listeners[e])}e.pop()}}b.registerPostcss=e=>{_=e},e.exports=b,b.default=b,d.registerLazyResult(b),l.registerLazyResult(b)},function(e,t,n){"use strict";(function(t){let{SourceMapConsumer:r,SourceMapGenerator:i}=n(161),{dirname:o,resolve:a,relative:s,sep:l}=n(162),{pathToFileURL:c}=n(371),u=n(126),d=Boolean(r&&i),h=Boolean(o&&a&&s&&l);e.exports=class{constructor(e,t,n,r){this.stringify=e,this.mapOpts=n.map||{},this.root=t,this.opts=n,this.css=r}isMap(){return void 0!==this.opts.map?!!this.opts.map:this.previous().length>0}previous(){if(!this.previousMaps)if(this.previousMaps=[],this.root)this.root.walk(e=>{if(e.source&&e.source.input.map){let t=e.source.input.map;this.previousMaps.includes(t)||this.previousMaps.push(t)}});else{let e=new u(this.css,this.opts);e.map&&this.previousMaps.push(e.map)}return this.previousMaps}isInline(){if(void 0!==this.mapOpts.inline)return this.mapOpts.inline;let e=this.mapOpts.annotation;return(void 0===e||!0===e)&&(!this.previous().length||this.previous().some(e=>e.inline))}isSourcesContent(){return void 0!==this.mapOpts.sourcesContent?this.mapOpts.sourcesContent:!this.previous().length||this.previous().some(e=>e.withContent())}clearAnnotation(){if(!1!==this.mapOpts.annotation)if(this.root){let e;for(let t=this.root.nodes.length-1;t>=0;t--)e=this.root.nodes[t],"comment"===e.type&&0===e.text.indexOf("# sourceMappingURL=")&&this.root.removeChild(t)}else this.css&&(this.css=this.css.replace(/(\n)?\/\*#[\S\s]*?\*\/$/gm,""))}setSourcesContent(){let e={};if(this.root)this.root.walk(t=>{if(t.source){let n=t.source.input.from;n&&!e[n]&&(e[n]=!0,this.map.setSourceContent(this.toUrl(this.path(n)),t.source.input.css))}});else if(this.css){let e=this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>";this.map.setSourceContent(e,this.css)}}applyPrevMaps(){for(let e of this.previous()){let t,n=this.toUrl(this.path(e.file)),i=e.root||o(e.file);!1===this.mapOpts.sourcesContent?(t=new r(e.text),t.sourcesContent&&(t.sourcesContent=t.sourcesContent.map(()=>null))):t=e.consumer(),this.map.applySourceMap(t,n,this.toUrl(this.path(i)))}}isAnnotation(){return!!this.isInline()||(void 0!==this.mapOpts.annotation?this.mapOpts.annotation:!this.previous().length||this.previous().some(e=>e.annotation))}toBase64(e){return t?t.from(e).toString("base64"):window.btoa(unescape(encodeURIComponent(e)))}addAnnotation(){let e;e=this.isInline()?"data:application/json;base64,"+this.toBase64(this.map.toString()):"string"==typeof this.mapOpts.annotation?this.mapOpts.annotation:"function"==typeof this.mapOpts.annotation?this.mapOpts.annotation(this.opts.to,this.root):this.outputFile()+".map";let t="\n";this.css.includes("\r\n")&&(t="\r\n"),this.css+=t+"/*# sourceMappingURL="+e+" */"}outputFile(){return this.opts.to?this.path(this.opts.to):this.opts.from?this.path(this.opts.from):"to.css"}generateMap(){if(this.root)this.generateString();else if(1===this.previous().length){let e=this.previous()[0].consumer();e.file=this.outputFile(),this.map=i.fromSourceMap(e)}else this.map=new i({file:this.outputFile()}),this.map.addMapping({source:this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>",generated:{line:1,column:0},original:{line:1,column:0}});return this.isSourcesContent()&&this.setSourcesContent(),this.root&&this.previous().length>0&&this.applyPrevMaps(),this.isAnnotation()&&this.addAnnotation(),this.isInline()?[this.css]:[this.css,this.map]}path(e){if(0===e.indexOf("<"))return e;if(/^\w+:\/\//.test(e))return e;if(this.mapOpts.absolute)return e;let t=this.opts.to?o(this.opts.to):".";return"string"==typeof this.mapOpts.annotation&&(t=o(a(t,this.mapOpts.annotation))),e=s(t,e)}toUrl(e){return"\\"===l&&(e=e.replace(/\\/g,"/")),encodeURI(e).replace(/[#?]/g,encodeURIComponent)}sourcePath(e){if(this.mapOpts.from)return this.toUrl(this.mapOpts.from);if(this.mapOpts.absolute){if(c)return c(e.source.input.from).toString();throw new Error("`map.absolute` option is not available in this PostCSS build")}return this.toUrl(this.path(e.source.input.from))}generateString(){this.css="",this.map=new i({file:this.outputFile()});let e,t,n=1,r=1,o={source:"",generated:{line:0,column:0},original:{line:0,column:0}};this.stringify(this.root,(i,a,s)=>{if(this.css+=i,a&&"end"!==s&&(o.generated.line=n,o.generated.column=r-1,a.source&&a.source.start?(o.source=this.sourcePath(a),o.original.line=a.source.start.line,o.original.column=a.source.start.column-1,this.map.addMapping(o)):(o.source="<no source>",o.original.line=1,o.original.column=0,this.map.addMapping(o))),e=i.match(/\n/g),e?(n+=e.length,t=i.lastIndexOf("\n"),r=i.length-t):r+=i.length,a&&"start"!==s){let e=a.parent||{raws:{}};("decl"!==a.type||a!==e.last||e.raws.semicolon)&&(a.source&&a.source.end?(o.source=this.sourcePath(a),o.original.line=a.source.end.line,o.original.column=a.source.end.column-1,o.generated.line=n,o.generated.column=r-2,this.map.addMapping(o)):(o.source="<no source>",o.original.line=1,o.original.column=0,o.generated.line=n,o.generated.column=r-1,this.map.addMapping(o)))}})}generate(){if(this.clearAnnotation(),h&&d&&this.isMap())return this.generateMap();{let e="";return this.stringify(this.root,t=>{e+=t}),[e]}}}}).call(this,n(160).Buffer)},function(e,t){},function(e,t,n){"use strict";(function(t){let{SourceMapConsumer:r,SourceMapGenerator:i}=n(161),{existsSync:o,readFileSync:a}=n(664),{dirname:s,join:l}=n(162);class c{constructor(e,t){if(!1===t.map)return;this.loadAnnotation(e),this.inline=this.startWith(this.annotation,"data:");let n=t.map?t.map.prev:void 0,r=this.loadMap(t.from,n);!this.mapFile&&t.from&&(this.mapFile=t.from),this.mapFile&&(this.root=s(this.mapFile)),r&&(this.text=r)}consumer(){return this.consumerCache||(this.consumerCache=new r(this.text)),this.consumerCache}withContent(){return!!(this.consumer().sourcesContent&&this.consumer().sourcesContent.length>0)}startWith(e,t){return!!e&&e.substr(0,t.length)===t}getAnnotationURL(e){return e.replace(/^\/\*\s*# sourceMappingURL=/,"").trim()}loadAnnotation(e){let t=e.match(/\/\*\s*# sourceMappingURL=/gm);if(!t)return;let n=e.lastIndexOf(t.pop()),r=e.indexOf("*/",n);n>-1&&r>-1&&(this.annotation=this.getAnnotationURL(e.substring(n,r)))}decodeInline(e){if(/^data:application\/json;charset=utf-?8,/.test(e)||/^data:application\/json,/.test(e))return decodeURIComponent(e.substr(RegExp.lastMatch.length));if(/^data:application\/json;charset=utf-?8;base64,/.test(e)||/^data:application\/json;base64,/.test(e))return n=e.substr(RegExp.lastMatch.length),t?t.from(n,"base64").toString():window.atob(n);var n;let r=e.match(/data:application\/json;([^,]+),/)[1];throw new Error("Unsupported source map encoding "+r)}loadFile(e){if(this.root=s(e),o(e))return this.mapFile=e,a(e,"utf-8").toString().trim()}loadMap(e,t){if(!1===t)return!1;if(t){if("string"==typeof t)return t;if("function"!=typeof t){if(t instanceof r)return i.fromSourceMap(t).toString();if(t instanceof i)return t.toString();if(this.isMap(t))return JSON.stringify(t);throw new Error("Unsupported previous source map format: "+t.toString())}{let n=t(e);if(n){let e=this.loadFile(n);if(!e)throw new Error("Unable to load previous source map: "+n.toString());return e}}}else{if(this.inline)return this.decodeInline(this.annotation);if(this.annotation){let t=this.annotation;return e&&(t=l(s(e),t)),this.loadFile(t)}}}isMap(e){return"object"==typeof e&&("string"==typeof e.mappings||"string"==typeof e._mappings||Array.isArray(e.sections))}}e.exports=c,c.default=c}).call(this,n(160).Buffer)},function(e,t,n){"use strict";let r={};e.exports=function(e){r[e]||(r[e]=!0,"undefined"!=typeof console&&console.warn&&console.warn(e))}},function(e,t,n){"use strict";class r{constructor(e,t={}){if(this.type="warning",this.text=e,t.node&&t.node.source){let e=t.node.rangeBy(t);this.line=e.start.line,this.column=e.start.column,this.endLine=e.end.line,this.endColumn=e.end.column}for(let e in t)this[e]=t[e]}toString(){return this.node?this.node.error(this.text,{plugin:this.plugin,index:this.index,word:this.word}).message:this.plugin?this.plugin+": "+this.text:this.text}}e.exports=r,r.default=r},function(e,t,n){"use strict";let r={split(e,t,n){let r=[],i="",o=!1,a=0,s=!1,l=!1;for(let n of e)l?l=!1:"\\"===n?l=!0:s?n===s&&(s=!1):'"'===n||"'"===n?s=n:"("===n?a+=1:")"===n?a>0&&(a-=1):0===a&&t.includes(n)&&(o=!0),o?(""!==i&&r.push(i.trim()),i="",o=!1):i+=n;return(n||""!==i)&&r.push(i.trim()),r},space:e=>r.split(e,[" ","\n","\t"]),comma:e=>r.split(e,[","],!0)};e.exports=r,r.default=r},function(e,t,n){!function(e){var t=/MSIE \d/.test(navigator.userAgent)&&(null==document.documentMode||document.documentMode<8),n=e.Pos,r={"(":")>",")":"(<","[":"]>","]":"[<","{":"}>","}":"{<","<":">>",">":"<<"};function i(e){return e&&e.bracketRegex||/[(){}[\]]/}function o(e,t,o){var s=e.getLineHandle(t.line),l=t.ch-1,c=o&&o.afterCursor;null==c&&(c=/(^| )cm-fat-cursor($| )/.test(e.getWrapperElement().className));var u=i(o),d=!c&&l>=0&&u.test(s.text.charAt(l))&&r[s.text.charAt(l)]||u.test(s.text.charAt(l+1))&&r[s.text.charAt(++l)];if(!d)return null;var h=">"==d.charAt(1)?1:-1;if(o&&o.strict&&h>0!=(l==t.ch))return null;var p=e.getTokenTypeAt(n(t.line,l+1)),f=a(e,n(t.line,l+(h>0?1:0)),h,p,o);return null==f?null:{from:n(t.line,l),to:f&&f.pos,match:f&&f.ch==d.charAt(0),forward:h>0}}function a(e,t,o,a,s){for(var l=s&&s.maxScanLineLength||1e4,c=s&&s.maxScanLines||1e3,u=[],d=i(s),h=o>0?Math.min(t.line+c,e.lastLine()+1):Math.max(e.firstLine()-1,t.line-c),p=t.line;p!=h;p+=o){var f=e.getLine(p);if(f){var m=o>0?0:f.length-1,g=o>0?f.length:-1;if(!(f.length>l))for(p==t.line&&(m=t.ch-(o<0?1:0));m!=g;m+=o){var v=f.charAt(m);if(d.test(v)&&(void 0===a||(e.getTokenTypeAt(n(p,m+1))||"")==(a||""))){var y=r[v];if(y&&">"==y.charAt(1)==o>0)u.push(v);else{if(!u.length)return{pos:n(p,m),ch:v};u.pop()}}}}}return p-o!=(o>0?e.lastLine():e.firstLine())&&null}function s(e,r,i){for(var a=e.state.matchBrackets.maxHighlightLineLength||1e3,s=i&&i.highlightNonMatching,l=[],c=e.listSelections(),u=0;u<c.length;u++){var d=c[u].empty()&&o(e,c[u].head,i);if(d&&(d.match||!1!==s)&&e.getLine(d.from.line).length<=a){var h=d.match?"CodeMirror-matchingbracket":"CodeMirror-nonmatchingbracket";l.push(e.markText(d.from,n(d.from.line,d.from.ch+1),{className:h})),d.to&&e.getLine(d.to.line).length<=a&&l.push(e.markText(d.to,n(d.to.line,d.to.ch+1),{className:h}))}}if(l.length){t&&e.state.focused&&e.focus();var p=function(){e.operation((function(){for(var e=0;e<l.length;e++)l[e].clear()}))};if(!r)return p;setTimeout(p,800)}}function l(e){e.operation((function(){e.state.matchBrackets.currentlyHighlighted&&(e.state.matchBrackets.currentlyHighlighted(),e.state.matchBrackets.currentlyHighlighted=null),e.state.matchBrackets.currentlyHighlighted=s(e,!1,e.state.matchBrackets)}))}function c(e){e.state.matchBrackets&&e.state.matchBrackets.currentlyHighlighted&&(e.state.matchBrackets.currentlyHighlighted(),e.state.matchBrackets.currentlyHighlighted=null)}e.defineOption("matchBrackets",!1,(function(t,n,r){r&&r!=e.Init&&(t.off("cursorActivity",l),t.off("focus",l),t.off("blur",c),c(t)),n&&(t.state.matchBrackets="object"==typeof n?n:{},t.on("cursorActivity",l),t.on("focus",l),t.on("blur",c))})),e.defineExtension("matchBrackets",(function(){s(this,!0)})),e.defineExtension("findMatchingBracket",(function(e,t,n){return(n||"boolean"==typeof t)&&(n?(n.strict=t,t=n):t=t?{strict:!0}:null),o(this,e,t)})),e.defineExtension("scanForBracket",(function(e,t,n,r){return a(this,e,t,n,r)}))}(n(14))},function(e,t,n){!function(e){"use strict";function t(t,n,i,o){if(i&&i.call){var a=i;i=null}else a=r(t,i,"rangeFinder");"number"==typeof n&&(n=e.Pos(n,0));var s=r(t,i,"minFoldSize");function l(e){var r=a(t,n);if(!r||r.to.line-r.from.line<s)return null;for(var i=t.findMarksAt(r.from),l=0;l<i.length;++l)if(i[l].__isFold&&"fold"!==o){if(!e)return null;r.cleared=!0,i[l].clear()}return r}var c=l(!0);if(r(t,i,"scanUp"))for(;!c&&n.line>t.firstLine();)n=e.Pos(n.line-1,0),c=l(!1);if(c&&!c.cleared&&"unfold"!==o){var u=function(e,t,n){var i=r(e,t,"widget");if("function"==typeof i&&(i=i(n.from,n.to)),"string"==typeof i){var o=document.createTextNode(i);(i=document.createElement("span")).appendChild(o),i.className="CodeMirror-foldmarker"}else i&&(i=i.cloneNode(!0));return i}(t,i,c);e.on(u,"mousedown",(function(t){d.clear(),e.e_preventDefault(t)}));var d=t.markText(c.from,c.to,{replacedWith:u,clearOnEnter:r(t,i,"clearOnEnter"),__isFold:!0});d.on("clear",(function(n,r){e.signal(t,"unfold",t,n,r)})),e.signal(t,"fold",t,c.from,c.to)}}e.newFoldFunction=function(e,n){return function(r,i){t(r,i,{rangeFinder:e,widget:n})}},e.defineExtension("foldCode",(function(e,n,r){t(this,e,n,r)})),e.defineExtension("isFolded",(function(e){for(var t=this.findMarksAt(e),n=0;n<t.length;++n)if(t[n].__isFold)return!0})),e.commands.toggleFold=function(e){e.foldCode(e.getCursor())},e.commands.fold=function(e){e.foldCode(e.getCursor(),null,"fold")},e.commands.unfold=function(e){e.foldCode(e.getCursor(),null,"unfold")},e.commands.foldAll=function(t){t.operation((function(){for(var n=t.firstLine(),r=t.lastLine();n<=r;n++)t.foldCode(e.Pos(n,0),null,"fold")}))},e.commands.unfoldAll=function(t){t.operation((function(){for(var n=t.firstLine(),r=t.lastLine();n<=r;n++)t.foldCode(e.Pos(n,0),null,"unfold")}))},e.registerHelper("fold","combine",(function(){var e=Array.prototype.slice.call(arguments,0);return function(t,n){for(var r=0;r<e.length;++r){var i=e[r](t,n);if(i)return i}}})),e.registerHelper("fold","auto",(function(e,t){for(var n=e.getHelpers(t,"fold"),r=0;r<n.length;r++){var i=n[r](e,t);if(i)return i}}));var n={rangeFinder:e.fold.auto,widget:"↔",minFoldSize:0,scanUp:!1,clearOnEnter:!0};function r(e,t,r){if(t&&void 0!==t[r])return t[r];var i=e.options.foldOptions;return i&&void 0!==i[r]?i[r]:n[r]}e.defineOption("foldOptions",null),e.defineExtension("foldOption",(function(e,t){return r(this,e,t)}))}(n(14))},function(e,t,n){!function(e){function t(t,n,r){var i,o=t.getWrapperElement();return(i=o.appendChild(document.createElement("div"))).className=r?"CodeMirror-dialog CodeMirror-dialog-bottom":"CodeMirror-dialog CodeMirror-dialog-top","string"==typeof n?i.innerHTML=n:i.appendChild(n),e.addClass(o,"dialog-opened"),i}function n(e,t){e.state.currentNotificationClose&&e.state.currentNotificationClose(),e.state.currentNotificationClose=t}e.defineExtension("openDialog",(function(r,i,o){o||(o={}),n(this,null);var a=t(this,r,o.bottom),s=!1,l=this;function c(t){if("string"==typeof t)d.value=t;else{if(s)return;s=!0,e.rmClass(a.parentNode,"dialog-opened"),a.parentNode.removeChild(a),l.focus(),o.onClose&&o.onClose(a)}}var u,d=a.getElementsByTagName("input")[0];return d?(d.focus(),o.value&&(d.value=o.value,!1!==o.selectValueOnOpen&&d.select()),o.onInput&&e.on(d,"input",(function(e){o.onInput(e,d.value,c)})),o.onKeyUp&&e.on(d,"keyup",(function(e){o.onKeyUp(e,d.value,c)})),e.on(d,"keydown",(function(t){o&&o.onKeyDown&&o.onKeyDown(t,d.value,c)||((27==t.keyCode||!1!==o.closeOnEnter&&13==t.keyCode)&&(d.blur(),e.e_stop(t),c()),13==t.keyCode&&i(d.value,t))})),!1!==o.closeOnBlur&&e.on(a,"focusout",(function(e){null!==e.relatedTarget&&c()}))):(u=a.getElementsByTagName("button")[0])&&(e.on(u,"click",(function(){c(),l.focus()})),!1!==o.closeOnBlur&&e.on(u,"blur",c),u.focus()),c})),e.defineExtension("openConfirm",(function(r,i,o){n(this,null);var a=t(this,r,o&&o.bottom),s=a.getElementsByTagName("button"),l=!1,c=this,u=1;function d(){l||(l=!0,e.rmClass(a.parentNode,"dialog-opened"),a.parentNode.removeChild(a),c.focus())}s[0].focus();for(var h=0;h<s.length;++h){var p=s[h];!function(t){e.on(p,"click",(function(n){e.e_preventDefault(n),d(),t&&t(c)}))}(i[h]),e.on(p,"blur",(function(){--u,setTimeout((function(){u<=0&&d()}),200)})),e.on(p,"focus",(function(){++u}))}})),e.defineExtension("openNotification",(function(r,i){n(this,c);var o,a=t(this,r,i&&i.bottom),s=!1,l=i&&void 0!==i.duration?i.duration:5e3;function c(){s||(s=!0,clearTimeout(o),e.rmClass(a.parentNode,"dialog-opened"),a.parentNode.removeChild(a))}return e.on(a,"click",(function(t){e.e_preventDefault(t),c()})),l&&(o=setTimeout(c,l)),c}))}(n(14))},function(e,t,n){"use strict";
/*
object-assign
(c) Sindre Sorhus
@license MIT
*/var r=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,o=Object.prototype.propertyIsEnumerable;function a(e){if(null==e)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(e)}e.exports=function(){try{if(!Object.assign)return!1;var e=new String("abc");if(e[5]="de","5"===Object.getOwnPropertyNames(e)[0])return!1;for(var t={},n=0;n<10;n++)t["_"+String.fromCharCode(n)]=n;if("0123456789"!==Object.getOwnPropertyNames(t).map((function(e){return t[e]})).join(""))return!1;var r={};return"abcdefghijklmnopqrst".split("").forEach((function(e){r[e]=e})),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},r)).join("")}catch(e){return!1}}()?Object.assign:function(e,t){for(var n,s,l=a(e),c=1;c<arguments.length;c++){for(var u in n=Object(arguments[c]))i.call(n,u)&&(l[u]=n[u]);if(r){s=r(n);for(var d=0;d<s.length;d++)o.call(n,s[d])&&(l[s[d]]=n[s[d]])}}return l}},function(e,t){
/*!
Copyright (C) 2013-2015 by Andrea Giammarchi - @WebReflection

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

*/
!function(e){"use strict";function t(){return d.createDocumentFragment()}function n(e){return d.createElement(e)}function r(e,t){if(!e)throw new Error("Failed to construct "+t+": 1 argument required, but only 0 present.")}function i(e){if(1===e.length)return o(e[0]);for(var n=t(),r=k.call(e),i=0;i<e.length;i++)n.appendChild(o(r[i]));return n}function o(e){return"object"==typeof e?e:d.createTextNode(e)}for(var a,s,l,c,u,d=e.document,h=Object.prototype.hasOwnProperty,p=Object.defineProperty||function(e,t,n){return h.call(n,"value")?e[t]=n.value:(h.call(n,"get")&&e.__defineGetter__(t,n.get),h.call(n,"set")&&e.__defineSetter__(t,n.set)),e},f=[].indexOf||function(e){for(var t=this.length;t--&&this[t]!==e;);return t},m=function(e){var t=void 0===e.className,n=t?e.getAttribute("class")||"":e.className,r=t||"object"==typeof n,i=(r?t?n:n.baseVal:n).replace(v,"");i.length&&I.push.apply(this,i.split(y)),this._isSVG=r,this._=e},g={get:function(){return new m(this)},set:function(){}},v=/^\s+|\s+$/g,y=/\s+/,_=function(e,t){return this.contains(e)?t||this.remove(e):(void 0===t||t)&&(t=!0,this.add(e)),!!t},b=e.DocumentFragment&&DocumentFragment.prototype,M=e.Node,w=(M||Element).prototype,A=e.CharacterData||M,C=A&&A.prototype,x=e.DocumentType,E=x&&x.prototype,L=(e.Element||M||e.HTMLElement).prototype,S=e.HTMLSelectElement||n("select").constructor,T=S.prototype.remove,O=e.SVGElement,I=["matches",L.matchesSelector||L.webkitMatchesSelector||L.khtmlMatchesSelector||L.mozMatchesSelector||L.msMatchesSelector||L.oMatchesSelector||function(e){var t=this.parentNode;return!!t&&-1<f.call(t.querySelectorAll(e),this)},"closest",function(e){for(var t,n=this;(t=n&&n.matches)&&!n.matches(e);)n=n.parentNode;return t?n:null},"prepend",function(){var e=this.firstChild,t=i(arguments);e?this.insertBefore(t,e):this.appendChild(t)},"append",function(){this.appendChild(i(arguments))},"before",function(){var e=this.parentNode;e&&e.insertBefore(i(arguments),this)},"after",function(){var e=this.parentNode,t=this.nextSibling,n=i(arguments);e&&(t?e.insertBefore(n,t):e.appendChild(n))},"toggleAttribute",function(e,t){var n=this.hasAttribute(e);return 1<arguments.length?n&&!t?this.removeAttribute(e):t&&!n&&this.setAttribute(e,""):n?this.removeAttribute(e):this.setAttribute(e,""),this.hasAttribute(e)},"replace",function(){this.replaceWith.apply(this,arguments)},"replaceWith",function(){var e=this.parentNode;e&&e.replaceChild(i(arguments),this)},"remove",function(){var e=this.parentNode;e&&e.removeChild(this)}],k=I.slice,D=I.length;D;D-=2)if((s=I[D-2])in L||(L[s]=I[D-1]),"remove"!==s||T._dom4||((S.prototype[s]=function(){return 0<arguments.length?T.apply(this,arguments):L.remove.call(this)})._dom4=!0),/^(?:before|after|replace|replaceWith|remove)$/.test(s)&&(A&&!(s in C)&&(C[s]=I[D-1]),x&&!(s in E)&&(E[s]=I[D-1])),/^(?:append|prepend)$/.test(s))if(b)s in b||(b[s]=I[D-1]);else try{t().constructor.prototype[s]=I[D-1]}catch(e){}var N;n("a").matches("a")||(L[s]=(N=L[s],function(e){return N.call(this.parentNode?this:t().appendChild(this),e)})),m.prototype={length:0,add:function(){for(var e,t=0;t<arguments.length;t++)e=arguments[t],this.contains(e)||I.push.call(this,s);this._isSVG?this._.setAttribute("class",""+this):this._.className=""+this},contains:function(e){return function(t){return-1<(D=e.call(this,s=function(e){if(!e)throw"SyntaxError";if(y.test(e))throw"InvalidCharacterError";return e}(t)))}}([].indexOf||function(e){for(D=this.length;D--&&this[D]!==e;);return D}),item:function(e){return this[e]||null},remove:function(){for(var e,t=0;t<arguments.length;t++)e=arguments[t],this.contains(e)&&I.splice.call(this,D,1);this._isSVG?this._.setAttribute("class",""+this):this._.className=""+this},toggle:_,toString:function(){return I.join.call(this," ")}},O&&!("classList"in O.prototype)&&p(O.prototype,"classList",g),"classList"in d.documentElement?((c=n("div").classList).add("a","b","a"),"a b"!=c&&("add"in(l=c.constructor.prototype)||(l=e.TemporaryTokenList.prototype),u=function(e){return function(){for(var t=0;t<arguments.length;)e.call(this,arguments[t++])}},l.add=u(l.add),l.remove=u(l.remove),l.toggle=_)):p(L,"classList",g),"contains"in w||p(w,"contains",{value:function(e){for(;e&&e!==this;)e=e.parentNode;return this===e}}),"head"in d||p(d,"head",{get:function(){return a||(a=d.getElementsByTagName("head")[0])}}),function(){for(var t,n=e.requestAnimationFrame,r=e.cancelAnimationFrame,i=["o","ms","moz","webkit"],o=i.length;!r&&o--;)n=n||e[i[o]+"RequestAnimationFrame"],r=e[i[o]+"CancelAnimationFrame"]||e[i[o]+"CancelRequestAnimationFrame"];r||(n?(t=n,n=function(e){var n=!0;return t((function(){n&&e.apply(this,arguments)})),function(){n=!1}},r=function(e){e()}):(n=function(e){return setTimeout(e,15,15)},r=function(e){clearTimeout(e)})),e.requestAnimationFrame=n,e.cancelAnimationFrame=r}();try{new e.CustomEvent("?")}catch(t){e.CustomEvent=function(e,t){function n(e,t,n,r){this.initEvent(e,t,n),this.detail=r}return function(r,i){var o=d.createEvent(e);if("string"!=typeof r)throw new Error("An event name must be provided");return"Event"==e&&(o.initCustomEvent=n),null==i&&(i=t),o.initCustomEvent(r,i.bubbles,i.cancelable,i.detail),o}}(e.CustomEvent?"CustomEvent":"Event",{bubbles:!1,cancelable:!1,detail:null})}try{new Event("_")}catch(t){t=function(e){function t(e,t){r(arguments.length,"Event");var n=d.createEvent("Event");return t||(t={}),n.initEvent(e,!!t.bubbles,!!t.cancelable),n}return t.prototype=e.prototype,t}(e.Event||function(){}),p(e,"Event",{value:t}),Event!==t&&(Event=t)}try{new KeyboardEvent("_",{})}catch(t){t=function(t){var n,i=0,o={char:"",key:"",location:0,ctrlKey:!1,shiftKey:!1,altKey:!1,metaKey:!1,altGraphKey:!1,repeat:!1,locale:navigator.language,detail:0,bubbles:!1,cancelable:!1,keyCode:0,charCode:0,which:0};try{var a=d.createEvent("KeyboardEvent");a.initKeyboardEvent("keyup",!1,!1,e,"+",3,!0,!1,!0,!1,!1),i="+"==(a.keyIdentifier||a.key)&&3==(a.keyLocation||a.location)&&(a.ctrlKey?a.altKey?1:3:a.shiftKey?2:4)||9}catch(e){}function s(e){for(var t=[],n=["ctrlKey","Control","shiftKey","Shift","altKey","Alt","metaKey","Meta","altGraphKey","AltGraph"],r=0;r<n.length;r+=2)e[n[r]]&&t.push(n[r+1]);return t.join(" ")}function l(e,t){for(var n in t)t.hasOwnProperty(n)&&!t.hasOwnProperty.call(e,n)&&(e[n]=t[n]);return e}function c(e,t,n){try{t[e]=n[e]}catch(e){}}function u(t,a){r(arguments.length,"KeyboardEvent"),a=l(a||{},o);var u,h=d.createEvent(n),p=a.ctrlKey,f=a.shiftKey,m=a.altKey,g=a.metaKey,v=a.altGraphKey,y=i>3?s(a):null,_=String(a.key),b=String(a.char),M=a.location,w=a.keyCode||(a.keyCode=_)&&_.charCodeAt(0)||0,A=a.charCode||(a.charCode=b)&&b.charCodeAt(0)||0,C=a.bubbles,x=a.cancelable,E=a.repeat,L=a.locale,S=a.view||e;if(a.which||(a.which=a.keyCode),"initKeyEvent"in h)h.initKeyEvent(t,C,x,S,p,m,f,g,w,A);else if(0<i&&"initKeyboardEvent"in h){switch(u=[t,C,x,S],i){case 1:u.push(_,M,p,f,m,g,v);break;case 2:u.push(p,m,f,g,w,A);break;case 3:u.push(_,M,p,m,f,g,v);break;case 4:u.push(_,M,y,E,L);break;default:u.push(char,_,M,y,E,L)}h.initKeyboardEvent.apply(h,u)}else h.initEvent(t,C,x);for(_ in h)o.hasOwnProperty(_)&&h[_]!==a[_]&&c(_,h,a);return h}return n=0<i?"KeyboardEvent":"Event",u.prototype=t.prototype,u}(e.KeyboardEvent||function(){}),p(e,"KeyboardEvent",{value:t}),KeyboardEvent!==t&&(KeyboardEvent=t)}try{new MouseEvent("_",{})}catch(t){t=function(t){function n(t,n){r(arguments.length,"MouseEvent");var i=d.createEvent("MouseEvent");return n||(n={}),i.initMouseEvent(t,!!n.bubbles,!!n.cancelable,n.view||e,n.detail||1,n.screenX||0,n.screenY||0,n.clientX||0,n.clientY||0,!!n.ctrlKey,!!n.altKey,!!n.shiftKey,!!n.metaKey,n.button||0,n.relatedTarget||null),i}return n.prototype=t.prototype,n}(e.MouseEvent||function(){}),p(e,"MouseEvent",{value:t}),MouseEvent!==t&&(MouseEvent=t)}d.querySelectorAll("*").forEach||function(){function e(e){var t=e.querySelectorAll;e.querySelectorAll=function(e){var n=t.call(this,e);return n.forEach=Array.prototype.forEach,n}}e(d),e(Element.prototype)}();try{d.querySelector(":scope *")}catch(e){!function(){var e="data-scope-"+(1e9*Math.random()>>>0),t=Element.prototype,n=t.querySelector,r=t.querySelectorAll;function i(t,n,r){if(t.type!=d.ELEMENT_NODE)return n.call(t,r);t.setAttribute(e,null);var i=n.call(t,String(r).replace(/(^|,\s*)(:scope([ >]|$))/g,(function(t,n,r,i){return n+"["+e+"]"+(i||" ")})));return t.removeAttribute(e),i}t.querySelector=function(e){return i(this,n,e)},t.querySelectorAll=function(e){return i(this,r,e)}}()}}(window),function(e){"use strict";var t=e.WeakMap||function(){var e,t=0,n=!1,r=!1;function i(t,i,o){r=o,n=!1,e=void 0,t.dispatchEvent(i)}function o(e){this.value=e}function s(){t++,this.__ce__=new a("@DOMMap:"+t+Math.random())}return o.prototype.handleEvent=function(t){n=!0,r?t.currentTarget.removeEventListener(t.type,this,!1):e=this.value},s.prototype={constructor:s,delete:function(e){return i(e,this.__ce__,!0),n},get:function(t){i(t,this.__ce__,!1);var n=e;return e=void 0,n},has:function(e){return i(e,this.__ce__,!1),n},set:function(e,t){return i(e,this.__ce__,!0),e.addEventListener(this.__ce__.type,new o(t),!1),this}},s}();function n(){}function r(e,t,n){function i(e){i.once&&(e.currentTarget.removeEventListener(e.type,t,i),i.removed=!0),i.passive&&(e.preventDefault=r.preventDefault),"function"==typeof i.callback?i.callback.call(this,e):i.callback&&i.callback.handleEvent(e),i.passive&&delete e.preventDefault}return i.type=e,i.callback=t,i.capture=!!n.capture,i.passive=!!n.passive,i.once=!!n.once,i.removed=!1,i}n.prototype=(Object.create||Object)(null),r.preventDefault=function(){};var i,o,a=e.CustomEvent,s=e.dispatchEvent,l=e.addEventListener,c=e.removeEventListener,u=0,d=function(){u++},h=[].indexOf||function(e){for(var t=this.length;t--&&this[t]!==e;);return t},p=function(e){return"".concat(e.capture?"1":"0",e.passive?"1":"0",e.once?"1":"0")};try{l("_",d,{once:!0}),s(new a("_")),s(new a("_")),c("_",d,{once:!0})}catch(e){}1!==u&&(o=new t,i=function(e){if(e){var t=e.prototype;t.addEventListener=function(e){return function(t,i,a){if(a&&"boolean"!=typeof a){var s,l,c,u=o.get(this),d=p(a);u||o.set(this,u=new n),t in u||(u[t]={handler:[],wrap:[]}),l=u[t],(s=h.call(l.handler,i))<0?(s=l.handler.push(i)-1,l.wrap[s]=c=new n):c=l.wrap[s],d in c||(c[d]=r(t,i,a),e.call(this,t,c[d],c[d].capture))}else e.call(this,t,i,a)}}(t.addEventListener),t.removeEventListener=function(e){return function(t,n,r){if(r&&"boolean"!=typeof r){var i,a,s,l,c=o.get(this);if(c&&t in c&&(s=c[t],-1<(a=h.call(s.handler,n))&&(i=p(r))in(l=s.wrap[a]))){for(i in e.call(this,t,l[i],l[i].capture),delete l[i],l)return;s.handler.splice(a,1),s.wrap.splice(a,1),0===s.handler.length&&delete c[t]}}else e.call(this,t,n,r)}}(t.removeEventListener)}},e.EventTarget?i(EventTarget):(i(e.Text),i(e.Element||e.HTMLElement),i(e.HTMLDocument),i(e.Window||{prototype:e}),i(e.XMLHttpRequest)))}(self)},function(e,t,n){"use strict";(function(e){var r,i,o,a;Object.defineProperty(t,"__esModule",{value:!0}),t.ALERT_BODY=t.ALERT=t.FIXED_POSITIONING_CONTAINING_BLOCK=t.RTL=t.LIST_UNSTYLED=t.LIST=t.HEADING=t.CODE_BLOCK=t.CODE=t.BLOCKQUOTE=t.TEXT_OVERFLOW_ELLIPSIS=t.TEXT_DISABLED=t.TEXT_MUTED=t.TEXT_SMALL=t.TEXT_LARGE=t.MONOSPACE_TEXT=t.RUNNING_TEXT=t.UI_TEXT=t.FOCUS_DISABLED=t.INTENT_DANGER=t.INTENT_WARNING=t.INTENT_SUCCESS=t.INTENT_PRIMARY=t.ELEVATION_4=t.ELEVATION_3=t.ELEVATION_2=t.ELEVATION_1=t.ELEVATION_0=t.POSITION_RIGHT=t.POSITION_LEFT=t.POSITION_BOTTOM=t.POSITION_TOP=t.VERTICAL=t.SMALL=t.ROUND=t.MULTILINE=t.OUTLINED=t.MINIMAL=t.LOADING=t.LARGE=t.INTERACTIVE=t.INLINE=t.FIXED_TOP=t.FIXED=t.FILL=t.DISABLED=t.DARK=t.ALIGN_RIGHT=t.ALIGN_LEFT=t.ACTIVE=void 0,t.INPUT_GHOST=t.INPUT=t.HTML_TABLE_STRIPED=t.HTML_TABLE_CONDENSED=t.HTML_TABLE_BORDERED=t.HTML_TABLE=t.SELECT=t.HTML_SELECT=t.FLEX_EXPANDER=t.EDITABLE_TEXT_PLACEHOLDER=t.EDITABLE_TEXT_INPUT=t.EDITABLE_TEXT_EDITING=t.EDITABLE_TEXT_CONTENT=t.EDITABLE_TEXT=t.DRAWER_HEADER=t.DRAWER_FOOTER=t.DRAWER_BODY=t.DRAWER=t.DIVIDER=t.DIALOG_STEP_VIEWED=t.DIALOG_STEP_ICON=t.DIALOG_STEP_TITLE=t.DIALOG_STEP_CONTAINER=t.DIALOG_STEP=t.DIALOG_HEADER=t.DIALOG_FOOTER_ACTIONS=t.DIALOG_FOOTER=t.DIALOG_CLOSE_BUTTON=t.DIALOG_BODY=t.DIALOG_CONTAINER=t.DIALOG=t.CONTROL_GROUP=t.CONTEXT_MENU_POPOVER_TARGET=t.CONTEXT_MENU=t.COLLAPSIBLE_LIST=t.COLLAPSE_BODY=t.COLLAPSE=t.CARD=t.CALLOUT_ICON=t.CALLOUT=t.BUTTON_TEXT=t.BUTTON_SPINNER=t.BUTTON_GROUP=t.BUTTON=t.BREADCRUMBS_COLLAPSED=t.BREADCRUMBS=t.BREADCRUMB_CURRENT=t.BREADCRUMB=t.ALERT_FOOTER=t.ALERT_CONTENTS=void 0,t.OVERLAY_CONTENT=t.OVERLAY_CONTAINER=t.OVERLAY_BACKDROP=t.OVERLAY=t.OVERFLOW_LIST_SPACER=t.OVERFLOW_LIST=t.NUMERIC_INPUT=t.NON_IDEAL_STATE_VISUAL=t.NON_IDEAL_STATE=t.NAVBAR_DIVIDER=t.NAVBAR_HEADING=t.NAVBAR_GROUP=t.NAVBAR=t.MULTISTEP_DIALOG_FOOTER=t.MULTISTEP_DIALOG_RIGHT_PANEL=t.MULTISTEP_DIALOG_LEFT_PANEL=t.MULTISTEP_DIALOG_PANELS=t.MULTISTEP_DIALOG=t.MENU_HEADER=t.MENU_DIVIDER=t.MENU_SUBMENU=t.MENU_ITEM_LABEL=t.MENU_ITEM=t.MENU=t.FORM_GROUP_SUB_LABEL=t.FORM_HELPER_TEXT=t.FORM_CONTENT=t.FORM_GROUP=t.LABEL=t.HOTKEY_DIALOG=t.HOTKEY_COLUMN=t.HOTKEY_LABEL=t.HOTKEY=t.MODIFIER_KEY=t.KEY_COMBO=t.KEY=t.FILE_UPLOAD_INPUT_CUSTOM_TEXT=t.FILE_UPLOAD_INPUT=t.FILE_INPUT_HAS_SELECTION=t.FILE_INPUT=t.SWITCH_INNER_TEXT=t.SWITCH=t.RADIO=t.CHECKBOX=t.CONTROL_INDICATOR_CHILD=t.CONTROL_INDICATOR=t.CONTROL=t.INPUT_ACTION=t.INPUT_LEFT_CONTAINER=t.INPUT_GROUP=void 0,t.TAB_PANEL=t.TAB_LIST=t.TAB_INDICATOR_WRAPPER=t.TAB_INDICATOR=t.TAB=t.SPINNER_TRACK=t.SPINNER_NO_SPIN=t.SPINNER_HEAD=t.SPINNER_ANIMATION=t.SPINNER=t.END=t.START=t.SLIDER_PROGRESS=t.SLIDER_TRACK=t.SLIDER_LABEL=t.SLIDER_HANDLE=t.SLIDER_AXIS=t.SLIDER=t.SKELETON=t.PORTAL=t.PROGRESS_NO_ANIMATION=t.PROGRESS_NO_STRIPES=t.PROGRESS_METER=t.PROGRESS_BAR=t.TRANSITION_CONTAINER=t.POPOVER_WRAPPER=t.POPOVER_TARGET=t.POPOVER_OUT_OF_BOUNDARIES=t.POPOVER_OPEN=t.POPOVER_DISMISS_OVERRIDE=t.POPOVER_DISMISS=t.POPOVER_CONTENT_SIZING=t.POPOVER_CONTENT=t.POPOVER_CAPTURING_DISMISS=t.POPOVER_BACKDROP=t.POPOVER_ARROW=t.POPOVER=t.PANEL_STACK2_VIEW=t.PANEL_STACK2_HEADER_BACK=t.PANEL_STACK2_HEADER=t.PANEL_STACK2=t.PANEL_STACK_VIEW=t.PANEL_STACK_HEADER_BACK=t.PANEL_STACK_HEADER=t.PANEL_STACK=t.OVERLAY_END_FOCUS_TRAP=t.OVERLAY_START_FOCUS_TRAP=t.OVERLAY_SCROLL_CONTAINER=t.OVERLAY_OPEN=t.OVERLAY_INLINE=void 0,t.positionClass=t.intentClass=t.iconClass=t.elevationClass=t.alignmentClass=t.getClassNamespace=t.ICON_LARGE=t.ICON_STANDARD=t.ICON=t.TREE_ROOT=t.TREE_NODE_SELECTED=t.TREE_NODE_SECONDARY_LABEL=t.TREE_NODE_LIST=t.TREE_NODE_LABEL=t.TREE_NODE_ICON=t.TREE_NODE_EXPANDED=t.TREE_NODE_CONTENT=t.TREE_NODE_CARET_OPEN=t.TREE_NODE_CARET_NONE=t.TREE_NODE_CARET_CLOSED=t.TREE_NODE_CARET=t.TREE_NODE=t.TREE=t.TOOLTIP_INDICATOR=t.TOOLTIP=t.TOAST_MESSAGE=t.TOAST_CONTAINER=t.TOAST=t.TAG_INPUT_VALUES=t.TAG_INPUT_ICON=t.TAG_INPUT=t.TAG_REMOVE=t.TAG=t.TABS=void 0;var s=n(382),l=n(383),c=n(128),u=n(384),d="bp3";function h(e){if(void 0!==e)return d+"-elevation-"+e}function p(e){if(null!=e&&e!==c.Intent.NONE)return d+"-intent-"+e.toLowerCase()}function f(e){if(void 0!==e)return d+"-position-"+e}void 0!==e&&(d=null!==(a=null!==(i=null===(r=e.env)||void 0===r?void 0:r.BLUEPRINT_NAMESPACE)&&void 0!==i?i:null===(o=e.env)||void 0===o?void 0:o.REACT_APP_BLUEPRINT_NAMESPACE)&&void 0!==a?a:d),t.ACTIVE=d+"-active",t.ALIGN_LEFT=d+"-align-left",t.ALIGN_RIGHT=d+"-align-right",t.DARK=d+"-dark",t.DISABLED=d+"-disabled",t.FILL=d+"-fill",t.FIXED=d+"-fixed",t.FIXED_TOP=d+"-fixed-top",t.INLINE=d+"-inline",t.INTERACTIVE=d+"-interactive",t.LARGE=d+"-large",t.LOADING=d+"-loading",t.MINIMAL=d+"-minimal",t.OUTLINED=d+"-outlined",t.MULTILINE=d+"-multiline",t.ROUND=d+"-round",t.SMALL=d+"-small",t.VERTICAL=d+"-vertical",t.POSITION_TOP=f(u.Position.TOP),t.POSITION_BOTTOM=f(u.Position.BOTTOM),t.POSITION_LEFT=f(u.Position.LEFT),t.POSITION_RIGHT=f(u.Position.RIGHT),t.ELEVATION_0=h(l.Elevation.ZERO),t.ELEVATION_1=h(l.Elevation.ONE),t.ELEVATION_2=h(l.Elevation.TWO),t.ELEVATION_3=h(l.Elevation.THREE),t.ELEVATION_4=h(l.Elevation.FOUR),t.INTENT_PRIMARY=p(c.Intent.PRIMARY),t.INTENT_SUCCESS=p(c.Intent.SUCCESS),t.INTENT_WARNING=p(c.Intent.WARNING),t.INTENT_DANGER=p(c.Intent.DANGER),t.FOCUS_DISABLED=d+"-focus-disabled",t.UI_TEXT=d+"-ui-text",t.RUNNING_TEXT=d+"-running-text",t.MONOSPACE_TEXT=d+"-monospace-text",t.TEXT_LARGE=d+"-text-large",t.TEXT_SMALL=d+"-text-small",t.TEXT_MUTED=d+"-text-muted",t.TEXT_DISABLED=d+"-text-disabled",t.TEXT_OVERFLOW_ELLIPSIS=d+"-text-overflow-ellipsis",t.BLOCKQUOTE=d+"-blockquote",t.CODE=d+"-code",t.CODE_BLOCK=d+"-code-block",t.HEADING=d+"-heading",t.LIST=d+"-list",t.LIST_UNSTYLED=d+"-list-unstyled",t.RTL=d+"-rtl",t.FIXED_POSITIONING_CONTAINING_BLOCK=d+"-fixed-positioning-containing-block",t.ALERT=d+"-alert",t.ALERT_BODY=t.ALERT+"-body",t.ALERT_CONTENTS=t.ALERT+"-contents",t.ALERT_FOOTER=t.ALERT+"-footer",t.BREADCRUMB=d+"-breadcrumb",t.BREADCRUMB_CURRENT=t.BREADCRUMB+"-current",t.BREADCRUMBS=t.BREADCRUMB+"s",t.BREADCRUMBS_COLLAPSED=t.BREADCRUMB+"s-collapsed",t.BUTTON=d+"-button",t.BUTTON_GROUP=t.BUTTON+"-group",t.BUTTON_SPINNER=t.BUTTON+"-spinner",t.BUTTON_TEXT=t.BUTTON+"-text",t.CALLOUT=d+"-callout",t.CALLOUT_ICON=t.CALLOUT+"-icon",t.CARD=d+"-card",t.COLLAPSE=d+"-collapse",t.COLLAPSE_BODY=t.COLLAPSE+"-body",t.COLLAPSIBLE_LIST=d+"-collapse-list",t.CONTEXT_MENU=d+"-context-menu",t.CONTEXT_MENU_POPOVER_TARGET=t.CONTEXT_MENU+"-popover-target",t.CONTROL_GROUP=d+"-control-group",t.DIALOG=d+"-dialog",t.DIALOG_CONTAINER=t.DIALOG+"-container",t.DIALOG_BODY=t.DIALOG+"-body",t.DIALOG_CLOSE_BUTTON=t.DIALOG+"-close-button",t.DIALOG_FOOTER=t.DIALOG+"-footer",t.DIALOG_FOOTER_ACTIONS=t.DIALOG+"-footer-actions",t.DIALOG_HEADER=t.DIALOG+"-header",t.DIALOG_STEP=d+"-dialog-step",t.DIALOG_STEP_CONTAINER=t.DIALOG_STEP+"-container",t.DIALOG_STEP_TITLE=t.DIALOG_STEP+"-title",t.DIALOG_STEP_ICON=t.DIALOG_STEP+"-icon",t.DIALOG_STEP_VIEWED=t.DIALOG_STEP+"-viewed",t.DIVIDER=d+"-divider",t.DRAWER=d+"-drawer",t.DRAWER_BODY=t.DRAWER+"-body",t.DRAWER_FOOTER=t.DRAWER+"-footer",t.DRAWER_HEADER=t.DRAWER+"-header",t.EDITABLE_TEXT=d+"-editable-text",t.EDITABLE_TEXT_CONTENT=t.EDITABLE_TEXT+"-content",t.EDITABLE_TEXT_EDITING=t.EDITABLE_TEXT+"-editing",t.EDITABLE_TEXT_INPUT=t.EDITABLE_TEXT+"-input",t.EDITABLE_TEXT_PLACEHOLDER=t.EDITABLE_TEXT+"-placeholder",t.FLEX_EXPANDER=d+"-flex-expander",t.HTML_SELECT=d+"-html-select",t.SELECT=d+"-select",t.HTML_TABLE=d+"-html-table",t.HTML_TABLE_BORDERED=t.HTML_TABLE+"-bordered",t.HTML_TABLE_CONDENSED=t.HTML_TABLE+"-condensed",t.HTML_TABLE_STRIPED=t.HTML_TABLE+"-striped",t.INPUT=d+"-input",t.INPUT_GHOST=t.INPUT+"-ghost",t.INPUT_GROUP=t.INPUT+"-group",t.INPUT_LEFT_CONTAINER=t.INPUT+"-left-container",t.INPUT_ACTION=t.INPUT+"-action",t.CONTROL=d+"-control",t.CONTROL_INDICATOR=t.CONTROL+"-indicator",t.CONTROL_INDICATOR_CHILD=t.CONTROL_INDICATOR+"-child",t.CHECKBOX=d+"-checkbox",t.RADIO=d+"-radio",t.SWITCH=d+"-switch",t.SWITCH_INNER_TEXT=t.SWITCH+"-inner-text",t.FILE_INPUT=d+"-file-input",t.FILE_INPUT_HAS_SELECTION=d+"-file-input-has-selection",t.FILE_UPLOAD_INPUT=d+"-file-upload-input",t.FILE_UPLOAD_INPUT_CUSTOM_TEXT=d+"-file-upload-input-custom-text",t.KEY=d+"-key",t.KEY_COMBO=t.KEY+"-combo",t.MODIFIER_KEY=d+"-modifier-key",t.HOTKEY=d+"-hotkey",t.HOTKEY_LABEL=t.HOTKEY+"-label",t.HOTKEY_COLUMN=t.HOTKEY+"-column",t.HOTKEY_DIALOG=t.HOTKEY+"-dialog",t.LABEL=d+"-label",t.FORM_GROUP=d+"-form-group",t.FORM_CONTENT=d+"-form-content",t.FORM_HELPER_TEXT=d+"-form-helper-text",t.FORM_GROUP_SUB_LABEL=d+"-form-group-sub-label",t.MENU=d+"-menu",t.MENU_ITEM=t.MENU+"-item",t.MENU_ITEM_LABEL=t.MENU_ITEM+"-label",t.MENU_SUBMENU=d+"-submenu",t.MENU_DIVIDER=t.MENU+"-divider",t.MENU_HEADER=t.MENU+"-header",t.MULTISTEP_DIALOG=d+"-multistep-dialog",t.MULTISTEP_DIALOG_PANELS=t.MULTISTEP_DIALOG+"-panels",t.MULTISTEP_DIALOG_LEFT_PANEL=t.MULTISTEP_DIALOG+"-left-panel",t.MULTISTEP_DIALOG_RIGHT_PANEL=t.MULTISTEP_DIALOG+"-right-panel",t.MULTISTEP_DIALOG_FOOTER=t.MULTISTEP_DIALOG+"-footer",t.NAVBAR=d+"-navbar",t.NAVBAR_GROUP=t.NAVBAR+"-group",t.NAVBAR_HEADING=t.NAVBAR+"-heading",t.NAVBAR_DIVIDER=t.NAVBAR+"-divider",t.NON_IDEAL_STATE=d+"-non-ideal-state",t.NON_IDEAL_STATE_VISUAL=t.NON_IDEAL_STATE+"-visual",t.NUMERIC_INPUT=d+"-numeric-input",t.OVERFLOW_LIST=d+"-overflow-list",t.OVERFLOW_LIST_SPACER=t.OVERFLOW_LIST+"-spacer",t.OVERLAY=d+"-overlay",t.OVERLAY_BACKDROP=t.OVERLAY+"-backdrop",t.OVERLAY_CONTAINER=t.OVERLAY+"-container",t.OVERLAY_CONTENT=t.OVERLAY+"-content",t.OVERLAY_INLINE=t.OVERLAY+"-inline",t.OVERLAY_OPEN=t.OVERLAY+"-open",t.OVERLAY_SCROLL_CONTAINER=t.OVERLAY+"-scroll-container",t.OVERLAY_START_FOCUS_TRAP=t.OVERLAY+"-start-focus-trap",t.OVERLAY_END_FOCUS_TRAP=t.OVERLAY+"-end-focus-trap",t.PANEL_STACK=d+"-panel-stack",t.PANEL_STACK_HEADER=t.PANEL_STACK+"-header",t.PANEL_STACK_HEADER_BACK=t.PANEL_STACK+"-header-back",t.PANEL_STACK_VIEW=t.PANEL_STACK+"-view",t.PANEL_STACK2=d+"-panel-stack2",t.PANEL_STACK2_HEADER=t.PANEL_STACK+"-header",t.PANEL_STACK2_HEADER_BACK=t.PANEL_STACK+"-header-back",t.PANEL_STACK2_VIEW=t.PANEL_STACK+"-view",t.POPOVER=d+"-popover",t.POPOVER_ARROW=t.POPOVER+"-arrow",t.POPOVER_BACKDROP=t.POPOVER+"-backdrop",t.POPOVER_CAPTURING_DISMISS=t.POPOVER+"-capturing-dismiss",t.POPOVER_CONTENT=t.POPOVER+"-content",t.POPOVER_CONTENT_SIZING=t.POPOVER_CONTENT+"-sizing",t.POPOVER_DISMISS=t.POPOVER+"-dismiss",t.POPOVER_DISMISS_OVERRIDE=t.POPOVER_DISMISS+"-override",t.POPOVER_OPEN=t.POPOVER+"-open",t.POPOVER_OUT_OF_BOUNDARIES=t.POPOVER+"-out-of-boundaries",t.POPOVER_TARGET=t.POPOVER+"-target",t.POPOVER_WRAPPER=t.POPOVER+"-wrapper",t.TRANSITION_CONTAINER=d+"-transition-container",t.PROGRESS_BAR=d+"-progress-bar",t.PROGRESS_METER=d+"-progress-meter",t.PROGRESS_NO_STRIPES=d+"-no-stripes",t.PROGRESS_NO_ANIMATION=d+"-no-animation",t.PORTAL=d+"-portal",t.SKELETON=d+"-skeleton",t.SLIDER=d+"-slider",t.SLIDER_AXIS=t.SLIDER+"-axis",t.SLIDER_HANDLE=t.SLIDER+"-handle",t.SLIDER_LABEL=t.SLIDER+"-label",t.SLIDER_TRACK=t.SLIDER+"-track",t.SLIDER_PROGRESS=t.SLIDER+"-progress",t.START=d+"-start",t.END=d+"-end",t.SPINNER=d+"-spinner",t.SPINNER_ANIMATION=t.SPINNER+"-animation",t.SPINNER_HEAD=t.SPINNER+"-head",t.SPINNER_NO_SPIN=d+"-no-spin",t.SPINNER_TRACK=t.SPINNER+"-track",t.TAB=d+"-tab",t.TAB_INDICATOR=t.TAB+"-indicator",t.TAB_INDICATOR_WRAPPER=t.TAB_INDICATOR+"-wrapper",t.TAB_LIST=t.TAB+"-list",t.TAB_PANEL=t.TAB+"-panel",t.TABS=t.TAB+"s",t.TAG=d+"-tag",t.TAG_REMOVE=t.TAG+"-remove",t.TAG_INPUT=d+"-tag-input",t.TAG_INPUT_ICON=t.TAG_INPUT+"-icon",t.TAG_INPUT_VALUES=t.TAG_INPUT+"-values",t.TOAST=d+"-toast",t.TOAST_CONTAINER=t.TOAST+"-container",t.TOAST_MESSAGE=t.TOAST+"-message",t.TOOLTIP=d+"-tooltip",t.TOOLTIP_INDICATOR=t.TOOLTIP+"-indicator",t.TREE=d+"-tree",t.TREE_NODE=d+"-tree-node",t.TREE_NODE_CARET=t.TREE_NODE+"-caret",t.TREE_NODE_CARET_CLOSED=t.TREE_NODE_CARET+"-closed",t.TREE_NODE_CARET_NONE=t.TREE_NODE_CARET+"-none",t.TREE_NODE_CARET_OPEN=t.TREE_NODE_CARET+"-open",t.TREE_NODE_CONTENT=t.TREE_NODE+"-content",t.TREE_NODE_EXPANDED=t.TREE_NODE+"-expanded",t.TREE_NODE_ICON=t.TREE_NODE+"-icon",t.TREE_NODE_LABEL=t.TREE_NODE+"-label",t.TREE_NODE_LIST=t.TREE_NODE+"-list",t.TREE_NODE_SECONDARY_LABEL=t.TREE_NODE+"-secondary-label",t.TREE_NODE_SELECTED=t.TREE_NODE+"-selected",t.TREE_ROOT=d+"-tree-root",t.ICON=d+"-icon",t.ICON_STANDARD=t.ICON+"-standard",t.ICON_LARGE=t.ICON+"-large",t.getClassNamespace=function(){return d},t.alignmentClass=function(e){switch(e){case s.Alignment.LEFT:return t.ALIGN_LEFT;case s.Alignment.RIGHT:return t.ALIGN_RIGHT;default:return}},t.elevationClass=h,t.iconClass=function(e){if(null!=e)return 0===e.indexOf(d+"-icon-")?e:d+"-icon-"+e},t.intentClass=p,t.positionClass=f}).call(this,n(61))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Alignment=void 0,t.Alignment={CENTER:"center",LEFT:"left",RIGHT:"right"}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Elevation=void 0,t.Elevation={ZERO:0,ONE:1,TWO:2,THREE:3,FOUR:4}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getPositionIgnoreAngles=t.isPositionVertical=t.isPositionHorizontal=t.Position=void 0,t.Position={BOTTOM:"bottom",BOTTOM_LEFT:"bottom-left",BOTTOM_RIGHT:"bottom-right",LEFT:"left",LEFT_BOTTOM:"left-bottom",LEFT_TOP:"left-top",RIGHT:"right",RIGHT_BOTTOM:"right-bottom",RIGHT_TOP:"right-top",TOP:"top",TOP_LEFT:"top-left",TOP_RIGHT:"top-right"},t.isPositionHorizontal=function(e){return e===t.Position.TOP||e===t.Position.TOP_LEFT||e===t.Position.TOP_RIGHT||e===t.Position.BOTTOM||e===t.Position.BOTTOM_LEFT||e===t.Position.BOTTOM_RIGHT},t.isPositionVertical=function(e){return e===t.Position.LEFT||e===t.Position.LEFT_TOP||e===t.Position.LEFT_BOTTOM||e===t.Position.RIGHT||e===t.Position.RIGHT_TOP||e===t.Position.RIGHT_BOTTOM},t.getPositionIgnoreAngles=function(e){return e===t.Position.TOP||e===t.Position.TOP_LEFT||e===t.Position.TOP_RIGHT?t.Position.TOP:e===t.Position.BOTTOM||e===t.Position.BOTTOM_LEFT||e===t.Position.BOTTOM_RIGHT?t.Position.BOTTOM:e===t.Position.LEFT||e===t.Position.LEFT_TOP||e===t.Position.LEFT_BOTTOM?t.Position.LEFT:t.Position.RIGHT}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Icon=t.IconSize=void 0;var r,i=n(1),o=i.__importDefault(n(5)),a=i.__importStar(n(0)),s=n(9),l=n(462),c=n(91);!function(e){e[e.STANDARD=16]="STANDARD",e[e.LARGE=20]="LARGE"}(r=t.IconSize||(t.IconSize={}));var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i.__extends(t,e),t.prototype.render=function(){var e=this.props.icon;if(null==e||"boolean"==typeof e)return null;if("string"!=typeof e)return e;var t=this.props,n=t.className,s=t.color,l=t.htmlTitle,u=t.iconSize,d=t.intent,h=t.size,p=void 0===h?null!=u?u:r.STANDARD:h,f=t.title,m=t.tagName,g=void 0===m?"span":m,v=i.__rest(t,["className","color","htmlTitle","iconSize","intent","size","title","tagName"]),y=p>=r.LARGE?r.LARGE:r.STANDARD,_=this.renderSvgPaths(y,e),b=o.default(c.Classes.ICON,c.Classes.iconClass(e),c.Classes.intentClass(d),n),M="0 0 "+y+" "+y;return a.createElement(g,i.__assign(i.__assign({},v),{"aria-hidden":!f||void 0,className:b,title:l}),a.createElement("svg",{fill:s,"data-icon":e,width:p,height:p,viewBox:M},f&&a.createElement("desc",null,f),_))},t.prototype.renderSvgPaths=function(e,t){var n=(e===r.STANDARD?l.IconSvgPaths16:l.IconSvgPaths20)[t];return null==n?null:n.map((function(e,t){return a.createElement("path",{key:t,d:e,fillRule:"evenodd"})}))},t.displayName=c.DISPLAYNAME_PREFIX+".Icon",t.SIZE_STANDARD=r.STANDARD,t.SIZE_LARGE=r.LARGE,t=i.__decorate([s.polyfill],t)}(c.AbstractPureComponent2);t.Icon=u},function(e,t,n){"use strict";function r(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];for(var n={},i=0,o=e;i<o.length;i++){var a=o[i];if(null!=a&&!1!==a)for(var s in a){var l=a[s];(l||0===l)&&("$nest"===s&&l?n[s]=n.$nest?r(n.$nest,l):l:-1!==s.indexOf("&")||0===s.indexOf("@media")?n[s]=n[s]?r(n[s],l):l:n[s]=l)}}return n}Object.defineProperty(t,"__esModule",{value:!0}),t.raf="undefined"==typeof requestAnimationFrame?function(e){return setTimeout(e)}:"undefined"==typeof window?requestAnimationFrame:requestAnimationFrame.bind(window),t.classes=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return e.map((function(e){return e&&"object"==typeof e?Object.keys(e).map((function(t){return!!e[t]&&t})):[e]})).reduce((function(e,t){return e.concat(t)}),[]).filter((function(e){return!!e})).join(" ")},t.extend=r,t.media=function(e){for(var t,n=[],o=1;o<arguments.length;o++)n[o-1]=arguments[o];var a=[];e.type&&a.push(e.type),e.orientation&&a.push("(orientation: "+e.orientation+")"),e.minWidth&&a.push("(min-width: "+i(e.minWidth)+")"),e.maxWidth&&a.push("(max-width: "+i(e.maxWidth)+")"),e.minHeight&&a.push("(min-height: "+i(e.minHeight)+")"),e.maxHeight&&a.push("(max-height: "+i(e.maxHeight)+")");var s="@media "+a.join(" and "),l={$nest:(t={},t[s]=r.apply(void 0,n),t)};return l};var i=function(e){return"string"==typeof e?e:e+"px"}},function(e,t,n){"use strict";(function(e){n.d(t,"e",(function(){return i})),n.d(t,"b",(function(){return o})),n.d(t,"a",(function(){return a})),n.d(t,"c",(function(){return s})),n.d(t,"d",(function(){return l})),n.d(t,"f",(function(){return u}));var r=n(17);function i(t){return void 0!==e&&e.env&&"production"===t}function o(e,t){return void 0===e&&(e=[]),void 0===t&&(t=[]),e.length-t.length}function a(e,t,n){return void 0===n&&(n=1e-5),Math.abs(e-t)<=n}function s(e,t,n){if(null==e)return e;if(n<t)throw new Error(r.d);return Math.min(Math.max(e,t),n)}function l(e){if(!isFinite(e))return 0;for(var t=1,n=0;Math.round(e*t)/t!==e;)t*=10,n++;return n}var c=new Map;function u(e){var t,n=null!==(t=c.get(e))&&void 0!==t?t:0;return c.set(e,n+1),e+"-"+n}}).call(this,n(61))},function(e,t,n){"use strict";t.__esModule=!0,t.default=t.EXITING=t.ENTERED=t.ENTERING=t.EXITED=t.UNMOUNTED=void 0;var r=function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)if(Object.prototype.hasOwnProperty.call(e,n)){var r=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,n):{};r.get||r.set?Object.defineProperty(t,n,r):t[n]=e[n]}return t.default=e,t}(n(93)),i=s(n(0)),o=s(n(34)),a=n(9);n(389);function s(e){return e&&e.__esModule?e:{default:e}}t.UNMOUNTED="unmounted";t.EXITED="exited";t.ENTERING="entering";t.ENTERED="entered";t.EXITING="exiting";var l=function(e){var t,n;function r(t,n){var r;r=e.call(this,t,n)||this;var i,o=n.transitionGroup,a=o&&!o.isMounting?t.enter:t.appear;return r.appearStatus=null,t.in?a?(i="exited",r.appearStatus="entering"):i="entered":i=t.unmountOnExit||t.mountOnEnter?"unmounted":"exited",r.state={status:i},r.nextCallback=null,r}n=e,(t=r).prototype=Object.create(n.prototype),t.prototype.constructor=t,t.__proto__=n;var a=r.prototype;return a.getChildContext=function(){return{transitionGroup:null}},r.getDerivedStateFromProps=function(e,t){return e.in&&"unmounted"===t.status?{status:"exited"}:null},a.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},a.componentDidUpdate=function(e){var t=null;if(e!==this.props){var n=this.state.status;this.props.in?"entering"!==n&&"entered"!==n&&(t="entering"):"entering"!==n&&"entered"!==n||(t="exiting")}this.updateStatus(!1,t)},a.componentWillUnmount=function(){this.cancelNextCallback()},a.getTimeouts=function(){var e,t,n,r=this.props.timeout;return e=t=n=r,null!=r&&"number"!=typeof r&&(e=r.exit,t=r.enter,n=void 0!==r.appear?r.appear:t),{exit:e,enter:t,appear:n}},a.updateStatus=function(e,t){if(void 0===e&&(e=!1),null!==t){this.cancelNextCallback();var n=o.default.findDOMNode(this);"entering"===t?this.performEnter(n,e):this.performExit(n)}else this.props.unmountOnExit&&"exited"===this.state.status&&this.setState({status:"unmounted"})},a.performEnter=function(e,t){var n=this,r=this.props.enter,i=this.context.transitionGroup?this.context.transitionGroup.isMounting:t,o=this.getTimeouts(),a=i?o.appear:o.enter;t||r?(this.props.onEnter(e,i),this.safeSetState({status:"entering"},(function(){n.props.onEntering(e,i),n.onTransitionEnd(e,a,(function(){n.safeSetState({status:"entered"},(function(){n.props.onEntered(e,i)}))}))}))):this.safeSetState({status:"entered"},(function(){n.props.onEntered(e)}))},a.performExit=function(e){var t=this,n=this.props.exit,r=this.getTimeouts();n?(this.props.onExit(e),this.safeSetState({status:"exiting"},(function(){t.props.onExiting(e),t.onTransitionEnd(e,r.exit,(function(){t.safeSetState({status:"exited"},(function(){t.props.onExited(e)}))}))}))):this.safeSetState({status:"exited"},(function(){t.props.onExited(e)}))},a.cancelNextCallback=function(){null!==this.nextCallback&&(this.nextCallback.cancel(),this.nextCallback=null)},a.safeSetState=function(e,t){t=this.setNextCallback(t),this.setState(e,t)},a.setNextCallback=function(e){var t=this,n=!0;return this.nextCallback=function(r){n&&(n=!1,t.nextCallback=null,e(r))},this.nextCallback.cancel=function(){n=!1},this.nextCallback},a.onTransitionEnd=function(e,t,n){this.setNextCallback(n);var r=null==t&&!this.props.addEndListener;e&&!r?(this.props.addEndListener&&this.props.addEndListener(e,this.nextCallback),null!=t&&setTimeout(this.nextCallback,t)):setTimeout(this.nextCallback,0)},a.render=function(){var e=this.state.status;if("unmounted"===e)return null;var t=this.props,n=t.children,r=function(e,t){if(null==e)return{};var n,r,i={},o=Object.keys(e);for(r=0;r<o.length;r++)n=o[r],t.indexOf(n)>=0||(i[n]=e[n]);return i}(t,["children"]);if(delete r.in,delete r.mountOnEnter,delete r.unmountOnExit,delete r.appear,delete r.enter,delete r.exit,delete r.timeout,delete r.addEndListener,delete r.onEnter,delete r.onEntering,delete r.onEntered,delete r.onExit,delete r.onExiting,delete r.onExited,"function"==typeof n)return n(e,r);var o=i.default.Children.only(n);return i.default.cloneElement(o,r)},r}(i.default.Component);function c(){}l.contextTypes={transitionGroup:r.object},l.childContextTypes={transitionGroup:function(){}},l.propTypes={},l.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:c,onEntering:c,onEntered:c,onExit:c,onExiting:c,onExited:c},l.UNMOUNTED=0,l.EXITED=1,l.ENTERING=2,l.ENTERED=3,l.EXITING=4;var u=(0,a.polyfill)(l);t.default=u},function(e,t,n){"use strict";t.__esModule=!0,t.classNamesShape=t.timeoutsShape=void 0;var r;(r=n(93))&&r.__esModule;t.timeoutsShape=null;t.classNamesShape=null},function(e,t,n){"use strict";t.__esModule=!0,t.default=void 0;var r=s(n(93)),i=s(n(0)),o=n(9),a=n(728);function s(e){return e&&e.__esModule?e:{default:e}}function l(){return(l=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}function c(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}var u=Object.values||function(e){return Object.keys(e).map((function(t){return e[t]}))},d=function(e){var t,n;function r(t,n){var r,i=(r=e.call(this,t,n)||this).handleExited.bind(c(c(r)));return r.state={handleExited:i,firstRender:!0},r}n=e,(t=r).prototype=Object.create(n.prototype),t.prototype.constructor=t,t.__proto__=n;var o=r.prototype;return o.getChildContext=function(){return{transitionGroup:{isMounting:!this.appeared}}},o.componentDidMount=function(){this.appeared=!0,this.mounted=!0},o.componentWillUnmount=function(){this.mounted=!1},r.getDerivedStateFromProps=function(e,t){var n=t.children,r=t.handleExited;return{children:t.firstRender?(0,a.getInitialChildMapping)(e,r):(0,a.getNextChildMapping)(e,n,r),firstRender:!1}},o.handleExited=function(e,t){var n=(0,a.getChildMapping)(this.props.children);e.key in n||(e.props.onExited&&e.props.onExited(t),this.mounted&&this.setState((function(t){var n=l({},t.children);return delete n[e.key],{children:n}})))},o.render=function(){var e=this.props,t=e.component,n=e.childFactory,r=function(e,t){if(null==e)return{};var n,r,i={},o=Object.keys(e);for(r=0;r<o.length;r++)n=o[r],t.indexOf(n)>=0||(i[n]=e[n]);return i}(e,["component","childFactory"]),o=u(this.state.children).map(n);return delete r.appear,delete r.enter,delete r.exit,null===t?o:i.default.createElement(t,r,o)},r}(i.default.Component);d.childContextTypes={transitionGroup:r.default.object.isRequired},d.propTypes={},d.defaultProps={component:"div",childFactory:function(e){return e}};var h=(0,o.polyfill)(d);t.default=h,e.exports=t.default},function(e,t,n){"use strict";var r=Array.prototype.slice,i=n(392),o=Object.keys,a=o?function(e){return o(e)}:n(729),s=Object.keys;a.shim=function(){Object.keys?function(){var e=Object.keys(arguments);return e&&e.length===arguments.length}(1,2)||(Object.keys=function(e){return i(e)?s(r.call(e)):s(e)}):Object.keys=a;return Object.keys||a},e.exports=a},function(e,t,n){"use strict";var r=Object.prototype.toString;e.exports=function(e){var t=r.call(e),n="[object Arguments]"===t;return n||(n="[object Array]"!==t&&null!==e&&"object"==typeof e&&"number"==typeof e.length&&e.length>=0&&"[object Function]"===r.call(e.callee)),n}},function(e,t,n){"use strict";e.exports=function(){if("function"!=typeof Symbol||"function"!=typeof Object.getOwnPropertySymbols)return!1;if("symbol"==typeof Symbol.iterator)return!0;var e={},t=Symbol("test"),n=Object(t);if("string"==typeof t)return!1;if("[object Symbol]"!==Object.prototype.toString.call(t))return!1;if("[object Symbol]"!==Object.prototype.toString.call(n))return!1;for(t in e[t]=42,e)return!1;if("function"==typeof Object.keys&&0!==Object.keys(e).length)return!1;if("function"==typeof Object.getOwnPropertyNames&&0!==Object.getOwnPropertyNames(e).length)return!1;var r=Object.getOwnPropertySymbols(e);if(1!==r.length||r[0]!==t)return!1;if(!Object.prototype.propertyIsEnumerable.call(e,t))return!1;if("function"==typeof Object.getOwnPropertyDescriptor){var i=Object.getOwnPropertyDescriptor(e,t);if(42!==i.value||!0!==i.enumerable)return!1}return!0}},function(e,t,n){"use strict";var r=n(395),i=n(176),o=i(r("String.prototype.indexOf"));e.exports=function(e,t){var n=r(e,!!t);return"function"==typeof n&&o(e,".prototype.")>-1?i(n):n}},function(e,t,n){"use strict";var r=SyntaxError,i=Function,o=TypeError,a=function(e){try{return i('"use strict"; return ('+e+").constructor;")()}catch(e){}},s=Object.getOwnPropertyDescriptor;if(s)try{s({},"")}catch(e){s=null}var l=function(){throw new o},c=s?function(){try{return l}catch(e){try{return s(arguments,"callee").get}catch(e){return l}}}():l,u=n(731)(),d=Object.getPrototypeOf||function(e){return e.__proto__},h={},p="undefined"==typeof Uint8Array?void 0:d(Uint8Array),f={"%AggregateError%":"undefined"==typeof AggregateError?void 0:AggregateError,"%Array%":Array,"%ArrayBuffer%":"undefined"==typeof ArrayBuffer?void 0:ArrayBuffer,"%ArrayIteratorPrototype%":u?d([][Symbol.iterator]()):void 0,"%AsyncFromSyncIteratorPrototype%":void 0,"%AsyncFunction%":h,"%AsyncGenerator%":h,"%AsyncGeneratorFunction%":h,"%AsyncIteratorPrototype%":h,"%Atomics%":"undefined"==typeof Atomics?void 0:Atomics,"%BigInt%":"undefined"==typeof BigInt?void 0:BigInt,"%Boolean%":Boolean,"%DataView%":"undefined"==typeof DataView?void 0:DataView,"%Date%":Date,"%decodeURI%":decodeURI,"%decodeURIComponent%":decodeURIComponent,"%encodeURI%":encodeURI,"%encodeURIComponent%":encodeURIComponent,"%Error%":Error,"%eval%":eval,"%EvalError%":EvalError,"%Float32Array%":"undefined"==typeof Float32Array?void 0:Float32Array,"%Float64Array%":"undefined"==typeof Float64Array?void 0:Float64Array,"%FinalizationRegistry%":"undefined"==typeof FinalizationRegistry?void 0:FinalizationRegistry,"%Function%":i,"%GeneratorFunction%":h,"%Int8Array%":"undefined"==typeof Int8Array?void 0:Int8Array,"%Int16Array%":"undefined"==typeof Int16Array?void 0:Int16Array,"%Int32Array%":"undefined"==typeof Int32Array?void 0:Int32Array,"%isFinite%":isFinite,"%isNaN%":isNaN,"%IteratorPrototype%":u?d(d([][Symbol.iterator]())):void 0,"%JSON%":"object"==typeof JSON?JSON:void 0,"%Map%":"undefined"==typeof Map?void 0:Map,"%MapIteratorPrototype%":"undefined"!=typeof Map&&u?d((new Map)[Symbol.iterator]()):void 0,"%Math%":Math,"%Number%":Number,"%Object%":Object,"%parseFloat%":parseFloat,"%parseInt%":parseInt,"%Promise%":"undefined"==typeof Promise?void 0:Promise,"%Proxy%":"undefined"==typeof Proxy?void 0:Proxy,"%RangeError%":RangeError,"%ReferenceError%":ReferenceError,"%Reflect%":"undefined"==typeof Reflect?void 0:Reflect,"%RegExp%":RegExp,"%Set%":"undefined"==typeof Set?void 0:Set,"%SetIteratorPrototype%":"undefined"!=typeof Set&&u?d((new Set)[Symbol.iterator]()):void 0,"%SharedArrayBuffer%":"undefined"==typeof SharedArrayBuffer?void 0:SharedArrayBuffer,"%String%":String,"%StringIteratorPrototype%":u?d(""[Symbol.iterator]()):void 0,"%Symbol%":u?Symbol:void 0,"%SyntaxError%":r,"%ThrowTypeError%":c,"%TypedArray%":p,"%TypeError%":o,"%Uint8Array%":"undefined"==typeof Uint8Array?void 0:Uint8Array,"%Uint8ClampedArray%":"undefined"==typeof Uint8ClampedArray?void 0:Uint8ClampedArray,"%Uint16Array%":"undefined"==typeof Uint16Array?void 0:Uint16Array,"%Uint32Array%":"undefined"==typeof Uint32Array?void 0:Uint32Array,"%URIError%":URIError,"%WeakMap%":"undefined"==typeof WeakMap?void 0:WeakMap,"%WeakRef%":"undefined"==typeof WeakRef?void 0:WeakRef,"%WeakSet%":"undefined"==typeof WeakSet?void 0:WeakSet},m={"%ArrayBufferPrototype%":["ArrayBuffer","prototype"],"%ArrayPrototype%":["Array","prototype"],"%ArrayProto_entries%":["Array","prototype","entries"],"%ArrayProto_forEach%":["Array","prototype","forEach"],"%ArrayProto_keys%":["Array","prototype","keys"],"%ArrayProto_values%":["Array","prototype","values"],"%AsyncFunctionPrototype%":["AsyncFunction","prototype"],"%AsyncGenerator%":["AsyncGeneratorFunction","prototype"],"%AsyncGeneratorPrototype%":["AsyncGeneratorFunction","prototype","prototype"],"%BooleanPrototype%":["Boolean","prototype"],"%DataViewPrototype%":["DataView","prototype"],"%DatePrototype%":["Date","prototype"],"%ErrorPrototype%":["Error","prototype"],"%EvalErrorPrototype%":["EvalError","prototype"],"%Float32ArrayPrototype%":["Float32Array","prototype"],"%Float64ArrayPrototype%":["Float64Array","prototype"],"%FunctionPrototype%":["Function","prototype"],"%Generator%":["GeneratorFunction","prototype"],"%GeneratorPrototype%":["GeneratorFunction","prototype","prototype"],"%Int8ArrayPrototype%":["Int8Array","prototype"],"%Int16ArrayPrototype%":["Int16Array","prototype"],"%Int32ArrayPrototype%":["Int32Array","prototype"],"%JSONParse%":["JSON","parse"],"%JSONStringify%":["JSON","stringify"],"%MapPrototype%":["Map","prototype"],"%NumberPrototype%":["Number","prototype"],"%ObjectPrototype%":["Object","prototype"],"%ObjProto_toString%":["Object","prototype","toString"],"%ObjProto_valueOf%":["Object","prototype","valueOf"],"%PromisePrototype%":["Promise","prototype"],"%PromiseProto_then%":["Promise","prototype","then"],"%Promise_all%":["Promise","all"],"%Promise_reject%":["Promise","reject"],"%Promise_resolve%":["Promise","resolve"],"%RangeErrorPrototype%":["RangeError","prototype"],"%ReferenceErrorPrototype%":["ReferenceError","prototype"],"%RegExpPrototype%":["RegExp","prototype"],"%SetPrototype%":["Set","prototype"],"%SharedArrayBufferPrototype%":["SharedArrayBuffer","prototype"],"%StringPrototype%":["String","prototype"],"%SymbolPrototype%":["Symbol","prototype"],"%SyntaxErrorPrototype%":["SyntaxError","prototype"],"%TypedArrayPrototype%":["TypedArray","prototype"],"%TypeErrorPrototype%":["TypeError","prototype"],"%Uint8ArrayPrototype%":["Uint8Array","prototype"],"%Uint8ClampedArrayPrototype%":["Uint8ClampedArray","prototype"],"%Uint16ArrayPrototype%":["Uint16Array","prototype"],"%Uint32ArrayPrototype%":["Uint32Array","prototype"],"%URIErrorPrototype%":["URIError","prototype"],"%WeakMapPrototype%":["WeakMap","prototype"],"%WeakSetPrototype%":["WeakSet","prototype"]},g=n(175),v=n(733),y=g.call(Function.call,Array.prototype.concat),_=g.call(Function.apply,Array.prototype.splice),b=g.call(Function.call,String.prototype.replace),M=g.call(Function.call,String.prototype.slice),w=/[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g,A=/\\(\\)?/g,C=function(e){var t=M(e,0,1),n=M(e,-1);if("%"===t&&"%"!==n)throw new r("invalid intrinsic syntax, expected closing `%`");if("%"===n&&"%"!==t)throw new r("invalid intrinsic syntax, expected opening `%`");var i=[];return b(e,w,(function(e,t,n,r){i[i.length]=n?b(r,A,"$1"):t||e})),i},x=function(e,t){var n,i=e;if(v(m,i)&&(i="%"+(n=m[i])[0]+"%"),v(f,i)){var s=f[i];if(s===h&&(s=function e(t){var n;if("%AsyncFunction%"===t)n=a("async function () {}");else if("%GeneratorFunction%"===t)n=a("function* () {}");else if("%AsyncGeneratorFunction%"===t)n=a("async function* () {}");else if("%AsyncGenerator%"===t){var r=e("%AsyncGeneratorFunction%");r&&(n=r.prototype)}else if("%AsyncIteratorPrototype%"===t){var i=e("%AsyncGenerator%");i&&(n=d(i.prototype))}return f[t]=n,n}(i)),void 0===s&&!t)throw new o("intrinsic "+e+" exists, but is not available. Please file an issue!");return{alias:n,name:i,value:s}}throw new r("intrinsic "+e+" does not exist!")};e.exports=function(e,t){if("string"!=typeof e||0===e.length)throw new o("intrinsic name must be a non-empty string");if(arguments.length>1&&"boolean"!=typeof t)throw new o('"allowMissing" argument must be a boolean');var n=C(e),i=n.length>0?n[0]:"",a=x("%"+i+"%",t),l=a.name,c=a.value,u=!1,d=a.alias;d&&(i=d[0],_(n,y([0,1],d)));for(var h=1,p=!0;h<n.length;h+=1){var m=n[h],g=M(m,0,1),b=M(m,-1);if(('"'===g||"'"===g||"`"===g||'"'===b||"'"===b||"`"===b)&&g!==b)throw new r("property names with quotes must have matching quotes");if("constructor"!==m&&p||(u=!0),v(f,l="%"+(i+="."+m)+"%"))c=f[l];else if(null!=c){if(!(m in c)){if(!t)throw new o("base intrinsic for "+e+" exists, but the property is not available.");return}if(s&&h+1>=n.length){var w=s(c,m);c=(p=!!w)&&"get"in w&&!("originalValue"in w.get)?w.get:c[m]}else p=v(c,m),c=c[m];p&&!u&&(f[l]=c)}}return c}},function(e,t,n){"use strict";var r=function(e){return e!=e};e.exports=function(e,t){return 0===e&&0===t?1/e==1/t:e===t||!(!r(e)||!r(t))}},function(e,t,n){"use strict";var r=n(396);e.exports=function(){return"function"==typeof Object.is?Object.is:r}},function(e,t,n){"use strict";var r=Object,i=TypeError;e.exports=function(){if(null!=this&&this!==r(this))throw new i("RegExp.prototype.flags getter called on non-object");var e="";return this.hasIndices&&(e+="d"),this.global&&(e+="g"),this.ignoreCase&&(e+="i"),this.multiline&&(e+="m"),this.dotAll&&(e+="s"),this.unicode&&(e+="u"),this.sticky&&(e+="y"),e}},function(e,t,n){"use strict";var r=n(398),i=n(104).supportsDescriptors,o=Object.getOwnPropertyDescriptor;e.exports=function(){if(i&&"gim"===/a/gim.flags){var e=o(RegExp.prototype,"flags");if(e&&"function"==typeof e.get&&"boolean"==typeof/a/.dotAll)return e.get}return r}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Classes=void 0;var r=n(1),i=r.__importStar(n(740));t.Classes=i,r.__exportStar(n(741),t),r.__exportStar(n(742),t),r.__exportStar(n(743),t),r.__exportStar(n(744),t),r.__exportStar(n(745),t)},function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));var r;!function(e){e.setGeometry=function(e){const{anchor:t,host:n,node:r,privilege:i}=e;if(r.classList.add("jp-HoverBox"),r.classList.add("jp-mod-outofview"),!n.contains(document.elementFromPoint(t.left,t.top)))return;r.style.maxHeight="",r.style.marginTop="",r.classList.remove("jp-mod-outofview");const o=e.style||window.getComputedStyle(r),a=window.innerHeight,s=t.top,l=a-t.bottom,c=parseInt(o.marginTop,10)||0,u=parseInt(o.minHeight,10)||e.minHeight;let d=parseInt(o.maxHeight,10)||e.maxHeight;const h="forceAbove"!==i&&("forceBelow"===i||("above"===i?s<d&&s<l:l>=d||l>=s));if(h?d=Math.min(l-c,d):(d=Math.min(s,d),r.style.marginTop="0px"),r.style.maxHeight=d+"px",!(d>u&&(l>=u||s>=u)))return void r.classList.add("jp-mod-outofview");const p=e.offset&&e.offset.vertical&&e.offset.vertical.above||0,f=e.offset&&e.offset.vertical&&e.offset.vertical.below||0,m=h?a-l+f:s-r.getBoundingClientRect().height+p;r.style.top=Math.floor(m)+"px";const g=e.offset&&e.offset.horizontal||0;let v=t.left+g;r.style.left=Math.ceil(v)+"px",r.style.width="auto",r.scrollHeight>=d&&(r.style.width=""+(2*r.offsetWidth-r.clientWidth),r.scrollTop=0);const y=r.getBoundingClientRect().right;y>window.innerWidth&&(v-=y-window.innerWidth,r.style.left=Math.ceil(v)+"px")}}(r||(r={}))},function(e,t){e.exports=function(e,t){return e===t||e!=e&&t!=t}},function(e,t,n){var r=n(105),i=n(405);e.exports=function(e){if(!i(e))return!1;var t=r(e);return"[object Function]"==t||"[object GeneratorFunction]"==t||"[object AsyncFunction]"==t||"[object Proxy]"==t}},function(e,t,n){(function(t){var n="object"==typeof t&&t&&t.Object===Object&&t;e.exports=n}).call(this,n(55))},function(e,t){e.exports=function(e){var t=typeof e;return null!=e&&("object"==t||"function"==t)}},function(e,t){var n=Function.prototype.toString;e.exports=function(e){if(null!=e){try{return n.call(e)}catch(e){}try{return e+""}catch(e){}}return""}},function(e,t,n){var r=n(766),i=n(773),o=n(775),a=n(776),s=n(777);function l(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}l.prototype.clear=r,l.prototype.delete=i,l.prototype.get=o,l.prototype.has=a,l.prototype.set=s,e.exports=l},function(e,t,n){var r=n(778),i=n(781),o=n(782);e.exports=function(e,t,n,a,s,l){var c=1&n,u=e.length,d=t.length;if(u!=d&&!(c&&d>u))return!1;var h=l.get(e),p=l.get(t);if(h&&p)return h==t&&p==e;var f=-1,m=!0,g=2&n?new r:void 0;for(l.set(e,t),l.set(t,e);++f<u;){var v=e[f],y=t[f];if(a)var _=c?a(y,v,f,t,e,l):a(v,y,f,e,t,l);if(void 0!==_){if(_)continue;m=!1;break}if(g){if(!i(t,(function(e,t){if(!o(g,t)&&(v===e||s(v,e,n,a,l)))return g.push(t)}))){m=!1;break}}else if(v!==y&&!s(v,y,n,a,l)){m=!1;break}}return l.delete(e),l.delete(t),m}},function(e,t,n){(function(e){var r=n(67),i=n(799),o=t&&!t.nodeType&&t,a=o&&"object"==typeof e&&e&&!e.nodeType&&e,s=a&&a.exports===o?r.Buffer:void 0,l=(s?s.isBuffer:void 0)||i;e.exports=l}).call(this,n(151)(e))},function(e,t,n){var r=n(801),i=n(802),o=n(803),a=o&&o.isTypedArray,s=a?i(a):r;e.exports=s},function(e,t){e.exports=function(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=9007199254740991}},function(e,t){e.exports=function(e,t){return function(n){return e(t(n))}}},function(e,t,n){var r,i,o;
/*!
 * jQuery UI Widget 1.13.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */!function(a){"use strict";i=[n(41),n(107)],void 0===(o="function"==typeof(r=function(e){var t=0,n=Array.prototype.hasOwnProperty,r=Array.prototype.slice;return e.cleanData=function(t){return function(n){var r,i,o;for(o=0;null!=(i=n[o]);o++)(r=e._data(i,"events"))&&r.remove&&e(i).triggerHandler("remove");t(n)}}(e.cleanData),e.widget=function(t,n,r){var i,o,a,s={},l=t.split(".")[0],c=l+"-"+(t=t.split(".")[1]);return r||(r=n,n=e.Widget),Array.isArray(r)&&(r=e.extend.apply(null,[{}].concat(r))),e.expr.pseudos[c.toLowerCase()]=function(t){return!!e.data(t,c)},e[l]=e[l]||{},i=e[l][t],o=e[l][t]=function(e,t){if(!this||!this._createWidget)return new o(e,t);arguments.length&&this._createWidget(e,t)},e.extend(o,i,{version:r.version,_proto:e.extend({},r),_childConstructors:[]}),(a=new n).options=e.widget.extend({},a.options),e.each(r,(function(e,t){s[e]="function"==typeof t?function(){function r(){return n.prototype[e].apply(this,arguments)}function i(t){return n.prototype[e].apply(this,t)}return function(){var e,n=this._super,o=this._superApply;return this._super=r,this._superApply=i,e=t.apply(this,arguments),this._super=n,this._superApply=o,e}}():t})),o.prototype=e.widget.extend(a,{widgetEventPrefix:i&&a.widgetEventPrefix||t},s,{constructor:o,namespace:l,widgetName:t,widgetFullName:c}),i?(e.each(i._childConstructors,(function(t,n){var r=n.prototype;e.widget(r.namespace+"."+r.widgetName,o,n._proto)})),delete i._childConstructors):n._childConstructors.push(o),e.widget.bridge(t,o),o},e.widget.extend=function(t){for(var i,o,a=r.call(arguments,1),s=0,l=a.length;s<l;s++)for(i in a[s])o=a[s][i],n.call(a[s],i)&&void 0!==o&&(e.isPlainObject(o)?t[i]=e.isPlainObject(t[i])?e.widget.extend({},t[i],o):e.widget.extend({},o):t[i]=o);return t},e.widget.bridge=function(t,n){var i=n.prototype.widgetFullName||t;e.fn[t]=function(o){var a="string"==typeof o,s=r.call(arguments,1),l=this;return a?this.length||"instance"!==o?this.each((function(){var n,r=e.data(this,i);return"instance"===o?(l=r,!1):r?"function"!=typeof r[o]||"_"===o.charAt(0)?e.error("no such method '"+o+"' for "+t+" widget instance"):(n=r[o].apply(r,s))!==r&&void 0!==n?(l=n&&n.jquery?l.pushStack(n.get()):n,!1):void 0:e.error("cannot call methods on "+t+" prior to initialization; attempted to call method '"+o+"'")})):l=void 0:(s.length&&(o=e.widget.extend.apply(null,[o].concat(s))),this.each((function(){var t=e.data(this,i);t?(t.option(o||{}),t._init&&t._init()):e.data(this,i,new n(o,this))}))),l}},e.Widget=function(){},e.Widget._childConstructors=[],e.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",defaultElement:"<div>",options:{classes:{},disabled:!1,create:null},_createWidget:function(n,r){r=e(r||this.defaultElement||this)[0],this.element=e(r),this.uuid=t++,this.eventNamespace="."+this.widgetName+this.uuid,this.bindings=e(),this.hoverable=e(),this.focusable=e(),this.classesElementLookup={},r!==this&&(e.data(r,this.widgetFullName,this),this._on(!0,this.element,{remove:function(e){e.target===r&&this.destroy()}}),this.document=e(r.style?r.ownerDocument:r.document||r),this.window=e(this.document[0].defaultView||this.document[0].parentWindow)),this.options=e.widget.extend({},this.options,this._getCreateOptions(),n),this._create(),this.options.disabled&&this._setOptionDisabled(this.options.disabled),this._trigger("create",null,this._getCreateEventData()),this._init()},_getCreateOptions:function(){return{}},_getCreateEventData:e.noop,_create:e.noop,_init:e.noop,destroy:function(){var t=this;this._destroy(),e.each(this.classesElementLookup,(function(e,n){t._removeClass(n,e)})),this.element.off(this.eventNamespace).removeData(this.widgetFullName),this.widget().off(this.eventNamespace).removeAttr("aria-disabled"),this.bindings.off(this.eventNamespace)},_destroy:e.noop,widget:function(){return this.element},option:function(t,n){var r,i,o,a=t;if(0===arguments.length)return e.widget.extend({},this.options);if("string"==typeof t)if(a={},r=t.split("."),t=r.shift(),r.length){for(i=a[t]=e.widget.extend({},this.options[t]),o=0;o<r.length-1;o++)i[r[o]]=i[r[o]]||{},i=i[r[o]];if(t=r.pop(),1===arguments.length)return void 0===i[t]?null:i[t];i[t]=n}else{if(1===arguments.length)return void 0===this.options[t]?null:this.options[t];a[t]=n}return this._setOptions(a),this},_setOptions:function(e){var t;for(t in e)this._setOption(t,e[t]);return this},_setOption:function(e,t){return"classes"===e&&this._setOptionClasses(t),this.options[e]=t,"disabled"===e&&this._setOptionDisabled(t),this},_setOptionClasses:function(t){var n,r,i;for(n in t)i=this.classesElementLookup[n],t[n]!==this.options.classes[n]&&i&&i.length&&(r=e(i.get()),this._removeClass(i,n),r.addClass(this._classes({element:r,keys:n,classes:t,add:!0})))},_setOptionDisabled:function(e){this._toggleClass(this.widget(),this.widgetFullName+"-disabled",null,!!e),e&&(this._removeClass(this.hoverable,null,"ui-state-hover"),this._removeClass(this.focusable,null,"ui-state-focus"))},enable:function(){return this._setOptions({disabled:!1})},disable:function(){return this._setOptions({disabled:!0})},_classes:function(t){var n=[],r=this;function i(){var n=[];t.element.each((function(t,i){e.map(r.classesElementLookup,(function(e){return e})).some((function(e){return e.is(i)}))||n.push(i)})),r._on(e(n),{remove:"_untrackClassesElement"})}function o(o,a){var s,l;for(l=0;l<o.length;l++)s=r.classesElementLookup[o[l]]||e(),t.add?(i(),s=e(e.uniqueSort(s.get().concat(t.element.get())))):s=e(s.not(t.element).get()),r.classesElementLookup[o[l]]=s,n.push(o[l]),a&&t.classes[o[l]]&&n.push(t.classes[o[l]])}return(t=e.extend({element:this.element,classes:this.options.classes||{}},t)).keys&&o(t.keys.match(/\S+/g)||[],!0),t.extra&&o(t.extra.match(/\S+/g)||[]),n.join(" ")},_untrackClassesElement:function(t){var n=this;e.each(n.classesElementLookup,(function(r,i){-1!==e.inArray(t.target,i)&&(n.classesElementLookup[r]=e(i.not(t.target).get()))})),this._off(e(t.target))},_removeClass:function(e,t,n){return this._toggleClass(e,t,n,!1)},_addClass:function(e,t,n){return this._toggleClass(e,t,n,!0)},_toggleClass:function(e,t,n,r){r="boolean"==typeof r?r:n;var i="string"==typeof e||null===e,o={extra:i?t:n,keys:i?e:t,element:i?this.element:e,add:r};return o.element.toggleClass(this._classes(o),r),this},_on:function(t,n,r){var i,o=this;"boolean"!=typeof t&&(r=n,n=t,t=!1),r?(n=i=e(n),this.bindings=this.bindings.add(n)):(r=n,n=this.element,i=this.widget()),e.each(r,(function(r,a){function s(){if(t||!0!==o.options.disabled&&!e(this).hasClass("ui-state-disabled"))return("string"==typeof a?o[a]:a).apply(o,arguments)}"string"!=typeof a&&(s.guid=a.guid=a.guid||s.guid||e.guid++);var l=r.match(/^([\w:-]*)\s*(.*)$/),c=l[1]+o.eventNamespace,u=l[2];u?i.on(c,u,s):n.on(c,s)}))},_off:function(t,n){n=(n||"").split(" ").join(this.eventNamespace+" ")+this.eventNamespace,t.off(n),this.bindings=e(this.bindings.not(t).get()),this.focusable=e(this.focusable.not(t).get()),this.hoverable=e(this.hoverable.not(t).get())},_delay:function(e,t){var n=this;return setTimeout((function(){return("string"==typeof e?n[e]:e).apply(n,arguments)}),t||0)},_hoverable:function(t){this.hoverable=this.hoverable.add(t),this._on(t,{mouseenter:function(t){this._addClass(e(t.currentTarget),null,"ui-state-hover")},mouseleave:function(t){this._removeClass(e(t.currentTarget),null,"ui-state-hover")}})},_focusable:function(t){this.focusable=this.focusable.add(t),this._on(t,{focusin:function(t){this._addClass(e(t.currentTarget),null,"ui-state-focus")},focusout:function(t){this._removeClass(e(t.currentTarget),null,"ui-state-focus")}})},_trigger:function(t,n,r){var i,o,a=this.options[t];if(r=r||{},(n=e.Event(n)).type=(t===this.widgetEventPrefix?t:this.widgetEventPrefix+t).toLowerCase(),n.target=this.element[0],o=n.originalEvent)for(i in o)i in n||(n[i]=o[i]);return this.element.trigger(n,r),!("function"==typeof a&&!1===a.apply(this.element[0],[n].concat(r))||n.isDefaultPrevented())}},e.each({show:"fadeIn",hide:"fadeOut"},(function(t,n){e.Widget.prototype["_"+t]=function(r,i,o){var a;"string"==typeof i&&(i={effect:i});var s=i?!0===i||"number"==typeof i?n:i.effect||n:t;"number"==typeof(i=i||{})?i={duration:i}:!0===i&&(i={}),a=!e.isEmptyObject(i),i.complete=o,i.delay&&r.delay(i.delay),a&&e.effects&&e.effects.effect[s]?r[t](i):s!==t&&r[s]?r[s](i.duration,i.easing,o):r.queue((function(n){e(this)[t](),o&&o.call(r[0]),n()}))}})),e.widget})?r.apply(t,i):r)||(e.exports=o)}()},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r=n(6);const i="commandlinker-command",o="commandlinker-args";class a{constructor(e){this._isDisposed=!1,this._commands=e.commands,document.body.addEventListener("click",this)}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,document.body.removeEventListener("click",this))}connectNode(e,t,n){return e.setAttribute("data-"+i,t),void 0!==n&&e.setAttribute("data-"+o,JSON.stringify(n)),e}disconnectNode(e){return e.removeAttribute("data-"+i),e.removeAttribute("data-"+o),e}handleEvent(e){switch(e.type){case"click":this._evtClick(e);break;default:return}}populateVNodeDataset(e,t){let n;return n=void 0!==t?{[o]:JSON.stringify(t),[i]:e}:{[i]:e},n}_evtClick(e){let t=e.target;for(;t&&t.parentElement;){if(t.hasAttribute("data-"+i)){e.preventDefault();const n=t.getAttribute("data-"+i);if(!n)return;const a=t.getAttribute("data-"+o);let s=r.JSONExt.emptyObject;return a&&(s=JSON.parse(a)),void this._commands.execute(n,s)}t=t.parentElement}}}},function(e,t,n){"use strict";n.d(t,"a",(function(){return u}));var r=n(22),i=n(8),o=n(3),a=n(114),s=n(116),l=n(140),c=n(141);class u extends o.Widget{constructor(e){super(e),this._changeGuard=!1,this._spinner=new l.a,this._isRevealed=!1,this.addClass("jp-MainAreaWidget"),this.addClass("jp-MainAreaWidget-ContainStrict"),this.id=a.a.createDomID();const t=(e.translator||r.b).load("jupyterlab"),n=this._content=e.content;n.node.setAttribute("role","region"),n.node.setAttribute("aria-label",t.__("notebook content"));const i=this._toolbar=e.toolbar||new c.c;i.node.setAttribute("role","navigation"),i.node.setAttribute("aria-label",t.__("notebook actions"));const s=this._contentHeader=e.contentHeader||new o.BoxPanel({direction:"top-to-bottom",spacing:0}),u=this.layout=new o.BoxLayout({spacing:0});u.direction="top-to-bottom",o.BoxLayout.setStretch(i,0),o.BoxLayout.setStretch(s,0),o.BoxLayout.setStretch(n,1),u.addWidget(i),u.addWidget(s),u.addWidget(n),n.id||(n.id=a.a.createDomID()),n.node.tabIndex=0,this._updateTitle(),n.title.changed.connect(this._updateTitle,this),this.title.closable=!0,this.title.changed.connect(this._updateContentTitle,this),e.reveal?(this.node.appendChild(this._spinner.node),this._revealed=e.reveal.then(()=>{if(n.isDisposed)return void this.dispose();n.disposed.connect(()=>this.dispose());const e=document.activeElement===this._spinner.node;this._disposeSpinner(),this._isRevealed=!0,e&&this._focusContent()}).catch(e=>{const t=new o.Widget,r=document.createElement("pre");throw r.textContent=String(e),t.node.appendChild(r),o.BoxLayout.setStretch(t,1),this._disposeSpinner(),n.dispose(),this._content=null,i.dispose(),this._toolbar=null,u.addWidget(t),this._isRevealed=!0,t})):(this._spinner.dispose(),this.removeClass("jp-MainAreaWidget-ContainStrict"),n.disposed.connect(()=>this.dispose()),this._isRevealed=!0,this._revealed=Promise.resolve(void 0))}[s.a.symbol](){return this._content?s.a.getPrintFunction(this._content):null}get content(){return this._content}get toolbar(){return this._toolbar}get contentHeader(){return this._contentHeader}get isRevealed(){return this._isRevealed}get revealed(){return this._revealed}onActivateRequest(e){this._isRevealed?this._content&&this._focusContent():this._spinner.node.focus()}onCloseRequest(e){this.dispose()}onUpdateRequest(e){this._content&&i.c.sendMessage(this._content,e)}_disposeSpinner(){this.node.removeChild(this._spinner.node),this._spinner.dispose(),this.removeClass("jp-MainAreaWidget-ContainStrict")}_updateTitle(){if(this._changeGuard||!this.content)return;this._changeGuard=!0;const e=this.content;this.title.label=e.title.label,this.title.mnemonic=e.title.mnemonic,this.title.icon=e.title.icon,this.title.iconClass=e.title.iconClass,this.title.iconLabel=e.title.iconLabel,this.title.caption=e.title.caption,this.title.className=e.title.className,this.title.dataset=e.title.dataset,this._changeGuard=!1}_updateContentTitle(){if(this._changeGuard||!this.content)return;this._changeGuard=!0;const e=this.content;e.title.label=this.title.label,e.title.mnemonic=this.title.mnemonic,e.title.icon=this.title.icon,e.title.iconClass=this.title.iconClass,e.title.iconLabel=this.title.iconLabel,e.title.caption=this.title.caption,e.title.className=this.title.className,e.title.dataset=this.title.dataset,this._changeGuard=!1}_focusContent(){this.content&&(this.content.node.contains(document.activeElement)||this.content.node.focus(),this.content.activate())}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractInputJax=void 0;var r=n(47),i=n(133),o=function(){function e(e){void 0===e&&(e={}),this.adaptor=null,this.mmlFactory=null;var t=this.constructor;this.options=r.userOptions(r.defaultOptions({},t.OPTIONS),e),this.preFilters=new i.FunctionList,this.postFilters=new i.FunctionList}return Object.defineProperty(e.prototype,"name",{get:function(){return this.constructor.NAME},enumerable:!1,configurable:!0}),e.prototype.setAdaptor=function(e){this.adaptor=e},e.prototype.setMmlFactory=function(e){this.mmlFactory=e},e.prototype.initialize=function(){},e.prototype.reset=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t]},Object.defineProperty(e.prototype,"processStrings",{get:function(){return!0},enumerable:!1,configurable:!0}),e.prototype.findMath=function(e,t){return[]},e.prototype.executeFilters=function(e,t,n,r){var i={math:t,document:n,data:r};return e.execute(i),i.data},e.NAME="generic",e.OPTIONS={},e}();t.AbstractInputJax=o},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.OPTABLE=t.MMLSPACING=t.getRange=t.RANGES=t.MO=t.OPDEF=void 0;var i=n(23);function o(e,t,n,r){return void 0===n&&(n=i.TEXCLASS.BIN),void 0===r&&(r=null),[e,t,n,r]}t.OPDEF=o,t.MO={ORD:o(0,0,i.TEXCLASS.ORD),ORD11:o(1,1,i.TEXCLASS.ORD),ORD21:o(2,1,i.TEXCLASS.ORD),ORD02:o(0,2,i.TEXCLASS.ORD),ORD55:o(5,5,i.TEXCLASS.ORD),OP:o(1,2,i.TEXCLASS.OP,{largeop:!0,movablelimits:!0,symmetric:!0}),OPFIXED:o(1,2,i.TEXCLASS.OP,{largeop:!0,movablelimits:!0}),INTEGRAL:o(0,1,i.TEXCLASS.OP,{largeop:!0,symmetric:!0}),INTEGRAL2:o(1,2,i.TEXCLASS.OP,{largeop:!0,symmetric:!0}),BIN3:o(3,3,i.TEXCLASS.BIN),BIN4:o(4,4,i.TEXCLASS.BIN),BIN01:o(0,1,i.TEXCLASS.BIN),BIN5:o(5,5,i.TEXCLASS.BIN),TALLBIN:o(4,4,i.TEXCLASS.BIN,{stretchy:!0}),BINOP:o(4,4,i.TEXCLASS.BIN,{largeop:!0,movablelimits:!0}),REL:o(5,5,i.TEXCLASS.REL),REL1:o(1,1,i.TEXCLASS.REL,{stretchy:!0}),REL4:o(4,4,i.TEXCLASS.REL),RELSTRETCH:o(5,5,i.TEXCLASS.REL,{stretchy:!0}),RELACCENT:o(5,5,i.TEXCLASS.REL,{accent:!0}),WIDEREL:o(5,5,i.TEXCLASS.REL,{accent:!0,stretchy:!0}),OPEN:o(0,0,i.TEXCLASS.OPEN,{fence:!0,stretchy:!0,symmetric:!0}),CLOSE:o(0,0,i.TEXCLASS.CLOSE,{fence:!0,stretchy:!0,symmetric:!0}),INNER:o(0,0,i.TEXCLASS.INNER),PUNCT:o(0,3,i.TEXCLASS.PUNCT),ACCENT:o(0,0,i.TEXCLASS.ORD,{accent:!0}),WIDEACCENT:o(0,0,i.TEXCLASS.ORD,{accent:!0,stretchy:!0})},t.RANGES=[[32,127,i.TEXCLASS.REL,"mo"],[160,191,i.TEXCLASS.ORD,"mo"],[192,591,i.TEXCLASS.ORD,"mi"],[688,879,i.TEXCLASS.ORD,"mo"],[880,6688,i.TEXCLASS.ORD,"mi"],[6832,6911,i.TEXCLASS.ORD,"mo"],[6912,7615,i.TEXCLASS.ORD,"mi"],[7616,7679,i.TEXCLASS.ORD,"mo"],[7680,8191,i.TEXCLASS.ORD,"mi"],[8192,8303,i.TEXCLASS.ORD,"mo"],[8304,8351,i.TEXCLASS.ORD,"mo"],[8448,8527,i.TEXCLASS.ORD,"mi"],[8528,8591,i.TEXCLASS.ORD,"mn"],[8592,8703,i.TEXCLASS.REL,"mo"],[8704,8959,i.TEXCLASS.BIN,"mo"],[8960,9215,i.TEXCLASS.ORD,"mo"],[9312,9471,i.TEXCLASS.ORD,"mn"],[9472,10223,i.TEXCLASS.ORD,"mo"],[10224,10239,i.TEXCLASS.REL,"mo"],[10240,10495,i.TEXCLASS.ORD,"mtext"],[10496,10623,i.TEXCLASS.REL,"mo"],[10624,10751,i.TEXCLASS.ORD,"mo"],[10752,11007,i.TEXCLASS.BIN,"mo"],[11008,11055,i.TEXCLASS.ORD,"mo"],[11056,11087,i.TEXCLASS.REL,"mo"],[11088,11263,i.TEXCLASS.ORD,"mo"],[11264,11744,i.TEXCLASS.ORD,"mi"],[11776,11903,i.TEXCLASS.ORD,"mo"],[11904,12255,i.TEXCLASS.ORD,"mi"],[12272,12351,i.TEXCLASS.ORD,"mo"],[12352,43055,i.TEXCLASS.ORD,"mi"],[43056,43071,i.TEXCLASS.ORD,"mn"],[43072,55295,i.TEXCLASS.ORD,"mi"],[63744,65023,i.TEXCLASS.ORD,"mi"],[65024,65135,i.TEXCLASS.ORD,"mo"],[65136,65791,i.TEXCLASS.ORD,"mi"],[65792,65935,i.TEXCLASS.ORD,"mn"],[65936,74751,i.TEXCLASS.ORD,"mi"],[74752,74879,i.TEXCLASS.ORD,"mn"],[74880,113823,i.TEXCLASS.ORD,"mi"],[113824,119391,i.TEXCLASS.ORD,"mo"],[119648,119679,i.TEXCLASS.ORD,"mn"],[119808,120781,i.TEXCLASS.ORD,"mi"],[120782,120831,i.TEXCLASS.ORD,"mn"],[122624,129023,i.TEXCLASS.ORD,"mo"],[129024,129279,i.TEXCLASS.REL,"mo"],[129280,129535,i.TEXCLASS.ORD,"mo"],[131072,195103,i.TEXCLASS.ORD,"mi"]],t.getRange=function(e){var n,i,o=e.codePointAt(0);try{for(var a=r(t.RANGES),s=a.next();!s.done;s=a.next()){var l=s.value;if(o<=l[1]){if(o>=l[0])return l;break}}}catch(e){n={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(n)throw n.error}}return null},t.MMLSPACING=[[0,0],[1,2],[3,3],[4,4],[0,0],[0,0],[0,3]],t.OPTABLE={prefix:{"(":t.MO.OPEN,"+":t.MO.BIN01,"-":t.MO.BIN01,"[":t.MO.OPEN,"{":t.MO.OPEN,"|":t.MO.OPEN,"||":[0,0,i.TEXCLASS.BIN,{fence:!0,stretchy:!0,symmetric:!0}],"|||":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0,symmetric:!0}],"¬":t.MO.ORD21,"±":t.MO.BIN01,"‖":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0}],"‘":[0,0,i.TEXCLASS.OPEN,{fence:!0}],"“":[0,0,i.TEXCLASS.OPEN,{fence:!0}],"ⅅ":t.MO.ORD21,"ⅆ":o(2,0,i.TEXCLASS.ORD),"∀":t.MO.ORD21,"∂":t.MO.ORD21,"∃":t.MO.ORD21,"∄":t.MO.ORD21,"∇":t.MO.ORD21,"∏":t.MO.OP,"∐":t.MO.OP,"∑":t.MO.OP,"−":t.MO.BIN01,"∓":t.MO.BIN01,"√":[1,1,i.TEXCLASS.ORD,{stretchy:!0}],"∛":t.MO.ORD11,"∜":t.MO.ORD11,"∠":t.MO.ORD,"∡":t.MO.ORD,"∢":t.MO.ORD,"∫":t.MO.INTEGRAL,"∬":t.MO.INTEGRAL,"∭":t.MO.INTEGRAL,"∮":t.MO.INTEGRAL,"∯":t.MO.INTEGRAL,"∰":t.MO.INTEGRAL,"∱":t.MO.INTEGRAL,"∲":t.MO.INTEGRAL,"∳":t.MO.INTEGRAL,"⋀":t.MO.OP,"⋁":t.MO.OP,"⋂":t.MO.OP,"⋃":t.MO.OP,"⌈":t.MO.OPEN,"⌊":t.MO.OPEN,"〈":t.MO.OPEN,"❲":t.MO.OPEN,"⟦":t.MO.OPEN,"⟨":t.MO.OPEN,"⟪":t.MO.OPEN,"⟬":t.MO.OPEN,"⟮":t.MO.OPEN,"⦀":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0}],"⦃":t.MO.OPEN,"⦅":t.MO.OPEN,"⦇":t.MO.OPEN,"⦉":t.MO.OPEN,"⦋":t.MO.OPEN,"⦍":t.MO.OPEN,"⦏":t.MO.OPEN,"⦑":t.MO.OPEN,"⦓":t.MO.OPEN,"⦕":t.MO.OPEN,"⦗":t.MO.OPEN,"⧼":t.MO.OPEN,"⨀":t.MO.OP,"⨁":t.MO.OP,"⨂":t.MO.OP,"⨃":t.MO.OP,"⨄":t.MO.OP,"⨅":t.MO.OP,"⨆":t.MO.OP,"⨇":t.MO.OP,"⨈":t.MO.OP,"⨉":t.MO.OP,"⨊":t.MO.OP,"⨋":t.MO.INTEGRAL2,"⨌":t.MO.INTEGRAL,"⨍":t.MO.INTEGRAL2,"⨎":t.MO.INTEGRAL2,"⨏":t.MO.INTEGRAL2,"⨐":t.MO.OP,"⨑":t.MO.OP,"⨒":t.MO.OP,"⨓":t.MO.OP,"⨔":t.MO.OP,"⨕":t.MO.INTEGRAL2,"⨖":t.MO.INTEGRAL2,"⨗":t.MO.INTEGRAL2,"⨘":t.MO.INTEGRAL2,"⨙":t.MO.INTEGRAL2,"⨚":t.MO.INTEGRAL2,"⨛":t.MO.INTEGRAL2,"⨜":t.MO.INTEGRAL2,"⫼":t.MO.OP,"⫿":t.MO.OP},postfix:{"!!":o(1,0),"!":[1,0,i.TEXCLASS.CLOSE,null],'"':t.MO.ACCENT,"&":t.MO.ORD,")":t.MO.CLOSE,"++":o(0,0),"--":o(0,0),"..":o(0,0),"...":t.MO.ORD,"'":t.MO.ACCENT,"]":t.MO.CLOSE,"^":t.MO.WIDEACCENT,_:t.MO.WIDEACCENT,"`":t.MO.ACCENT,"|":t.MO.CLOSE,"}":t.MO.CLOSE,"~":t.MO.WIDEACCENT,"||":[0,0,i.TEXCLASS.BIN,{fence:!0,stretchy:!0,symmetric:!0}],"|||":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0,symmetric:!0}],"¨":t.MO.ACCENT,"ª":t.MO.ACCENT,"¯":t.MO.WIDEACCENT,"°":t.MO.ORD,"²":t.MO.ACCENT,"³":t.MO.ACCENT,"´":t.MO.ACCENT,"¸":t.MO.ACCENT,"¹":t.MO.ACCENT,"º":t.MO.ACCENT,"ˆ":t.MO.WIDEACCENT,"ˇ":t.MO.WIDEACCENT,"ˉ":t.MO.WIDEACCENT,"ˊ":t.MO.ACCENT,"ˋ":t.MO.ACCENT,"ˍ":t.MO.WIDEACCENT,"˘":t.MO.ACCENT,"˙":t.MO.ACCENT,"˚":t.MO.ACCENT,"˜":t.MO.WIDEACCENT,"˝":t.MO.ACCENT,"˷":t.MO.WIDEACCENT,"̂":t.MO.WIDEACCENT,"̑":t.MO.ACCENT,"϶":t.MO.REL,"‖":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0}],"’":[0,0,i.TEXCLASS.CLOSE,{fence:!0}],"‚":t.MO.ACCENT,"‛":t.MO.ACCENT,"”":[0,0,i.TEXCLASS.CLOSE,{fence:!0}],"„":t.MO.ACCENT,"‟":t.MO.ACCENT,"′":t.MO.ORD,"″":t.MO.ACCENT,"‴":t.MO.ACCENT,"‵":t.MO.ACCENT,"‶":t.MO.ACCENT,"‷":t.MO.ACCENT,"‾":t.MO.WIDEACCENT,"⁗":t.MO.ACCENT,"⃛":t.MO.ACCENT,"⃜":t.MO.ACCENT,"⌉":t.MO.CLOSE,"⌋":t.MO.CLOSE,"〉":t.MO.CLOSE,"⎴":t.MO.WIDEACCENT,"⎵":t.MO.WIDEACCENT,"⏜":t.MO.WIDEACCENT,"⏝":t.MO.WIDEACCENT,"⏞":t.MO.WIDEACCENT,"⏟":t.MO.WIDEACCENT,"⏠":t.MO.WIDEACCENT,"⏡":t.MO.WIDEACCENT,"■":t.MO.BIN3,"□":t.MO.BIN3,"▪":t.MO.BIN3,"▫":t.MO.BIN3,"▭":t.MO.BIN3,"▮":t.MO.BIN3,"▯":t.MO.BIN3,"▰":t.MO.BIN3,"▱":t.MO.BIN3,"▲":t.MO.BIN4,"▴":t.MO.BIN4,"▶":t.MO.BIN4,"▷":t.MO.BIN4,"▸":t.MO.BIN4,"▼":t.MO.BIN4,"▾":t.MO.BIN4,"◀":t.MO.BIN4,"◁":t.MO.BIN4,"◂":t.MO.BIN4,"◄":t.MO.BIN4,"◅":t.MO.BIN4,"◆":t.MO.BIN4,"◇":t.MO.BIN4,"◈":t.MO.BIN4,"◉":t.MO.BIN4,"◌":t.MO.BIN4,"◍":t.MO.BIN4,"◎":t.MO.BIN4,"●":t.MO.BIN4,"◖":t.MO.BIN4,"◗":t.MO.BIN4,"◦":t.MO.BIN4,"♭":t.MO.ORD02,"♮":t.MO.ORD02,"♯":t.MO.ORD02,"❳":t.MO.CLOSE,"⟧":t.MO.CLOSE,"⟩":t.MO.CLOSE,"⟫":t.MO.CLOSE,"⟭":t.MO.CLOSE,"⟯":t.MO.CLOSE,"⦀":[0,0,i.TEXCLASS.ORD,{fence:!0,stretchy:!0}],"⦄":t.MO.CLOSE,"⦆":t.MO.CLOSE,"⦈":t.MO.CLOSE,"⦊":t.MO.CLOSE,"⦌":t.MO.CLOSE,"⦎":t.MO.CLOSE,"⦐":t.MO.CLOSE,"⦒":t.MO.CLOSE,"⦔":t.MO.CLOSE,"⦖":t.MO.CLOSE,"⦘":t.MO.CLOSE,"⧽":t.MO.CLOSE},infix:{"!=":t.MO.BIN4,"#":t.MO.ORD,$:t.MO.ORD,"%":[3,3,i.TEXCLASS.ORD,null],"&&":t.MO.BIN4,"":t.MO.ORD,"*":t.MO.BIN3,"**":o(1,1),"*=":t.MO.BIN4,"+":t.MO.BIN4,"+=":t.MO.BIN4,",":[0,3,i.TEXCLASS.PUNCT,{linebreakstyle:"after",separator:!0}],"-":t.MO.BIN4,"-=":t.MO.BIN4,"->":t.MO.BIN5,".":[0,3,i.TEXCLASS.PUNCT,{separator:!0}],"/":t.MO.ORD11,"//":o(1,1),"/=":t.MO.BIN4,":":[1,2,i.TEXCLASS.REL,null],":=":t.MO.BIN4,";":[0,3,i.TEXCLASS.PUNCT,{linebreakstyle:"after",separator:!0}],"<":t.MO.REL,"<=":t.MO.BIN5,"<>":o(1,1),"=":t.MO.REL,"==":t.MO.BIN4,">":t.MO.REL,">=":t.MO.BIN5,"?":[1,1,i.TEXCLASS.CLOSE,null],"@":t.MO.ORD11,"\\":t.MO.ORD,"^":t.MO.ORD11,_:t.MO.ORD11,"|":[2,2,i.TEXCLASS.ORD,{fence:!0,stretchy:!0,symmetric:!0}],"||":[2,2,i.TEXCLASS.BIN,{fence:!0,stretchy:!0,symmetric:!0}],"|||":[2,2,i.TEXCLASS.ORD,{fence:!0,stretchy:!0,symmetric:!0}],"±":t.MO.BIN4,"·":t.MO.BIN4,"×":t.MO.BIN4,"÷":t.MO.BIN4,"ʹ":t.MO.ORD,"̀":t.MO.ACCENT,"́":t.MO.ACCENT,"̃":t.MO.WIDEACCENT,"̄":t.MO.ACCENT,"̆":t.MO.ACCENT,"̇":t.MO.ACCENT,"̈":t.MO.ACCENT,"̌":t.MO.ACCENT,"̲":t.MO.WIDEACCENT,"̸":t.MO.REL4,"―":[0,0,i.TEXCLASS.ORD,{stretchy:!0}],"‗":[0,0,i.TEXCLASS.ORD,{stretchy:!0}],"†":t.MO.BIN3,"‡":t.MO.BIN3,"•":t.MO.BIN4,"…":t.MO.INNER,"⁃":t.MO.BIN4,"⁄":t.MO.TALLBIN,"⁡":t.MO.ORD,"⁢":t.MO.ORD,"⁣":[0,0,i.TEXCLASS.ORD,{linebreakstyle:"after",separator:!0}],"⁤":t.MO.ORD,"⃗":t.MO.ACCENT,"ℑ":t.MO.ORD,"ℓ":t.MO.ORD,"℘":t.MO.ORD,"ℜ":t.MO.ORD,"←":t.MO.WIDEREL,"↑":t.MO.RELSTRETCH,"→":t.MO.WIDEREL,"↓":t.MO.RELSTRETCH,"↔":t.MO.WIDEREL,"↕":t.MO.RELSTRETCH,"↖":t.MO.RELSTRETCH,"↗":t.MO.RELSTRETCH,"↘":t.MO.RELSTRETCH,"↙":t.MO.RELSTRETCH,"↚":t.MO.RELACCENT,"↛":t.MO.RELACCENT,"↜":t.MO.WIDEREL,"↝":t.MO.WIDEREL,"↞":t.MO.WIDEREL,"↟":t.MO.WIDEREL,"↠":t.MO.WIDEREL,"↡":t.MO.RELSTRETCH,"↢":t.MO.WIDEREL,"↣":t.MO.WIDEREL,"↤":t.MO.WIDEREL,"↥":t.MO.RELSTRETCH,"↦":t.MO.WIDEREL,"↧":t.MO.RELSTRETCH,"↨":t.MO.RELSTRETCH,"↩":t.MO.WIDEREL,"↪":t.MO.WIDEREL,"↫":t.MO.WIDEREL,"↬":t.MO.WIDEREL,"↭":t.MO.WIDEREL,"↮":t.MO.RELACCENT,"↯":t.MO.RELSTRETCH,"↰":t.MO.RELSTRETCH,"↱":t.MO.RELSTRETCH,"↲":t.MO.RELSTRETCH,"↳":t.MO.RELSTRETCH,"↴":t.MO.RELSTRETCH,"↵":t.MO.RELSTRETCH,"↶":t.MO.RELACCENT,"↷":t.MO.RELACCENT,"↸":t.MO.REL,"↹":t.MO.WIDEREL,"↺":t.MO.REL,"↻":t.MO.REL,"↼":t.MO.WIDEREL,"↽":t.MO.WIDEREL,"↾":t.MO.RELSTRETCH,"↿":t.MO.RELSTRETCH,"⇀":t.MO.WIDEREL,"⇁":t.MO.WIDEREL,"⇂":t.MO.RELSTRETCH,"⇃":t.MO.RELSTRETCH,"⇄":t.MO.WIDEREL,"⇅":t.MO.RELSTRETCH,"⇆":t.MO.WIDEREL,"⇇":t.MO.WIDEREL,"⇈":t.MO.RELSTRETCH,"⇉":t.MO.WIDEREL,"⇊":t.MO.RELSTRETCH,"⇋":t.MO.WIDEREL,"⇌":t.MO.WIDEREL,"⇍":t.MO.RELACCENT,"⇎":t.MO.RELACCENT,"⇏":t.MO.RELACCENT,"⇐":t.MO.WIDEREL,"⇑":t.MO.RELSTRETCH,"⇒":t.MO.WIDEREL,"⇓":t.MO.RELSTRETCH,"⇔":t.MO.WIDEREL,"⇕":t.MO.RELSTRETCH,"⇖":t.MO.RELSTRETCH,"⇗":t.MO.RELSTRETCH,"⇘":t.MO.RELSTRETCH,"⇙":t.MO.RELSTRETCH,"⇚":t.MO.WIDEREL,"⇛":t.MO.WIDEREL,"⇜":t.MO.WIDEREL,"⇝":t.MO.WIDEREL,"⇞":t.MO.REL,"⇟":t.MO.REL,"⇠":t.MO.WIDEREL,"⇡":t.MO.RELSTRETCH,"⇢":t.MO.WIDEREL,"⇣":t.MO.RELSTRETCH,"⇤":t.MO.WIDEREL,"⇥":t.MO.WIDEREL,"⇦":t.MO.WIDEREL,"⇧":t.MO.RELSTRETCH,"⇨":t.MO.WIDEREL,"⇩":t.MO.RELSTRETCH,"⇪":t.MO.RELSTRETCH,"⇫":t.MO.RELSTRETCH,"⇬":t.MO.RELSTRETCH,"⇭":t.MO.RELSTRETCH,"⇮":t.MO.RELSTRETCH,"⇯":t.MO.RELSTRETCH,"⇰":t.MO.WIDEREL,"⇱":t.MO.REL,"⇲":t.MO.REL,"⇳":t.MO.RELSTRETCH,"⇴":t.MO.RELACCENT,"⇵":t.MO.RELSTRETCH,"⇶":t.MO.WIDEREL,"⇷":t.MO.RELACCENT,"⇸":t.MO.RELACCENT,"⇹":t.MO.RELACCENT,"⇺":t.MO.RELACCENT,"⇻":t.MO.RELACCENT,"⇼":t.MO.RELACCENT,"⇽":t.MO.WIDEREL,"⇾":t.MO.WIDEREL,"⇿":t.MO.WIDEREL,"∁":o(1,2,i.TEXCLASS.ORD),"∅":t.MO.ORD,"∆":t.MO.BIN3,"∈":t.MO.REL,"∉":t.MO.REL,"∊":t.MO.REL,"∋":t.MO.REL,"∌":t.MO.REL,"∍":t.MO.REL,"∎":t.MO.BIN3,"−":t.MO.BIN4,"∓":t.MO.BIN4,"∔":t.MO.BIN4,"∕":t.MO.TALLBIN,"∖":t.MO.BIN4,"∗":t.MO.BIN4,"∘":t.MO.BIN4,"∙":t.MO.BIN4,"∝":t.MO.REL,"∞":t.MO.ORD,"∟":t.MO.REL,"∣":t.MO.REL,"∤":t.MO.REL,"∥":t.MO.REL,"∦":t.MO.REL,"∧":t.MO.BIN4,"∨":t.MO.BIN4,"∩":t.MO.BIN4,"∪":t.MO.BIN4,"∴":t.MO.REL,"∵":t.MO.REL,"∶":t.MO.REL,"∷":t.MO.REL,"∸":t.MO.BIN4,"∹":t.MO.REL,"∺":t.MO.BIN4,"∻":t.MO.REL,"∼":t.MO.REL,"∽":t.MO.REL,"∽̱":t.MO.BIN3,"∾":t.MO.REL,"∿":t.MO.BIN3,"≀":t.MO.BIN4,"≁":t.MO.REL,"≂":t.MO.REL,"≂̸":t.MO.REL,"≃":t.MO.REL,"≄":t.MO.REL,"≅":t.MO.REL,"≆":t.MO.REL,"≇":t.MO.REL,"≈":t.MO.REL,"≉":t.MO.REL,"≊":t.MO.REL,"≋":t.MO.REL,"≌":t.MO.REL,"≍":t.MO.REL,"≎":t.MO.REL,"≎̸":t.MO.REL,"≏":t.MO.REL,"≏̸":t.MO.REL,"≐":t.MO.REL,"≑":t.MO.REL,"≒":t.MO.REL,"≓":t.MO.REL,"≔":t.MO.REL,"≕":t.MO.REL,"≖":t.MO.REL,"≗":t.MO.REL,"≘":t.MO.REL,"≙":t.MO.REL,"≚":t.MO.REL,"≛":t.MO.REL,"≜":t.MO.REL,"≝":t.MO.REL,"≞":t.MO.REL,"≟":t.MO.REL,"≠":t.MO.REL,"≡":t.MO.REL,"≢":t.MO.REL,"≣":t.MO.REL,"≤":t.MO.REL,"≥":t.MO.REL,"≦":t.MO.REL,"≦̸":t.MO.REL,"≧":t.MO.REL,"≨":t.MO.REL,"≩":t.MO.REL,"≪":t.MO.REL,"≪̸":t.MO.REL,"≫":t.MO.REL,"≫̸":t.MO.REL,"≬":t.MO.REL,"≭":t.MO.REL,"≮":t.MO.REL,"≯":t.MO.REL,"≰":t.MO.REL,"≱":t.MO.REL,"≲":t.MO.REL,"≳":t.MO.REL,"≴":t.MO.REL,"≵":t.MO.REL,"≶":t.MO.REL,"≷":t.MO.REL,"≸":t.MO.REL,"≹":t.MO.REL,"≺":t.MO.REL,"≻":t.MO.REL,"≼":t.MO.REL,"≽":t.MO.REL,"≾":t.MO.REL,"≿":t.MO.REL,"≿̸":t.MO.REL,"⊀":t.MO.REL,"⊁":t.MO.REL,"⊂":t.MO.REL,"⊂⃒":t.MO.REL,"⊃":t.MO.REL,"⊃⃒":t.MO.REL,"⊄":t.MO.REL,"⊅":t.MO.REL,"⊆":t.MO.REL,"⊇":t.MO.REL,"⊈":t.MO.REL,"⊉":t.MO.REL,"⊊":t.MO.REL,"⊋":t.MO.REL,"⊌":t.MO.BIN4,"⊍":t.MO.BIN4,"⊎":t.MO.BIN4,"⊏":t.MO.REL,"⊏̸":t.MO.REL,"⊐":t.MO.REL,"⊐̸":t.MO.REL,"⊑":t.MO.REL,"⊒":t.MO.REL,"⊓":t.MO.BIN4,"⊔":t.MO.BIN4,"⊕":t.MO.BIN4,"⊖":t.MO.BIN4,"⊗":t.MO.BIN4,"⊘":t.MO.BIN4,"⊙":t.MO.BIN4,"⊚":t.MO.BIN4,"⊛":t.MO.BIN4,"⊜":t.MO.BIN4,"⊝":t.MO.BIN4,"⊞":t.MO.BIN4,"⊟":t.MO.BIN4,"⊠":t.MO.BIN4,"⊡":t.MO.BIN4,"⊢":t.MO.REL,"⊣":t.MO.REL,"⊤":t.MO.ORD55,"⊥":t.MO.REL,"⊦":t.MO.REL,"⊧":t.MO.REL,"⊨":t.MO.REL,"⊩":t.MO.REL,"⊪":t.MO.REL,"⊫":t.MO.REL,"⊬":t.MO.REL,"⊭":t.MO.REL,"⊮":t.MO.REL,"⊯":t.MO.REL,"⊰":t.MO.REL,"⊱":t.MO.REL,"⊲":t.MO.REL,"⊳":t.MO.REL,"⊴":t.MO.REL,"⊵":t.MO.REL,"⊶":t.MO.REL,"⊷":t.MO.REL,"⊸":t.MO.REL,"⊹":t.MO.REL,"⊺":t.MO.BIN4,"⊻":t.MO.BIN4,"⊼":t.MO.BIN4,"⊽":t.MO.BIN4,"⊾":t.MO.BIN3,"⊿":t.MO.BIN3,"⋄":t.MO.BIN4,"⋅":t.MO.BIN4,"⋆":t.MO.BIN4,"⋇":t.MO.BIN4,"⋈":t.MO.REL,"⋉":t.MO.BIN4,"⋊":t.MO.BIN4,"⋋":t.MO.BIN4,"⋌":t.MO.BIN4,"⋍":t.MO.REL,"⋎":t.MO.BIN4,"⋏":t.MO.BIN4,"⋐":t.MO.REL,"⋑":t.MO.REL,"⋒":t.MO.BIN4,"⋓":t.MO.BIN4,"⋔":t.MO.REL,"⋕":t.MO.REL,"⋖":t.MO.REL,"⋗":t.MO.REL,"⋘":t.MO.REL,"⋙":t.MO.REL,"⋚":t.MO.REL,"⋛":t.MO.REL,"⋜":t.MO.REL,"⋝":t.MO.REL,"⋞":t.MO.REL,"⋟":t.MO.REL,"⋠":t.MO.REL,"⋡":t.MO.REL,"⋢":t.MO.REL,"⋣":t.MO.REL,"⋤":t.MO.REL,"⋥":t.MO.REL,"⋦":t.MO.REL,"⋧":t.MO.REL,"⋨":t.MO.REL,"⋩":t.MO.REL,"⋪":t.MO.REL,"⋫":t.MO.REL,"⋬":t.MO.REL,"⋭":t.MO.REL,"⋮":t.MO.ORD55,"⋯":t.MO.INNER,"⋰":t.MO.REL,"⋱":[5,5,i.TEXCLASS.INNER,null],"⋲":t.MO.REL,"⋳":t.MO.REL,"⋴":t.MO.REL,"⋵":t.MO.REL,"⋶":t.MO.REL,"⋷":t.MO.REL,"⋸":t.MO.REL,"⋹":t.MO.REL,"⋺":t.MO.REL,"⋻":t.MO.REL,"⋼":t.MO.REL,"⋽":t.MO.REL,"⋾":t.MO.REL,"⋿":t.MO.REL,"⌅":t.MO.BIN3,"⌆":t.MO.BIN3,"⌢":t.MO.REL4,"⌣":t.MO.REL4,"〈":t.MO.OPEN,"〉":t.MO.CLOSE,"⎪":t.MO.ORD,"⎯":[0,0,i.TEXCLASS.ORD,{stretchy:!0}],"⎰":t.MO.OPEN,"⎱":t.MO.CLOSE,"─":t.MO.ORD,"△":t.MO.BIN4,"▵":t.MO.BIN4,"▹":t.MO.BIN4,"▽":t.MO.BIN4,"▿":t.MO.BIN4,"◃":t.MO.BIN4,"◯":t.MO.BIN3,"♠":t.MO.ORD,"♡":t.MO.ORD,"♢":t.MO.ORD,"♣":t.MO.ORD,"❘":t.MO.REL,"⟰":t.MO.RELSTRETCH,"⟱":t.MO.RELSTRETCH,"⟵":t.MO.WIDEREL,"⟶":t.MO.WIDEREL,"⟷":t.MO.WIDEREL,"⟸":t.MO.WIDEREL,"⟹":t.MO.WIDEREL,"⟺":t.MO.WIDEREL,"⟻":t.MO.WIDEREL,"⟼":t.MO.WIDEREL,"⟽":t.MO.WIDEREL,"⟾":t.MO.WIDEREL,"⟿":t.MO.WIDEREL,"⤀":t.MO.RELACCENT,"⤁":t.MO.RELACCENT,"⤂":t.MO.RELACCENT,"⤃":t.MO.RELACCENT,"⤄":t.MO.RELACCENT,"⤅":t.MO.RELACCENT,"⤆":t.MO.RELACCENT,"⤇":t.MO.RELACCENT,"⤈":t.MO.REL,"⤉":t.MO.REL,"⤊":t.MO.RELSTRETCH,"⤋":t.MO.RELSTRETCH,"⤌":t.MO.WIDEREL,"⤍":t.MO.WIDEREL,"⤎":t.MO.WIDEREL,"⤏":t.MO.WIDEREL,"⤐":t.MO.WIDEREL,"⤑":t.MO.RELACCENT,"⤒":t.MO.RELSTRETCH,"⤓":t.MO.RELSTRETCH,"⤔":t.MO.RELACCENT,"⤕":t.MO.RELACCENT,"⤖":t.MO.RELACCENT,"⤗":t.MO.RELACCENT,"⤘":t.MO.RELACCENT,"⤙":t.MO.RELACCENT,"⤚":t.MO.RELACCENT,"⤛":t.MO.RELACCENT,"⤜":t.MO.RELACCENT,"⤝":t.MO.RELACCENT,"⤞":t.MO.RELACCENT,"⤟":t.MO.RELACCENT,"⤠":t.MO.RELACCENT,"⤡":t.MO.RELSTRETCH,"⤢":t.MO.RELSTRETCH,"⤣":t.MO.REL,"⤤":t.MO.REL,"⤥":t.MO.REL,"⤦":t.MO.REL,"⤧":t.MO.REL,"⤨":t.MO.REL,"⤩":t.MO.REL,"⤪":t.MO.REL,"⤫":t.MO.REL,"⤬":t.MO.REL,"⤭":t.MO.REL,"⤮":t.MO.REL,"⤯":t.MO.REL,"⤰":t.MO.REL,"⤱":t.MO.REL,"⤲":t.MO.REL,"⤳":t.MO.RELACCENT,"⤴":t.MO.REL,"⤵":t.MO.REL,"⤶":t.MO.REL,"⤷":t.MO.REL,"⤸":t.MO.REL,"⤹":t.MO.REL,"⤺":t.MO.RELACCENT,"⤻":t.MO.RELACCENT,"⤼":t.MO.RELACCENT,"⤽":t.MO.RELACCENT,"⤾":t.MO.REL,"⤿":t.MO.REL,"⥀":t.MO.REL,"⥁":t.MO.REL,"⥂":t.MO.RELACCENT,"⥃":t.MO.RELACCENT,"⥄":t.MO.RELACCENT,"⥅":t.MO.RELACCENT,"⥆":t.MO.RELACCENT,"⥇":t.MO.RELACCENT,"⥈":t.MO.RELACCENT,"⥉":t.MO.REL,"⥊":t.MO.RELACCENT,"⥋":t.MO.RELACCENT,"⥌":t.MO.REL,"⥍":t.MO.REL,"⥎":t.MO.WIDEREL,"⥏":t.MO.RELSTRETCH,"⥐":t.MO.WIDEREL,"⥑":t.MO.RELSTRETCH,"⥒":t.MO.WIDEREL,"⥓":t.MO.WIDEREL,"⥔":t.MO.RELSTRETCH,"⥕":t.MO.RELSTRETCH,"⥖":t.MO.RELSTRETCH,"⥗":t.MO.RELSTRETCH,"⥘":t.MO.RELSTRETCH,"⥙":t.MO.RELSTRETCH,"⥚":t.MO.WIDEREL,"⥛":t.MO.WIDEREL,"⥜":t.MO.RELSTRETCH,"⥝":t.MO.RELSTRETCH,"⥞":t.MO.WIDEREL,"⥟":t.MO.WIDEREL,"⥠":t.MO.RELSTRETCH,"⥡":t.MO.RELSTRETCH,"⥢":t.MO.RELACCENT,"⥣":t.MO.REL,"⥤":t.MO.RELACCENT,"⥥":t.MO.REL,"⥦":t.MO.RELACCENT,"⥧":t.MO.RELACCENT,"⥨":t.MO.RELACCENT,"⥩":t.MO.RELACCENT,"⥪":t.MO.RELACCENT,"⥫":t.MO.RELACCENT,"⥬":t.MO.RELACCENT,"⥭":t.MO.RELACCENT,"⥮":t.MO.RELSTRETCH,"⥯":t.MO.RELSTRETCH,"⥰":t.MO.RELACCENT,"⥱":t.MO.RELACCENT,"⥲":t.MO.RELACCENT,"⥳":t.MO.RELACCENT,"⥴":t.MO.RELACCENT,"⥵":t.MO.RELACCENT,"⥶":t.MO.RELACCENT,"⥷":t.MO.RELACCENT,"⥸":t.MO.RELACCENT,"⥹":t.MO.RELACCENT,"⥺":t.MO.RELACCENT,"⥻":t.MO.RELACCENT,"⥼":t.MO.RELACCENT,"⥽":t.MO.RELACCENT,"⥾":t.MO.REL,"⥿":t.MO.REL,"⦁":t.MO.BIN3,"⦂":t.MO.BIN3,"⦙":t.MO.BIN3,"⦚":t.MO.BIN3,"⦛":t.MO.BIN3,"⦜":t.MO.BIN3,"⦝":t.MO.BIN3,"⦞":t.MO.BIN3,"⦟":t.MO.BIN3,"⦠":t.MO.BIN3,"⦡":t.MO.BIN3,"⦢":t.MO.BIN3,"⦣":t.MO.BIN3,"⦤":t.MO.BIN3,"⦥":t.MO.BIN3,"⦦":t.MO.BIN3,"⦧":t.MO.BIN3,"⦨":t.MO.BIN3,"⦩":t.MO.BIN3,"⦪":t.MO.BIN3,"⦫":t.MO.BIN3,"⦬":t.MO.BIN3,"⦭":t.MO.BIN3,"⦮":t.MO.BIN3,"⦯":t.MO.BIN3,"⦰":t.MO.BIN3,"⦱":t.MO.BIN3,"⦲":t.MO.BIN3,"⦳":t.MO.BIN3,"⦴":t.MO.BIN3,"⦵":t.MO.BIN3,"⦶":t.MO.BIN4,"⦷":t.MO.BIN4,"⦸":t.MO.BIN4,"⦹":t.MO.BIN4,"⦺":t.MO.BIN4,"⦻":t.MO.BIN4,"⦼":t.MO.BIN4,"⦽":t.MO.BIN4,"⦾":t.MO.BIN4,"⦿":t.MO.BIN4,"⧀":t.MO.REL,"⧁":t.MO.REL,"⧂":t.MO.BIN3,"⧃":t.MO.BIN3,"⧄":t.MO.BIN4,"⧅":t.MO.BIN4,"⧆":t.MO.BIN4,"⧇":t.MO.BIN4,"⧈":t.MO.BIN4,"⧉":t.MO.BIN3,"⧊":t.MO.BIN3,"⧋":t.MO.BIN3,"⧌":t.MO.BIN3,"⧍":t.MO.BIN3,"⧎":t.MO.REL,"⧏":t.MO.REL,"⧏̸":t.MO.REL,"⧐":t.MO.REL,"⧐̸":t.MO.REL,"⧑":t.MO.REL,"⧒":t.MO.REL,"⧓":t.MO.REL,"⧔":t.MO.REL,"⧕":t.MO.REL,"⧖":t.MO.BIN4,"⧗":t.MO.BIN4,"⧘":t.MO.BIN3,"⧙":t.MO.BIN3,"⧛":t.MO.BIN3,"⧜":t.MO.BIN3,"⧝":t.MO.BIN3,"⧞":t.MO.REL,"⧟":t.MO.BIN3,"⧠":t.MO.BIN3,"⧡":t.MO.REL,"⧢":t.MO.BIN4,"⧣":t.MO.REL,"⧤":t.MO.REL,"⧥":t.MO.REL,"⧦":t.MO.REL,"⧧":t.MO.BIN3,"⧨":t.MO.BIN3,"⧩":t.MO.BIN3,"⧪":t.MO.BIN3,"⧫":t.MO.BIN3,"⧬":t.MO.BIN3,"⧭":t.MO.BIN3,"⧮":t.MO.BIN3,"⧯":t.MO.BIN3,"⧰":t.MO.BIN3,"⧱":t.MO.BIN3,"⧲":t.MO.BIN3,"⧳":t.MO.BIN3,"⧴":t.MO.REL,"⧵":t.MO.BIN4,"⧶":t.MO.BIN4,"⧷":t.MO.BIN4,"⧸":t.MO.BIN3,"⧹":t.MO.BIN3,"⧺":t.MO.BIN3,"⧻":t.MO.BIN3,"⧾":t.MO.BIN4,"⧿":t.MO.BIN4,"⨝":t.MO.BIN3,"⨞":t.MO.BIN3,"⨟":t.MO.BIN3,"⨠":t.MO.BIN3,"⨡":t.MO.BIN3,"⨢":t.MO.BIN4,"⨣":t.MO.BIN4,"⨤":t.MO.BIN4,"⨥":t.MO.BIN4,"⨦":t.MO.BIN4,"⨧":t.MO.BIN4,"⨨":t.MO.BIN4,"⨩":t.MO.BIN4,"⨪":t.MO.BIN4,"⨫":t.MO.BIN4,"⨬":t.MO.BIN4,"⨭":t.MO.BIN4,"⨮":t.MO.BIN4,"⨯":t.MO.BIN4,"⨰":t.MO.BIN4,"⨱":t.MO.BIN4,"⨲":t.MO.BIN4,"⨳":t.MO.BIN4,"⨴":t.MO.BIN4,"⨵":t.MO.BIN4,"⨶":t.MO.BIN4,"⨷":t.MO.BIN4,"⨸":t.MO.BIN4,"⨹":t.MO.BIN4,"⨺":t.MO.BIN4,"⨻":t.MO.BIN4,"⨼":t.MO.BIN4,"⨽":t.MO.BIN4,"⨾":t.MO.BIN4,"⨿":t.MO.BIN4,"⩀":t.MO.BIN4,"⩁":t.MO.BIN4,"⩂":t.MO.BIN4,"⩃":t.MO.BIN4,"⩄":t.MO.BIN4,"⩅":t.MO.BIN4,"⩆":t.MO.BIN4,"⩇":t.MO.BIN4,"⩈":t.MO.BIN4,"⩉":t.MO.BIN4,"⩊":t.MO.BIN4,"⩋":t.MO.BIN4,"⩌":t.MO.BIN4,"⩍":t.MO.BIN4,"⩎":t.MO.BIN4,"⩏":t.MO.BIN4,"⩐":t.MO.BIN4,"⩑":t.MO.BIN4,"⩒":t.MO.BIN4,"⩓":t.MO.BIN4,"⩔":t.MO.BIN4,"⩕":t.MO.BIN4,"⩖":t.MO.BIN4,"⩗":t.MO.BIN4,"⩘":t.MO.BIN4,"⩙":t.MO.REL,"⩚":t.MO.BIN4,"⩛":t.MO.BIN4,"⩜":t.MO.BIN4,"⩝":t.MO.BIN4,"⩞":t.MO.BIN4,"⩟":t.MO.BIN4,"⩠":t.MO.BIN4,"⩡":t.MO.BIN4,"⩢":t.MO.BIN4,"⩣":t.MO.BIN4,"⩤":t.MO.BIN4,"⩥":t.MO.BIN4,"⩦":t.MO.REL,"⩧":t.MO.REL,"⩨":t.MO.REL,"⩩":t.MO.REL,"⩪":t.MO.REL,"⩫":t.MO.REL,"⩬":t.MO.REL,"⩭":t.MO.REL,"⩮":t.MO.REL,"⩯":t.MO.REL,"⩰":t.MO.REL,"⩱":t.MO.BIN4,"⩲":t.MO.BIN4,"⩳":t.MO.REL,"⩴":t.MO.REL,"⩵":t.MO.REL,"⩶":t.MO.REL,"⩷":t.MO.REL,"⩸":t.MO.REL,"⩹":t.MO.REL,"⩺":t.MO.REL,"⩻":t.MO.REL,"⩼":t.MO.REL,"⩽":t.MO.REL,"⩽̸":t.MO.REL,"⩾":t.MO.REL,"⩾̸":t.MO.REL,"⩿":t.MO.REL,"⪀":t.MO.REL,"⪁":t.MO.REL,"⪂":t.MO.REL,"⪃":t.MO.REL,"⪄":t.MO.REL,"⪅":t.MO.REL,"⪆":t.MO.REL,"⪇":t.MO.REL,"⪈":t.MO.REL,"⪉":t.MO.REL,"⪊":t.MO.REL,"⪋":t.MO.REL,"⪌":t.MO.REL,"⪍":t.MO.REL,"⪎":t.MO.REL,"⪏":t.MO.REL,"⪐":t.MO.REL,"⪑":t.MO.REL,"⪒":t.MO.REL,"⪓":t.MO.REL,"⪔":t.MO.REL,"⪕":t.MO.REL,"⪖":t.MO.REL,"⪗":t.MO.REL,"⪘":t.MO.REL,"⪙":t.MO.REL,"⪚":t.MO.REL,"⪛":t.MO.REL,"⪜":t.MO.REL,"⪝":t.MO.REL,"⪞":t.MO.REL,"⪟":t.MO.REL,"⪠":t.MO.REL,"⪡":t.MO.REL,"⪡̸":t.MO.REL,"⪢":t.MO.REL,"⪢̸":t.MO.REL,"⪣":t.MO.REL,"⪤":t.MO.REL,"⪥":t.MO.REL,"⪦":t.MO.REL,"⪧":t.MO.REL,"⪨":t.MO.REL,"⪩":t.MO.REL,"⪪":t.MO.REL,"⪫":t.MO.REL,"⪬":t.MO.REL,"⪭":t.MO.REL,"⪮":t.MO.REL,"⪯":t.MO.REL,"⪯̸":t.MO.REL,"⪰":t.MO.REL,"⪰̸":t.MO.REL,"⪱":t.MO.REL,"⪲":t.MO.REL,"⪳":t.MO.REL,"⪴":t.MO.REL,"⪵":t.MO.REL,"⪶":t.MO.REL,"⪷":t.MO.REL,"⪸":t.MO.REL,"⪹":t.MO.REL,"⪺":t.MO.REL,"⪻":t.MO.REL,"⪼":t.MO.REL,"⪽":t.MO.REL,"⪾":t.MO.REL,"⪿":t.MO.REL,"⫀":t.MO.REL,"⫁":t.MO.REL,"⫂":t.MO.REL,"⫃":t.MO.REL,"⫄":t.MO.REL,"⫅":t.MO.REL,"⫆":t.MO.REL,"⫇":t.MO.REL,"⫈":t.MO.REL,"⫉":t.MO.REL,"⫊":t.MO.REL,"⫋":t.MO.REL,"⫌":t.MO.REL,"⫍":t.MO.REL,"⫎":t.MO.REL,"⫏":t.MO.REL,"⫐":t.MO.REL,"⫑":t.MO.REL,"⫒":t.MO.REL,"⫓":t.MO.REL,"⫔":t.MO.REL,"⫕":t.MO.REL,"⫖":t.MO.REL,"⫗":t.MO.REL,"⫘":t.MO.REL,"⫙":t.MO.REL,"⫚":t.MO.REL,"⫛":t.MO.REL,"⫝":t.MO.REL,"⫝̸":t.MO.REL,"⫞":t.MO.REL,"⫟":t.MO.REL,"⫠":t.MO.REL,"⫡":t.MO.REL,"⫢":t.MO.REL,"⫣":t.MO.REL,"⫤":t.MO.REL,"⫥":t.MO.REL,"⫦":t.MO.REL,"⫧":t.MO.REL,"⫨":t.MO.REL,"⫩":t.MO.REL,"⫪":t.MO.REL,"⫫":t.MO.REL,"⫬":t.MO.REL,"⫭":t.MO.REL,"⫮":t.MO.REL,"⫯":t.MO.REL,"⫰":t.MO.REL,"⫱":t.MO.REL,"⫲":t.MO.REL,"⫳":t.MO.REL,"⫴":t.MO.BIN4,"⫵":t.MO.BIN4,"⫶":t.MO.BIN4,"⫷":t.MO.REL,"⫸":t.MO.REL,"⫹":t.MO.REL,"⫺":t.MO.REL,"⫻":t.MO.BIN4,"⫽":t.MO.BIN4,"⫾":t.MO.BIN3,"⭅":t.MO.RELSTRETCH,"⭆":t.MO.RELSTRETCH,"〈":t.MO.OPEN,"〉":t.MO.CLOSE,"︷":t.MO.WIDEACCENT,"︸":t.MO.WIDEACCENT}},t.OPTABLE.infix["^"]=t.MO.WIDEREL,t.OPTABLE.infix._=t.MO.WIDEREL,t.OPTABLE.infix["⫝̸"]=t.MO.REL},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0});var a=n(39),s=function(){function e(e,t,n){this._factory=e,this._env=t,this.global={},this.stack=[],this.global={isInner:n},this.stack=[this._factory.create("start",this.global)],t&&(this.stack[0].env=t),this.env=this.stack[0].env}return Object.defineProperty(e.prototype,"env",{get:function(){return this._env},set:function(e){this._env=e},enumerable:!1,configurable:!0}),e.prototype.Push=function(){for(var e,t,n=[],s=0;s<arguments.length;s++)n[s]=arguments[s];try{for(var l=r(n),c=l.next();!c.done;c=l.next()){var u=c.value;if(u){var d=a.default.isNode(u)?this._factory.create("mml",u):u;d.global=this.global;var h=i(this.stack.length?this.Top().checkItem(d):[null,!0],2),p=h[0],f=h[1];f&&(p?(this.Pop(),this.Push.apply(this,o([],i(p)))):(this.stack.push(d),d.env?(d.copyEnv&&Object.assign(d.env,this.env),this.env=d.env):d.env=this.env))}}}catch(t){e={error:t}}finally{try{c&&!c.done&&(t=l.return)&&t.call(l)}finally{if(e)throw e.error}}},e.prototype.Pop=function(){var e=this.stack.pop();return e.isOpen||delete e.env,this.env=this.stack.length?this.Top().env:{},e},e.prototype.Top=function(e){return void 0===e&&(e=1),this.stack.length<e?null:this.stack[this.stack.length-e]},e.prototype.Prev=function(e){var t=this.Top();return e?t.First:t.Pop()},e.prototype.toString=function(){return"stack[\n  "+this.stack.join("\n  ")+"\n]"},e}();t.default=s},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0});var a=n(826),s=n(182),l=n(39),c=n(47),u=function(){function e(e,t){void 0===t&&(t=[]),this.options={},this.packageData=new Map,this.parsers=[],this.root=null,this.nodeLists={},this.error=!1,this.handlers=e.handlers,this.nodeFactory=new s.NodeFactory,this.nodeFactory.configuration=this,this.nodeFactory.setCreators(e.nodes),this.itemFactory=new a.default(e.items),this.itemFactory.configuration=this,c.defaultOptions.apply(void 0,i([this.options],r(t))),c.defaultOptions(this.options,e.options)}return e.prototype.pushParser=function(e){this.parsers.unshift(e)},e.prototype.popParser=function(){this.parsers.shift()},Object.defineProperty(e.prototype,"parser",{get:function(){return this.parsers[0]},enumerable:!1,configurable:!0}),e.prototype.clear=function(){this.parsers=[],this.root=null,this.nodeLists={},this.error=!1,this.tags.resetTag()},e.prototype.addNode=function(e,t){var n=this.nodeLists[e];if(n||(n=this.nodeLists[e]=[]),n.push(t),t.kind!==e){var r=l.default.getProperty(t,"in-lists")||"",i=(r?r.split(/,/):[]).concat(e).join(",");l.default.setProperty(t,"in-lists",i)}},e.prototype.getList=function(e){var t,n,r=this.nodeLists[e]||[],i=[];try{for(var a=o(r),s=a.next();!s.done;s=a.next()){var l=s.value;this.inTree(l)&&i.push(l)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}return this.nodeLists[e]=i,i},e.prototype.removeFromList=function(e,t){var n,r,i=this.nodeLists[e]||[];try{for(var a=o(t),s=a.next();!s.done;s=a.next()){var l=s.value,c=i.indexOf(l);c>=0&&i.splice(c,1)}}catch(e){n={error:e}}finally{try{s&&!s.done&&(r=a.return)&&r.call(a)}finally{if(n)throw n.error}}},e.prototype.inTree=function(e){for(;e&&e!==this.root;)e=e.parent;return!!e},e}();t.default=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractOutputJax=void 0;var r=n(47),i=n(133),o=function(){function e(e){void 0===e&&(e={}),this.adaptor=null;var t=this.constructor;this.options=r.userOptions(r.defaultOptions({},t.OPTIONS),e),this.postFilters=new i.FunctionList}return Object.defineProperty(e.prototype,"name",{get:function(){return this.constructor.NAME},enumerable:!1,configurable:!0}),e.prototype.setAdaptor=function(e){this.adaptor=e},e.prototype.initialize=function(){},e.prototype.reset=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t]},e.prototype.getMetrics=function(e){},e.prototype.styleSheet=function(e){return null},e.prototype.pageElements=function(e){return null},e.prototype.executeFilters=function(e,t,n,r){var i={math:t,document:n,data:r};return e.execute(i),i.data},e.NAME="generic",e.OPTIONS={},e}();t.AbstractOutputJax=o},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.Styles=void 0;var a=["top","right","bottom","left"],s=["width","style","color"];function l(e){for(var t=e.split(/((?:'[^']*'|"[^"]*"|,[\s\n]|[^\s\n])*)/g),n=[];t.length>1;)t.shift(),n.push(t.shift());return n}function c(e){var t,n,i=l(this.styles[e]);0===i.length&&i.push(""),1===i.length&&i.push(i[0]),2===i.length&&i.push(i[0]),3===i.length&&i.push(i[1]);try{for(var o=r(b.connect[e].children),a=o.next();!a.done;a=o.next()){var s=a.value;this.setStyle(this.childName(e,s),i.shift())}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}}function u(e){var t,n,i=b.connect[e].children,o=[];try{for(var a=r(i),s=a.next();!s.done;s=a.next()){var l=s.value,c=this.styles[e+"-"+l];if(!c)return void delete this.styles[e];o.push(c)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}o[3]===o[1]&&(o.pop(),o[2]===o[0]&&(o.pop(),o[1]===o[0]&&o.pop())),this.styles[e]=o.join(" ")}function d(e){var t,n;try{for(var i=r(b.connect[e].children),o=i.next();!o.done;o=i.next()){var a=o.value;this.setStyle(this.childName(e,a),this.styles[e])}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}}function h(e){var t,n,a=o([],i(b.connect[e].children)),s=this.styles[this.childName(e,a.shift())];try{for(var l=r(a),c=l.next();!c.done;c=l.next()){var u=c.value;if(this.styles[this.childName(e,u)]!==s)return void delete this.styles[e]}}catch(e){t={error:e}}finally{try{c&&!c.done&&(n=l.return)&&n.call(l)}finally{if(t)throw t.error}}this.styles[e]=s}var p=/^(?:[\d.]+(?:[a-z]+)|thin|medium|thick|inherit|initial|unset)$/,f=/^(?:none|hidden|dotted|dashed|solid|double|groove|ridge|inset|outset|inherit|initial|unset)$/;function m(e){var t,n,i,o,a={width:"",style:"",color:""};try{for(var s=r(l(this.styles[e])),c=s.next();!c.done;c=s.next()){var u=c.value;u.match(p)&&""===a.width?a.width=u:u.match(f)&&""===a.style?a.style=u:a.color=u}}catch(e){t={error:e}}finally{try{c&&!c.done&&(n=s.return)&&n.call(s)}finally{if(t)throw t.error}}try{for(var d=r(b.connect[e].children),h=d.next();!h.done;h=d.next()){var m=h.value;this.setStyle(this.childName(e,m),a[m])}}catch(e){i={error:e}}finally{try{h&&!h.done&&(o=d.return)&&o.call(d)}finally{if(i)throw i.error}}}function g(e){var t,n,i=[];try{for(var o=r(b.connect[e].children),a=o.next();!a.done;a=o.next()){var s=a.value,l=this.styles[this.childName(e,s)];l&&i.push(l)}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}i.length?this.styles[e]=i.join(" "):delete this.styles[e]}var v={style:/^(?:normal|italic|oblique|inherit|initial|unset)$/,variant:new RegExp("^(?:"+["normal|none","inherit|initial|unset","common-ligatures|no-common-ligatures","discretionary-ligatures|no-discretionary-ligatures","historical-ligatures|no-historical-ligatures","contextual|no-contextual","(?:stylistic|character-variant|swash|ornaments|annotation)\\([^)]*\\)","small-caps|all-small-caps|petite-caps|all-petite-caps|unicase|titling-caps","lining-nums|oldstyle-nums|proportional-nums|tabular-nums","diagonal-fractions|stacked-fractions","ordinal|slashed-zero","jis78|jis83|jis90|jis04|simplified|traditional","full-width|proportional-width","ruby"].join("|")+")$"),weight:/^(?:normal|bold|bolder|lighter|[1-9]00|inherit|initial|unset)$/,stretch:new RegExp("^(?:"+["normal","(?:(?:ultra|extra|semi)-)?condensed","(?:(?:semi|extra|ulta)-)?expanded","inherit|initial|unset"].join("|")+")$"),size:new RegExp("^(?:"+["xx-small|x-small|small|medium|large|x-large|xx-large|larger|smaller","[d.]+%|[d.]+[a-z]+","inherit|initial|unset"].join("|")+")(?:/(?:normal|[d.+](?:%|[a-z]+)?))?$")};function y(e){var t,n,o,a,s=l(this.styles[e]),c={style:"",variant:[],weight:"",stretch:"",size:"",family:"","line-height":""};try{for(var u=r(s),d=u.next();!d.done;d=u.next()){var h=d.value;c.family=h;try{for(var p=(o=void 0,r(Object.keys(v))),f=p.next();!f.done;f=p.next()){var m=f.value;if((Array.isArray(c[m])||""===c[m])&&h.match(v[m]))if("size"===m){var g=i(h.split(/\//),2),y=g[0],_=g[1];c[m]=y,_&&(c["line-height"]=_)}else""===c.size&&(Array.isArray(c[m])?c[m].push(h):c[m]=h)}}catch(e){o={error:e}}finally{try{f&&!f.done&&(a=p.return)&&a.call(p)}finally{if(o)throw o.error}}}}catch(e){t={error:e}}finally{try{d&&!d.done&&(n=u.return)&&n.call(u)}finally{if(t)throw t.error}}!function(e,t){var n,i;try{for(var o=r(b.connect[e].children),a=o.next();!a.done;a=o.next()){var s=a.value,l=this.childName(e,s);if(Array.isArray(t[s])){var c=t[s];c.length&&(this.styles[l]=c.join(" "))}else""!==t[s]&&(this.styles[l]=t[s])}}catch(e){n={error:e}}finally{try{a&&!a.done&&(i=o.return)&&i.call(o)}finally{if(n)throw n.error}}}(e,c),delete this.styles[e]}function _(e){}var b=function(){function e(e){void 0===e&&(e=""),this.parse(e)}return Object.defineProperty(e.prototype,"cssText",{get:function(){var e,t,n=[];try{for(var i=r(Object.keys(this.styles)),o=i.next();!o.done;o=i.next()){var a=o.value,s=this.parentName(a);this.styles[s]||n.push(a+": "+this.styles[a])}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return n.join("; ")},enumerable:!1,configurable:!0}),e.prototype.set=function(t,n){for(t=this.normalizeName(t),this.setStyle(t,n),e.connect[t]&&!e.connect[t].combine&&(this.combineChildren(t),delete this.styles[t]);t.match(/-/)&&(t=this.parentName(t),e.connect[t]);)e.connect[t].combine.call(this,t)},e.prototype.get=function(e){return e=this.normalizeName(e),this.styles.hasOwnProperty(e)?this.styles[e]:""},e.prototype.setStyle=function(t,n){this.styles[t]=n,e.connect[t]&&e.connect[t].children&&e.connect[t].split.call(this,t),""===n&&delete this.styles[t]},e.prototype.combineChildren=function(t){var n,i,o=this.parentName(t);try{for(var a=r(e.connect[t].children),s=a.next();!s.done;s=a.next()){var l=s.value,c=this.childName(o,l);e.connect[c].combine.call(this,c)}}catch(e){n={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(n)throw n.error}}},e.prototype.parentName=function(e){var t=e.replace(/-[^-]*$/,"");return e===t?"":t},e.prototype.childName=function(t,n){return n.match(/-/)?n:(e.connect[t]&&!e.connect[t].combine&&(n+=t.replace(/.*-/,"-"),t=this.parentName(t)),t+"-"+n)},e.prototype.normalizeName=function(e){return e.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()}))},e.prototype.parse=function(e){void 0===e&&(e="");var t=this.constructor.pattern;this.styles={};for(var n=e.replace(t.comment,"").split(t.style);n.length>1;){var r=i(n.splice(0,3),3),o=r[0],a=r[1],s=r[2];if(o.match(/[^\s\n]/))return;this.set(a,s)}},e.pattern={style:/([-a-z]+)[\s\n]*:[\s\n]*((?:'[^']*'|"[^"]*"|\n|.)*?)[\s\n]*(?:;|$)/g,comment:/\/\*[^]*?\*\//g},e.connect={padding:{children:a,split:c,combine:u},border:{children:a,split:d,combine:h},"border-top":{children:s,split:m,combine:g},"border-right":{children:s,split:m,combine:g},"border-bottom":{children:s,split:m,combine:g},"border-left":{children:s,split:m,combine:g},"border-width":{children:a,split:c,combine:null},"border-style":{children:a,split:c,combine:null},"border-color":{children:a,split:c,combine:null},font:{children:["style","variant","weight","stretch","line-height","size","family"],split:y,combine:_}},e}();t.Styles=b},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CssStyles=void 0;var i=function(){function e(e){void 0===e&&(e=null),this.styles={},this.addStyles(e)}return Object.defineProperty(e.prototype,"cssText",{get:function(){return this.getStyleString()},enumerable:!1,configurable:!0}),e.prototype.addStyles=function(e){var t,n;if(e)try{for(var i=r(Object.keys(e)),o=i.next();!o.done;o=i.next()){var a=o.value;this.styles[a]||(this.styles[a]={}),Object.assign(this.styles[a],e[a])}}catch(e){t={error:e}}finally{try{o&&!o.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},e.prototype.removeStyles=function(){for(var e,t,n=[],i=0;i<arguments.length;i++)n[i]=arguments[i];try{for(var o=r(n),a=o.next();!a.done;a=o.next()){var s=a.value;delete this.styles[s]}}catch(t){e={error:t}}finally{try{a&&!a.done&&(t=o.return)&&t.call(o)}finally{if(e)throw e.error}}},e.prototype.clear=function(){this.styles={}},e.prototype.getStyleString=function(){return this.getStyleRules().join("\n\n")},e.prototype.getStyleRules=function(){var e,t,n=Object.keys(this.styles),i=new Array(n.length),o=0;try{for(var a=r(n),s=a.next();!s.done;s=a.next()){var l=s.value;i[o++]=l+" {\n"+this.getStyleDefString(this.styles[l])+"\n}"}}catch(t){e={error:t}}finally{try{s&&!s.done&&(t=a.return)&&t.call(a)}finally{if(e)throw e.error}}return i},e.prototype.getStyleDefString=function(e){var t,n,i=Object.keys(e),o=new Array(i.length),a=0;try{for(var s=r(i),l=s.next();!l.done;l=s.next()){var c=l.value;o[a++]="  "+c+": "+e[c]+";"}}catch(e){t={error:e}}finally{try{l&&!l.done&&(n=s.return)&&n.call(s)}finally{if(t)throw t.error}}return o.join("\n")},e}();t.CssStyles=i},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMath=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"math"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(t,n,r,i){"display"===this.attributes.get("mode")&&this.attributes.setInherited("display","block"),t=this.addInheritedAttributes(t,this.attributes.getAllAttributes()),n=!!this.attributes.get("displaystyle")||!this.attributes.get("displaystyle")&&"block"===this.attributes.get("display"),this.attributes.setInherited("displaystyle",n),r=this.attributes.get("scriptlevel")||this.constructor.defaults.scriptlevel,e.prototype.setChildInheritedAttributes.call(this,t,n,r,i)},t.defaults=o(o({},a.AbstractMmlLayoutNode.defaults),{mathvariant:"normal",mathsize:"normal",mathcolor:"",mathbackground:"transparent",dir:"ltr",scriptlevel:0,displaystyle:!1,display:"inline",maxwidth:"",overflow:"linebreak",altimg:"","altimg-width":"","altimg-height":"","altimg-valign":"",alttext:"",cdgroup:"",scriptsizemultiplier:1/Math.sqrt(2),scriptminsize:"8px",infixlinebreakstyle:"before",lineleading:"1ex",linebreakmultchar:"⁢",indentshift:"auto",indentalign:"auto",indenttarget:"",indentalignfirst:"indentalign",indentshiftfirst:"indentshift",indentalignlast:"indentalign",indentshiftlast:"indentshift"}),t}(a.AbstractMmlLayoutNode);t.MmlMath=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMi=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mi"},enumerable:!1,configurable:!0}),t.prototype.setInheritedAttributes=function(n,r,i,o){void 0===n&&(n={}),void 0===r&&(r=!1),void 0===i&&(i=0),void 0===o&&(o=!1),e.prototype.setInheritedAttributes.call(this,n,r,i,o),this.getText().match(t.singleCharacter)&&!n.mathvariant&&this.attributes.setInherited("mathvariant","italic")},t.prototype.setTeXclass=function(e){this.getPrevClass(e);var n=this.getText();return n.length>1&&n.match(t.operatorName)&&"normal"===this.attributes.get("mathvariant")&&void 0===this.getProperty("autoOP")&&void 0===this.getProperty("texClass")&&(this.texClass=a.TEXCLASS.OP,this.setProperty("autoOP",!0)),this},t.defaults=o({},a.AbstractMmlTokenNode.defaults),t.operatorName=/^[a-z][a-z0-9]*$/i,t.singleCharacter=/^[\uD800-\uDBFF]?.[\u0300-\u036F\u1AB0-\u1ABE\u1DC0-\u1DFF\u20D0-\u20EF]*$/,t}(a.AbstractMmlTokenNode);t.MmlMi=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMn=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mn"},enumerable:!1,configurable:!0}),t.defaults=o({},a.AbstractMmlTokenNode.defaults),t}(a.AbstractMmlTokenNode);t.MmlMn=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMs=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"ms"},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlTokenNode.defaults),{lquote:'"',rquote:'"'}),t}(a.AbstractMmlTokenNode);t.MmlMs=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMtext=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mtext"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return!0},enumerable:!1,configurable:!0}),t.defaults=o({},a.AbstractMmlTokenNode.defaults),t}(a.AbstractMmlTokenNode);t.MmlMtext=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMspace=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.NONE,t}return i(t,e),t.prototype.setTeXclass=function(e){return e},Object.defineProperty(t.prototype,"kind",{get:function(){return"mspace"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"hasNewline",{get:function(){var e=this.attributes;return null==e.getExplicit("width")&&null==e.getExplicit("height")&&null==e.getExplicit("depth")&&"newline"===e.get("linebreak")},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlTokenNode.defaults),{width:"0em",height:"0ex",depth:"0ex",linebreak:"auto"}),t}(a.AbstractMmlTokenNode);t.MmlMspace=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMpadded=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mpadded"},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlLayoutNode.defaults),{width:"",height:"",depth:"",lspace:0,voffset:0}),t}(a.AbstractMmlLayoutNode);t.MmlMpadded=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMenclose=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"menclose"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContininer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){return e=this.childNodes[0].setTeXclass(e),this.updateTeXclass(this.childNodes[0]),e},t.defaults=o(o({},a.AbstractMmlNode.defaults),{notation:"longdiv"}),t}(a.AbstractMmlNode);t.MmlMenclose=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonInferredMrowMixin=t.CommonMrowMixin=void 0;var l=n(74);t.CommonMrowMixin=function(e){return function(e){function t(){for(var t,n,r=[],i=0;i<arguments.length;i++)r[i]=arguments[i];var c=e.apply(this,a([],o(r)))||this;c.stretchChildren();try{for(var u=s(c.childNodes),d=u.next();!d.done;d=u.next()){var h=d.value;if(h.bbox.pwidth){c.bbox.pwidth=l.BBox.fullWidth;break}}}catch(e){t={error:e}}finally{try{d&&!d.done&&(n=u.return)&&n.call(u)}finally{if(t)throw t.error}}return c}return i(t,e),Object.defineProperty(t.prototype,"fixesPWidth",{get:function(){return!1},enumerable:!1,configurable:!0}),t.prototype.stretchChildren=function(){var e,t,n,r,i,o,a=[];try{for(var l=s(this.childNodes),c=l.next();!c.done;c=l.next()){(C=c.value).canStretch(1)&&a.push(C)}}catch(t){e={error:t}}finally{try{c&&!c.done&&(t=l.return)&&t.call(l)}finally{if(e)throw e.error}}var u=a.length,d=this.childNodes.length;if(u&&d>1){var h=0,p=0,f=u>1&&u===d;try{for(var m=s(this.childNodes),g=m.next();!g.done;g=m.next()){var v=0===(C=g.value).stretch.dir;if(f||v){var y=C.getBBox(v),_=y.h,b=y.d,M=y.rscale;(_*=M)>h&&(h=_),(b*=M)>p&&(p=b)}}}catch(e){n={error:e}}finally{try{g&&!g.done&&(r=m.return)&&r.call(m)}finally{if(n)throw n.error}}try{for(var w=s(a),A=w.next();!A.done;A=w.next()){var C;(C=A.value).coreMO().getStretchedVariant([h,p])}}catch(e){i={error:e}}finally{try{A&&!A.done&&(o=w.return)&&o.call(w)}finally{if(i)throw i.error}}}},t}(e)},t.CommonInferredMrowMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.getScale=function(){this.bbox.scale=this.parent.bbox.scale,this.bbox.rscale=1},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlInferredMrow=t.MmlMrow=void 0;var s=n(23),l=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._core=null,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mrow"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){var e,t;try{for(var n=a(this.childNodes),r=n.next();!r.done;r=n.next()){if(!r.value.isSpacelike)return!1}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isEmbellished",{get:function(){var e,t,n=!1,r=0;try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){var s=o.value;if(s)if(s.isEmbellished){if(n)return!1;n=!0,this._core=r}else if(!s.isSpacelike)return!1;r++}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return n},enumerable:!1,configurable:!0}),t.prototype.core=function(){return this.isEmbellished&&null!=this._core?this.childNodes[this._core]:this},t.prototype.coreMO=function(){return this.isEmbellished&&null!=this._core?this.childNodes[this._core].coreMO():this},t.prototype.nonSpaceLength=function(){var e,t,n=0;try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){var o=i.value;o&&!o.isSpacelike&&n++}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}return n},t.prototype.firstNonSpace=function(){var e,t;try{for(var n=a(this.childNodes),r=n.next();!r.done;r=n.next()){var i=r.value;if(i&&!i.isSpacelike)return i}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}return null},t.prototype.lastNonSpace=function(){for(var e=this.childNodes.length;--e>=0;){var t=this.childNodes[e];if(t&&!t.isSpacelike)return t}return null},t.prototype.setTeXclass=function(e){var t,n,r,i;if(null!=this.getProperty("open")||null!=this.getProperty("close")){this.getPrevClass(e),e=null;try{for(var o=a(this.childNodes),l=o.next();!l.done;l=o.next()){e=l.value.setTeXclass(e)}}catch(e){t={error:e}}finally{try{l&&!l.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}null==this.texClass&&(this.texClass=s.TEXCLASS.INNER)}else{try{for(var c=a(this.childNodes),u=c.next();!u.done;u=c.next()){e=u.value.setTeXclass(e)}}catch(e){r={error:e}}finally{try{u&&!u.done&&(i=c.return)&&i.call(c)}finally{if(r)throw r.error}}this.childNodes[0]&&this.updateTeXclass(this.childNodes[0])}return e},t.defaults=o({},s.AbstractMmlNode.defaults),t}(s.AbstractMmlNode);t.MmlMrow=l;var c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"inferredMrow"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isInferred",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"notParent",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.toString=function(){return"["+this.childNodes.join(",")+"]"},t.defaults=l.defaults,t}(l);t.MmlInferredMrow=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMfenced=void 0;var s=n(23),l=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=s.TEXCLASS.INNER,t.separators=[],t.open=null,t.close=null,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mfenced"},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){this.getPrevClass(e),this.open&&(e=this.open.setTeXclass(e)),this.childNodes[0]&&(e=this.childNodes[0].setTeXclass(e));for(var t=1,n=this.childNodes.length;t<n;t++)this.separators[t-1]&&(e=this.separators[t-1].setTeXclass(e)),this.childNodes[t]&&(e=this.childNodes[t].setTeXclass(e));return this.close&&(e=this.close.setTeXclass(e)),this.updateTeXclass(this.open),e},t.prototype.setChildInheritedAttributes=function(t,n,r,i){var o,s;this.addFakeNodes();try{for(var l=a([this.open,this.close].concat(this.separators)),c=l.next();!c.done;c=l.next()){var u=c.value;u&&u.setInheritedAttributes(t,n,r,i)}}catch(e){o={error:e}}finally{try{c&&!c.done&&(s=l.return)&&s.call(l)}finally{if(o)throw o.error}}e.prototype.setChildInheritedAttributes.call(this,t,n,r,i)},t.prototype.addFakeNodes=function(){var e,t,n=this.attributes.getList("open","close","separators"),r=n.open,i=n.close,o=n.separators;if(r=r.replace(/[ \t\n\r]/g,""),i=i.replace(/[ \t\n\r]/g,""),o=o.replace(/[ \t\n\r]/g,""),r&&(this.open=this.fakeNode(r,{fence:!0,form:"prefix"},s.TEXCLASS.OPEN)),o){for(;o.length<this.childNodes.length-1;)o+=o.charAt(o.length-1);var l=0;try{for(var c=a(this.childNodes.slice(1)),u=c.next();!u.done;u=c.next()){u.value&&this.separators.push(this.fakeNode(o.charAt(l++)))}}catch(t){e={error:t}}finally{try{u&&!u.done&&(t=c.return)&&t.call(c)}finally{if(e)throw e.error}}}i&&(this.close=this.fakeNode(i,{fence:!0,form:"postfix"},s.TEXCLASS.CLOSE))},t.prototype.fakeNode=function(e,t,n){void 0===t&&(t={}),void 0===n&&(n=null);var r=this.factory.create("text").setText(e),i=this.factory.create("mo",t,[r]);return i.texClass=n,i.parent=this,i},t.defaults=o(o({},s.AbstractMmlNode.defaults),{open:"(",close:")",separators:","}),t}(s.AbstractMmlNode);t.MmlMfenced=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMfrac=void 0;var s=n(23),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mfrac"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){var t,n;this.getPrevClass(e);try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){i.value.setTeXclass(null)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return this},t.prototype.setChildInheritedAttributes=function(e,t,n,r){(!t||n>0)&&n++,this.childNodes[0].setInheritedAttributes(e,!1,n,r),this.childNodes[1].setInheritedAttributes(e,!1,n,!0)},t.defaults=o(o({},s.AbstractMmlBaseNode.defaults),{linethickness:"medium",numalign:"center",denomalign:"center",bevelled:!1}),t}(s.AbstractMmlBaseNode);t.MmlMfrac=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmsqrt=void 0;var a=n(40),s=n(859),l=n(436),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n,r,i,a=this.childNodes[this.surd],s=this.childNodes[this.base],l=a.getBBox(),c=s.getBBox(),u=o(this.getPQ(l),2)[1],d=this.font.params.rule_thickness,h=c.h+u+d,p=this.standardCHTMLnode(e);null!=this.root&&(r=this.adaptor.append(p,this.html("mjx-root")),i=this.childNodes[this.root]);var f=this.adaptor.append(p,this.html("mjx-sqrt",{},[t=this.html("mjx-surd"),n=this.html("mjx-box",{style:{paddingTop:this.em(u)}})]));this.addRoot(r,i,l,h),a.toCHTML(t),s.toCHTML(n),a.size<0&&this.adaptor.addClass(f,"mjx-tall")},t.prototype.addRoot=function(e,t,n,r){},t.kind=l.MmlMsqrt.prototype.kind,t.styles={"mjx-root":{display:"inline-block","white-space":"nowrap"},"mjx-surd":{display:"inline-block","vertical-align":"top"},"mjx-sqrt":{display:"inline-block","padding-top":".07em"},"mjx-sqrt > mjx-box":{"border-top":".07em solid"},"mjx-sqrt.mjx-tall > mjx-box":{"padding-left":".3em","margin-left":"-.3em"}},t}(s.CommonMsqrtMixin(a.CHTMLWrapper));t.CHTMLmsqrt=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMsqrt=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"msqrt"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){return this.getPrevClass(e),this.childNodes[0].setTeXclass(null),this},t.prototype.setChildInheritedAttributes=function(e,t,n,r){this.childNodes[0].setInheritedAttributes(e,t,n,!0)},t.defaults=o({},a.AbstractMmlNode.defaults),t}(a.AbstractMmlNode);t.MmlMsqrt=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMroot=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mroot"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){return this.getPrevClass(e),this.childNodes[0].setTeXclass(null),this.childNodes[1].setTeXclass(null),this},t.prototype.setChildInheritedAttributes=function(e,t,n,r){this.childNodes[0].setInheritedAttributes(e,t,n,!0),this.childNodes[1].setInheritedAttributes(e,!1,n+2,r)},t.defaults=o({},a.AbstractMmlNode.defaults),t}(a.AbstractMmlNode);t.MmlMroot=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMover=t.MmlMunder=t.MmlMunderover=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"munderover"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 3},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"base",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"under",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"over",{get:function(){return 2},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i=this.childNodes;i[0].setInheritedAttributes(e,t,n,r||!!i[this.over]);var o=!(t||!i[0].coreMO().attributes.get("movablelimits")),a=this.constructor.ACCENTS;i[1].setInheritedAttributes(e,!1,this.getScriptlevel(a[1],o,n),r||1===this.under),this.setInheritedAccent(1,a[1],t,n,r,o),i[2]&&(i[2].setInheritedAttributes(e,!1,this.getScriptlevel(a[2],o,n),r||2===this.under),this.setInheritedAccent(2,a[2],t,n,r,o))},t.prototype.getScriptlevel=function(e,t,n){return!t&&this.attributes.get(e)||n++,n},t.prototype.setInheritedAccent=function(e,t,n,r,i,o){var a=this.childNodes[e];if(null==this.attributes.getExplicit(t)&&a.isEmbellished){var s=a.coreMO().attributes.get("accent");this.attributes.setInherited(t,s),s!==this.attributes.getDefault(t)&&a.setInheritedAttributes({},n,this.getScriptlevel(t,o,r),i)}},t.defaults=o(o({},a.AbstractMmlBaseNode.defaults),{accent:!1,accentunder:!1,align:"center"}),t.ACCENTS=["","accentunder","accent"],t}(a.AbstractMmlBaseNode);t.MmlMunderover=s;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"munder"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),t.defaults=o({},s.defaults),t}(s);t.MmlMunder=l;var c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mover"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 2},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"over",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"under",{get:function(){return 2},enumerable:!1,configurable:!0}),t.defaults=o({},s.defaults),t.ACCENTS=["","accent","accentunder"],t}(s);t.MmlMover=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlNone=t.MmlMprescripts=t.MmlMmultiscripts=void 0;var a=n(23),s=n(187),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mmultiscripts"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 1},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(e,t,n,r){this.childNodes[0].setInheritedAttributes(e,t,n,r);for(var i=!1,o=1,a=0;o<this.childNodes.length;o++){var s=this.childNodes[o];if(s.isKind("mprescripts")){if(!i&&(i=!0,o%2==0)){var l=this.factory.create("mrow");this.childNodes.splice(o,0,l),l.parent=this,o++}}else{var c=r||a%2==0;s.setInheritedAttributes(e,!1,n+1,c),a++}}this.childNodes.length%2==(i?1:0)&&(this.appendChild(this.factory.create("mrow")),this.childNodes[this.childNodes.length-1].setInheritedAttributes(e,!1,n+1,r))},t.prototype.verifyChildren=function(t){for(var n=!1,r=t.fixMmultiscripts,i=0;i<this.childNodes.length;i++){var o=this.childNodes[i];o.isKind("mprescripts")&&(n?o.mError(o.kind+" can only appear once in "+this.kind,t,!0):(n=!0,i%2!=0||r||this.mError("There must be an equal number of prescripts of each type",t)))}this.childNodes.length%2!=(n?1:0)||r||this.mError("There must be an equal number of scripts of each type",t),e.prototype.verifyChildren.call(this,t)},t.defaults=o({},s.MmlMsubsup.defaults),t}(s.MmlMsubsup);t.MmlMmultiscripts=l;var c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mprescripts"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 0},enumerable:!1,configurable:!0}),t.prototype.verifyTree=function(t){e.prototype.verifyTree.call(this,t),this.parent&&!this.parent.isKind("mmultiscripts")&&this.mError(this.kind+" must be a child of mmultiscripts",t,!0)},t.defaults=o({},a.AbstractMmlNode.defaults),t}(a.AbstractMmlNode);t.MmlMprescripts=c;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"none"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 0},enumerable:!1,configurable:!0}),t.prototype.verifyTree=function(t){e.prototype.verifyTree.call(this,t),this.parent&&!this.parent.isKind("mmultiscripts")&&this.mError(this.kind+" must be a child of mmultiscripts",t,!0)},t.defaults=o({},a.AbstractMmlNode.defaults),t}(a.AbstractMmlNode);t.MmlNone=u},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMtable=void 0;var s=n(23),l=n(62),c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.properties={useHeight:!0},t.texclass=s.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mtable"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setInheritedAttributes=function(t,n,r,i){var o,l;try{for(var c=a(s.indentAttributes),u=c.next();!u.done;u=c.next()){var d=u.value;t[d]&&this.attributes.setInherited(d,t[d][1]),void 0!==this.attributes.getExplicit(d)&&delete this.attributes.getAllAttributes()[d]}}catch(e){o={error:e}}finally{try{u&&!u.done&&(l=c.return)&&l.call(c)}finally{if(o)throw o.error}}e.prototype.setInheritedAttributes.call(this,t,n,r,i)},t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i,o,s,c;try{for(var u=a(this.childNodes),d=u.next();!d.done;d=u.next()){(g=d.value).isKind("mtr")||this.replaceChild(this.factory.create("mtr"),g).appendChild(g)}}catch(e){i={error:e}}finally{try{d&&!d.done&&(o=u.return)&&o.call(u)}finally{if(i)throw i.error}}n=this.getProperty("scriptlevel")||n,t=!(!this.attributes.getExplicit("displaystyle")&&!this.attributes.getDefault("displaystyle")),e=this.addInheritedAttributes(e,{columnalign:this.attributes.get("columnalign"),rowalign:"center"});var h=this.attributes.getExplicit("data-cramped"),p=l.split(this.attributes.get("rowalign"));try{for(var f=a(this.childNodes),m=f.next();!m.done;m=f.next()){var g=m.value;e.rowalign[1]=p.shift()||e.rowalign[1],g.setInheritedAttributes(e,t,n,!!h)}}catch(e){s={error:e}}finally{try{m&&!m.done&&(c=f.return)&&c.call(f)}finally{if(s)throw s.error}}},t.prototype.verifyChildren=function(t){var n,r;if(!t.fixMtables)try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){o.value.isKind("mtr")||this.mError("Children of "+this.kind+" must be mtr or mlabeledtr",t)}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}e.prototype.verifyChildren.call(this,t)},t.prototype.setTeXclass=function(e){var t,n;this.getPrevClass(e);try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){i.value.setTeXclass(null)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return this},t.defaults=o(o({},s.AbstractMmlNode.defaults),{align:"axis",rowalign:"baseline",columnalign:"center",groupalign:"{left}",alignmentscope:!0,columnwidth:"auto",width:"auto",rowspacing:"1ex",columnspacing:".8em",rowlines:"none",columnlines:"none",frame:"none",framespacing:"0.4em 0.5ex",equalrows:!1,equalcolumns:!1,displaystyle:!1,side:"right",minlabelspacing:"0.8em"}),t}(s.AbstractMmlNode);t.MmlMtable=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMlabeledtrMixin=t.CommonMtrMixin=void 0,t.CommonMtrMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"fixesPWidth",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"numCells",{get:function(){return this.childNodes.length},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"labeled",{get:function(){return!1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"tableCells",{get:function(){return this.childNodes},enumerable:!1,configurable:!0}),t.prototype.getChild=function(e){return this.childNodes[e]},t.prototype.getChildBBoxes=function(){return this.childNodes.map((function(e){return e.getBBox()}))},t.prototype.stretchChildren=function(e){var t,n,r,i,a,s;void 0===e&&(e=null);var l=[],c=this.labeled?this.childNodes.slice(1):this.childNodes;try{for(var u=o(c),d=u.next();!d.done;d=u.next()){(x=d.value.childNodes[0]).canStretch(1)&&l.push(x)}}catch(e){t={error:e}}finally{try{d&&!d.done&&(n=u.return)&&n.call(u)}finally{if(t)throw t.error}}var h=l.length,p=this.childNodes.length;if(h&&p>1){if(null===e){var f=0,m=0,g=h>1&&h===p;try{for(var v=o(c),y=v.next();!y.done;y=v.next()){var _=0===(x=y.value.childNodes[0]).stretch.dir;if(g||_){var b=x.getBBox(_),M=b.h,w=b.d;M>f&&(f=M),w>m&&(m=w)}}}catch(e){r={error:e}}finally{try{y&&!y.done&&(i=v.return)&&i.call(v)}finally{if(r)throw r.error}}e=[f,m]}try{for(var A=o(l),C=A.next();!C.done;C=A.next()){var x;(x=C.value).coreMO().getStretchedVariant(e)}}catch(e){a={error:e}}finally{try{C&&!C.done&&(s=A.return)&&s.call(A)}finally{if(a)throw a.error}}}},t}(e)},t.CommonMlabeledtrMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"numCells",{get:function(){return Math.max(0,this.childNodes.length-1)},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"labeled",{get:function(){return!0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"tableCells",{get:function(){return this.childNodes.slice(1)},enumerable:!1,configurable:!0}),t.prototype.getChild=function(e){return this.childNodes[e+1]},t.prototype.getChildBBoxes=function(){return this.childNodes.slice(1).map((function(e){return e.getBBox()}))},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMlabeledtr=t.MmlMtr=void 0;var s=n(23),l=n(110),c=n(62),u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mtr"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i,o,s,l;try{for(var u=a(this.childNodes),d=u.next();!d.done;d=u.next()){(m=d.value).isKind("mtd")||this.replaceChild(this.factory.create("mtd"),m).appendChild(m)}}catch(e){i={error:e}}finally{try{d&&!d.done&&(o=u.return)&&o.call(u)}finally{if(i)throw i.error}}var h=c.split(this.attributes.get("columnalign"));1===this.arity&&h.unshift(this.parent.attributes.get("side")),e=this.addInheritedAttributes(e,{rowalign:this.attributes.get("rowalign"),columnalign:"center"});try{for(var p=a(this.childNodes),f=p.next();!f.done;f=p.next()){var m=f.value;e.columnalign[1]=h.shift()||e.columnalign[1],m.setInheritedAttributes(e,t,n,r)}}catch(e){s={error:e}}finally{try{f&&!f.done&&(l=p.return)&&l.call(p)}finally{if(s)throw s.error}}},t.prototype.verifyChildren=function(t){var n,r;if(!this.parent||this.parent.isKind("mtable")){if(!t.fixMtables)try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){var s=o.value;if(!s.isKind("mtd"))this.replaceChild(this.factory.create("mtr"),s).mError("Children of "+this.kind+" must be mtd",t,!0)}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}e.prototype.verifyChildren.call(this,t)}else this.mError(this.kind+" can only be a child of an mtable",t,!0)},t.prototype.setTeXclass=function(e){var t,n;this.getPrevClass(e);try{for(var r=a(this.childNodes),i=r.next();!i.done;i=r.next()){i.value.setTeXclass(null)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return this},t.defaults=o(o({},s.AbstractMmlNode.defaults),{rowalign:l.INHERIT,columnalign:l.INHERIT,groupalign:l.INHERIT}),t}(s.AbstractMmlNode);t.MmlMtr=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mlabeledtr"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 1},enumerable:!1,configurable:!0}),t}(u);t.MmlMlabeledtr=d},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMtd=void 0;var a=n(23),s=n(110),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mtd"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.verifyChildren=function(t){!this.parent||this.parent.isKind("mtr")?e.prototype.verifyChildren.call(this,t):this.mError(this.kind+" can only be a child of an mtr or mlabeledtr",t,!0)},t.prototype.setTeXclass=function(e){return this.getPrevClass(e),this.childNodes[0].setTeXclass(null),this},t.defaults=o(o({},a.AbstractMmlBaseNode.defaults),{rowspan:1,columnspan:1,rowalign:s.INHERIT,columnalign:s.INHERIT,groupalign:s.INHERIT}),t}(a.AbstractMmlBaseNode);t.MmlMtd=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMactionMixin=t.TooltipData=void 0;var s=n(62);t.TooltipData={dx:".2em",dy:".1em",postDelay:600,clearDelay:100,hoverTimer:new Map,clearTimer:new Map,stopTimers:function(e,t){t.clearTimer.has(e)&&(clearTimeout(t.clearTimer.get(e)),t.clearTimer.delete(e)),t.hoverTimer.has(e)&&(clearTimeout(t.hoverTimer.get(e)),t.hoverTimer.delete(e))}},t.CommonMactionMixin=function(e){return function(e){function n(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this,i=r.constructor.actions,s=r.node.attributes.get("actiontype"),l=o(i.get(s)||[function(e,t){},{}],2),c=l[0],u=l[1];return r.action=c,r.data=u,r.getParameters(),r}return i(n,e),Object.defineProperty(n.prototype,"selected",{get:function(){var e=this.node.attributes.get("selection"),t=Math.max(1,Math.min(this.childNodes.length,e))-1;return this.childNodes[t]||this.wrap(this.node.selected)},enumerable:!1,configurable:!0}),n.prototype.getParameters=function(){var e=this.node.attributes.get("data-offsets"),n=o(s.split(e||""),2),r=n[0],i=n[1];this.dx=this.length2em(r||t.TooltipData.dx),this.dy=this.length2em(i||t.TooltipData.dy)},n.prototype.computeBBox=function(e,t){void 0===t&&(t=!1),e.updateFrom(this.selected.getBBox()),this.selected.setChildPWidths(t)},n}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMaction=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"maction"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"selected",{get:function(){var e=this.attributes.get("selection"),t=Math.max(1,Math.min(this.childNodes.length,e))-1;return this.childNodes[t]||this.factory.create("mrow")},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isEmbellished",{get:function(){return this.selected.isEmbellished},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return this.selected.isSpacelike},enumerable:!1,configurable:!0}),t.prototype.core=function(){return this.selected.core()},t.prototype.coreMO=function(){return this.selected.coreMO()},t.prototype.verifyAttributes=function(t){(e.prototype.verifyAttributes.call(this,t),"toggle"!==this.attributes.get("actiontype")&&void 0!==this.attributes.getExplicit("selection"))&&delete this.attributes.getAllAttributes().selection},t.prototype.setTeXclass=function(e){"tooltip"===this.attributes.get("actiontype")&&this.childNodes[1]&&this.childNodes[1].setTeXclass(null);var t=this.selected;return e=t.setTeXclass(e),this.updateTeXclass(t),e},t.prototype.nextToggleSelection=function(){var e=Math.max(1,this.attributes.get("selection")+1);e>this.childNodes.length&&(e=1),this.attributes.set("selection",e)},t.defaults=o(o({},a.AbstractMmlNode.defaults),{actiontype:"toggle",selection:1}),t}(a.AbstractMmlNode);t.MmlMaction=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMglyph=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mglyph"},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlTokenNode.defaults),{alt:"",src:"",width:"auto",height:"auto",valign:"0em"}),t}(a.AbstractMmlTokenNode);t.MmlMglyph=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlAnnotation=t.MmlAnnotationXML=t.MmlSemantics=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"semantics"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"notParent",{get:function(){return!0},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlBaseNode.defaults),{definitionUrl:null,encoding:null}),t}(a.AbstractMmlBaseNode);t.MmlSemantics=s;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"annotation-xml"},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(){},t.defaults=o(o({},a.AbstractMmlNode.defaults),{definitionUrl:null,encoding:null,cd:"mathmlkeys",name:"",src:null}),t}(a.AbstractMmlNode);t.MmlAnnotationXML=l;var c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.properties={isChars:!0},t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"annotation"},enumerable:!1,configurable:!0}),t.defaults=o({},l.defaults),t}(l);t.MmlAnnotation=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.TeXAtom=void 0;var a=n(23),s=n(134),l=function(e){function t(t,n,r){var i=e.call(this,t,n,r)||this;return i.texclass=a.TEXCLASS.ORD,i.setProperty("texClass",i.texClass),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"TeXAtom"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"notParent",{get:function(){return this.childNodes[0]&&1===this.childNodes[0].childNodes.length},enumerable:!1,configurable:!0}),t.prototype.setTeXclass=function(e){return this.childNodes[0].setTeXclass(null),this.adjustTeXclass(e)},t.prototype.adjustTeXclass=function(e){return e},t.defaults=o({},a.AbstractMmlBaseNode.defaults),t}(a.AbstractMmlBaseNode);t.TeXAtom=l,l.prototype.adjustTeXclass=s.MmlMo.prototype.adjustTeXclass},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Usage=void 0;var r=function(){function e(){this.used=new Set,this.needsUpdate=[]}return e.prototype.add=function(e){this.used.has(e)||this.needsUpdate.push(e),this.used.add(e)},e.prototype.has=function(e){return this.used.has(e)},e.prototype.clear=function(){this.used.clear(),this.needsUpdate=[]},e.prototype.update=function(){var e=this.needsUpdate;return this.needsUpdate=[],e},e}();t.Usage=r},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractMathDocument=t.resetAllOptions=t.resetOptions=t.RenderList=void 0;var l=n(47),c=n(416),u=n(420),d=n(451),h=n(109),p=n(937),f=n(946),m=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.create=function(e){var t,n,r=new this;try{for(var i=o(Object.keys(e)),s=i.next();!s.done;s=i.next()){var l=s.value,c=a(this.action(l,e[l]),2),u=c[0],d=c[1];d&&r.add(u,d)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}return r},t.action=function(e,t){var n,r,i,o,s,l,c=!0,u=t[0];if(1===t.length||"boolean"==typeof t[1])2===t.length&&(c=t[1]),s=(n=a(this.methodActions(e),2))[0],l=n[1];else if("string"==typeof t[1])if("string"==typeof t[2]){4===t.length&&(c=t[3]);var d=a(t.slice(1),2),h=d[0],p=d[1];s=(r=a(this.methodActions(h,p),2))[0],l=r[1]}else 3===t.length&&(c=t[2]),s=(i=a(this.methodActions(t[1]),2))[0],l=i[1];else 4===t.length&&(c=t[3]),s=(o=a(t.slice(1),2))[0],l=o[1];return[{id:e,renderDoc:s,renderMath:l,convert:c},u]},t.methodActions=function(e,t){return void 0===t&&(t=e),[function(t){return e&&t[e](),!1},function(e,n){return t&&e[t](n),!1}]},t.prototype.renderDoc=function(e,t){var n,r;void 0===t&&(t=h.STATE.UNPROCESSED);try{for(var i=o(this.items),a=i.next();!a.done;a=i.next()){var s=a.value;if(s.priority>=t&&s.item.renderDoc(e))return}}catch(e){n={error:e}}finally{try{a&&!a.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}},t.prototype.renderMath=function(e,t,n){var r,i;void 0===n&&(n=h.STATE.UNPROCESSED);try{for(var a=o(this.items),s=a.next();!s.done;s=a.next()){var l=s.value;if(l.priority>=n&&l.item.renderMath(e,t))return}}catch(e){r={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(r)throw r.error}}},t.prototype.renderConvert=function(e,t,n){var r,i;void 0===n&&(n=h.STATE.LAST);try{for(var a=o(this.items),s=a.next();!s.done;s=a.next()){var l=s.value;if(l.priority>n)return;if(l.item.convert&&l.item.renderMath(e,t))return}}catch(e){r={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(r)throw r.error}}},t.prototype.findID=function(e){var t,n;try{for(var r=o(this.items),i=r.next();!i.done;i=r.next()){var a=i.value;if(a.item.id===e)return a.item}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return null},t}(n(108).PrioritizedList);t.RenderList=m,t.resetOptions={all:!1,processed:!1,inputJax:null,outputJax:null},t.resetAllOptions={all:!0,processed:!0,inputJax:[],outputJax:[]};var g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.compile=function(e){return null},t}(c.AbstractInputJax),v=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.typeset=function(e,t){return void 0===t&&(t=null),null},t.prototype.escaped=function(e,t){return null},t}(u.AbstractOutputJax),y=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t}(d.AbstractMathList),_=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t}(h.AbstractMathItem),b=function(){function e(t,n,r){var i=this,o=this.constructor;this.document=t,this.options=l.userOptions(l.defaultOptions({},o.OPTIONS),r),this.math=new(this.options.MathList||y),this.renderActions=m.create(this.options.renderActions),this.processed=new e.ProcessBits,this.outputJax=this.options.OutputJax||new v;var a=this.options.InputJax||[new g];Array.isArray(a)||(a=[a]),this.inputJax=a,this.adaptor=n,this.outputJax.setAdaptor(n),this.inputJax.map((function(e){return e.setAdaptor(n)})),this.mmlFactory=this.options.MmlFactory||new p.MmlFactory,this.inputJax.map((function(e){return e.setMmlFactory(i.mmlFactory)})),this.outputJax.initialize(),this.inputJax.map((function(e){return e.initialize()}))}return Object.defineProperty(e.prototype,"kind",{get:function(){return this.constructor.KIND},enumerable:!1,configurable:!0}),e.prototype.addRenderAction=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];var r=a(m.action(e,t),2),i=r[0],o=r[1];this.renderActions.add(i,o)},e.prototype.removeRenderAction=function(e){var t=this.renderActions.findID(e);t&&this.renderActions.remove(t)},e.prototype.render=function(){return this.renderActions.renderDoc(this),this},e.prototype.rerender=function(e){return void 0===e&&(e=h.STATE.RERENDER),this.state(e-1),this.render(),this},e.prototype.convert=function(e,t){void 0===t&&(t={});var n=l.userOptions({format:this.inputJax[0].name,display:!0,end:h.STATE.LAST,em:16,ex:8,containerWidth:null,lineWidth:1e6,scale:1,family:""},t),r=n.format,i=n.display,o=n.end,a=n.ex,s=n.em,c=n.containerWidth,u=n.lineWidth,d=n.scale,p=n.family;null===c&&(c=80*a);var f=this.inputJax.reduce((function(e,t){return t.name===r?t:e}),null),m=new this.options.MathItem(e,f,i);return m.start.node=this.adaptor.body(this.document),m.setMetrics(s,a,c,u,d),this.outputJax.options.mtextInheritFont&&(m.outputData.mtextFamily=p),this.outputJax.options.merrorInheritFont&&(m.outputData.merrorFamily=p),m.convert(this,o),m.typesetRoot||m.root},e.prototype.findMath=function(e){return void 0===e&&(e=null),this.processed.set("findMath"),this},e.prototype.compile=function(){var e,t,n,r;if(!this.processed.isSet("compile")){var i=[];try{for(var a=o(this.math),s=a.next();!s.done;s=a.next()){var l=s.value;this.compileMath(l),void 0!==l.inputData.recompile&&i.push(l)}}catch(t){e={error:t}}finally{try{s&&!s.done&&(t=a.return)&&t.call(a)}finally{if(e)throw e.error}}try{for(var c=o(i),u=c.next();!u.done;u=c.next()){var d=(l=u.value).inputData.recompile;l.state(d.state),l.inputData.recompile=d,this.compileMath(l)}}catch(e){n={error:e}}finally{try{u&&!u.done&&(r=c.return)&&r.call(c)}finally{if(n)throw n.error}}this.processed.set("compile")}return this},e.prototype.compileMath=function(e){try{e.compile(this)}catch(t){if(t.retry||t.restart)throw t;this.options.compileError(this,e,t),e.inputData.error=t}},e.prototype.compileError=function(e,t){e.root=this.mmlFactory.create("math",null,[this.mmlFactory.create("merror",{"data-mjx-error":t.message,title:t.message},[this.mmlFactory.create("mtext",null,[this.mmlFactory.create("text").setText("Math input error")])])]),e.display&&e.root.attributes.set("display","block"),e.inputData.error=t.message},e.prototype.typeset=function(){var e,t;if(!this.processed.isSet("typeset")){try{for(var n=o(this.math),r=n.next();!r.done;r=n.next()){var i=r.value;try{i.typeset(this)}catch(e){if(e.retry||e.restart)throw e;this.options.typesetError(this,i,e),i.outputData.error=e}}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}this.processed.set("typeset")}return this},e.prototype.typesetError=function(e,t){e.typesetRoot=this.adaptor.node("mjx-container",{class:"MathJax mjx-output-error",jax:this.outputJax.name},[this.adaptor.node("span",{"data-mjx-error":t.message,title:t.message,style:{color:"red","background-color":"yellow","line-height":"normal"}},[this.adaptor.text("Math output error")])]),e.display&&this.adaptor.setAttributes(e.typesetRoot,{style:{display:"block",margin:"1em 0","text-align":"center"}}),e.outputData.error=t.message},e.prototype.getMetrics=function(){return this.processed.isSet("getMetrics")||(this.outputJax.getMetrics(this),this.processed.set("getMetrics")),this},e.prototype.updateDocument=function(){var e,t;if(!this.processed.isSet("updateDocument")){try{for(var n=o(this.math.reversed()),r=n.next();!r.done;r=n.next()){r.value.updateDocument(this)}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}this.processed.set("updateDocument")}return this},e.prototype.removeFromDocument=function(e){return void 0===e&&(e=!1),this},e.prototype.state=function(e,t){var n,r;void 0===t&&(t=!1);try{for(var i=o(this.math),a=i.next();!a.done;a=i.next()){a.value.state(e,t)}}catch(e){n={error:e}}finally{try{a&&!a.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return e<h.STATE.INSERTED&&this.processed.clear("updateDocument"),e<h.STATE.TYPESET&&(this.processed.clear("typeset"),this.processed.clear("getMetrics")),e<h.STATE.COMPILED&&this.processed.clear("compile"),this},e.prototype.reset=function(e){var n;return void 0===e&&(e={processed:!0}),(e=l.userOptions(Object.assign({},t.resetOptions),e)).all&&Object.assign(e,t.resetAllOptions),e.processed&&this.processed.reset(),e.inputJax&&this.inputJax.forEach((function(t){return t.reset.apply(t,s([],a(e.inputJax)))})),e.outputJax&&(n=this.outputJax).reset.apply(n,s([],a(e.outputJax))),this},e.prototype.clear=function(){return this.reset(),this.math.clear(),this},e.prototype.concat=function(e){return this.math.merge(e),this},e.prototype.clearMathItemsWithin=function(e){var t,n=this.getMathItemsWithin(e);return(t=this.math).remove.apply(t,s([],a(n))),n},e.prototype.getMathItemsWithin=function(e){var t,n,r,i;Array.isArray(e)||(e=[e]);var a=this.adaptor,s=[],l=a.getElements(e,this.document);try{e:for(var c=o(this.math),u=c.next();!u.done;u=c.next()){var d=u.value;try{for(var h=(r=void 0,o(l)),p=h.next();!p.done;p=h.next()){var f=p.value;if(d.start.node&&a.contains(f,d.start.node)){s.push(d);continue e}}}catch(e){r={error:e}}finally{try{p&&!p.done&&(i=h.return)&&i.call(h)}finally{if(r)throw r.error}}}}catch(e){t={error:e}}finally{try{u&&!u.done&&(n=c.return)&&n.call(c)}finally{if(t)throw t.error}}return s},e.KIND="MathDocument",e.OPTIONS={OutputJax:null,InputJax:null,MmlFactory:null,MathList:y,MathItem:_,compileError:function(e,t,n){e.compileError(t,n)},typesetError:function(e,t,n){e.typesetError(t,n)},renderActions:l.expandable({find:[h.STATE.FINDMATH,"findMath","",!1],compile:[h.STATE.COMPILED],metrics:[h.STATE.METRICS,"getMetrics","",!1],typeset:[h.STATE.TYPESET],update:[h.STATE.INSERTED,"updateDocument",!1]})},e.ProcessBits=f.BitFieldClass("findMath","compile","getMetrics","typeset","updateDocument"),e}();t.AbstractMathDocument=b},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractMathList=void 0;var o=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.isBefore=function(e,t){return e.start.i<t.start.i||e.start.i===t.start.i&&e.start.n<t.start.n},t}(n(936).LinkedList);t.AbstractMathList=o},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.AmsConfiguration=t.AmsTags=void 0;var a=n(29),s=n(453),l=n(72),c=n(112);n(952);var u=n(28),d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(l.AbstractTags);t.AmsTags=d;t.AmsConfiguration=a.Configuration.create("ams",{handler:{delimiter:["AMSsymbols-delimiter","AMSmath-delimiter"],macro:["AMSsymbols-mathchar0mi","AMSsymbols-mathchar0mo","AMSsymbols-delimiter","AMSsymbols-macros","AMSmath-mathchar0mo","AMSmath-macros","AMSmath-delimiter"],environment:["AMSmath-environment"]},items:(i={},i[s.MultlineItem.prototype.kind]=s.MultlineItem,i[s.FlalignItem.prototype.kind]=s.FlalignItem,i),tags:{ams:d},init:function(e){new u.CommandMap(c.NEW_OPS,{},{}),e.append(a.Configuration.local({handler:{macro:[c.NEW_OPS]},priority:-1}))},config:function(e,t){t.parseOptions.options.multlineWidth&&(t.parseOptions.options.ams.multlineWidth=t.parseOptions.options.multlineWidth),delete t.parseOptions.options.multlineWidth},options:{multlineWidth:"",ams:{multlineWidth:"100%",multlineIndent:"1em"}}})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.FlalignItem=t.MultlineItem=void 0;var a=n(68),s=n(37),l=n(39),c=n(31),u=n(50),d=function(e){function t(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var i=e.call(this,t)||this;return i.factory.configuration.tags.start("multline",!0,n[0]),i}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"multline"},enumerable:!1,configurable:!0}),t.prototype.EndEntry=function(){this.table.length&&s.default.fixInitialMO(this.factory.configuration,this.nodes);var e=this.getProperty("shove"),t=this.create("node","mtd",this.nodes,e?{columnalign:e}:{});this.setProperty("shove",null),this.row.push(t),this.Clear()},t.prototype.EndRow=function(){if(1!==this.row.length)throw new c.default("MultlineRowsOneCol","The rows within the %1 environment must have exactly one column","multline");var e=this.create("node","mtr",this.row);this.table.push(e),this.row=[]},t.prototype.EndTable=function(){if(e.prototype.EndTable.call(this),this.table.length){var t=this.table.length-1,n=-1;l.default.getAttribute(l.default.getChildren(this.table[0])[0],"columnalign")||l.default.setAttribute(l.default.getChildren(this.table[0])[0],"columnalign",u.TexConstant.Align.LEFT),l.default.getAttribute(l.default.getChildren(this.table[t])[0],"columnalign")||l.default.setAttribute(l.default.getChildren(this.table[t])[0],"columnalign",u.TexConstant.Align.RIGHT);var r=this.factory.configuration.tags.getTag();if(r){n=this.arraydef.side===u.TexConstant.Align.LEFT?0:this.table.length-1;var i=this.table[n],o=this.create("node","mlabeledtr",[r].concat(l.default.getChildren(i)));l.default.copyAttributes(i,o),this.table[n]=o}}this.factory.configuration.tags.end()},t}(a.ArrayItem);t.MultlineItem=d;var h=function(e){function t(t,n,r,i,o){var a=e.call(this,t)||this;return a.name=n,a.numbered=r,a.padded=i,a.center=o,a.factory.configuration.tags.start(n,r,r),a}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"flalign"},enumerable:!1,configurable:!0}),t.prototype.EndEntry=function(){e.prototype.EndEntry.call(this);var t=this.getProperty("xalignat");if(t&&this.row.length>t)throw new c.default("XalignOverflow","Extra %1 in row of %2","&",this.name)},t.prototype.EndRow=function(){for(var t,n=this.row,r=this.getProperty("xalignat");n.length<r;)n.push(this.create("node","mtd"));for(this.row=[],this.padded&&this.row.push(this.create("node","mtd"));t=n.shift();)this.row.push(t),(t=n.shift())&&this.row.push(t),(n.length||this.padded)&&this.row.push(this.create("node","mtd"));this.row.length>this.maxrow&&(this.maxrow=this.row.length),e.prototype.EndRow.call(this);var i=this.table[this.table.length-1];if(this.getProperty("zeroWidthLabel")&&i.isKind("mlabeledtr")){var a=l.default.getChildren(i)[0],s=this.factory.configuration.options.tagSide,c=o({width:0},"right"===s?{lspace:"-1width"}:{}),u=this.create("node","mpadded",l.default.getChildren(a),c);a.setChildren([u])}},t.prototype.EndTable=function(){(e.prototype.EndTable.call(this),this.center)&&(this.maxrow<=2&&(delete this.arraydef.width,delete this.global.indentalign))},t}(a.EqnArrayItem);t.FlalignItem=h},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.EncloseConfiguration=t.EncloseMethods=t.ENCLOSE_OPTIONS=void 0;var r=n(29),i=n(28),o=n(37);t.ENCLOSE_OPTIONS={"data-arrowhead":1,color:1,mathcolor:1,background:1,mathbackground:1,"data-padding":1,"data-thickness":1},t.EncloseMethods={},t.EncloseMethods.Enclose=function(e,n){var r=e.GetArgument(n).replace(/,/g," "),i=e.GetBrackets(n,""),a=e.ParseArg(n),s=o.default.keyvalOptions(i,t.ENCLOSE_OPTIONS);s.notation=r,e.Push(e.create("node","menclose",[a],s))},new i.CommandMap("enclose",{enclose:"Enclose"},t.EncloseMethods),t.EncloseConfiguration=r.Configuration.create("enclose",{handler:{macro:["enclose"]}})},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.EmpheqUtil=void 0;var a=n(37),s=n(49);t.EmpheqUtil={environment:function(e,t,n,o){var a=o[0],s=e.itemFactory.create(a+"-begin").setProperties({name:t,end:a});e.Push(n.apply(void 0,i([e,s],r(o.slice(1)))))},splitOptions:function(e,t){return void 0===t&&(t=null),a.default.keyvalOptions(e,t,!0)},columnCount:function(e){var t,n,r=0;try{for(var i=o(e.childNodes),a=i.next();!a.done;a=i.next()){var s=a.value,l=s.childNodes.length-(s.isKind("mlabeledtr")?1:0);l>r&&(r=l)}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}return r},cellBlock:function(e,t,n,r){var i,a,l=n.create("node","mpadded",[],{height:0,depth:0,voffset:"-1height"}),c=new s.default(e,n.stack.env,n.configuration),u=c.mml();r&&c.configuration.tags.label&&(c.configuration.tags.currentTag.env=r,c.configuration.tags.getTag(!0));try{for(var d=o(u.isInferred?u.childNodes:[u]),h=d.next();!h.done;h=d.next()){var p=h.value;l.appendChild(p)}}catch(e){i={error:e}}finally{try{h&&!h.done&&(a=d.return)&&a.call(d)}finally{if(i)throw i.error}}return l.appendChild(n.create("node","mphantom",[n.create("node","mpadded",[t],{width:0})])),l},topRowTable:function(e,t){var n=a.default.copyNode(e,t);return n.setChildren(n.childNodes.slice(0,1)),n.attributes.set("align","baseline 1"),e.factory.create("mphantom",{},[t.create("node","mpadded",[n],{width:0})])},rowspanCell:function(e,t,n,r,i){e.appendChild(r.create("node","mpadded",[this.cellBlock(t,a.default.copyNode(n,r),r,i),this.topRowTable(n,r)],{height:0,depth:0,voffset:"height"}))},left:function(e,t,n,r,i){var a,s,l;void 0===i&&(i=""),e.attributes.set("columnalign","right "+(e.attributes.get("columnalign")||"")),e.attributes.set("columnspacing","0em "+(e.attributes.get("columnspacing")||""));try{for(var c=o(e.childNodes.slice(0).reverse()),u=c.next();!u.done;u=c.next()){var d=u.value;l=r.create("node","mtd"),d.childNodes.unshift(l),d.replaceChild(l,l),d.isKind("mlabeledtr")&&(d.childNodes[0]=d.childNodes[1],d.childNodes[1]=l)}}catch(e){a={error:e}}finally{try{u&&!u.done&&(s=c.return)&&s.call(c)}finally{if(a)throw a.error}}this.rowspanCell(l,n,t,r,i)},right:function(e,n,r,i,o){void 0===o&&(o=""),0===e.childNodes.length&&e.appendChild(i.create("node","mtr"));for(var a=t.EmpheqUtil.columnCount(e),s=e.childNodes[0];s.childNodes.length<a;)s.appendChild(i.create("node","mtd"));var l=s.appendChild(i.create("node","mtd"));t.EmpheqUtil.rowspanCell(l,r,n,i,o),e.attributes.set("columnalign",(e.attributes.get("columnalign")||"").split(/ /).slice(0,a).join(" ")+" left"),e.attributes.set("columnspacing",(e.attributes.get("columnspacing")||"").split(/ /).slice(0,a-1).join(" ")+" 0em")},adjustTable:function(e,t){var n=e.getProperty("left"),r=e.getProperty("right");if(n||r){var i=e.Last,o=a.default.copyNode(i,t);n&&this.left(i,o,n,t),r&&this.right(i,o,r,t)}},allowEnv:{equation:!0,align:!0,gather:!0,flalign:!0,alignat:!0,multline:!0},checkEnv:function(e){return this.allowEnv.hasOwnProperty(e.replace(/\*$/,""))||!1}}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.BeginEnvItem=void 0;var o=n(31),a=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"beginEnv"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){if(t.isKind("end")){if(t.getName()!==this.getName())throw new o.default("EnvBadEnd","\\begin{%1} ended with \\end{%2}",this.getName(),t.getName());return[[this.factory.create("mml",this.toMml())],!0]}if(t.isKind("stop"))throw new o.default("EnvMissingEnd","Missing \\end{%1}",this.getName());return e.prototype.checkItem.call(this,t)},t}(n(95).BaseItem);t.BeginEnvItem=a},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.NewcommandConfiguration=void 0;var i=n(29),o=n(456),a=n(137);n(978);var s=n(73),l=n(28);t.NewcommandConfiguration=i.Configuration.create("newcommand",{handler:{macro:["Newcommand-macros"]},items:(r={},r[o.BeginEnvItem.prototype.kind]=o.BeginEnvItem,r),options:{maxMacros:1e3},init:function(e){new l.DelimiterMap(a.default.NEW_DELIMITER,s.default.delimiter,{}),new l.CommandMap(a.default.NEW_COMMAND,{},{}),new l.EnvironmentMap(a.default.NEW_ENVIRONMENT,s.default.environment,{},{}),e.append(i.Configuration.local({handler:{character:[],delimiter:[a.default.NEW_DELIMITER],macro:[a.default.NEW_DELIMITER,a.default.NEW_COMMAND],environment:[a.default.NEW_ENVIRONMENT]},priority:-1}))}})},function(e,t,n){"use strict";var r,i=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MathtoolsConfiguration=t.fixPrescripts=t.PAIREDDELIMS=void 0;var o=n(29),a=n(28),s=n(39),l=n(47);n(982);var c=n(460),u=n(983),d=n(984);function h(e){var t,n,r,o,a,l,c=e.data;try{for(var u=i(c.getList("mmultiscripts")),d=u.next();!d.done;d=u.next()){var h=d.value;if(h.getProperty("fixPrescript")){var p=s.default.getChildren(h),f=0;try{for(var m=(r=void 0,i([1,2])),g=m.next();!g.done;g=m.next()){p[_=g.value]||(s.default.setChild(h,_,c.nodeFactory.create("node","none")),f++)}}catch(e){r={error:e}}finally{try{g&&!g.done&&(o=m.return)&&o.call(m)}finally{if(r)throw r.error}}try{for(var v=(a=void 0,i([4,5])),y=v.next();!y.done;y=v.next()){var _=y.value;s.default.isType(p[_],"mrow")&&0===s.default.getChildren(p[_]).length&&s.default.setChild(h,_,c.nodeFactory.create("node","none"))}}catch(e){a={error:e}}finally{try{y&&!y.done&&(l=v.return)&&l.call(v)}finally{if(a)throw a.error}}2===f&&p.splice(1,2)}}}catch(e){t={error:e}}finally{try{d&&!d.done&&(n=u.return)&&n.call(u)}finally{if(t)throw t.error}}}t.PAIREDDELIMS="mathtools-paired-delims",t.fixPrescripts=h,t.MathtoolsConfiguration=o.Configuration.create("mathtools",{handler:{macro:["mathtools-macros","mathtools-delimiters"],environment:["mathtools-environments"],delimiter:["mathtools-delimiters"],character:["mathtools-characters"]},items:(r={},r[d.MultlinedItem.prototype.kind]=d.MultlinedItem,r),init:function(e){new a.CommandMap(t.PAIREDDELIMS,{},{}),e.append(o.Configuration.local({handler:{macro:[t.PAIREDDELIMS]},priority:-5}))},config:function(e,t){var n,r,o=t.parseOptions,a=o.options.mathtools.pairedDelimiters;try{for(var s=i(Object.keys(a)),l=s.next();!l.done;l=s.next()){var d=l.value;c.MathtoolsUtil.addPairedDelims(o,d,a[d])}}catch(e){n={error:e}}finally{try{l&&!l.done&&(r=s.return)&&r.call(s)}finally{if(n)throw n.error}}u.MathtoolsTagFormat(e,t)},postprocessors:[[h,-6]],options:{mathtools:{multlinegap:"1em","multlined-pos":"c","firstline-afterskip":"","lastline-preskip":"","smallmatrix-align":"c",shortvdotsadjustabove:".2em",shortvdotsadjustbelow:".2em",centercolon:!1,"centercolon-offset":".04em","thincolon-dx":"-.04em","thincolon-dw":"-.08em","use-unicode":!1,"prescript-sub-format":"","prescript-sup-format":"","prescript-arg-format":"","allow-mathtoolsset":!0,pairedDelimiters:l.expandable({}),tagforms:l.expandable({})}}})},function(e,t,n){"use strict";var r=this&&this.__assign||function(){return(r=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.MathtoolsMethods=void 0;var a=n(37),s=n(112),l=n(57),c=n(49),u=n(31),d=n(39),h=n(23),p=n(58),f=n(47),m=n(137),g=n(190),v=n(460);t.MathtoolsMethods={MtMatrix:function(e,n,r,i){var o=e.GetBrackets("\\begin{"+n.getName()+"}","c");return t.MathtoolsMethods.Array(e,n,r,i,o)},MtSmallMatrix:function(e,n,r,i,o){return o||(o=e.GetBrackets("\\begin{"+n.getName()+"}",e.options.mathtools["smallmatrix-align"])),t.MathtoolsMethods.Array(e,n,r,i,o,a.default.Em(1/3),".2em","S",1)},MtMultlined:function(e,t){var n,r="\\begin{"+t.getName()+"}",o=e.GetBrackets(r,e.options.mathtools["multlined-pos"]||"c"),s=o?e.GetBrackets(r,""):"";o&&!o.match(/^[cbt]$/)&&(s=(n=i([o,s],2))[0],o=n[1]),e.Push(t);var l=e.itemFactory.create("multlined",e,t);return l.arraydef={displaystyle:!0,rowspacing:".5em",width:s||"auto",columnwidth:"100%"},a.default.setArrayAlign(l,o||"c")},HandleShove:function(e,t,n){var r=e.stack.Top();if("multline"!==r.kind&&"multlined"!==r.kind)throw new u.default("CommandInMultlined","%1 can only appear within the multline or multlined environments",t);if(r.Size())throw new u.default("CommandAtTheBeginingOfLine","%1 must come at the beginning of the line",t);r.setProperty("shove",n);var i=e.GetBrackets(t),o=e.ParseArg(t);if(i){var a=e.create("node","mrow",[]),s=e.create("node","mspace",[],{width:i});"left"===n?(a.appendChild(s),a.appendChild(o)):(a.appendChild(o),a.appendChild(s)),o=a}e.Push(o)},SpreadLines:function(e,t){var n,r;if(e.stack.env.closing===t.getName()){delete e.stack.env.closing;var i=e.stack.Pop(),a=i.toMml(),s=i.getProperty("spread");if(a.isInferred)try{for(var l=o(d.default.getChildren(a)),c=l.next();!c.done;c=l.next()){var u=c.value;v.MathtoolsUtil.spreadLines(u,s)}}catch(e){n={error:e}}finally{try{c&&!c.done&&(r=l.return)&&r.call(l)}finally{if(n)throw n.error}}else v.MathtoolsUtil.spreadLines(a,s);e.Push(a)}else{s=e.GetDimen("\\begin{"+t.getName()+"}");t.setProperty("spread",s),e.Push(t)}},Cases:function(e,t,n,r,i){var o=e.itemFactory.create("array").setProperty("casesEnv",t.getName());return o.arraydef={rowspacing:".2em",columnspacing:"1em",columnalign:"left"},"D"===i&&(o.arraydef.displaystyle=!0),o.setProperties({open:n,close:r}),e.Push(t),o},MathLap:function(e,t,n,i){var o=e.GetBrackets(t,"").trim(),a=e.create("node","mstyle",[e.create("node","mpadded",[e.ParseArg(t)],r({width:0},"r"===n?{}:{lspace:"l"===n?"-1width":"-.5width"}))],{"data-cramped":i});v.MathtoolsUtil.setDisplayLevel(a,o),e.Push(e.create("node","TeXAtom",[a]))},Cramped:function(e,t){var n=e.GetBrackets(t,"").trim(),r=e.ParseArg(t),i=e.create("node","mstyle",[r],{"data-cramped":!0});v.MathtoolsUtil.setDisplayLevel(i,n),e.Push(i)},MtLap:function(e,t,n){var r=a.default.internalMath(e,e.GetArgument(t),0),i=e.create("node","mpadded",r,{width:0});"r"!==n&&d.default.setAttribute(i,"lspace","l"===n?"-1width":"-.5width"),e.Push(i)},MathMakeBox:function(e,t){var n=e.GetBrackets(t),r=e.GetBrackets(t,"c"),i=e.create("node","mpadded",[e.ParseArg(t)]);n&&d.default.setAttribute(i,"width",n);var o=f.lookup(r,{c:"center",r:"right"},"");o&&d.default.setAttribute(i,"data-align",o),e.Push(i)},MathMBox:function(e,t){e.Push(e.create("node","mrow",[e.ParseArg(t)]))},UnderOverBracket:function(e,t){var n,r=p.length2em(e.GetBrackets(t,".1em"),.1),o=e.GetBrackets(t,".2em"),s=e.GetArgument(t),l=i("o"===t.charAt(1)?["over","accent","bottom","height"]:["under","accentunder","top","depth"],4),u=l[0],h=l[1],f=l[2],m=l[3],g=p.em(r),v=p.em(2*r),y=new c.default(s,e.stack.env,e.configuration).mml(),_=new c.default(s,e.stack.env,e.configuration).mml(),b=e.create("node","mpadded",[e.create("node","mpadded",[e.create("node","mphantom",[_])],{style:"border: "+g+" solid; border-"+f+": none",width:"-"+v,height:o,depth:0})],((n={width:"+"+v})[m]="+"+g,n)),M=a.default.underOver(e,y,b,u,!0),w=d.default.getChildAt(d.default.getChildAt(M,0),0);d.default.setAttribute(w,h,!0),e.Push(M)},Aboxed:function(e,t){var n=v.MathtoolsUtil.checkAlignment(e,t);n.row.length%2==1&&n.row.push(e.create("node","mtd",[]));var r=e.GetArgument(t),i=e.string.substr(e.i);e.string=r+"&&\\endAboxed",e.i=0;var o=e.GetUpTo(t,"&"),s=e.GetUpTo(t,"&");e.GetUpTo(t,"\\endAboxed");var l=a.default.substituteArgs(e,[o,s],"\\rlap{\\boxed{#1{}#2}}\\kern.267em\\phantom{#1}&\\phantom{{}#2}\\kern.267em");e.string=l+i,e.i=0},ArrowBetweenLines:function(e,t){var n=v.MathtoolsUtil.checkAlignment(e,t);if(n.Size()||n.row.length)throw new u.default("BetweenLines","%1 must be on a row by itself",t);var r=e.GetStar(),i=e.GetBrackets(t,"\\Updownarrow");r&&(n.EndEntry(),n.EndEntry());var o=r?"\\quad"+i:i+"\\quad",a=new c.default(o,e.stack.env,e.configuration).mml();e.Push(a),n.EndEntry(),n.EndRow()},VDotsWithin:function(e,t){var n=e.stack.Top(),i=n.getProperty("flushspaceabove")===n.table.length,o="\\mmlToken{mi}{}"+e.GetArgument(t)+"\\mmlToken{mi}{}",a=new c.default(o,e.stack.env,e.configuration).mml(),s=e.create("node","mpadded",[e.create("node","mpadded",[e.create("node","mo",[e.create("text","⋮")])],r({width:0,lspace:"-.5width"},i?{height:"-.6em",voffset:"-.18em"}:{})),e.create("node","mphantom",[a])],{lspace:".5width"});e.Push(s)},ShortVDotsWithin:function(e,n){var r=e.stack.Top(),i=e.GetStar();t.MathtoolsMethods.FlushSpaceAbove(e,"\\MTFlushSpaceAbove"),!i&&r.EndEntry(),t.MathtoolsMethods.VDotsWithin(e,"\\vdotswithin"),i&&r.EndEntry(),t.MathtoolsMethods.FlushSpaceBelow(e,"\\MTFlushSpaceBelow")},FlushSpaceAbove:function(e,t){var n=v.MathtoolsUtil.checkAlignment(e,t);n.setProperty("flushspaceabove",n.table.length),n.addRowSpacing("-"+e.options.mathtools.shortvdotsadjustabove)},FlushSpaceBelow:function(e,t){var n=v.MathtoolsUtil.checkAlignment(e,t);n.Size()&&n.EndEntry(),n.EndRow(),n.addRowSpacing("-"+e.options.mathtools.shortvdotsadjustbelow)},PairedDelimiters:function(e,t,n,r,o,s,l,c){void 0===o&&(o="#1"),void 0===s&&(s=1),void 0===l&&(l=""),void 0===c&&(c="");var u=e.GetStar(),d=u?"":e.GetBrackets(t),h=i(u?["\\left","\\right"]:d?[d+"l",d+"r"]:["",""],2),p=h[0],f=h[1],m=u?"\\middle":d||"";if(s){for(var g=[],v=g.length;v<s;v++)g.push(e.GetArgument(t));o=a.default.substituteArgs(e,g,o)}o=o.replace(/\\delimsize/g,m),e.string=[l,p,n,o,f,r,c,e.string.substr(e.i)].reduce((function(t,n){return a.default.addArgs(e,t,n)}),""),e.i=0,a.default.checkMaxMacros(e)},DeclarePairedDelimiters:function(e,t){var n=m.default.GetCsNameArgument(e,t),r=e.GetArgument(t),i=e.GetArgument(t);v.MathtoolsUtil.addPairedDelims(e.configuration,n,[r,i])},DeclarePairedDelimitersX:function(e,t){var n=m.default.GetCsNameArgument(e,t),r=m.default.GetArgCount(e,t),i=e.GetArgument(t),o=e.GetArgument(t),a=e.GetArgument(t);v.MathtoolsUtil.addPairedDelims(e.configuration,n,[i,o,a,r])},DeclarePairedDelimitersXPP:function(e,t){var n=m.default.GetCsNameArgument(e,t),r=m.default.GetArgCount(e,t),i=e.GetArgument(t),o=e.GetArgument(t),a=e.GetArgument(t),s=e.GetArgument(t),l=e.GetArgument(t);v.MathtoolsUtil.addPairedDelims(e.configuration,n,[o,a,l,r,i,s])},CenterColon:function(e,t,n,i,o){void 0===i&&(i=!1),void 0===o&&(o=!1);var a=e.options.mathtools,s=e.create("token","mo",{},":");if(n&&(a.centercolon||i)){var l=a["centercolon-offset"];s=e.create("node","mpadded",[s],r({voffset:l,height:"+"+l,depth:"-"+l},o?{width:a["thincolon-dw"],lspace:a["thincolon-dx"]}:{}))}e.Push(s)},Relation:function(e,t,n,r){e.options.mathtools["use-unicode"]&&r?e.Push(e.create("token","mo",{texClass:h.TEXCLASS.REL},r)):(n="\\mathrel{"+n.replace(/:/g,"\\MTThinColon").replace(/-/g,"\\mathrel{-}")+"}",e.string=a.default.addArgs(e,n,e.string.substr(e.i)),e.i=0)},NArrow:function(e,t,n,r){e.Push(e.create("node","TeXAtom",[e.create("token","mtext",{},n),e.create("node","mpadded",[e.create("node","mpadded",[e.create("node","menclose",[e.create("node","mspace",[],{height:".2em",depth:0,width:".4em"})],{notation:"updiagonalstrike","data-thickness":".05em","data-padding":0})],{width:0,lspace:"-.5width",voffset:r}),e.create("node","mphantom",[e.create("token","mtext",{},n)])],{width:0,lspace:"-.5width"})],{texClass:h.TEXCLASS.REL}))},SplitFrac:function(e,t,n){var r=e.ParseArg(t),i=e.ParseArg(t);e.Push(e.create("node","mstyle",[e.create("node","mfrac",[e.create("node","mstyle",[r,e.create("token","mi"),e.create("token","mspace",{width:"1em"})],{scriptlevel:0}),e.create("node","mstyle",[e.create("token","mspace",{width:"1em"}),e.create("token","mi"),i],{scriptlevel:0})],{linethickness:0,numalign:"left",denomalign:"right"})],{displaystyle:n,scriptlevel:0}))},XMathStrut:function(e,t){var n=e.GetBrackets(t),r=e.GetArgument(t);r=v.MathtoolsUtil.plusOrMinus(t,r),n=v.MathtoolsUtil.plusOrMinus(t,n||r),e.Push(e.create("node","TeXAtom",[e.create("node","mpadded",[e.create("node","mphantom",[e.create("token","mo",{stretchy:!1},"(")])],{width:0,height:r+"height",depth:n+"depth"})],{texClass:h.TEXCLASS.ORD}))},Prescript:function(e,t){var n=v.MathtoolsUtil.getScript(e,t,"sup"),r=v.MathtoolsUtil.getScript(e,t,"sub"),i=v.MathtoolsUtil.getScript(e,t,"arg");if(d.default.isType(n,"none")&&d.default.isType(r,"none"))e.Push(i);else{var o=e.create("node","mmultiscripts",[i]);d.default.getChildren(o).push(null,null),d.default.appendChildren(o,[e.create("node","mprescripts"),r,n]),o.setProperty("fixPrescript",!0),e.Push(o)}},NewTagForm:function(e,t,n){void 0===n&&(n=!1);var r=e.tags;if(!("mtFormats"in r))throw new u.default("TagsNotMT","%1 can only be used with ams or mathtools tags",t);var i=e.GetArgument(t).trim();if(!i)throw new u.default("InvalidTagFormID","Tag form name can't be empty");var o=e.GetBrackets(t,""),a=e.GetArgument(t),s=e.GetArgument(t);if(!n&&r.mtFormats.has(i))throw new u.default("DuplicateTagForm","Duplicate tag form: %1",i);r.mtFormats.set(i,[a,s,o])},UseTagForm:function(e,t){var n=e.tags;if(!("mtFormats"in n))throw new u.default("TagsNotMT","%1 can only be used with ams or mathtools tags",t);var r=e.GetArgument(t).trim();if(r){if(!n.mtFormats.has(r))throw new u.default("UndefinedTagForm","Undefined tag form: %1",r);n.mtCurrent=n.mtFormats.get(r)}else n.mtCurrent=null},SetOptions:function(e,t){var n,r,i=e.options.mathtools;if(!i["allow-mathtoolsset"])throw new u.default("ForbiddenMathtoolsSet","%1 is disabled",t);var s={};Object.keys(i).forEach((function(e){"pariedDelimiters"!==e&&"tagforms"!==e&&"allow-mathtoolsset"!==e&&(s[e]=1)}));var l=e.GetArgument(t),c=a.default.keyvalOptions(l,s,!0);try{for(var d=o(Object.keys(c)),h=d.next();!h.done;h=d.next()){var p=h.value;i[p]=c[p]}}catch(e){n={error:e}}finally{try{h&&!h.done&&(r=d.return)&&r.call(d)}finally{if(n)throw n.error}}},Array:l.default.Array,Macro:l.default.Macro,xArrow:s.AmsMethods.xArrow,HandleRef:s.AmsMethods.HandleRef,AmsEqnArray:s.AmsMethods.AmsEqnArray,MacroWithTemplate:g.default.MacroWithTemplate}},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.MathtoolsUtil=void 0;var i=n(68),o=n(37),a=n(49),s=n(31),l=n(96),c=n(47),u=n(459),d=n(458);t.MathtoolsUtil={setDisplayLevel:function(e,t){if(t){var n=r(c.lookup(t,{"\\displaystyle":[!0,0],"\\textstyle":[!1,0],"\\scriptstyle":[!1,1],"\\scriptscriptstyle":[!1,2]},[null,null]),2),i=n[0],o=n[1];null!==i&&(e.attributes.set("displaystyle",i),e.attributes.set("scriptlevel",o))}},checkAlignment:function(e,t){var n=e.stack.Top();if(n.kind!==i.EqnArrayItem.prototype.kind)throw new s.default("NotInAlignment","%1 can only be used in aligment environments",t);return n},addPairedDelims:function(e,t,n){e.handlers.retrieve(d.PAIREDDELIMS).add(t,new l.Macro(t,u.MathtoolsMethods.PairedDelimiters,n))},spreadLines:function(e,t){if(e.isKind("mtable")){var n=e.attributes.get("rowspacing");if(n){var r=o.default.dimen2em(t);n=n.split(/ /).map((function(e){return o.default.Em(Math.max(0,o.default.dimen2em(e)+r))})).join(" ")}else n=t;e.attributes.set("rowspacing",n)}},plusOrMinus:function(e,t){if(!(t=t.trim()).match(/^[-+]?(?:\d+(?:\.\d*)?|\.\d+)$/))throw new s.default("NotANumber","Argument to %1 is not a number",e);return t.match(/^[-+]/)?t:"+"+t},getScript:function(e,t,n){var r=o.default.trimSpaces(e.GetArgument(t));if(""===r)return e.create("node","none");var i=e.options.mathtools["prescript-"+n+"-format"];return i&&(r=i+"{"+r+"}"),new a.default(r,e.stack.env,e.configuration).mml()}}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.TextParser=void 0;var l=n(49),c=n(31),u=n(37),d=n(23),h=n(39),p=n(68),f=function(e){function t(t,n,r,i){var o=e.call(this,t,n,r)||this;return o.level=i,o}return i(t,e),Object.defineProperty(t.prototype,"texParser",{get:function(){return this.configuration.packageData.get("textmacros").texParser},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"tags",{get:function(){return this.texParser.tags},enumerable:!1,configurable:!0}),t.prototype.mml=function(){return null!=this.level?this.create("node","mstyle",this.nodes,{displaystyle:!1,scriptlevel:this.level}):1===this.nodes.length?this.nodes[0]:this.create("node","mrow",this.nodes)},t.prototype.Parse=function(){this.text="",this.nodes=[],this.envStack=[],e.prototype.Parse.call(this)},t.prototype.saveText=function(){if(this.text){var e=this.stack.env.mathvariant,t=u.default.internalText(this,this.text,e?{mathvariant:e}:{});this.text="",this.Push(t)}},t.prototype.Push=function(t){if(this.text&&this.saveText(),t instanceof p.StopItem)return e.prototype.Push.call(this,t);t instanceof p.StyleItem?this.stack.env.mathcolor=this.stack.env.color:t instanceof d.AbstractMmlNode&&(this.addAttributes(t),this.nodes.push(t))},t.prototype.PushMath=function(e){var t,n,r=this.stack.env;try{for(var i=o(["mathsize","mathcolor"]),a=i.next();!a.done;a=i.next()){var s=a.value;r[s]&&!e.attributes.getExplicit(s)&&(e.isToken||e.isKind("mstyle")||(e=this.create("node","mstyle",[e])),h.default.setAttribute(e,s,r[s]))}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}e.isInferred&&(e=this.create("node","mrow",e.childNodes)),this.nodes.push(e)},t.prototype.addAttributes=function(e){var t,n,r=this.stack.env;if(e.isToken)try{for(var i=o(["mathsize","mathcolor","mathvariant"]),a=i.next();!a.done;a=i.next()){var s=a.value;r[s]&&!e.attributes.getExplicit(s)&&h.default.setAttribute(e,s,r[s])}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}},t.prototype.ParseTextArg=function(e,n){return new t(this.GetArgument(e),n=Object.assign(Object.assign({},this.stack.env),n),this.configuration).mml()},t.prototype.ParseArg=function(e){return new t(this.GetArgument(e),this.stack.env,this.configuration).mml()},t.prototype.Error=function(e,t){for(var n=[],r=2;r<arguments.length;r++)n[r-2]=arguments[r];throw new(c.default.bind.apply(c.default,s([void 0,e,t],a(n))))},t}(l.default);t.TextParser=f},function(e,t,n){"use strict";n.r(t),n.d(t,"IconContents",(function(){return r})),n.d(t,"IconNames",(function(){return i})),n.d(t,"IconSvgPaths16",(function(){return hy.a})),n.d(t,"IconSvgPaths20",(function(){return hy.b}));var r={};n.r(r),n.d(r,"ADD",(function(){return o})),n.d(r,"ADD_COLUMN_LEFT",(function(){return a})),n.d(r,"ADD_COLUMN_RIGHT",(function(){return s})),n.d(r,"ADD_ROW_BOTTOM",(function(){return l})),n.d(r,"ADD_ROW_TOP",(function(){return c})),n.d(r,"ADD_TO_ARTIFACT",(function(){return u})),n.d(r,"ADD_TO_FOLDER",(function(){return d})),n.d(r,"AIRPLANE",(function(){return h})),n.d(r,"ALIGN_CENTER",(function(){return p})),n.d(r,"ALIGN_JUSTIFY",(function(){return f})),n.d(r,"ALIGN_LEFT",(function(){return m})),n.d(r,"ALIGN_RIGHT",(function(){return g})),n.d(r,"ALIGNMENT_BOTTOM",(function(){return v})),n.d(r,"ALIGNMENT_HORIZONTAL_CENTER",(function(){return y})),n.d(r,"ALIGNMENT_LEFT",(function(){return _})),n.d(r,"ALIGNMENT_RIGHT",(function(){return b})),n.d(r,"ALIGNMENT_TOP",(function(){return M})),n.d(r,"ALIGNMENT_VERTICAL_CENTER",(function(){return w})),n.d(r,"ANNOTATION",(function(){return A})),n.d(r,"APPLICATION",(function(){return C})),n.d(r,"APPLICATIONS",(function(){return x})),n.d(r,"ARCHIVE",(function(){return E})),n.d(r,"ARROW_BOTTOM_LEFT",(function(){return L})),n.d(r,"ARROW_BOTTOM_RIGHT",(function(){return S})),n.d(r,"ARROW_DOWN",(function(){return T})),n.d(r,"ARROW_LEFT",(function(){return O})),n.d(r,"ARROW_RIGHT",(function(){return I})),n.d(r,"ARROW_TOP_LEFT",(function(){return k})),n.d(r,"ARROW_TOP_RIGHT",(function(){return D})),n.d(r,"ARROW_UP",(function(){return N})),n.d(r,"ARROWS_HORIZONTAL",(function(){return j})),n.d(r,"ARROWS_VERTICAL",(function(){return P})),n.d(r,"ASTERISK",(function(){return z})),n.d(r,"AUTOMATIC_UPDATES",(function(){return R})),n.d(r,"BADGE",(function(){return B})),n.d(r,"BAN_CIRCLE",(function(){return H})),n.d(r,"BANK_ACCOUNT",(function(){return F})),n.d(r,"BARCODE",(function(){return Y})),n.d(r,"BLANK",(function(){return V})),n.d(r,"BLOCKED_PERSON",(function(){return U})),n.d(r,"BOLD",(function(){return W})),n.d(r,"BOOK",(function(){return G})),n.d(r,"BOOKMARK",(function(){return q})),n.d(r,"BOX",(function(){return K})),n.d(r,"BRIEFCASE",(function(){return X})),n.d(r,"BRING_DATA",(function(){return J})),n.d(r,"BUILD",(function(){return Q})),n.d(r,"CALCULATOR",(function(){return Z})),n.d(r,"CALENDAR",(function(){return $})),n.d(r,"CAMERA",(function(){return ee})),n.d(r,"CARET_DOWN",(function(){return te})),n.d(r,"CARET_LEFT",(function(){return ne})),n.d(r,"CARET_RIGHT",(function(){return re})),n.d(r,"CARET_UP",(function(){return ie})),n.d(r,"CELL_TOWER",(function(){return oe})),n.d(r,"CHANGES",(function(){return ae})),n.d(r,"CHART",(function(){return se})),n.d(r,"CHAT",(function(){return le})),n.d(r,"CHEVRON_BACKWARD",(function(){return ce})),n.d(r,"CHEVRON_DOWN",(function(){return ue})),n.d(r,"CHEVRON_FORWARD",(function(){return de})),n.d(r,"CHEVRON_LEFT",(function(){return he})),n.d(r,"CHEVRON_RIGHT",(function(){return pe})),n.d(r,"CHEVRON_UP",(function(){return fe})),n.d(r,"CIRCLE",(function(){return me})),n.d(r,"CIRCLE_ARROW_DOWN",(function(){return ge})),n.d(r,"CIRCLE_ARROW_LEFT",(function(){return ve})),n.d(r,"CIRCLE_ARROW_RIGHT",(function(){return ye})),n.d(r,"CIRCLE_ARROW_UP",(function(){return _e})),n.d(r,"CITATION",(function(){return be})),n.d(r,"CLEAN",(function(){return Me})),n.d(r,"CLIPBOARD",(function(){return we})),n.d(r,"CLOUD",(function(){return Ae})),n.d(r,"CLOUD_DOWNLOAD",(function(){return Ce})),n.d(r,"CLOUD_UPLOAD",(function(){return xe})),n.d(r,"CODE",(function(){return Ee})),n.d(r,"CODE_BLOCK",(function(){return Le})),n.d(r,"COG",(function(){return Se})),n.d(r,"COLLAPSE_ALL",(function(){return Te})),n.d(r,"COLUMN_LAYOUT",(function(){return Oe})),n.d(r,"COMMENT",(function(){return Ie})),n.d(r,"COMPARISON",(function(){return ke})),n.d(r,"COMPASS",(function(){return De})),n.d(r,"COMPRESSED",(function(){return Ne})),n.d(r,"CONFIRM",(function(){return je})),n.d(r,"CONSOLE",(function(){return Pe})),n.d(r,"CONTRAST",(function(){return ze})),n.d(r,"CONTROL",(function(){return Re})),n.d(r,"CREDIT_CARD",(function(){return Be})),n.d(r,"CROSS",(function(){return He})),n.d(r,"CROWN",(function(){return Fe})),n.d(r,"CUBE",(function(){return Ye})),n.d(r,"CUBE_ADD",(function(){return Ve})),n.d(r,"CUBE_REMOVE",(function(){return Ue})),n.d(r,"CURVED_RANGE_CHART",(function(){return We})),n.d(r,"CUT",(function(){return Ge})),n.d(r,"DASHBOARD",(function(){return qe})),n.d(r,"DATA_LINEAGE",(function(){return Ke})),n.d(r,"DATABASE",(function(){return Xe})),n.d(r,"DELETE",(function(){return Je})),n.d(r,"DELTA",(function(){return Qe})),n.d(r,"DERIVE_COLUMN",(function(){return Ze})),n.d(r,"DESKTOP",(function(){return $e})),n.d(r,"DIAGNOSIS",(function(){return et})),n.d(r,"DIAGRAM_TREE",(function(){return tt})),n.d(r,"DIRECTION_LEFT",(function(){return nt})),n.d(r,"DIRECTION_RIGHT",(function(){return rt})),n.d(r,"DISABLE",(function(){return it})),n.d(r,"DOCUMENT",(function(){return ot})),n.d(r,"DOCUMENT_OPEN",(function(){return at})),n.d(r,"DOCUMENT_SHARE",(function(){return st})),n.d(r,"DOLLAR",(function(){return lt})),n.d(r,"DOT",(function(){return ct})),n.d(r,"DOUBLE_CARET_HORIZONTAL",(function(){return ut})),n.d(r,"DOUBLE_CARET_VERTICAL",(function(){return dt})),n.d(r,"DOUBLE_CHEVRON_DOWN",(function(){return ht})),n.d(r,"DOUBLE_CHEVRON_LEFT",(function(){return pt})),n.d(r,"DOUBLE_CHEVRON_RIGHT",(function(){return ft})),n.d(r,"DOUBLE_CHEVRON_UP",(function(){return mt})),n.d(r,"DOUGHNUT_CHART",(function(){return gt})),n.d(r,"DOWNLOAD",(function(){return vt})),n.d(r,"DRAG_HANDLE_HORIZONTAL",(function(){return yt})),n.d(r,"DRAG_HANDLE_VERTICAL",(function(){return _t})),n.d(r,"DRAW",(function(){return bt})),n.d(r,"DRIVE_TIME",(function(){return Mt})),n.d(r,"DUPLICATE",(function(){return wt})),n.d(r,"EDIT",(function(){return At})),n.d(r,"EJECT",(function(){return Ct})),n.d(r,"ENDORSED",(function(){return xt})),n.d(r,"ENVELOPE",(function(){return Et})),n.d(r,"EQUALS",(function(){return Lt})),n.d(r,"ERASER",(function(){return St})),n.d(r,"ERROR",(function(){return Tt})),n.d(r,"EURO",(function(){return Ot})),n.d(r,"EXCHANGE",(function(){return It})),n.d(r,"EXCLUDE_ROW",(function(){return kt})),n.d(r,"EXPAND_ALL",(function(){return Dt})),n.d(r,"EXPORT",(function(){return Nt})),n.d(r,"EYE_OFF",(function(){return jt})),n.d(r,"EYE_ON",(function(){return Pt})),n.d(r,"EYE_OPEN",(function(){return zt})),n.d(r,"FAST_BACKWARD",(function(){return Rt})),n.d(r,"FAST_FORWARD",(function(){return Bt})),n.d(r,"FEED",(function(){return Ht})),n.d(r,"FEED_SUBSCRIBED",(function(){return Ft})),n.d(r,"FILM",(function(){return Yt})),n.d(r,"FILTER",(function(){return Vt})),n.d(r,"FILTER_KEEP",(function(){return Ut})),n.d(r,"FILTER_LIST",(function(){return Wt})),n.d(r,"FILTER_OPEN",(function(){return Gt})),n.d(r,"FILTER_REMOVE",(function(){return qt})),n.d(r,"FLAG",(function(){return Kt})),n.d(r,"FLAME",(function(){return Xt})),n.d(r,"FLASH",(function(){return Jt})),n.d(r,"FLOPPY_DISK",(function(){return Qt})),n.d(r,"FLOW_BRANCH",(function(){return Zt})),n.d(r,"FLOW_END",(function(){return $t})),n.d(r,"FLOW_LINEAR",(function(){return en})),n.d(r,"FLOW_REVIEW",(function(){return tn})),n.d(r,"FLOW_REVIEW_BRANCH",(function(){return nn})),n.d(r,"FLOWS",(function(){return rn})),n.d(r,"FOLDER_CLOSE",(function(){return on})),n.d(r,"FOLDER_NEW",(function(){return an})),n.d(r,"FOLDER_OPEN",(function(){return sn})),n.d(r,"FOLDER_SHARED",(function(){return ln})),n.d(r,"FOLDER_SHARED_OPEN",(function(){return cn})),n.d(r,"FOLLOWER",(function(){return un})),n.d(r,"FOLLOWING",(function(){return dn})),n.d(r,"FONT",(function(){return hn})),n.d(r,"FORK",(function(){return pn})),n.d(r,"FORM",(function(){return fn})),n.d(r,"FULL_CIRCLE",(function(){return mn})),n.d(r,"FULL_STACKED_CHART",(function(){return gn})),n.d(r,"FULLSCREEN",(function(){return vn})),n.d(r,"FUNCTION",(function(){return yn})),n.d(r,"GANTT_CHART",(function(){return _n})),n.d(r,"GEOLOCATION",(function(){return bn})),n.d(r,"GEOSEARCH",(function(){return Mn})),n.d(r,"GIT_BRANCH",(function(){return wn})),n.d(r,"GIT_COMMIT",(function(){return An})),n.d(r,"GIT_MERGE",(function(){return Cn})),n.d(r,"GIT_NEW_BRANCH",(function(){return xn})),n.d(r,"GIT_PULL",(function(){return En})),n.d(r,"GIT_PUSH",(function(){return Ln})),n.d(r,"GIT_REPO",(function(){return Sn})),n.d(r,"GLASS",(function(){return Tn})),n.d(r,"GLOBE",(function(){return On})),n.d(r,"GLOBE_NETWORK",(function(){return In})),n.d(r,"GRAPH",(function(){return kn})),n.d(r,"GRAPH_REMOVE",(function(){return Dn})),n.d(r,"GREATER_THAN",(function(){return Nn})),n.d(r,"GREATER_THAN_OR_EQUAL_TO",(function(){return jn})),n.d(r,"GRID",(function(){return Pn})),n.d(r,"GRID_VIEW",(function(){return zn})),n.d(r,"GROUP_OBJECTS",(function(){return Rn})),n.d(r,"GROUPED_BAR_CHART",(function(){return Bn})),n.d(r,"HAND",(function(){return Hn})),n.d(r,"HAND_DOWN",(function(){return Fn})),n.d(r,"HAND_LEFT",(function(){return Yn})),n.d(r,"HAND_RIGHT",(function(){return Vn})),n.d(r,"HAND_UP",(function(){return Un})),n.d(r,"HEADER",(function(){return Wn})),n.d(r,"HEADER_ONE",(function(){return Gn})),n.d(r,"HEADER_TWO",(function(){return qn})),n.d(r,"HEADSET",(function(){return Kn})),n.d(r,"HEART",(function(){return Xn})),n.d(r,"HEART_BROKEN",(function(){return Jn})),n.d(r,"HEAT_GRID",(function(){return Qn})),n.d(r,"HEATMAP",(function(){return Zn})),n.d(r,"HELP",(function(){return $n})),n.d(r,"HELPER_MANAGEMENT",(function(){return er})),n.d(r,"HIGHLIGHT",(function(){return tr})),n.d(r,"HISTORY",(function(){return nr})),n.d(r,"HOME",(function(){return rr})),n.d(r,"HORIZONTAL_BAR_CHART",(function(){return ir})),n.d(r,"HORIZONTAL_BAR_CHART_ASC",(function(){return or})),n.d(r,"HORIZONTAL_BAR_CHART_DESC",(function(){return ar})),n.d(r,"HORIZONTAL_DISTRIBUTION",(function(){return sr})),n.d(r,"ID_NUMBER",(function(){return lr})),n.d(r,"IMAGE_ROTATE_LEFT",(function(){return cr})),n.d(r,"IMAGE_ROTATE_RIGHT",(function(){return ur})),n.d(r,"IMPORT",(function(){return dr})),n.d(r,"INBOX",(function(){return hr})),n.d(r,"INBOX_FILTERED",(function(){return pr})),n.d(r,"INBOX_GEO",(function(){return fr})),n.d(r,"INBOX_SEARCH",(function(){return mr})),n.d(r,"INBOX_UPDATE",(function(){return gr})),n.d(r,"INFO_SIGN",(function(){return vr})),n.d(r,"INHERITANCE",(function(){return yr})),n.d(r,"INNER_JOIN",(function(){return _r})),n.d(r,"INSERT",(function(){return br})),n.d(r,"INTERSECTION",(function(){return Mr})),n.d(r,"IP_ADDRESS",(function(){return wr})),n.d(r,"ISSUE",(function(){return Ar})),n.d(r,"ISSUE_CLOSED",(function(){return Cr})),n.d(r,"ISSUE_NEW",(function(){return xr})),n.d(r,"ITALIC",(function(){return Er})),n.d(r,"JOIN_TABLE",(function(){return Lr})),n.d(r,"KEY",(function(){return Sr})),n.d(r,"KEY_BACKSPACE",(function(){return Tr})),n.d(r,"KEY_COMMAND",(function(){return Or})),n.d(r,"KEY_CONTROL",(function(){return Ir})),n.d(r,"KEY_DELETE",(function(){return kr})),n.d(r,"KEY_ENTER",(function(){return Dr})),n.d(r,"KEY_ESCAPE",(function(){return Nr})),n.d(r,"KEY_OPTION",(function(){return jr})),n.d(r,"KEY_SHIFT",(function(){return Pr})),n.d(r,"KEY_TAB",(function(){return zr})),n.d(r,"KNOWN_VEHICLE",(function(){return Rr})),n.d(r,"LAB_TEST",(function(){return Br})),n.d(r,"LABEL",(function(){return Hr})),n.d(r,"LAYER",(function(){return Fr})),n.d(r,"LAYERS",(function(){return Yr})),n.d(r,"LAYOUT",(function(){return Vr})),n.d(r,"LAYOUT_AUTO",(function(){return Ur})),n.d(r,"LAYOUT_BALLOON",(function(){return Wr})),n.d(r,"LAYOUT_CIRCLE",(function(){return Gr})),n.d(r,"LAYOUT_GRID",(function(){return qr})),n.d(r,"LAYOUT_GROUP_BY",(function(){return Kr})),n.d(r,"LAYOUT_HIERARCHY",(function(){return Xr})),n.d(r,"LAYOUT_LINEAR",(function(){return Jr})),n.d(r,"LAYOUT_SKEW_GRID",(function(){return Qr})),n.d(r,"LAYOUT_SORTED_CLUSTERS",(function(){return Zr})),n.d(r,"LEARNING",(function(){return $r})),n.d(r,"LEFT_JOIN",(function(){return ei})),n.d(r,"LESS_THAN",(function(){return ti})),n.d(r,"LESS_THAN_OR_EQUAL_TO",(function(){return ni})),n.d(r,"LIFESAVER",(function(){return ri})),n.d(r,"LIGHTBULB",(function(){return ii})),n.d(r,"LINK",(function(){return oi})),n.d(r,"LIST",(function(){return ai})),n.d(r,"LIST_COLUMNS",(function(){return si})),n.d(r,"LIST_DETAIL_VIEW",(function(){return li})),n.d(r,"LOCATE",(function(){return ci})),n.d(r,"LOCK",(function(){return ui})),n.d(r,"LOG_IN",(function(){return di})),n.d(r,"LOG_OUT",(function(){return hi})),n.d(r,"MANUAL",(function(){return pi})),n.d(r,"MANUALLY_ENTERED_DATA",(function(){return fi})),n.d(r,"MAP",(function(){return mi})),n.d(r,"MAP_CREATE",(function(){return gi})),n.d(r,"MAP_MARKER",(function(){return vi})),n.d(r,"MAXIMIZE",(function(){return yi})),n.d(r,"MEDIA",(function(){return _i})),n.d(r,"MENU",(function(){return bi})),n.d(r,"MENU_CLOSED",(function(){return Mi})),n.d(r,"MENU_OPEN",(function(){return wi})),n.d(r,"MERGE_COLUMNS",(function(){return Ai})),n.d(r,"MERGE_LINKS",(function(){return Ci})),n.d(r,"MINIMIZE",(function(){return xi})),n.d(r,"MINUS",(function(){return Ei})),n.d(r,"MOBILE_PHONE",(function(){return Li})),n.d(r,"MOBILE_VIDEO",(function(){return Si})),n.d(r,"MOON",(function(){return Ti})),n.d(r,"MORE",(function(){return Oi})),n.d(r,"MOUNTAIN",(function(){return Ii})),n.d(r,"MOVE",(function(){return ki})),n.d(r,"MUGSHOT",(function(){return Di})),n.d(r,"MULTI_SELECT",(function(){return Ni})),n.d(r,"MUSIC",(function(){return ji})),n.d(r,"NEW_DRAWING",(function(){return Pi})),n.d(r,"NEW_GRID_ITEM",(function(){return zi})),n.d(r,"NEW_LAYER",(function(){return Ri})),n.d(r,"NEW_LAYERS",(function(){return Bi})),n.d(r,"NEW_LINK",(function(){return Hi})),n.d(r,"NEW_OBJECT",(function(){return Fi})),n.d(r,"NEW_PERSON",(function(){return Yi})),n.d(r,"NEW_PRESCRIPTION",(function(){return Vi})),n.d(r,"NEW_TEXT_BOX",(function(){return Ui})),n.d(r,"NINJA",(function(){return Wi})),n.d(r,"NOT_EQUAL_TO",(function(){return Gi})),n.d(r,"NOTIFICATIONS",(function(){return qi})),n.d(r,"NOTIFICATIONS_UPDATED",(function(){return Ki})),n.d(r,"NUMBERED_LIST",(function(){return Xi})),n.d(r,"NUMERICAL",(function(){return Ji})),n.d(r,"OFFICE",(function(){return Qi})),n.d(r,"OFFLINE",(function(){return Zi})),n.d(r,"OIL_FIELD",(function(){return $i})),n.d(r,"ONE_COLUMN",(function(){return eo})),n.d(r,"OUTDATED",(function(){return to})),n.d(r,"PAGE_LAYOUT",(function(){return no})),n.d(r,"PANEL_STATS",(function(){return ro})),n.d(r,"PANEL_TABLE",(function(){return io})),n.d(r,"PAPERCLIP",(function(){return oo})),n.d(r,"PARAGRAPH",(function(){return ao})),n.d(r,"PATH",(function(){return so})),n.d(r,"PATH_SEARCH",(function(){return lo})),n.d(r,"PAUSE",(function(){return co})),n.d(r,"PEOPLE",(function(){return uo})),n.d(r,"PERCENTAGE",(function(){return ho})),n.d(r,"PERSON",(function(){return po})),n.d(r,"PHONE",(function(){return fo})),n.d(r,"PIE_CHART",(function(){return mo})),n.d(r,"PIN",(function(){return go})),n.d(r,"PIVOT",(function(){return vo})),n.d(r,"PIVOT_TABLE",(function(){return yo})),n.d(r,"PLAY",(function(){return _o})),n.d(r,"PLUS",(function(){return bo})),n.d(r,"POLYGON_FILTER",(function(){return Mo})),n.d(r,"POWER",(function(){return wo})),n.d(r,"PREDICTIVE_ANALYSIS",(function(){return Ao})),n.d(r,"PRESCRIPTION",(function(){return Co})),n.d(r,"PRESENTATION",(function(){return xo})),n.d(r,"PRINT",(function(){return Eo})),n.d(r,"PROJECTS",(function(){return Lo})),n.d(r,"PROPERTIES",(function(){return So})),n.d(r,"PROPERTY",(function(){return To})),n.d(r,"PUBLISH_FUNCTION",(function(){return Oo})),n.d(r,"PULSE",(function(){return Io})),n.d(r,"RANDOM",(function(){return ko})),n.d(r,"RECORD",(function(){return Do})),n.d(r,"REDO",(function(){return No})),n.d(r,"REFRESH",(function(){return jo})),n.d(r,"REGRESSION_CHART",(function(){return Po})),n.d(r,"REMOVE",(function(){return zo})),n.d(r,"REMOVE_COLUMN",(function(){return Ro})),n.d(r,"REMOVE_COLUMN_LEFT",(function(){return Bo})),n.d(r,"REMOVE_COLUMN_RIGHT",(function(){return Ho})),n.d(r,"REMOVE_ROW_BOTTOM",(function(){return Fo})),n.d(r,"REMOVE_ROW_TOP",(function(){return Yo})),n.d(r,"REPEAT",(function(){return Vo})),n.d(r,"RESET",(function(){return Uo})),n.d(r,"RESOLVE",(function(){return Wo})),n.d(r,"RIG",(function(){return Go})),n.d(r,"RIGHT_JOIN",(function(){return qo})),n.d(r,"RING",(function(){return Ko})),n.d(r,"ROTATE_DOCUMENT",(function(){return Xo})),n.d(r,"ROTATE_PAGE",(function(){return Jo})),n.d(r,"SATELLITE",(function(){return Qo})),n.d(r,"SAVED",(function(){return Zo})),n.d(r,"SCATTER_PLOT",(function(){return $o})),n.d(r,"SEARCH",(function(){return ea})),n.d(r,"SEARCH_AROUND",(function(){return ta})),n.d(r,"SEARCH_TEMPLATE",(function(){return na})),n.d(r,"SEARCH_TEXT",(function(){return ra})),n.d(r,"SEGMENTED_CONTROL",(function(){return ia})),n.d(r,"SELECT",(function(){return oa})),n.d(r,"SELECTION",(function(){return aa})),n.d(r,"SEND_TO",(function(){return sa})),n.d(r,"SEND_TO_GRAPH",(function(){return la})),n.d(r,"SEND_TO_MAP",(function(){return ca})),n.d(r,"SERIES_ADD",(function(){return ua})),n.d(r,"SERIES_CONFIGURATION",(function(){return da})),n.d(r,"SERIES_DERIVED",(function(){return ha})),n.d(r,"SERIES_FILTERED",(function(){return pa})),n.d(r,"SERIES_SEARCH",(function(){return fa})),n.d(r,"SETTINGS",(function(){return ma})),n.d(r,"SHARE",(function(){return ga})),n.d(r,"SHIELD",(function(){return va})),n.d(r,"SHOP",(function(){return ya})),n.d(r,"SHOPPING_CART",(function(){return _a})),n.d(r,"SIGNAL_SEARCH",(function(){return ba})),n.d(r,"SIM_CARD",(function(){return Ma})),n.d(r,"SLASH",(function(){return wa})),n.d(r,"SMALL_CROSS",(function(){return Aa})),n.d(r,"SMALL_MINUS",(function(){return Ca})),n.d(r,"SMALL_PLUS",(function(){return xa})),n.d(r,"SMALL_TICK",(function(){return Ea})),n.d(r,"SNOWFLAKE",(function(){return La})),n.d(r,"SOCIAL_MEDIA",(function(){return Sa})),n.d(r,"SORT",(function(){return Ta})),n.d(r,"SORT_ALPHABETICAL",(function(){return Oa})),n.d(r,"SORT_ALPHABETICAL_DESC",(function(){return Ia})),n.d(r,"SORT_ASC",(function(){return ka})),n.d(r,"SORT_DESC",(function(){return Da})),n.d(r,"SORT_NUMERICAL",(function(){return Na})),n.d(r,"SORT_NUMERICAL_DESC",(function(){return ja})),n.d(r,"SPLIT_COLUMNS",(function(){return Pa})),n.d(r,"SQUARE",(function(){return za})),n.d(r,"STACKED_CHART",(function(){return Ra})),n.d(r,"STAR",(function(){return Ba})),n.d(r,"STAR_EMPTY",(function(){return Ha})),n.d(r,"STEP_BACKWARD",(function(){return Fa})),n.d(r,"STEP_CHART",(function(){return Ya})),n.d(r,"STEP_FORWARD",(function(){return Va})),n.d(r,"STOP",(function(){return Ua})),n.d(r,"STOPWATCH",(function(){return Wa})),n.d(r,"STRIKETHROUGH",(function(){return Ga})),n.d(r,"STYLE",(function(){return qa})),n.d(r,"SWAP_HORIZONTAL",(function(){return Ka})),n.d(r,"SWAP_VERTICAL",(function(){return Xa})),n.d(r,"SYMBOL_CIRCLE",(function(){return Ja})),n.d(r,"SYMBOL_CROSS",(function(){return Qa})),n.d(r,"SYMBOL_DIAMOND",(function(){return Za})),n.d(r,"SYMBOL_SQUARE",(function(){return $a})),n.d(r,"SYMBOL_TRIANGLE_DOWN",(function(){return es})),n.d(r,"SYMBOL_TRIANGLE_UP",(function(){return ts})),n.d(r,"TAG",(function(){return ns})),n.d(r,"TAKE_ACTION",(function(){return rs})),n.d(r,"TAXI",(function(){return is})),n.d(r,"TEXT_HIGHLIGHT",(function(){return os})),n.d(r,"TH",(function(){return as})),n.d(r,"TH_DERIVED",(function(){return ss})),n.d(r,"TH_DISCONNECT",(function(){return ls})),n.d(r,"TH_FILTERED",(function(){return cs})),n.d(r,"TH_LIST",(function(){return us})),n.d(r,"THUMBS_DOWN",(function(){return ds})),n.d(r,"THUMBS_UP",(function(){return hs})),n.d(r,"TICK",(function(){return ps})),n.d(r,"TICK_CIRCLE",(function(){return fs})),n.d(r,"TIME",(function(){return ms})),n.d(r,"TIMELINE_AREA_CHART",(function(){return gs})),n.d(r,"TIMELINE_BAR_CHART",(function(){return vs})),n.d(r,"TIMELINE_EVENTS",(function(){return ys})),n.d(r,"TIMELINE_LINE_CHART",(function(){return _s})),n.d(r,"TINT",(function(){return bs})),n.d(r,"TORCH",(function(){return Ms})),n.d(r,"TRACTOR",(function(){return ws})),n.d(r,"TRAIN",(function(){return As})),n.d(r,"TRANSLATE",(function(){return Cs})),n.d(r,"TRASH",(function(){return xs})),n.d(r,"TREE",(function(){return Es})),n.d(r,"TRENDING_DOWN",(function(){return Ls})),n.d(r,"TRENDING_UP",(function(){return Ss})),n.d(r,"TRUCK",(function(){return Ts})),n.d(r,"TWO_COLUMNS",(function(){return Os})),n.d(r,"UNARCHIVE",(function(){return Is})),n.d(r,"UNDERLINE",(function(){return ks})),n.d(r,"UNDO",(function(){return Ds})),n.d(r,"UNGROUP_OBJECTS",(function(){return Ns})),n.d(r,"UNKNOWN_VEHICLE",(function(){return js})),n.d(r,"UNLOCK",(function(){return Ps})),n.d(r,"UNPIN",(function(){return zs})),n.d(r,"UNRESOLVE",(function(){return Rs})),n.d(r,"UPDATED",(function(){return Bs})),n.d(r,"UPLOAD",(function(){return Hs})),n.d(r,"USER",(function(){return Fs})),n.d(r,"VARIABLE",(function(){return Ys})),n.d(r,"VERTICAL_BAR_CHART_ASC",(function(){return Vs})),n.d(r,"VERTICAL_BAR_CHART_DESC",(function(){return Us})),n.d(r,"VERTICAL_DISTRIBUTION",(function(){return Ws})),n.d(r,"VIDEO",(function(){return Gs})),n.d(r,"VOLUME_DOWN",(function(){return qs})),n.d(r,"VOLUME_OFF",(function(){return Ks})),n.d(r,"VOLUME_UP",(function(){return Xs})),n.d(r,"WALK",(function(){return Js})),n.d(r,"WARNING_SIGN",(function(){return Qs})),n.d(r,"WATERFALL_CHART",(function(){return Zs})),n.d(r,"WIDGET",(function(){return $s})),n.d(r,"WIDGET_BUTTON",(function(){return el})),n.d(r,"WIDGET_FOOTER",(function(){return tl})),n.d(r,"WIDGET_HEADER",(function(){return nl})),n.d(r,"WRENCH",(function(){return rl})),n.d(r,"ZOOM_IN",(function(){return il})),n.d(r,"ZOOM_OUT",(function(){return ol})),n.d(r,"ZOOM_TO_FIT",(function(){return al}));var i={};n.r(i),n.d(i,"ADD",(function(){return sl})),n.d(i,"ADD_CLIP",(function(){return ll})),n.d(i,"ADD_COLUMN_LEFT",(function(){return cl})),n.d(i,"ADD_COLUMN_RIGHT",(function(){return ul})),n.d(i,"ADD_LOCATION",(function(){return dl})),n.d(i,"ADD_ROW_BOTTOM",(function(){return hl})),n.d(i,"ADD_ROW_TOP",(function(){return pl})),n.d(i,"ADD_TO_ARTIFACT",(function(){return fl})),n.d(i,"ADD_TO_FOLDER",(function(){return ml})),n.d(i,"AIRPLANE",(function(){return gl})),n.d(i,"ALIGN_CENTER",(function(){return vl})),n.d(i,"ALIGN_JUSTIFY",(function(){return yl})),n.d(i,"ALIGN_LEFT",(function(){return _l})),n.d(i,"ALIGN_RIGHT",(function(){return bl})),n.d(i,"ALIGNMENT_BOTTOM",(function(){return Ml})),n.d(i,"ALIGNMENT_HORIZONTAL_CENTER",(function(){return wl})),n.d(i,"ALIGNMENT_LEFT",(function(){return Al})),n.d(i,"ALIGNMENT_RIGHT",(function(){return Cl})),n.d(i,"ALIGNMENT_TOP",(function(){return xl})),n.d(i,"ALIGNMENT_VERTICAL_CENTER",(function(){return El})),n.d(i,"ANNOTATION",(function(){return Ll})),n.d(i,"ANTENNA",(function(){return Sl})),n.d(i,"APP_HEADER",(function(){return Tl})),n.d(i,"APPLICATION",(function(){return Ol})),n.d(i,"APPLICATIONS",(function(){return Il})),n.d(i,"ARCHIVE",(function(){return kl})),n.d(i,"AREA_OF_INTEREST",(function(){return Dl})),n.d(i,"ARRAY",(function(){return Nl})),n.d(i,"ARRAY_BOOLEAN",(function(){return jl})),n.d(i,"ARRAY_DATE",(function(){return Pl})),n.d(i,"ARRAY_NUMERIC",(function(){return zl})),n.d(i,"ARRAY_STRING",(function(){return Rl})),n.d(i,"ARRAY_TIMESTAMP",(function(){return Bl})),n.d(i,"ARROW_BOTTOM_LEFT",(function(){return Hl})),n.d(i,"ARROW_BOTTOM_RIGHT",(function(){return Fl})),n.d(i,"ARROW_DOWN",(function(){return Yl})),n.d(i,"ARROW_LEFT",(function(){return Vl})),n.d(i,"ARROW_RIGHT",(function(){return Ul})),n.d(i,"ARROW_TOP_LEFT",(function(){return Wl})),n.d(i,"ARROW_TOP_RIGHT",(function(){return Gl})),n.d(i,"ARROW_UP",(function(){return ql})),n.d(i,"ARROWS_HORIZONTAL",(function(){return Kl})),n.d(i,"ARROWS_VERTICAL",(function(){return Xl})),n.d(i,"ASTERISK",(function(){return Jl})),n.d(i,"AUTOMATIC_UPDATES",(function(){return Ql})),n.d(i,"BACKLINK",(function(){return Zl})),n.d(i,"BADGE",(function(){return $l})),n.d(i,"BAN_CIRCLE",(function(){return ec})),n.d(i,"BANK_ACCOUNT",(function(){return tc})),n.d(i,"BARCODE",(function(){return nc})),n.d(i,"BLANK",(function(){return rc})),n.d(i,"BLOCKED_PERSON",(function(){return ic})),n.d(i,"BOLD",(function(){return oc})),n.d(i,"BOOK",(function(){return ac})),n.d(i,"BOOKMARK",(function(){return sc})),n.d(i,"BOX",(function(){return lc})),n.d(i,"BRIEFCASE",(function(){return cc})),n.d(i,"BRING_DATA",(function(){return uc})),n.d(i,"BUGGY",(function(){return dc})),n.d(i,"BUILD",(function(){return hc})),n.d(i,"CALCULATOR",(function(){return pc})),n.d(i,"CALENDAR",(function(){return fc})),n.d(i,"CAMERA",(function(){return mc})),n.d(i,"CARET_DOWN",(function(){return gc})),n.d(i,"CARET_LEFT",(function(){return vc})),n.d(i,"CARET_RIGHT",(function(){return yc})),n.d(i,"CARET_UP",(function(){return _c})),n.d(i,"CARGO_SHIP",(function(){return bc})),n.d(i,"CELL_TOWER",(function(){return Mc})),n.d(i,"CHANGES",(function(){return wc})),n.d(i,"CHART",(function(){return Ac})),n.d(i,"CHAT",(function(){return Cc})),n.d(i,"CHEVRON_BACKWARD",(function(){return xc})),n.d(i,"CHEVRON_DOWN",(function(){return Ec})),n.d(i,"CHEVRON_FORWARD",(function(){return Lc})),n.d(i,"CHEVRON_LEFT",(function(){return Sc})),n.d(i,"CHEVRON_RIGHT",(function(){return Tc})),n.d(i,"CHEVRON_UP",(function(){return Oc})),n.d(i,"CIRCLE",(function(){return Ic})),n.d(i,"CIRCLE_ARROW_DOWN",(function(){return kc})),n.d(i,"CIRCLE_ARROW_LEFT",(function(){return Dc})),n.d(i,"CIRCLE_ARROW_RIGHT",(function(){return Nc})),n.d(i,"CIRCLE_ARROW_UP",(function(){return jc})),n.d(i,"CITATION",(function(){return Pc})),n.d(i,"CLEAN",(function(){return zc})),n.d(i,"CLIP",(function(){return Rc})),n.d(i,"CLIPBOARD",(function(){return Bc})),n.d(i,"CLOUD",(function(){return Hc})),n.d(i,"CLOUD_DOWNLOAD",(function(){return Fc})),n.d(i,"CLOUD_UPLOAD",(function(){return Yc})),n.d(i,"CODE",(function(){return Vc})),n.d(i,"CODE_BLOCK",(function(){return Uc})),n.d(i,"COG",(function(){return Wc})),n.d(i,"COLLAPSE_ALL",(function(){return Gc})),n.d(i,"COLUMN_LAYOUT",(function(){return qc})),n.d(i,"COMMENT",(function(){return Kc})),n.d(i,"COMPARISON",(function(){return Xc})),n.d(i,"COMPASS",(function(){return Jc})),n.d(i,"COMPRESSED",(function(){return Qc})),n.d(i,"CONFIRM",(function(){return Zc})),n.d(i,"CONSOLE",(function(){return $c})),n.d(i,"CONTRAST",(function(){return eu})),n.d(i,"CONTROL",(function(){return tu})),n.d(i,"CREDIT_CARD",(function(){return nu})),n.d(i,"CROSS",(function(){return ru})),n.d(i,"CROWN",(function(){return iu})),n.d(i,"CUBE",(function(){return ou})),n.d(i,"CUBE_ADD",(function(){return au})),n.d(i,"CUBE_REMOVE",(function(){return su})),n.d(i,"CURVED_RANGE_CHART",(function(){return lu})),n.d(i,"CUT",(function(){return cu})),n.d(i,"CYCLE",(function(){return uu})),n.d(i,"DASHBOARD",(function(){return du})),n.d(i,"DATA_CONNECTION",(function(){return hu})),n.d(i,"DATA_LINEAGE",(function(){return pu})),n.d(i,"DATABASE",(function(){return fu})),n.d(i,"DELETE",(function(){return mu})),n.d(i,"DELTA",(function(){return gu})),n.d(i,"DERIVE_COLUMN",(function(){return vu})),n.d(i,"DESKTOP",(function(){return yu})),n.d(i,"DIAGNOSIS",(function(){return _u})),n.d(i,"DIAGRAM_TREE",(function(){return bu})),n.d(i,"DIRECTION_LEFT",(function(){return Mu})),n.d(i,"DIRECTION_RIGHT",(function(){return wu})),n.d(i,"DISABLE",(function(){return Au})),n.d(i,"DOCUMENT",(function(){return Cu})),n.d(i,"DOCUMENT_OPEN",(function(){return xu})),n.d(i,"DOCUMENT_SHARE",(function(){return Eu})),n.d(i,"DOLLAR",(function(){return Lu})),n.d(i,"DOT",(function(){return Su})),n.d(i,"DOUBLE_CARET_HORIZONTAL",(function(){return Tu})),n.d(i,"DOUBLE_CARET_VERTICAL",(function(){return Ou})),n.d(i,"DOUBLE_CHEVRON_DOWN",(function(){return Iu})),n.d(i,"DOUBLE_CHEVRON_LEFT",(function(){return ku})),n.d(i,"DOUBLE_CHEVRON_RIGHT",(function(){return Du})),n.d(i,"DOUBLE_CHEVRON_UP",(function(){return Nu})),n.d(i,"DOUGHNUT_CHART",(function(){return ju})),n.d(i,"DOWNLOAD",(function(){return Pu})),n.d(i,"DRAG_HANDLE_HORIZONTAL",(function(){return zu})),n.d(i,"DRAG_HANDLE_VERTICAL",(function(){return Ru})),n.d(i,"DRAW",(function(){return Bu})),n.d(i,"DRAWER_LEFT",(function(){return Hu})),n.d(i,"DRAWER_LEFT_FILLED",(function(){return Fu})),n.d(i,"DRAWER_RIGHT",(function(){return Yu})),n.d(i,"DRAWER_RIGHT_FILLED",(function(){return Vu})),n.d(i,"DRIVE_TIME",(function(){return Uu})),n.d(i,"DUPLICATE",(function(){return Wu})),n.d(i,"EDIT",(function(){return Gu})),n.d(i,"EJECT",(function(){return qu})),n.d(i,"EMOJI",(function(){return Ku})),n.d(i,"ENDORSED",(function(){return Xu})),n.d(i,"ENVELOPE",(function(){return Ju})),n.d(i,"EQUALS",(function(){return Qu})),n.d(i,"ERASER",(function(){return Zu})),n.d(i,"ERROR",(function(){return $u})),n.d(i,"EURO",(function(){return ed})),n.d(i,"EXCHANGE",(function(){return td})),n.d(i,"EXCLUDE_ROW",(function(){return nd})),n.d(i,"EXPAND_ALL",(function(){return rd})),n.d(i,"EXPORT",(function(){return id})),n.d(i,"EYE_OFF",(function(){return od})),n.d(i,"EYE_ON",(function(){return ad})),n.d(i,"EYE_OPEN",(function(){return sd})),n.d(i,"FAST_BACKWARD",(function(){return ld})),n.d(i,"FAST_FORWARD",(function(){return cd})),n.d(i,"FEED",(function(){return ud})),n.d(i,"FEED_SUBSCRIBED",(function(){return dd})),n.d(i,"FILM",(function(){return hd})),n.d(i,"FILTER",(function(){return pd})),n.d(i,"FILTER_KEEP",(function(){return fd})),n.d(i,"FILTER_LIST",(function(){return md})),n.d(i,"FILTER_OPEN",(function(){return gd})),n.d(i,"FILTER_REMOVE",(function(){return vd})),n.d(i,"FLAG",(function(){return yd})),n.d(i,"FLAME",(function(){return _d})),n.d(i,"FLASH",(function(){return bd})),n.d(i,"FLOPPY_DISK",(function(){return Md})),n.d(i,"FLOW_BRANCH",(function(){return wd})),n.d(i,"FLOW_END",(function(){return Ad})),n.d(i,"FLOW_LINEAR",(function(){return Cd})),n.d(i,"FLOW_REVIEW",(function(){return xd})),n.d(i,"FLOW_REVIEW_BRANCH",(function(){return Ed})),n.d(i,"FLOWS",(function(){return Ld})),n.d(i,"FOLDER_CLOSE",(function(){return Sd})),n.d(i,"FOLDER_NEW",(function(){return Td})),n.d(i,"FOLDER_OPEN",(function(){return Od})),n.d(i,"FOLDER_SHARED",(function(){return Id})),n.d(i,"FOLDER_SHARED_OPEN",(function(){return kd})),n.d(i,"FOLLOWER",(function(){return Dd})),n.d(i,"FOLLOWING",(function(){return Nd})),n.d(i,"FONT",(function(){return jd})),n.d(i,"FORK",(function(){return Pd})),n.d(i,"FORM",(function(){return zd})),n.d(i,"FULL_CIRCLE",(function(){return Rd})),n.d(i,"FULL_STACKED_CHART",(function(){return Bd})),n.d(i,"FULLSCREEN",(function(){return Hd})),n.d(i,"FUNCTION",(function(){return Fd})),n.d(i,"GANTT_CHART",(function(){return Yd})),n.d(i,"GEOFENCE",(function(){return Vd})),n.d(i,"GEOLOCATION",(function(){return Ud})),n.d(i,"GEOSEARCH",(function(){return Wd})),n.d(i,"GIT_BRANCH",(function(){return Gd})),n.d(i,"GIT_COMMIT",(function(){return qd})),n.d(i,"GIT_MERGE",(function(){return Kd})),n.d(i,"GIT_NEW_BRANCH",(function(){return Xd})),n.d(i,"GIT_PULL",(function(){return Jd})),n.d(i,"GIT_PUSH",(function(){return Qd})),n.d(i,"GIT_REPO",(function(){return Zd})),n.d(i,"GLASS",(function(){return $d})),n.d(i,"GLOBE",(function(){return eh})),n.d(i,"GLOBE_NETWORK",(function(){return th})),n.d(i,"GRAPH",(function(){return nh})),n.d(i,"GRAPH_REMOVE",(function(){return rh})),n.d(i,"GREATER_THAN",(function(){return ih})),n.d(i,"GREATER_THAN_OR_EQUAL_TO",(function(){return oh})),n.d(i,"GRID",(function(){return ah})),n.d(i,"GRID_VIEW",(function(){return sh})),n.d(i,"GROUP_OBJECTS",(function(){return lh})),n.d(i,"GROUPED_BAR_CHART",(function(){return ch})),n.d(i,"HAND",(function(){return uh})),n.d(i,"HAND_DOWN",(function(){return dh})),n.d(i,"HAND_LEFT",(function(){return hh})),n.d(i,"HAND_RIGHT",(function(){return ph})),n.d(i,"HAND_UP",(function(){return fh})),n.d(i,"HAT",(function(){return mh})),n.d(i,"HEADER",(function(){return gh})),n.d(i,"HEADER_ONE",(function(){return vh})),n.d(i,"HEADER_THREE",(function(){return yh})),n.d(i,"HEADER_TWO",(function(){return _h})),n.d(i,"HEADSET",(function(){return bh})),n.d(i,"HEART",(function(){return Mh})),n.d(i,"HEART_BROKEN",(function(){return wh})),n.d(i,"HEAT_GRID",(function(){return Ah})),n.d(i,"HEATMAP",(function(){return Ch})),n.d(i,"HELICOPTER",(function(){return xh})),n.d(i,"HELP",(function(){return Eh})),n.d(i,"HELPER_MANAGEMENT",(function(){return Lh})),n.d(i,"HIGH_PRIORITY",(function(){return Sh})),n.d(i,"HIGHLIGHT",(function(){return Th})),n.d(i,"HISTORY",(function(){return Oh})),n.d(i,"HOME",(function(){return Ih})),n.d(i,"HORIZONTAL_BAR_CHART",(function(){return kh})),n.d(i,"HORIZONTAL_BAR_CHART_ASC",(function(){return Dh})),n.d(i,"HORIZONTAL_BAR_CHART_DESC",(function(){return Nh})),n.d(i,"HORIZONTAL_DISTRIBUTION",(function(){return jh})),n.d(i,"HURRICANE",(function(){return Ph})),n.d(i,"ID_NUMBER",(function(){return zh})),n.d(i,"IMAGE_ROTATE_LEFT",(function(){return Rh})),n.d(i,"IMAGE_ROTATE_RIGHT",(function(){return Bh})),n.d(i,"IMPORT",(function(){return Hh})),n.d(i,"INBOX",(function(){return Fh})),n.d(i,"INBOX_FILTERED",(function(){return Yh})),n.d(i,"INBOX_GEO",(function(){return Vh})),n.d(i,"INBOX_SEARCH",(function(){return Uh})),n.d(i,"INBOX_UPDATE",(function(){return Wh})),n.d(i,"INFO_SIGN",(function(){return Gh})),n.d(i,"INHERITANCE",(function(){return qh})),n.d(i,"INHERITED_GROUP",(function(){return Kh})),n.d(i,"INNER_JOIN",(function(){return Xh})),n.d(i,"INSERT",(function(){return Jh})),n.d(i,"INTERSECTION",(function(){return Qh})),n.d(i,"IP_ADDRESS",(function(){return Zh})),n.d(i,"ISSUE",(function(){return $h})),n.d(i,"ISSUE_CLOSED",(function(){return ep})),n.d(i,"ISSUE_NEW",(function(){return tp})),n.d(i,"ITALIC",(function(){return np})),n.d(i,"JOIN_TABLE",(function(){return rp})),n.d(i,"KEY",(function(){return ip})),n.d(i,"KEY_BACKSPACE",(function(){return op})),n.d(i,"KEY_COMMAND",(function(){return ap})),n.d(i,"KEY_CONTROL",(function(){return sp})),n.d(i,"KEY_DELETE",(function(){return lp})),n.d(i,"KEY_ENTER",(function(){return cp})),n.d(i,"KEY_ESCAPE",(function(){return up})),n.d(i,"KEY_OPTION",(function(){return dp})),n.d(i,"KEY_SHIFT",(function(){return hp})),n.d(i,"KEY_TAB",(function(){return pp})),n.d(i,"KNOWN_VEHICLE",(function(){return fp})),n.d(i,"LAB_TEST",(function(){return mp})),n.d(i,"LABEL",(function(){return gp})),n.d(i,"LAYER",(function(){return vp})),n.d(i,"LAYER_OUTLINE",(function(){return yp})),n.d(i,"LAYERS",(function(){return _p})),n.d(i,"LAYOUT",(function(){return bp})),n.d(i,"LAYOUT_AUTO",(function(){return Mp})),n.d(i,"LAYOUT_BALLOON",(function(){return wp})),n.d(i,"LAYOUT_CIRCLE",(function(){return Ap})),n.d(i,"LAYOUT_GRID",(function(){return Cp})),n.d(i,"LAYOUT_GROUP_BY",(function(){return xp})),n.d(i,"LAYOUT_HIERARCHY",(function(){return Ep})),n.d(i,"LAYOUT_LINEAR",(function(){return Lp})),n.d(i,"LAYOUT_SKEW_GRID",(function(){return Sp})),n.d(i,"LAYOUT_SORTED_CLUSTERS",(function(){return Tp})),n.d(i,"LEARNING",(function(){return Op})),n.d(i,"LEFT_JOIN",(function(){return Ip})),n.d(i,"LESS_THAN",(function(){return kp})),n.d(i,"LESS_THAN_OR_EQUAL_TO",(function(){return Dp})),n.d(i,"LIFESAVER",(function(){return Np})),n.d(i,"LIGHTBULB",(function(){return jp})),n.d(i,"LIGHTNING",(function(){return Pp})),n.d(i,"LINK",(function(){return zp})),n.d(i,"LIST",(function(){return Rp})),n.d(i,"LIST_COLUMNS",(function(){return Bp})),n.d(i,"LIST_DETAIL_VIEW",(function(){return Hp})),n.d(i,"LOCATE",(function(){return Fp})),n.d(i,"LOCK",(function(){return Yp})),n.d(i,"LOG_IN",(function(){return Vp})),n.d(i,"LOG_OUT",(function(){return Up})),n.d(i,"MANUAL",(function(){return Wp})),n.d(i,"MANUALLY_ENTERED_DATA",(function(){return Gp})),n.d(i,"MANY_TO_MANY",(function(){return qp})),n.d(i,"MANY_TO_ONE",(function(){return Kp})),n.d(i,"MAP",(function(){return Xp})),n.d(i,"MAP_CREATE",(function(){return Jp})),n.d(i,"MAP_MARKER",(function(){return Qp})),n.d(i,"MAXIMIZE",(function(){return Zp})),n.d(i,"MEDIA",(function(){return $p})),n.d(i,"MENU",(function(){return ef})),n.d(i,"MENU_CLOSED",(function(){return tf})),n.d(i,"MENU_OPEN",(function(){return nf})),n.d(i,"MERGE_COLUMNS",(function(){return rf})),n.d(i,"MERGE_LINKS",(function(){return of})),n.d(i,"MINIMIZE",(function(){return af})),n.d(i,"MINUS",(function(){return sf})),n.d(i,"MOBILE_PHONE",(function(){return lf})),n.d(i,"MOBILE_VIDEO",(function(){return cf})),n.d(i,"MODAL",(function(){return uf})),n.d(i,"MODAL_FILLED",(function(){return df})),n.d(i,"MOON",(function(){return hf})),n.d(i,"MORE",(function(){return pf})),n.d(i,"MOUNTAIN",(function(){return ff})),n.d(i,"MOVE",(function(){return mf})),n.d(i,"MUGSHOT",(function(){return gf})),n.d(i,"MULTI_SELECT",(function(){return vf})),n.d(i,"MUSIC",(function(){return yf})),n.d(i,"NEST",(function(){return _f})),n.d(i,"NEW_DRAWING",(function(){return bf})),n.d(i,"NEW_GRID_ITEM",(function(){return Mf})),n.d(i,"NEW_LAYER",(function(){return wf})),n.d(i,"NEW_LAYERS",(function(){return Af})),n.d(i,"NEW_LINK",(function(){return Cf})),n.d(i,"NEW_OBJECT",(function(){return xf})),n.d(i,"NEW_PERSON",(function(){return Ef})),n.d(i,"NEW_PRESCRIPTION",(function(){return Lf})),n.d(i,"NEW_TEXT_BOX",(function(){return Sf})),n.d(i,"NINJA",(function(){return Tf})),n.d(i,"NOT_EQUAL_TO",(function(){return Of})),n.d(i,"NOTIFICATIONS",(function(){return If})),n.d(i,"NOTIFICATIONS_SNOOZE",(function(){return kf})),n.d(i,"NOTIFICATIONS_UPDATED",(function(){return Df})),n.d(i,"NUMBERED_LIST",(function(){return Nf})),n.d(i,"NUMERICAL",(function(){return jf})),n.d(i,"OFFICE",(function(){return Pf})),n.d(i,"OFFLINE",(function(){return zf})),n.d(i,"OIL_FIELD",(function(){return Rf})),n.d(i,"ONE_COLUMN",(function(){return Bf})),n.d(i,"ONE_TO_MANY",(function(){return Hf})),n.d(i,"ONE_TO_ONE",(function(){return Ff})),n.d(i,"OUTDATED",(function(){return Yf})),n.d(i,"PAGE_LAYOUT",(function(){return Vf})),n.d(i,"PANEL_STATS",(function(){return Uf})),n.d(i,"PANEL_TABLE",(function(){return Wf})),n.d(i,"PAPERCLIP",(function(){return Gf})),n.d(i,"PARAGRAPH",(function(){return qf})),n.d(i,"PATH",(function(){return Kf})),n.d(i,"PATH_SEARCH",(function(){return Xf})),n.d(i,"PAUSE",(function(){return Jf})),n.d(i,"PEOPLE",(function(){return Qf})),n.d(i,"PERCENTAGE",(function(){return Zf})),n.d(i,"PERSON",(function(){return $f})),n.d(i,"PHONE",(function(){return em})),n.d(i,"PIE_CHART",(function(){return tm})),n.d(i,"PIN",(function(){return nm})),n.d(i,"PIVOT",(function(){return rm})),n.d(i,"PIVOT_TABLE",(function(){return im})),n.d(i,"PLAY",(function(){return om})),n.d(i,"PLUS",(function(){return am})),n.d(i,"POLYGON_FILTER",(function(){return sm})),n.d(i,"POWER",(function(){return lm})),n.d(i,"PREDICTIVE_ANALYSIS",(function(){return cm})),n.d(i,"PRESCRIPTION",(function(){return um})),n.d(i,"PRESENTATION",(function(){return dm})),n.d(i,"PRINT",(function(){return hm})),n.d(i,"PROJECTS",(function(){return pm})),n.d(i,"PROPERTIES",(function(){return fm})),n.d(i,"PROPERTY",(function(){return mm})),n.d(i,"PUBLISH_FUNCTION",(function(){return gm})),n.d(i,"PULSE",(function(){return vm})),n.d(i,"RAIN",(function(){return ym})),n.d(i,"RANDOM",(function(){return _m})),n.d(i,"RECORD",(function(){return bm})),n.d(i,"REDO",(function(){return Mm})),n.d(i,"REFRESH",(function(){return wm})),n.d(i,"REGRESSION_CHART",(function(){return Am})),n.d(i,"REMOVE",(function(){return Cm})),n.d(i,"REMOVE_COLUMN",(function(){return xm})),n.d(i,"REMOVE_COLUMN_LEFT",(function(){return Em})),n.d(i,"REMOVE_COLUMN_RIGHT",(function(){return Lm})),n.d(i,"REMOVE_ROW_BOTTOM",(function(){return Sm})),n.d(i,"REMOVE_ROW_TOP",(function(){return Tm})),n.d(i,"REPEAT",(function(){return Om})),n.d(i,"RESET",(function(){return Im})),n.d(i,"RESOLVE",(function(){return km})),n.d(i,"RIG",(function(){return Dm})),n.d(i,"RIGHT_JOIN",(function(){return Nm})),n.d(i,"RING",(function(){return jm})),n.d(i,"ROCKET",(function(){return Pm})),n.d(i,"ROCKET_SLANT",(function(){return zm})),n.d(i,"ROTATE_DOCUMENT",(function(){return Rm})),n.d(i,"ROTATE_PAGE",(function(){return Bm})),n.d(i,"ROUTE",(function(){return Hm})),n.d(i,"SATELLITE",(function(){return Fm})),n.d(i,"SAVED",(function(){return Ym})),n.d(i,"SCATTER_PLOT",(function(){return Vm})),n.d(i,"SEARCH",(function(){return Um})),n.d(i,"SEARCH_AROUND",(function(){return Wm})),n.d(i,"SEARCH_TEMPLATE",(function(){return Gm})),n.d(i,"SEARCH_TEXT",(function(){return qm})),n.d(i,"SEGMENTED_CONTROL",(function(){return Km})),n.d(i,"SELECT",(function(){return Xm})),n.d(i,"SELECTION",(function(){return Jm})),n.d(i,"SEND_MESSAGE",(function(){return Qm})),n.d(i,"SEND_TO",(function(){return Zm})),n.d(i,"SEND_TO_GRAPH",(function(){return $m})),n.d(i,"SEND_TO_MAP",(function(){return eg})),n.d(i,"SERIES_ADD",(function(){return tg})),n.d(i,"SERIES_CONFIGURATION",(function(){return ng})),n.d(i,"SERIES_DERIVED",(function(){return rg})),n.d(i,"SERIES_FILTERED",(function(){return ig})),n.d(i,"SERIES_SEARCH",(function(){return og})),n.d(i,"SETTINGS",(function(){return ag})),n.d(i,"SHAPES",(function(){return sg})),n.d(i,"SHARE",(function(){return lg})),n.d(i,"SHARED_FILTER",(function(){return cg})),n.d(i,"SHIELD",(function(){return ug})),n.d(i,"SHIP",(function(){return dg})),n.d(i,"SHOP",(function(){return hg})),n.d(i,"SHOPPING_CART",(function(){return pg})),n.d(i,"SIGNAL_SEARCH",(function(){return fg})),n.d(i,"SIM_CARD",(function(){return mg})),n.d(i,"SLASH",(function(){return gg})),n.d(i,"SMALL_CROSS",(function(){return vg})),n.d(i,"SMALL_MINUS",(function(){return yg})),n.d(i,"SMALL_PLUS",(function(){return _g})),n.d(i,"SMALL_SQUARE",(function(){return bg})),n.d(i,"SMALL_TICK",(function(){return Mg})),n.d(i,"SNOWFLAKE",(function(){return wg})),n.d(i,"SOCIAL_MEDIA",(function(){return Ag})),n.d(i,"SORT",(function(){return Cg})),n.d(i,"SORT_ALPHABETICAL",(function(){return xg})),n.d(i,"SORT_ALPHABETICAL_DESC",(function(){return Eg})),n.d(i,"SORT_ASC",(function(){return Lg})),n.d(i,"SORT_DESC",(function(){return Sg})),n.d(i,"SORT_NUMERICAL",(function(){return Tg})),n.d(i,"SORT_NUMERICAL_DESC",(function(){return Og})),n.d(i,"SPLIT_COLUMNS",(function(){return Ig})),n.d(i,"SQUARE",(function(){return kg})),n.d(i,"STACKED_CHART",(function(){return Dg})),n.d(i,"STADIUM_GEOMETRY",(function(){return Ng})),n.d(i,"STAR",(function(){return jg})),n.d(i,"STAR_EMPTY",(function(){return Pg})),n.d(i,"STEP_BACKWARD",(function(){return zg})),n.d(i,"STEP_CHART",(function(){return Rg})),n.d(i,"STEP_FORWARD",(function(){return Bg})),n.d(i,"STOP",(function(){return Hg})),n.d(i,"STOPWATCH",(function(){return Fg})),n.d(i,"STRIKETHROUGH",(function(){return Yg})),n.d(i,"STYLE",(function(){return Vg})),n.d(i,"SWAP_HORIZONTAL",(function(){return Ug})),n.d(i,"SWAP_VERTICAL",(function(){return Wg})),n.d(i,"SWITCH",(function(){return Gg})),n.d(i,"SYMBOL_CIRCLE",(function(){return qg})),n.d(i,"SYMBOL_CROSS",(function(){return Kg})),n.d(i,"SYMBOL_DIAMOND",(function(){return Xg})),n.d(i,"SYMBOL_SQUARE",(function(){return Jg})),n.d(i,"SYMBOL_TRIANGLE_DOWN",(function(){return Qg})),n.d(i,"SYMBOL_TRIANGLE_UP",(function(){return Zg})),n.d(i,"SYRINGE",(function(){return $g})),n.d(i,"TAG",(function(){return ev})),n.d(i,"TAKE_ACTION",(function(){return tv})),n.d(i,"TANK",(function(){return nv})),n.d(i,"TARGET",(function(){return rv})),n.d(i,"TAXI",(function(){return iv})),n.d(i,"TEMPERATURE",(function(){return ov})),n.d(i,"TEXT_HIGHLIGHT",(function(){return av})),n.d(i,"TH",(function(){return sv})),n.d(i,"TH_DERIVED",(function(){return lv})),n.d(i,"TH_DISCONNECT",(function(){return cv})),n.d(i,"TH_FILTERED",(function(){return uv})),n.d(i,"TH_LIST",(function(){return dv})),n.d(i,"THIRD_PARTY",(function(){return hv})),n.d(i,"THUMBS_DOWN",(function(){return pv})),n.d(i,"THUMBS_UP",(function(){return fv})),n.d(i,"TICK",(function(){return mv})),n.d(i,"TICK_CIRCLE",(function(){return gv})),n.d(i,"TIME",(function(){return vv})),n.d(i,"TIMELINE_AREA_CHART",(function(){return yv})),n.d(i,"TIMELINE_BAR_CHART",(function(){return _v})),n.d(i,"TIMELINE_EVENTS",(function(){return bv})),n.d(i,"TIMELINE_LINE_CHART",(function(){return Mv})),n.d(i,"TINT",(function(){return wv})),n.d(i,"TORCH",(function(){return Av})),n.d(i,"TRACTOR",(function(){return Cv})),n.d(i,"TRAIN",(function(){return xv})),n.d(i,"TRANSLATE",(function(){return Ev})),n.d(i,"TRASH",(function(){return Lv})),n.d(i,"TREE",(function(){return Sv})),n.d(i,"TRENDING_DOWN",(function(){return Tv})),n.d(i,"TRENDING_UP",(function(){return Ov})),n.d(i,"TRUCK",(function(){return Iv})),n.d(i,"TWO_COLUMNS",(function(){return kv})),n.d(i,"UNARCHIVE",(function(){return Dv})),n.d(i,"UNDERLINE",(function(){return Nv})),n.d(i,"UNDO",(function(){return jv})),n.d(i,"UNGROUP_OBJECTS",(function(){return Pv})),n.d(i,"UNKNOWN_VEHICLE",(function(){return zv})),n.d(i,"UNLOCK",(function(){return Rv})),n.d(i,"UNPIN",(function(){return Bv})),n.d(i,"UNRESOLVE",(function(){return Hv})),n.d(i,"UPDATED",(function(){return Fv})),n.d(i,"UPLOAD",(function(){return Yv})),n.d(i,"USER",(function(){return Vv})),n.d(i,"VARIABLE",(function(){return Uv})),n.d(i,"VERTICAL_BAR_CHART_ASC",(function(){return Wv})),n.d(i,"VERTICAL_BAR_CHART_DESC",(function(){return Gv})),n.d(i,"VERTICAL_DISTRIBUTION",(function(){return qv})),n.d(i,"VIDEO",(function(){return Kv})),n.d(i,"VIRUS",(function(){return Xv})),n.d(i,"VOLUME_DOWN",(function(){return Jv})),n.d(i,"VOLUME_OFF",(function(){return Qv})),n.d(i,"VOLUME_UP",(function(){return Zv})),n.d(i,"WALK",(function(){return $v})),n.d(i,"WARNING_SIGN",(function(){return ey})),n.d(i,"WATERFALL_CHART",(function(){return ty})),n.d(i,"WAVES",(function(){return ny})),n.d(i,"WIDGET",(function(){return ry})),n.d(i,"WIDGET_BUTTON",(function(){return iy})),n.d(i,"WIDGET_FOOTER",(function(){return oy})),n.d(i,"WIDGET_HEADER",(function(){return ay})),n.d(i,"WIND",(function(){return sy})),n.d(i,"WRENCH",(function(){return ly})),n.d(i,"ZOOM_IN",(function(){return cy})),n.d(i,"ZOOM_OUT",(function(){return uy})),n.d(i,"ZOOM_TO_FIT",(function(){return dy}));var o="",a="",s="",l="",c="",u="",d="",h="",p="",f="",m="",g="",v="",y="",_="",b="",M="",w="",A="",C="",x="",E="",L="↙",S="↘",T="↓",O="←",I="→",k="↖",D="↗",N="↑",j="↔",P="↕",z="*",R="",B="",H="",F="",Y="",V="",U="",W="",G="",q="",K="",X="",J="",Q="",Z="",$="",ee="",te="⌄",ne="〈",re="〉",ie="⌃",oe="",ae="",se="",le="",ce="",ue="",de="",he="",pe="",fe="",me="",ge="",ve="",ye="",_e="",be="",Me="",we="",Ae="☁",Ce="",xe="",Ee="",Le="",Se="",Te="",Oe="",Ie="",ke="",De="",Ne="",je="",Pe="",ze="",Re="",Be="",He="✗",Fe="",Ye="",Ve="",Ue="",We="",Ge="",qe="",Ke="",Xe="",Je="",Qe="Δ",Ze="",$e="",et="",tt="",nt="",rt="",it="",ot="",at="",st="",lt="$",ct="•",ut="",dt="",ht="",pt="",ft="",mt="",gt="",vt="",yt="",_t="",bt="",Mt="",wt="",At="✎",Ct="⏏",xt="",Et="✉",Lt="",St="",Tt="",Ot="€",It="",kt="",Dt="",Nt="",jt="",Pt="",zt="",Rt="",Bt="",Ht="",Ft="",Yt="",Vt="",Ut="",Wt="",Gt="",qt="",Kt="⚑",Xt="",Jt="",Qt="",Zt="",$t="",en="",tn="",nn="",rn="",on="",an="",sn="",ln="",cn="",un="",dn="",hn="",pn="",fn="",mn="",gn="",vn="",yn="",_n="",bn="",Mn="",wn="",An="",Cn="",xn="",En="",Ln="",Sn="",Tn="",On="",In="",kn="",Dn="",Nn="",jn="",Pn="",zn="",Rn="",Bn="",Hn="",Fn="",Yn="",Vn="",Un="",Wn="",Gn="",qn="",Kn="",Xn="♥",Jn="",Qn="",Zn="",$n="?",er="",tr="",nr="",rr="⌂",ir="",or="",ar="",sr="",lr="",cr="",ur="",dr="",hr="",pr="",fr="",mr="",gr="",vr="ℹ",yr="",_r="",br="",Mr="",wr="",Ar="",Cr="",xr="",Er="",Lr="",Sr="",Tr="",Or="",Ir="",kr="",Dr="",Nr="",jr="",Pr="",zr="",Rr="",Br="",Hr="",Fr="",Yr="",Vr="",Ur="",Wr="",Gr="",qr="",Kr="",Xr="",Jr="",Qr="",Zr="",$r="",ei="",ti="",ni="",ri="",ii="",oi="",ai="☰",si="",li="",ci="",ui="",di="",hi="",pi="",fi="",mi="",gi="",vi="",yi="",_i="",bi="",Mi="",wi="",Ai="",Ci="",xi="",Ei="−",Li="",Si="",Ti="",Oi="",Ii="",ki="",Di="",Ni="",ji="",Pi="",zi="",Ri="",Bi="",Hi="",Fi="",Yi="",Vi="",Ui="",Wi="",Gi="",qi="",Ki="",Xi="",Ji="",Qi="",Zi="",$i="",eo="",to="",no="",ro="",io="",oo="",ao="",so="",lo="",co="",uo="",ho="",po="",fo="☎",mo="",go="",vo="",yo="",_o="",bo="+",Mo="",wo="",Ao="",Co="",xo="",Eo="⎙",Lo="",So="",To="",Oo="",Io="",ko="",Do="",No="",jo="",Po="",zo="",Ro="",Bo="",Ho="",Fo="",Yo="",Vo="",Uo="",Wo="",Go="",qo="",Ko="",Xo="",Jo="",Qo="",Zo="",$o="",ea="",ta="",na="",ra="",ia="",oa="",aa="⦿",sa="",la="",ca="",ua="",da="",ha="",pa="",fa="",ma="",ga="",va="",ya="",_a="",ba="",Ma="",wa="",Aa="",Ca="",xa="",Ea="",La="",Sa="",Ta="",Oa="",Ia="",ka="",Da="",Na="",ja="",Pa="",za="",Ra="",Ba="★",Ha="☆",Fa="",Ya="",Va="",Ua="",Wa="",Ga="",qa="",Ka="",Xa="",Ja="",Qa="",Za="",$a="",es="",ts="",ns="",rs="",is="",os="",as="",ss="",ls="",cs="",us="",ds="",hs="",ps="✓",fs="",ms="⏲",gs="",vs="",ys="",_s="",bs="",Ms="",ws="",As="",Cs="",xs="",Es="",Ls="",Ss="",Ts="",Os="",Is="",ks="⎁",Ds="⎌",Ns="",js="",Ps="",zs="",Rs="",Bs="",Hs="",Fs="",Ys="",Vs="",Us="",Ws="",Gs="",qs="",Ks="",Xs="",Js="",Qs="",Zs="",$s="",el="",tl="",nl="",rl="",il="",ol="",al="",sl="add",ll="add-clip",cl="add-column-left",ul="add-column-right",dl="add-location",hl="add-row-bottom",pl="add-row-top",fl="add-to-artifact",ml="add-to-folder",gl="airplane",vl="align-center",yl="align-justify",_l="align-left",bl="align-right",Ml="alignment-bottom",wl="alignment-horizontal-center",Al="alignment-left",Cl="alignment-right",xl="alignment-top",El="alignment-vertical-center",Ll="annotation",Sl="antenna",Tl="app-header",Ol="application",Il="applications",kl="archive",Dl="area-of-interest",Nl="array",jl="array-boolean",Pl="array-date",zl="array-numeric",Rl="array-string",Bl="array-timestamp",Hl="arrow-bottom-left",Fl="arrow-bottom-right",Yl="arrow-down",Vl="arrow-left",Ul="arrow-right",Wl="arrow-top-left",Gl="arrow-top-right",ql="arrow-up",Kl="arrows-horizontal",Xl="arrows-vertical",Jl="asterisk",Ql="automatic-updates",Zl="backlink",$l="badge",ec="ban-circle",tc="bank-account",nc="barcode",rc="blank",ic="blocked-person",oc="bold",ac="book",sc="bookmark",lc="box",cc="briefcase",uc="bring-data",dc="buggy",hc="build",pc="calculator",fc="calendar",mc="camera",gc="caret-down",vc="caret-left",yc="caret-right",_c="caret-up",bc="cargo-ship",Mc="cell-tower",wc="changes",Ac="chart",Cc="chat",xc="chevron-backward",Ec="chevron-down",Lc="chevron-forward",Sc="chevron-left",Tc="chevron-right",Oc="chevron-up",Ic="circle",kc="circle-arrow-down",Dc="circle-arrow-left",Nc="circle-arrow-right",jc="circle-arrow-up",Pc="citation",zc="clean",Rc="clip",Bc="clipboard",Hc="cloud",Fc="cloud-download",Yc="cloud-upload",Vc="code",Uc="code-block",Wc="cog",Gc="collapse-all",qc="column-layout",Kc="comment",Xc="comparison",Jc="compass",Qc="compressed",Zc="confirm",$c="console",eu="contrast",tu="control",nu="credit-card",ru="cross",iu="crown",ou="cube",au="cube-add",su="cube-remove",lu="curved-range-chart",cu="cut",uu="cycle",du="dashboard",hu="data-connection",pu="data-lineage",fu="database",mu="delete",gu="delta",vu="derive-column",yu="desktop",_u="diagnosis",bu="diagram-tree",Mu="direction-left",wu="direction-right",Au="disable",Cu="document",xu="document-open",Eu="document-share",Lu="dollar",Su="dot",Tu="double-caret-horizontal",Ou="double-caret-vertical",Iu="double-chevron-down",ku="double-chevron-left",Du="double-chevron-right",Nu="double-chevron-up",ju="doughnut-chart",Pu="download",zu="drag-handle-horizontal",Ru="drag-handle-vertical",Bu="draw",Hu="drawer-left",Fu="drawer-left-filled",Yu="drawer-right",Vu="drawer-right-filled",Uu="drive-time",Wu="duplicate",Gu="edit",qu="eject",Ku="emoji",Xu="endorsed",Ju="envelope",Qu="equals",Zu="eraser",$u="error",ed="euro",td="exchange",nd="exclude-row",rd="expand-all",id="export",od="eye-off",ad="eye-on",sd="eye-open",ld="fast-backward",cd="fast-forward",ud="feed",dd="feed-subscribed",hd="film",pd="filter",fd="filter-keep",md="filter-list",gd="filter-open",vd="filter-remove",yd="flag",_d="flame",bd="flash",Md="floppy-disk",wd="flow-branch",Ad="flow-end",Cd="flow-linear",xd="flow-review",Ed="flow-review-branch",Ld="flows",Sd="folder-close",Td="folder-new",Od="folder-open",Id="folder-shared",kd="folder-shared-open",Dd="follower",Nd="following",jd="font",Pd="fork",zd="form",Rd="full-circle",Bd="full-stacked-chart",Hd="fullscreen",Fd="function",Yd="gantt-chart",Vd="geofence",Ud="geolocation",Wd="geosearch",Gd="git-branch",qd="git-commit",Kd="git-merge",Xd="git-new-branch",Jd="git-pull",Qd="git-push",Zd="git-repo",$d="glass",eh="globe",th="globe-network",nh="graph",rh="graph-remove",ih="greater-than",oh="greater-than-or-equal-to",ah="grid",sh="grid-view",lh="group-objects",ch="grouped-bar-chart",uh="hand",dh="hand-down",hh="hand-left",ph="hand-right",fh="hand-up",mh="hat",gh="header",vh="header-one",yh="header-three",_h="header-two",bh="headset",Mh="heart",wh="heart-broken",Ah="heat-grid",Ch="heatmap",xh="helicopter",Eh="help",Lh="helper-management",Sh="high-priority",Th="highlight",Oh="history",Ih="home",kh="horizontal-bar-chart",Dh="horizontal-bar-chart-asc",Nh="horizontal-bar-chart-desc",jh="horizontal-distribution",Ph="hurricane",zh="id-number",Rh="image-rotate-left",Bh="image-rotate-right",Hh="import",Fh="inbox",Yh="inbox-filtered",Vh="inbox-geo",Uh="inbox-search",Wh="inbox-update",Gh="info-sign",qh="inheritance",Kh="inherited-group",Xh="inner-join",Jh="insert",Qh="intersection",Zh="ip-address",$h="issue",ep="issue-closed",tp="issue-new",np="italic",rp="join-table",ip="key",op="key-backspace",ap="key-command",sp="key-control",lp="key-delete",cp="key-enter",up="key-escape",dp="key-option",hp="key-shift",pp="key-tab",fp="known-vehicle",mp="lab-test",gp="label",vp="layer",yp="layer-outline",_p="layers",bp="layout",Mp="layout-auto",wp="layout-balloon",Ap="layout-circle",Cp="layout-grid",xp="layout-group-by",Ep="layout-hierarchy",Lp="layout-linear",Sp="layout-skew-grid",Tp="layout-sorted-clusters",Op="learning",Ip="left-join",kp="less-than",Dp="less-than-or-equal-to",Np="lifesaver",jp="lightbulb",Pp="lightning",zp="link",Rp="list",Bp="list-columns",Hp="list-detail-view",Fp="locate",Yp="lock",Vp="log-in",Up="log-out",Wp="manual",Gp="manually-entered-data",qp="many-to-many",Kp="many-to-one",Xp="map",Jp="map-create",Qp="map-marker",Zp="maximize",$p="media",ef="menu",tf="menu-closed",nf="menu-open",rf="merge-columns",of="merge-links",af="minimize",sf="minus",lf="mobile-phone",cf="mobile-video",uf="modal",df="modal-filled",hf="moon",pf="more",ff="mountain",mf="move",gf="mugshot",vf="multi-select",yf="music",_f="nest",bf="new-drawing",Mf="new-grid-item",wf="new-layer",Af="new-layers",Cf="new-link",xf="new-object",Ef="new-person",Lf="new-prescription",Sf="new-text-box",Tf="ninja",Of="not-equal-to",If="notifications",kf="notifications-snooze",Df="notifications-updated",Nf="numbered-list",jf="numerical",Pf="office",zf="offline",Rf="oil-field",Bf="one-column",Hf="one-to-many",Ff="one-to-one",Yf="outdated",Vf="page-layout",Uf="panel-stats",Wf="panel-table",Gf="paperclip",qf="paragraph",Kf="path",Xf="path-search",Jf="pause",Qf="people",Zf="percentage",$f="person",em="phone",tm="pie-chart",nm="pin",rm="pivot",im="pivot-table",om="play",am="plus",sm="polygon-filter",lm="power",cm="predictive-analysis",um="prescription",dm="presentation",hm="print",pm="projects",fm="properties",mm="property",gm="publish-function",vm="pulse",ym="rain",_m="random",bm="record",Mm="redo",wm="refresh",Am="regression-chart",Cm="remove",xm="remove-column",Em="remove-column-left",Lm="remove-column-right",Sm="remove-row-bottom",Tm="remove-row-top",Om="repeat",Im="reset",km="resolve",Dm="rig",Nm="right-join",jm="ring",Pm="rocket",zm="rocket-slant",Rm="rotate-document",Bm="rotate-page",Hm="route",Fm="satellite",Ym="saved",Vm="scatter-plot",Um="search",Wm="search-around",Gm="search-template",qm="search-text",Km="segmented-control",Xm="select",Jm="selection",Qm="send-message",Zm="send-to",$m="send-to-graph",eg="send-to-map",tg="series-add",ng="series-configuration",rg="series-derived",ig="series-filtered",og="series-search",ag="settings",sg="shapes",lg="share",cg="shared-filter",ug="shield",dg="ship",hg="shop",pg="shopping-cart",fg="signal-search",mg="sim-card",gg="slash",vg="small-cross",yg="small-minus",_g="small-plus",bg="small-square",Mg="small-tick",wg="snowflake",Ag="social-media",Cg="sort",xg="sort-alphabetical",Eg="sort-alphabetical-desc",Lg="sort-asc",Sg="sort-desc",Tg="sort-numerical",Og="sort-numerical-desc",Ig="split-columns",kg="square",Dg="stacked-chart",Ng="stadium-geometry",jg="star",Pg="star-empty",zg="step-backward",Rg="step-chart",Bg="step-forward",Hg="stop",Fg="stopwatch",Yg="strikethrough",Vg="style",Ug="swap-horizontal",Wg="swap-vertical",Gg="switch",qg="symbol-circle",Kg="symbol-cross",Xg="symbol-diamond",Jg="symbol-square",Qg="symbol-triangle-down",Zg="symbol-triangle-up",$g="syringe",ev="tag",tv="take-action",nv="tank",rv="target",iv="taxi",ov="temperature",av="text-highlight",sv="th",lv="th-derived",cv="th-disconnect",uv="th-filtered",dv="th-list",hv="third-party",pv="thumbs-down",fv="thumbs-up",mv="tick",gv="tick-circle",vv="time",yv="timeline-area-chart",_v="timeline-bar-chart",bv="timeline-events",Mv="timeline-line-chart",wv="tint",Av="torch",Cv="tractor",xv="train",Ev="translate",Lv="trash",Sv="tree",Tv="trending-down",Ov="trending-up",Iv="truck",kv="two-columns",Dv="unarchive",Nv="underline",jv="undo",Pv="ungroup-objects",zv="unknown-vehicle",Rv="unlock",Bv="unpin",Hv="unresolve",Fv="updated",Yv="upload",Vv="user",Uv="variable",Wv="vertical-bar-chart-asc",Gv="vertical-bar-chart-desc",qv="vertical-distribution",Kv="video",Xv="virus",Jv="volume-down",Qv="volume-off",Zv="volume-up",$v="walk",ey="warning-sign",ty="waterfall-chart",ny="waves",ry="widget",iy="widget-button",oy="widget-footer",ay="widget-header",sy="wind",ly="wrench",cy="zoom-in",uy="zoom-out",dy="zoom-to-fit",hy=n(173)},function(e,t){e.exports="data:application/font-woff;base64,d09GRk9UVE8AAAVYAAsAAAAACVQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABDRkYgAAAEbAAAAKUAAACtD3M310ZGVE0AAAUUAAAAGgAAABx2+H9qR0RFRgAABTAAAAAdAAAAIAAqAB5PUy8yAAABXAAAAEIAAABgQMTnh2NtYXAAAAQgAAAANAAAAUIADfKiaGVhZAAAAQgAAAAvAAAANgnczu9oaGVhAAABOAAAABoAAAAkAGYAmGhtdHgAAAVQAAAABgAAAAYA+gAAbWF4cAAAAVQAAAAGAAAABgACUABuYW1lAAABoAAAAn4AAAV64wVcYHBvc3QAAARUAAAAFgAAACD/hgAzeNpjYGRgYGBmYHj34mdrPL/NVwZu5hdAEYarsQt9wHTcm30MCMDBwASiAHAWCvQAeNpjYGRgYEj5PwdI/mKAAEYGVMAIAFRtAv0AAAAAUAAAAgAAeNpjYGH4xTiBgZWBgamLaQ8DA0MPhGZ8wGDIyMSABBoYUEFAmmsKw4H3f97/YUj5PwcokMKQooCsQAEIGQH40w9nAAB42p1SQUsbQRR+G6Ol2xr0IqWngV60JBMjxZRghSAsKFExigcvdkzG7NjNbpiZZLW/sT+jpx4Lvffb2U3dUIXSLLvzzXvf+743b0JEG16NPMp/7/Hm2KPX2OW4Qi9ot8BL9I4+Fbha4izTK/pc4JVSfJV+0ZcC1+itN+eslTjrTn+JvOpL7Pre1wJ79Mb7VuAK1bzvBV6iwPtZ4GqJs0wblY8FXinFV70flZMC1+hDdc5ZK3HWM/2DZPKg1Si0bHOwxXa2W212EUp2LGx4JO7ZQRKbRFs1HfMidH0lddKXo2kkdJDENkj0SLIOK6exbTd2G5napdRGJTFr8dbfVvXnvNjmXpqmfIzMnbjnsNjfqvupsiHrSyP1TA5ZZs5OxFguWHPfvwiVybPnya1NhZYMgUgNZGxQN42HUjML4/PDHjudyDgn93JCnZVa5rlYUcvETKhI3ESSuVYEC7pnTNiOH1o76TSbZqDVxBpuVJT13DwNes9n6IASmtADaVI0opAsMdqkAW1h3aFtalEb6AIZifWYBBghHVGX7rHPqmMy+GrEFU1pXOIIcK7pCpUajD7WERgR4poCV2ndqhHP1DsLDovVebZNDfxjG386u3RZA+dMjSHG8f7LmepPnko8eyruNPYodQ9HJK+5czW8OMU+POrkg6FclrlTG9flDN8hIvOTMzpB7fiJDh5PzaHluz4VVMq150C3QKmbZqaRMyKsA+xj55r5TYGHTo85D+mqD6mH9RRzkm5yj8q9BYVsTk9PmS90tujL0NUMr3K3fYNvFnucinCOXTpz2OJufXdPFv10qInHQC27vwliBl7Gac3n3ETnATr9j5rfXBgPxAAAeNpjYGBgZoBgGQZGBhCwAfIYwXwWBgUgzQKEQP77P///Q0gBVqhKBkY2BhhzxAIAVPcInXjaY2BmAIP/zQxGQIqRAQ0AAChVAbkAAHjaY2RgYWRgZGTk9U0syfBKrIiPSi3KBwnI/pBh+CHL+EOO6Ycc8w8Jlh4exu/C/Ou+ywl9FxMEamLk4DZxKM3LdHVzczbWM3DOL6gsykzPKFHQSNZUMDIwNFcIyUhVgJqq4JyfV5xfVJJZmotiDwMDYzsDEyMjEzMfX+nCH85zvuf2zFzC9jupl11ugWXyfx7Obh6uvVx7uWUZGFgeiQAAYPEzbAAAAHjaY2BgYGQAgjO2i86D6Kuxeb4wGgBIXwZWAAB42mNgZGBg4AFiEQYZBkYoZAHyQeJMDAwABhQASQAAAAD6AAAAAAAA"},function(e,t){e.exports="/voila/static/9995de4787f908d8237dba7007f6c3fe.woff"},function(e,t){e.exports="/voila/static/c9423d5dc9d82a38ca215f74e9cdd9f2.woff"},function(e,t){e.exports="/voila/static/7e83626ba8bf2d20dc41565f1e6d0afc.woff"},function(e,t){e.exports="/voila/static/5589d1a8fc62be6613020ef2fa13e410.woff"},function(e,t){e.exports="/voila/static/77dbcee3c3d9a82a0c04a4ae7992b895.woff"},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="/voila/static/07173fb77d2ee655811499d40c8388e7.woff"},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="data:application/font-woff;base64, "},function(e,t){e.exports="/voila/static/b80e08d5a79acbd1fafb1ca6f3515664.woff"},function(e,t){e.exports="/voila/static/bc42125861bd5bfc8686deeb612dcbb3.woff"},function(e,t){e.exports="/voila/static/bc3af04f9a671fcabd6498042c57478f.woff"},function(e,t){e.exports="/voila/static/07281897a98a61c3733e1670f82a9fd5.woff"},function(e,t){e.exports="/voila/static/3d580bd561716bfb1f0b4fdd7063a802.woff"},function(e,t){e.exports="/voila/static/4c74e33b0feb1fdbda49403a5e7ed604.woff"},function(e,t){e.exports="/voila/static/72815766b08ca24d4d29ad1f5d4ecb45.woff"},function(e,t){e.exports="data:application/font-woff;base64,d09GRk9UVE8AAARwAAsAAAAABoAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABDRkYgAAADKAAAAQkAAAElso6A7EZGVE0AAAQ0AAAAHAAAABx3J0njR0RFRgAABFAAAAAYAAAAHAAoAAJPUy8yAAABaAAAAEkAAABgd6mCHGNtYXAAAALcAAAANAAAAUIADSQ4aGVhZAAAAQgAAAA1AAAANgw5vZloaGVhAAABQAAAAB4AAAAkBKMBLmhtdHgAAARoAAAABgAAAAYCEQAAbWF4cAAAAWAAAAAGAAAABgACUABuYW1lAAABtAAAASYAAAIx/gQR3nBvc3QAAAMQAAAAFgAAACD/hgAzeNpjYGRgYADir0asH+L5bb4ycDO/AIowXJ28TRJCHzzLIMvEwnid6RSQy8HABBIFAFQsC7IAAAB42mNgZGBgOvXfgoGB8QsDEDBeZ2BkQAWMAGVAA9QAAAAAUAAAAgAAeNpjYGH8wviFgZWBgamLaQ8DA0MPhGZ8wGDIyAQUZWBjZoABRiBWgHEC0lxTGA4oTlKcxHTqvwVQ5SmGE1A1EKAAhIwAzIwNswAAAHjalZCxasMwEIZ/xU5KKXTM1EF0iqEJcZZAhkJxyRDIYoLX1BhhC2IryHJJxr5QX6YP0ico9OzckqRLDfJ9+u+/O0kA7vEJgdMX0DqxID1g7uEGc2YPj3hm9jHEG3Mfd3hnHnS6B+Hf0i7GB7PAA76Ye9T/m9nDK36YfTyJF+Y+hqJkHrR6ZPZHq/PCyVEWyNk0nMtNoeQ6dcUqPcjIVLWxTjclK9tEZc7YWOXNLrVLU7mlsbmSC3luGLPjbzVRttamkuEkRASDPY6w0MhRwEFihIyeSmKGKUJ6KIkNZRTFNVJyFFhRPNC+ra5Q09+SrtGgvPBskVBlRkrriYlzcu0oZ7Hsql0XLenthMXVlPMO44se//G2OUun1d1cSXebIPwFZj5mrgAAeNpjYGBgZoBgGQZGBhCwAfIYwXwWBgUgzQKEQL7ipP//IeS9fKhKBkY2BhhzxAIA+yMHZXjaY2BmAIP/zQxGQIqRAQ0AAChVAbkAAHjaY2RgYWJgZGQU900syfBKrIgPS00uyS/SDUpNL81JLAJJqf7gZ/ghw/hDlumHHPMPcZYeHsYVP2b8yP4Zx/rdln/295VC3x0EGVgYGblNvCISi4ryy4sy0zNKnPMLKsEMBY1kTQUjA0NzhZCMVAWoPQrO+XnF+UUlmaW52G1GFWVgYGBsZ2BiZGRK4fvB+9NLtLtuZu7Uao7fv9laW1vaupu6mya2TWrj+G7f9d2+m7WuITO3u7K7flrzlO7p3d39U6ctXL5w3qrZMyb193TP6J7cMaF5Akf5jJoFrYvap3f2t/d19LX3tnXXdzc3djdy8HXzcG3m2sq9mYdnKw/vjw4RAKc+clgAAAAAAAABAAAAAMw9os8AAAAA1VXxAgAAAADVk7YReNpjYGRgYOABYhEgZoRCFjCbAQADFgArAfQAAAAdAAA="},function(e,t){e.exports="data:application/font-woff;base64,d09GRk9UVE8AAARcAAsAAAAABjAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABDRkYgAAADGAAAAQcAAAEfGT6+mEZGVE0AAAQgAAAAHAAAABx3J0n8R0RFRgAABDwAAAAYAAAAHAAoAAJPUy8yAAABaAAAAEkAAABgd7yCRmNtYXAAAALMAAAANAAAAUIADSQ4aGVhZAAAAQgAAAA1AAAANgyFt9poaGVhAAABQAAAAB0AAAAkBPMBb2htdHgAAARUAAAABgAAAAYCYAAAbWF4cAAAAWAAAAAGAAAABgACUABuYW1lAAABtAAAARYAAAHs9k2y63Bvc3QAAAMAAAAAFgAAACD/hgAzeNpjYGRgYABiU6dQ9nh+m68M3MwvgCIMVydvM4bQu98xKDIxMskxXQaq42BgAokCABb+CfEAAAB42mNgZGBguvxfD0jaMwABkxwDIwMqYAQARfsCZwAAAAAAUAAAAgAAeNpjYGGyZ/zCwMrAwNTFtIeBgaEHQjM+YDBkZAKKMrAxM8AAIxArwDgBaa4pDAsUJylOYrr8Xw+o8jLDJagaCFAAQkYAiH0M8QAAAHjadY/NasJAFIW/mCgthW4K3XZWRReKcSNIKUXBheCmiFuRGJIUzchkBH2pPkGfpss+RW+SQaQ/AzPnuydn7p0At7zjUa+O7Jo97qSquUHAk2OfB14cBxeZJjesHLcq38cLrqV65c2xxyMfjhtc8enY55kvx8FFpsm913bcKv2J3p9MlqRWtaOOGvTDoVqksZqvbTpbH9VE54U2NjvsnLNaxpHVpjvW2025pzq3U22SWI3UH5FlbIpM5yrshUzQ7DlhyEhIsSjaRPJfigF9QoZCC/kSi85ZSyJlJnqUurydU8hpxM84sPuRWbGUm5E4ZabLWHTL5qzTqoOt1MgLyimjX5P+61K6RuZnVRclr+0RfgNnQFOYAAB42mNgYGBmgGAZBkYGELAB8hjBfBYGBSDNAoRAvuKk//8h5L18qEoGRjYGGHPEAgD7IwdleNpjYGYAg//NDEZAipEBDQAAKFUBuQAAeNpjZGBhYmBkZBTxTSzJ8EqsiA9LTS7JL9J1ys9JAYmr/uBn+CHD+EOW6Ycc8w9xlh4exjU/pv7Y9DOd9bs5/7zvC4S+WwkysDAycpu4hyYWFeWXF2WmZ5Q45xdUghkKGsmaCkYGhuYKIRmpClBLFJzz84rzi0oyS3OxWIsqxMDAwNjOwMTIyJTI9+2H1k8v0e666WWTGzj+sLHVtzS0dld210xtmtHG8d2h67tDd10ta21te1d3dXf1jNo53dO7+/rmzF6yZOmc1dPnTZ4yoXt+94zWybWTOfKnV89uWNI8p3VCeXdVd2NVdz0HXzcP12aurdybeXi28vD+6BD5kSEKAO9nb1wAAAAAAQAAAADMPaLPAAAAANVV8QIAAAAA1ZO2KnjaY2BkYGDgAWIRIGaEQhYwmwEAAxYAKwI/AAAAIQAA"},function(e,t,n){"use strict";n.d(t,"a",(function(){return s}));var r,i=n(2),o=function(){function e(e){this._root=new r.LeafNode,this.cmp=e}return Object.defineProperty(e.prototype,"isEmpty",{get:function(){return 0===this._root.size},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"size",{get:function(){return this._root.size},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"first",{get:function(){var e=r.firstLeaf(this._root);return e.size>0?e.items[0]:void 0},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"last",{get:function(){var e=r.lastLeaf(this._root);return e.size>0?e.items[e.size-1]:void 0},enumerable:!0,configurable:!0}),e.prototype.iter=function(){return r.iterItems(this._root)},e.prototype.retro=function(){return r.retroItems(this._root)},e.prototype.slice=function(e,t){return r.sliceItems(this._root,e,t)},e.prototype.retroSlice=function(e,t){return r.retroSliceItems(this._root,e,t)},e.prototype.at=function(e){return r.itemAt(this._root,e)},e.prototype.has=function(e,t){return r.hasItem(this._root,e,t)},e.prototype.indexOf=function(e,t){return r.indexOf(this._root,e,t)},e.prototype.get=function(e,t){return r.getItem(this._root,e,t)},e.prototype.assign=function(e){this.clear(),this.update(e)},e.prototype.insert=function(e){var t=r.insertItem(this._root,e,this.cmp);return this._root=r.maybeSplitRoot(this._root),t},e.prototype.update=function(e){var t=this;Object(i.each)(e,(function(e){t.insert(e)}))},e.prototype.delete=function(e,t){var n=r.deleteItem(this._root,e,t);return this._root=r.maybeExtractRoot(this._root),n},e.prototype.remove=function(e){var t=r.removeItem(this._root,e);return this._root=r.maybeExtractRoot(this._root),t},e.prototype.clear=function(){r.clear(this._root),this._root=new r.LeafNode},e}();!function(e){e.from=function(t,n){var r=new e(n);return r.assign(t),r}}(o||(o={})),function(e){var t=function(){function e(){this.items=[],this.sizes=[],this.children=[]}return Object.defineProperty(e.prototype,"type",{get:function(){return 0},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"size",{get:function(){return this.sizes[this.sizes.length-1]},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"width",{get:function(){return this.children.length},enumerable:!0,configurable:!0}),e}();e.BranchNode=t;var n=function(){function e(){this.next=null,this.prev=null,this.items=[]}return Object.defineProperty(e.prototype,"type",{get:function(){return 1},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"size",{get:function(){return this.items.length},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"width",{get:function(){return this.items.length},enumerable:!0,configurable:!0}),e}();function r(e){for(;0===e.type;)e=e.children[0];return e}function o(e){for(;0===e.type;)e=e.children[e.children.length-1];return e}function a(e){0===e.type?(Object(i.each)(e.children,a),e.children.length=0,e.sizes.length=0,e.items.length=0):(e.items.length=0,e.next=null,e.prev=null)}e.LeafNode=n,e.firstLeaf=r,e.lastLeaf=o,e.iterItems=function(e){var t=r(e);return new c(t,0,-1)},e.retroItems=function(e){var t=o(e);return new u(t,t.size-1,-1)},e.sliceItems=function(e,t,n){t=void 0===t?0:t<0?Math.max(0,t+e.size):Math.min(t,e.size),n=void 0===n?e.size:n<0?Math.max(0,n+e.size):Math.min(n,e.size);var r=Math.max(0,n-t);if(0===r)return Object(i.empty)();for(;0===e.type;){var o=d(e.sizes,t);o>0&&(t-=e.sizes[o-1]),e=e.children[o]}return new c(e,t,r)},e.retroSliceItems=function(e,t,n){t=void 0===t?e.size-1:t<0?Math.max(-1,t+e.size):Math.min(t,e.size-1),n=void 0===n?-1:n<0?Math.max(-1,n+e.size):Math.min(n,e.size-1);var r=Math.max(0,t-n);if(0===r)return Object(i.empty)();for(;0===e.type;){var o=d(e.sizes,t);o>0&&(t-=e.sizes[o-1]),e=e.children[o]}return new u(e,t,r)},e.itemAt=function(e,t){if(t<0&&(t+=e.size),!(t<0||t>=e.size)){for(;0===e.type;){var n=d(e.sizes,t);n>0&&(t-=e.sizes[n-1]),e=e.children[n]}return e.items[t]}},e.hasItem=function(e,t,n){for(;0===e.type;){var r=h(e.items,t,n);e=e.children[r]}return p(e.items,t,n)>=0},e.indexOf=function(e,t,n){for(var r=0;0===e.type;){var i=h(e.items,t,n);i>0&&(r+=e.sizes[i-1]),e=e.children[i]}var o=p(e.items,t,n);return o>=0?r+o:-r+o},e.getItem=function(e,t,n){for(;0===e.type;){var r=h(e.items,t,n);e=e.children[r]}var i=p(e.items,t,n);return i>=0?e.items[i]:void 0},e.insertItem=function e(t,n,r){if(1===t.type){var o,a=p(t.items,n,r);return a>=0?(o=t.items[a],t.items[a]=n):(o=void 0,i.ArrayExt.insert(t.items,-a-1,n)),o}var l=h(t.items,n,r),c=t.children[l],u=c.size,d=e(c,n,r),g=c.size;if(t.items[l]=c.items[0],u===g)return d;if(c.width>s){var v=m(c);i.ArrayExt.insert(t.children,l+1,v),i.ArrayExt.insert(t.items,l+1,v.items[0])}return f(t,l),d},e.deleteItem=function e(t,n,r){if(1===t.type){var o=p(t.items,n,r);if(o<0)return;return i.ArrayExt.removeAt(t.items,o)}var a=h(t.items,n,r),s=t.children[a],c=s.size,u=e(s,n,r);return c===s.size||(t.items[a]=s.items[0],s.width<l&&(a=g(t,a)),f(t,a)),u},e.removeItem=function e(t,n){if(n<0&&(n+=t.size),!(n<0||n>=t.size)){if(1===t.type)return i.ArrayExt.removeAt(t.items,n);var r=d(t.sizes,n);r>0&&(n-=t.sizes[r]);var o=t.children[r],a=e(o,n);return t.items[r]=o.items[0],o.width<l&&(r=g(t,r)),f(t,r),a}},e.clear=a,e.maybeSplitRoot=function(e){if(e.width<=s)return e;var n=new t,r=m(e);return n.sizes[0]=e.size,n.sizes[1]=e.size+r.size,n.children[0]=e,n.children[1]=r,n.items[0]=e.items[0],n.items[1]=r.items[0],n},e.maybeExtractRoot=function(e){if(1===e.type)return e;if(e.children.length>1)return e;var t=e.children.pop();return a(e),t};var s=32,l=s>>1,c=function(){function e(e,t,n){this._node=e,this._index=t,this._count=n}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node,this._index,this._count)},e.prototype.next=function(){if(null!==this._node&&0!==this._count)return this._index>=this._node.size?(this._node=this._node.next,this._index=0,this.next()):(this._count>0&&this._count--,this._node.items[this._index++])},e}(),u=function(){function e(e,t,n){this._node=e,this._index=t,this._count=n}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node,this._index,this._count)},e.prototype.next=function(){if(null!==this._node&&0!==this._count)return this._index>=this._node.size&&(this._index=this._node.size-1),this._index<0?(this._node=this._node.prev,this._index=this._node?this._node.size-1:-1,this.next()):(this._count>0&&this._count--,this._node.items[this._index--])},e}();function d(e,t){for(var n=e.length,r=0;r<n;++r)if(e[r]>t)return r;return n-1}function h(e,t,n){for(var r=e.length,i=1;i<r;++i)if(n(e[i],t)>0)return i-1;return r-1}function p(e,t,n){for(var r=e.length,i=0;i<r;++i){var o=n(e[i],t);if(0===o)return i;if(o>0)return-i-1}return-r-1}function f(e,t){for(var n=e.sizes,r=e.children,i=t>0?n[t-1]:0,o=r.length;t<o;++t)i=n[t]=i+r[t].size;n.length=r.length}function m(e){if(1===e.type){for(var r=new n,i=e.items,o=r.items,a=l,s=i.length;a<s;++a)o.push(i[a]);return i.length=l,e.next&&(e.next.prev=r),r.next=e.next,r.prev=e,e.next=r,r}var c=new t,u=e.children,d=c.children;for(a=l,s=u.length;a<s;++a)d.push(u[a]);u.length=l;var h=e.items,p=c.items;for(a=l,s=h.length;a<s;++a)p.push(h[a]);return h.length=l,f(e,l),f(c,0),c}function g(e,t){var n,r,o,s,c,u,d=e.children[t],h=0===t?e.children[t+1]:e.children[t-1],p=0===t,m=1===d.type,g=h.width>l;if(m&&g&&p){var v=h;return(y=d).items.push(v.items.shift()),e.items[t+1]=v.items[0],t}if(m&&g&&!p){v=h;return(y=d).items.unshift(v.items.pop()),e.items[t]=y.items[0],t-1}if(m&&!g&&p){var y=d;return(n=(v=h).items).unshift.apply(n,y.items),i.ArrayExt.removeAt(e.children,t),i.ArrayExt.removeAt(e.items,t+1),y.prev&&(y.prev.next=v),v.prev=y.prev,a(y),t}if(m&&!g&&!p){y=d;return(r=(v=h).items).push.apply(r,y.items),i.ArrayExt.removeAt(e.children,t),i.ArrayExt.removeAt(e.items,t),y.next&&(y.next.prev=v),v.next=y.next,a(y),t-1}if(!m&&g&&p){v=h;return(y=d).children.push(v.children.shift()),y.items.push(v.items.shift()),e.items[t+1]=v.items[0],f(y,y.width-1),f(v,0),t}if(!m&&g&&!p){v=h;return(y=d).children.unshift(v.children.pop()),y.items.unshift(v.items.pop()),e.items[t]=y.items[0],f(y,0),f(v,v.width-1),t-1}if(!m&&!g&&p){y=d;return(o=(v=h).children).unshift.apply(o,y.children),(s=v.items).unshift.apply(s,y.items),i.ArrayExt.removeAt(e.children,t),i.ArrayExt.removeAt(e.items,t+1),f(v,0),y.children.length=0,a(y),t}if(!m&&!g&&!p){y=d;return(c=(v=h).children).push.apply(c,y.children),(u=v.items).push.apply(u,y.items),i.ArrayExt.removeAt(e.children,t),i.ArrayExt.removeAt(e.items,t),f(v,0),y.children.length=0,a(y),t-1}throw"unreachable"}}(r||(r={}));var a,s=function(){function e(){this._first=null,this._last=null,this._size=0}return Object.defineProperty(e.prototype,"isEmpty",{get:function(){return 0===this._size},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"size",{get:function(){return this._size},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"length",{get:function(){return this._size},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"first",{get:function(){return this._first?this._first.value:void 0},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"last",{get:function(){return this._last?this._last.value:void 0},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"firstNode",{get:function(){return this._first},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"lastNode",{get:function(){return this._last},enumerable:!0,configurable:!0}),e.prototype.iter=function(){return new e.ForwardValueIterator(this._first)},e.prototype.retro=function(){return new e.RetroValueIterator(this._last)},e.prototype.nodes=function(){return new e.ForwardNodeIterator(this._first)},e.prototype.retroNodes=function(){return new e.RetroNodeIterator(this._last)},e.prototype.assign=function(e){var t=this;this.clear(),Object(i.each)(e,(function(e){t.addLast(e)}))},e.prototype.push=function(e){this.addLast(e)},e.prototype.pop=function(){return this.removeLast()},e.prototype.shift=function(e){this.addFirst(e)},e.prototype.unshift=function(){return this.removeFirst()},e.prototype.addFirst=function(e){var t=new a.LinkedListNode(this,e);return this._first?(t.next=this._first,this._first.prev=t,this._first=t):(this._first=t,this._last=t),this._size++,t},e.prototype.addLast=function(e){var t=new a.LinkedListNode(this,e);return this._last?(t.prev=this._last,this._last.next=t,this._last=t):(this._first=t,this._last=t),this._size++,t},e.prototype.insertBefore=function(e,t){if(!t||t===this._first)return this.addFirst(e);if(!(t instanceof a.LinkedListNode)||t.list!==this)throw new Error("Reference node is not owned by the list.");var n=new a.LinkedListNode(this,e),r=t,i=r.prev;return n.next=r,n.prev=i,r.prev=n,i.next=n,this._size++,n},e.prototype.insertAfter=function(e,t){if(!t||t===this._last)return this.addLast(e);if(!(t instanceof a.LinkedListNode)||t.list!==this)throw new Error("Reference node is not owned by the list.");var n=new a.LinkedListNode(this,e),r=t,i=r.next;return n.next=i,n.prev=r,r.next=n,i.prev=n,this._size++,n},e.prototype.removeFirst=function(){var e=this._first;if(e)return e===this._last?(this._first=null,this._last=null):(this._first=e.next,this._first.prev=null),e.list=null,e.next=null,e.prev=null,this._size--,e.value},e.prototype.removeLast=function(){var e=this._last;if(e)return e===this._first?(this._first=null,this._last=null):(this._last=e.prev,this._last.next=null),e.list=null,e.next=null,e.prev=null,this._size--,e.value},e.prototype.removeNode=function(e){if(!(e instanceof a.LinkedListNode)||e.list!==this)throw new Error("Node is not owned by the list.");var t=e;t===this._first&&t===this._last?(this._first=null,this._last=null):t===this._first?(this._first=t.next,this._first.prev=null):t===this._last?(this._last=t.prev,this._last.next=null):(t.next.prev=t.prev,t.prev.next=t.next),t.list=null,t.next=null,t.prev=null,this._size--},e.prototype.clear=function(){for(var e=this._first;e;){var t=e.next;e.list=null,e.prev=null,e.next=null,e=t}this._first=null,this._last=null,this._size=0},e}();!function(e){e.from=function(t){var n=new e;return n.assign(t),n};var t=function(){function e(e){this._node=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node)},e.prototype.next=function(){if(this._node){var e=this._node;return this._node=e.next,e.value}},e}();e.ForwardValueIterator=t;var n=function(){function e(e){this._node=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node)},e.prototype.next=function(){if(this._node){var e=this._node;return this._node=e.prev,e.value}},e}();e.RetroValueIterator=n;var r=function(){function e(e){this._node=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node)},e.prototype.next=function(){if(this._node){var e=this._node;return this._node=e.next,e}},e}();e.ForwardNodeIterator=r;var i=function(){function e(e){this._node=e}return e.prototype.iter=function(){return this},e.prototype.clone=function(){return new e(this._node)},e.prototype.next=function(){if(this._node){var e=this._node;return this._node=e.prev,e}},e}();e.RetroNodeIterator=i}(s||(s={})),function(e){var t=function(e,t){this.list=null,this.next=null,this.prev=null,this.list=e,this.value=t};e.LinkedListNode=t}(a||(a={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r,i=n(2),o=n(4);class a{constructor(e={}){this._array=[],this._isDisposed=!1,this._changed=new o.Signal(this),void 0!==e.values&&Object(i.each)(e.values,e=>{this._array.push(e)}),this._itemCmp=e.itemCmp||r.itemCmp}get type(){return"List"}get changed(){return this._changed}get length(){return this._array.length}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed||(this._isDisposed=!0,o.Signal.clearData(this),this.clear())}iter(){return new i.ArrayIterator(this._array)}get(e){return this._array[e]}set(e,t){const n=this._array[e];if(void 0===t)throw new Error("Cannot set an undefined item");(0,this._itemCmp)(n,t)||(this._array[e]=t,this._changed.emit({type:"set",oldIndex:e,newIndex:e,oldValues:[n],newValues:[t]}))}push(e){const t=this._array.push(e);return this._changed.emit({type:"add",oldIndex:-1,newIndex:this.length-1,oldValues:[],newValues:[e]}),t}insert(e,t){e===this._array.length?this._array.push(t):i.ArrayExt.insert(this._array,e,t),this._changed.emit({type:"add",oldIndex:-2,newIndex:e,oldValues:[],newValues:[t]})}removeValue(e){const t=this._itemCmp,n=i.ArrayExt.findFirstIndex(this._array,n=>t(n,e));return this.remove(n),n}remove(e){const t=i.ArrayExt.removeAt(this._array,e);if(void 0!==t)return this._changed.emit({type:"remove",oldIndex:e,newIndex:-1,newValues:[],oldValues:[t]}),t}clear(){const e=this._array.slice();this._array.length=0,this._changed.emit({type:"remove",oldIndex:0,newIndex:0,newValues:[],oldValues:e})}move(e,t){if(this.length<=1||e===t)return;const n=[this._array[e]];i.ArrayExt.move(this._array,e,t),this._changed.emit({type:"move",oldIndex:e,newIndex:t,oldValues:n,newValues:n})}pushAll(e){const t=this.length;return Object(i.each)(e,e=>{this._array.push(e)}),this._changed.emit({type:"add",oldIndex:-1,newIndex:t,oldValues:[],newValues:Object(i.toArray)(e)}),this.length}insertAll(e,t){const n=e;Object(i.each)(t,t=>{i.ArrayExt.insert(this._array,e++,t)}),this._changed.emit({type:"add",oldIndex:-2,newIndex:n,oldValues:[],newValues:Object(i.toArray)(t)})}removeRange(e,t){const n=this._array.slice(e,t);for(let n=e;n<t;n++)i.ArrayExt.removeAt(this._array,e);return this._changed.emit({type:"remove",oldIndex:e,newIndex:-1,oldValues:n,newValues:[]}),this.length}}!function(e){e.itemCmp=function(e,t){return e===t}}(r||(r={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r=n(6),i=n(8),o=n(144);class a extends o.a{constructor(e={}){super({itemCmp:r.JSONExt.deepEqual,values:e.values})}toJSON(){const e=Object.create(null),t=this.keys();for(const n of t){const t=this.get(n);void 0!==t&&(e[n]=r.JSONExt.deepCopy(t))}return e}}!function(e){class t extends i.b{constructor(e,t){super(e),this.args=t}}e.ChangeMessage=t}(a||(a={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return o}));let r=new class{constructor(){this.map=new Map}setItem(e,t){this.map.set(e,t)}getItem(e){return this.map.get(e)}},i=!0;try{"undefined"!=typeof localStorage&&(r=localStorage,i=!1)}catch(e){}const o=r},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AnchorButton=t.Button=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(84),a=n(170),s=n(693),l=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buttonRef=null,t.handleRef=a.refHandler(t,"buttonRef",t.props.elementRef),t}return r.__extends(t,e),t.prototype.render=function(){return i.createElement("button",r.__assign({type:"button",ref:this.handleRef},o.removeNonHTMLProps(this.props),this.getCommonButtonProps()),this.renderChildren())},t.prototype.componentDidUpdate=function(e){e.elementRef!==this.props.elementRef&&(a.setRef(e.elementRef,null),this.handleRef=a.refHandler(this,"buttonRef",this.props.elementRef),a.setRef(this.props.elementRef,this.buttonRef))},t.displayName=o.DISPLAYNAME_PREFIX+".Button",t}(s.AbstractButton);t.Button=l;var c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buttonRef=null,t.handleRef=a.refHandler(t,"buttonRef",t.props.elementRef),t}return r.__extends(t,e),t.prototype.render=function(){var e=this.props,t=e.href,n=e.tabIndex,a=void 0===n?0:n,s=this.getCommonButtonProps();return i.createElement("a",r.__assign({role:"button",ref:this.handleRef},o.removeNonHTMLProps(this.props),s,{href:s.disabled?void 0:t,tabIndex:s.disabled?-1:a}),this.renderChildren())},t.prototype.componentDidUpdate=function(e){e.elementRef!==this.props.elementRef&&(a.setRef(e.elementRef,null),this.handleRef=a.refHandler(this,"buttonRef",this.props.elementRef),a.setRef(this.props.elementRef,this.buttonRef))},t.displayName=o.DISPLAYNAME_PREFIX+".AnchorButton",t}(s.AbstractButton);t.AnchorButton=c},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoCiAgICAgICAgY2xhc3M9ImpwLWljb24wIgogICAgICAgIGZpbGw9IiMwMDAiCiAgICAgICAgZD0iTTI0IDIwLjE4OGwtOC4zMTUtOC4yMDkgOC4yLTguMjgyLTMuNjk3LTMuNjk3LTguMjEyIDguMzE4LTguMzEtOC4yMDMtMy42NjYgMy42NjYgOC4zMjEgOC4yNC04LjIwNiA4LjMxMyAzLjY2NiAzLjY2NiA4LjIzNy04LjMxOCA4LjI4NSA4LjIwM3oiCiAgICAvPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoCiAgICAgICAgZmlsbD0iIzAwMCIKICAgICAgICBmaWxsLW9wYWNpdHk9IjAuMCIKICAgICAgICBkPSJNMjQgMjAuMTg4bC04LjMxNS04LjIwOSA4LjItOC4yODItMy42OTctMy42OTctOC4yMTIgOC4zMTgtOC4zMS04LjIwMy0zLjY2NiAzLjY2NiA4LjMyMSA4LjI0LTguMjA2IDguMzEzIDMuNjY2IDMuNjY2IDguMjM3LTguMzE4IDguMjg1IDguMjAzeiIKICAgIC8+Cjwvc3ZnPgo="},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Collapse=t.AnimationStates=void 0;var r,i=n(1),o=i.__importDefault(n(5)),a=i.__importStar(n(0)),s=n(9),l=n(91),c=n(84);!function(e){e[e.OPEN_START=0]="OPEN_START",e[e.OPENING=1]="OPENING",e[e.OPEN=2]="OPEN",e[e.CLOSING_START=3]="CLOSING_START",e[e.CLOSING=4]="CLOSING",e[e.CLOSED=5]="CLOSED"}(r=t.AnimationStates||(t.AnimationStates={}));var u=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={animationState:t.props.isOpen?r.OPEN:r.CLOSED,height:void 0,heightWhenOpen:void 0},t.contents=null,t.contentsRefHandler=function(e){if(t.contents=e,null!=t.contents){var n=t.contents.clientHeight;t.setState({animationState:t.props.isOpen?r.OPEN:r.CLOSED,height:0===n?void 0:n+"px",heightWhenOpen:0===n?void 0:n})}},t}return i.__extends(t,e),t.getDerivedStateFromProps=function(e,t){var n=e.isOpen,i=t.animationState;if(n)switch(i){case r.OPEN:case r.OPENING:break;default:return{animationState:r.OPEN_START}}else switch(i){case r.CLOSED:case r.CLOSING:break;default:return{animationState:r.CLOSING_START,height:t.heightWhenOpen+"px"}}return null},t.prototype.render=function(){var e=this.state.animationState!==r.CLOSED,t=e||this.props.keepChildrenMounted,n=e&&this.state.animationState!==r.CLOSING,i="auto"===this.state.height,s={height:e?this.state.height:void 0,overflowY:i?"visible":void 0,transition:i?"none":void 0},c={transform:n?"translateY(0)":"translateY(-"+this.state.heightWhenOpen+"px)",transition:i?"none":void 0};return a.createElement(this.props.component,{className:o.default(l.Classes.COLLAPSE,this.props.className),style:s},a.createElement("div",{className:l.Classes.COLLAPSE_BODY,ref:this.contentsRefHandler,style:c,"aria-hidden":!e&&this.props.keepChildrenMounted},t?this.props.children:null))},t.prototype.componentDidMount=function(){this.forceUpdate(),this.props.isOpen?this.setState({animationState:r.OPEN,height:"auto"}):this.setState({animationState:r.CLOSED,height:"0px"})},t.prototype.componentDidUpdate=function(){var e=this;if(null!=this.contents){var t=this.props.transitionDuration,n=this.state.animationState;if(n===r.OPEN_START){var i=this.contents.clientHeight;this.setState({animationState:r.OPENING,height:i+"px",heightWhenOpen:i}),this.setTimeout((function(){return e.onDelayedStateChange()}),t)}else if(n===r.CLOSING_START){var o=this.contents.clientHeight;this.setTimeout((function(){return e.setState({animationState:r.CLOSING,height:"0px",heightWhenOpen:o})})),this.setTimeout((function(){return e.onDelayedStateChange()}),t)}}},t.prototype.onDelayedStateChange=function(){switch(this.state.animationState){case r.OPENING:this.setState({animationState:r.OPEN,height:"auto"});break;case r.CLOSING:this.setState({animationState:r.CLOSED})}},t.displayName=c.DISPLAYNAME_PREFIX+".Collapse",t.defaultProps={component:"div",isOpen:!1,keepChildrenMounted:!1,transitionDuration:200},t=i.__decorate([s.polyfill],t)}(l.AbstractPureComponent2);t.Collapse=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Select=void 0;var r=n(1),i=r.__importDefault(n(5)),o=r.__importStar(n(0)),a=n(138),s=n(400),l=n(746),c=function(e){function t(){var t,n=e.apply(this,arguments)||this;return n.state={isOpen:!1},n.TypedQueryList=l.QueryList.ofType(),n.inputElement=null,n.queryList=null,n.handleInputRef=a.refHandler(n,"inputElement",null===(t=n.props.inputProps)||void 0===t?void 0:t.inputRef),n.handleQueryListRef=function(e){return n.queryList=e},n.renderQueryList=function(e){var t,l=n.props,c=l.fill,u=l.filterable,d=void 0===u||u,h=l.disabled,p=void 0!==h&&h,f=l.inputProps,m=void 0===f?{}:f,g=l.popoverProps,v=void 0===g?{}:g,y=l.matchTargetWidth;c&&(v.fill=!0),y&&(null==v.modifiers&&(v.modifiers={}),v.modifiers.minWidth={enabled:!0,fn:function(e){return e.styles.width=e.offsets.reference.width+"px",e},order:800},v.usePortal=!1,v.wrapperTagName="div");var _=o.createElement(a.InputGroup,r.__assign({leftIcon:"search",placeholder:"Filter...",rightElement:n.maybeRenderClearButton(e.query)},m,{inputRef:n.handleInputRef,onChange:e.handleQueryChange,value:e.query})),b=e.handleKeyDown,M=e.handleKeyUp;return o.createElement(a.Popover,r.__assign({autoFocus:!1,enforceFocus:!1,isOpen:n.state.isOpen,disabled:p,position:a.Position.BOTTOM_LEFT},v,{className:i.default(e.className,v.className),onInteraction:n.handlePopoverInteraction,popoverClassName:i.default(s.Classes.SELECT_POPOVER,v.popoverClassName,(t={},t[s.Classes.SELECT_MATCH_TARGET_WIDTH]=y,t)),onOpening:n.handlePopoverOpening,onOpened:n.handlePopoverOpened,onClosing:n.handlePopoverClosing}),o.createElement("div",{onKeyDown:n.state.isOpen?b:n.handleTargetKeyDown,onKeyUp:n.state.isOpen?M:void 0},n.props.children),o.createElement("div",{onKeyDown:b,onKeyUp:M},d?_:void 0,e.itemList))},n.handleTargetKeyDown=function(e){e.which!==a.Keys.ARROW_UP&&e.which!==a.Keys.ARROW_DOWN||(e.preventDefault(),n.setState({isOpen:!0}))},n.handleItemSelect=function(e,t){var r,i;n.setState({isOpen:!1}),null===(i=(r=n.props).onItemSelect)||void 0===i||i.call(r,e,t)},n.handlePopoverInteraction=function(e,t){var r,i;n.setState({isOpen:e}),null===(i=null===(r=n.props.popoverProps)||void 0===r?void 0:r.onInteraction)||void 0===i||i.call(r,e,t)},n.handlePopoverOpening=function(e){var t,r;n.previousFocusedElement=document.activeElement,n.props.resetOnClose&&n.resetQuery(),null===(r=null===(t=n.props.popoverProps)||void 0===t?void 0:t.onOpening)||void 0===r||r.call(t,e)},n.handlePopoverOpened=function(e){var t,r;null!=n.queryList&&n.queryList.scrollActiveItemIntoView(),n.requestAnimationFrame((function(){var e,t=n.props.inputProps;!1!==(void 0===t?{}:t).autoFocus&&(null===(e=n.inputElement)||void 0===e||e.focus())})),null===(r=null===(t=n.props.popoverProps)||void 0===t?void 0:t.onOpened)||void 0===r||r.call(t,e)},n.handlePopoverClosing=function(e){var t,r;n.requestAnimationFrame((function(){void 0!==n.previousFocusedElement&&(n.previousFocusedElement.focus(),n.previousFocusedElement=void 0)})),null===(r=null===(t=n.props.popoverProps)||void 0===t?void 0:t.onClosing)||void 0===r||r.call(t,e)},n.resetQuery=function(){return n.queryList&&n.queryList.setQuery("",!0)},n}return r.__extends(t,e),t.ofType=function(){return t},t.prototype.render=function(){var e=this.props,t=(e.filterable,e.inputProps,e.popoverProps,r.__rest(e,["filterable","inputProps","popoverProps"]));return o.createElement(this.TypedQueryList,r.__assign({},t,{onItemSelect:this.handleItemSelect,ref:this.handleQueryListRef,renderer:this.renderQueryList}))},t.prototype.componentDidUpdate=function(e,t){var n,r,i,o,s;(null===(n=e.inputProps)||void 0===n?void 0:n.inputRef)!==(null===(r=this.props.inputProps)||void 0===r?void 0:r.inputRef)&&(a.setRef(null===(i=e.inputProps)||void 0===i?void 0:i.inputRef,null),this.handleInputRef=a.refHandler(this,"inputElement",null===(o=this.props.inputProps)||void 0===o?void 0:o.inputRef),a.setRef(null===(s=this.props.inputProps)||void 0===s?void 0:s.inputRef,this.inputElement)),this.state.isOpen&&!t.isOpen&&null!=this.queryList&&this.queryList.scrollActiveItemIntoView()},t.prototype.maybeRenderClearButton=function(e){return e.length>0?o.createElement(a.Button,{icon:"cross",minimal:!0,onClick:this.resetQuery}):void 0},t.displayName=a.DISPLAYNAME_PREFIX+".Select",t}(a.AbstractPureComponent2);t.Select=c},function(e,t){e.exports=function(e,t){if(null==e)return{};var n,r,i={},o=Object.keys(e);for(r=0;r<o.length;r++)n=o[r],t.indexOf(n)>=0||(i[n]=e[n]);return i},e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){var r=n(391),i=n(730),o=n(734),a=n(736),s=n(737),l=n(739),c=Date.prototype.getTime;function u(e,t,n){var p=n||{};return!!(p.strict?o(e,t):e===t)||(!e||!t||"object"!=typeof e&&"object"!=typeof t?p.strict?o(e,t):e==t:function(e,t,n){var o,p;if(typeof e!=typeof t)return!1;if(d(e)||d(t))return!1;if(e.prototype!==t.prototype)return!1;if(i(e)!==i(t))return!1;var f=a(e),m=a(t);if(f!==m)return!1;if(f||m)return e.source===t.source&&s(e)===s(t);if(l(e)&&l(t))return c.call(e)===c.call(t);var g=h(e),v=h(t);if(g!==v)return!1;if(g||v){if(e.length!==t.length)return!1;for(o=0;o<e.length;o++)if(e[o]!==t[o])return!1;return!0}if(typeof e!=typeof t)return!1;try{var y=r(e),_=r(t)}catch(e){return!1}if(y.length!==_.length)return!1;for(y.sort(),_.sort(),o=y.length-1;o>=0;o--)if(y[o]!=_[o])return!1;for(o=y.length-1;o>=0;o--)if(p=y[o],!u(e[p],t[p],n))return!1;return!0}(e,t,p))}function d(e){return null==e}function h(e){return!(!e||"object"!=typeof e||"number"!=typeof e.length)&&("function"==typeof e.copy&&"function"==typeof e.slice&&!(e.length>0&&"number"!=typeof e[0]))}e.exports=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Checkbox=t.Radio=t.Switch=void 0;var r=n(1),i=r.__importDefault(n(5)),o=r.__importStar(n(0)),a=n(9),s=n(91),l=n(84),c=function(e){var t,n=e.alignIndicator,a=e.children,l=e.className,c=e.indicatorChildren,u=e.inline,d=e.inputRef,h=e.label,p=e.labelElement,f=e.large,m=e.style,g=e.type,v=e.typeClassName,y=e.tagName,_=void 0===y?"label":y,b=r.__rest(e,["alignIndicator","children","className","indicatorChildren","inline","inputRef","label","labelElement","large","style","type","typeClassName","tagName"]),M=i.default(s.Classes.CONTROL,v,((t={})[s.Classes.DISABLED]=b.disabled,t[s.Classes.INLINE]=u,t[s.Classes.LARGE]=f,t),s.Classes.alignmentClass(n),l);return o.createElement(_,{className:M,style:m},o.createElement("input",r.__assign({},b,{ref:d,type:g})),o.createElement("span",{className:s.Classes.CONTROL_INDICATOR},c),h,p,a)},u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return r.__extends(t,e),t.prototype.render=function(){var e=this.props,t=e.innerLabelChecked,n=e.innerLabel,i=r.__rest(e,["innerLabelChecked","innerLabel"]),a=n||t?[o.createElement("div",{key:"checked",className:s.Classes.CONTROL_INDICATOR_CHILD},o.createElement("div",{className:s.Classes.SWITCH_INNER_TEXT},t||n)),o.createElement("div",{key:"unchecked",className:s.Classes.CONTROL_INDICATOR_CHILD},o.createElement("div",{className:s.Classes.SWITCH_INNER_TEXT},n))]:null;return o.createElement(c,r.__assign({},i,{type:"checkbox",typeClassName:s.Classes.SWITCH,indicatorChildren:a}))},t.displayName=l.DISPLAYNAME_PREFIX+".Switch",t=r.__decorate([a.polyfill],t)}(s.AbstractPureComponent2);t.Switch=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return r.__extends(t,e),t.prototype.render=function(){return o.createElement(c,r.__assign({},this.props,{type:"radio",typeClassName:s.Classes.RADIO}))},t.displayName=l.DISPLAYNAME_PREFIX+".Radio",t=r.__decorate([a.polyfill],t)}(s.AbstractPureComponent2);t.Radio=d;var h=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={indeterminate:t.props.indeterminate||t.props.defaultIndeterminate||!1},t.input=null,t.handleInputRef=s.refHandler(t,"input",t.props.inputRef),t.handleChange=function(e){var n,r,i=e.target.indeterminate;null==t.props.indeterminate&&t.setState({indeterminate:i}),null===(r=(n=t.props).onChange)||void 0===r||r.call(n,e)},t}return r.__extends(t,e),t.getDerivedStateFromProps=function(e){var t=e.indeterminate;return null!=t?{indeterminate:t}:null},t.prototype.render=function(){var e=this.props,t=(e.defaultIndeterminate,e.indeterminate,r.__rest(e,["defaultIndeterminate","indeterminate"]));return o.createElement(c,r.__assign({},t,{inputRef:this.handleInputRef,onChange:this.handleChange,type:"checkbox",typeClassName:s.Classes.CHECKBOX}))},t.prototype.componentDidMount=function(){this.updateIndeterminate()},t.prototype.componentDidUpdate=function(e){this.updateIndeterminate(),e.inputRef!==this.props.inputRef&&(s.setRef(e.inputRef,null),this.handleInputRef=s.refHandler(this,"input",this.props.inputRef),s.setRef(this.props.inputRef,this.input))},t.prototype.updateIndeterminate=function(){null!=this.input&&(this.input.indeterminate=this.state.indeterminate)},t.displayName=l.DISPLAYNAME_PREFIX+".Checkbox",t=r.__decorate([a.polyfill],t)}(s.AbstractPureComponent2);t.Checkbox=h},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTE5IDEzaC02djZoLTJ2LTZINXYtMmg2VjVoMnY2aDZ2MnoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjQiIGhlaWdodD0iMjQiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiM2MTYxNjEiPgogICAgICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgY2xpcC1ydWxlPSJldmVub2RkIiBkPSJNMTcuMTkgOEgyMFYxMEgxNy45MUMxNy45NiAxMC4zMyAxOCAxMC42NiAxOCAxMVYxMkgyMFYxNEgxOC41SDE4VjE0LjAyNzVDMTUuNzUgMTQuMjc2MiAxNCAxNi4xODM3IDE0IDE4LjVDMTQgMTkuMjA4IDE0LjE2MzUgMTkuODc3OSAxNC40NTQ5IDIwLjQ3MzlDMTMuNzA2MyAyMC44MTE3IDEyLjg3NTcgMjEgMTIgMjFDOS43OCAyMSA3Ljg1IDE5Ljc5IDYuODEgMThINFYxNkg2LjA5QzYuMDQgMTUuNjcgNiAxNS4zNCA2IDE1VjE0SDRWMTJINlYxMUM2IDEwLjY2IDYuMDQgMTAuMzMgNi4wOSAxMEg0VjhINi44MUM3LjI2IDcuMjIgNy44OCA2LjU1IDguNjIgNi4wNEw3IDQuNDFMOC40MSAzTDEwLjU5IDUuMTdDMTEuMDQgNS4wNiAxMS41MSA1IDEyIDVDMTIuNDkgNSAxMi45NiA1LjA2IDEzLjQyIDUuMTdMMTUuNTkgM0wxNyA0LjQxTDE1LjM3IDYuMDRDMTYuMTIgNi41NSAxNi43NCA3LjIyIDE3LjE5IDhaTTEwIDE2SDE0VjE0SDEwVjE2Wk0xMCAxMkgxNFYxMEgxMFYxMloiIGZpbGw9IiM2MTYxNjEiLz4KICAgICAgICA8cGF0aCBkPSJNMjIgMTguNUMyMiAyMC40MzMgMjAuNDMzIDIyIDE4LjUgMjJDMTYuNTY3IDIyIDE1IDIwLjQzMyAxNSAxOC41QzE1IDE2LjU2NyAxNi41NjcgMTUgMTguNSAxNUMyMC40MzMgMTUgMjIgMTYuNTY3IDIyIDE4LjVaIiBmaWxsPSIjNjE2MTYxIi8+CiAgICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIj4KICAgIDxwYXRoIGQ9Ik0yMCA4aC0yLjgxYy0uNDUtLjc4LTEuMDctMS40NS0xLjgyLTEuOTZMMTcgNC40MSAxNS41OSAzbC0yLjE3IDIuMTdDMTIuOTYgNS4wNiAxMi40OSA1IDEyIDVjLS40OSAwLS45Ni4wNi0xLjQxLjE3TDguNDEgMyA3IDQuNDFsMS42MiAxLjYzQzcuODggNi41NSA3LjI2IDcuMjIgNi44MSA4SDR2MmgyLjA5Yy0uMDUuMzMtLjA5LjY2LS4wOSAxdjFINHYyaDJ2MWMwIC4zNC4wNC42Ny4wOSAxSDR2MmgyLjgxYzEuMDQgMS43OSAyLjk3IDMgNS4xOSAzczQuMTUtMS4yMSA1LjE5LTNIMjB2LTJoLTIuMDljLjA1LS4zMy4wOS0uNjYuMDktMXYtMWgydi0yaC0ydi0xYzAtLjM0LS4wNC0uNjctLjA5LTFIMjBWOHptLTYgOGgtNHYtMmg0djJ6bTAtNGgtNHYtMmg0djJ6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTYiIHZpZXdCb3g9IjAgMCAyNCAyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTE0LjkgMTcuNDVDMTYuMjUgMTcuNDUgMTcuMzUgMTYuMzUgMTcuMzUgMTVDMTcuMzUgMTMuNjUgMTYuMjUgMTIuNTUgMTQuOSAxMi41NUMxMy41NCAxMi41NSAxMi40NSAxMy42NSAxMi40NSAxNUMxMi40NSAxNi4zNSAxMy41NCAxNy40NSAxNC45IDE3LjQ1Wk0yMC4xIDE1LjY4TDIxLjU4IDE2Ljg0QzIxLjcxIDE2Ljk1IDIxLjc1IDE3LjEzIDIxLjY2IDE3LjI5TDIwLjI2IDE5LjcxQzIwLjE3IDE5Ljg2IDIwIDE5LjkyIDE5LjgzIDE5Ljg2TDE4LjA5IDE5LjE2QzE3LjczIDE5LjQ0IDE3LjMzIDE5LjY3IDE2LjkxIDE5Ljg1TDE2LjY0IDIxLjdDMTYuNjIgMjEuODcgMTYuNDcgMjIgMTYuMyAyMkgxMy41QzEzLjMyIDIyIDEzLjE4IDIxLjg3IDEzLjE1IDIxLjdMMTIuODkgMTkuODVDMTIuNDYgMTkuNjcgMTIuMDcgMTkuNDQgMTEuNzEgMTkuMTZMOS45NjAwMiAxOS44NkM5LjgxMDAyIDE5LjkyIDkuNjIwMDIgMTkuODYgOS41NDAwMiAxOS43MUw4LjE0MDAyIDE3LjI5QzguMDUwMDIgMTcuMTMgOC4wOTAwMiAxNi45NSA4LjIyMDAyIDE2Ljg0TDkuNzAwMDIgMTUuNjhMOS42NTAwMSAxNUw5LjcwMDAyIDE0LjMxTDguMjIwMDIgMTMuMTZDOC4wOTAwMiAxMy4wNSA4LjA1MDAyIDEyLjg2IDguMTQwMDIgMTIuNzFMOS41NDAwMiAxMC4yOUM5LjYyMDAyIDEwLjEzIDkuODEwMDIgMTAuMDcgOS45NjAwMiAxMC4xM0wxMS43MSAxMC44NEMxMi4wNyAxMC41NiAxMi40NiAxMC4zMiAxMi44OSAxMC4xNUwxMy4xNSA4LjI4OTk4QzEzLjE4IDguMTI5OTggMTMuMzIgNy45OTk5OCAxMy41IDcuOTk5OThIMTYuM0MxNi40NyA3Ljk5OTk4IDE2LjYyIDguMTI5OTggMTYuNjQgOC4yODk5OEwxNi45MSAxMC4xNUMxNy4zMyAxMC4zMiAxNy43MyAxMC41NiAxOC4wOSAxMC44NEwxOS44MyAxMC4xM0MyMCAxMC4wNyAyMC4xNyAxMC4xMyAyMC4yNiAxMC4yOUwyMS42NiAxMi43MUMyMS43NSAxMi44NiAyMS43MSAxMy4wNSAyMS41OCAxMy4xNkwyMC4xIDE0LjMxTDIwLjE1IDE1TDIwLjEgMTUuNjhaIi8+CiAgICA8cGF0aCBkPSJNNy4zMjk2NiA3LjQ0NDU0QzguMDgzMSA3LjAwOTU0IDguMzM5MzIgNi4wNTMzMiA3LjkwNDMyIDUuMjk5ODhDNy40NjkzMiA0LjU0NjQzIDYuNTA4MSA0LjI4MTU2IDUuNzU0NjYgNC43MTY1NkM1LjM5MTc2IDQuOTI2MDggNS4xMjY5NSA1LjI3MTE4IDUuMDE4NDkgNS42NzU5NEM0LjkxMDA0IDYuMDgwNzEgNC45NjY4MiA2LjUxMTk4IDUuMTc2MzQgNi44NzQ4OEM1LjYxMTM0IDcuNjI4MzIgNi41NzYyMiA3Ljg3OTU0IDcuMzI5NjYgNy40NDQ1NFpNOS42NTcxOCA0Ljc5NTkzTDEwLjg2NzIgNC45NTE3OUMxMC45NjI4IDQuOTc3NDEgMTEuMDQwMiA1LjA3MTMzIDExLjAzODIgNS4xODc5M0wxMS4wMzg4IDYuOTg4OTNDMTEuMDQ1NSA3LjEwMDU0IDEwLjk2MTYgNy4xOTUxOCAxMC44NTUgNy4yMTA1NEw5LjY2MDAxIDcuMzgwODNMOS4yMzkxNSA4LjEzMTg4TDkuNjY5NjEgOS4yNTc0NUM5LjcwNzI5IDkuMzYyNzEgOS42NjkzNCA5LjQ3Njk5IDkuNTc0MDggOS41MzE5OUw4LjAxNTIzIDEwLjQzMkM3LjkxMTMxIDEwLjQ5MiA3Ljc5MzM3IDEwLjQ2NzcgNy43MjEwNSAxMC4zODI0TDYuOTg3NDggOS40MzE4OEw2LjEwOTMxIDkuNDMwODNMNS4zNDcwNCAxMC4zOTA1QzUuMjg5MDkgMTAuNDcwMiA1LjE3MzgzIDEwLjQ5MDUgNS4wNzE4NyAxMC40MzM5TDMuNTEyNDUgOS41MzI5M0MzLjQxMDQ5IDkuNDc2MzMgMy4zNzY0NyA5LjM1NzQxIDMuNDEwNzUgOS4yNTY3OUwzLjg2MzQ3IDguMTQwOTNMMy42MTc0OSA3Ljc3NDg4TDMuNDIzNDcgNy4zNzg4M0wyLjIzMDc1IDcuMjEyOTdDMi4xMjY0NyA3LjE5MjM1IDIuMDQwNDkgNy4xMDM0MiAyLjA0MjQ1IDYuOTg2ODJMMi4wNDE4NyA1LjE4NTgyQzIuMDQzODMgNS4wNjkyMiAyLjExOTA5IDQuOTc5NTggMi4yMTcwNCA0Ljk2OTIyTDMuNDIwNjUgNC43OTM5M0wzLjg2NzQ5IDQuMDI3ODhMMy40MTEwNSAyLjkxNzMxQzMuMzczMzcgMi44MTIwNCAzLjQxMTMxIDIuNjk3NzYgMy41MTUyMyAyLjYzNzc2TDUuMDc0MDggMS43Mzc3NkM1LjE2OTM0IDEuNjgyNzYgNS4yODcyOSAxLjcwNzA0IDUuMzU5NjEgMS43OTIzMUw2LjExOTE1IDIuNzI3ODhMNi45ODAwMSAyLjczODkzTDcuNzI0OTYgMS43ODkyMkM3Ljc5MTU2IDEuNzA0NTggNy45MTU0OCAxLjY3OTIyIDguMDA4NzkgMS43NDA4Mkw5LjU2ODIxIDIuNjQxODJDOS42NzAxNyAyLjY5ODQyIDkuNzEyODUgMi44MTIzNCA5LjY4NzIzIDIuOTA3OTdMOS4yMTcxOCA0LjAzMzgzTDkuNDYzMTYgNC4zOTk4OEw5LjY1NzE4IDQuNzk1OTNaIi8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiIHNoYXBlLXJlbmRlcmluZz0iZ2VvbWV0cmljUHJlY2lzaW9uIj4KICAgIDxwYXRoIGQ9Ik01LjIsNS45TDksOS43bDMuOC0zLjhsMS4yLDEuMmwtNC45LDVsLTQuOS01TDUuMiw1Ljl6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIwIDIwIj4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSIgc2hhcGUtcmVuZGVyaW5nPSJnZW9tZXRyaWNQcmVjaXNpb24iPgoJCTxwb2x5Z29uIGNsYXNzPSJzdDEiIHBvaW50cz0iOS45LDEzLjYgMy42LDcuNCA0LjQsNi42IDkuOSwxMi4yIDE1LjQsNi43IDE2LjEsNy40ICIvPgoJPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiIHNoYXBlLXJlbmRlcmluZz0iZ2VvbWV0cmljUHJlY2lzaW9uIj4KICAgIDxwYXRoIGQ9Ik01LjIsNy41TDksMTEuMmwzLjgtMy44SDUuMnoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSIgc2hhcGUtcmVuZGVyaW5nPSJnZW9tZXRyaWNQcmVjaXNpb24iPgoJCTxwYXRoIGQ9Ik0xMC44LDEyLjhMNy4xLDlsMy44LTMuOGwwLDcuNkgxMC44eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiIHNoYXBlLXJlbmRlcmluZz0iZ2VvbWV0cmljUHJlY2lzaW9uIj4KICAgIDxwYXRoIGQ9Ik03LjIsNS4yTDEwLjksOWwtMy44LDMuOFY1LjJINy4yeiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIwIDIwIj4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSIgc2hhcGUtcmVuZGVyaW5nPSJnZW9tZXRyaWNQcmVjaXNpb24iPgoJCTxwb2x5Z29uIGNsYXNzPSJzdDEiIHBvaW50cz0iMTUuNCwxMy4zIDkuOSw3LjcgNC40LDEzLjIgMy42LDEyLjUgOS45LDYuMyAxNi4xLDEyLjYgIi8+Cgk8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDE4IDE4Ij4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSIgc2hhcGUtcmVuZGVyaW5nPSJnZW9tZXRyaWNQcmVjaXNpb24iPgoJCTxwYXRoIGQ9Ik01LjIsMTAuNUw5LDYuOGwzLjgsMy44SDUuMnoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIwIDIwIj4KICA8ZyBjbGFzcz0ianAtaWNvbjIiIGZpbGw9IiM0MTQxNDEiPgogICAgPHJlY3QgeD0iMiIgeT0iMiIgd2lkdGg9IjE2IiBoZWlnaHQ9IjE2Ii8+CiAgPC9nPgogIDxnIGNsYXNzPSJqcC1pY29uLWFjY2VudDIiIGZpbGw9IiNGRkYiPgogICAgPHBhdGggZD0iTTcuNiw4aDAuOWwzLjUsOGgtMS4xTDEwLDE0SDZsLTAuOSwySDRMNy42LDh6IE04LDkuMUw2LjQsMTNoMy4yTDgsOS4xeiIvPgogICAgPHBhdGggZD0iTTE2LjYsOS44Yy0wLjIsMC4xLTAuNCwwLjEtMC43LDAuMWMtMC4yLDAtMC40LTAuMS0wLjYtMC4yYy0wLjEtMC4xLTAuMi0wLjQtMC4yLTAuNyBjLTAuMywwLjMtMC42LDAuNS0wLjksMC43Yy0wLjMsMC4xLTAuNywwLjItMS4xLDAuMmMtMC4zLDAtMC41LDAtMC43LTAuMWMtMC4yLTAuMS0wLjQtMC4yLTAuNi0wLjNjLTAuMi0wLjEtMC4zLTAuMy0wLjQtMC41IGMtMC4xLTAuMi0wLjEtMC40LTAuMS0wLjdjMC0wLjMsMC4xLTAuNiwwLjItMC44YzAuMS0wLjIsMC4zLTAuNCwwLjQtMC41QzEyLDcsMTIuMiw2LjksMTIuNSw2LjhjMC4yLTAuMSwwLjUtMC4xLDAuNy0wLjIgYzAuMy0wLjEsMC41LTAuMSwwLjctMC4xYzAuMiwwLDAuNC0wLjEsMC42LTAuMWMwLjIsMCwwLjMtMC4xLDAuNC0wLjJjMC4xLTAuMSwwLjItMC4yLDAuMi0wLjRjMC0xLTEuMS0xLTEuMy0xIGMtMC40LDAtMS40LDAtMS40LDEuMmgtMC45YzAtMC40LDAuMS0wLjcsMC4yLTFjMC4xLTAuMiwwLjMtMC40LDAuNS0wLjZjMC4yLTAuMiwwLjUtMC4zLDAuOC0wLjNDMTMuMyw0LDEzLjYsNCwxMy45LDQgYzAuMywwLDAuNSwwLDAuOCwwLjFjMC4zLDAsMC41LDAuMSwwLjcsMC4yYzAuMiwwLjEsMC40LDAuMywwLjUsMC41QzE2LDUsMTYsNS4yLDE2LDUuNnYyLjljMCwwLjIsMCwwLjQsMCwwLjUgYzAsMC4xLDAuMSwwLjIsMC4zLDAuMmMwLjEsMCwwLjIsMCwwLjMsMFY5Ljh6IE0xNS4yLDYuOWMtMS4yLDAuNi0zLjEsMC4yLTMuMSwxLjRjMCwxLjQsMy4xLDEsMy4xLTAuNVY2Ljl6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIj4KICAgIDxwYXRoIGQ9Ik05IDE2LjE3TDQuODMgMTJsLTEuNDIgMS40MUw5IDE5IDIxIDdsLTEuNDEtMS40MXoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTEyIDJDNi40NyAyIDIgNi40NyAyIDEyczQuNDcgMTAgMTAgMTAgMTAtNC40NyAxMC0xMFMxNy41MyAyIDEyIDJ6bTAgMThjLTQuNDEgMC04LTMuNTktOC04czMuNTktOCA4LTggOCAzLjU5IDggOC0zLjU5IDgtOCA4eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMTggMTgiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPGNpcmNsZSBjeD0iOSIgY3k9IjkiIHI9IjgiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8bWFzayBpZD0iZG9udXRIb2xlIj4KICAgIDxyZWN0IHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgZmlsbD0id2hpdGUiIC8+CiAgICA8Y2lyY2xlIGN4PSIxMiIgY3k9IjEyIiByPSI4IiBmaWxsPSJibGFjayIvPgogIDwvbWFzaz4KCiAgPGcgY2xhc3M9ImpwLWljb24zIiBmaWxsPSIjNjE2MTYxIj4KICAgIDxyZWN0IGhlaWdodD0iMTgiIHdpZHRoPSIyIiB4PSIxMSIgeT0iMyIgdHJhbnNmb3JtPSJyb3RhdGUoMzE1LCAxMiwgMTIpIi8+CiAgICA8Y2lyY2xlIGN4PSIxMiIgY3k9IjEyIiByPSIxMCIgbWFzaz0idXJsKCNkb251dEhvbGUpIi8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbi1ub25lIGpwLWljb24tc2VsZWN0YWJsZS1pbnZlcnNlIGpwLWljb24zLWhvdmVyIiBmaWxsPSJub25lIj4KICAgIDxjaXJjbGUgY3g9IjEyIiBjeT0iMTIiIHI9IjExIi8+CiAgPC9nPgoKICA8ZyBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIGpwLWljb24tYWNjZW50Mi1ob3ZlciIgZmlsbD0iIzYxNjE2MSI+CiAgICA8cGF0aCBkPSJNMTkgNi40MUwxNy41OSA1IDEyIDEwLjU5IDYuNDEgNSA1IDYuNDEgMTAuNTkgMTIgNSAxNy41OSA2LjQxIDE5IDEyIDEzLjQxIDE3LjU5IDE5IDE5IDE3LjU5IDEzLjQxIDEyeiIvPgogIDwvZz4KCiAgPGcgY2xhc3M9ImpwLWljb24tbm9uZSBqcC1pY29uLWJ1c3kiIGZpbGw9Im5vbmUiPgogICAgPGNpcmNsZSBjeD0iMTIiIGN5PSIxMiIgcj0iNyIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjIiIGhlaWdodD0iMjIiIHZpZXdCb3g9IjAgMCAyOCAyOCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CgkJPHBhdGggZD0iTTExLjQgMTguNkw2LjggMTRMMTEuNCA5LjRMMTAgOEw0IDE0TDEwIDIwTDExLjQgMTguNlpNMTYuNiAxOC42TDIxLjIgMTRMMTYuNiA5LjRMMTggOEwyNCAxNEwxOCAyMEwxNi42IDE4LjZWMTguNloiLz4KCTwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIwMCAyMDAiPgogIDxnIGNsYXNzPSJqcC1pY29uLWJyYW5kMSBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiMwMjg4RDEiPgogICAgPHBhdGggZD0iTTIwIDE5LjhoMTYwdjE1OS45SDIweiIvPgogIDwvZz4KICA8ZyBjbGFzcz0ianAtaWNvbi1zZWxlY3RhYmxlLWludmVyc2UiIGZpbGw9IiNmZmYiPgogICAgPHBhdGggZD0iTTEwNSAxMjcuM2g0MHYxMi44aC00MHpNNTEuMSA3N0w3NCA5OS45bC0yMy4zIDIzLjMgMTAuNSAxMC41IDIzLjMtMjMuM0w5NSA5OS45IDg0LjUgODkuNCA2MS42IDY2LjV6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMTggMTgiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTExLjksMUgzLjJDMi40LDEsMS43LDEuNywxLjcsMi41djEwLjJoMS41VjIuNWg4LjdWMXogTTE0LjEsMy45aC04Yy0wLjgsMC0xLjUsMC43LTEuNSwxLjV2MTAuMmMwLDAuOCwwLjcsMS41LDEuNSwxLjVoOCBjMC44LDAsMS41LTAuNywxLjUtMS41VjUuNEMxNS41LDQuNiwxNC45LDMuOSwxNC4xLDMuOXogTTE0LjEsMTUuNWgtOFY1LjRoOFYxNS41eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGVuYWJsZS1iYWNrZ3JvdW5kPSJuZXcgMCAwIDI0IDI0IiBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCI+CiAgPGcgY2xhc3M9ImpwLWljb24zIiBmaWxsPSIjNjE2MTYxIj4KICAgIDxwYXRoIGQ9Ik0xMS44OCw5LjE0YzEuMjgsMC4wNiwxLjYxLDEuMTUsMS42MywxLjY2aDEuNzljLTAuMDgtMS45OC0xLjQ5LTMuMTktMy40NS0zLjE5QzkuNjQsNy42MSw4LDksOCwxMi4xNCBjMCwxLjk0LDAuOTMsNC4yNCwzLjg0LDQuMjRjMi4yMiwwLDMuNDEtMS42NSwzLjQ0LTIuOTVoLTEuNzljLTAuMDMsMC41OS0wLjQ1LDEuMzgtMS42MywxLjQ0QzEwLjU1LDE0LjgzLDEwLDEzLjgxLDEwLDEyLjE0IEMxMCw5LjI1LDExLjI4LDkuMTYsMTEuODgsOS4xNHogTTEyLDJDNi40OCwyLDIsNi40OCwyLDEyczQuNDgsMTAsMTAsMTBzMTAtNC40OCwxMC0xMFMxNy41MiwyLDEyLDJ6IE0xMiwyMGMtNC40MSwwLTgtMy41OS04LTggczMuNTktOCw4LThzOCwzLjU5LDgsOFMxNi40MSwyMCwxMiwyMHoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTkuNjQgNy42NGMuMjMtLjUuMzYtMS4wNS4zNi0xLjY0IDAtMi4yMS0xLjc5LTQtNC00UzIgMy43OSAyIDZzMS43OSA0IDQgNGMuNTkgMCAxLjE0LS4xMyAxLjY0LS4zNkwxMCAxMmwtMi4zNiAyLjM2QzcuMTQgMTQuMTMgNi41OSAxNCA2IDE0Yy0yLjIxIDAtNCAxLjc5LTQgNHMxLjc5IDQgNCA0IDQtMS43OSA0LTRjMC0uNTktLjEzLTEuMTQtLjM2LTEuNjRMMTIgMTRsNyA3aDN2LTFMOS42NCA3LjY0ek02IDhjLTEuMSAwLTItLjg5LTItMnMuOS0yIDItMiAyIC44OSAyIDItLjkgMi0yIDJ6bTAgMTJjLTEuMSAwLTItLjg5LTItMnMuOS0yIDItMiAyIC44OSAyIDItLjkgMi0yIDJ6bTYtNy41Yy0uMjggMC0uNS0uMjItLjUtLjVzLjIyLS41LjUtLjUuNS4yMi41LjUtLjIyLjUtLjUuNXpNMTkgM2wtNiA2IDIgMiA3LTdWM3oiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTE5IDloLTRWM0g5djZINWw3IDcgNy03ek01IDE4djJoMTR2LTJINXoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTMgMTcuMjVWMjFoMy43NUwxNy44MSA5Ljk0bC0zLjc1LTMuNzVMMyAxNy4yNXpNMjAuNzEgNy4wNGMuMzktLjM5LjM5LTEuMDIgMC0xLjQxbC0yLjM0LTIuMzRjLS4zOS0uMzktMS4wMi0uMzktMS40MSAwbC0xLjgzIDEuODMgMy43NSAzLjc1IDEuODMtMS44M3oiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPGNpcmNsZSBjeD0iNSIgY3k9IjEyIiByPSIyIi8+CiAgICA8Y2lyY2xlIGN4PSIxMiIgY3k9IjEyIiByPSIyIi8+CiAgICA8Y2lyY2xlIGN4PSIxOSIgY3k9IjEyIiByPSIyIi8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTIwLjUgMTFIMTlWN2MwLTEuMS0uOS0yLTItMmgtNFYzLjVDMTMgMi4xMiAxMS44OCAxIDEwLjUgMVM4IDIuMTIgOCAzLjVWNUg0Yy0xLjEgMC0xLjk5LjktMS45OSAydjMuOEgzLjVjMS40OSAwIDIuNyAxLjIxIDIuNyAyLjdzLTEuMjEgMi43LTIuNyAyLjdIMlYyMGMwIDEuMS45IDIgMiAyaDMuOHYtMS41YzAtMS40OSAxLjIxLTIuNyAyLjctMi43IDEuNDkgMCAyLjcgMS4yMSAyLjcgMi43VjIySDE3YzEuMSAwIDItLjkgMi0ydi00aDEuNWMxLjM4IDAgMi41LTEuMTIgMi41LTIuNVMyMS44OCAxMSAyMC41IDExeiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTQgMThsOC41LTZMNCA2djEyem05LTEydjEybDguNS02TDEzIDZ6Ii8+CiAgICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMTkuMyA4LjJsLTUuNS01LjVjLS4zLS4zLS43LS41LTEuMi0uNUgzLjljLS44LjEtMS42LjktMS42IDEuOHYxNC4xYzAgLjkuNyAxLjYgMS42IDEuNmgxNC4yYy45IDAgMS42LS43IDEuNi0xLjZWOS40Yy4xLS41LS4xLS45LS40LTEuMnptLTUuOC0zLjNsMy40IDMuNmgtMy40VjQuOXptMy45IDEyLjdINC43Yy0uMSAwLS4yIDAtLjItLjJWNC43YzAtLjIuMS0uMy4yLS4zaDcuMnY0LjRzMCAuOC4zIDEuMWMuMy4zIDEuMS4zIDEuMS4zaDQuM3Y3LjJzLS4xLjItLjIuMnoiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTkgMTZoNnYtNmg0bC03LTctNyA3aDR6bS00IDJoMTR2Mkg1eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTEwIDE4aDR2LTJoLTR2MnpNMyA2djJoMThWNkgzem0zIDdoMTJ2LTJINnYyeiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMTAgNEg0Yy0xLjEgMC0xLjk5LjktMS45OSAyTDIgMThjMCAxLjEuOSAyIDIgMmgxNmMxLjEgMCAyLS45IDItMlY4YzAtMS4xLS45LTItMi0yaC04bC0yLTJ6Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDUxMiA1MTIiPgogIDxwYXRoIGNsYXNzPSJqcC1pY29uMCBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiMwMDAiIGQ9Ik0xMDguNCAwaDIzdjIyLjhoMjEuMlYwaDIzdjY5aC0yM1Y0NmgtMjF2MjNoLTIzLjJNMjA2IDIzaC0yMC4zVjBoNjMuN3YyM0gyMjl2NDZoLTIzbTUzLjUtNjloMjQuMWwxNC44IDI0LjNMMzEzLjIgMGgyNC4xdjY5aC0yM1YzNC44bC0xNi4xIDI0LjgtMTYuMS0yNC44VjY5aC0yMi42bTg5LjItNjloMjN2NDYuMmgzMi42VjY5aC01NS42Ii8+CiAgPHBhdGggY2xhc3M9ImpwLWljb24tc2VsZWN0YWJsZSIgZmlsbD0iI2U0NGQyNiIgZD0iTTEwNy42IDQ3MWwtMzMtMzcwLjRoMzYyLjhsLTMzIDM3MC4yTDI1NS43IDUxMiIvPgogIDxwYXRoIGNsYXNzPSJqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiNmMTY1MjkiIGQ9Ik0yNTYgNDgwLjVWMTMxaDE0OC4zTDM3NiA0NDciLz4KICA8cGF0aCBjbGFzcz0ianAtaWNvbi1zZWxlY3RhYmxlLWludmVyc2UiIGZpbGw9IiNlYmViZWIiIGQ9Ik0xNDIgMTc2LjNoMTE0djQ1LjRoLTY0LjJsNC4yIDQ2LjVoNjB2NDUuM0gxNTQuNG0yIDIyLjhIMjAybDMuMiAzNi4zIDUwLjggMTMuNnY0Ny40bC05My4yLTI2Ii8+CiAgPHBhdGggY2xhc3M9ImpwLWljb24tc2VsZWN0YWJsZS1pbnZlcnNlIiBmaWxsPSIjZmZmIiBkPSJNMzY5LjYgMTc2LjNIMjU1Ljh2NDUuNGgxMDkuNm0tNC4xIDQ2LjVIMjU1Ljh2NDUuNGg1NmwtNS4zIDU5LTUwLjcgMTMuNnY0Ny4ybDkzLTI1LjgiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8cGF0aCBjbGFzcz0ianAtaWNvbi1icmFuZDQganAtaWNvbi1zZWxlY3RhYmxlLWludmVyc2UiIGZpbGw9IiNGRkYiIGQ9Ik0yLjIgMi4yaDE3LjV2MTcuNUgyLjJ6Ii8+CiAgPHBhdGggY2xhc3M9ImpwLWljb24tYnJhbmQwIGpwLWljb24tc2VsZWN0YWJsZSIgZmlsbD0iIzNGNTFCNSIgZD0iTTIuMiAyLjJ2MTcuNWgxNy41bC4xLTE3LjVIMi4yem0xMi4xIDIuMmMxLjIgMCAyLjIgMSAyLjIgMi4ycy0xIDIuMi0yLjIgMi4yLTIuMi0xLTIuMi0yLjIgMS0yLjIgMi4yLTIuMnpNNC40IDE3LjZsMy4zLTguOCAzLjMgNi42IDIuMi0zLjIgNC40IDUuNEg0LjR6Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMjAgNEg0Yy0xLjEgMC0xLjk5LjktMS45OSAyTDIgMThjMCAxLjEuOSAyIDIgMmgxNmMxLjEgMCAyLS45IDItMlY2YzAtMS4xLS45LTItMi0yem0tNSAxNEg0di00aDExdjR6bTAtNUg0VjloMTF2NHptNSA1aC00VjloNHY5eiIvPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8ZyBjbGFzcz0ianAtaWNvbi13YXJuMSBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiNGOUE4MjUiPgogICAgPHBhdGggZD0iTTIwLjIgMTEuOGMtMS42IDAtMS43LjUtMS43IDEgMCAuNC4xLjkuMSAxLjMuMS41LjEuOS4xIDEuMyAwIDEuNy0xLjQgMi4zLTMuNSAyLjNoLS45di0xLjloLjVjMS4xIDAgMS40IDAgMS40LS44IDAtLjMgMC0uNi0uMS0xIDAtLjQtLjEtLjgtLjEtMS4yIDAtMS4zIDAtMS44IDEuMy0yLTEuMy0uMi0xLjMtLjctMS4zLTIgMC0uNC4xLS44LjEtMS4yLjEtLjQuMS0uNy4xLTEgMC0uOC0uNC0uNy0xLjQtLjhoLS41VjQuMWguOWMyLjIgMCAzLjUuNyAzLjUgMi4zIDAgLjQtLjEuOS0uMSAxLjMtLjEuNS0uMS45LS4xIDEuMyAwIC41LjIgMSAxLjcgMXYxLjh6TTEuOCAxMC4xYzEuNiAwIDEuNy0uNSAxLjctMSAwLS40LS4xLS45LS4xLTEuMy0uMS0uNS0uMS0uOS0uMS0xLjMgMC0xLjYgMS40LTIuMyAzLjUtMi4zaC45djEuOWgtLjVjLTEgMC0xLjQgMC0xLjQuOCAwIC4zIDAgLjYuMSAxIDAgLjIuMS42LjEgMSAwIDEuMyAwIDEuOC0xLjMgMkM2IDExLjIgNiAxMS43IDYgMTNjMCAuNC0uMS44LS4xIDEuMi0uMS4zLS4xLjctLjEgMSAwIC44LjMuOCAxLjQuOGguNXYxLjloLS45Yy0yLjEgMC0zLjUtLjYtMy41LTIuMyAwLS40LjEtLjkuMS0xLjMuMS0uNS4xLS45LjEtMS4zIDAtLjUtLjItMS0xLjctMXYtMS45eiIvPgogICAgPGNpcmNsZSBjeD0iMTEiIGN5PSIxMy44IiByPSIyLjEiLz4KICAgIDxjaXJjbGUgY3g9IjExIiBjeT0iOC4yIiByPSIyLjEiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDMyNSAzMDAiPgogIDxnIGNsYXNzPSJqcC1icmFuZDAganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjY2IzYzMzIj4KICAgIDxwYXRoIGQ9Ik0gMTUwLjg5ODQzOCAyMjUgQyAxNTAuODk4NDM4IDI2Ni40MjE4NzUgMTE3LjMyMDMxMiAzMDAgNzUuODk4NDM4IDMwMCBDIDM0LjQ3NjU2MiAzMDAgMC44OTg0MzggMjY2LjQyMTg3NSAwLjg5ODQzOCAyMjUgQyAwLjg5ODQzOCAxODMuNTc4MTI1IDM0LjQ3NjU2MiAxNTAgNzUuODk4NDM4IDE1MCBDIDExNy4zMjAzMTIgMTUwIDE1MC44OTg0MzggMTgzLjU3ODEyNSAxNTAuODk4NDM4IDIyNSIvPgogIDwvZz4KICA8ZyBjbGFzcz0ianAtYnJhbmQwIGpwLWljb24tc2VsZWN0YWJsZSIgZmlsbD0iIzM4OTgyNiI+CiAgICA8cGF0aCBkPSJNIDIzNy41IDc1IEMgMjM3LjUgMTE2LjQyMTg3NSAyMDMuOTIxODc1IDE1MCAxNjIuNSAxNTAgQyAxMjEuMDc4MTI1IDE1MCA4Ny41IDExNi40MjE4NzUgODcuNSA3NSBDIDg3LjUgMzMuNTc4MTI1IDEyMS4wNzgxMjUgMCAxNjIuNSAwIEMgMjAzLjkyMTg3NSAwIDIzNy41IDMzLjU3ODEyNSAyMzcuNSA3NSIvPgogIDwvZz4KICA8ZyBjbGFzcz0ianAtYnJhbmQwIGpwLWljb24tc2VsZWN0YWJsZSIgZmlsbD0iIzk1NThiMiI+CiAgICA8cGF0aCBkPSJNIDMyNC4xMDE1NjIgMjI1IEMgMzI0LjEwMTU2MiAyNjYuNDIxODc1IDI5MC41MjM0MzggMzAwIDI0OS4xMDE1NjIgMzAwIEMgMjA3LjY3OTY4OCAzMDAgMTc0LjEwMTU2MiAyNjYuNDIxODc1IDE3NC4xMDE1NjIgMjI1IEMgMTc0LjEwMTU2MiAxODMuNTc4MTI1IDIwNy42Nzk2ODggMTUwIDI0OS4xMDE1NjIgMTUwIEMgMjkwLjUyMzQzOCAxNTAgMzI0LjEwMTU2MiAxODMuNTc4MTI1IDMyNC4xMDE1NjIgMjI1Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTUyIiBoZWlnaHQ9IjE2NSIgdmlld0JveD0iMCAwIDE1MiAxNjUiIHZlcnNpb249IjEuMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbi13YXJuMCIgZmlsbD0iI0YzNzcyNiI+CiAgICA8cGF0aCB0cmFuc2Zvcm09InRyYW5zbGF0ZSgwLjA3ODk0NywgMTEwLjU4MjkyNykiIGQ9Ik03NS45NDIyODQyLDI5LjU4MDQ1NjEgQzQzLjMwMjM5NDcsMjkuNTgwNDU2MSAxNC43OTY3ODMyLDE3LjY1MzQ2MzQgMCwwIEM1LjUxMDgzMjExLDE1Ljg0MDY4MjkgMTUuNzgxNTM4OSwyOS41NjY3NzMyIDI5LjM5MDQ5NDcsMzkuMjc4NDE3MSBDNDIuOTk5Nyw0OC45ODk4NTM3IDU5LjI3MzcsNTQuMjA2NzgwNSA3NS45NjA1Nzg5LDU0LjIwNjc4MDUgQzkyLjY0NzQ1NzksNTQuMjA2NzgwNSAxMDguOTIxNDU4LDQ4Ljk4OTg1MzcgMTIyLjUzMDY2MywzOS4yNzg0MTcxIEMxMzYuMTM5NDUzLDI5LjU2Njc3MzIgMTQ2LjQxMDI4NCwxNS44NDA2ODI5IDE1MS45MjExNTgsMCBDMTM3LjA4Nzg2OCwxNy42NTM0NjM0IDEwOC41ODI1ODksMjkuNTgwNDU2MSA3NS45NDIyODQyLDI5LjU4MDQ1NjEgTDc1Ljk0MjI4NDIsMjkuNTgwNDU2MSBaIiAvPgogICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMC4wMzczNjgsIDAuNzA0ODc4KSIgZD0iTTc1Ljk3ODQ1NzksMjQuNjI2NDA3MyBDMTA4LjYxODc2MywyNC42MjY0MDczIDEzNy4xMjQ0NTgsMzYuNTUzNDQxNSAxNTEuOTIxMTU4LDU0LjIwNjc4MDUgQzE0Ni40MTAyODQsMzguMzY2MjIyIDEzNi4xMzk0NTMsMjQuNjQwMTMxNyAxMjIuNTMwNjYzLDE0LjkyODQ4NzggQzEwOC45MjE0NTgsNS4yMTY4NDM5IDkyLjY0NzQ1NzksMCA3NS45NjA1Nzg5LDAgQzU5LjI3MzcsMCA0Mi45OTk3LDUuMjE2ODQzOSAyOS4zOTA0OTQ3LDE0LjkyODQ4NzggQzE1Ljc4MTUzODksMjQuNjQwMTMxNyA1LjUxMDgzMjExLDM4LjM2NjIyMiAwLDU0LjIwNjc4MDUgQzE0LjgzMzA4MTYsMzYuNTg5OTI5MyA0My4zMzg1Njg0LDI0LjYyNjQwNzMgNzUuOTc4NDU3OSwyNC42MjY0MDczIEw3NS45Nzg0NTc5LDI0LjYyNjQwNzMgWiIgLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,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"},function(e,t){e.exports="data:image/svg+xml;base64, "},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoIGNsYXNzPSJqcC1pY29uMiIgZmlsbD0iIzYxNjE2MSIgZD0iTTE1IDlIOXY2aDZWOXptLTIgNGgtMnYtMmgydjJ6bTgtMlY5aC0yVjdjMC0xLjEtLjktMi0yLTJoLTJWM2gtMnYyaC0yVjNIOXYySDdjLTEuMSAwLTIgLjktMiAydjJIM3YyaDJ2MkgzdjJoMnYyYzAgMS4xLjkgMiAyIDJoMnYyaDJ2LTJoMnYyaDJ2LTJoMmMxLjEgMCAyLS45IDItMnYtMmgydi0yaC0ydi0yaDJ6bS00IDZIN1Y3aDEwdjEweiIvPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMjAgNUg0Yy0xLjEgMC0xLjk5LjktMS45OSAyTDIgMTdjMCAxLjEuOSAyIDIgMmgxNmMxLjEgMCAyLS45IDItMlY3YzAtMS4xLS45LTItMi0yem0tOSAzaDJ2MmgtMlY4em0wIDNoMnYyaC0ydi0yek04IDhoMnYySDhWOHptMCAzaDJ2Mkg4di0yem0tMSAySDV2LTJoMnYyem0wLTNINVY4aDJ2MnptOSA3SDh2LTJoOHYyem0wLTRoLTJ2LTJoMnYyem0wLTNoLTJWOGgydjJ6bTMgM2gtMnYtMmgydjJ6bTAtM2gtMlY4aDJ2MnoiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMTkgMTlINVY1aDdWM0g1YTIgMiAwIDAwLTIgMnYxNGEyIDIgMCAwMDIgMmgxNGMxLjEgMCAyLS45IDItMnYtN2gtMnY3ek0xNCAzdjJoMy41OWwtOS44MyA5LjgzIDEuNDEgMS40MUwxOSA2LjQxVjEwaDJWM2gtN3oiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoIGZpbGw9IndoaXRlIiBkPSJNNS44OCA0LjEyTDEzLjc2IDEybC03Ljg4IDcuODhMOCAyMmwxMC0xMEw4IDJ6Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTMuOSAxMmMwLTEuNzEgMS4zOS0zLjEgMy4xLTMuMWg0VjdIN2MtMi43NiAwLTUgMi4yNC01IDVzMi4yNCA1IDUgNWg0di0xLjlIN2MtMS43MSAwLTMuMS0xLjM5LTMuMS0zLjF6TTggMTNoOHYtMkg4djJ6bTktNmgtNHYxLjloNGMxLjcxIDAgMy4xIDEuMzkgMy4xIDMuMXMtMS4zOSAzLjEtMy4xIDMuMWgtNFYxN2g0YzIuNzYgMCA1LTIuMjQgNS01cy0yLjI0LTUtNS01eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoIGNsYXNzPSJqcC1pY29uMiBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiM2MTYxNjEiIGQ9Ik0xOSA1djE0SDVWNWgxNG0xLjEtMkgzLjljLS41IDAtLjkuNC0uOS45djE2LjJjMCAuNC40LjkuOS45aDE2LjJjLjQgMCAuOS0uNS45LS45VjMuOWMwLS41LS41LS45LS45LS45ek0xMSA3aDZ2MmgtNlY3em0wIDRoNnYyaC02di0yem0wIDRoNnYyaC02ek03IDdoMnYySDd6bTAgNGgydjJIN3ptMCA0aDJ2Mkg3eiIvPgo8L3N2Zz4="},function(e,t){e.exports="data:image/svg+xml;base64,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"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8cGF0aCBjbGFzcz0ianAtaWNvbi1jb250cmFzdDAganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjN0IxRkEyIiBkPSJNNSAxNC45aDEybC02LjEgNnptOS40LTYuOGMwLTEuMy0uMS0yLjktLjEtNC41LS40IDEuNC0uOSAyLjktMS4zIDQuM2wtMS4zIDQuM2gtMkw4LjUgNy45Yy0uNC0xLjMtLjctMi45LTEtNC4zLS4xIDEuNi0uMSAzLjItLjIgNC42TDcgMTIuNEg0LjhsLjctMTFoMy4zTDEwIDVjLjQgMS4yLjcgMi43IDEgMy45LjMtMS4yLjctMi42IDEtMy45bDEuMi0zLjdoMy4zbC42IDExaC0yLjRsLS4zLTQuMnoiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTIwIDZoLThsLTItMkg0Yy0xLjExIDAtMS45OS44OS0xLjk5IDJMMiAxOGMwIDEuMTEuODkgMiAyIDJoMTZjMS4xMSAwIDItLjg5IDItMlY4YzAtMS4xMS0uODktMi0yLTJ6bS0xIDhoLTN2M2gtMnYtM2gtM3YtMmgzVjloMnYzaDN2MnoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBmaWxsPSJub25lIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI1IDI1Ij4KICAgIDxwYXRoIGNsYXNzPSJqcC1pY29uMiIgc3Ryb2tlPSIjMzMzMzMzIiBzdHJva2Utd2lkdGg9IjIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDMgMykiIGQ9Ik0xLjg2MDk0IDExLjQ0MDlDMC44MjY0NDggOC43NzAyNyAwLjg2Mzc3OSA2LjA1NzY0IDEuMjQ5MDcgNC4xOTkzMkMyLjQ4MjA2IDMuOTMzNDcgNC4wODA2OCAzLjQwMzQ3IDUuNjAxMDIgMi44NDQ5QzcuMjM1NDkgMi4yNDQ0IDguODU2NjYgMS41ODE1IDkuOTg3NiAxLjA5NTM5QzExLjA1OTcgMS41ODM0MSAxMi42MDk0IDIuMjQ0NCAxNC4yMTggMi44NDMzOUMxNS43NTAzIDMuNDEzOTQgMTcuMzk5NSAzLjk1MjU4IDE4Ljc1MzkgNC4yMTM4NUMxOS4xMzY0IDYuMDcxNzcgMTkuMTcwOSA4Ljc3NzIyIDE4LjEzOSAxMS40NDA5QzE3LjAzMDMgMTQuMzAzMiAxNC42NjY4IDE3LjE4NDQgOS45OTk5OSAxOC45MzU0QzUuMzMzMTkgMTcuMTg0NCAyLjk2OTY4IDE0LjMwMzIgMS44NjA5NCAxMS40NDA5WiIvPgogICAgPHBhdGggY2xhc3M9ImpwLWljb24yIiBzdHJva2U9IiMzMzMzMzMiIHN0cm9rZS13aWR0aD0iMiIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS4zMTU5MiA5LjMyMDMxKSIgZD0iTTcuMzY4NDIgMEwwIDcuMzY0NzkiLz4KICAgIDxwYXRoIGNsYXNzPSJqcC1pY29uMiIgc3Ryb2tlPSIjMzMzMzMzIiBzdHJva2Utd2lkdGg9IjIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDkuMzE1OTIgMTYuNjgzNikgc2NhbGUoMSAtMSkiIGQ9Ik03LjM2ODQyIDBMMCA3LjM2NDc5Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8ZyBjbGFzcz0ianAtaWNvbi13YXJuMCBqcC1pY29uLXNlbGVjdGFibGUiIGZpbGw9IiNFRjZDMDAiPgogICAgPHBhdGggZD0iTTE4LjcgMy4zdjE1LjRIMy4zVjMuM2gxNS40bTEuNS0xLjVIMS44djE4LjNoMTguM2wuMS0xOC4zeiIvPgogICAgPHBhdGggZD0iTTE2LjUgMTYuNWwtNS40LTQuMy01LjYgNC4zdi0xMWgxMXoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjIiIGhlaWdodD0iMjIiIHZpZXdCb3g9IjAgMCAyOCAyOCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CgkJPHBhdGggZD0iTTQgMTlINlYxOS41SDVWMjAuNUg2VjIxSDRWMjJIN1YxOEg0VjE5Wk01IDEwSDZWNkg0VjdINVYxMFpNNCAxM0g1LjhMNCAxNS4xVjE2SDdWMTVINS4yTDcgMTIuOVYxMkg0VjEzWk05IDdWOUgyM1Y3SDlaTTkgMjFIMjNWMTlIOVYyMVpNOSAxNUgyM1YxM0g5VjE1WiIvPgoJPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCIgd2lkdGg9IjE2Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTEyIDIuMDJjLTUuNTEgMC05Ljk4IDQuNDctOS45OCA5Ljk4czQuNDcgOS45OCA5Ljk4IDkuOTggOS45OC00LjQ3IDkuOTgtOS45OFMxNy41MSAyLjAyIDEyIDIuMDJ6TTExLjQ4IDIwdi02LjI2SDhMMTMgNHY2LjI2aDMuMzVMMTEuNDggMjB6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTE4IDEzVjIwSDRWNkg5LjAyQzkuMDcgNS4yOSA5LjI0IDQuNjIgOS41IDRINEMyLjkgNCAyIDQuOSAyIDZWMjBDMiAyMS4xIDIuOSAyMiA0IDIySDE4QzE5LjEgMjIgMjAgMjEuMSAyMCAyMFYxNUwxOCAxM1pNMTkuMyA4Ljg5QzE5Ljc0IDguMTkgMjAgNy4zOCAyMCA2LjVDMjAgNC4wMSAxNy45OSAyIDE1LjUgMkMxMy4wMSAyIDExIDQuMDEgMTEgNi41QzExIDguOTkgMTMuMDEgMTEgMTUuNDkgMTFDMTYuMzcgMTEgMTcuMTkgMTAuNzQgMTcuODggMTAuM0wyMSAxMy40MkwyMi40MiAxMkwxOS4zIDguODlaTTE1LjUgOUMxNC4xMiA5IDEzIDcuODggMTMgNi41QzEzIDUuMTIgMTQuMTIgNCAxNS41IDRDMTYuODggNCAxOCA1LjEyIDE4IDYuNUMxOCA3Ljg4IDE2Ljg4IDkgMTUuNSA5WiIvPgogICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBjbGlwLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00IDZIOS4wMTg5NEM5LjAwNjM5IDYuMTY1MDIgOSA2LjMzMTc2IDkgNi41QzkgOC44MTU3NyAxMC4yMTEgMTAuODQ4NyAxMi4wMzQzIDEySDlWMTRIMTZWMTIuOTgxMUMxNi41NzAzIDEyLjkzNzcgMTcuMTIgMTIuODIwNyAxNy42Mzk2IDEyLjYzOTZMMTggMTNWMjBINFY2Wk04IDhINlYxMEg4VjhaTTYgMTJIOFYxNEg2VjEyWk04IDE2SDZWMThIOFYxNlpNOSAxNkgxNlYxOEg5VjE2WiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTE5IDJoLTQuMThDMTQuNC44NCAxMy4zIDAgMTIgMGMtMS4zIDAtMi40Ljg0LTIuODIgMkg1Yy0xLjEgMC0yIC45LTIgMnYxNmMwIDEuMS45IDIgMiAyaDE0YzEuMSAwIDItLjkgMi0yVjRjMC0xLjEtLjktMi0yLTJ6bS03IDBjLjU1IDAgMSAuNDUgMSAxcy0uNDUgMS0xIDEtMS0uNDUtMS0xIC40NS0xIDEtMXptNyAxOEg1VjRoMnYzaDEwVjRoMnYxNnoiLz4KICAgIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZwogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyMiAyMiIgd2lkdGg9IjE2Ij4KICAgIDxwYXRoIHRyYW5zZm9ybT0icm90YXRlKDQ1KSIgY2xhc3M9ImpwLWljb24tc2VsZWN0YWJsZSIgZmlsbD0iI0ZGMkEyQSIKICAgICAgIGQ9Im0gMjIuMzQ0MzY5LC0zLjAxNjM2NDIgaCA1LjYzODYwNCB2IDEuNTc5MjQzMyBoIC0zLjU0OTIyNyB2IDEuNTA4NjkyOTkgaCAzLjMzNzU3NiBWIDEuNjUwODE1NCBoIC0zLjMzNzU3NiB2IDMuNDM1MjYxMyBoIC0yLjA4OTM3NyB6IG0gLTcuMTM2NDQ0LDEuNTc5MjQzMyB2IDQuOTQzOTU0MyBoIDAuNzQ4OTIgcSAxLjI4MDc2MSwwIDEuOTUzNzAzLC0wLjYzNDk1MzUgMC42NzgzNjksLTAuNjM0OTUzNSAwLjY3ODM2OSwtMS44NDUxNjQxIDAsLTEuMjA0NzgzNTUgLTAuNjcyOTQyLC0xLjgzNDMxMDExIC0wLjY3Mjk0MiwtMC42Mjk1MjY1OSAtMS45NTkxMywtMC42Mjk1MjY1OSB6IG0gLTIuMDg5Mzc3LC0xLjU3OTI0MzMgaCAyLjIwMzM0MyBxIDEuODQ1MTY0LDAgMi43NDYwMzksMC4yNjU5MjA3IDAuOTA2MzAxLDAuMjYwNDkzNyAxLjU1MjEwOCwwLjg5MDAyMDMgMC41Njk4MywwLjU0ODEyMjMgMC44NDY2MDUsMS4yNjQ0ODAwNiAwLjI3Njc3NCwwLjcxNjM1NzgxIDAuMjc2Nzc0LDEuNjIyNjU4OTQgMCwwLjkxNzE1NTEgLTAuMjc2Nzc0LDEuNjM4OTM5OSAtMC4yNzY3NzUsMC43MTYzNTc4IC0wLjg0NjYwNSwxLjI2NDQ4IC0wLjY1MTIzNCwwLjYyOTUyNjYgLTEuNTYyOTYyLDAuODk1NDQ3MyAtMC45MTE3MjgsMC4yNjA0OTM3IC0yLjczNTE4NSwwLjI2MDQ5MzcgaCAtMi4yMDMzNDMgeiBtIC04LjE0NTg1NjUsMCBoIDMuNDY3ODIzIHEgMS41NDY2ODE2LDAgMi4zNzE1Nzg1LDAuNjg5MjIzIDAuODMwMzI0LDAuNjgzNzk2MSAwLjgzMDMyNCwxLjk1MzcwMzE0IDAsMS4yNzUzMzM5NyAtMC44MzAzMjQsMS45NjQ1NTcwNiBRIDkuOTg3MTk2MSwyLjI3NDkxNSA4LjQ0MDUxNDUsMi4yNzQ5MTUgSCA3LjA2MjA2ODQgViA1LjA4NjA3NjcgSCA0Ljk3MjY5MTUgWiBtIDIuMDg5Mzc2OSwxLjUxNDExOTkgdiAyLjI2MzAzOTQzIGggMS4xNTU5NDEgcSAwLjYwNzgxODgsMCAwLjkzODg2MjksLTAuMjkzMDU1NDcgMC4zMzEwNDQxLC0wLjI5ODQ4MjQxIDAuMzMxMDQ0MSwtMC44NDExNzc3MiAwLC0wLjU0MjY5NTMxIC0wLjMzMTA0NDEsLTAuODM1NzUwNzQgLTAuMzMxMDQ0MSwtMC4yOTMwNTU1IC0wLjkzODg2MjksLTAuMjkzMDU1NSB6IgovPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8ZyBjbGFzcz0ianAtaWNvbi1icmFuZDAganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjMEQ0N0ExIj4KICAgIDxwYXRoIGQ9Ik0xMS4xIDYuOVY1LjhINi45YzAtLjUgMC0xLjMuMi0xLjYuNC0uNy44LTEuMSAxLjctMS40IDEuNy0uMyAyLjUtLjMgMy45LS4xIDEgLjEgMS45LjkgMS45IDEuOXY0LjJjMCAuNS0uOSAxLjYtMiAxLjZIOC44Yy0xLjUgMC0yLjQgMS40LTIuNCAyLjh2Mi4ySDQuN0MzLjUgMTUuMSAzIDE0IDMgMTMuMVY5Yy0uMS0xIC42LTIgMS44LTIgMS41LS4xIDYuMy0uMSA2LjMtLjF6Ii8+CiAgICA8cGF0aCBkPSJNMTAuOSAxNS4xdjEuMWg0LjJjMCAuNSAwIDEuMy0uMiAxLjYtLjQuNy0uOCAxLjEtMS43IDEuNC0xLjcuMy0yLjUuMy0zLjkuMS0xLS4xLTEuOS0uOS0xLjktMS45di00LjJjMC0uNS45LTEuNiAyLTEuNmgzLjhjMS41IDAgMi40LTEuNCAyLjQtMi44VjYuNmgxLjdDMTguNSA2LjkgMTkgOCAxOSA4LjlWMTNjMCAxLS43IDIuMS0xLjkgMi4xaC02LjJ6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8cGF0aCBjbGFzcz0ianAtaWNvbi1jb250cmFzdDMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjMjE5NkYzIiBkPSJNNC40IDIuNWMxLjItLjEgMi45LS4zIDQuOS0uMyAyLjUgMCA0LjEuNCA1LjIgMS4zIDEgLjcgMS41IDEuOSAxLjUgMy41IDAgMi0xLjQgMy41LTIuOSA0LjEgMS4yLjQgMS43IDEuNiAyLjIgMyAuNiAxLjkgMSAzLjkgMS4zIDQuNmgtMy44Yy0uMy0uNC0uOC0xLjctMS4yLTMuN3MtMS4yLTIuNi0yLjYtMi42aC0uOXY2LjRINC40VjIuNXptMy43IDYuOWgxLjRjMS45IDAgMi45LS45IDIuOS0yLjNzLTEtMi4zLTIuOC0yLjNjLS43IDAtMS4zIDAtMS42LjJ2NC41aC4xdi0uMXoiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,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"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMjQiIHZpZXdCb3g9IjAgMCAyNCAyNCIgd2lkdGg9IjE2Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgICA8cGF0aCBkPSJNMCAwaDI0djI0SDB6IiBmaWxsPSJub25lIi8+PHBhdGggZD0iTTE4LjQgMTAuNkMxNi41NSA4Ljk5IDE0LjE1IDggMTEuNSA4Yy00LjY1IDAtOC41OCAzLjAzLTkuOTYgNy4yMkwzLjkgMTZjMS4wNS0zLjE5IDQuMDUtNS41IDcuNi01LjUgMS45NSAwIDMuNzMuNzIgNS4xMiAxLjg4TDEzIDE2aDlWN2wtMy42IDMuNnoiLz4KICA8L2c+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIwIDIwIj4KICA8ZyBjbGFzcz0ianAtaWNvbjIiIGZpbGw9IiM0MTQxNDEiPgogICAgPHJlY3QgeD0iMiIgeT0iMiIgd2lkdGg9IjE2IiBoZWlnaHQ9IjE2Ii8+CiAgPC9nPgoKICA8ZyBjbGFzcz0ianAtaWNvbi1hY2NlbnQyIiBmaWxsPSIjRkZGIj4KICAgIDxjaXJjbGUgY2xhc3M9InN0MiIgY3g9IjUuNSIgY3k9IjE0LjUiIHI9IjEuNSIvPgogICAgPHJlY3QgeD0iMTIiIHk9IjQiIGNsYXNzPSJzdDIiIHdpZHRoPSIxIiBoZWlnaHQ9IjgiLz4KICAgIDxyZWN0IHg9IjguNSIgeT0iNy41IiB0cmFuc2Zvcm09Im1hdHJpeCgwLjg2NiAtMC41IDAuNSAwLjg2NiAtMi4zMjU1IDcuMzIxOSkiIGNsYXNzPSJzdDIiIHdpZHRoPSI4IiBoZWlnaHQ9IjEiLz4KICAgIDxyZWN0IHg9IjEyIiB5PSI0IiB0cmFuc2Zvcm09Im1hdHJpeCgwLjUgLTAuODY2IDAuODY2IDAuNSAtMC42Nzc5IDE0LjgyNTIpIiBjbGFzcz0ic3QyIiB3aWR0aD0iMSIgaGVpZ2h0PSI4Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTggNXYxNGwxMS03eiIvPgogICAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDUxMiA1MTIiPgogIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICA8cGF0aCBkPSJNMjU2IDhDMTE5IDggOCAxMTkgOCAyNTZzMTExIDI0OCAyNDggMjQ4IDI0OC0xMTEgMjQ4LTI0OFMzOTMgOCAyNTYgOHptOTYgMzI4YzAgOC44LTcuMiAxNi0xNiAxNkgxNzZjLTguOCAwLTE2LTcuMi0xNi0xNlYxNzZjMC04LjggNy4yLTE2IDE2LTE2aDE2MGM4LjggMCAxNiA3LjIgMTYgMTZ2MTYweiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTE3IDNINWMtMS4xMSAwLTIgLjktMiAydjE0YzAgMS4xLjg5IDIgMiAyaDE0YzEuMSAwIDItLjkgMi0yVjdsLTQtNHptLTUgMTZjLTEuNjYgMC0zLTEuMzQtMy0zczEuMzQtMyAzLTMgMyAxLjM0IDMgMy0xLjM0IDMtMyAzem0zLTEwSDVWNWgxMHY0eiIvPgogICAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMTggMTgiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTEyLjEsMTAuOWgtMC43bC0wLjItMC4yYzAuOC0wLjksMS4zLTIuMiwxLjMtMy41YzAtMy0yLjQtNS40LTUuNC01LjRTMS44LDQuMiwxLjgsNy4xczIuNCw1LjQsNS40LDUuNCBjMS4zLDAsMi41LTAuNSwzLjUtMS4zbDAuMiwwLjJ2MC43bDQuMSw0LjFsMS4yLTEuMkwxMi4xLDEwLjl6IE03LjEsMTAuOWMtMi4xLDAtMy43LTEuNy0zLjctMy43czEuNy0zLjcsMy43LTMuN3MzLjcsMS43LDMuNywzLjcgUzkuMiwxMC45LDcuMSwxMC45eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMTkuNDMgMTIuOThjLjA0LS4zMi4wNy0uNjQuMDctLjk4cy0uMDMtLjY2LS4wNy0uOThsMi4xMS0xLjY1Yy4xOS0uMTUuMjQtLjQyLjEyLS42NGwtMi0zLjQ2Yy0uMTItLjIyLS4zOS0uMy0uNjEtLjIybC0yLjQ5IDFjLS41Mi0uNC0xLjA4LS43My0xLjY5LS45OGwtLjM4LTIuNjVBLjQ4OC40ODggMCAwMDE0IDJoLTRjLS4yNSAwLS40Ni4xOC0uNDkuNDJsLS4zOCAyLjY1Yy0uNjEuMjUtMS4xNy41OS0xLjY5Ljk4bC0yLjQ5LTFjLS4yMy0uMDktLjQ5IDAtLjYxLjIybC0yIDMuNDZjLS4xMy4yMi0uMDcuNDkuMTIuNjRsMi4xMSAxLjY1Yy0uMDQuMzItLjA3LjY1LS4wNy45OHMuMDMuNjYuMDcuOThsLTIuMTEgMS42NWMtLjE5LjE1LS4yNC40Mi0uMTIuNjRsMiAzLjQ2Yy4xMi4yMi4zOS4zLjYxLjIybDIuNDktMWMuNTIuNCAxLjA4LjczIDEuNjkuOThsLjM4IDIuNjVjLjAzLjI0LjI0LjQyLjQ5LjQyaDRjLjI1IDAgLjQ2LS4xOC40OS0uNDJsLjM4LTIuNjVjLjYxLS4yNSAxLjE3LS41OSAxLjY5LS45OGwyLjQ5IDFjLjIzLjA5LjQ5IDAgLjYxLS4yMmwyLTMuNDZjLjEyLS4yMi4wNy0uNDktLjEyLS42NGwtMi4xMS0xLjY1ek0xMiAxNS41Yy0xLjkzIDAtMy41LTEuNTctMy41LTMuNXMxLjU3LTMuNSAzLjUtMy41IDMuNSAxLjU3IDMuNSAzLjUtMS41NyAzLjUtMy41IDMuNXoiLz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8cGF0aCBjbGFzcz0ianAtaWNvbi1jb250cmFzdDEganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNENBRjUwIiBkPSJNMi4yIDIuMnYxNy42aDE3LjZWMi4ySDIuMnptMTUuNCA3LjdoLTUuNVY0LjRoNS41djUuNXpNOS45IDQuNHY1LjVINC40VjQuNGg1LjV6bS01LjUgNy43aDUuNXY1LjVINC40di01LjV6bTcuNyA1LjV2LTUuNWg1LjV2NS41aC01LjV6Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTAgMGgyNHYyNEgweiIgZmlsbD0ibm9uZSIvPgogICAgICAgIDxwYXRoIGQ9Ik02IDZoMTJ2MTJINnoiLz4KICAgIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTIxIDNIM2MtMS4xIDAtMiAuOS0yIDJ2MTRjMCAxLjEuOSAyIDIgMmgxOGMxLjEgMCAyLS45IDItMlY1YzAtMS4xLS45LTItMi0yem0wIDE2SDNWNWgxMHY0aDh2MTB6Ii8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTAgMGgyNHYyNEgweiIgZmlsbD0ibm9uZSIvPgogICAgICAgIDxwYXRoIGQ9Ik0yMSw4SDNWNGgxOFY4eiBNMjEsMTBIM3Y0aDE4VjEweiBNMjEsMTZIM3Y0aDE4VjE2eiIvPgogICAgPC9nPgo8L3N2Zz4="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjgiIGhlaWdodD0iMjgiIHZpZXdCb3g9IjAgMCA0MyAyOCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KCTxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CgkJPHBhdGggZD0iTTI4LjgzMzIgMTIuMzM0TDMyLjk5OTggMTYuNTAwN0wzNy4xNjY1IDEyLjMzNEgyOC44MzMyWiIvPgoJCTxwYXRoIGQ9Ik0xNi4yMDk1IDIxLjYxMDRDMTUuNjg3MyAyMi4xMjk5IDE0Ljg0NDMgMjIuMTI5OSAxNC4zMjQ4IDIxLjYxMDRMNi45ODI5IDE0LjcyNDVDNi41NzI0IDE0LjMzOTQgNi4wODMxMyAxMy42MDk4IDYuMDQ3ODYgMTMuMDQ4MkM1Ljk1MzQ3IDExLjUyODggNi4wMjAwMiA4LjYxOTQ0IDYuMDY2MjEgNy4wNzY5NUM2LjA4MjgxIDYuNTE0NzcgNi41NTU0OCA2LjA0MzQ3IDcuMTE4MDQgNi4wMzA1NUM5LjA4ODYzIDUuOTg0NzMgMTMuMjYzOCA1LjkzNTc5IDEzLjY1MTggNi4zMjQyNUwyMS43MzY5IDEzLjYzOUMyMi4yNTYgMTQuMTU4NSAyMS43ODUxIDE1LjQ3MjQgMjEuMjYyIDE1Ljk5NDZMMTYuMjA5NSAyMS42MTA0Wk05Ljc3NTg1IDguMjY1QzkuMzM1NTEgNy44MjU2NiA4LjYyMzUxIDcuODI1NjYgOC4xODI4IDguMjY1QzcuNzQzNDYgOC43MDU3MSA3Ljc0MzQ2IDkuNDE3MzMgOC4xODI4IDkuODU2NjdDOC42MjM4MiAxMC4yOTY0IDkuMzM1ODIgMTAuMjk2NCA5Ljc3NTg1IDkuODU2NjdDMTAuMjE1NiA5LjQxNzMzIDEwLjIxNTYgOC43MDUzMyA5Ljc3NTg1IDguMjY1WiIvPgoJPC9nPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,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"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8cGF0aCBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIiBkPSJNMTUgMTVIM3YyaDEydi0yem0wLThIM3YyaDEyVjd6TTMgMTNoMTh2LTJIM3Yyem0wIDhoMTh2LTJIM3Yyek0zIDN2MmgxOFYzSDN6Ii8+Cjwvc3ZnPgo="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICA8ZyBjbGFzcz0ianAtaWNvbjMganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjNjE2MTYxIj4KICAgIDxwYXRoIGQ9Ik03LDVIMjFWN0g3VjVNNywxM1YxMUgyMVYxM0g3TTQsNC41QTEuNSwxLjUgMCAwLDEgNS41LDZBMS41LDEuNSAwIDAsMSA0LDcuNUExLjUsMS41IDAgMCwxIDIuNSw2QTEuNSwxLjUgMCAwLDEgNCw0LjVNNCwxMC41QTEuNSwxLjUgMCAwLDEgNS41LDEyQTEuNSwxLjUgMCAwLDEgNCwxMy41QTEuNSwxLjUgMCAwLDEgMi41LDEyQTEuNSwxLjUgMCAwLDEgNCwxMC41TTcsMTlWMTdIMjFWMTlIN000LDE2LjVBMS41LDEuNSAwIDAsMSA1LjUsMThBMS41LDEuNSAwIDAsMSA0LDE5LjVBMS41LDEuNSAwIDAsMSAyLjUsMThBMS41LDEuNSAwIDAsMSA0LDE2LjVaIiAvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBoZWlnaHQ9IjI0IiB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICAgIDxnIGNsYXNzPSJqcC1pY29uMyIgZmlsbD0iIzYxNjE2MSI+CiAgICAgICAgPHBhdGggZD0iTTAgMGgyNHYyNEgweiIgZmlsbD0ibm9uZSIvPgogICAgICAgIDxwYXRoIGQ9Ik0yMiAxMVYzaC03djNIOVYzSDJ2OGg3VjhoMnYxMGg0djNoN3YtOGgtN3YzaC0yVjhoMnYzeiIvPgogICAgPC9nPgo8L3N2Zz4="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyBmaWxsPSJub25lIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDI0IDI1Ij4KICAgIDxwYXRoIGNsYXNzPSJqcC1pY29uMiIgc3Ryb2tlPSIjMzMzMzMzIiBzdHJva2Utd2lkdGg9IjIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDIgMykiIGQ9Ik0xLjg2MDk0IDExLjQ0MDlDMC44MjY0NDggOC43NzAyNyAwLjg2Mzc3OSA2LjA1NzY0IDEuMjQ5MDcgNC4xOTkzMkMyLjQ4MjA2IDMuOTMzNDcgNC4wODA2OCAzLjQwMzQ3IDUuNjAxMDIgMi44NDQ5QzcuMjM1NDkgMi4yNDQ0IDguODU2NjYgMS41ODE1IDkuOTg3NiAxLjA5NTM5QzExLjA1OTcgMS41ODM0MSAxMi42MDk0IDIuMjQ0NCAxNC4yMTggMi44NDMzOUMxNS43NTAzIDMuNDEzOTQgMTcuMzk5NSAzLjk1MjU4IDE4Ljc1MzkgNC4yMTM4NUMxOS4xMzY0IDYuMDcxNzcgMTkuMTcwOSA4Ljc3NzIyIDE4LjEzOSAxMS40NDA5QzE3LjAzMDMgMTQuMzAzMiAxNC42NjY4IDE3LjE4NDQgOS45OTk5OSAxOC45MzU0QzUuMzMzMiAxNy4xODQ0IDIuOTY5NjggMTQuMzAzMiAxLjg2MDk0IDExLjQ0MDlaIi8+CiAgICA8cGF0aCBjbGFzcz0ianAtaWNvbjIiIGZpbGw9IiMzMzMzMzMiIHN0cm9rZT0iIzMzMzMzMyIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOCA5Ljg2NzE5KSIgZD0iTTIuODYwMTUgNC44NjUzNUwwLjcyNjU0OSAyLjk5OTU5TDAgMy42MzA0NUwyLjg2MDE1IDYuMTMxNTdMOCAwLjYzMDg3Mkw3LjI3ODU3IDBMMi44NjAxNSA0Ljg2NTM1WiIvPgo8L3N2Zz4K"},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIHdpZHRoPSIxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZyBjbGFzcz0ianAtaWNvbjMiIGZpbGw9IiM2MTYxNjEiPgogICAgPHBhdGggZD0iTTEyLjUgOGMtMi42NSAwLTUuMDUuOTktNi45IDIuNkwyIDd2OWg5bC0zLjYyLTMuNjJjMS4zOS0xLjE2IDMuMTYtMS44OCA1LjEyLTEuODggMy41NCAwIDYuNTUgMi4zMSA3LjYgNS41bDIuMzctLjc4QzIxLjA4IDExLjAzIDE3LjE1IDggMTIuNSA4eiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8ZyBjbGFzcz0ianAtaWNvbjEganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjMjEyMTIxIj4KICAgIDxwYXRoIGQ9Ik0xMC42IDUuNGwyLjItMy4ySDIuMnY3LjNsNC02LjZ6Ii8+CiAgICA8cGF0aCBkPSJNMTUuOCAyLjJsLTQuNCA2LjZMNyA2LjNsLTQuOCA4djUuNWgxNy42VjIuMmgtNHptLTcgMTUuNEg1LjV2LTQuNGgzLjN2NC40em00LjQgMEg5LjhWOS44aDMuNHY3Ljh6bTQuNCAwaC0zLjRWNi41aDMuNHYxMS4xeiIvPgogIDwvZz4KPC9zdmc+Cg=="},function(e,t){e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgdmlld0JveD0iMCAwIDIyIDIyIj4KICA8ZyBjbGFzcz0ianAtaWNvbi1jb250cmFzdDIganAtaWNvbi1zZWxlY3RhYmxlIiBmaWxsPSIjRDgxQjYwIj4KICAgIDxwYXRoIGQ9Ik03LjIgMTguNnYtNS40TDMgNS42aDMuM2wxLjQgMy4xYy4zLjkuNiAxLjYgMSAyLjUuMy0uOC42LTEuNiAxLTIuNWwxLjQtMy4xaDMuNGwtNC40IDcuNnY1LjVsLTIuOS0uMXoiLz4KICAgIDxjaXJjbGUgY2xhc3M9InN0MCIgY3g9IjE3LjYiIGN5PSIxNi41IiByPSIyLjEiLz4KICAgIDxjaXJjbGUgY2xhc3M9InN0MCIgY3g9IjE3LjYiIGN5PSIxMSIgcj0iMi4xIi8+CiAgPC9nPgo8L3N2Zz4K"},function(e,t,n){(function(t){var n=/[&<>"'`]/g,r=RegExp(n.source),i="object"==typeof t&&t&&t.Object===Object&&t,o="object"==typeof self&&self&&self.Object===Object&&self,a=i||o||Function("return this")();var s,l=(s={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","`":"&#96;"},function(e){return null==s?void 0:s[e]}),c=Object.prototype.toString,u=a.Symbol,d=u?u.prototype:void 0,h=d?d.toString:void 0;function p(e){if("string"==typeof e)return e;if(function(e){return"symbol"==typeof e||function(e){return!!e&&"object"==typeof e}(e)&&"[object Symbol]"==c.call(e)}(e))return h?h.call(e):"";var t=e+"";return"0"==t&&1/e==-1/0?"-0":t}e.exports=function(e){var t;return(e=null==(t=e)?"":p(t))&&r.test(e)?e.replace(n,l):e}}).call(this,n(55))},function(module,__webpack_exports__,__webpack_require__){"use strict";__webpack_require__.d(__webpack_exports__,"a",(function(){return rendererFactory}));var _jupyterlab_rendermime__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(70);const TEXT_JAVASCRIPT_MIMETYPE="text/javascript",APPLICATION_JAVASCRIPT_MIMETYPE="application/javascript";function evalInContext(code,element,document,window){return eval(code)}class ExperimentalRenderedJavascript extends _jupyterlab_rendermime__WEBPACK_IMPORTED_MODULE_0__.c{render(e){const t=this.translator.load("jupyterlab"),n=()=>{try{const t=e.data[this.mimeType];return t&&evalInContext(t,this.node,document,window),Promise.resolve()}catch(e){return Promise.reject(e)}};if(!e.trusted){const e=document.createElement("pre");e.textContent=t.__("Are you sure that you want to run arbitrary Javascript within your JupyterLab session?");const r=document.createElement("button");return r.textContent=t.__("Run"),this.node.appendChild(e),this.node.appendChild(r),r.onclick=e=>{this.node.textContent="",n()},Promise.resolve()}return n()}}const rendererFactory={safe:!1,mimeTypes:[TEXT_JAVASCRIPT_MIMETYPE,APPLICATION_JAVASCRIPT_MIMETYPE],createRenderer:e=>new ExperimentalRenderedJavascript(e)},extension={id:"@jupyterlab/javascript-extension:factory",rendererFactory:rendererFactory,rank:0,dataType:"string"};var _unused_webpack_default_export=extension},function(e,t,n){var r=n(747);e.exports=function(e,t){return r(e,t)}},function(e,t,n){var r=n(105),i=n(813),o=n(106),a=Function.prototype,s=Object.prototype,l=a.toString,c=s.hasOwnProperty,u=l.call(Object);e.exports=function(e){if(!o(e)||"[object Object]"!=r(e))return!1;var t=i(e);if(null===t)return!0;var n=c.call(t,"constructor")&&t.constructor;return"function"==typeof n&&n instanceof n&&l.call(n)==u}},function(e,t,n){"use strict";const r=n(819),i=e=>{if(!Number.isInteger(e)&&e!==1/0||!(e>0))return Promise.reject(new TypeError("Expected `concurrency` to be a number from 1 and up"));const t=[];let n=0;const i=()=>{n--,t.length>0&&t.shift()()},o=(e,t,...o)=>{n++;const a=r(e,...o);t(a),a.then(i,i)},a=(r,...i)=>new Promise(a=>((r,i,...a)=>{n<e?o(r,i,...a):t.push(o.bind(null,r,i,...a))})(r,a,...i));return Object.defineProperties(a,{activeCount:{get:()=>n},pendingCount:{get:()=>t.length},clearQueue:{value:()=>{t.length=0}}}),a};e.exports=i,e.exports.default=i},function(e,t,n){"use strict";var r=n(75),i=n.n(r),o=n(76),a=n.n(o)()(i.a);a.push([e.i,"/* This file has code derived from PhosphorJS CSS files, as noted below. The license for this PhosphorJS code is:\n\nCopyright (c) 2014-2017, PhosphorJS Contributors\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n* Redistributions of source code must retain the above copyright notice, this\n  list of conditions and the following disclaimer.\n\n* Redistributions in binary form must reproduce the above copyright notice,\n  this list of conditions and the following disclaimer in the documentation\n  and/or other materials provided with the distribution.\n\n* Neither the name of the copyright holder nor the names of its\n  contributors may be used to endorse or promote products derived from\n  this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\nAND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE\nFOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\nDAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\nSERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\nCAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\nOR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\nOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n*/\n\n/*\n * The following section is derived from https://github.com/phosphorjs/phosphor/blob/23b9d075ebc5b73ab148b6ebfc20af97f85714c4/packages/widgets/style/tabbar.css \n * We've scoped the rules so that they are consistent with exactly our code.\n */\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n  display: flex;\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='horizontal'] {\n  flex-direction: row;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='vertical'] {\n  flex-direction: column;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar > .p-TabBar-content {\n  margin: 0;\n  padding: 0;\n  display: flex;\n  flex: 1 1 auto;\n  list-style-type: none;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='horizontal'] > .p-TabBar-content {\n  flex-direction: row;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='vertical'] > .p-TabBar-content {\n  flex-direction: column;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab {\n  display: flex;\n  flex-direction: row;\n  box-sizing: border-box;\n  overflow: hidden;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabIcon,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabCloseIcon {\n  flex: 0 0 auto;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabLabel {\n  flex: 1 1 auto;\n  overflow: hidden;\n  white-space: nowrap;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-hidden {\n  display: none !important;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging .p-TabBar-tab {\n  position: relative;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging[data-orientation='horizontal'] .p-TabBar-tab {\n  left: 0;\n  transition: left 150ms ease;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging[data-orientation='vertical'] .p-TabBar-tab {\n  top: 0;\n  transition: top 150ms ease;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging .p-TabBar-tab.p-mod-dragging {\n  transition: none;\n}\n\n/* End tabbar.css */\n","",{version:3,sources:["webpack://./../../node_modules/@jupyter-widgets/controls/css/phosphor.css"],names:[],mappings:"AAAA;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;CA8BC;;AAED;;;EAGE;;AAEF;EACE,aAAa;EACb,yBAAyB;EACzB,sBAAsB;EACtB,qBAAqB;EACrB,iBAAiB;AACnB;;;AAGA;EACE,mBAAmB;AACrB;;;AAGA;EACE,sBAAsB;AACxB;;;AAGA;EACE,SAAS;EACT,UAAU;EACV,aAAa;EACb,cAAc;EACd,qBAAqB;AACvB;;;AAGA;EACE,mBAAmB;AACrB;;;AAGA;EACE,sBAAsB;AACxB;;;AAGA;EACE,aAAa;EACb,mBAAmB;EACnB,sBAAsB;EACtB,gBAAgB;AAClB;;;AAGA;;EAEE,cAAc;AAChB;;;AAGA;EACE,cAAc;EACd,gBAAgB;EAChB,mBAAmB;AACrB;;;AAGA;EACE,wBAAwB;AAC1B;;;AAGA;EACE,kBAAkB;AACpB;;;AAGA;EACE,OAAO;EACP,2BAA2B;AAC7B;;;AAGA;EACE,MAAM;EACN,0BAA0B;AAC5B;;;AAGA;EACE,gBAAgB;AAClB;;AAEA,mBAAmB",sourcesContent:["/* This file has code derived from PhosphorJS CSS files, as noted below. The license for this PhosphorJS code is:\n\nCopyright (c) 2014-2017, PhosphorJS Contributors\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n* Redistributions of source code must retain the above copyright notice, this\n  list of conditions and the following disclaimer.\n\n* Redistributions in binary form must reproduce the above copyright notice,\n  this list of conditions and the following disclaimer in the documentation\n  and/or other materials provided with the distribution.\n\n* Neither the name of the copyright holder nor the names of its\n  contributors may be used to endorse or promote products derived from\n  this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\nAND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE\nFOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\nDAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\nSERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\nCAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\nOR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\nOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n*/\n\n/*\n * The following section is derived from https://github.com/phosphorjs/phosphor/blob/23b9d075ebc5b73ab148b6ebfc20af97f85714c4/packages/widgets/style/tabbar.css \n * We've scoped the rules so that they are consistent with exactly our code.\n */\n\n.jupyter-widgets.widget-tab > .p-TabBar {\n  display: flex;\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='horizontal'] {\n  flex-direction: row;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='vertical'] {\n  flex-direction: column;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar > .p-TabBar-content {\n  margin: 0;\n  padding: 0;\n  display: flex;\n  flex: 1 1 auto;\n  list-style-type: none;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='horizontal'] > .p-TabBar-content {\n  flex-direction: row;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar[data-orientation='vertical'] > .p-TabBar-content {\n  flex-direction: column;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab {\n  display: flex;\n  flex-direction: row;\n  box-sizing: border-box;\n  overflow: hidden;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabIcon,\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabCloseIcon {\n  flex: 0 0 auto;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tabLabel {\n  flex: 1 1 auto;\n  overflow: hidden;\n  white-space: nowrap;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar .p-TabBar-tab.p-mod-hidden {\n  display: none !important;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging .p-TabBar-tab {\n  position: relative;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging[data-orientation='horizontal'] .p-TabBar-tab {\n  left: 0;\n  transition: left 150ms ease;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging[data-orientation='vertical'] .p-TabBar-tab {\n  top: 0;\n  transition: top 150ms ease;\n}\n\n\n.jupyter-widgets.widget-tab > .p-TabBar.p-mod-dragging .p-TabBar-tab.p-mod-dragging {\n  transition: none;\n}\n\n/* End tabbar.css */\n"],sourceRoot:""}]),t.a=a},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.TeX=void 0;var s=n(416),l=n(47),c=n(821),u=n(823),d=n(39),h=n(49),p=n(31),f=n(419),m=n(72),g=n(29);n(183);var v=function(e){function t(n){void 0===n&&(n={});var r=this,i=a(l.separateOptions(n,t.OPTIONS,c.FindTeX.OPTIONS),3),o=i[0],s=i[1],d=i[2];(r=e.call(this,s)||this).findTeX=r.options.FindTeX||new c.FindTeX(d);var h=r.options.packages,p=r.configuration=t.configure(h),g=r._parseOptions=new f.default(p,[r.options,m.TagsFactory.OPTIONS]);return l.userOptions(g.options,o),p.config(r),t.tags(g,p),r.postFilters.add(u.default.cleanSubSup,-6),r.postFilters.add(u.default.setInherited,-5),r.postFilters.add(u.default.moveLimits,-4),r.postFilters.add(u.default.cleanStretchy,-3),r.postFilters.add(u.default.cleanAttributes,-2),r.postFilters.add(u.default.combineRelations,-1),r}return i(t,e),t.configure=function(e){var t=new g.ParserConfiguration(e,["tex"]);return t.init(),t},t.tags=function(e,t){m.TagsFactory.addTags(t.tags),m.TagsFactory.setDefault(e.options.tags),e.tags=m.TagsFactory.getDefault(),e.tags.configuration=e},t.prototype.setMmlFactory=function(t){e.prototype.setMmlFactory.call(this,t),this._parseOptions.nodeFactory.setMmlFactory(t)},Object.defineProperty(t.prototype,"parseOptions",{get:function(){return this._parseOptions},enumerable:!1,configurable:!0}),t.prototype.reset=function(e){void 0===e&&(e=0),this.parseOptions.tags.reset(e)},t.prototype.compile=function(e,t){this.parseOptions.clear(),this.executeFilters(this.preFilters,e,t,this.parseOptions);var n,r,i=e.display;this.latex=e.math,this.parseOptions.tags.startEquation(e);try{var o=new h.default(this.latex,{display:i,isInner:!1},this.parseOptions);n=o.mml(),r=o.stack.global}catch(e){if(!(e instanceof p.default))throw e;this.parseOptions.error=!0,n=this.options.formatError(this,e)}return n=this.parseOptions.nodeFactory.create("node","math",[n]),(null==r?void 0:r.indentalign)&&d.default.setAttribute(n,"indentalign",r.indentalign),i&&d.default.setAttribute(n,"display","block"),this.parseOptions.tags.finishEquation(e),this.parseOptions.root=n,this.executeFilters(this.postFilters,e,t,this.parseOptions),this.mathNode=this.parseOptions.root,this.mathNode},t.prototype.findMath=function(e){return this.findTeX.findMath(e)},t.prototype.formatError=function(e){var t=e.message.replace(/\n.*/,"");return this.parseOptions.nodeFactory.create("error",t,e.id,this.latex)},t.NAME="TeX",t.OPTIONS=o(o({},s.AbstractInputJax.OPTIONS),{FindTeX:null,packages:["base"],digits:/^(?:[0-9]+(?:\{,\}[0-9]{3})*(?:\.[0-9]*)?|\.[0-9]+)/,maxBuffer:5120,formatError:function(e,t){return e.formatError(t)}}),t}(s.AbstractInputJax);t.TeX=v},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTML=void 0;var s=n(828),l=n(422),c=n(829),u=n(449),d=n(194),h=n(58),p=n(62),f=function(e){function t(t){void 0===t&&(t=null);var n=e.call(this,t,c.CHTMLWrapperFactory,d.TeXFont)||this;return n.chtmlStyles=null,n.font.adaptiveCSS(n.options.adaptiveCSS),n.wrapperUsage=new u.Usage,n}return i(t,e),t.prototype.escaped=function(e,t){return this.setDocument(t),this.html("span",{},[this.text(e.math)])},t.prototype.styleSheet=function(n){if(this.chtmlStyles){if(this.options.adaptiveCSS){var r=new l.CssStyles;this.addWrapperStyles(r),this.updateFontStyles(r),this.adaptor.insertRules(this.chtmlStyles,r.getStyleRules())}return this.chtmlStyles}var i=this.chtmlStyles=e.prototype.styleSheet.call(this,n);return this.adaptor.setAttribute(i,"id",t.STYLESHEETID),this.wrapperUsage.update(),i},t.prototype.updateFontStyles=function(e){e.addStyles(this.font.updateStyles({}))},t.prototype.addWrapperStyles=function(t){var n,r;if(this.options.adaptiveCSS)try{for(var i=a(this.wrapperUsage.update()),o=i.next();!o.done;o=i.next()){var s=o.value,l=this.factory.getNodeClass(s);l&&this.addClassStyles(l,t)}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}else e.prototype.addWrapperStyles.call(this,t)},t.prototype.addClassStyles=function(t,n){var r,i=t;i.autoStyle&&"unknown"!==i.kind&&n.addStyles(((r={})["mjx-"+i.kind]={display:"inline-block","text-align":"left"},r)),this.wrapperUsage.add(i.kind),e.prototype.addClassStyles.call(this,t,n)},t.prototype.processMath=function(e,t){this.factory.wrap(e).toCHTML(t)},t.prototype.clearCache=function(){this.cssStyles.clear(),this.font.clearCache(),this.wrapperUsage.clear(),this.chtmlStyles=null},t.prototype.reset=function(){this.clearCache()},t.prototype.unknownText=function(e,t,n){void 0===n&&(n=null);var r={},i=100/this.math.metrics.scale;if(100!==i&&(r["font-size"]=this.fixed(i,1)+"%",r.padding=h.em(75/i)+" 0 "+h.em(20/i)+" 0"),"-explicitFont"!==t){var o=p.unicodeChars(e);(1!==o.length||o[0]<119808||o[0]>120831)&&this.cssFontStyles(this.font.getCssFont(t),r)}if(null!==n){var a=this.math.metrics;r.width=Math.round(n*a.em*a.scale)+"px"}return this.html("mjx-utext",{variant:t,style:r},[this.text(e)])},t.prototype.measureTextNode=function(e){var t=this.adaptor,n=t.clone(e);t.setStyle(n,"font-family",t.getStyle(n,"font-family").replace(/MJXZERO, /g,""));var r=this.html("mjx-measure-text",{style:{position:"absolute","white-space":"nowrap"}},[n]);t.append(t.parent(this.math.start.node),this.container),t.append(this.container,r);var i=t.nodeSize(n,this.math.metrics.em)[0]/this.math.metrics.scale;return t.remove(this.container),t.remove(r),{w:i,h:.75,d:.2}},t.NAME="CHTML",t.OPTIONS=o(o({},s.CommonOutputJax.OPTIONS),{adaptiveCSS:!0,matchFontHeight:!0}),t.commonStyles={'mjx-container[jax="CHTML"]':{"line-height":0},'mjx-container [space="1"]':{"margin-left":".111em"},'mjx-container [space="2"]':{"margin-left":".167em"},'mjx-container [space="3"]':{"margin-left":".222em"},'mjx-container [space="4"]':{"margin-left":".278em"},'mjx-container [space="5"]':{"margin-left":".333em"},'mjx-container [rspace="1"]':{"margin-right":".111em"},'mjx-container [rspace="2"]':{"margin-right":".167em"},'mjx-container [rspace="3"]':{"margin-right":".222em"},'mjx-container [rspace="4"]':{"margin-right":".278em"},'mjx-container [rspace="5"]':{"margin-right":".333em"},'mjx-container [size="s"]':{"font-size":"70.7%"},'mjx-container [size="ss"]':{"font-size":"50%"},'mjx-container [size="Tn"]':{"font-size":"60%"},'mjx-container [size="sm"]':{"font-size":"85%"},'mjx-container [size="lg"]':{"font-size":"120%"},'mjx-container [size="Lg"]':{"font-size":"144%"},'mjx-container [size="LG"]':{"font-size":"173%"},'mjx-container [size="hg"]':{"font-size":"207%"},'mjx-container [size="HG"]':{"font-size":"249%"},'mjx-container [width="full"]':{width:"100%"},"mjx-box":{display:"inline-block"},"mjx-block":{display:"block"},"mjx-itable":{display:"inline-table"},"mjx-row":{display:"table-row"},"mjx-row > *":{display:"table-cell"},"mjx-mtext":{display:"inline-block"},"mjx-mstyle":{display:"inline-block"},"mjx-merror":{display:"inline-block",color:"red","background-color":"yellow"},"mjx-mphantom":{visibility:"hidden"},"_::-webkit-full-page-media, _:future, :root mjx-container":{"will-change":"opacity"}},t.STYLESHEETID="MJX-CHTML-styles",t}(s.CommonOutputJax);t.CHTML=f},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.browserAdaptor=void 0;var r=n(932);t.browserAdaptor=function(){return new r.HTMLAdaptor(window)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.RegisterHTMLHandler=void 0;var r=n(142),i=n(934);t.RegisterHTMLHandler=function(e){var t=new i.HTMLHandler(e);return r.mathjax.handlers.register(t),t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AllPackages=void 0,n(183),n(951),n(452),n(953),n(956),n(957),n(958),n(962),n(966),n(967),n(968),n(969),n(973),n(974),n(975),n(976),n(454),n(977),n(979),n(980),n(458),n(985),n(457),n(987),n(988),n(989),n(993),n(994),n(995),n(997),n(999),n(1e3),n(1001),"undefined"!=typeof MathJax&&MathJax.loader&&MathJax.loader.preLoad("[tex]/action","[tex]/ams","[tex]/amscd","[tex]/bbox","[tex]/boldsymbol","[tex]/braket","[tex]/bussproofs","[tex]/cancel","[tex]/cases","[tex]/centernot","[tex]/color","[tex]/colorv2","[tex]/colortbl","[tex]/empheq","[tex]/enclose","[tex]/extpfeil","[tex]/gensymb","[tex]/html","[tex]/mathtools","[tex]/mhchem","[tex]/newcommand","[tex]/noerrors","[tex]/noundefined","[tex]/physics","[tex]/upgreek","[tex]/unicode","[tex]/verb","[tex]/configmacros","[tex]/tagformat","[tex]/textcomp","[tex]/textmacros","[tex]/setoptions"),t.AllPackages=["base","action","ams","amscd","bbox","boldsymbol","braket","bussproofs","cancel","cases","centernot","color","colortbl","empheq","enclose","extpfeil","gensymb","html","mathtools","mhchem","newcommand","noerrors","noundefined","upgreek","unicode","verb","configmacros","tagformat","textcomp","textmacros"]},function(e,t,n){"use strict";n.d(t,"a",(function(){return a}));var r=n(489),i=(n(492),n(496),n(197),n(493),n(0)),o=(n(13),n(45));const a=e=>i.createElement(r.Button,Object.assign({},e,{className:Object(o.a)(e.className,e.minimal?"minimal":"","jp-Button")}))},function(e,t,n){!function(e){"use strict";function t(e,t){if(!e.hasOwnProperty(t))throw new Error("Undefined state "+t+" in simple mode")}function n(e,t){if(!e)return/(?:)/;var n="";return e instanceof RegExp?(e.ignoreCase&&(n="i"),e.unicode&&(n+="u"),e=e.source):e=String(e),new RegExp((!1===t?"":"^")+"(?:"+e+")",n)}function r(e,r){(e.next||e.push)&&t(r,e.next||e.push),this.regex=n(e.regex),this.token=function(e){if(!e)return null;if(e.apply)return e;if("string"==typeof e)return e.replace(/\./g," ");for(var t=[],n=0;n<e.length;n++)t.push(e[n]&&e[n].replace(/\./g," "));return t}(e.token),this.data=e}function i(e,t){return function(n,r){if(r.pending){var i=r.pending.shift();return 0==r.pending.length&&(r.pending=null),n.pos+=i.text.length,i.token}if(r.local){if(r.local.end&&n.match(r.local.end)){var o=r.local.endToken||null;return r.local=r.localState=null,o}var s;return o=r.local.mode.token(n,r.localState),r.local.endScan&&(s=r.local.endScan.exec(n.current()))&&(n.pos=n.start+s.index),o}for(var l=e[r.state],c=0;c<l.length;c++){var u=l[c],d=(!u.data.sol||n.sol())&&n.match(u.regex);if(d){u.data.next?r.state=u.data.next:u.data.push?((r.stack||(r.stack=[])).push(r.state),r.state=u.data.push):u.data.pop&&r.stack&&r.stack.length&&(r.state=r.stack.pop()),u.data.mode&&a(t,r,u.data.mode,u.token),u.data.indent&&r.indent.push(n.indentation()+t.indentUnit),u.data.dedent&&r.indent.pop();var h=u.token;if(h&&h.apply&&(h=h(d)),d.length>2&&u.token&&"string"!=typeof u.token){for(var p=2;p<d.length;p++)d[p]&&(r.pending||(r.pending=[])).push({text:d[p],token:u.token[p-1]});return n.backUp(d[0].length-(d[1]?d[1].length:0)),h[0]}return h&&h.join?h[0]:h}}return n.next(),null}}function o(e,t){if(e===t)return!0;if(!e||"object"!=typeof e||!t||"object"!=typeof t)return!1;var n=0;for(var r in e)if(e.hasOwnProperty(r)){if(!t.hasOwnProperty(r)||!o(e[r],t[r]))return!1;n++}for(var r in t)t.hasOwnProperty(r)&&n--;return 0==n}function a(t,r,i,a){var s;if(i.persistent)for(var l=r.persistentStates;l&&!s;l=l.next)(i.spec?o(i.spec,l.spec):i.mode==l.mode)&&(s=l);var c=s?s.mode:i.mode||e.getMode(t,i.spec),u=s?s.state:e.startState(c);i.persistent&&!s&&(r.persistentStates={mode:c,spec:i.spec,state:u,next:r.persistentStates}),r.localState=u,r.local={mode:c,end:i.end&&n(i.end),endScan:i.end&&!1!==i.forceEnd&&n(i.end,!1),endToken:a&&a.join?a[a.length-1]:a}}function s(t,n){return function(r,i,o){if(r.local&&r.local.mode.indent)return r.local.mode.indent(r.localState,i,o);if(null==r.indent||r.local||n.dontIndentStates&&function(e,t){for(var n=0;n<t.length;n++)if(t[n]===e)return!0}(r.state,n.dontIndentStates)>-1)return e.Pass;var a=r.indent.length-1,s=t[r.state];e:for(;;){for(var l=0;l<s.length;l++){var c=s[l];if(c.data.dedent&&!1!==c.data.dedentIfLineStart){var u=c.regex.exec(i);if(u&&u[0]){a--,(c.next||c.push)&&(s=t[c.next||c.push]),i=i.slice(u[0].length);continue e}}}break}return a<0?0:r.indent[a]}}e.defineSimpleMode=function(t,n){e.defineMode(t,(function(t){return e.simpleMode(t,n)}))},e.simpleMode=function(n,o){t(o,"start");var a={},l=o.meta||{},c=!1;for(var u in o)if(u!=l&&o.hasOwnProperty(u))for(var d=a[u]=[],h=o[u],p=0;p<h.length;p++){var f=h[p];d.push(new r(f,o)),(f.indent||f.dedent)&&(c=!0)}var m={startState:function(){return{state:"start",pending:null,local:null,localState:null,indent:c?[]:null}},copyState:function(t){var n={state:t.state,pending:t.pending,local:t.local,localState:null,indent:t.indent&&t.indent.slice(0)};t.localState&&(n.localState=e.copyState(t.local.mode,t.localState)),t.stack&&(n.stack=t.stack.slice(0));for(var r=t.persistentStates;r;r=r.next)n.persistentStates={mode:r.mode,spec:r.spec,state:r.state==t.localState?n.localState:e.copyState(r.mode,r.state),next:n.persistentStates};return n},token:i(a,n),innerMode:function(e){return e.local&&{mode:e.local.mode,state:e.localState}},indent:s(a,l)};if(l)for(var g in l)l.hasOwnProperty(g)&&(m[g]=l[g]);return m}}(n(14))},function(e,t,n){!function(e){"use strict";function t(e){for(var t={},n=0;n<e.length;++n)t[e[n].toLowerCase()]=!0;return t}e.defineMode("css",(function(t,n){var r=n.inline;n.propertyKeywords||(n=e.resolveMode("text/css"));var i,o,a=t.indentUnit,s=n.tokenHooks,l=n.documentTypes||{},c=n.mediaTypes||{},u=n.mediaFeatures||{},d=n.mediaValueKeywords||{},h=n.propertyKeywords||{},p=n.nonStandardPropertyKeywords||{},f=n.fontProperties||{},m=n.counterDescriptors||{},g=n.colorKeywords||{},v=n.valueKeywords||{},y=n.allowNested,_=n.lineComment,b=!0===n.supportsAtComponent,M=!1!==t.highlightNonStandardPropertyKeywords;function w(e,t){return i=t,e}function A(e,t){var n=e.next();if(s[n]){var r=s[n](e,t);if(!1!==r)return r}return"@"==n?(e.eatWhile(/[\w\\\-]/),w("def",e.current())):"="==n||("~"==n||"|"==n)&&e.eat("=")?w(null,"compare"):'"'==n||"'"==n?(t.tokenize=C(n),t.tokenize(e,t)):"#"==n?(e.eatWhile(/[\w\\\-]/),w("atom","hash")):"!"==n?(e.match(/^\s*\w*/),w("keyword","important")):/\d/.test(n)||"."==n&&e.eat(/\d/)?(e.eatWhile(/[\w.%]/),w("number","unit")):"-"!==n?/[,+>*\/]/.test(n)?w(null,"select-op"):"."==n&&e.match(/^-?[_a-z][_a-z0-9-]*/i)?w("qualifier","qualifier"):/[:;{}\[\]\(\)]/.test(n)?w(null,n):e.match(/^[\w-.]+(?=\()/)?(/^(url(-prefix)?|domain|regexp)$/i.test(e.current())&&(t.tokenize=x),w("variable callee","variable")):/[\w\\\-]/.test(n)?(e.eatWhile(/[\w\\\-]/),w("property","word")):w(null,null):/[\d.]/.test(e.peek())?(e.eatWhile(/[\w.%]/),w("number","unit")):e.match(/^-[\w\\\-]*/)?(e.eatWhile(/[\w\\\-]/),e.match(/^\s*:/,!1)?w("variable-2","variable-definition"):w("variable-2","variable")):e.match(/^\w+-/)?w("meta","meta"):void 0}function C(e){return function(t,n){for(var r,i=!1;null!=(r=t.next());){if(r==e&&!i){")"==e&&t.backUp(1);break}i=!i&&"\\"==r}return(r==e||!i&&")"!=e)&&(n.tokenize=null),w("string","string")}}function x(e,t){return e.next(),e.match(/^\s*[\"\')]/,!1)?t.tokenize=null:t.tokenize=C(")"),w(null,"(")}function E(e,t,n){this.type=e,this.indent=t,this.prev=n}function L(e,t,n,r){return e.context=new E(n,t.indentation()+(!1===r?0:a),e.context),n}function S(e){return e.context.prev&&(e.context=e.context.prev),e.context.type}function T(e,t,n){return k[n.context.type](e,t,n)}function O(e,t,n,r){for(var i=r||1;i>0;i--)n.context=n.context.prev;return T(e,t,n)}function I(e){var t=e.current().toLowerCase();o=v.hasOwnProperty(t)?"atom":g.hasOwnProperty(t)?"keyword":"variable"}var k={top:function(e,t,n){if("{"==e)return L(n,t,"block");if("}"==e&&n.context.prev)return S(n);if(b&&/@component/i.test(e))return L(n,t,"atComponentBlock");if(/^@(-moz-)?document$/i.test(e))return L(n,t,"documentTypes");if(/^@(media|supports|(-moz-)?document|import)$/i.test(e))return L(n,t,"atBlock");if(/^@(font-face|counter-style)/i.test(e))return n.stateArg=e,"restricted_atBlock_before";if(/^@(-(moz|ms|o|webkit)-)?keyframes$/i.test(e))return"keyframes";if(e&&"@"==e.charAt(0))return L(n,t,"at");if("hash"==e)o="builtin";else if("word"==e)o="tag";else{if("variable-definition"==e)return"maybeprop";if("interpolation"==e)return L(n,t,"interpolation");if(":"==e)return"pseudo";if(y&&"("==e)return L(n,t,"parens")}return n.context.type},block:function(e,t,n){if("word"==e){var r=t.current().toLowerCase();return h.hasOwnProperty(r)?(o="property","maybeprop"):p.hasOwnProperty(r)?(o=M?"string-2":"property","maybeprop"):y?(o=t.match(/^\s*:(?:\s|$)/,!1)?"property":"tag","block"):(o+=" error","maybeprop")}return"meta"==e?"block":y||"hash"!=e&&"qualifier"!=e?k.top(e,t,n):(o="error","block")},maybeprop:function(e,t,n){return":"==e?L(n,t,"prop"):T(e,t,n)},prop:function(e,t,n){if(";"==e)return S(n);if("{"==e&&y)return L(n,t,"propBlock");if("}"==e||"{"==e)return O(e,t,n);if("("==e)return L(n,t,"parens");if("hash"!=e||/^#([0-9a-fA-f]{3,4}|[0-9a-fA-f]{6}|[0-9a-fA-f]{8})$/.test(t.current())){if("word"==e)I(t);else if("interpolation"==e)return L(n,t,"interpolation")}else o+=" error";return"prop"},propBlock:function(e,t,n){return"}"==e?S(n):"word"==e?(o="property","maybeprop"):n.context.type},parens:function(e,t,n){return"{"==e||"}"==e?O(e,t,n):")"==e?S(n):"("==e?L(n,t,"parens"):"interpolation"==e?L(n,t,"interpolation"):("word"==e&&I(t),"parens")},pseudo:function(e,t,n){return"meta"==e?"pseudo":"word"==e?(o="variable-3",n.context.type):T(e,t,n)},documentTypes:function(e,t,n){return"word"==e&&l.hasOwnProperty(t.current())?(o="tag",n.context.type):k.atBlock(e,t,n)},atBlock:function(e,t,n){if("("==e)return L(n,t,"atBlock_parens");if("}"==e||";"==e)return O(e,t,n);if("{"==e)return S(n)&&L(n,t,y?"block":"top");if("interpolation"==e)return L(n,t,"interpolation");if("word"==e){var r=t.current().toLowerCase();o="only"==r||"not"==r||"and"==r||"or"==r?"keyword":c.hasOwnProperty(r)?"attribute":u.hasOwnProperty(r)?"property":d.hasOwnProperty(r)?"keyword":h.hasOwnProperty(r)?"property":p.hasOwnProperty(r)?M?"string-2":"property":v.hasOwnProperty(r)?"atom":g.hasOwnProperty(r)?"keyword":"error"}return n.context.type},atComponentBlock:function(e,t,n){return"}"==e?O(e,t,n):"{"==e?S(n)&&L(n,t,y?"block":"top",!1):("word"==e&&(o="error"),n.context.type)},atBlock_parens:function(e,t,n){return")"==e?S(n):"{"==e||"}"==e?O(e,t,n,2):k.atBlock(e,t,n)},restricted_atBlock_before:function(e,t,n){return"{"==e?L(n,t,"restricted_atBlock"):"word"==e&&"@counter-style"==n.stateArg?(o="variable","restricted_atBlock_before"):T(e,t,n)},restricted_atBlock:function(e,t,n){return"}"==e?(n.stateArg=null,S(n)):"word"==e?(o="@font-face"==n.stateArg&&!f.hasOwnProperty(t.current().toLowerCase())||"@counter-style"==n.stateArg&&!m.hasOwnProperty(t.current().toLowerCase())?"error":"property","maybeprop"):"restricted_atBlock"},keyframes:function(e,t,n){return"word"==e?(o="variable","keyframes"):"{"==e?L(n,t,"top"):T(e,t,n)},at:function(e,t,n){return";"==e?S(n):"{"==e||"}"==e?O(e,t,n):("word"==e?o="tag":"hash"==e&&(o="builtin"),"at")},interpolation:function(e,t,n){return"}"==e?S(n):"{"==e||";"==e?O(e,t,n):("word"==e?o="variable":"variable"!=e&&"("!=e&&")"!=e&&(o="error"),"interpolation")}};return{startState:function(e){return{tokenize:null,state:r?"block":"top",stateArg:null,context:new E(r?"block":"top",e||0,null)}},token:function(e,t){if(!t.tokenize&&e.eatSpace())return null;var n=(t.tokenize||A)(e,t);return n&&"object"==typeof n&&(i=n[1],n=n[0]),o=n,"comment"!=i&&(t.state=k[t.state](i,e,t)),o},indent:function(e,t){var n=e.context,r=t&&t.charAt(0),i=n.indent;return"prop"!=n.type||"}"!=r&&")"!=r||(n=n.prev),n.prev&&("}"!=r||"block"!=n.type&&"top"!=n.type&&"interpolation"!=n.type&&"restricted_atBlock"!=n.type?(")"!=r||"parens"!=n.type&&"atBlock_parens"!=n.type)&&("{"!=r||"at"!=n.type&&"atBlock"!=n.type)||(i=Math.max(0,n.indent-a)):i=(n=n.prev).indent),i},electricChars:"}",blockCommentStart:"/*",blockCommentEnd:"*/",blockCommentContinue:" * ",lineComment:_,fold:"brace"}}));var n=["domain","regexp","url","url-prefix"],r=t(n),i=["all","aural","braille","handheld","print","projection","screen","tty","tv","embossed"],o=t(i),a=["width","min-width","max-width","height","min-height","max-height","device-width","min-device-width","max-device-width","device-height","min-device-height","max-device-height","aspect-ratio","min-aspect-ratio","max-aspect-ratio","device-aspect-ratio","min-device-aspect-ratio","max-device-aspect-ratio","color","min-color","max-color","color-index","min-color-index","max-color-index","monochrome","min-monochrome","max-monochrome","resolution","min-resolution","max-resolution","scan","grid","orientation","device-pixel-ratio","min-device-pixel-ratio","max-device-pixel-ratio","pointer","any-pointer","hover","any-hover","prefers-color-scheme"],s=t(a),l=["landscape","portrait","none","coarse","fine","on-demand","hover","interlace","progressive","dark","light"],c=t(l),u=["align-content","align-items","align-self","alignment-adjust","alignment-baseline","all","anchor-point","animation","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-timing-function","appearance","azimuth","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","binding","bleed","block-size","bookmark-label","bookmark-level","bookmark-state","bookmark-target","border","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-decoration-break","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","color","color-profile","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","content","counter-increment","counter-reset","crop","cue","cue-after","cue-before","cursor","direction","display","dominant-baseline","drop-initial-after-adjust","drop-initial-after-align","drop-initial-before-adjust","drop-initial-before-align","drop-initial-size","drop-initial-value","elevation","empty-cells","fit","fit-position","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","float-offset","flow-from","flow-into","font","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-size","font-size-adjust","font-stretch","font-style","font-synthesis","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","gap","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-gap","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-gap","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphens","icon","image-orientation","image-rendering","image-resolution","inline-box-align","inset","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","left","letter-spacing","line-break","line-height","line-height-step","line-stacking","line-stacking-ruby","line-stacking-shift","line-stacking-strategy","list-style","list-style-image","list-style-position","list-style-type","margin","margin-bottom","margin-left","margin-right","margin-top","marks","marquee-direction","marquee-loop","marquee-play-count","marquee-speed","marquee-style","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","move-to","nav-down","nav-index","nav-left","nav-right","nav-up","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-style","overflow-wrap","overflow-x","overflow-y","padding","padding-bottom","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","page-policy","pause","pause-after","pause-before","perspective","perspective-origin","pitch","pitch-range","place-content","place-items","place-self","play-during","position","presentation-level","punctuation-trim","quotes","region-break-after","region-break-before","region-break-inside","region-fragment","rendering-intent","resize","rest","rest-after","rest-before","richness","right","rotate","rotation","rotation-point","row-gap","ruby-align","ruby-overhang","ruby-position","ruby-span","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-type","shape-image-threshold","shape-inside","shape-margin","shape-outside","size","speak","speak-as","speak-header","speak-numeral","speak-punctuation","speech-rate","stress","string-set","tab-size","table-layout","target","target-name","target-new","target-position","text-align","text-align-last","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-height","text-indent","text-justify","text-orientation","text-outline","text-overflow","text-rendering","text-shadow","text-size-adjust","text-space-collapse","text-transform","text-underline-position","text-wrap","top","touch-action","transform","transform-origin","transform-style","transition","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-select","vertical-align","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","volume","white-space","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","z-index","clip-path","clip-rule","mask","enable-background","filter","flood-color","flood-opacity","lighting-color","stop-color","stop-opacity","pointer-events","color-interpolation","color-interpolation-filters","color-rendering","fill","fill-opacity","fill-rule","image-rendering","marker","marker-end","marker-mid","marker-start","paint-order","shape-rendering","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","text-rendering","baseline-shift","dominant-baseline","glyph-orientation-horizontal","glyph-orientation-vertical","text-anchor","writing-mode"],d=t(u),h=["border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","margin-block","margin-block-end","margin-block-start","margin-inline","margin-inline-end","margin-inline-start","padding-block","padding-block-end","padding-block-start","padding-inline","padding-inline-end","padding-inline-start","scroll-snap-stop","scrollbar-3d-light-color","scrollbar-arrow-color","scrollbar-base-color","scrollbar-dark-shadow-color","scrollbar-face-color","scrollbar-highlight-color","scrollbar-shadow-color","scrollbar-track-color","searchfield-cancel-button","searchfield-decoration","searchfield-results-button","searchfield-results-decoration","shape-inside","zoom"],p=t(h),f=t(["font-display","font-family","src","unicode-range","font-variant","font-feature-settings","font-stretch","font-weight","font-style"]),m=t(["additive-symbols","fallback","negative","pad","prefix","range","speak-as","suffix","symbols","system"]),g=["aliceblue","antiquewhite","aqua","aquamarine","azure","beige","bisque","black","blanchedalmond","blue","blueviolet","brown","burlywood","cadetblue","chartreuse","chocolate","coral","cornflowerblue","cornsilk","crimson","cyan","darkblue","darkcyan","darkgoldenrod","darkgray","darkgreen","darkkhaki","darkmagenta","darkolivegreen","darkorange","darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkturquoise","darkviolet","deeppink","deepskyblue","dimgray","dodgerblue","firebrick","floralwhite","forestgreen","fuchsia","gainsboro","ghostwhite","gold","goldenrod","gray","grey","green","greenyellow","honeydew","hotpink","indianred","indigo","ivory","khaki","lavender","lavenderblush","lawngreen","lemonchiffon","lightblue","lightcoral","lightcyan","lightgoldenrodyellow","lightgray","lightgreen","lightpink","lightsalmon","lightseagreen","lightskyblue","lightslategray","lightsteelblue","lightyellow","lime","limegreen","linen","magenta","maroon","mediumaquamarine","mediumblue","mediumorchid","mediumpurple","mediumseagreen","mediumslateblue","mediumspringgreen","mediumturquoise","mediumvioletred","midnightblue","mintcream","mistyrose","moccasin","navajowhite","navy","oldlace","olive","olivedrab","orange","orangered","orchid","palegoldenrod","palegreen","paleturquoise","palevioletred","papayawhip","peachpuff","peru","pink","plum","powderblue","purple","rebeccapurple","red","rosybrown","royalblue","saddlebrown","salmon","sandybrown","seagreen","seashell","sienna","silver","skyblue","slateblue","slategray","snow","springgreen","steelblue","tan","teal","thistle","tomato","turquoise","violet","wheat","white","whitesmoke","yellow","yellowgreen"],v=t(g),y=["above","absolute","activeborder","additive","activecaption","afar","after-white-space","ahead","alias","all","all-scroll","alphabetic","alternate","always","amharic","amharic-abegede","antialiased","appworkspace","arabic-indic","armenian","asterisks","attr","auto","auto-flow","avoid","avoid-column","avoid-page","avoid-region","axis-pan","background","backwards","baseline","below","bidi-override","binary","bengali","blink","block","block-axis","bold","bolder","border","border-box","both","bottom","break","break-all","break-word","bullets","button","button-bevel","buttonface","buttonhighlight","buttonshadow","buttontext","calc","cambodian","capitalize","caps-lock-indicator","caption","captiontext","caret","cell","center","checkbox","circle","cjk-decimal","cjk-earthly-branch","cjk-heavenly-stem","cjk-ideographic","clear","clip","close-quote","col-resize","collapse","color","color-burn","color-dodge","column","column-reverse","compact","condensed","contain","content","contents","content-box","context-menu","continuous","copy","counter","counters","cover","crop","cross","crosshair","currentcolor","cursive","cyclic","darken","dashed","decimal","decimal-leading-zero","default","default-button","dense","destination-atop","destination-in","destination-out","destination-over","devanagari","difference","disc","discard","disclosure-closed","disclosure-open","document","dot-dash","dot-dot-dash","dotted","double","down","e-resize","ease","ease-in","ease-in-out","ease-out","element","ellipse","ellipsis","embed","end","ethiopic","ethiopic-abegede","ethiopic-abegede-am-et","ethiopic-abegede-gez","ethiopic-abegede-ti-er","ethiopic-abegede-ti-et","ethiopic-halehame-aa-er","ethiopic-halehame-aa-et","ethiopic-halehame-am-et","ethiopic-halehame-gez","ethiopic-halehame-om-et","ethiopic-halehame-sid-et","ethiopic-halehame-so-et","ethiopic-halehame-ti-er","ethiopic-halehame-ti-et","ethiopic-halehame-tig","ethiopic-numeric","ew-resize","exclusion","expanded","extends","extra-condensed","extra-expanded","fantasy","fast","fill","fill-box","fixed","flat","flex","flex-end","flex-start","footnotes","forwards","from","geometricPrecision","georgian","graytext","grid","groove","gujarati","gurmukhi","hand","hangul","hangul-consonant","hard-light","hebrew","help","hidden","hide","higher","highlight","highlighttext","hiragana","hiragana-iroha","horizontal","hsl","hsla","hue","icon","ignore","inactiveborder","inactivecaption","inactivecaptiontext","infinite","infobackground","infotext","inherit","initial","inline","inline-axis","inline-block","inline-flex","inline-grid","inline-table","inset","inside","intrinsic","invert","italic","japanese-formal","japanese-informal","justify","kannada","katakana","katakana-iroha","keep-all","khmer","korean-hangul-formal","korean-hanja-formal","korean-hanja-informal","landscape","lao","large","larger","left","level","lighter","lighten","line-through","linear","linear-gradient","lines","list-item","listbox","listitem","local","logical","loud","lower","lower-alpha","lower-armenian","lower-greek","lower-hexadecimal","lower-latin","lower-norwegian","lower-roman","lowercase","ltr","luminosity","malayalam","manipulation","match","matrix","matrix3d","media-controls-background","media-current-time-display","media-fullscreen-button","media-mute-button","media-play-button","media-return-to-realtime-button","media-rewind-button","media-seek-back-button","media-seek-forward-button","media-slider","media-sliderthumb","media-time-remaining-display","media-volume-slider","media-volume-slider-container","media-volume-sliderthumb","medium","menu","menulist","menulist-button","menulist-text","menulist-textfield","menutext","message-box","middle","min-intrinsic","mix","mongolian","monospace","move","multiple","multiple_mask_images","multiply","myanmar","n-resize","narrower","ne-resize","nesw-resize","no-close-quote","no-drop","no-open-quote","no-repeat","none","normal","not-allowed","nowrap","ns-resize","numbers","numeric","nw-resize","nwse-resize","oblique","octal","opacity","open-quote","optimizeLegibility","optimizeSpeed","oriya","oromo","outset","outside","outside-shape","overlay","overline","padding","padding-box","painted","page","paused","persian","perspective","pinch-zoom","plus-darker","plus-lighter","pointer","polygon","portrait","pre","pre-line","pre-wrap","preserve-3d","progress","push-button","radial-gradient","radio","read-only","read-write","read-write-plaintext-only","rectangle","region","relative","repeat","repeating-linear-gradient","repeating-radial-gradient","repeat-x","repeat-y","reset","reverse","rgb","rgba","ridge","right","rotate","rotate3d","rotateX","rotateY","rotateZ","round","row","row-resize","row-reverse","rtl","run-in","running","s-resize","sans-serif","saturation","scale","scale3d","scaleX","scaleY","scaleZ","screen","scroll","scrollbar","scroll-position","se-resize","searchfield","searchfield-cancel-button","searchfield-decoration","searchfield-results-button","searchfield-results-decoration","self-start","self-end","semi-condensed","semi-expanded","separate","serif","show","sidama","simp-chinese-formal","simp-chinese-informal","single","skew","skewX","skewY","skip-white-space","slide","slider-horizontal","slider-vertical","sliderthumb-horizontal","sliderthumb-vertical","slow","small","small-caps","small-caption","smaller","soft-light","solid","somali","source-atop","source-in","source-out","source-over","space","space-around","space-between","space-evenly","spell-out","square","square-button","start","static","status-bar","stretch","stroke","stroke-box","sub","subpixel-antialiased","svg_masks","super","sw-resize","symbolic","symbols","system-ui","table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row","table-row-group","tamil","telugu","text","text-bottom","text-top","textarea","textfield","thai","thick","thin","threeddarkshadow","threedface","threedhighlight","threedlightshadow","threedshadow","tibetan","tigre","tigrinya-er","tigrinya-er-abegede","tigrinya-et","tigrinya-et-abegede","to","top","trad-chinese-formal","trad-chinese-informal","transform","translate","translate3d","translateX","translateY","translateZ","transparent","ultra-condensed","ultra-expanded","underline","unidirectional-pan","unset","up","upper-alpha","upper-armenian","upper-greek","upper-hexadecimal","upper-latin","upper-norwegian","upper-roman","uppercase","urdu","url","var","vertical","vertical-text","view-box","visible","visibleFill","visiblePainted","visibleStroke","visual","w-resize","wait","wave","wider","window","windowframe","windowtext","words","wrap","wrap-reverse","x-large","x-small","xor","xx-large","xx-small"],_=t(y),b=n.concat(i).concat(a).concat(l).concat(u).concat(h).concat(g).concat(y);function M(e,t){for(var n,r=!1;null!=(n=e.next());){if(r&&"/"==n){t.tokenize=null;break}r="*"==n}return["comment","comment"]}e.registerHelper("hintWords","css",b),e.defineMIME("text/css",{documentTypes:r,mediaTypes:o,mediaFeatures:s,mediaValueKeywords:c,propertyKeywords:d,nonStandardPropertyKeywords:p,fontProperties:f,counterDescriptors:m,colorKeywords:v,valueKeywords:_,tokenHooks:{"/":function(e,t){return!!e.eat("*")&&(t.tokenize=M,M(e,t))}},name:"css"}),e.defineMIME("text/x-scss",{mediaTypes:o,mediaFeatures:s,mediaValueKeywords:c,propertyKeywords:d,nonStandardPropertyKeywords:p,colorKeywords:v,valueKeywords:_,fontProperties:f,allowNested:!0,lineComment:"//",tokenHooks:{"/":function(e,t){return e.eat("/")?(e.skipToEnd(),["comment","comment"]):e.eat("*")?(t.tokenize=M,M(e,t)):["operator","operator"]},":":function(e){return!!e.match(/^\s*\{/,!1)&&[null,null]},$:function(e){return e.match(/^[\w-]+/),e.match(/^\s*:/,!1)?["variable-2","variable-definition"]:["variable-2","variable"]},"#":function(e){return!!e.eat("{")&&[null,"interpolation"]}},name:"css",helperType:"scss"}),e.defineMIME("text/x-less",{mediaTypes:o,mediaFeatures:s,mediaValueKeywords:c,propertyKeywords:d,nonStandardPropertyKeywords:p,colorKeywords:v,valueKeywords:_,fontProperties:f,allowNested:!0,lineComment:"//",tokenHooks:{"/":function(e,t){return e.eat("/")?(e.skipToEnd(),["comment","comment"]):e.eat("*")?(t.tokenize=M,M(e,t)):["operator","operator"]},"@":function(e){return e.eat("{")?[null,"interpolation"]:!e.match(/^(charset|document|font-face|import|(-(moz|ms|o|webkit)-)?keyframes|media|namespace|page|supports)\b/i,!1)&&(e.eatWhile(/[\w\\\-]/),e.match(/^\s*:/,!1)?["variable-2","variable-definition"]:["variable-2","variable"])},"&":function(){return["atom","atom"]}},name:"css",helperType:"less"}),e.defineMIME("text/x-gss",{documentTypes:r,mediaTypes:o,mediaFeatures:s,propertyKeywords:d,nonStandardPropertyKeywords:p,fontProperties:f,counterDescriptors:m,colorKeywords:v,valueKeywords:_,supportsAtComponent:!0,tokenHooks:{"/":function(e,t){return!!e.eat("*")&&(t.tokenize=M,M(e,t))}},name:"css",helperType:"gss"})}(n(14))},function(e,t,n){!function(e){"use strict";e.overlayMode=function(t,n,r){return{startState:function(){return{base:e.startState(t),overlay:e.startState(n),basePos:0,baseCur:null,overlayPos:0,overlayCur:null,streamSeen:null}},copyState:function(r){return{base:e.copyState(t,r.base),overlay:e.copyState(n,r.overlay),basePos:r.basePos,baseCur:null,overlayPos:r.overlayPos,overlayCur:null}},token:function(e,i){return(e!=i.streamSeen||Math.min(i.basePos,i.overlayPos)<e.start)&&(i.streamSeen=e,i.basePos=i.overlayPos=e.start),e.start==i.basePos&&(i.baseCur=t.token(e,i.base),i.basePos=e.pos),e.start==i.overlayPos&&(e.pos=e.start,i.overlayCur=n.token(e,i.overlay),i.overlayPos=e.pos),e.pos=Math.min(i.basePos,i.overlayPos),null==i.overlayCur?i.baseCur:null!=i.baseCur&&i.overlay.combineTokens||r&&null==i.overlay.combineTokens?i.baseCur+" "+i.overlayCur:i.overlayCur},indent:t.indent&&function(e,n,r){return t.indent(e.base,n,r)},electricChars:t.electricChars,innerMode:function(e){return{state:e.base,mode:t}},blankLine:function(e){var i,o;return t.blankLine&&(i=t.blankLine(e.base)),n.blankLine&&(o=n.blankLine(e.overlay)),null==o?i:r&&null!=i?i+" "+o:o}}}}(n(14))},function(e,t,n){!function(e){"use strict";function t(e,t,n,r,i,o){this.indented=e,this.column=t,this.type=n,this.info=r,this.align=i,this.prev=o}function n(e,n,r,i){var o=e.indented;return e.context&&"statement"==e.context.type&&"statement"!=r&&(o=e.context.indented),e.context=new t(o,n,r,i,null,e.context)}function r(e){var t=e.context.type;return")"!=t&&"]"!=t&&"}"!=t||(e.indented=e.context.indented),e.context=e.context.prev}function i(e,t,n){return"variable"==t.prevToken||"type"==t.prevToken||!!/\S(?:[^- ]>|[*\]])\s*$|\*$/.test(e.string.slice(0,n))||!(!t.typeAtEndOfLine||e.column()!=e.indentation())||void 0}function o(e){for(;;){if(!e||"top"==e.type)return!0;if("}"==e.type&&"namespace"!=e.prev.info)return!1;e=e.prev}}function a(e){for(var t={},n=e.split(" "),r=0;r<n.length;++r)t[n[r]]=!0;return t}function s(e,t){return"function"==typeof e?e(t):e.propertyIsEnumerable(t)}e.defineMode("clike",(function(a,l){var c,u,d=a.indentUnit,h=l.statementIndentUnit||d,p=l.dontAlignCalls,f=l.keywords||{},m=l.types||{},g=l.builtin||{},v=l.blockKeywords||{},y=l.defKeywords||{},_=l.atoms||{},b=l.hooks||{},M=l.multiLineStrings,w=!1!==l.indentStatements,A=!1!==l.indentSwitch,C=l.namespaceSeparator,x=l.isPunctuationChar||/[\[\]{}\(\),;\:\.]/,E=l.numberStart||/[\d\.]/,L=l.number||/^(?:0x[a-f\d]+|0b[01]+|(?:\d+\.?\d*|\.\d+)(?:e[-+]?\d+)?)(u|ll?|l|f)?/i,S=l.isOperatorChar||/[+\-*&%=<>!?|\/]/,T=l.isIdentifierChar||/[\w\$_\xa1-\uffff]/,O=l.isReservedIdentifier||!1;function I(e,t){var n,r=e.next();if(b[r]){var i=b[r](e,t);if(!1!==i)return i}if('"'==r||"'"==r)return t.tokenize=(n=r,function(e,t){for(var r,i=!1,o=!1;null!=(r=e.next());){if(r==n&&!i){o=!0;break}i=!i&&"\\"==r}return(o||!i&&!M)&&(t.tokenize=null),"string"}),t.tokenize(e,t);if(E.test(r)){if(e.backUp(1),e.match(L))return"number";e.next()}if(x.test(r))return c=r,null;if("/"==r){if(e.eat("*"))return t.tokenize=k,k(e,t);if(e.eat("/"))return e.skipToEnd(),"comment"}if(S.test(r)){for(;!e.match(/^\/[\/*]/,!1)&&e.eat(S););return"operator"}if(e.eatWhile(T),C)for(;e.match(C);)e.eatWhile(T);var o=e.current();return s(f,o)?(s(v,o)&&(c="newstatement"),s(y,o)&&(u=!0),"keyword"):s(m,o)?"type":s(g,o)||O&&O(o)?(s(v,o)&&(c="newstatement"),"builtin"):s(_,o)?"atom":"variable"}function k(e,t){for(var n,r=!1;n=e.next();){if("/"==n&&r){t.tokenize=null;break}r="*"==n}return"comment"}function D(e,t){l.typeFirstDefinitions&&e.eol()&&o(t.context)&&(t.typeAtEndOfLine=i(e,t,e.pos))}return{startState:function(e){return{tokenize:null,context:new t((e||0)-d,0,"top",null,!1),indented:0,startOfLine:!0,prevToken:null}},token:function(e,t){var a=t.context;if(e.sol()&&(null==a.align&&(a.align=!1),t.indented=e.indentation(),t.startOfLine=!0),e.eatSpace())return D(e,t),null;c=u=null;var s=(t.tokenize||I)(e,t);if("comment"==s||"meta"==s)return s;if(null==a.align&&(a.align=!0),";"==c||":"==c||","==c&&e.match(/^\s*(?:\/\/.*)?$/,!1))for(;"statement"==t.context.type;)r(t);else if("{"==c)n(t,e.column(),"}");else if("["==c)n(t,e.column(),"]");else if("("==c)n(t,e.column(),")");else if("}"==c){for(;"statement"==a.type;)a=r(t);for("}"==a.type&&(a=r(t));"statement"==a.type;)a=r(t)}else c==a.type?r(t):w&&(("}"==a.type||"top"==a.type)&&";"!=c||"statement"==a.type&&"newstatement"==c)&&n(t,e.column(),"statement",e.current());if("variable"==s&&("def"==t.prevToken||l.typeFirstDefinitions&&i(e,t,e.start)&&o(t.context)&&e.match(/^\s*\(/,!1))&&(s="def"),b.token){var d=b.token(e,t,s);void 0!==d&&(s=d)}return"def"==s&&!1===l.styleDefs&&(s="variable"),t.startOfLine=!1,t.prevToken=u?"def":s||c,D(e,t),s},indent:function(t,n){if(t.tokenize!=I&&null!=t.tokenize||t.typeAtEndOfLine)return e.Pass;var r=t.context,i=n&&n.charAt(0),o=i==r.type;if("statement"==r.type&&"}"==i&&(r=r.prev),l.dontIndentStatements)for(;"statement"==r.type&&l.dontIndentStatements.test(r.info);)r=r.prev;if(b.indent){var a=b.indent(t,r,n,d);if("number"==typeof a)return a}var s=r.prev&&"switch"==r.prev.info;if(l.allmanIndentation&&/[{(]/.test(i)){for(;"top"!=r.type&&"}"!=r.type;)r=r.prev;return r.indented}return"statement"==r.type?r.indented+("{"==i?0:h):!r.align||p&&")"==r.type?")"!=r.type||o?r.indented+(o?0:d)+(o||!s||/^(?:case|default)\b/.test(n)?0:d):r.indented+h:r.column+(o?0:1)},electricInput:A?/^\s*(?:case .*?:|default:|\{\}?|\})$/:/^\s*[{}]$/,blockCommentStart:"/*",blockCommentEnd:"*/",blockCommentContinue:" * ",lineComment:"//",fold:"brace"}}));var l="auto if break case register continue return default do sizeof static else struct switch extern typedef union for goto while enum const volatile inline restrict asm fortran",c="alignas alignof and and_eq audit axiom bitand bitor catch class compl concept constexpr const_cast decltype delete dynamic_cast explicit export final friend import module mutable namespace new noexcept not not_eq operator or or_eq override private protected public reinterpret_cast requires static_assert static_cast template this thread_local throw try typeid typename using virtual xor xor_eq",u="bycopy byref in inout oneway out self super atomic nonatomic retain copy readwrite readonly strong weak assign typeof nullable nonnull null_resettable _cmd @interface @implementation @end @protocol @encode @property @synthesize @dynamic @class @public @package @private @protected @required @optional @try @catch @finally @import @selector @encode @defs @synchronized @autoreleasepool @compatibility_alias @available",d="FOUNDATION_EXPORT FOUNDATION_EXTERN NS_INLINE NS_FORMAT_FUNCTION  NS_RETURNS_RETAINEDNS_ERROR_ENUM NS_RETURNS_NOT_RETAINED NS_RETURNS_INNER_POINTER NS_DESIGNATED_INITIALIZER NS_ENUM NS_OPTIONS NS_REQUIRES_NIL_TERMINATION NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_SWIFT_NAME NS_REFINED_FOR_SWIFT",h=a("int long char short double float unsigned signed void bool"),p=a("SEL instancetype id Class Protocol BOOL");function f(e){return s(h,e)||/.+_t$/.test(e)}function m(e){return f(e)||s(p,e)}var g="case do else for if switch while struct enum union";function v(e,t){if(!t.startOfLine)return!1;for(var n,r=null;n=e.peek();){if("\\"==n&&e.match(/^.$/)){r=v;break}if("/"==n&&e.match(/^\/[\/\*]/,!1))break;e.next()}return t.tokenize=r,"meta"}function y(e,t){return"type"==t.prevToken&&"type"}function _(e){return!(!e||e.length<2||"_"!=e[0]||"_"!=e[1]&&e[1]===e[1].toLowerCase())}function b(e){return e.eatWhile(/[\w\.']/),"number"}function M(e,t){if(e.backUp(1),e.match(/^(?:R|u8R|uR|UR|LR)/)){var n=e.match(/^"([^\s\\()]{0,16})\(/);return!!n&&(t.cpp11RawStringDelim=n[1],t.tokenize=C,C(e,t))}return e.match(/^(?:u8|u|U|L)/)?!!e.match(/^["']/,!1)&&"string":(e.next(),!1)}function w(e){var t=/(\w+)::~?(\w+)$/.exec(e);return t&&t[1]==t[2]}function A(e,t){for(var n;null!=(n=e.next());)if('"'==n&&!e.eat('"')){t.tokenize=null;break}return"string"}function C(e,t){var n=t.cpp11RawStringDelim.replace(/[^\w\s]/g,"\\$&");return e.match(new RegExp(".*?\\)"+n+'"'))?t.tokenize=null:e.skipToEnd(),"string"}function x(t,n){"string"==typeof t&&(t=[t]);var r=[];function i(e){if(e)for(var t in e)e.hasOwnProperty(t)&&r.push(t)}i(n.keywords),i(n.types),i(n.builtin),i(n.atoms),r.length&&(n.helperType=t[0],e.registerHelper("hintWords",t[0],r));for(var o=0;o<t.length;++o)e.defineMIME(t[o],n)}function E(e,t){for(var n=!1;!e.eol();){if(!n&&e.match('"""')){t.tokenize=null;break}n="\\"==e.next()&&!n}return"string"}function L(e){return function(t,n){for(var r;r=t.next();){if("*"==r&&t.eat("/")){if(1==e){n.tokenize=null;break}return n.tokenize=L(e-1),n.tokenize(t,n)}if("/"==r&&t.eat("*"))return n.tokenize=L(e+1),n.tokenize(t,n)}return"comment"}}x(["text/x-csrc","text/x-c","text/x-chdr"],{name:"clike",keywords:a(l),types:f,blockKeywords:a(g),defKeywords:a("struct enum union"),typeFirstDefinitions:!0,atoms:a("NULL true false"),isReservedIdentifier:_,hooks:{"#":v,"*":y},modeProps:{fold:["brace","include"]}}),x(["text/x-c++src","text/x-c++hdr"],{name:"clike",keywords:a(l+" "+c),types:f,blockKeywords:a(g+" class try catch"),defKeywords:a("struct enum union class namespace"),typeFirstDefinitions:!0,atoms:a("true false NULL nullptr"),dontIndentStatements:/^template$/,isIdentifierChar:/[\w\$_~\xa1-\uffff]/,isReservedIdentifier:_,hooks:{"#":v,"*":y,u:M,U:M,L:M,R:M,0:b,1:b,2:b,3:b,4:b,5:b,6:b,7:b,8:b,9:b,token:function(e,t,n){if("variable"==n&&"("==e.peek()&&(";"==t.prevToken||null==t.prevToken||"}"==t.prevToken)&&w(e.current()))return"def"}},namespaceSeparator:"::",modeProps:{fold:["brace","include"]}}),x("text/x-java",{name:"clike",keywords:a("abstract assert break case catch class const continue default do else enum extends final finally for goto if implements import instanceof interface native new package private protected public return static strictfp super switch synchronized this throw throws transient try volatile while @interface"),types:a("byte short int long float double boolean char void Boolean Byte Character Double Float Integer Long Number Object Short String StringBuffer StringBuilder Void"),blockKeywords:a("catch class do else finally for if switch try while"),defKeywords:a("class interface enum @interface"),typeFirstDefinitions:!0,atoms:a("true false null"),number:/^(?:0x[a-f\d_]+|0b[01_]+|(?:[\d_]+\.?\d*|\.\d+)(?:e[-+]?[\d_]+)?)(u|ll?|l|f)?/i,hooks:{"@":function(e){return!e.match("interface",!1)&&(e.eatWhile(/[\w\$_]/),"meta")}},modeProps:{fold:["brace","import"]}}),x("text/x-csharp",{name:"clike",keywords:a("abstract as async await base break case catch checked class const continue default delegate do else enum event explicit extern finally fixed for foreach goto if implicit in interface internal is lock namespace new operator out override params private protected public readonly ref return sealed sizeof stackalloc static struct switch this throw try typeof unchecked unsafe using virtual void volatile while add alias ascending descending dynamic from get global group into join let orderby partial remove select set value var yield"),types:a("Action Boolean Byte Char DateTime DateTimeOffset Decimal Double Func Guid Int16 Int32 Int64 Object SByte Single String Task TimeSpan UInt16 UInt32 UInt64 bool byte char decimal double short int long object sbyte float string ushort uint ulong"),blockKeywords:a("catch class do else finally for foreach if struct switch try while"),defKeywords:a("class interface namespace struct var"),typeFirstDefinitions:!0,atoms:a("true false null"),hooks:{"@":function(e,t){return e.eat('"')?(t.tokenize=A,A(e,t)):(e.eatWhile(/[\w\$_]/),"meta")}}}),x("text/x-scala",{name:"clike",keywords:a("abstract case catch class def do else extends final finally for forSome if implicit import lazy match new null object override package private protected return sealed super this throw trait try type val var while with yield _ assert assume require print println printf readLine readBoolean readByte readShort readChar readInt readLong readFloat readDouble"),types:a("AnyVal App Application Array BufferedIterator BigDecimal BigInt Char Console Either Enumeration Equiv Error Exception Fractional Function IndexedSeq Int Integral Iterable Iterator List Map Numeric Nil NotNull Option Ordered Ordering PartialFunction PartialOrdering Product Proxy Range Responder Seq Serializable Set Specializable Stream StringBuilder StringContext Symbol Throwable Traversable TraversableOnce Tuple Unit Vector Boolean Byte Character CharSequence Class ClassLoader Cloneable Comparable Compiler Double Exception Float Integer Long Math Number Object Package Pair Process Runtime Runnable SecurityManager Short StackTraceElement StrictMath String StringBuffer System Thread ThreadGroup ThreadLocal Throwable Triple Void"),multiLineStrings:!0,blockKeywords:a("catch class enum do else finally for forSome if match switch try while"),defKeywords:a("class enum def object package trait type val var"),atoms:a("true false null"),indentStatements:!1,indentSwitch:!1,isOperatorChar:/[+\-*&%=<>!?|\/#:@]/,hooks:{"@":function(e){return e.eatWhile(/[\w\$_]/),"meta"},'"':function(e,t){return!!e.match('""')&&(t.tokenize=E,t.tokenize(e,t))},"'":function(e){return e.eatWhile(/[\w\$_\xa1-\uffff]/),"atom"},"=":function(e,n){var r=n.context;return!("}"!=r.type||!r.align||!e.eat(">"))&&(n.context=new t(r.indented,r.column,r.type,r.info,null,r.prev),"operator")},"/":function(e,t){return!!e.eat("*")&&(t.tokenize=L(1),t.tokenize(e,t))}},modeProps:{closeBrackets:{pairs:'()[]{}""',triples:'"'}}}),x("text/x-kotlin",{name:"clike",keywords:a("package as typealias class interface this super val operator var fun for is in This throw return annotation break continue object if else while do try when !in !is as? file import where by get set abstract enum open inner override private public internal protected catch finally out final vararg reified dynamic companion constructor init sealed field property receiver param sparam lateinit data inline noinline tailrec external annotation crossinline const operator infix suspend actual expect setparam value"),types:a("Boolean Byte Character CharSequence Class ClassLoader Cloneable Comparable Compiler Double Exception Float Integer Long Math Number Object Package Pair Process Runtime Runnable SecurityManager Short StackTraceElement StrictMath String StringBuffer System Thread ThreadGroup ThreadLocal Throwable Triple Void Annotation Any BooleanArray ByteArray Char CharArray DeprecationLevel DoubleArray Enum FloatArray Function Int IntArray Lazy LazyThreadSafetyMode LongArray Nothing ShortArray Unit"),intendSwitch:!1,indentStatements:!1,multiLineStrings:!0,number:/^(?:0x[a-f\d_]+|0b[01_]+|(?:[\d_]+(\.\d+)?|\.\d+)(?:e[-+]?[\d_]+)?)(u|ll?|l|f)?/i,blockKeywords:a("catch class do else finally for if where try while enum"),defKeywords:a("class val var object interface fun"),atoms:a("true false null this"),hooks:{"@":function(e){return e.eatWhile(/[\w\$_]/),"meta"},"*":function(e,t){return"."==t.prevToken?"variable":"operator"},'"':function(e,t){var n;return t.tokenize=(n=e.match('""'),function(e,t){for(var r,i=!1,o=!1;!e.eol();){if(!n&&!i&&e.match('"')){o=!0;break}if(n&&e.match('"""')){o=!0;break}r=e.next(),!i&&"$"==r&&e.match("{")&&e.skipTo("}"),i=!i&&"\\"==r&&!n}return!o&&n||(t.tokenize=null),"string"}),t.tokenize(e,t)},"/":function(e,t){return!!e.eat("*")&&(t.tokenize=L(1),t.tokenize(e,t))},indent:function(e,t,n,r){var i=n&&n.charAt(0);return"}"!=e.prevToken&&")"!=e.prevToken||""!=n?"operator"==e.prevToken&&"}"!=n&&"}"!=e.context.type||"variable"==e.prevToken&&"."==i||("}"==e.prevToken||")"==e.prevToken)&&"."==i?2*r+t.indented:t.align&&"}"==t.type?t.indented+(e.context.type==(n||"").charAt(0)?0:r):void 0:e.indented}},modeProps:{closeBrackets:{triples:'"'}}}),x(["x-shader/x-vertex","x-shader/x-fragment"],{name:"clike",keywords:a("sampler1D sampler2D sampler3D samplerCube sampler1DShadow sampler2DShadow const attribute uniform varying break continue discard return for while do if else struct in out inout"),types:a("float int bool void vec2 vec3 vec4 ivec2 ivec3 ivec4 bvec2 bvec3 bvec4 mat2 mat3 mat4"),blockKeywords:a("for while do if else struct"),builtin:a("radians degrees sin cos tan asin acos atan pow exp log exp2 sqrt inversesqrt abs sign floor ceil fract mod min max clamp mix step smoothstep length distance dot cross normalize ftransform faceforward reflect refract matrixCompMult lessThan lessThanEqual greaterThan greaterThanEqual equal notEqual any all not texture1D texture1DProj texture1DLod texture1DProjLod texture2D texture2DProj texture2DLod texture2DProjLod texture3D texture3DProj texture3DLod texture3DProjLod textureCube textureCubeLod shadow1D shadow2D shadow1DProj shadow2DProj shadow1DLod shadow2DLod shadow1DProjLod shadow2DProjLod dFdx dFdy fwidth noise1 noise2 noise3 noise4"),atoms:a("true false gl_FragColor gl_SecondaryColor gl_Normal gl_Vertex gl_MultiTexCoord0 gl_MultiTexCoord1 gl_MultiTexCoord2 gl_MultiTexCoord3 gl_MultiTexCoord4 gl_MultiTexCoord5 gl_MultiTexCoord6 gl_MultiTexCoord7 gl_FogCoord gl_PointCoord gl_Position gl_PointSize gl_ClipVertex gl_FrontColor gl_BackColor gl_FrontSecondaryColor gl_BackSecondaryColor gl_TexCoord gl_FogFragCoord gl_FragCoord gl_FrontFacing gl_FragData gl_FragDepth gl_ModelViewMatrix gl_ProjectionMatrix gl_ModelViewProjectionMatrix gl_TextureMatrix gl_NormalMatrix gl_ModelViewMatrixInverse gl_ProjectionMatrixInverse gl_ModelViewProjectionMatrixInverse gl_TextureMatrixTranspose gl_ModelViewMatrixInverseTranspose gl_ProjectionMatrixInverseTranspose gl_ModelViewProjectionMatrixInverseTranspose gl_TextureMatrixInverseTranspose gl_NormalScale gl_DepthRange gl_ClipPlane gl_Point gl_FrontMaterial gl_BackMaterial gl_LightSource gl_LightModel gl_FrontLightModelProduct gl_BackLightModelProduct gl_TextureColor gl_EyePlaneS gl_EyePlaneT gl_EyePlaneR gl_EyePlaneQ gl_FogParameters gl_MaxLights gl_MaxClipPlanes gl_MaxTextureUnits gl_MaxTextureCoords gl_MaxVertexAttribs gl_MaxVertexUniformComponents gl_MaxVaryingFloats gl_MaxVertexTextureImageUnits gl_MaxTextureImageUnits gl_MaxFragmentUniformComponents gl_MaxCombineTextureImageUnits gl_MaxDrawBuffers"),indentSwitch:!1,hooks:{"#":v},modeProps:{fold:["brace","include"]}}),x("text/x-nesc",{name:"clike",keywords:a(l+" as atomic async call command component components configuration event generic implementation includes interface module new norace nx_struct nx_union post provides signal task uses abstract extends"),types:f,blockKeywords:a(g),atoms:a("null true false"),hooks:{"#":v},modeProps:{fold:["brace","include"]}}),x("text/x-objectivec",{name:"clike",keywords:a(l+" "+u),types:m,builtin:a(d),blockKeywords:a(g+" @synthesize @try @catch @finally @autoreleasepool @synchronized"),defKeywords:a("struct enum union @interface @implementation @protocol @class"),dontIndentStatements:/^@.*$/,typeFirstDefinitions:!0,atoms:a("YES NO NULL Nil nil true false nullptr"),isReservedIdentifier:_,hooks:{"#":v,"*":y},modeProps:{fold:["brace","include"]}}),x("text/x-objectivec++",{name:"clike",keywords:a(l+" "+u+" "+c),types:m,builtin:a(d),blockKeywords:a(g+" @synthesize @try @catch @finally @autoreleasepool @synchronized class try catch"),defKeywords:a("struct enum union @interface @implementation @protocol @class class namespace"),dontIndentStatements:/^@.*$|^template$/,typeFirstDefinitions:!0,atoms:a("YES NO NULL Nil nil true false nullptr"),isReservedIdentifier:_,hooks:{"#":v,"*":y,u:M,U:M,L:M,R:M,0:b,1:b,2:b,3:b,4:b,5:b,6:b,7:b,8:b,9:b,token:function(e,t,n){if("variable"==n&&"("==e.peek()&&(";"==t.prevToken||null==t.prevToken||"}"==t.prevToken)&&w(e.current()))return"def"}},namespaceSeparator:"::",modeProps:{fold:["brace","include"]}}),x("text/x-squirrel",{name:"clike",keywords:a("base break clone continue const default delete enum extends function in class foreach local resume return this throw typeof yield constructor instanceof static"),types:f,blockKeywords:a("case catch class else for foreach if switch try while"),defKeywords:a("function local class"),typeFirstDefinitions:!0,atoms:a("true false null"),hooks:{"#":v},modeProps:{fold:["brace","include"]}});var S=null;x("text/x-ceylon",{name:"clike",keywords:a("abstracts alias assembly assert assign break case catch class continue dynamic else exists extends finally for function given if import in interface is let module new nonempty object of out outer package return satisfies super switch then this throw try value void while"),types:function(e){var t=e.charAt(0);return t===t.toUpperCase()&&t!==t.toLowerCase()},blockKeywords:a("case catch class dynamic else finally for function if interface module new object switch try while"),defKeywords:a("class dynamic function interface module object package value"),builtin:a("abstract actual aliased annotation by default deprecated doc final formal late license native optional sealed see serializable shared suppressWarnings tagged throws variable"),isPunctuationChar:/[\[\]{}\(\),;\:\.`]/,isOperatorChar:/[+\-*&%=<>!?|^~:\/]/,numberStart:/[\d#$]/,number:/^(?:#[\da-fA-F_]+|\$[01_]+|[\d_]+[kMGTPmunpf]?|[\d_]+\.[\d_]+(?:[eE][-+]?\d+|[kMGTPmunpf]|)|)/i,multiLineStrings:!0,typeFirstDefinitions:!0,atoms:a("true false null larger smaller equal empty finished"),indentSwitch:!1,styleDefs:!1,hooks:{"@":function(e){return e.eatWhile(/[\w\$_]/),"meta"},'"':function(e,t){return t.tokenize=function e(t){return function(n,r){for(var i,o=!1,a=!1;!n.eol();){if(!o&&n.match('"')&&("single"==t||n.match('""'))){a=!0;break}if(!o&&n.match("``")){S=e(t),a=!0;break}i=n.next(),o="single"==t&&!o&&"\\"==i}return a&&(r.tokenize=null),"string"}}(e.match('""')?"triple":"single"),t.tokenize(e,t)},"`":function(e,t){return!(!S||!e.match("`"))&&(t.tokenize=S,S=null,t.tokenize(e,t))},"'":function(e){return e.eatWhile(/[\w\$_\xa1-\uffff]/),"atom"},token:function(e,t,n){if(("variable"==n||"type"==n)&&"."==t.prevToken)return"variable-2"}},modeProps:{fold:["brace","import"],closeBrackets:{triples:'"'}}})}(n(14))},function(e,t,n){!function(e){"use strict";e.multiplexingMode=function(t){var n=Array.prototype.slice.call(arguments,1);function r(e,t,n,r){if("string"==typeof t){var i=e.indexOf(t,n);return r&&i>-1?i+t.length:i}var o=t.exec(n?e.slice(n):e);return o?o.index+n+(r?o[0].length:0):-1}return{startState:function(){return{outer:e.startState(t),innerActive:null,inner:null,startingInner:!1}},copyState:function(n){return{outer:e.copyState(t,n.outer),innerActive:n.innerActive,inner:n.innerActive&&e.copyState(n.innerActive.mode,n.inner),startingInner:n.startingInner}},token:function(i,o){if(o.innerActive){var a=o.innerActive;if(c=i.string,!a.close&&i.sol())return o.innerActive=o.inner=null,this.token(i,o);if((d=a.close&&!o.startingInner?r(c,a.close,i.pos,a.parseDelimiters):-1)==i.pos&&!a.parseDelimiters)return i.match(a.close),o.innerActive=o.inner=null,a.delimStyle&&a.delimStyle+" "+a.delimStyle+"-close";d>-1&&(i.string=c.slice(0,d));var s=a.mode.token(i,o.inner);return d>-1?i.string=c:i.pos>i.start&&(o.startingInner=!1),d==i.pos&&a.parseDelimiters&&(o.innerActive=o.inner=null),a.innerStyle&&(s=s?s+" "+a.innerStyle:a.innerStyle),s}for(var l=1/0,c=i.string,u=0;u<n.length;++u){var d,h=n[u];if((d=r(c,h.open,i.pos))==i.pos){h.parseDelimiters||i.match(h.open),o.startingInner=!!h.parseDelimiters,o.innerActive=h;var p=0;if(t.indent){var f=t.indent(o.outer,"","");f!==e.Pass&&(p=f)}return o.inner=e.startState(h.mode,p),h.delimStyle&&h.delimStyle+" "+h.delimStyle+"-open"}-1!=d&&d<l&&(l=d)}l!=1/0&&(i.string=c.slice(0,l));var m=t.token(i,o.outer);return l!=1/0&&(i.string=c),m},indent:function(n,r,i){var o=n.innerActive?n.innerActive.mode:t;return o.indent?o.indent(n.innerActive?n.inner:n.outer,r,i):e.Pass},blankLine:function(r){var i=r.innerActive?r.innerActive.mode:t;if(i.blankLine&&i.blankLine(r.innerActive?r.inner:r.outer),r.innerActive)"\n"===r.innerActive.close&&(r.innerActive=r.inner=null);else for(var o=0;o<n.length;++o){var a=n[o];"\n"===a.open&&(r.innerActive=a,r.inner=e.startState(a.mode,i.indent?i.indent(r.outer,"",""):0))}},electricChars:t.electricChars,innerMode:function(e){return e.inner?{state:e.inner,mode:e.innerActive.mode}:{state:e.outer,mode:t}}}}}(n(14))},function(e,t,n){!function(e){"use strict";function t(e){return new RegExp("^(("+e.join(")|(")+"))\\b")}var n,r=t(["and","or","not","is"]),i=["as","assert","break","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","lambda","pass","raise","return","try","while","with","yield","in"],o=["abs","all","any","bin","bool","bytearray","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip","__import__","NotImplemented","Ellipsis","__debug__"];function a(e){return e.scopes[e.scopes.length-1]}e.registerHelper("hintWords","python",i.concat(o)),e.defineMode("python",(function(n,s){for(var l=s.delimiters||s.singleDelimiters||/^[\(\)\[\]\{\}@,:`=;\.\\]/,c=[s.singleOperators,s.doubleOperators,s.doubleDelimiters,s.tripleDelimiters,s.operators||/^([-+*/%\/&|^]=?|[<>=]+|\/\/=?|\*\*=?|!=|[~!@]|\.\.\.)/],u=0;u<c.length;u++)c[u]||c.splice(u--,1);var d=s.hangingIndent||n.indentUnit,h=i,p=o;null!=s.extra_keywords&&(h=h.concat(s.extra_keywords)),null!=s.extra_builtins&&(p=p.concat(s.extra_builtins));var f=!(s.version&&Number(s.version)<3);if(f){var m=s.identifiers||/^[_A-Za-z\u00A1-\uFFFF][_A-Za-z0-9\u00A1-\uFFFF]*/;h=h.concat(["nonlocal","False","True","None","async","await"]),p=p.concat(["ascii","bytes","exec","print"]);var g=new RegExp("^(([rbuf]|(br)|(fr))?('{3}|\"{3}|['\"]))","i")}else m=s.identifiers||/^[_A-Za-z][_A-Za-z0-9]*/,h=h.concat(["exec","print"]),p=p.concat(["apply","basestring","buffer","cmp","coerce","execfile","file","intern","long","raw_input","reduce","reload","unichr","unicode","xrange","False","True","None"]),g=new RegExp("^(([rubf]|(ur)|(br))?('{3}|\"{3}|['\"]))","i");var v=t(h),y=t(p);function _(e,t){var n=e.sol()&&"\\"!=t.lastToken;if(n&&(t.indent=e.indentation()),n&&"py"==a(t).type){var r=a(t).offset;if(e.eatSpace()){var i=e.indentation();return i>r?M(t):i<r&&w(e,t)&&"#"!=e.peek()&&(t.errorToken=!0),null}var o=b(e,t);return r>0&&w(e,t)&&(o+=" error"),o}return b(e,t)}function b(e,t,n){if(e.eatSpace())return null;if(!n&&e.match(/^#.*/))return"comment";if(e.match(/^[0-9\.]/,!1)){var i=!1;if(e.match(/^[\d_]*\.\d+(e[\+\-]?\d+)?/i)&&(i=!0),e.match(/^[\d_]+\.\d*/)&&(i=!0),e.match(/^\.\d+/)&&(i=!0),i)return e.eat(/J/i),"number";var o=!1;if(e.match(/^0x[0-9a-f_]+/i)&&(o=!0),e.match(/^0b[01_]+/i)&&(o=!0),e.match(/^0o[0-7_]+/i)&&(o=!0),e.match(/^[1-9][\d_]*(e[\+\-]?[\d_]+)?/)&&(e.eat(/J/i),o=!0),e.match(/^0(?![\dx])/i)&&(o=!0),o)return e.eat(/L/i),"number"}if(e.match(g))return-1!==e.current().toLowerCase().indexOf("f")?(t.tokenize=function(e,t){for(;"rubf".indexOf(e.charAt(0).toLowerCase())>=0;)e=e.substr(1);var n=1==e.length;function r(e){return function(t,n){var o=b(t,n,!0);return"punctuation"==o&&("{"==t.current()?n.tokenize=r(e+1):"}"==t.current()&&(n.tokenize=e>1?r(e-1):i)),o}}function i(i,o){for(;!i.eol();)if(i.eatWhile(/[^'"\{\}\\]/),i.eat("\\")){if(i.next(),n&&i.eol())return"string"}else{if(i.match(e))return o.tokenize=t,"string";if(i.match("{{"))return"string";if(i.match("{",!1))return o.tokenize=r(0),i.current()?"string":o.tokenize(i,o);if(i.match("}}"))return"string";if(i.match("}"))return"error";i.eat(/['"]/)}if(n){if(s.singleLineStringErrors)return"error";o.tokenize=t}return"string"}return i.isString=!0,i}(e.current(),t.tokenize),t.tokenize(e,t)):(t.tokenize=function(e,t){for(;"rubf".indexOf(e.charAt(0).toLowerCase())>=0;)e=e.substr(1);var n=1==e.length;function r(r,i){for(;!r.eol();)if(r.eatWhile(/[^'"\\]/),r.eat("\\")){if(r.next(),n&&r.eol())return"string"}else{if(r.match(e))return i.tokenize=t,"string";r.eat(/['"]/)}if(n){if(s.singleLineStringErrors)return"error";i.tokenize=t}return"string"}return r.isString=!0,r}(e.current(),t.tokenize),t.tokenize(e,t));for(var a=0;a<c.length;a++)if(e.match(c[a]))return"operator";return e.match(l)?"punctuation":"."==t.lastToken&&e.match(m)?"property":e.match(v)||e.match(r)?"keyword":e.match(y)?"builtin":e.match(/^(self|cls)\b/)?"variable-2":e.match(m)?"def"==t.lastToken||"class"==t.lastToken?"def":"variable":(e.next(),n?null:"error")}function M(e){for(;"py"!=a(e).type;)e.scopes.pop();e.scopes.push({offset:a(e).offset+n.indentUnit,type:"py",align:null})}function w(e,t){for(var n=e.indentation();t.scopes.length>1&&a(t).offset>n;){if("py"!=a(t).type)return!0;t.scopes.pop()}return a(t).offset!=n}function A(e,t){e.sol()&&(t.beginningOfLine=!0);var n=t.tokenize(e,t),r=e.current();if(t.beginningOfLine&&"@"==r)return e.match(m,!1)?"meta":f?"operator":"error";if(/\S/.test(r)&&(t.beginningOfLine=!1),"variable"!=n&&"builtin"!=n||"meta"!=t.lastToken||(n="meta"),"pass"!=r&&"return"!=r||(t.dedent+=1),"lambda"==r&&(t.lambda=!0),":"==r&&!t.lambda&&"py"==a(t).type&&e.match(/^\s*(?:#|$)/,!1)&&M(t),1==r.length&&!/string|comment/.test(n)){var i="[({".indexOf(r);if(-1!=i&&function(e,t,n){var r=e.match(/^[\s\[\{\(]*(?:#|$)/,!1)?null:e.column()+1;t.scopes.push({offset:t.indent+d,type:n,align:r})}(e,t,"])}".slice(i,i+1)),-1!=(i="])}".indexOf(r))){if(a(t).type!=r)return"error";t.indent=t.scopes.pop().offset-d}}return t.dedent>0&&e.eol()&&"py"==a(t).type&&(t.scopes.length>1&&t.scopes.pop(),t.dedent-=1),n}return{startState:function(e){return{tokenize:_,scopes:[{offset:e||0,type:"py",align:null}],indent:e||0,lastToken:null,lambda:!1,dedent:0}},token:function(e,t){var n=t.errorToken;n&&(t.errorToken=!1);var r=A(e,t);return r&&"comment"!=r&&(t.lastToken="keyword"==r||"punctuation"==r?e.current():r),"punctuation"==r&&(r=null),e.eol()&&t.lambda&&(t.lambda=!1),n?r+" error":r},indent:function(t,n){if(t.tokenize!=_)return t.tokenize.isString?e.Pass:0;var r=a(t),i=r.type==n.charAt(0);return null!=r.align?r.align-(i?1:0):r.offset-(i?d:0)},electricInput:/^\s*[\}\]\)]$/,closeBrackets:{triples:"'\""},lineComment:"#",fold:"indent"}})),e.defineMIME("text/x-python","python"),e.defineMIME("text/x-cython",{name:"python",extra_keywords:(n="by cdef cimport cpdef ctypedef enum except extern gil include nogil property public readonly struct union DEF IF ELIF ELSE",n.split(" "))})}(n(14))},function(e,t,n){!function(e){"use strict";e.defineMode("stex",(function(e,t){function n(e,t){e.cmdState.push(t)}function r(e){return e.cmdState.length>0?e.cmdState[e.cmdState.length-1]:null}function i(e,t,n){return function(){this.name=e,this.bracketNo=0,this.style=t,this.styles=n,this.argument=null,this.styleIdentifier=function(){return this.styles[this.bracketNo-1]||null},this.openBracket=function(){return this.bracketNo++,"bracket"},this.closeBracket=function(){}}}var o={};function a(e,t){e.f=t}function s(e,t){var i;if(e.match(/^\\[a-zA-Z@]+/)){var s=e.current().slice(1);return n(t,i=new(i=o.hasOwnProperty(s)?o[s]:o.DEFAULT)),a(t,c),i.style}if(e.match(/^\\[$&%#{}_]/))return"tag";if(e.match(/^\\[,;!\/\\]/))return"tag";if(e.match("\\["))return a(t,(function(e,t){return l(e,t,"\\]")})),"keyword";if(e.match("\\("))return a(t,(function(e,t){return l(e,t,"\\)")})),"keyword";if(e.match("$$"))return a(t,(function(e,t){return l(e,t,"$$")})),"keyword";if(e.match("$"))return a(t,(function(e,t){return l(e,t,"$")})),"keyword";var u=e.next();return"%"==u?(e.skipToEnd(),"comment"):"}"==u||"]"==u?(i=r(t))?(i.closeBracket(u),a(t,c),"bracket"):"error":"{"==u||"["==u?(n(t,i=new(i=o.DEFAULT)),"bracket"):/\d/.test(u)?(e.eatWhile(/[\w.%]/),"atom"):(e.eatWhile(/[\w\-_]/),"begin"==(i=function(e){for(var t=e.cmdState,n=t.length-1;n>=0;n--){var r=t[n];if("DEFAULT"!=r.name)return r}return{styleIdentifier:function(){return null}}}(t)).name&&(i.argument=e.current()),i.styleIdentifier())}function l(e,t,n){if(e.eatSpace())return null;if(n&&e.match(n))return a(t,s),"keyword";if(e.match(/^\\[a-zA-Z@]+/))return"tag";if(e.match(/^[a-zA-Z]+/))return"variable-2";if(e.match(/^\\[$&%#{}_]/))return"tag";if(e.match(/^\\[,;!\/]/))return"tag";if(e.match(/^[\^_&]/))return"tag";if(e.match(/^[+\-<>|=,\/@!*:;'"`~#?]/))return null;if(e.match(/^(\d+\.\d*|\d*\.\d+|\d+)/))return"number";var r=e.next();return"{"==r||"}"==r||"["==r||"]"==r||"("==r||")"==r?"bracket":"%"==r?(e.skipToEnd(),"comment"):"error"}function c(e,t){var n=e.peek();return"{"==n||"["==n?(r(t).openBracket(n),e.eat(n),a(t,s),"bracket"):/[ \t\r]/.test(n)?(e.eat(n),null):(a(t,s),function(e){var t=e.cmdState.pop();t&&t.closeBracket()}(t),s(e,t))}return o.importmodule=i("importmodule","tag",["string","builtin"]),o.documentclass=i("documentclass","tag",["","atom"]),o.usepackage=i("usepackage","tag",["atom"]),o.begin=i("begin","tag",["atom"]),o.end=i("end","tag",["atom"]),o.label=i("label","tag",["atom"]),o.ref=i("ref","tag",["atom"]),o.eqref=i("eqref","tag",["atom"]),o.cite=i("cite","tag",["atom"]),o.bibitem=i("bibitem","tag",["atom"]),o.Bibitem=i("Bibitem","tag",["atom"]),o.RBibitem=i("RBibitem","tag",["atom"]),o.DEFAULT=function(){this.name="DEFAULT",this.style="tag",this.styleIdentifier=this.openBracket=this.closeBracket=function(){}},{startState:function(){return{cmdState:[],f:t.inMathMode?function(e,t){return l(e,t)}:s}},copyState:function(e){return{cmdState:e.cmdState.slice(),f:e.f}},token:function(e,t){return t.f(e,t)},blankLine:function(e){e.f=s,e.cmdState.length=0},lineComment:"%"}})),e.defineMIME("text/x-stex","stex"),e.defineMIME("text/x-latex","stex")}(n(14))},function(e,t,n){!function(e){"use strict";function t(e,t,n,r){this.state=e,this.mode=t,this.depth=n,this.prev=r}function n(r){return new t(e.copyState(r.mode,r.state),r.mode,r.depth,r.prev&&n(r.prev))}e.defineMode("jsx",(function(r,i){var o=e.getMode(r,{name:"xml",allowMissing:!0,multilineTagIndentPastTag:!1,allowMissingTagName:!0}),a=e.getMode(r,i&&i.base||"javascript");function s(e){var t=e.tagName;e.tagName=null;var n=o.indent(e,"","");return e.tagName=t,n}function l(n,i){return i.context.mode==o?function(n,i,c){if(2==c.depth)return n.match(/^.*?\*\//)?c.depth=1:n.skipToEnd(),"comment";if("{"==n.peek()){o.skipAttribute(c.state);var u=s(c.state),d=c.state.context;if(d&&n.match(/^[^>]*>\s*$/,!1)){for(;d.prev&&!d.startOfLine;)d=d.prev;d.startOfLine?u-=r.indentUnit:c.prev.state.lexical&&(u=c.prev.state.lexical.indented)}else 1==c.depth&&(u+=r.indentUnit);return i.context=new t(e.startState(a,u),a,0,i.context),null}if(1==c.depth){if("<"==n.peek())return o.skipAttribute(c.state),i.context=new t(e.startState(o,s(c.state)),o,0,i.context),null;if(n.match("//"))return n.skipToEnd(),"comment";if(n.match("/*"))return c.depth=2,l(n,i)}var h,p=o.token(n,c.state),f=n.current();return/\btag\b/.test(p)?/>$/.test(f)?c.state.context?c.depth=0:i.context=i.context.prev:/^</.test(f)&&(c.depth=1):!p&&(h=f.indexOf("{"))>-1&&n.backUp(f.length-h),p}(n,i,i.context):function(n,r,i){if("<"==n.peek()&&a.expressionAllowed(n,i.state))return r.context=new t(e.startState(o,a.indent(i.state,"","")),o,0,r.context),a.skipExpression(i.state),null;var s=a.token(n,i.state);if(!s&&null!=i.depth){var l=n.current();"{"==l?i.depth++:"}"==l&&0==--i.depth&&(r.context=r.context.prev)}return s}(n,i,i.context)}return{startState:function(){return{context:new t(e.startState(a),a)}},copyState:function(e){return{context:n(e.context)}},token:l,indent:function(e,t,n){return e.context.mode.indent(e.context.state,t,n)},innerMode:function(e){return e.context}}}),"xml","javascript"),e.defineMIME("text/jsx","jsx"),e.defineMIME("text/typescript-jsx",{name:"jsx",base:{name:"javascript",typescript:!0}})}(n(14),n(205),n(204))},function(e,t,n){!function(e){"use strict";e.defineMode("julia",(function(t,n){function r(e,t){return void 0===t&&(t="\\b"),new RegExp("^(("+e.join(")|(")+"))"+t)}var i=n.operators||r(["[<>]:","[<>=]=","<<=?",">>>?=?","=>","->","\\/\\/","[\\\\%*+\\-<>!=\\/^|&\\u00F7\\u22BB]=?","\\?","\\$","~",":","\\u00D7","\\u2208","\\u2209","\\u220B","\\u220C","\\u2218","\\u221A","\\u221B","\\u2229","\\u222A","\\u2260","\\u2264","\\u2265","\\u2286","\\u2288","\\u228A","\\u22C5","\\b(in|isa)\\b(?!.?\\()"],""),o=n.delimiters||/^[;,()[\]{}]/,a=n.identifiers||/^[_A-Za-z\u00A1-\u2217\u2219-\uFFFF][\w\u00A1-\u2217\u2219-\uFFFF]*!*/,s=r(["\\\\[0-7]{1,3}","\\\\x[A-Fa-f0-9]{1,2}","\\\\[abefnrtv0%?'\"\\\\]","([^\\u0027\\u005C\\uD800-\\uDFFF]|[\\uD800-\\uDFFF][\\uDC00-\\uDFFF])"],"'"),l=["if","else","elseif","while","for","begin","let","end","do","try","catch","finally","return","break","continue","global","local","const","export","import","importall","using","function","where","macro","module","baremodule","struct","type","mutable","immutable","quote","typealias","abstract","primitive","bitstype"],c=["true","false","nothing","NaN","Inf"];e.registerHelper("hintWords","julia",l.concat(c));var u=r(["begin","function","type","struct","immutable","let","macro","for","while","quote","if","else","elseif","try","finally","catch","do"]),d=r(["end","else","elseif","catch","finally"]),h=r(l),p=r(c),f=/^@[_A-Za-z][\w]*/,m=/^:[_A-Za-z\u00A1-\uFFFF][\w\u00A1-\uFFFF]*!*/,g=/^(`|([_A-Za-z\u00A1-\uFFFF]*"("")?))/;function v(e){return e.nestedArrays>0}function y(e,t){return void 0===t&&(t=0),e.scopes.length<=t?null:e.scopes[e.scopes.length-(t+1)]}function _(e,t){if(e.match("#=",!1))return t.tokenize=M,t.tokenize(e,t);var n=t.leavingExpr;if(e.sol()&&(n=!1),t.leavingExpr=!1,n&&e.match(/^'+/))return"operator";if(e.match(/\.{4,}/))return"error";if(e.match(/\.{1,3}/))return"operator";if(e.eatSpace())return null;var r,s,l=e.peek();if("#"===l)return e.skipToEnd(),"comment";if("["===l&&(t.scopes.push("["),t.nestedArrays++),"("===l&&(t.scopes.push("("),t.nestedGenerators++),v(t)&&"]"===l){for(;t.scopes.length&&"["!==y(t);)t.scopes.pop();t.scopes.pop(),t.nestedArrays--,t.leavingExpr=!0}if(function(e){return e.nestedGenerators>0}(t)&&")"===l){for(;t.scopes.length&&"("!==y(t);)t.scopes.pop();t.scopes.pop(),t.nestedGenerators--,t.leavingExpr=!0}if(v(t)){if("end"==t.lastToken&&e.match(":"))return"operator";if(e.match("end"))return"number"}if((r=e.match(u,!1))&&t.scopes.push(r[0]),e.match(d,!1)&&t.scopes.pop(),e.match(/^::(?![:\$])/))return t.tokenize=b,t.tokenize(e,t);if(!n&&e.match(m)||e.match(/:([<>]:|<<=?|>>>?=?|->|\/\/|\.{2,3}|[\.\\%*+\-<>!\/^|&]=?|[~\?\$])/))return"builtin";if(e.match(i))return"operator";if(e.match(/^\.?\d/,!1)){var c=RegExp(/^im\b/),A=!1;if(e.match(/^0x\.[0-9a-f_]+p[\+\-]?[_\d]+/i)&&(A=!0),e.match(/^0x[0-9a-f_]+/i)&&(A=!0),e.match(/^0b[01_]+/i)&&(A=!0),e.match(/^0o[0-7_]+/i)&&(A=!0),e.match(/^(?:(?:\d[_\d]*)?\.(?!\.)(?:\d[_\d]*)?|\d[_\d]*\.(?!\.)(?:\d[_\d]*))?([Eef][\+\-]?[_\d]+)?/i)&&(A=!0),e.match(/^\d[_\d]*(e[\+\-]?\d+)?/i)&&(A=!0),A)return e.match(c),t.leavingExpr=!0,"number"}if(e.match("'"))return t.tokenize=w,t.tokenize(e,t);if(e.match(g))return t.tokenize=('"""'===(s=e.current()).substr(-3)?s='"""':'"'===s.substr(-1)&&(s='"'),function(e,t){if(e.eat("\\"))e.next();else{if(e.match(s))return t.tokenize=_,t.leavingExpr=!0,"string";e.eat(/[`"]/)}return e.eatWhile(/[^\\`"]/),"string"}),t.tokenize(e,t);if(e.match(f))return"meta";if(e.match(o))return null;if(e.match(h))return"keyword";if(e.match(p))return"builtin";var C=t.isDefinition||"function"==t.lastToken||"macro"==t.lastToken||"type"==t.lastToken||"struct"==t.lastToken||"immutable"==t.lastToken;return e.match(a)?C?"."===e.peek()?(t.isDefinition=!0,"variable"):(t.isDefinition=!1,"def"):(t.leavingExpr=!0,"variable"):(e.next(),"error")}function b(e,t){return e.match(/.*?(?=[,;{}()=\s]|$)/),e.match("{")?t.nestedParameters++:e.match("}")&&t.nestedParameters>0&&t.nestedParameters--,t.nestedParameters>0?e.match(/.*?(?={|})/)||e.next():0==t.nestedParameters&&(t.tokenize=_),"builtin"}function M(e,t){return e.match("#=")&&t.nestedComments++,e.match(/.*?(?=(#=|=#))/)||e.skipToEnd(),e.match("=#")&&(t.nestedComments--,0==t.nestedComments&&(t.tokenize=_)),"comment"}function w(e,t){var n,r=!1;if(e.match(s))r=!0;else if(n=e.match(/\\u([a-f0-9]{1,4})(?=')/i))((i=parseInt(n[1],16))<=55295||i>=57344)&&(r=!0,e.next());else if(n=e.match(/\\U([A-Fa-f0-9]{5,8})(?=')/)){var i;(i=parseInt(n[1],16))<=1114111&&(r=!0,e.next())}return r?(t.leavingExpr=!0,t.tokenize=_,"string"):(e.match(/^[^']+(?=')/)||e.skipToEnd(),e.match("'")&&(t.tokenize=_),"error")}return{startState:function(){return{tokenize:_,scopes:[],lastToken:null,leavingExpr:!1,isDefinition:!1,nestedArrays:0,nestedComments:0,nestedGenerators:0,nestedParameters:0,firstParenPos:-1}},token:function(e,t){var n=t.tokenize(e,t),r=e.current();return r&&n&&(t.lastToken=r),n},indent:function(e,n){var r=0;return("]"===n||")"===n||/^end\b/.test(n)||/^else/.test(n)||/^catch\b/.test(n)||/^elseif\b/.test(n)||/^finally/.test(n))&&(r=-1),(e.scopes.length+r)*t.indentUnit},electricInput:/\b(end|else|catch|finally)\b/,blockCommentStart:"#=",blockCommentEnd:"=#",lineComment:"#",closeBrackets:'()[]{}""',fold:"indent"}})),e.defineMIME("text/x-julia","julia")}(n(14))},function(e,t,n){!function(e){"use strict";e.registerHelper("wordChars","r",/[\w.]/),e.defineMode("r",(function(t){function n(e){for(var t={},n=0;n<e.length;++n)t[e[n]]=!0;return t}var r=["NULL","NA","Inf","NaN","NA_integer_","NA_real_","NA_complex_","NA_character_","TRUE","FALSE"],i=["list","quote","bquote","eval","return","call","parse","deparse"],o=["if","else","repeat","while","function","for","in","next","break"];e.registerHelper("hintWords","r",r.concat(i,o));var a,s=n(r),l=n(i),c=n(o),u=n(["if","else","repeat","while","function","for"]),d=/[+\-*\/^<>=!&|~$:]/;function h(e,t){a=null;var n,r=e.next();if("#"==r)return e.skipToEnd(),"comment";if("0"==r&&e.eat("x"))return e.eatWhile(/[\da-f]/i),"number";if("."==r&&e.eat(/\d/))return e.match(/\d*(?:e[+\-]?\d+)?/),"number";if(/\d/.test(r))return e.match(/\d*(?:\.\d+)?(?:e[+\-]\d+)?L?/),"number";if("'"==r||'"'==r)return t.tokenize=(n=r,function(e,t){if(e.eat("\\")){var r=e.next();return"x"==r?e.match(/^[a-f0-9]{2}/i):("u"==r||"U"==r)&&e.eat("{")&&e.skipTo("}")?e.next():"u"==r?e.match(/^[a-f0-9]{4}/i):"U"==r?e.match(/^[a-f0-9]{8}/i):/[0-7]/.test(r)&&e.match(/^[0-7]{1,2}/),"string-2"}for(var i;null!=(i=e.next());){if(i==n){t.tokenize=h;break}if("\\"==i){e.backUp(1);break}}return"string"}),"string";if("`"==r)return e.match(/[^`]+`/),"variable-3";if("."==r&&e.match(/.(?:[.]|\d+)/))return"keyword";if(/[a-zA-Z\.]/.test(r)){e.eatWhile(/[\w\.]/);var i=e.current();return s.propertyIsEnumerable(i)?"atom":c.propertyIsEnumerable(i)?(u.propertyIsEnumerable(i)&&!e.match(/\s*if(\s+|$)/,!1)&&(a="block"),"keyword"):l.propertyIsEnumerable(i)?"builtin":"variable"}return"%"==r?(e.skipTo("%")&&e.next(),"operator variable-2"):"<"==r&&e.eat("-")||"<"==r&&e.match("<-")||"-"==r&&e.match(/>>?/)?"operator arrow":"="==r&&t.ctx.argList?"arg-is":d.test(r)?"$"==r?"operator dollar":(e.eatWhile(d),"operator"):/[\(\){}\[\];]/.test(r)?(a=r,";"==r?"semi":null):null}function p(e,t,n){e.ctx={type:t,indent:e.indent,flags:0,column:n.column(),prev:e.ctx}}function f(e,t){var n=e.ctx;e.ctx={type:n.type,indent:n.indent,flags:n.flags|t,column:n.column,prev:n.prev}}function m(e){e.indent=e.ctx.indent,e.ctx=e.ctx.prev}return{startState:function(){return{tokenize:h,ctx:{type:"top",indent:-t.indentUnit,flags:2},indent:0,afterIdent:!1}},token:function(e,t){if(e.sol()&&(0==(3&t.ctx.flags)&&(t.ctx.flags|=2),4&t.ctx.flags&&m(t),t.indent=e.indentation()),e.eatSpace())return null;var n=t.tokenize(e,t);return"comment"!=n&&0==(2&t.ctx.flags)&&f(t,1),";"!=a&&"{"!=a&&"}"!=a||"block"!=t.ctx.type||m(t),"{"==a?p(t,"}",e):"("==a?(p(t,")",e),t.afterIdent&&(t.ctx.argList=!0)):"["==a?p(t,"]",e):"block"==a?p(t,"block",e):a==t.ctx.type?m(t):"block"==t.ctx.type&&"comment"!=n&&f(t,4),t.afterIdent="variable"==n||"keyword"==n,n},indent:function(e,n){if(e.tokenize!=h)return 0;var r=n&&n.charAt(0),i=e.ctx,o=r==i.type;return 4&i.flags&&(i=i.prev),"block"==i.type?i.indent+("{"==r?0:t.indentUnit):1&i.flags?i.column+(o?0:1):i.indent+(o?0:t.indentUnit)},lineComment:"#"}})),e.defineMIME("text/x-rsrc","r")}(n(14))},function(e,t,n){!function(e){"use strict";e.defineMode("shell",(function(){var t={};function n(e,n){for(var r=0;r<n.length;r++)t[n[r]]=e}var r=["true","false"],i=["if","then","do","else","elif","while","until","for","in","esac","fi","fin","fil","done","exit","set","unset","export","function"],o=["ab","awk","bash","beep","cat","cc","cd","chown","chmod","chroot","clear","cp","curl","cut","diff","echo","find","gawk","gcc","get","git","grep","hg","kill","killall","ln","ls","make","mkdir","openssl","mv","nc","nl","node","npm","ping","ps","restart","rm","rmdir","sed","service","sh","shopt","shred","source","sort","sleep","ssh","start","stop","su","sudo","svn","tee","telnet","top","touch","vi","vim","wall","wc","wget","who","write","yes","zsh"];function a(e,n){if(e.eatSpace())return null;var r,i=e.sol(),o=e.next();if("\\"===o)return e.next(),null;if("'"===o||'"'===o||"`"===o)return n.tokens.unshift(s(o,"`"===o?"quote":"string")),u(e,n);if("#"===o)return i&&e.eat("!")?(e.skipToEnd(),"meta"):(e.skipToEnd(),"comment");if("$"===o)return n.tokens.unshift(c),u(e,n);if("+"===o||"="===o)return"operator";if("-"===o)return e.eat("-"),e.eatWhile(/\w/),"attribute";if("<"==o){if(e.match("<<"))return"operator";var a=e.match(/^<-?\s*['"]?([^'"]*)['"]?/);if(a)return n.tokens.unshift((r=a[1],function(e,t){return e.sol()&&e.string==r&&t.tokens.shift(),e.skipToEnd(),"string-2"})),"string-2"}if(/\d/.test(o)&&(e.eatWhile(/\d/),e.eol()||!/\w/.test(e.peek())))return"number";e.eatWhile(/[\w-]/);var l=e.current();return"="===e.peek()&&/\w+/.test(l)?"def":t.hasOwnProperty(l)?t[l]:null}function s(e,t){var n="("==e?")":"{"==e?"}":e;return function(r,i){for(var o,a=!1;null!=(o=r.next());){if(o===n&&!a){i.tokens.shift();break}if("$"===o&&!a&&"'"!==e&&r.peek()!=n){a=!0,r.backUp(1),i.tokens.unshift(c);break}if(!a&&e!==n&&o===e)return i.tokens.unshift(s(e,t)),u(r,i);if(!a&&/['"]/.test(o)&&!/['"]/.test(e)){i.tokens.unshift(l(o,"string")),r.backUp(1);break}a=!a&&"\\"===o}return t}}function l(e,t){return function(n,r){return r.tokens[0]=s(e,t),n.next(),u(n,r)}}e.registerHelper("hintWords","shell",r.concat(i,o)),n("atom",r),n("keyword",i),n("builtin",o);var c=function(e,t){t.tokens.length>1&&e.eat("$");var n=e.next();return/['"({]/.test(n)?(t.tokens[0]=s(n,"("==n?"quote":"{"==n?"def":"string"),u(e,t)):(/\d/.test(n)||e.eatWhile(/\w/),t.tokens.shift(),"def")};function u(e,t){return(t.tokens[0]||a)(e,t)}return{startState:function(){return{tokens:[]}},token:function(e,t){return u(e,t)},closeBrackets:"()[]{}''\"\"``",lineComment:"#",fold:"brace"}})),e.defineMIME("text/x-sh","shell"),e.defineMIME("application/x-sh","shell")}(n(14))},function(e,t,n){!function(e){"use strict";function t(e){for(var t;null!=(t=e.next());)if("`"==t&&!e.eat("`"))return"variable-2";return e.backUp(e.current().length-1),e.eatWhile(/\w/)?"variable-2":null}function n(e){return e.eat("@")&&(e.match("session."),e.match("local."),e.match("global.")),e.eat("'")?(e.match(/^.*'/),"variable-2"):e.eat('"')?(e.match(/^.*"/),"variable-2"):e.eat("`")?(e.match(/^.*`/),"variable-2"):e.match(/^[0-9a-zA-Z$\.\_]+/)?"variable-2":null}function r(e){return e.eat("N")?"atom":e.match(/^[a-zA-Z.#!?]/)?"variable-2":null}e.defineMode("sql",(function(t,n){var r=n.client||{},s=n.atoms||{false:!0,true:!0,null:!0},l=n.builtin||o(a),c=n.keywords||o(i),u=n.operatorChars||/^[*+\-%<>!=&|~^\/]/,d=n.support||{},h=n.hooks||{},p=n.dateSQL||{date:!0,time:!0,timestamp:!0},f=!1!==n.backslashStringEscapes,m=n.brackets||/^[\{}\(\)\[\]]/,g=n.punctuation||/^[;.,:]/;function v(e,t){var n=e.next();if(h[n]){var i=h[n](e,t);if(!1!==i)return i}if(d.hexNumber&&("0"==n&&e.match(/^[xX][0-9a-fA-F]+/)||("x"==n||"X"==n)&&e.match(/^'[0-9a-fA-F]+'/)))return"number";if(d.binaryNumber&&(("b"==n||"B"==n)&&e.match(/^'[01]+'/)||"0"==n&&e.match(/^b[01]+/)))return"number";if(n.charCodeAt(0)>47&&n.charCodeAt(0)<58)return e.match(/^[0-9]*(\.[0-9]+)?([eE][-+]?[0-9]+)?/),d.decimallessFloat&&e.match(/^\.(?!\.)/),"number";if("?"==n&&(e.eatSpace()||e.eol()||e.eat(";")))return"variable-3";if("'"==n||'"'==n&&d.doubleQuote)return t.tokenize=y(n),t.tokenize(e,t);if((d.nCharCast&&("n"==n||"N"==n)||d.charsetCast&&"_"==n&&e.match(/[a-z][a-z0-9]*/i))&&("'"==e.peek()||'"'==e.peek()))return"keyword";if(d.escapeConstant&&("e"==n||"E"==n)&&("'"==e.peek()||'"'==e.peek()&&d.doubleQuote))return t.tokenize=function(e,t){return(t.tokenize=y(e.next(),!0))(e,t)},"keyword";if(d.commentSlashSlash&&"/"==n&&e.eat("/"))return e.skipToEnd(),"comment";if(d.commentHash&&"#"==n||"-"==n&&e.eat("-")&&(!d.commentSpaceRequired||e.eat(" ")))return e.skipToEnd(),"comment";if("/"==n&&e.eat("*"))return t.tokenize=function e(t){return function(n,r){var i=n.match(/^.*?(\/\*|\*\/)/);return i?"/*"==i[1]?r.tokenize=e(t+1):r.tokenize=t>1?e(t-1):v:n.skipToEnd(),"comment"}}(1),t.tokenize(e,t);if("."!=n){if(u.test(n))return e.eatWhile(u),"operator";if(m.test(n))return"bracket";if(g.test(n))return e.eatWhile(g),"punctuation";if("{"==n&&(e.match(/^( )*(d|D|t|T|ts|TS)( )*'[^']*'( )*}/)||e.match(/^( )*(d|D|t|T|ts|TS)( )*"[^"]*"( )*}/)))return"number";e.eatWhile(/^[_\w\d]/);var o=e.current().toLowerCase();return p.hasOwnProperty(o)&&(e.match(/^( )+'[^']*'/)||e.match(/^( )+"[^"]*"/))?"number":s.hasOwnProperty(o)?"atom":l.hasOwnProperty(o)?"builtin":c.hasOwnProperty(o)?"keyword":r.hasOwnProperty(o)?"string-2":null}return d.zerolessFloat&&e.match(/^(?:\d+(?:e[+-]?\d+)?)/i)?"number":e.match(/^\.+/)?null:d.ODBCdotTable&&e.match(/^[\w\d_$#]+/)?"variable-2":void 0}function y(e,t){return function(n,r){for(var i,o=!1;null!=(i=n.next());){if(i==e&&!o){r.tokenize=v;break}o=(f||t)&&!o&&"\\"==i}return"string"}}function _(e,t,n){t.context={prev:t.context,indent:e.indentation(),col:e.column(),type:n}}return{startState:function(){return{tokenize:v,context:null}},token:function(e,t){if(e.sol()&&t.context&&null==t.context.align&&(t.context.align=!1),t.tokenize==v&&e.eatSpace())return null;var n=t.tokenize(e,t);if("comment"==n)return n;t.context&&null==t.context.align&&(t.context.align=!0);var r=e.current();return"("==r?_(e,t,")"):"["==r?_(e,t,"]"):t.context&&t.context.type==r&&function(e){e.indent=e.context.indent,e.context=e.context.prev}(t),n},indent:function(n,r){var i=n.context;if(!i)return e.Pass;var o=r.charAt(0)==i.type;return i.align?i.col+(o?0:1):i.indent+(o?0:t.indentUnit)},blockCommentStart:"/*",blockCommentEnd:"*/",lineComment:d.commentSlashSlash?"//":d.commentHash?"#":"--",closeBrackets:"()[]{}''\"\"``"}}));var i="alter and as asc between by count create delete desc distinct drop from group having in insert into is join like not on or order select set table union update values where limit ";function o(e){for(var t={},n=e.split(" "),r=0;r<n.length;++r)t[n[r]]=!0;return t}var a="bool boolean bit blob enum long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision real date datetime year unsigned signed decimal numeric";e.defineMIME("text/x-sql",{name:"sql",keywords:o(i+"begin"),builtin:o(a),atoms:o("false true null unknown"),dateSQL:o("date time timestamp"),support:o("ODBCdotTable doubleQuote binaryNumber hexNumber")}),e.defineMIME("text/x-mssql",{name:"sql",client:o("$partition binary_checksum checksum connectionproperty context_info current_request_id error_line error_message error_number error_procedure error_severity error_state formatmessage get_filestream_transaction_context getansinull host_id host_name isnull isnumeric min_active_rowversion newid newsequentialid rowcount_big xact_state object_id"),keywords:o(i+"begin trigger proc view index for add constraint key primary foreign collate clustered nonclustered declare exec go if use index holdlock nolock nowait paglock readcommitted readcommittedlock readpast readuncommitted repeatableread rowlock serializable snapshot tablock tablockx updlock with"),builtin:o("bigint numeric bit smallint decimal smallmoney int tinyint money float real char varchar text nchar nvarchar ntext binary varbinary image cursor timestamp hierarchyid uniqueidentifier sql_variant xml table "),atoms:o("is not null like and or in left right between inner outer join all any some cross unpivot pivot exists"),operatorChars:/^[*+\-%<>!=^\&|\/]/,brackets:/^[\{}\(\)]/,punctuation:/^[;.,:/]/,backslashStringEscapes:!1,dateSQL:o("date datetimeoffset datetime2 smalldatetime datetime time"),hooks:{"@":n}}),e.defineMIME("text/x-mysql",{name:"sql",client:o("charset clear connect edit ego exit go help nopager notee nowarning pager print prompt quit rehash source status system tee"),keywords:o(i+"accessible action add after algorithm all analyze asensitive at authors auto_increment autocommit avg avg_row_length before binary binlog both btree cache call cascade cascaded case catalog_name chain change changed character check checkpoint checksum class_origin client_statistics close coalesce code collate collation collations column columns comment commit committed completion concurrent condition connection consistent constraint contains continue contributors convert cross current current_date current_time current_timestamp current_user cursor data database databases day_hour day_microsecond day_minute day_second deallocate dec declare default delay_key_write delayed delimiter des_key_file describe deterministic dev_pop dev_samp deviance diagnostics directory disable discard distinctrow div dual dumpfile each elseif enable enclosed end ends engine engines enum errors escape escaped even event events every execute exists exit explain extended fast fetch field fields first flush for force foreign found_rows full fulltext function general get global grant grants group group_concat handler hash help high_priority hosts hour_microsecond hour_minute hour_second if ignore ignore_server_ids import index index_statistics infile inner innodb inout insensitive insert_method install interval invoker isolation iterate key keys kill language last leading leave left level limit linear lines list load local localtime localtimestamp lock logs low_priority master master_heartbeat_period master_ssl_verify_server_cert masters match max max_rows maxvalue message_text middleint migrate min min_rows minute_microsecond minute_second mod mode modifies modify mutex mysql_errno natural next no no_write_to_binlog offline offset one online open optimize option optionally out outer outfile pack_keys parser partition partitions password phase plugin plugins prepare preserve prev primary privileges procedure processlist profile profiles purge query quick range read read_write reads real rebuild recover references regexp relaylog release remove rename reorganize repair repeatable replace require resignal restrict resume return returns revoke right rlike rollback rollup row row_format rtree savepoint schedule schema schema_name schemas second_microsecond security sensitive separator serializable server session share show signal slave slow smallint snapshot soname spatial specific sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_no_cache sql_small_result sqlexception sqlstate sqlwarning ssl start starting starts status std stddev stddev_pop stddev_samp storage straight_join subclass_origin sum suspend table_name table_statistics tables tablespace temporary terminated to trailing transaction trigger triggers truncate uncommitted undo uninstall unique unlock upgrade usage use use_frm user user_resources user_statistics using utc_date utc_time utc_timestamp value variables varying view views warnings when while with work write xa xor year_month zerofill begin do then else loop repeat"),builtin:o("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision date datetime year unsigned signed numeric"),atoms:o("false true null unknown"),operatorChars:/^[*+\-%<>!=&|^]/,dateSQL:o("date time timestamp"),support:o("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber doubleQuote nCharCast charsetCast commentHash commentSpaceRequired"),hooks:{"@":n,"`":t,"\\":r}}),e.defineMIME("text/x-mariadb",{name:"sql",client:o("charset clear connect edit ego exit go help nopager notee nowarning pager print prompt quit rehash source status system tee"),keywords:o(i+"accessible action add after algorithm all always analyze asensitive at authors auto_increment autocommit avg avg_row_length before binary binlog both btree cache call cascade cascaded case catalog_name chain change changed character check checkpoint checksum class_origin client_statistics close coalesce code collate collation collations column columns comment commit committed completion concurrent condition connection consistent constraint contains continue contributors convert cross current current_date current_time current_timestamp current_user cursor data database databases day_hour day_microsecond day_minute day_second deallocate dec declare default delay_key_write delayed delimiter des_key_file describe deterministic dev_pop dev_samp deviance diagnostics directory disable discard distinctrow div dual dumpfile each elseif enable enclosed end ends engine engines enum errors escape escaped even event events every execute exists exit explain extended fast fetch field fields first flush for force foreign found_rows full fulltext function general generated get global grant grants group groupby_concat handler hard hash help high_priority hosts hour_microsecond hour_minute hour_second if ignore ignore_server_ids import index index_statistics infile inner innodb inout insensitive insert_method install interval invoker isolation iterate key keys kill language last leading leave left level limit linear lines list load local localtime localtimestamp lock logs low_priority master master_heartbeat_period master_ssl_verify_server_cert masters match max max_rows maxvalue message_text middleint migrate min min_rows minute_microsecond minute_second mod mode modifies modify mutex mysql_errno natural next no no_write_to_binlog offline offset one online open optimize option optionally out outer outfile pack_keys parser partition partitions password persistent phase plugin plugins prepare preserve prev primary privileges procedure processlist profile profiles purge query quick range read read_write reads real rebuild recover references regexp relaylog release remove rename reorganize repair repeatable replace require resignal restrict resume return returns revoke right rlike rollback rollup row row_format rtree savepoint schedule schema schema_name schemas second_microsecond security sensitive separator serializable server session share show shutdown signal slave slow smallint snapshot soft soname spatial specific sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_no_cache sql_small_result sqlexception sqlstate sqlwarning ssl start starting starts status std stddev stddev_pop stddev_samp storage straight_join subclass_origin sum suspend table_name table_statistics tables tablespace temporary terminated to trailing transaction trigger triggers truncate uncommitted undo uninstall unique unlock upgrade usage use use_frm user user_resources user_statistics using utc_date utc_time utc_timestamp value variables varying view views virtual warnings when while with work write xa xor year_month zerofill begin do then else loop repeat"),builtin:o("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision date datetime year unsigned signed numeric"),atoms:o("false true null unknown"),operatorChars:/^[*+\-%<>!=&|^]/,dateSQL:o("date time timestamp"),support:o("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber doubleQuote nCharCast charsetCast commentHash commentSpaceRequired"),hooks:{"@":n,"`":t,"\\":r}}),e.defineMIME("text/x-sqlite",{name:"sql",client:o("auth backup bail binary changes check clone databases dbinfo dump echo eqp exit explain fullschema headers help import imposter indexes iotrace limit lint load log mode nullvalue once open output print prompt quit read restore save scanstats schema separator session shell show stats system tables testcase timeout timer trace vfsinfo vfslist vfsname width"),keywords:o(i+"abort action add after all analyze attach autoincrement before begin cascade case cast check collate column commit conflict constraint cross current_date current_time current_timestamp database default deferrable deferred detach each else end escape except exclusive exists explain fail for foreign full glob if ignore immediate index indexed initially inner instead intersect isnull key left limit match natural no notnull null of offset outer plan pragma primary query raise recursive references regexp reindex release rename replace restrict right rollback row savepoint temp temporary then to transaction trigger unique using vacuum view virtual when with without"),builtin:o("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text clob bigint int int2 int8 integer float double char varchar date datetime year unsigned signed numeric real"),atoms:o("null current_date current_time current_timestamp"),operatorChars:/^[*+\-%<>!=&|/~]/,dateSQL:o("date time timestamp datetime"),support:o("decimallessFloat zerolessFloat"),identifierQuote:'"',hooks:{"@":n,":":n,"?":n,$:n,'"':function(e){for(var t;null!=(t=e.next());)if('"'==t&&!e.eat('"'))return"variable-2";return e.backUp(e.current().length-1),e.eatWhile(/\w/)?"variable-2":null},"`":t}}),e.defineMIME("text/x-cassandra",{name:"sql",client:{},keywords:o("add all allow alter and any apply as asc authorize batch begin by clustering columnfamily compact consistency count create custom delete desc distinct drop each_quorum exists filtering from grant if in index insert into key keyspace keyspaces level limit local_one local_quorum modify nan norecursive nosuperuser not of on one order password permission permissions primary quorum rename revoke schema select set storage superuser table three to token truncate ttl two type unlogged update use user users using values where with writetime"),builtin:o("ascii bigint blob boolean counter decimal double float frozen inet int list map static text timestamp timeuuid tuple uuid varchar varint"),atoms:o("false true infinity NaN"),operatorChars:/^[<>=]/,dateSQL:{},support:o("commentSlashSlash decimallessFloat"),hooks:{}}),e.defineMIME("text/x-plsql",{name:"sql",client:o("appinfo arraysize autocommit autoprint autorecovery autotrace blockterminator break btitle cmdsep colsep compatibility compute concat copycommit copytypecheck define describe echo editfile embedded escape exec execute feedback flagger flush heading headsep instance linesize lno loboffset logsource long longchunksize markup native newpage numformat numwidth pagesize pause pno recsep recsepchar release repfooter repheader serveroutput shiftinout show showmode size spool sqlblanklines sqlcase sqlcode sqlcontinue sqlnumber sqlpluscompatibility sqlprefix sqlprompt sqlterminator suffix tab term termout time timing trimout trimspool ttitle underline verify version wrap"),keywords:o("abort accept access add all alter and any array arraylen as asc assert assign at attributes audit authorization avg base_table begin between binary_integer body boolean by case cast char char_base check close cluster clusters colauth column comment commit compress connect connected constant constraint crash create current currval cursor data_base database date dba deallocate debugoff debugon decimal declare default definition delay delete desc digits dispose distinct do drop else elseif elsif enable end entry escape exception exception_init exchange exclusive exists exit external fast fetch file for force form from function generic goto grant group having identified if immediate in increment index indexes indicator initial initrans insert interface intersect into is key level library like limited local lock log logging long loop master maxextents maxtrans member minextents minus mislabel mode modify multiset new next no noaudit nocompress nologging noparallel not nowait number_base object of off offline on online only open option or order out package parallel partition pctfree pctincrease pctused pls_integer positive positiven pragma primary prior private privileges procedure public raise range raw read rebuild record ref references refresh release rename replace resource restrict return returning returns reverse revoke rollback row rowid rowlabel rownum rows run savepoint schema segment select separate session set share snapshot some space split sql start statement storage subtype successful synonym tabauth table tables tablespace task terminate then to trigger truncate type union unique unlimited unrecoverable unusable update use using validate value values variable view views when whenever where while with work"),builtin:o("abs acos add_months ascii asin atan atan2 average bfile bfilename bigserial bit blob ceil character chartorowid chr clob concat convert cos cosh count dec decode deref dual dump dup_val_on_index empty error exp false float floor found glb greatest hextoraw initcap instr instrb int integer isopen last_day least length lengthb ln lower lpad ltrim lub make_ref max min mlslabel mod months_between natural naturaln nchar nclob new_time next_day nextval nls_charset_decl_len nls_charset_id nls_charset_name nls_initcap nls_lower nls_sort nls_upper nlssort no_data_found notfound null number numeric nvarchar2 nvl others power rawtohex real reftohex round rowcount rowidtochar rowtype rpad rtrim serial sign signtype sin sinh smallint soundex sqlcode sqlerrm sqrt stddev string substr substrb sum sysdate tan tanh to_char text to_date to_label to_multi_byte to_number to_single_byte translate true trunc uid unlogged upper user userenv varchar varchar2 variance varying vsize xml"),operatorChars:/^[*\/+\-%<>!=~]/,dateSQL:o("date time timestamp"),support:o("doubleQuote nCharCast zerolessFloat binaryNumber hexNumber")}),e.defineMIME("text/x-hive",{name:"sql",keywords:o("select alter $elem$ $key$ $value$ add after all analyze and archive as asc before between binary both bucket buckets by cascade case cast change cluster clustered clusterstatus collection column columns comment compute concatenate continue create cross cursor data database databases dbproperties deferred delete delimited desc describe directory disable distinct distribute drop else enable end escaped exclusive exists explain export extended external fetch fields fileformat first format formatted from full function functions grant group having hold_ddltime idxproperties if import in index indexes inpath inputdriver inputformat insert intersect into is items join keys lateral left like limit lines load local location lock locks mapjoin materialized minus msck no_drop nocompress not of offline on option or order out outer outputdriver outputformat overwrite partition partitioned partitions percent plus preserve procedure purge range rcfile read readonly reads rebuild recordreader recordwriter recover reduce regexp rename repair replace restrict revoke right rlike row schema schemas semi sequencefile serde serdeproperties set shared show show_database sort sorted ssl statistics stored streamtable table tables tablesample tblproperties temporary terminated textfile then tmp to touch transform trigger unarchive undo union uniquejoin unlock update use using utc utc_tmestamp view when where while with admin authorization char compact compactions conf cube current current_date current_timestamp day decimal defined dependency directories elem_type exchange file following for grouping hour ignore inner interval jar less logical macro minute month more none noscan over owner partialscan preceding pretty principals protection reload rewrite role roles rollup rows second server sets skewed transactions truncate unbounded unset uri user values window year"),builtin:o("bool boolean long timestamp tinyint smallint bigint int float double date datetime unsigned string array struct map uniontype key_type utctimestamp value_type varchar"),atoms:o("false true null unknown"),operatorChars:/^[*+\-%<>!=]/,dateSQL:o("date timestamp"),support:o("ODBCdotTable doubleQuote binaryNumber hexNumber")}),e.defineMIME("text/x-pgsql",{name:"sql",client:o("source"),keywords:o(i+"a abort abs absent absolute access according action ada add admin after aggregate alias all allocate also alter always analyse analyze and any are array array_agg array_max_cardinality as asc asensitive assert assertion assignment asymmetric at atomic attach attribute attributes authorization avg backward base64 before begin begin_frame begin_partition bernoulli between bigint binary bit bit_length blob blocked bom boolean both breadth by c cache call called cardinality cascade cascaded case cast catalog catalog_name ceil ceiling chain char char_length character character_length character_set_catalog character_set_name character_set_schema characteristics characters check checkpoint class class_origin clob close cluster coalesce cobol collate collation collation_catalog collation_name collation_schema collect column column_name columns command_function command_function_code comment comments commit committed concurrently condition condition_number configuration conflict connect connection connection_name constant constraint constraint_catalog constraint_name constraint_schema constraints constructor contains content continue control conversion convert copy corr corresponding cost count covar_pop covar_samp create cross csv cube cume_dist current current_catalog current_date current_default_transform_group current_path current_role current_row current_schema current_time current_timestamp current_transform_group_for_type current_user cursor cursor_name cycle data database datalink datatype date datetime_interval_code datetime_interval_precision day db deallocate debug dec decimal declare default defaults deferrable deferred defined definer degree delete delimiter delimiters dense_rank depends depth deref derived desc describe descriptor detach detail deterministic diagnostics dictionary disable discard disconnect dispatch distinct dlnewcopy dlpreviouscopy dlurlcomplete dlurlcompleteonly dlurlcompletewrite dlurlpath dlurlpathonly dlurlpathwrite dlurlscheme dlurlserver dlvalue do document domain double drop dump dynamic dynamic_function dynamic_function_code each element else elseif elsif empty enable encoding encrypted end end_frame end_partition endexec enforced enum equals errcode error escape event every except exception exclude excluding exclusive exec execute exists exit exp explain expression extension external extract false family fetch file filter final first first_value flag float floor following for force foreach foreign fortran forward found frame_row free freeze from fs full function functions fusion g general generated get global go goto grant granted greatest group grouping groups handler having header hex hierarchy hint hold hour id identity if ignore ilike immediate immediately immutable implementation implicit import in include including increment indent index indexes indicator info inherit inherits initially inline inner inout input insensitive insert instance instantiable instead int integer integrity intersect intersection interval into invoker is isnull isolation join k key key_member key_type label lag language large last last_value lateral lead leading leakproof least left length level library like like_regex limit link listen ln load local localtime localtimestamp location locator lock locked log logged loop lower m map mapping match matched materialized max max_cardinality maxvalue member merge message message_length message_octet_length message_text method min minute minvalue mod mode modifies module month more move multiset mumps name names namespace national natural nchar nclob nesting new next nfc nfd nfkc nfkd nil no none normalize normalized not nothing notice notify notnull nowait nth_value ntile null nullable nullif nulls number numeric object occurrences_regex octet_length octets of off offset oids old on only open operator option options or order ordering ordinality others out outer output over overlaps overlay overriding owned owner p pad parallel parameter parameter_mode parameter_name parameter_ordinal_position parameter_specific_catalog parameter_specific_name parameter_specific_schema parser partial partition pascal passing passthrough password path percent percent_rank percentile_cont percentile_disc perform period permission pg_context pg_datatype_name pg_exception_context pg_exception_detail pg_exception_hint placing plans pli policy portion position position_regex power precedes preceding precision prepare prepared preserve primary print_strict_params prior privileges procedural procedure procedures program public publication query quote raise range rank read reads real reassign recheck recovery recursive ref references referencing refresh regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy regr_syy reindex relative release rename repeatable replace replica requiring reset respect restart restore restrict result result_oid return returned_cardinality returned_length returned_octet_length returned_sqlstate returning returns reverse revoke right role rollback rollup routine routine_catalog routine_name routine_schema routines row row_count row_number rows rowtype rule savepoint scale schema schema_name schemas scope scope_catalog scope_name scope_schema scroll search second section security select selective self sensitive sequence sequences serializable server server_name session session_user set setof sets share show similar simple size skip slice smallint snapshot some source space specific specific_name specifictype sql sqlcode sqlerror sqlexception sqlstate sqlwarning sqrt stable stacked standalone start state statement static statistics stddev_pop stddev_samp stdin stdout storage strict strip structure style subclass_origin submultiset subscription substring substring_regex succeeds sum symmetric sysid system system_time system_user t table table_name tables tablesample tablespace temp template temporary text then ties time timestamp timezone_hour timezone_minute to token top_level_count trailing transaction transaction_active transactions_committed transactions_rolled_back transform transforms translate translate_regex translation treat trigger trigger_catalog trigger_name trigger_schema trim trim_array true truncate trusted type types uescape unbounded uncommitted under unencrypted union unique unknown unlink unlisten unlogged unnamed unnest until untyped update upper uri usage use_column use_variable user user_defined_type_catalog user_defined_type_code user_defined_type_name user_defined_type_schema using vacuum valid validate validator value value_of values var_pop var_samp varbinary varchar variable_conflict variadic varying verbose version versioning view views volatile warning when whenever where while whitespace width_bucket window with within without work wrapper write xml xmlagg xmlattributes xmlbinary xmlcast xmlcomment xmlconcat xmldeclaration xmldocument xmlelement xmlexists xmlforest xmliterate xmlnamespaces xmlparse xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltext xmlvalidate year yes zone"),builtin:o("bigint int8 bigserial serial8 bit varying varbit boolean bool box bytea character char varchar cidr circle date double precision float8 inet integer int int4 interval json jsonb line lseg macaddr macaddr8 money numeric decimal path pg_lsn point polygon real float4 smallint int2 smallserial serial2 serial serial4 text time without zone with timetz timestamp timestamptz tsquery tsvector txid_snapshot uuid xml"),atoms:o("false true null unknown"),operatorChars:/^[*\/+\-%<>!=&|^\/#@?~]/,backslashStringEscapes:!1,dateSQL:o("date time timestamp"),support:o("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber nCharCast charsetCast escapeConstant")}),e.defineMIME("text/x-gql",{name:"sql",keywords:o("ancestor and asc by contains desc descendant distinct from group has in is limit offset on order select superset where"),atoms:o("false true"),builtin:o("blob datetime first key __key__ string integer double boolean null"),operatorChars:/^[*+\-%<>!=]/}),e.defineMIME("text/x-gpsql",{name:"sql",client:o("source"),keywords:o("abort absolute access action active add admin after aggregate all also alter always analyse analyze and any array as asc assertion assignment asymmetric at authorization backward before begin between bigint binary bit boolean both by cache called cascade cascaded case cast chain char character characteristics check checkpoint class close cluster coalesce codegen collate column comment commit committed concurrency concurrently configuration connection constraint constraints contains content continue conversion copy cost cpu_rate_limit create createdb createexttable createrole createuser cross csv cube current current_catalog current_date current_role current_schema current_time current_timestamp current_user cursor cycle data database day deallocate dec decimal declare decode default defaults deferrable deferred definer delete delimiter delimiters deny desc dictionary disable discard distinct distributed do document domain double drop dxl each else enable encoding encrypted end enum errors escape every except exchange exclude excluding exclusive execute exists explain extension external extract false family fetch fields filespace fill filter first float following for force foreign format forward freeze from full function global grant granted greatest group group_id grouping handler hash having header hold host hour identity if ignore ilike immediate immutable implicit in including inclusive increment index indexes inherit inherits initially inline inner inout input insensitive insert instead int integer intersect interval into invoker is isnull isolation join key language large last leading least left level like limit list listen load local localtime localtimestamp location lock log login mapping master match maxvalue median merge minute minvalue missing mode modifies modify month move name names national natural nchar new newline next no nocreatedb nocreateexttable nocreaterole nocreateuser noinherit nologin none noovercommit nosuperuser not nothing notify notnull nowait null nullif nulls numeric object of off offset oids old on only operator option options or order ordered others out outer over overcommit overlaps overlay owned owner parser partial partition partitions passing password percent percentile_cont percentile_disc placing plans position preceding precision prepare prepared preserve primary prior privileges procedural procedure protocol queue quote randomly range read readable reads real reassign recheck recursive ref references reindex reject relative release rename repeatable replace replica reset resource restart restrict returning returns revoke right role rollback rollup rootpartition row rows rule savepoint scatter schema scroll search second security segment select sequence serializable session session_user set setof sets share show similar simple smallint some split sql stable standalone start statement statistics stdin stdout storage strict strip subpartition subpartitions substring superuser symmetric sysid system table tablespace temp template temporary text then threshold ties time timestamp to trailing transaction treat trigger trim true truncate trusted type unbounded uncommitted unencrypted union unique unknown unlisten until update user using vacuum valid validation validator value values varchar variadic varying verbose version view volatile web when where whitespace window with within without work writable write xml xmlattributes xmlconcat xmlelement xmlexists xmlforest xmlparse xmlpi xmlroot xmlserialize year yes zone"),builtin:o("bigint int8 bigserial serial8 bit varying varbit boolean bool box bytea character char varchar cidr circle date double precision float float8 inet integer int int4 interval json jsonb line lseg macaddr macaddr8 money numeric decimal path pg_lsn point polygon real float4 smallint int2 smallserial serial2 serial serial4 text time without zone with timetz timestamp timestamptz tsquery tsvector txid_snapshot uuid xml"),atoms:o("false true null unknown"),operatorChars:/^[*+\-%<>!=&|^\/#@?~]/,dateSQL:o("date time timestamp"),support:o("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber nCharCast charsetCast")}),e.defineMIME("text/x-sparksql",{name:"sql",keywords:o("add after all alter analyze and anti archive array as asc at between bucket buckets by cache cascade case cast change clear cluster clustered codegen collection column columns comment commit compact compactions compute concatenate cost create cross cube current current_date current_timestamp database databases data dbproperties defined delete delimited deny desc describe dfs directories distinct distribute drop else end escaped except exchange exists explain export extended external false fields fileformat first following for format formatted from full function functions global grant group grouping having if ignore import in index indexes inner inpath inputformat insert intersect interval into is items join keys last lateral lazy left like limit lines list load local location lock locks logical macro map minus msck natural no not null nulls of on optimize option options or order out outer outputformat over overwrite partition partitioned partitions percent preceding principals purge range recordreader recordwriter recover reduce refresh regexp rename repair replace reset restrict revoke right rlike role roles rollback rollup row rows schema schemas select semi separated serde serdeproperties set sets show skewed sort sorted start statistics stored stratify struct table tables tablesample tblproperties temp temporary terminated then to touch transaction transactions transform true truncate unarchive unbounded uncache union unlock unset use using values view when where window with"),builtin:o("tinyint smallint int bigint boolean float double string binary timestamp decimal array map struct uniontype delimited serde sequencefile textfile rcfile inputformat outputformat"),atoms:o("false true null"),operatorChars:/^[*\/+\-%<>!=~&|^]/,dateSQL:o("date time timestamp"),support:o("ODBCdotTable doubleQuote zerolessFloat")}),e.defineMIME("text/x-esper",{name:"sql",client:o("source"),keywords:o("alter and as asc between by count create delete desc distinct drop from group having in insert into is join like not on or order select set table union update values where limit after all and as at asc avedev avg between by case cast coalesce count create current_timestamp day days delete define desc distinct else end escape events every exists false first from full group having hour hours in inner insert instanceof into irstream is istream join last lastweekday left limit like max match_recognize matches median measures metadatasql min minute minutes msec millisecond milliseconds not null offset on or order outer output partition pattern prev prior regexp retain-union retain-intersection right rstream sec second seconds select set some snapshot sql stddev sum then true unidirectional until update variable weekday when where window"),builtin:{},atoms:o("false true null"),operatorChars:/^[*+\-%<>!=&|^\/#@?~]/,dateSQL:o("time"),support:o("decimallessFloat zerolessFloat binaryNumber hexNumber")})}(n(14))},function(e,t,n){!function(e){"use strict";var t=/^((?:(?:aaas?|about|acap|adiumxtra|af[ps]|aim|apt|attachment|aw|beshare|bitcoin|bolo|callto|cap|chrome(?:-extension)?|cid|coap|com-eventbrite-attendee|content|crid|cvs|data|dav|dict|dlna-(?:playcontainer|playsingle)|dns|doi|dtn|dvb|ed2k|facetime|feed|file|finger|fish|ftp|geo|gg|git|gizmoproject|go|gopher|gtalk|h323|hcp|https?|iax|icap|icon|im|imap|info|ipn|ipp|irc[6s]?|iris(?:\.beep|\.lwz|\.xpc|\.xpcs)?|itms|jar|javascript|jms|keyparc|lastfm|ldaps?|magnet|mailto|maps|market|message|mid|mms|ms-help|msnim|msrps?|mtqp|mumble|mupdate|mvn|news|nfs|nih?|nntp|notes|oid|opaquelocktoken|palm|paparazzi|platform|pop|pres|proxy|psyc|query|res(?:ource)?|rmi|rsync|rtmp|rtsp|secondlife|service|session|sftp|sgn|shttp|sieve|sips?|skype|sm[bs]|snmp|soap\.beeps?|soldat|spotify|ssh|steam|svn|tag|teamspeak|tel(?:net)?|tftp|things|thismessage|tip|tn3270|tv|udp|unreal|urn|ut2004|vemmi|ventrilo|view-source|webcal|wss?|wtai|wyciwyg|xcon(?:-userid)?|xfire|xmlrpc\.beeps?|xmpp|xri|ymsgr|z39\.50[rs]?):(?:\/{1,3}|[a-z0-9%])|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}\/)(?:[^\s()<>]|\([^\s()<>]*\))+(?:\([^\s()<>]*\)|[^\s`*!()\[\]{};:'".,<>?«»“”‘’]))/i;e.defineMode("gfm",(function(n,r){var i=0,o={startState:function(){return{code:!1,codeBlock:!1,ateSpace:!1}},copyState:function(e){return{code:e.code,codeBlock:e.codeBlock,ateSpace:e.ateSpace}},token:function(e,n){if(n.combineTokens=null,n.codeBlock)return e.match(/^```+/)?(n.codeBlock=!1,null):(e.skipToEnd(),null);if(e.sol()&&(n.code=!1),e.sol()&&e.match(/^```+/))return e.skipToEnd(),n.codeBlock=!0,null;if("`"===e.peek()){e.next();var o=e.pos;e.eatWhile("`");var a=1+e.pos-o;return n.code?a===i&&(n.code=!1):(i=a,n.code=!0),null}if(n.code)return e.next(),null;if(e.eatSpace())return n.ateSpace=!0,null;if((e.sol()||n.ateSpace)&&(n.ateSpace=!1,!1!==r.gitHubSpice)){if(e.match(/^(?:[a-zA-Z0-9\-_]+\/)?(?:[a-zA-Z0-9\-_]+@)?(?=.{0,6}\d)(?:[a-f0-9]{7,40}\b)/))return n.combineTokens=!0,"link";if(e.match(/^(?:[a-zA-Z0-9\-_]+\/)?(?:[a-zA-Z0-9\-_]+)?#[0-9]+\b/))return n.combineTokens=!0,"link"}return e.match(t)&&"]("!=e.string.slice(e.start-2,e.start)&&(0==e.start||/\W/.test(e.string.charAt(e.start-1)))?(n.combineTokens=!0,"link"):(e.next(),null)},blankLine:function(e){return e.code=!1,null}},a={taskLists:!0,strikethrough:!0,emoji:!0};for(var s in r)a[s]=r[s];return a.name="markdown",e.overlayMode(e.getMode(n,a),o)}),"markdown"),e.defineMIME("text/x-gfm","gfm")}(n(14),n(206),n(589))},,,,,,,function(e,t,n){e.exports=n(1002)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ConfigWithDefaults=t.ConfigSection=void 0;const r=n(12),i=n(38);!function(e){e.create=function(e){const t=new o(e);return t.load().then(()=>t)}}(t.ConfigSection||(t.ConfigSection={}));class o{constructor(e){var t;this._url="unknown";const n=this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:i.ServerConnection.makeSettings();this._url=r.URLExt.join(n.baseUrl,"api/config",encodeURIComponent(e.name))}get data(){return this._data}async load(){const e=await i.ServerConnection.makeRequest(this._url,{},this.serverSettings);if(200!==e.status){throw await i.ServerConnection.ResponseError.create(e)}this._data=await e.json()}async update(e){this._data=Object.assign(Object.assign({},this._data),e);const t={method:"PATCH",body:JSON.stringify(e)},n=await i.ServerConnection.makeRequest(this._url,t,this.serverSettings);if(200!==n.status){throw await i.ServerConnection.ResponseError.create(n)}return this._data=await n.json(),this._data}}t.ConfigWithDefaults=class{constructor(e){var t,n;this._className="",this._section=e.section,this._defaults=null!==(t=e.defaults)&&void 0!==t?t:{},this._className=null!==(n=e.className)&&void 0!==n?n:""}get(e){const t=this._classData();return e in t?t[e]:this._defaults[e]}set(e,t){const n={};if(n[e]=t,this._className){const e={};return e[this._className]=n,this._section.update(e)}return this._section.update(n)}_classData(){const e=this._section.data;return this._className&&this._className in e?e[this._className]:e}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ActivityMonitor=void 0;const r=n(4);t.ActivityMonitor=class{constructor(e){this._timer=-1,this._timeout=-1,this._isDisposed=!1,this._activityStopped=new r.Signal(this),e.signal.connect(this._onSignalFired,this),this._timeout=e.timeout||1e3}get activityStopped(){return this._activityStopped}get timeout(){return this._timeout}set timeout(e){this._timeout=e}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed||(this._isDisposed=!0,r.Signal.clearData(this))}_onSignalFired(e,t){clearTimeout(this._timer),this._sender=e,this._args=t,this._timer=setTimeout(()=>{this._activityStopped.emit({sender:this._sender,args:this._args})},this._timeout)}}},function(e,t,n){(function(e,t){!function(e,n){"use strict";if(!e.setImmediate){var r,i,o,a,s,l=1,c={},u=!1,d=e.document,h=Object.getPrototypeOf&&Object.getPrototypeOf(e);h=h&&h.setTimeout?h:e,"[object process]"==={}.toString.call(e.process)?r=function(e){t.nextTick((function(){f(e)}))}:!function(){if(e.postMessage&&!e.importScripts){var t=!0,n=e.onmessage;return e.onmessage=function(){t=!1},e.postMessage("","*"),e.onmessage=n,t}}()?e.MessageChannel?((o=new MessageChannel).port1.onmessage=function(e){f(e.data)},r=function(e){o.port2.postMessage(e)}):d&&"onreadystatechange"in d.createElement("script")?(i=d.documentElement,r=function(e){var t=d.createElement("script");t.onreadystatechange=function(){f(e),t.onreadystatechange=null,i.removeChild(t),t=null},i.appendChild(t)}):r=function(e){setTimeout(f,0,e)}:(a="setImmediate$"+Math.random()+"$",s=function(t){t.source===e&&"string"==typeof t.data&&0===t.data.indexOf(a)&&f(+t.data.slice(a.length))},e.addEventListener?e.addEventListener("message",s,!1):e.attachEvent("onmessage",s),r=function(t){e.postMessage(a+t,"*")}),h.setImmediate=function(e){"function"!=typeof e&&(e=new Function(""+e));for(var t=new Array(arguments.length-1),n=0;n<t.length;n++)t[n]=arguments[n+1];var i={callback:e,args:t};return c[l]=i,r(l),l++},h.clearImmediate=p}function p(e){delete c[e]}function f(e){if(u)setTimeout(f,0,e);else{var t=c[e];if(t){u=!0;try{!function(e){var t=e.callback,n=e.args;switch(n.length){case 0:t();break;case 1:t(n[0]);break;case 2:t(n[0],n[1]);break;case 3:t(n[0],n[1],n[2]);break;default:t.apply(void 0,n)}}(t)}finally{p(e),u=!1}}}}}("undefined"==typeof self?void 0===e?this:e:self)}).call(this,n(55),n(61))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.MarkdownCodeBlocks=void 0,function(e){e.CODE_BLOCK_MARKER="```";const t=[".markdown",".mdown",".mkdn",".md",".mkd",".mdwn",".mdtxt",".mdtext",".text",".txt",".Rmd"];class n{constructor(e){this.startLine=e,this.code="",this.endLine=-1}}e.MarkdownCodeBlock=n,e.isMarkdown=function(e){return t.indexOf(e)>-1},e.findMarkdownCodeBlocks=function(t){if(!t||""===t)return[];const r=t.split("\n"),i=[];let o=null;for(let t=0;t<r.length;t++){const a=r[t],s=0===a.indexOf(e.CODE_BLOCK_MARKER),l=null!=o;if(s||l)if(l)o&&(s?(o.endLine=t-1,i.push(o),o=null):o.code+=a+"\n");else{o=new n(t);const r=a.indexOf(e.CODE_BLOCK_MARKER),s=a.lastIndexOf(e.CODE_BLOCK_MARKER);r!==s&&(o.code=a.substring(r+e.CODE_BLOCK_MARKER.length,s),o.endLine=t,i.push(o),o=null)}}return i}}(t.MarkdownCodeBlocks||(t.MarkdownCodeBlocks={}))},function(module,exports,__webpack_require__){"use strict";(function(process){var __importDefault=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(exports,"__esModule",{value:!0}),exports.PageConfig=void 0;const coreutils_1=__webpack_require__(6),minimist_1=__importDefault(__webpack_require__(613)),url_1=__webpack_require__(210);var PageConfig;!function(PageConfig){function getOption(name){if(configData)return configData[name]||getBodyData(name);configData=Object.create(null);let found=!1;if("undefined"!=typeof document&&document){const e=document.getElementById("jupyter-config-data");e&&(configData=JSON.parse(e.textContent||""),found=!0)}if(!found&&void 0!==process&&process.argv)try{const cli=minimist_1.default(process.argv.slice(2)),path=__webpack_require__(150);let fullPath="";"jupyter-config-data"in cli?fullPath=path.resolve(cli["jupyter-config-data"]):"JUPYTER_CONFIG_DATA"in process.env&&(fullPath=path.resolve(process.env.JUPYTER_CONFIG_DATA)),fullPath&&(configData=eval("require")(fullPath))}catch(e){console.error(e)}if(coreutils_1.JSONExt.isObject(configData))for(const e in configData)"string"!=typeof configData[e]&&(configData[e]=JSON.stringify(configData[e]));else configData=Object.create(null);return configData[name]||getBodyData(name)}function setOption(e,t){const n=getOption(e);return configData[e]=t,n}function getBaseUrl(){return url_1.URLExt.normalize(getOption("baseUrl")||"/")}function getTreeUrl(){return url_1.URLExt.join(getBaseUrl(),getOption("treeUrl"))}function getShareUrl(){return url_1.URLExt.normalize(getOption("shareUrl")||getBaseUrl())}function getTreeShareUrl(){return url_1.URLExt.normalize(url_1.URLExt.join(getShareUrl(),getOption("treeUrl")))}function getUrl(e){var t,n,r,i;let o=e.toShare?getShareUrl():getBaseUrl();const a=null!==(t=e.mode)&&void 0!==t?t:getOption("mode"),s=null!==(n=e.workspace)&&void 0!==n?n:getOption("workspace"),l="single-document"===a?"doc":"lab";o=url_1.URLExt.join(o,l),s!==PageConfig.defaultWorkspace&&(o=url_1.URLExt.join(o,"workspaces",encodeURIComponent(null!==(r=getOption("workspace"))&&void 0!==r?r:PageConfig.defaultWorkspace)));const c=null!==(i=e.treePath)&&void 0!==i?i:getOption("treePath");return c&&(o=url_1.URLExt.join(o,"tree",url_1.URLExt.encodeParts(c))),o}function getWsUrl(e){let t=getOption("wsUrl");if(!t){if(0!==(e=e?url_1.URLExt.normalize(e):getBaseUrl()).indexOf("http"))return"";t="ws"+e.slice(4)}return url_1.URLExt.normalize(t)}function getNBConvertURL({path:e,format:t,download:n}){const r=url_1.URLExt.encodeParts(e),i=url_1.URLExt.join(getBaseUrl(),"nbconvert",t,r);return n?i+"?download=true":i}function getToken(){return getOption("token")||getBodyData("jupyterApiToken")}function getNotebookVersion(){const e=getOption("notebookVersion");return""===e?[0,0,0]:JSON.parse(e)}PageConfig.getOption=getOption,PageConfig.setOption=setOption,PageConfig.getBaseUrl=getBaseUrl,PageConfig.getTreeUrl=getTreeUrl,PageConfig.getShareUrl=getShareUrl,PageConfig.getTreeShareUrl=getTreeShareUrl,PageConfig.getUrl=getUrl,PageConfig.defaultWorkspace="default",PageConfig.getWsUrl=getWsUrl,PageConfig.getNBConvertURL=getNBConvertURL,PageConfig.getToken=getToken,PageConfig.getNotebookVersion=getNotebookVersion;let configData=null,Extension;function getBodyData(e){if("undefined"==typeof document||!document.body)return"";const t=document.body.dataset[e];return void 0===t?"":decodeURIComponent(t)}!function(e){function t(e){try{const t=getOption(e);if(t)return JSON.parse(t)}catch(t){console.warn(`Unable to parse ${e}.`,t)}return[]}e.deferred=t("deferredExtensions"),e.disabled=t("disabledExtensions"),e.isDeferred=function(t){const n=t.indexOf(":");let r="";return-1!==n&&(r=t.slice(0,n)),e.deferred.some(e=>e===t||r&&e===r)},e.isDisabled=function(t){const n=t.indexOf(":");let r="";return-1!==n&&(r=t.slice(0,n)),e.disabled.some(e=>e===t||r&&e===r)}}(Extension=PageConfig.Extension||(PageConfig.Extension={}))}(PageConfig=exports.PageConfig||(exports.PageConfig={}))}).call(this,__webpack_require__(61))},function(e,t){function n(e){return"number"==typeof e||(!!/^0x[0-9a-f]+$/i.test(e)||/^[-+]?(?:\d+(?:\.\d*)?|\.\d+)(e[-+]?\d+)?$/.test(e))}e.exports=function(e,t){t||(t={});var r={bools:{},strings:{},unknownFn:null};"function"==typeof t.unknown&&(r.unknownFn=t.unknown),"boolean"==typeof t.boolean&&t.boolean?r.allBools=!0:[].concat(t.boolean).filter(Boolean).forEach((function(e){r.bools[e]=!0}));var i={};Object.keys(t.alias||{}).forEach((function(e){i[e]=[].concat(t.alias[e]),i[e].forEach((function(t){i[t]=[e].concat(i[e].filter((function(e){return t!==e})))}))})),[].concat(t.string).filter(Boolean).forEach((function(e){r.strings[e]=!0,i[e]&&(r.strings[i[e]]=!0)}));var o=t.default||{},a={_:[]};Object.keys(r.bools).forEach((function(e){l(e,void 0!==o[e]&&o[e])}));var s=[];function l(e,t,o){if(!o||!r.unknownFn||function(e,t){return r.allBools&&/^--[^=]+$/.test(t)||r.strings[e]||r.bools[e]||i[e]}(e,o)||!1!==r.unknownFn(o)){var s=!r.strings[e]&&n(t)?Number(t):t;c(a,e.split("."),s),(i[e]||[]).forEach((function(e){c(a,e.split("."),s)}))}}function c(e,t,n){for(var i=e,o=0;o<t.length-1;o++){if("__proto__"===(a=t[o]))return;void 0===i[a]&&(i[a]={}),i[a]!==Object.prototype&&i[a]!==Number.prototype&&i[a]!==String.prototype||(i[a]={}),i[a]===Array.prototype&&(i[a]=[]),i=i[a]}var a;"__proto__"!==(a=t[t.length-1])&&(i!==Object.prototype&&i!==Number.prototype&&i!==String.prototype||(i={}),i===Array.prototype&&(i=[]),void 0===i[a]||r.bools[a]||"boolean"==typeof i[a]?i[a]=n:Array.isArray(i[a])?i[a].push(n):i[a]=[i[a],n])}function u(e){return i[e].some((function(e){return r.bools[e]}))}-1!==e.indexOf("--")&&(s=e.slice(e.indexOf("--")+1),e=e.slice(0,e.indexOf("--")));for(var d=0;d<e.length;d++){var h=e[d];if(/^--.+=/.test(h)){var p=h.match(/^--([^=]+)=([\s\S]*)$/),f=p[1],m=p[2];r.bools[f]&&(m="false"!==m),l(f,m,h)}else if(/^--no-.+/.test(h)){l(f=h.match(/^--no-(.+)/)[1],!1,h)}else if(/^--.+/.test(h)){f=h.match(/^--(.+)/)[1];void 0===(_=e[d+1])||/^-/.test(_)||r.bools[f]||r.allBools||i[f]&&u(f)?/^(true|false)$/.test(_)?(l(f,"true"===_,h),d++):l(f,!r.strings[f]||"",h):(l(f,_,h),d++)}else if(/^-[^-]+/.test(h)){for(var g=h.slice(1,-1).split(""),v=!1,y=0;y<g.length;y++){var _;if("-"!==(_=h.slice(y+2))){if(/[A-Za-z]/.test(g[y])&&/=/.test(_)){l(g[y],_.split("=")[1],h),v=!0;break}if(/[A-Za-z]/.test(g[y])&&/-?\d+(\.\d*)?(e-?\d+)?$/.test(_)){l(g[y],_,h),v=!0;break}if(g[y+1]&&g[y+1].match(/\W/)){l(g[y],h.slice(y+2),h),v=!0;break}l(g[y],!r.strings[g[y]]||"",h)}else l(g[y],_,h)}f=h.slice(-1)[0];v||"-"===f||(!e[d+1]||/^(-|--)[^-]/.test(e[d+1])||r.bools[f]||i[f]&&u(f)?e[d+1]&&/^(true|false)$/.test(e[d+1])?(l(f,"true"===e[d+1],h),d++):l(f,!r.strings[f]||"",h):(l(f,e[d+1],h),d++))}else if(r.unknownFn&&!1===r.unknownFn(h)||a._.push(r.strings._||!n(h)?h:Number(h)),t.stopEarly){a._.push.apply(a._,e.slice(d+1));break}}return Object.keys(o).forEach((function(e){var t,n,r;t=a,n=e.split("."),r=t,n.slice(0,-1).forEach((function(e){r=r[e]||{}})),n[n.length-1]in r||(c(a,e.split("."),o[e]),(i[e]||[]).forEach((function(t){c(a,t.split("."),o[e])})))})),t["--"]?(a["--"]=new Array,s.forEach((function(e){a["--"].push(e)}))):s.forEach((function(e){a._.push(e)})),a}},function(e,t,n){"use strict";(function(t){var r=n(615),i=n(616),o=/[\n\r\t]/g,a=/^[A-Za-z][A-Za-z0-9+-.]*:\/\//,s=/^([a-z][a-z0-9.+-]*:)?(\/\/)?([\\/]+)?([\S\s]*)/i,l=/^[a-zA-Z]:/,c=/^[ \f\n\r\t\v\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]+/;function u(e){return(e||"").toString().replace(c,"")}var d=[["#","hash"],["?","query"],function(e,t){return f(t.protocol)?e.replace(/\\/g,"/"):e},["/","pathname"],["@","auth",1],[NaN,"host",void 0,1,1],[/:(\d+)$/,"port",void 0,1],[NaN,"hostname",void 0,1,1]],h={hash:1,query:1};function p(e){var n,r=("undefined"!=typeof window?window:void 0!==t?t:"undefined"!=typeof self?self:{}).location||{},i={},o=typeof(e=e||r);if("blob:"===e.protocol)i=new g(unescape(e.pathname),{});else if("string"===o)for(n in i=new g(e,{}),h)delete i[n];else if("object"===o){for(n in e)n in h||(i[n]=e[n]);void 0===i.slashes&&(i.slashes=a.test(e.href))}return i}function f(e){return"file:"===e||"ftp:"===e||"http:"===e||"https:"===e||"ws:"===e||"wss:"===e}function m(e,t){e=(e=u(e)).replace(o,""),t=t||{};var n,r=s.exec(e),i=r[1]?r[1].toLowerCase():"",a=!!r[2],l=!!r[3],c=0;return a?l?(n=r[2]+r[3]+r[4],c=r[2].length+r[3].length):(n=r[2]+r[4],c=r[2].length):l?(n=r[3]+r[4],c=r[3].length):n=r[4],"file:"===i?c>=2&&(n=n.slice(2)):f(i)?n=r[4]:i?a&&(n=n.slice(2)):c>=2&&f(t.protocol)&&(n=r[4]),{protocol:i,slashes:a||f(i),slashesCount:c,rest:n}}function g(e,t,n){if(e=(e=u(e)).replace(o,""),!(this instanceof g))return new g(e,t,n);var a,s,c,h,v,y,_=d.slice(),b=typeof t,M=this,w=0;for("object"!==b&&"string"!==b&&(n=t,t=null),n&&"function"!=typeof n&&(n=i.parse),a=!(s=m(e||"",t=p(t))).protocol&&!s.slashes,M.slashes=s.slashes||a&&t.slashes,M.protocol=s.protocol||t.protocol||"",e=s.rest,("file:"===s.protocol&&(2!==s.slashesCount||l.test(e))||!s.slashes&&(s.protocol||s.slashesCount<2||!f(M.protocol)))&&(_[3]=[/(.*)/,"pathname"]);w<_.length;w++)"function"!=typeof(h=_[w])?(c=h[0],y=h[1],c!=c?M[y]=e:"string"==typeof c?~(v="@"===c?e.lastIndexOf(c):e.indexOf(c))&&("number"==typeof h[2]?(M[y]=e.slice(0,v),e=e.slice(v+h[2])):(M[y]=e.slice(v),e=e.slice(0,v))):(v=c.exec(e))&&(M[y]=v[1],e=e.slice(0,v.index)),M[y]=M[y]||a&&h[3]&&t[y]||"",h[4]&&(M[y]=M[y].toLowerCase())):e=h(e,M);n&&(M.query=n(M.query)),a&&t.slashes&&"/"!==M.pathname.charAt(0)&&(""!==M.pathname||""!==t.pathname)&&(M.pathname=function(e,t){if(""===e)return t;for(var n=(t||"/").split("/").slice(0,-1).concat(e.split("/")),r=n.length,i=n[r-1],o=!1,a=0;r--;)"."===n[r]?n.splice(r,1):".."===n[r]?(n.splice(r,1),a++):a&&(0===r&&(o=!0),n.splice(r,1),a--);return o&&n.unshift(""),"."!==i&&".."!==i||n.push(""),n.join("/")}(M.pathname,t.pathname)),"/"!==M.pathname.charAt(0)&&f(M.protocol)&&(M.pathname="/"+M.pathname),r(M.port,M.protocol)||(M.host=M.hostname,M.port=""),M.username=M.password="",M.auth&&(~(v=M.auth.indexOf(":"))?(M.username=M.auth.slice(0,v),M.username=encodeURIComponent(decodeURIComponent(M.username)),M.password=M.auth.slice(v+1),M.password=encodeURIComponent(decodeURIComponent(M.password))):M.username=encodeURIComponent(decodeURIComponent(M.auth)),M.auth=M.password?M.username+":"+M.password:M.username),M.origin="file:"!==M.protocol&&f(M.protocol)&&M.host?M.protocol+"//"+M.host:"null",M.href=M.toString()}g.prototype={set:function(e,t,n){var o=this;switch(e){case"query":"string"==typeof t&&t.length&&(t=(n||i.parse)(t)),o[e]=t;break;case"port":o[e]=t,r(t,o.protocol)?t&&(o.host=o.hostname+":"+t):(o.host=o.hostname,o[e]="");break;case"hostname":o[e]=t,o.port&&(t+=":"+o.port),o.host=t;break;case"host":o[e]=t,/:\d+$/.test(t)?(t=t.split(":"),o.port=t.pop(),o.hostname=t.join(":")):(o.hostname=t,o.port="");break;case"protocol":o.protocol=t.toLowerCase(),o.slashes=!n;break;case"pathname":case"hash":if(t){var a="pathname"===e?"/":"#";o[e]=t.charAt(0)!==a?a+t:t}else o[e]=t;break;case"username":case"password":o[e]=encodeURIComponent(t);break;case"auth":var s=t.indexOf(":");~s?(o.username=t.slice(0,s),o.username=encodeURIComponent(decodeURIComponent(o.username)),o.password=t.slice(s+1),o.password=encodeURIComponent(decodeURIComponent(o.password))):o.username=encodeURIComponent(decodeURIComponent(t))}for(var l=0;l<d.length;l++){var c=d[l];c[4]&&(o[c[1]]=o[c[1]].toLowerCase())}return o.auth=o.password?o.username+":"+o.password:o.username,o.origin="file:"!==o.protocol&&f(o.protocol)&&o.host?o.protocol+"//"+o.host:"null",o.href=o.toString(),o},toString:function(e){e&&"function"==typeof e||(e=i.stringify);var t,n=this,r=n.protocol;r&&":"!==r.charAt(r.length-1)&&(r+=":");var o=r+(n.protocol&&n.slashes||f(n.protocol)?"//":"");return n.username?(o+=n.username,n.password&&(o+=":"+n.password),o+="@"):n.password?(o+=":"+n.password,o+="@"):"file:"!==n.protocol&&f(n.protocol)&&!n.host&&"/"!==n.pathname&&(o+="@"),o+=n.host+n.pathname,(t="object"==typeof n.query?e(n.query):n.query)&&(o+="?"!==t.charAt(0)?"?"+t:t),n.hash&&(o+=n.hash),o}},g.extractProtocol=m,g.location=p,g.trimLeft=u,g.qs=i,e.exports=g}).call(this,n(55))},function(e,t,n){"use strict";e.exports=function(e,t){if(t=t.split(":")[0],!(e=+e))return!1;switch(t){case"http":case"ws":return 80!==e;case"https":case"wss":return 443!==e;case"ftp":return 21!==e;case"gopher":return 70!==e;case"file":return!1}return 0!==e}},function(e,t,n){"use strict";var r=Object.prototype.hasOwnProperty;function i(e){try{return decodeURIComponent(e.replace(/\+/g," "))}catch(e){return null}}function o(e){try{return encodeURIComponent(e)}catch(e){return null}}t.stringify=function(e,t){t=t||"";var n,i,a=[];for(i in"string"!=typeof t&&(t="?"),e)if(r.call(e,i)){if((n=e[i])||null!=n&&!isNaN(n)||(n=""),i=o(i),n=o(n),null===i||null===n)continue;a.push(i+"="+n)}return a.length?t+a.join("&"):""},t.parse=function(e){for(var t,n=/([^=?#&]+)=?([^&]*)/g,r={};t=n.exec(e);){var o=i(t[1]),a=i(t[2]);null===o||null===a||o in r||(r[o]=a)}return r}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.PathExt=void 0;const r=n(150);!function(e){function t(e){return 0===e.indexOf("/")&&(e=e.slice(1)),e}e.join=function(...e){const n=r.posix.join(...e);return"."===n?"":t(n)},e.basename=function(e,t){return r.posix.basename(e,t)},e.dirname=function(e){const n=t(r.posix.dirname(e));return"."===n?"":n},e.extname=function(e){return r.posix.extname(e)},e.normalize=function(e){return""===e?"":t(r.posix.normalize(e))},e.resolve=function(...e){return t(r.posix.resolve(...e))},e.relative=function(e,n){return t(r.posix.relative(e,n))},e.normalizeExtension=function(e){return e.length>0&&0!==e.indexOf(".")&&(e="."+e),e},e.removeSlash=t}(t.PathExt||(t.PathExt={}))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Text=void 0,function(e){const t="𝐚".length>1;e.jsIndexToCharIndex=function(e,n){if(t)return e;let r=e;for(let t=0;t+1<n.length&&t<e;t++){const e=n.charCodeAt(t);if(e>=55296&&e<=56319){const e=n.charCodeAt(t+1);e>=56320&&e<=57343&&(r--,t++)}}return r},e.charIndexToJsIndex=function(e,n){if(t)return e;let r=e;for(let e=0;e+1<n.length&&e<r;e++){const t=n.charCodeAt(e);if(t>=55296&&t<=56319){const t=n.charCodeAt(e+1);t>=56320&&t<=57343&&(r++,e++)}}return r},e.camelCase=function(e,t=!1){return e.replace(/^(\w)|[\s-_:]+(\w)/g,(function(e,n,r){return r?r.toUpperCase():t?n.toUpperCase():n.toLowerCase()}))},e.titleCase=function(e){return(e||"").toLowerCase().split(" ").map(e=>e.charAt(0).toUpperCase()+e.slice(1)).join(" ")}}(t.Text||(t.Text={}))},function(e,t,n){"use strict";var r=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.Time=void 0;const i=r(n(7));!function(e){e.formatHuman=function(e){i.default.locale(document.documentElement.lang);let t=i.default(e).fromNow();return t="a few seconds ago"===t?"seconds ago":t,t},e.format=function(e,t="YYYY-MM-DD HH:mm"){return i.default(e).format(t)}}(t.Time||(t.Time={}))},function(e,t,n){var r={"./af":211,"./af.js":211,"./ar":212,"./ar-dz":213,"./ar-dz.js":213,"./ar-kw":214,"./ar-kw.js":214,"./ar-ly":215,"./ar-ly.js":215,"./ar-ma":216,"./ar-ma.js":216,"./ar-sa":217,"./ar-sa.js":217,"./ar-tn":218,"./ar-tn.js":218,"./ar.js":212,"./az":219,"./az.js":219,"./be":220,"./be.js":220,"./bg":221,"./bg.js":221,"./bm":222,"./bm.js":222,"./bn":223,"./bn-bd":224,"./bn-bd.js":224,"./bn.js":223,"./bo":225,"./bo.js":225,"./br":226,"./br.js":226,"./bs":227,"./bs.js":227,"./ca":228,"./ca.js":228,"./cs":229,"./cs.js":229,"./cv":230,"./cv.js":230,"./cy":231,"./cy.js":231,"./da":232,"./da.js":232,"./de":233,"./de-at":234,"./de-at.js":234,"./de-ch":235,"./de-ch.js":235,"./de.js":233,"./dv":236,"./dv.js":236,"./el":237,"./el.js":237,"./en-au":238,"./en-au.js":238,"./en-ca":239,"./en-ca.js":239,"./en-gb":240,"./en-gb.js":240,"./en-ie":241,"./en-ie.js":241,"./en-il":242,"./en-il.js":242,"./en-in":243,"./en-in.js":243,"./en-nz":244,"./en-nz.js":244,"./en-sg":245,"./en-sg.js":245,"./eo":246,"./eo.js":246,"./es":247,"./es-do":248,"./es-do.js":248,"./es-mx":249,"./es-mx.js":249,"./es-us":250,"./es-us.js":250,"./es.js":247,"./et":251,"./et.js":251,"./eu":252,"./eu.js":252,"./fa":253,"./fa.js":253,"./fi":254,"./fi.js":254,"./fil":255,"./fil.js":255,"./fo":256,"./fo.js":256,"./fr":257,"./fr-ca":258,"./fr-ca.js":258,"./fr-ch":259,"./fr-ch.js":259,"./fr.js":257,"./fy":260,"./fy.js":260,"./ga":261,"./ga.js":261,"./gd":262,"./gd.js":262,"./gl":263,"./gl.js":263,"./gom-deva":264,"./gom-deva.js":264,"./gom-latn":265,"./gom-latn.js":265,"./gu":266,"./gu.js":266,"./he":267,"./he.js":267,"./hi":268,"./hi.js":268,"./hr":269,"./hr.js":269,"./hu":270,"./hu.js":270,"./hy-am":271,"./hy-am.js":271,"./id":272,"./id.js":272,"./is":273,"./is.js":273,"./it":274,"./it-ch":275,"./it-ch.js":275,"./it.js":274,"./ja":276,"./ja.js":276,"./jv":277,"./jv.js":277,"./ka":278,"./ka.js":278,"./kk":279,"./kk.js":279,"./km":280,"./km.js":280,"./kn":281,"./kn.js":281,"./ko":282,"./ko.js":282,"./ku":283,"./ku.js":283,"./ky":284,"./ky.js":284,"./lb":285,"./lb.js":285,"./lo":286,"./lo.js":286,"./lt":287,"./lt.js":287,"./lv":288,"./lv.js":288,"./me":289,"./me.js":289,"./mi":290,"./mi.js":290,"./mk":291,"./mk.js":291,"./ml":292,"./ml.js":292,"./mn":293,"./mn.js":293,"./mr":294,"./mr.js":294,"./ms":295,"./ms-my":296,"./ms-my.js":296,"./ms.js":295,"./mt":297,"./mt.js":297,"./my":298,"./my.js":298,"./nb":299,"./nb.js":299,"./ne":300,"./ne.js":300,"./nl":301,"./nl-be":302,"./nl-be.js":302,"./nl.js":301,"./nn":303,"./nn.js":303,"./oc-lnc":304,"./oc-lnc.js":304,"./pa-in":305,"./pa-in.js":305,"./pl":306,"./pl.js":306,"./pt":307,"./pt-br":308,"./pt-br.js":308,"./pt.js":307,"./ro":309,"./ro.js":309,"./ru":310,"./ru.js":310,"./sd":311,"./sd.js":311,"./se":312,"./se.js":312,"./si":313,"./si.js":313,"./sk":314,"./sk.js":314,"./sl":315,"./sl.js":315,"./sq":316,"./sq.js":316,"./sr":317,"./sr-cyrl":318,"./sr-cyrl.js":318,"./sr.js":317,"./ss":319,"./ss.js":319,"./sv":320,"./sv.js":320,"./sw":321,"./sw.js":321,"./ta":322,"./ta.js":322,"./te":323,"./te.js":323,"./tet":324,"./tet.js":324,"./tg":325,"./tg.js":325,"./th":326,"./th.js":326,"./tk":327,"./tk.js":327,"./tl-ph":328,"./tl-ph.js":328,"./tlh":329,"./tlh.js":329,"./tr":330,"./tr.js":330,"./tzl":331,"./tzl.js":331,"./tzm":332,"./tzm-latn":333,"./tzm-latn.js":333,"./tzm.js":332,"./ug-cn":334,"./ug-cn.js":334,"./uk":335,"./uk.js":335,"./ur":336,"./ur.js":336,"./uz":337,"./uz-latn":338,"./uz-latn.js":338,"./uz.js":337,"./vi":339,"./vi.js":339,"./x-pseudo":340,"./x-pseudo.js":340,"./yo":341,"./yo.js":341,"./zh-cn":342,"./zh-cn.js":342,"./zh-hk":343,"./zh-hk.js":343,"./zh-mo":344,"./zh-mo.js":344,"./zh-tw":345,"./zh-tw.js":345};function i(e){var t=o(e);return n(t)}function o(e){if(!n.o(r,e)){var t=new Error("Cannot find module '"+e+"'");throw t.code="MODULE_NOT_FOUND",t}return r[e]}i.keys=function(){return Object.keys(r)},i.resolve=o,e.exports=i,i.id=620},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.validateCheckpointModel=t.validateContentsModel=void 0;const r=n(119);t.validateContentsModel=function(e){r.validateProperty(e,"name","string"),r.validateProperty(e,"path","string"),r.validateProperty(e,"type","string"),r.validateProperty(e,"created","string"),r.validateProperty(e,"last_modified","string"),r.validateProperty(e,"mimetype","object"),r.validateProperty(e,"content","object"),r.validateProperty(e,"format","object")},t.validateCheckpointModel=function(e){r.validateProperty(e,"id","string"),r.validateProperty(e,"last_modified","string")}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t){},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.default=WebSocket},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.KernelManager=void 0;const r=n(2),i=n(64),o=n(4),a=n(38),s=n(121),l=n(152),c=n(192);class u extends s.BaseManager{constructor(e={}){var t;super(e),this._isReady=!1,this._kernelConnections=new Set,this._models=new Map,this._runningChanged=new o.Signal(this),this._connectionFailure=new o.Signal(this),this._pollModels=new i.Poll({auto:!1,factory:()=>this.requestRunning(),frequency:{interval:1e4,backoff:!0,max:3e5},name:"@jupyterlab/services:KernelManager#models",standby:null!==(t=e.standby)&&void 0!==t?t:"when-hidden"}),this._ready=(async()=>{await this._pollModels.start(),await this._pollModels.tick,this._isReady=!0})()}get isReady(){return this._isReady}get ready(){return this._ready}get runningChanged(){return this._runningChanged}get connectionFailure(){return this._connectionFailure}dispose(){this.isDisposed||(this._models.clear(),this._kernelConnections.forEach(e=>e.dispose()),this._pollModels.dispose(),super.dispose())}connectTo(e){var t;const{id:n}=e.model;let r=null===(t=e.handleComms)||void 0===t||t;if(void 0===e.handleComms)for(const e of this._kernelConnections)if(e.id===n&&e.handleComms){r=!1;break}const i=new c.KernelConnection(Object.assign(Object.assign({handleComms:r},e),{serverSettings:this.serverSettings}));return this._onStarted(i),this._models.has(n)||this.refreshRunning().catch(()=>{}),i}running(){return r.iter([...this._models.values()])}async refreshRunning(){await this._pollModels.refresh(),await this._pollModels.tick}async startNew(e={},t={}){const n=await l.startNew(e,this.serverSettings);return this.connectTo(Object.assign(Object.assign({},t),{model:n}))}async shutdown(e){await l.shutdownKernel(e,this.serverSettings),await this.refreshRunning()}async shutdownAll(){await this.refreshRunning(),await Promise.all([...this._models.keys()].map(e=>l.shutdownKernel(e,this.serverSettings))),await this.refreshRunning()}async findById(e){return this._models.has(e)||await this.refreshRunning(),this._models.get(e)}async requestRunning(){var e,t;let n;try{n=await l.listRunning(this.serverSettings)}catch(n){throw(n instanceof a.ServerConnection.NetworkError||503===(null===(e=n.response)||void 0===e?void 0:e.status)||424===(null===(t=n.response)||void 0===t?void 0:t.status))&&this._connectionFailure.emit(n),n}this.isDisposed||this._models.size===n.length&&r.every(n,e=>{const t=this._models.get(e.id);return!!t&&t.name===e.name})||(this._models=new Map(n.map(e=>[e.id,e])),this._kernelConnections.forEach(e=>{this._models.has(e.id)||e.handleShutdown()}),this._runningChanged.emit(n))}_onStarted(e){this._kernelConnections.add(e),e.statusChanged.connect(this._onStatusChanged,this),e.disposed.connect(this._onDisposed,this)}_onDisposed(e){this._kernelConnections.delete(e),this.refreshRunning().catch(()=>{})}_onStatusChanged(e,t){"dead"===t&&this.refreshRunning().catch(()=>{})}}t.KernelManager=u},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0}),t.CommHandler=void 0;const a=n(27),s=o(n(120));class l extends a.DisposableDelegate{constructor(e,t,n,r){super(r),this._target="",this._id="",this._id=t,this._target=e,this._kernel=n}get commId(){return this._id}get targetName(){return this._target}get onClose(){return this._onClose}set onClose(e){this._onClose=e}get onMsg(){return this._onMsg}set onMsg(e){this._onMsg=e}open(e,t,n=[]){if(this.isDisposed||this._kernel.isDisposed)throw new Error("Cannot open");const r=s.createMessage({msgType:"comm_open",channel:"shell",username:this._kernel.username,session:this._kernel.clientId,content:{comm_id:this._id,target_name:this._target,data:null!=e?e:{}},metadata:t,buffers:n});return this._kernel.sendShellMessage(r,!1,!0)}send(e,t,n=[],r=!0){if(this.isDisposed||this._kernel.isDisposed)throw new Error("Cannot send");const i=s.createMessage({msgType:"comm_msg",channel:"shell",username:this._kernel.username,session:this._kernel.clientId,content:{comm_id:this._id,data:e},metadata:t,buffers:n});return this._kernel.sendShellMessage(i,!1,r)}close(e,t,n=[]){if(this.isDisposed||this._kernel.isDisposed)throw new Error("Cannot close");const r=s.createMessage({msgType:"comm_close",channel:"shell",username:this._kernel.username,session:this._kernel.clientId,content:{comm_id:this._id,data:null!=e?e:{}},metadata:t,buffers:n}),i=this._kernel.sendShellMessage(r,!1,!0),o=this._onClose;if(o){o(s.createMessage({msgType:"comm_close",channel:"iopub",username:this._kernel.username,session:this._kernel.clientId,content:{comm_id:this._id,data:null!=e?e:{}},metadata:t,buffers:n}))}return this.dispose(),i}}t.CommHandler=l},function(e,t,n){"use strict";(function(e){var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0}),t.KernelShellFutureHandler=t.KernelControlFutureHandler=t.KernelFutureHandler=void 0;const a=n(6),s=n(27),l=o(n(120));class c extends s.DisposableDelegate{constructor(e,t,n,r,i){super(e),this._status=0,this._stdin=u.noOp,this._iopub=u.noOp,this._reply=u.noOp,this._done=new a.PromiseDelegate,this._hooks=new u.HookList,this._disposeOnDone=!0,this._msg=t,n||this._setFlag(u.KernelFutureFlag.GotReply),this._disposeOnDone=r,this._kernel=i}get msg(){return this._msg}get done(){return this._done.promise}get onReply(){return this._reply}set onReply(e){this._reply=e}get onIOPub(){return this._iopub}set onIOPub(e){this._iopub=e}get onStdin(){return this._stdin}set onStdin(e){this._stdin=e}registerMessageHook(e){if(this.isDisposed)throw new Error("Kernel future is disposed");this._hooks.add(e)}removeMessageHook(e){this.isDisposed||this._hooks.remove(e)}sendInputReply(e){this._kernel.sendInputReply(e)}dispose(){this._stdin=u.noOp,this._iopub=u.noOp,this._reply=u.noOp,this._hooks=null,this._testFlag(u.KernelFutureFlag.IsDone)||(this._done.promise.catch(()=>{}),this._done.reject(new Error(`Canceled future for ${this.msg.header.msg_type} message before replies were done`))),super.dispose()}async handleMsg(e){switch(e.channel){case"control":case"shell":e.channel===this.msg.channel&&e.parent_header.msg_id===this.msg.header.msg_id&&await this._handleReply(e);break;case"stdin":await this._handleStdin(e);break;case"iopub":await this._handleIOPub(e)}}async _handleReply(e){const t=this._reply;t&&await t(e),this._replyMsg=e,this._setFlag(u.KernelFutureFlag.GotReply),this._testFlag(u.KernelFutureFlag.GotIdle)&&this._handleDone()}async _handleStdin(e){this._kernel.hasPendingInput=!0;const t=this._stdin;t&&await t(e)}async _handleIOPub(e){const t=await this._hooks.process(e),n=this._iopub;t&&n&&await n(e),l.isStatusMsg(e)&&"idle"===e.content.execution_state&&(this._setFlag(u.KernelFutureFlag.GotIdle),this._testFlag(u.KernelFutureFlag.GotReply)&&this._handleDone())}_handleDone(){this._testFlag(u.KernelFutureFlag.IsDone)||(this._setFlag(u.KernelFutureFlag.IsDone),this._done.resolve(this._replyMsg),this._disposeOnDone&&this.dispose())}_testFlag(e){return 0!=(this._status&e)}_setFlag(e){this._status|=e}}t.KernelFutureHandler=c;t.KernelControlFutureHandler=class extends c{};var u;t.KernelShellFutureHandler=class extends c{},function(t){t.noOp=()=>{};const n="function"==typeof requestAnimationFrame?requestAnimationFrame:e;let r;t.HookList=class{constructor(){this._hooks=[]}add(e){this.remove(e),this._hooks.push(e)}remove(e){const t=this._hooks.indexOf(e);t>=0&&(this._hooks[t]=null,this._scheduleCompact())}async process(e){await this._processing;const t=new a.PromiseDelegate;let n;this._processing=t.promise;for(let r=this._hooks.length-1;r>=0;r--){const i=this._hooks[r];if(null!==i){try{n=await i(e)}catch(e){n=!0,console.error(e)}if(!1===n)return t.resolve(void 0),!1}}return t.resolve(void 0),!0}_scheduleCompact(){this._compactScheduled||(this._compactScheduled=!0,n(()=>{this._processing=this._processing.then(()=>{this._compactScheduled=!1,this._compact()})}))}_compact(){let e=0;for(let t=0,n=this._hooks.length;t<n;t++){const n=this._hooks[t];null===this._hooks[t]?e++:this._hooks[t-e]=n}this._hooks.length-=e}},function(e){e[e.GotReply=1]="GotReply",e[e.GotIdle=2]="GotIdle",e[e.IsDone=4]="IsDone",e[e.DisposeOnDone=8]="DisposeOnDone"}(r=t.KernelFutureFlag||(t.KernelFutureFlag={}))}(u||(u={}))}).call(this,n(90).setImmediate)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.serialize=t.deserialize=void 0,t.deserialize=function(e){let t;return t="string"==typeof e?JSON.parse(e):function(e){const t=new DataView(e),n=t.getUint32(0),r=[];if(n<2)throw new Error("Invalid incoming Kernel Message");for(let e=1;e<=n;e++)r.push(t.getUint32(4*e));const i=new Uint8Array(e.slice(r[0],r[1])),o=JSON.parse(new TextDecoder("utf8").decode(i));o.buffers=[];for(let t=1;t<n;t++){const n=r[t],i=r[t+1]||e.byteLength;o.buffers.push(new DataView(e.slice(n,i)))}return o}(e),t},t.serialize=function(e){var t;let n;return n=(null===(t=e.buffers)||void 0===t?void 0:t.length)?function(e){const t=[],n=[],r=new TextEncoder;let i=[];void 0!==e.buffers&&(i=e.buffers,delete e.buffers);const o=r.encode(JSON.stringify(e));n.push(o.buffer);for(let e=0;e<i.length;e++){const t=i[e];n.push(ArrayBuffer.isView(t)?t.buffer:t)}const a=n.length;t.push(4*(a+1));for(let e=0;e+1<n.length;e++)t.push(t[t.length-1]+n[e].byteLength);const s=new Uint8Array(t[t.length-1]+n[n.length-1].byteLength),l=new DataView(s.buffer);l.setUint32(0,a);for(let e=0;e<t.length;e++)l.setUint32(4*(e+1),t[e]);for(let e=0;e<n.length;e++)s.set(new Uint8Array(n[e]),t[e]);return s.buffer}(e):JSON.stringify(e),n}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.validateSpecModels=t.validateSpecModel=void 0;const r=n(119);function i(e){const t=e.spec;if(!t)throw new Error("Invalid kernel spec");r.validateProperty(e,"name","string"),r.validateProperty(e,"resources","object"),r.validateProperty(t,"language","string"),r.validateProperty(t,"display_name","string"),r.validateProperty(t,"argv","array");let n=null;t.hasOwnProperty("metadata")&&(r.validateProperty(t,"metadata","object"),n=t.metadata);let i=null;return t.hasOwnProperty("env")&&(r.validateProperty(t,"env","object"),i=t.env),{name:e.name,resources:e.resources,language:t.language,display_name:t.display_name,argv:t.argv,metadata:n,env:i}}t.validateSpecModel=i,t.validateSpecModels=function(e){if(!e.hasOwnProperty("kernelspecs"))throw new Error("No kernelspecs found");let t=Object.keys(e.kernelspecs);const n=Object.create(null);let r=e.default;for(let r=0;r<t.length;r++){const o=e.kernelspecs[t[r]];try{n[t[r]]=i(o)}catch(e){console.warn("Removing errant kernel spec: "+t[r])}}if(t=Object.keys(n),!t.length)throw new Error("No valid kernelspecs found");return r&&"string"==typeof r&&r in n||(r=t[0],console.warn(`Default kernel not found, using '${t[0]}'`)),{default:r,kernelspecs:n}}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t};Object.defineProperty(t,"__esModule",{value:!0}),t.KernelSpecManager=void 0;const a=n(6),s=n(64),l=n(4),c=o(n(348)),u=n(121);class d extends u.BaseManager{constructor(e={}){var t;super(e),this._isReady=!1,this._connectionFailure=new l.Signal(this),this._specs=null,this._specsChanged=new l.Signal(this),this._ready=Promise.all([this.requestSpecs()]).then(e=>{}).catch(e=>{}).then(()=>{this.isDisposed||(this._isReady=!0)}),this._pollSpecs=new s.Poll({auto:!1,factory:()=>this.requestSpecs(),frequency:{interval:61e3,backoff:!0,max:3e5},name:"@jupyterlab/services:KernelSpecManager#specs",standby:null!==(t=e.standby)&&void 0!==t?t:"when-hidden"}),this.ready.then(()=>{this._pollSpecs.start()})}get isReady(){return this._isReady}get ready(){return this._ready}get specs(){return this._specs}get specsChanged(){return this._specsChanged}get connectionFailure(){return this._connectionFailure}dispose(){this._pollSpecs.dispose(),super.dispose()}async refreshSpecs(){await this._pollSpecs.refresh(),await this._pollSpecs.tick}async requestSpecs(){const e=await c.getSpecs(this.serverSettings);this.isDisposed||a.JSONExt.deepEqual(e,this._specs)||(this._specs=e,this._specsChanged.emit(e))}}t.KernelSpecManager=d},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ServiceManager=void 0;const r=n(4),i=n(633),o=n(349),a=n(346),s=n(154),l=n(350),c=n(351),u=n(352),d=n(56),h=n(353),p=n(347);t.ServiceManager=class{constructor(e={}){var t,n;this._isDisposed=!1,this._connectionFailure=new r.Signal(this),this._isReady=!1;const f=e.defaultDrive,m=null!==(t=e.serverSettings)&&void 0!==t?t:d.ServerConnection.makeSettings(),g={defaultDrive:f,serverSettings:m,standby:null!==(n=e.standby)&&void 0!==n?n:"when-hidden"},v=new p.KernelManager(g);this.serverSettings=m,this.contents=new a.ContentsManager(g),this.sessions=new l.SessionManager(Object.assign(Object.assign({},g),{kernelManager:v})),this.settings=new c.SettingManager(g),this.terminals=new u.TerminalManager(g),this.builder=new i.BuildManager(g),this.workspaces=new h.WorkspaceManager(g),this.nbconvert=new o.NbConvertManager(g),this.kernelspecs=new s.KernelSpecManager(g),this.kernelspecs.connectionFailure.connect(this._onConnectionFailure,this),this.sessions.connectionFailure.connect(this._onConnectionFailure,this),this.terminals.connectionFailure.connect(this._onConnectionFailure,this);const y=[this.sessions.ready,this.kernelspecs.ready];this.terminals.isAvailable()&&y.push(this.terminals.ready),this._readyPromise=Promise.all(y).then(()=>{this._isReady=!0})}get connectionFailure(){return this._connectionFailure}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,r.Signal.clearData(this),this.contents.dispose(),this.sessions.dispose(),this.terminals.dispose())}get isReady(){return this._isReady}get ready(){return this._readyPromise}_onConnectionFailure(e,t){this._connectionFailure.emit(t)}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.BuildManager=void 0;const r=n(12),i=n(56);t.BuildManager=class{constructor(e={}){var t;this._url="",this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:i.ServerConnection.makeSettings();const{baseUrl:n,appUrl:o}=this.serverSettings;this._url=r.URLExt.join(n,o,"api/build")}get isAvailable(){return"true"===r.PageConfig.getOption("buildAvailable").toLowerCase()}get shouldCheck(){return"true"===r.PageConfig.getOption("buildCheck").toLowerCase()}getStatus(){const{_url:e,serverSettings:t}=this;return i.ServerConnection.makeRequest(e,{},t).then(e=>{if(200!==e.status)throw new i.ServerConnection.ResponseError(e);return e.json()}).then(e=>{if("string"!=typeof e.status)throw new Error("Invalid data");if("string"!=typeof e.message)throw new Error("Invalid data");return e})}build(){const{_url:e,serverSettings:t}=this;return i.ServerConnection.makeRequest(e,{method:"POST"},t).then(e=>{if(400===e.status)throw new i.ServerConnection.ResponseError(e,"Build aborted");if(200!==e.status){const t=`Build failed with ${e.status}.\n\n        If you are experiencing the build failure after installing an extension (or trying to include previously installed extension after updating JupyterLab) please check the extension repository for new installation instructions as many extensions migrated to the prebuilt extensions system which no longer requires rebuilding JupyterLab (but uses a different installation procedure, typically involving a package manager such as 'pip' or 'conda').\n\n        If you specifically intended to install a source extension, please run 'jupyter lab build' on the server for full output.`;throw new i.ServerConnection.ResponseError(e,t)}})}cancel(){const{_url:e,serverSettings:t}=this;return i.ServerConnection.makeRequest(e,{method:"DELETE"},t).then(e=>{if(204!==e.status)throw new i.ServerConnection.ResponseError(e)})}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.validateModels=t.updateLegacySessionModel=t.validateModel=void 0;const r=n(153),i=n(119);function o(e){i.validateProperty(e,"id","string"),i.validateProperty(e,"type","string"),i.validateProperty(e,"name","string"),i.validateProperty(e,"path","string"),i.validateProperty(e,"kernel","object"),r.validateModel(e.kernel)}t.validateModel=o,t.updateLegacySessionModel=function(e){void 0===e.path&&void 0!==e.notebook&&(e.path=e.notebook.path,e.type="notebook",e.name="")},t.validateModels=function(e){if(!Array.isArray(e))throw new Error("Invalid session list");e.forEach(e=>o(e))}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.SessionManager=void 0;const r=n(2),i=n(64),o=n(4),a=n(56),s=n(121),l=n(637),c=n(155);class u extends s.BaseManager{constructor(e){var t;super(e),this._isReady=!1,this._sessionConnections=new Set,this._models=new Map,this._runningChanged=new o.Signal(this),this._connectionFailure=new o.Signal(this),this._connectToKernel=e=>this._kernelManager.connectTo(e),this._kernelManager=e.kernelManager,this._pollModels=new i.Poll({auto:!1,factory:()=>this.requestRunning(),frequency:{interval:1e4,backoff:!0,max:3e5},name:"@jupyterlab/services:SessionManager#models",standby:null!==(t=e.standby)&&void 0!==t?t:"when-hidden"}),this._ready=(async()=>{await this._pollModels.start(),await this._pollModels.tick,await this._kernelManager.ready,this._isReady=!0})()}get isReady(){return this._isReady}get ready(){return this._ready}get runningChanged(){return this._runningChanged}get connectionFailure(){return this._connectionFailure}dispose(){this.isDisposed||(this._models.clear(),this._sessionConnections.forEach(e=>e.dispose()),this._pollModels.dispose(),super.dispose())}connectTo(e){const t=new l.SessionConnection(Object.assign(Object.assign({},e),{connectToKernel:this._connectToKernel,serverSettings:this.serverSettings}));return this._onStarted(t),this._models.has(e.model.id)||this.refreshRunning().catch(()=>{}),t}running(){return r.iter([...this._models.values()])}async refreshRunning(){await this._pollModels.refresh(),await this._pollModels.tick}async startNew(e,t={}){const n=await c.startSession(e,this.serverSettings);return await this.refreshRunning(),this.connectTo(Object.assign(Object.assign({},t),{model:n}))}async shutdown(e){await c.shutdownSession(e,this.serverSettings),await this.refreshRunning()}async shutdownAll(){await this.refreshRunning(),await Promise.all([...this._models.keys()].map(e=>c.shutdownSession(e,this.serverSettings))),await this.refreshRunning()}async stopIfNeeded(e){try{const t=(await c.listRunning(this.serverSettings)).filter(t=>t.path===e);if(1===t.length){const e=t[0].id;await this.shutdown(e)}}catch(e){}}async findById(e){return this._models.has(e)||await this.refreshRunning(),this._models.get(e)}async findByPath(e){for(const t of this._models.values())if(t.path===e)return t;await this.refreshRunning();for(const t of this._models.values())if(t.path===e)return t}async requestRunning(){var e,t;let n;try{n=await c.listRunning(this.serverSettings)}catch(n){throw(n instanceof a.ServerConnection.NetworkError||503===(null===(e=n.response)||void 0===e?void 0:e.status)||424===(null===(t=n.response)||void 0===t?void 0:t.status))&&this._connectionFailure.emit(n),n}this.isDisposed||this._models.size===n.length&&r.every(n,e=>{var t,n,r,i;const o=this._models.get(e.id);return!!o&&((null===(t=o.kernel)||void 0===t?void 0:t.id)===(null===(n=e.kernel)||void 0===n?void 0:n.id)&&(null===(r=o.kernel)||void 0===r?void 0:r.name)===(null===(i=e.kernel)||void 0===i?void 0:i.name)&&o.name===e.name&&o.path===e.path&&o.type===e.type)})||(this._models=new Map(n.map(e=>[e.id,e])),this._sessionConnections.forEach(e=>{this._models.has(e.id)?e.update(this._models.get(e.id)):e.dispose()}),this._runningChanged.emit(n))}_onStarted(e){this._sessionConnections.add(e),e.disposed.connect(this._onDisposed,this),e.propertyChanged.connect(this._onChanged,this),e.kernelChanged.connect(this._onChanged,this)}_onDisposed(e){this._sessionConnections.delete(e),this.refreshRunning().catch(()=>{})}_onChanged(){this.refreshRunning().catch(()=>{})}}t.SessionManager=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.SessionConnection=void 0;const r=n(4),i=n(38),o=n(155),a=n(6);t.SessionConnection=class{constructor(e){var t,n,o,s;this._id="",this._path="",this._name="",this._type="",this._kernel=null,this._isDisposed=!1,this._disposed=new r.Signal(this),this._kernelChanged=new r.Signal(this),this._statusChanged=new r.Signal(this),this._connectionStatusChanged=new r.Signal(this),this._pendingInput=new r.Signal(this),this._iopubMessage=new r.Signal(this),this._unhandledMessage=new r.Signal(this),this._anyMessage=new r.Signal(this),this._propertyChanged=new r.Signal(this),this._id=e.model.id,this._name=e.model.name,this._path=e.model.path,this._type=e.model.type,this._username=null!==(t=e.username)&&void 0!==t?t:"",this._clientId=null!==(n=e.clientId)&&void 0!==n?n:a.UUID.uuid4(),this._connectToKernel=e.connectToKernel,this._kernelConnectionOptions=null!==(o=e.kernelConnectionOptions)&&void 0!==o?o:{},this.serverSettings=null!==(s=e.serverSettings)&&void 0!==s?s:i.ServerConnection.makeSettings(),this.setupKernel(e.model.kernel)}get disposed(){return this._disposed}get kernelChanged(){return this._kernelChanged}get statusChanged(){return this._statusChanged}get connectionStatusChanged(){return this._connectionStatusChanged}get pendingInput(){return this._pendingInput}get iopubMessage(){return this._iopubMessage}get unhandledMessage(){return this._unhandledMessage}get anyMessage(){return this._anyMessage}get propertyChanged(){return this._propertyChanged}get id(){return this._id}get kernel(){return this._kernel}get path(){return this._path}get type(){return this._type}get name(){return this._name}get model(){return{id:this.id,kernel:this.kernel&&{id:this.kernel.id,name:this.kernel.name},path:this._path,type:this._type,name:this._name}}get isDisposed(){return this._isDisposed}update(e){const t=this.model;if(this._path=e.path,this._name=e.name,this._type=e.type,null===this._kernel&&null!==e.kernel||null!==this._kernel&&null===e.kernel||null!==this._kernel&&null!==e.kernel&&this._kernel.id!==e.kernel.id){null!==this._kernel&&this._kernel.dispose();const t=this._kernel||null;this.setupKernel(e.kernel);const n=this._kernel||null;this._kernelChanged.emit({name:"kernel",oldValue:t,newValue:n})}this._handleModelChange(t)}dispose(){if(!this.isDisposed){if(this._isDisposed=!0,this._disposed.emit(),this._kernel){this._kernel.dispose();const e=this._kernel;this._kernel=null;const t=this._kernel;this._kernelChanged.emit({name:"kernel",oldValue:e,newValue:t})}r.Signal.clearData(this)}}async setPath(e){if(this.isDisposed)throw new Error("Session is disposed");await this._patch({path:e})}async setName(e){if(this.isDisposed)throw new Error("Session is disposed");await this._patch({name:e})}async setType(e){if(this.isDisposed)throw new Error("Session is disposed");await this._patch({type:e})}async changeKernel(e){if(this.isDisposed)throw new Error("Session is disposed");return await this._patch({kernel:e}),this.kernel}async shutdown(){if(this.isDisposed)throw new Error("Session is disposed");await o.shutdownSession(this.id,this.serverSettings),this.dispose()}setupKernel(e){if(null===e)return void(this._kernel=null);const t=this._connectToKernel(Object.assign(Object.assign({},this._kernelConnectionOptions),{model:e,username:this._username,clientId:this._clientId,serverSettings:this.serverSettings}));this._kernel=t,t.statusChanged.connect(this.onKernelStatus,this),t.connectionStatusChanged.connect(this.onKernelConnectionStatus,this),t.pendingInput.connect(this.onPendingInput,this),t.unhandledMessage.connect(this.onUnhandledMessage,this),t.iopubMessage.connect(this.onIOPubMessage,this),t.anyMessage.connect(this.onAnyMessage,this)}onKernelStatus(e,t){this._statusChanged.emit(t)}onKernelConnectionStatus(e,t){this._connectionStatusChanged.emit(t)}onPendingInput(e,t){this._pendingInput.emit(t)}onIOPubMessage(e,t){this._iopubMessage.emit(t)}onUnhandledMessage(e,t){this._unhandledMessage.emit(t)}onAnyMessage(e,t){this._anyMessage.emit(t)}async _patch(e){const t=await o.updateSession(Object.assign(Object.assign({},e),{id:this._id}),this.serverSettings);return this.update(t),t}_handleModelChange(e){e.name!==this._name&&this._propertyChanged.emit("name"),e.type!==this._type&&this._propertyChanged.emit("type"),e.path!==this._path&&this._propertyChanged.emit("path")}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.DataConnector=void 0;t.DataConnector=class{async list(e){throw new Error("DataConnector#list method has not been implemented.")}async remove(e){throw new Error("DataConnector#remove method has not been implemented.")}async save(e,t){throw new Error("DataConnector#save method has not been implemented.")}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.RestorablePool=void 0;const r=n(6),i=n(43),o=n(4);var a;t.RestorablePool=class{constructor(e){this._added=new o.Signal(this),this._current=null,this._currentChanged=new o.Signal(this),this._hasRestored=!1,this._isDisposed=!1,this._objects=new Set,this._restore=null,this._restored=new r.PromiseDelegate,this._updated=new o.Signal(this),this.namespace=e.namespace}get added(){return this._added}get current(){return this._current}set current(e){this._current!==e&&null!==e&&this._objects.has(e)&&(this._current=e,this._currentChanged.emit(this._current))}get currentChanged(){return this._currentChanged}get isDisposed(){return this._isDisposed}get restored(){return this._restored.promise}get size(){return this._objects.size}get updated(){return this._updated}async add(e){var t,n;if(e.isDisposed){const t="A disposed object cannot be added.";throw console.warn(t,e),new Error(t)}if(this._objects.has(e)){const t="This object already exists in the pool.";throw console.warn(t,e),new Error(t)}if(this._objects.add(e),e.disposed.connect(this._onInstanceDisposed,this),!a.injectedProperty.get(e)){if(this._restore){const{connector:r}=this._restore,i=this._restore.name(e);if(i){const o=`${this.namespace}:${i}`,s=null===(n=(t=this._restore).args)||void 0===n?void 0:n.call(t,e);a.nameProperty.set(e,o),await r.save(o,{data:s})}}this._added.emit(e)}}dispose(){this.isDisposed||(this._current=null,this._isDisposed=!0,this._objects.clear(),o.Signal.clearData(this))}find(e){const t=this._objects.values();for(const n of t)if(e(n))return n}forEach(e){this._objects.forEach(e)}filter(e){const t=[];return this.forEach(n=>{e(n)&&t.push(n)}),t}inject(e){return a.injectedProperty.set(e,!0),this.add(e)}has(e){return this._objects.has(e)}async restore(e){if(this._hasRestored)throw new Error("This pool has already been restored.");this._hasRestored=!0;const{command:t,connector:n,registry:r,when:i}=e,o=this.namespace,a=i?[n.list(o)].concat(i):[n.list(o)];this._restore=e;const[s]=await Promise.all(a),l=await Promise.all(s.ids.map(async(e,i)=>{const o=s.values[i],a=o&&o.data;return void 0===a?n.remove(e):r.execute(t,a).catch(()=>n.remove(e))}));return this._restored.resolve(),l}async save(e){var t,n;const r=a.injectedProperty.get(e);if(!this._restore||!this.has(e)||r)return;const{connector:i}=this._restore,o=this._restore.name(e),s=a.nameProperty.get(e),l=o?`${this.namespace}:${o}`:"";if(s&&s!==l&&await i.remove(s),a.nameProperty.set(e,l),l){const r=null===(n=(t=this._restore).args)||void 0===n?void 0:n.call(t,e);await i.save(l,{data:r})}s!==l&&this._updated.emit(e)}_onInstanceDisposed(e){if(this._objects.delete(e),e===this._current&&(this._current=null,this._currentChanged.emit(this._current)),a.injectedProperty.get(e))return;if(!this._restore)return;const{connector:t}=this._restore,n=a.nameProperty.get(e);n&&t.remove(n)}},function(e){e.injectedProperty=new i.AttachedProperty({name:"injected",create:()=>!1}),e.nameProperty=new i.AttachedProperty({name:"name",create:()=>""})}(a||(a={}))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.StateDB=void 0;const r=n(4);class i{constructor(e={}){this._changed=new r.Signal(this);const{connector:t,transform:n}=e;this._connector=t||new i.Connector,this._ready=n?n.then(e=>{const{contents:t,type:n}=e;switch(n){case"cancel":return;case"clear":return this._clear();case"merge":return this._merge(t||{});case"overwrite":return this._overwrite(t||{});default:return}}):Promise.resolve(void 0)}get changed(){return this._changed}async clear(){await this._ready,await this._clear()}async fetch(e){return await this._ready,this._fetch(e)}async list(e){return await this._ready,this._list(e)}async remove(e){await this._ready,await this._remove(e),this._changed.emit({id:e,type:"remove"})}async save(e,t){await this._ready,await this._save(e,t),this._changed.emit({id:e,type:"save"})}async toJSON(){await this._ready;const{ids:e,values:t}=await this._list();return t.reduce((t,n,r)=>(t[e[r]]=n,t),{})}async _clear(){await Promise.all((await this._list()).ids.map(e=>this._remove(e)))}async _fetch(e){const t=await this._connector.fetch(e);if(t)return JSON.parse(t).v}async _list(e=""){const{ids:t,values:n}=await this._connector.list(e);return{ids:t,values:n.map(e=>JSON.parse(e).v)}}async _merge(e){await Promise.all(Object.keys(e).map(t=>e[t]&&this._save(t,e[t])))}async _overwrite(e){await this._clear(),await this._merge(e)}async _remove(e){return this._connector.remove(e)}async _save(e,t){return this._connector.save(e,JSON.stringify({v:t}))}}t.StateDB=i,function(e){e.Connector=class{constructor(){this._storage={}}async fetch(e){return this._storage[e]}async list(e=""){return Object.keys(this._storage).reduce((t,n)=>(""!==e&&e!==n.split(":")[0]||(t.ids.push(n),t.values.push(this._storage[n])),t),{ids:[],values:[]})}async remove(e){delete this._storage[e]}async save(e,t){this._storage[e]=t}}}(i=t.StateDB||(t.StateDB={}))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.IStateDB=void 0;const r=n(6);t.IStateDB=new r.Token("@jupyterlab/coreutils:IStateDB")},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.isAvailable=void 0;const r=n(122);Object.defineProperty(t,"isAvailable",{enumerable:!0,get:function(){return r.isAvailable}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TerminalManager=void 0;const r=n(2),i=n(64),o=n(4),a=n(38),s=n(121),l=n(122),c=n(645);class u extends s.BaseManager{constructor(e={}){var t;if(super(e),this._isReady=!1,this._names=[],this._terminalConnections=new Set,this._runningChanged=new o.Signal(this),this._connectionFailure=new o.Signal(this),!this.isAvailable())return this._ready=Promise.reject("Terminals unavailable"),void this._ready.catch(e=>{});this._pollModels=new i.Poll({auto:!1,factory:()=>this.requestRunning(),frequency:{interval:1e4,backoff:!0,max:3e5},name:"@jupyterlab/services:TerminalManager#models",standby:null!==(t=e.standby)&&void 0!==t?t:"when-hidden"}),this._ready=(async()=>{await this._pollModels.start(),await this._pollModels.tick,this._isReady=!0})()}get isReady(){return this._isReady}get ready(){return this._ready}get runningChanged(){return this._runningChanged}get connectionFailure(){return this._connectionFailure}dispose(){this.isDisposed||(this._names.length=0,this._terminalConnections.forEach(e=>e.dispose()),this._pollModels.dispose(),super.dispose())}isAvailable(){return l.isAvailable()}connectTo(e){const t=new c.TerminalConnection(Object.assign(Object.assign({},e),{serverSettings:this.serverSettings}));return this._onStarted(t),this._names.includes(e.model.name)||this.refreshRunning().catch(()=>{}),t}running(){return r.iter(this._models)}async refreshRunning(){await this._pollModels.refresh(),await this._pollModels.tick}async startNew(){const e=await l.startNew(this.serverSettings);return await this.refreshRunning(),this.connectTo({model:e})}async shutdown(e){await l.shutdownTerminal(e,this.serverSettings),await this.refreshRunning()}async shutdownAll(){await this.refreshRunning(),await Promise.all(this._names.map(e=>l.shutdownTerminal(e,this.serverSettings))),await this.refreshRunning()}async requestRunning(){var e,t;let n;try{n=await l.listRunning(this.serverSettings)}catch(n){throw(n instanceof a.ServerConnection.NetworkError||503===(null===(e=n.response)||void 0===e?void 0:e.status)||424===(null===(t=n.response)||void 0===t?void 0:t.status))&&this._connectionFailure.emit(n),n}if(this.isDisposed)return;const r=n.map(({name:e})=>e).sort();r!==this._names&&(this._names=r,this._terminalConnections.forEach(e=>{r.includes(e.name)||e.dispose()}),this._runningChanged.emit(this._models))}_onStarted(e){this._terminalConnections.add(e),e.disposed.connect(this._onDisposed,this)}_onDisposed(e){this._terminalConnections.delete(e),this.refreshRunning().catch(()=>{})}get _models(){return this._names.map(e=>({name:e}))}}t.TerminalManager=u},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TerminalConnection=void 0;const r=n(12),i=n(6),o=n(4),a=n(38),s=n(122);class l{constructor(e){var t;this._createSocket=()=>{this._errorIfDisposed(),this._clearSocket(),this._updateConnectionStatus("connecting");const e=this._name,t=this.serverSettings;let n=r.URLExt.join(t.wsUrl,"terminals","websocket",encodeURIComponent(e));const i=t.token;t.appendToken&&""!==i&&(n=n+"?token="+encodeURIComponent(i)),this._ws=new t.WebSocket(n),this._ws.onmessage=this._onWSMessage,this._ws.onclose=this._onWSClose,this._ws.onerror=this._onWSClose},this._onWSMessage=e=>{if(this._isDisposed)return;const t=JSON.parse(e.data);"disconnect"===t[0]&&this.dispose(),"connecting"!==this._connectionStatus?this._messageReceived.emit({type:t[0],content:t.slice(1)}):"setup"===t[0]&&this._updateConnectionStatus("connected")},this._onWSClose=e=>{console.warn("Terminal websocket closed: "+e.code),this.isDisposed||this._reconnect()},this._connectionStatus="connecting",this._connectionStatusChanged=new o.Signal(this),this._isDisposed=!1,this._disposed=new o.Signal(this),this._messageReceived=new o.Signal(this),this._reconnectTimeout=null,this._ws=null,this._noOp=()=>{},this._reconnectLimit=7,this._reconnectAttempt=0,this._pendingMessages=[],this._name=e.model.name,this.serverSettings=null!==(t=e.serverSettings)&&void 0!==t?t:a.ServerConnection.makeSettings(),this._createSocket()}get disposed(){return this._disposed}get messageReceived(){return this._messageReceived}get name(){return this._name}get model(){return{name:this._name}}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed||(this._isDisposed=!0,this._disposed.emit(),this._updateConnectionStatus("disconnected"),this._clearSocket(),o.Signal.clearData(this))}send(e){this._sendMessage(e)}_sendMessage(e,t=!0){if(!this._isDisposed&&e.content)if("connected"===this.connectionStatus&&this._ws){const t=[e.type,...e.content];this._ws.send(JSON.stringify(t))}else{if(!t)throw new Error("Could not send message: "+JSON.stringify(e));this._pendingMessages.push(e)}}_sendPending(){for(;"connected"===this.connectionStatus&&this._pendingMessages.length>0;)this._sendMessage(this._pendingMessages[0],!1),this._pendingMessages.shift()}reconnect(){this._errorIfDisposed();const e=new i.PromiseDelegate,t=(n,r)=>{"connected"===r?(e.resolve(),this.connectionStatusChanged.disconnect(t,this)):"disconnected"===r&&(e.reject(new Error("Terminal connection disconnected")),this.connectionStatusChanged.disconnect(t,this))};return this.connectionStatusChanged.connect(t,this),this._reconnectAttempt=0,this._reconnect(),e.promise}_reconnect(){if(this._errorIfDisposed(),clearTimeout(this._reconnectTimeout),this._reconnectAttempt<this._reconnectLimit){this._updateConnectionStatus("connecting");const e=c.getRandomIntInclusive(0,1e3*(Math.pow(2,this._reconnectAttempt)-1));console.error(`Connection lost, reconnecting in ${Math.floor(e/1e3)} seconds.`),this._reconnectTimeout=setTimeout(this._createSocket,e),this._reconnectAttempt+=1}else this._updateConnectionStatus("disconnected");this._clearSocket()}_clearSocket(){null!==this._ws&&(this._ws.onopen=this._noOp,this._ws.onclose=this._noOp,this._ws.onerror=this._noOp,this._ws.onmessage=this._noOp,this._ws.close(),this._ws=null)}async shutdown(){await s.shutdownTerminal(this.name,this.serverSettings),this.dispose()}clone(){return new l(this)}_updateConnectionStatus(e){this._connectionStatus!==e&&(this._connectionStatus=e,"connecting"!==e&&(this._reconnectAttempt=0,clearTimeout(this._reconnectTimeout)),"connected"===e&&this._sendPending(),this._connectionStatusChanged.emit(e))}_errorIfDisposed(){if(this.isDisposed)throw new Error("Terminal connection is disposed")}get connectionStatusChanged(){return this._connectionStatusChanged}get connectionStatus(){return this._connectionStatus}}var c;t.TerminalConnection=l,function(e){e.getTermUrl=function(e,t){return r.URLExt.join(e,s.TERMINAL_SERVICE_URL,encodeURIComponent(t))},e.getRandomIntInclusive=function(e,t){return e=Math.ceil(e),t=Math.floor(t),Math.floor(Math.random()*(t-e+1))+e}}(c||(c={}))},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),o=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&r(t,e,n);return i(t,e),t},a=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)},s=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(t,"__esModule",{value:!0}),t.RssHandler=t.DefaultHandler=t.DomUtils=t.ElementType=t.Tokenizer=t.createDomStream=t.parseDOM=t.parseDocument=t.DomHandler=t.Parser=void 0;var l=n(355);Object.defineProperty(t,"Parser",{enumerable:!0,get:function(){return l.Parser}});var c=n(71);function u(e,t){var n=new c.DomHandler(void 0,t);return new l.Parser(n,t).end(e),n.root}Object.defineProperty(t,"DomHandler",{enumerable:!0,get:function(){return c.DomHandler}}),Object.defineProperty(t,"DefaultHandler",{enumerable:!0,get:function(){return c.DomHandler}}),t.parseDocument=u,t.parseDOM=function(e,t){return u(e,t).children},t.createDomStream=function(e,t,n){var r=new c.DomHandler(e,t,n);return new l.Parser(r,t)};var d=n(356);Object.defineProperty(t,"Tokenizer",{enumerable:!0,get:function(){return s(d).default}});var h=o(n(102));t.ElementType=h,a(n(360),t),t.DomUtils=o(n(361));var p=n(360);Object.defineProperty(t,"RssHandler",{enumerable:!0,get:function(){return p.FeedHandler}})},function(e){e.exports=JSON.parse('{"0":65533,"128":8364,"130":8218,"131":402,"132":8222,"133":8230,"134":8224,"135":8225,"136":710,"137":8240,"138":352,"139":8249,"140":338,"142":381,"145":8216,"146":8217,"147":8220,"148":8221,"149":8226,"150":8211,"151":8212,"152":732,"153":8482,"154":353,"155":8250,"156":339,"158":382,"159":376}')},function(e,t,n){"use strict";var r=this&&this.__assign||function(){return(r=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},i=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),o=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),a=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)"default"!==n&&Object.prototype.hasOwnProperty.call(e,n)&&i(t,e,n);return o(t,e),t};Object.defineProperty(t,"__esModule",{value:!0});var s=a(n(102)),l=n(649),c=n(650),u=new Set(["style","script","xmp","iframe","noembed","noframes","plaintext","noscript"]);var d=new Set(["area","base","basefont","br","col","command","embed","frame","hr","img","input","isindex","keygen","link","meta","param","source","track","wbr"]);function h(e,t){void 0===t&&(t={});for(var n=("length"in e?e:[e]),r="",i=0;i<n.length;i++)r+=p(n[i],t);return r}function p(e,t){switch(e.type){case s.Root:return h(e.children,t);case s.Directive:case s.Doctype:return"<"+e.data+">";case s.Comment:return function(e){return"\x3c!--"+e.data+"--\x3e"}(e);case s.CDATA:return function(e){return"<![CDATA["+e.children[0].data+"]]>"}(e);case s.Script:case s.Style:case s.Tag:return function(e,t){var n;"foreign"===t.xmlMode&&(e.name=null!==(n=c.elementNames.get(e.name))&&void 0!==n?n:e.name,e.parent&&f.has(e.parent.name)&&(t=r(r({},t),{xmlMode:!1})));!t.xmlMode&&m.has(e.name)&&(t=r(r({},t),{xmlMode:"foreign"}));var i="<"+e.name,o=function(e,t){if(e)return Object.keys(e).map((function(n){var r,i,o=null!==(r=e[n])&&void 0!==r?r:"";return"foreign"===t.xmlMode&&(n=null!==(i=c.attributeNames.get(n))&&void 0!==i?i:n),t.emptyAttrs||t.xmlMode||""!==o?n+'="'+(!1!==t.decodeEntities?l.encodeXML(o):o.replace(/"/g,"&quot;"))+'"':n})).join(" ")}(e.attribs,t);o&&(i+=" "+o);0===e.children.length&&(t.xmlMode?!1!==t.selfClosingTags:t.selfClosingTags&&d.has(e.name))?(t.xmlMode||(i+=" "),i+="/>"):(i+=">",e.children.length>0&&(i+=h(e.children,t)),!t.xmlMode&&d.has(e.name)||(i+="</"+e.name+">"));return i}(e,t);case s.Text:return function(e,t){var n=e.data||"";!1===t.decodeEntities||!t.xmlMode&&e.parent&&u.has(e.parent.name)||(n=l.encodeXML(n));return n}(e,t)}}t.default=h;var f=new Set(["mi","mo","mn","ms","mtext","annotation-xml","foreignObject","desc","title"]),m=new Set(["svg","math"])},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.decodeXMLStrict=t.decodeHTML5Strict=t.decodeHTML4Strict=t.decodeHTML5=t.decodeHTML4=t.decodeHTMLStrict=t.decodeHTML=t.decodeXML=t.encodeHTML5=t.encodeHTML4=t.escapeUTF8=t.escape=t.encodeNonAsciiHTML=t.encodeHTML=t.encodeXML=t.encode=t.decodeStrict=t.decode=void 0;var r=n(363),i=n(364);t.decode=function(e,t){return(!t||t<=0?r.decodeXML:r.decodeHTML)(e)},t.decodeStrict=function(e,t){return(!t||t<=0?r.decodeXML:r.decodeHTMLStrict)(e)},t.encode=function(e,t){return(!t||t<=0?i.encodeXML:i.encodeHTML)(e)};var o=n(364);Object.defineProperty(t,"encodeXML",{enumerable:!0,get:function(){return o.encodeXML}}),Object.defineProperty(t,"encodeHTML",{enumerable:!0,get:function(){return o.encodeHTML}}),Object.defineProperty(t,"encodeNonAsciiHTML",{enumerable:!0,get:function(){return o.encodeNonAsciiHTML}}),Object.defineProperty(t,"escape",{enumerable:!0,get:function(){return o.escape}}),Object.defineProperty(t,"escapeUTF8",{enumerable:!0,get:function(){return o.escapeUTF8}}),Object.defineProperty(t,"encodeHTML4",{enumerable:!0,get:function(){return o.encodeHTML}}),Object.defineProperty(t,"encodeHTML5",{enumerable:!0,get:function(){return o.encodeHTML}});var a=n(363);Object.defineProperty(t,"decodeXML",{enumerable:!0,get:function(){return a.decodeXML}}),Object.defineProperty(t,"decodeHTML",{enumerable:!0,get:function(){return a.decodeHTML}}),Object.defineProperty(t,"decodeHTMLStrict",{enumerable:!0,get:function(){return a.decodeHTMLStrict}}),Object.defineProperty(t,"decodeHTML4",{enumerable:!0,get:function(){return a.decodeHTML}}),Object.defineProperty(t,"decodeHTML5",{enumerable:!0,get:function(){return a.decodeHTML}}),Object.defineProperty(t,"decodeHTML4Strict",{enumerable:!0,get:function(){return a.decodeHTMLStrict}}),Object.defineProperty(t,"decodeHTML5Strict",{enumerable:!0,get:function(){return a.decodeHTMLStrict}}),Object.defineProperty(t,"decodeXMLStrict",{enumerable:!0,get:function(){return a.decodeXML}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.attributeNames=t.elementNames=void 0,t.elementNames=new Map([["altglyph","altGlyph"],["altglyphdef","altGlyphDef"],["altglyphitem","altGlyphItem"],["animatecolor","animateColor"],["animatemotion","animateMotion"],["animatetransform","animateTransform"],["clippath","clipPath"],["feblend","feBlend"],["fecolormatrix","feColorMatrix"],["fecomponenttransfer","feComponentTransfer"],["fecomposite","feComposite"],["feconvolvematrix","feConvolveMatrix"],["fediffuselighting","feDiffuseLighting"],["fedisplacementmap","feDisplacementMap"],["fedistantlight","feDistantLight"],["fedropshadow","feDropShadow"],["feflood","feFlood"],["fefunca","feFuncA"],["fefuncb","feFuncB"],["fefuncg","feFuncG"],["fefuncr","feFuncR"],["fegaussianblur","feGaussianBlur"],["feimage","feImage"],["femerge","feMerge"],["femergenode","feMergeNode"],["femorphology","feMorphology"],["feoffset","feOffset"],["fepointlight","fePointLight"],["fespecularlighting","feSpecularLighting"],["fespotlight","feSpotLight"],["fetile","feTile"],["feturbulence","feTurbulence"],["foreignobject","foreignObject"],["glyphref","glyphRef"],["lineargradient","linearGradient"],["radialgradient","radialGradient"],["textpath","textPath"]]),t.attributeNames=new Map([["definitionurl","definitionURL"],["attributename","attributeName"],["attributetype","attributeType"],["basefrequency","baseFrequency"],["baseprofile","baseProfile"],["calcmode","calcMode"],["clippathunits","clipPathUnits"],["diffuseconstant","diffuseConstant"],["edgemode","edgeMode"],["filterunits","filterUnits"],["glyphref","glyphRef"],["gradienttransform","gradientTransform"],["gradientunits","gradientUnits"],["kernelmatrix","kernelMatrix"],["kernelunitlength","kernelUnitLength"],["keypoints","keyPoints"],["keysplines","keySplines"],["keytimes","keyTimes"],["lengthadjust","lengthAdjust"],["limitingconeangle","limitingConeAngle"],["markerheight","markerHeight"],["markerunits","markerUnits"],["markerwidth","markerWidth"],["maskcontentunits","maskContentUnits"],["maskunits","maskUnits"],["numoctaves","numOctaves"],["pathlength","pathLength"],["patterncontentunits","patternContentUnits"],["patterntransform","patternTransform"],["patternunits","patternUnits"],["pointsatx","pointsAtX"],["pointsaty","pointsAtY"],["pointsatz","pointsAtZ"],["preservealpha","preserveAlpha"],["preserveaspectratio","preserveAspectRatio"],["primitiveunits","primitiveUnits"],["refx","refX"],["refy","refY"],["repeatcount","repeatCount"],["repeatdur","repeatDur"],["requiredextensions","requiredExtensions"],["requiredfeatures","requiredFeatures"],["specularconstant","specularConstant"],["specularexponent","specularExponent"],["spreadmethod","spreadMethod"],["startoffset","startOffset"],["stddeviation","stdDeviation"],["stitchtiles","stitchTiles"],["surfacescale","surfaceScale"],["systemlanguage","systemLanguage"],["tablevalues","tableValues"],["targetx","targetX"],["targety","targetY"],["textlength","textLength"],["viewbox","viewBox"],["viewtarget","viewTarget"],["xchannelselector","xChannelSelector"],["ychannelselector","yChannelSelector"],["zoomandpan","zoomAndPan"]])},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.prevElementSibling=t.nextElementSibling=t.getName=t.hasAttrib=t.getAttributeValue=t.getSiblings=t.getParent=t.getChildren=void 0;var r=n(71),i=[];function o(e){var t;return null!==(t=e.children)&&void 0!==t?t:i}function a(e){return e.parent||null}t.getChildren=o,t.getParent=a,t.getSiblings=function(e){var t=a(e);if(null!=t)return o(t);for(var n=[e],r=e.prev,i=e.next;null!=r;)n.unshift(r),r=r.prev;for(;null!=i;)n.push(i),i=i.next;return n},t.getAttributeValue=function(e,t){var n;return null===(n=e.attribs)||void 0===n?void 0:n[t]},t.hasAttrib=function(e,t){return null!=e.attribs&&Object.prototype.hasOwnProperty.call(e.attribs,t)&&null!=e.attribs[t]},t.getName=function(e){return e.name},t.nextElementSibling=function(e){for(var t=e.next;null!==t&&!(0,r.isTag)(t);)t=t.next;return t},t.prevElementSibling=function(e){for(var t=e.prev;null!==t&&!(0,r.isTag)(t);)t=t.prev;return t}},function(e,t,n){"use strict";function r(e){if(e.prev&&(e.prev.next=e.next),e.next&&(e.next.prev=e.prev),e.parent){var t=e.parent.children;t.splice(t.lastIndexOf(e),1)}}Object.defineProperty(t,"__esModule",{value:!0}),t.prepend=t.prependChild=t.append=t.appendChild=t.replaceElement=t.removeElement=void 0,t.removeElement=r,t.replaceElement=function(e,t){var n=t.prev=e.prev;n&&(n.next=t);var r=t.next=e.next;r&&(r.prev=t);var i=t.parent=e.parent;if(i){var o=i.children;o[o.lastIndexOf(e)]=t}},t.appendChild=function(e,t){if(r(t),t.next=null,t.parent=e,e.children.push(t)>1){var n=e.children[e.children.length-2];n.next=t,t.prev=n}else t.prev=null},t.append=function(e,t){r(t);var n=e.parent,i=e.next;if(t.next=i,t.prev=e,e.next=t,t.parent=n,i){if(i.prev=t,n){var o=n.children;o.splice(o.lastIndexOf(i),0,t)}}else n&&n.children.push(t)},t.prependChild=function(e,t){if(r(t),t.parent=e,t.prev=null,1!==e.children.unshift(t)){var n=e.children[1];n.prev=t,t.next=n}else t.next=null},t.prepend=function(e,t){r(t);var n=e.parent;if(n){var i=n.children;i.splice(i.indexOf(e),0,t)}e.prev&&(e.prev.next=t),t.parent=n,t.prev=e.prev,t.next=e,e.prev=t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.uniqueSort=t.compareDocumentPosition=t.removeSubsets=void 0;var r=n(71);function i(e,t){var n=[],i=[];if(e===t)return 0;for(var o=(0,r.hasChildren)(e)?e:e.parent;o;)n.unshift(o),o=o.parent;for(o=(0,r.hasChildren)(t)?t:t.parent;o;)i.unshift(o),o=o.parent;for(var a=Math.min(n.length,i.length),s=0;s<a&&n[s]===i[s];)s++;if(0===s)return 1;var l=n[s-1],c=l.children,u=n[s],d=i[s];return c.indexOf(u)>c.indexOf(d)?l===t?20:4:l===e?10:2}t.removeSubsets=function(e){for(var t=e.length;--t>=0;){var n=e[t];if(t>0&&e.lastIndexOf(n,t-1)>=0)e.splice(t,1);else for(var r=n.parent;r;r=r.parent)if(e.includes(r)){e.splice(t,1);break}}return e},t.compareDocumentPosition=i,t.uniqueSort=function(e){return(e=e.filter((function(e,t,n){return!n.includes(e,t+1)}))).sort((function(e,t){var n=i(e,t);return 2&n?-1:4&n?1:0})),e}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getFeed=void 0;var r=n(362),i=n(366);t.getFeed=function(e){var t=l(d,e);return t?"feed"===t.name?function(e){var t,n=e.children,r={type:"atom",items:(0,i.getElementsByTagName)("entry",n).map((function(e){var t,n=e.children,r={media:s(n)};u(r,"id","id",n),u(r,"title","title",n);var i=null===(t=l("link",n))||void 0===t?void 0:t.attribs.href;i&&(r.link=i);var o=c("summary",n)||c("content",n);o&&(r.description=o);var a=c("updated",n);return a&&(r.pubDate=new Date(a)),r}))};u(r,"id","id",n),u(r,"title","title",n);var o=null===(t=l("link",n))||void 0===t?void 0:t.attribs.href;o&&(r.link=o);u(r,"description","subtitle",n);var a=c("updated",n);a&&(r.updated=new Date(a));return u(r,"author","email",n,!0),r}(t):function(e){var t,n,r=null!==(n=null===(t=l("channel",e.children))||void 0===t?void 0:t.children)&&void 0!==n?n:[],o={type:e.name.substr(0,3),id:"",items:(0,i.getElementsByTagName)("item",e.children).map((function(e){var t=e.children,n={media:s(t)};u(n,"id","guid",t),u(n,"title","title",t),u(n,"link","link",t),u(n,"description","description",t);var r=c("pubDate",t);return r&&(n.pubDate=new Date(r)),n}))};u(o,"title","title",r),u(o,"link","link",r),u(o,"description","description",r);var a=c("lastBuildDate",r);a&&(o.updated=new Date(a));return u(o,"author","managingEditor",r,!0),o}(t):null};var o=["url","type","lang"],a=["fileSize","bitrate","framerate","samplingrate","channels","duration","height","width"];function s(e){return(0,i.getElementsByTagName)("media:content",e).map((function(e){for(var t=e.attribs,n={medium:t.medium,isDefault:!!t.isDefault},r=0,i=o;r<i.length;r++){t[c=i[r]]&&(n[c]=t[c])}for(var s=0,l=a;s<l.length;s++){var c;t[c=l[s]]&&(n[c]=parseInt(t[c],10))}return t.expression&&(n.expression=t.expression),n}))}function l(e,t){return(0,i.getElementsByTagName)(e,t,!0,1)[0]}function c(e,t,n){return void 0===n&&(n=!1),(0,r.textContent)((0,i.getElementsByTagName)(e,t,n,1)).trim()}function u(e,t,n,r,i){void 0===i&&(i=!1);var o=c(n,r,i);o&&(e[t]=o)}function d(e){return"rss"===e||"feed"===e||"rdf:RDF"===e}},function(e,t,n){"use strict";e.exports=e=>{if("string"!=typeof e)throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}},function(e,t,n){"use strict";
/*!
 * is-plain-object <https://github.com/jonschlinkert/is-plain-object>
 *
 * Copyright (c) 2014-2017, Jon Schlinkert.
 * Released under the MIT License.
 */
function r(e){return"[object Object]"===Object.prototype.toString.call(e)}function i(e){var t,n;return!1!==r(e)&&(void 0===(t=e.constructor)||!1!==r(n=t.prototype)&&!1!==n.hasOwnProperty("isPrototypeOf"))}n.r(t),n.d(t,"isPlainObject",(function(){return i}))},function(e,t,n){"use strict";var r=function(e){return function(e){return!!e&&"object"==typeof e}(e)&&!function(e){var t=Object.prototype.toString.call(e);return"[object RegExp]"===t||"[object Date]"===t||function(e){return e.$$typeof===i}(e)}(e)};var i="function"==typeof Symbol&&Symbol.for?Symbol.for("react.element"):60103;function o(e,t){return!1!==t.clone&&t.isMergeableObject(e)?u((n=e,Array.isArray(n)?[]:{}),e,t):e;var n}function a(e,t,n){return e.concat(t).map((function(e){return o(e,n)}))}function s(e){return Object.keys(e).concat(function(e){return Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(e).filter((function(t){return e.propertyIsEnumerable(t)})):[]}(e))}function l(e,t){try{return t in e}catch(e){return!1}}function c(e,t,n){var r={};return n.isMergeableObject(e)&&s(e).forEach((function(t){r[t]=o(e[t],n)})),s(t).forEach((function(i){(function(e,t){return l(e,t)&&!(Object.hasOwnProperty.call(e,t)&&Object.propertyIsEnumerable.call(e,t))})(e,i)||(l(e,i)&&n.isMergeableObject(t[i])?r[i]=function(e,t){if(!t.customMerge)return u;var n=t.customMerge(e);return"function"==typeof n?n:u}(i,n)(e[i],t[i],n):r[i]=o(t[i],n))})),r}function u(e,t,n){(n=n||{}).arrayMerge=n.arrayMerge||a,n.isMergeableObject=n.isMergeableObject||r,n.cloneUnlessOtherwiseSpecified=o;var i=Array.isArray(t);return i===Array.isArray(e)?i?n.arrayMerge(e,t,n):c(e,t,n):o(t,n)}u.all=function(e,t){if(!Array.isArray(e))throw new Error("first argument should be an array");return e.reduce((function(e,n){return u(e,n,t)}),{})};var d=u;e.exports=d},function(e,t,n){var r,i,o;i=[],void 0===(o="function"==typeof(r=function(){return function(e){function t(e){return" "===e||"\t"===e||"\n"===e||"\f"===e||"\r"===e}function n(t){var n,r=t.exec(e.substring(m));if(r)return n=r[0],m+=n.length,n}for(var r,i,o,a,s,l=e.length,c=/^[ \t\n\r\u000c]+/,u=/^[, \t\n\r\u000c]+/,d=/^[^ \t\n\r\u000c]+/,h=/[,]+$/,p=/^\d+$/,f=/^-?(?:[0-9]+|[0-9]*\.[0-9]+)(?:[eE][+-]?[0-9]+)?$/,m=0,g=[];;){if(n(u),m>=l)return g;r=n(d),i=[],","===r.slice(-1)?(r=r.replace(h,""),y()):v()}function v(){for(n(c),o="",a="in descriptor";;){if(s=e.charAt(m),"in descriptor"===a)if(t(s))o&&(i.push(o),o="",a="after descriptor");else{if(","===s)return m+=1,o&&i.push(o),void y();if("("===s)o+=s,a="in parens";else{if(""===s)return o&&i.push(o),void y();o+=s}}else if("in parens"===a)if(")"===s)o+=s,a="in descriptor";else{if(""===s)return i.push(o),void y();o+=s}else if("after descriptor"===a)if(t(s));else{if(""===s)return void y();a="in descriptor",m-=1}m+=1}}function y(){var t,n,o,a,s,l,c,u,d,h=!1,m={};for(a=0;a<i.length;a++)l=(s=i[a])[s.length-1],c=s.substring(0,s.length-1),u=parseInt(c,10),d=parseFloat(c),p.test(c)&&"w"===l?((t||n)&&(h=!0),0===u?h=!0:t=u):f.test(c)&&"x"===l?((t||n||o)&&(h=!0),d<0?h=!0:n=d):p.test(c)&&"h"===l?((o||n)&&(h=!0),0===u?h=!0:o=u):h=!0;h?console&&console.log&&console.log("Invalid srcset descriptor found in '"+e+"' at '"+s+"'."):(m.url=r,t&&(m.w=t),n&&(m.d=n),o&&(m.h=o),g.push(m))}}})?r.apply(t,i):r)||(e.exports=o)},function(e,t,n){"use strict";(function(t){let r=n(158),i=n(123),o=n(369),a=n(83),s=n(667),l=n(125),c=n(669),u=n(163),d=n(374),h=n(127),p=n(166),f=n(164),m=n(126),g=n(165),v=n(375),y=n(167),_=n(103),b=n(124);function M(...e){return 1===e.length&&Array.isArray(e[0])&&(e=e[0]),new s(e)}M.plugin=function(e,n){function r(...t){let r=n(...t);return r.postcssPlugin=e,r.postcssVersion=(new s).version,r}let i;return console&&console.warn&&(console.warn(e+": postcss.plugin was deprecated. Migration guide:\nhttps://evilmartians.com/chronicles/postcss-8-plugin-migration"),t.env.LANG&&t.env.LANG.startsWith("cn")&&console.warn(e+": 里面 postcss.plugin 被弃用. 迁移指南:\nhttps://www.w3ctech.com/topic/2226")),Object.defineProperty(r,"postcss",{get:()=>(i||(i=r()),i)}),r.process=function(e,t,n){return M([r(n)]).process(e,t)},r},M.stringify=l,M.parse=g,M.fromJSON=c,M.list=v,M.comment=e=>new h(e),M.atRule=e=>new p(e),M.decl=e=>new i(e),M.rule=e=>new y(e),M.root=e=>new _(e),M.document=e=>new u(e),M.CssSyntaxError=r,M.Declaration=i,M.Container=a,M.Processor=s,M.Document=u,M.Comment=h,M.Warning=d,M.AtRule=p,M.Result=f,M.Input=m,M.Rule=y,M.Root=_,M.Node=b,o.registerPostcss(M),e.exports=M,M.default=M}).call(this,n(61))},function(e,t){var n=String,r=function(){return{isColorSupported:!1,reset:n,bold:n,dim:n,italic:n,underline:n,inverse:n,hidden:n,strikethrough:n,black:n,red:n,green:n,yellow:n,blue:n,magenta:n,cyan:n,white:n,gray:n,bgBlack:n,bgRed:n,bgGreen:n,bgYellow:n,bgBlue:n,bgMagenta:n,bgCyan:n,bgWhite:n}};e.exports=r(),e.exports.createColors=r},function(e,t){
/*! ieee754. BSD-3-Clause License. Feross Aboukhadijeh <https://feross.org/opensource> */
t.read=function(e,t,n,r,i){var o,a,s=8*i-r-1,l=(1<<s)-1,c=l>>1,u=-7,d=n?i-1:0,h=n?-1:1,p=e[t+d];for(d+=h,o=p&(1<<-u)-1,p>>=-u,u+=s;u>0;o=256*o+e[t+d],d+=h,u-=8);for(a=o&(1<<-u)-1,o>>=-u,u+=r;u>0;a=256*a+e[t+d],d+=h,u-=8);if(0===o)o=1-c;else{if(o===l)return a?NaN:1/0*(p?-1:1);a+=Math.pow(2,r),o-=c}return(p?-1:1)*a*Math.pow(2,o-r)},t.write=function(e,t,n,r,i,o){var a,s,l,c=8*o-i-1,u=(1<<c)-1,d=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=r?0:o-1,f=r?1:-1,m=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(s=isNaN(t)?1:0,a=u):(a=Math.floor(Math.log(t)/Math.LN2),t*(l=Math.pow(2,-a))<1&&(a--,l*=2),(t+=a+d>=1?h/l:h*Math.pow(2,1-d))*l>=2&&(a++,l/=2),a+d>=u?(s=0,a=u):a+d>=1?(s=(t*l-1)*Math.pow(2,i),a+=d):(s=t*Math.pow(2,d-1)*Math.pow(2,i),a=0));i>=8;e[n+p]=255&s,p+=f,s/=256,i-=8);for(a=a<<i|s,c+=i;c>0;e[n+p]=255&a,p+=f,a/=256,c-=8);e[n+p-f]|=128*m}},function(e,t){var n={}.toString;e.exports=Array.isArray||function(e){return"[object Array]"==n.call(e)}},function(e,t,n){"use strict";n.r(t),n.d(t,"nanoid",(function(){return i})),n.d(t,"customAlphabet",(function(){return r}));let r=(e,t=21)=>(n=t)=>{let r="",i=n;for(;i--;)r+=e[Math.random()*e.length|0];return r},i=(e=21)=>{let t="",n=e;for(;n--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[64*Math.random()|0];return t}},function(e,t){},function(e,t,n){"use strict";let r=n(123),i=n(666),o=n(127),a=n(166),s=n(103),l=n(167);e.exports=class{constructor(e){this.input=e,this.root=new s,this.current=this.root,this.spaces="",this.semicolon=!1,this.customProperty=!1,this.createTokenizer(),this.root.source={input:e,start:{offset:0,line:1,column:1}}}createTokenizer(){this.tokenizer=i(this.input)}parse(){let e;for(;!this.tokenizer.endOfFile();)switch(e=this.tokenizer.nextToken(),e[0]){case"space":this.spaces+=e[1];break;case";":this.freeSemicolon(e);break;case"}":this.end(e);break;case"comment":this.comment(e);break;case"at-word":this.atrule(e);break;case"{":this.emptyRule(e);break;default:this.other(e)}this.endFile()}comment(e){let t=new o;this.init(t,e[2]),t.source.end=this.getPosition(e[3]||e[2]);let n=e[1].slice(2,-2);if(/^\s*$/.test(n))t.text="",t.raws.left=n,t.raws.right="";else{let e=n.match(/^(\s*)([^]*\S)(\s*)$/);t.text=e[2],t.raws.left=e[1],t.raws.right=e[3]}}emptyRule(e){let t=new l;this.init(t,e[2]),t.selector="",t.raws.between="",this.current=t}other(e){let t=!1,n=null,r=!1,i=null,o=[],a=e[1].startsWith("--"),s=[],l=e;for(;l;){if(n=l[0],s.push(l),"("===n||"["===n)i||(i=l),o.push("("===n?")":"]");else if(a&&r&&"{"===n)i||(i=l),o.push("}");else if(0===o.length){if(";"===n){if(r)return void this.decl(s,a);break}if("{"===n)return void this.rule(s);if("}"===n){this.tokenizer.back(s.pop()),t=!0;break}":"===n&&(r=!0)}else n===o[o.length-1]&&(o.pop(),0===o.length&&(i=null));l=this.tokenizer.nextToken()}if(this.tokenizer.endOfFile()&&(t=!0),o.length>0&&this.unclosedBracket(i),t&&r){if(!a)for(;s.length&&(l=s[s.length-1][0],"space"===l||"comment"===l);)this.tokenizer.back(s.pop());this.decl(s,a)}else this.unknownWord(s)}rule(e){e.pop();let t=new l;this.init(t,e[0][2]),t.raws.between=this.spacesAndCommentsFromEnd(e),this.raw(t,"selector",e),this.current=t}decl(e,t){let n=new r;this.init(n,e[0][2]);let i,o=e[e.length-1];for(";"===o[0]&&(this.semicolon=!0,e.pop()),n.source.end=this.getPosition(o[3]||o[2]);"word"!==e[0][0];)1===e.length&&this.unknownWord(e),n.raws.before+=e.shift()[1];for(n.source.start=this.getPosition(e[0][2]),n.prop="";e.length;){let t=e[0][0];if(":"===t||"space"===t||"comment"===t)break;n.prop+=e.shift()[1]}for(n.raws.between="";e.length;){if(i=e.shift(),":"===i[0]){n.raws.between+=i[1];break}"word"===i[0]&&/\w/.test(i[1])&&this.unknownWord([i]),n.raws.between+=i[1]}"_"!==n.prop[0]&&"*"!==n.prop[0]||(n.raws.before+=n.prop[0],n.prop=n.prop.slice(1));let a,s=[];for(;e.length&&(a=e[0][0],"space"===a||"comment"===a);)s.push(e.shift());this.precheckMissedSemicolon(e);for(let t=e.length-1;t>=0;t--){if(i=e[t],"!important"===i[1].toLowerCase()){n.important=!0;let r=this.stringFrom(e,t);r=this.spacesFromEnd(e)+r," !important"!==r&&(n.raws.important=r);break}if("important"===i[1].toLowerCase()){let r=e.slice(0),i="";for(let e=t;e>0;e--){let t=r[e][0];if(0===i.trim().indexOf("!")&&"space"!==t)break;i=r.pop()[1]+i}0===i.trim().indexOf("!")&&(n.important=!0,n.raws.important=i,e=r)}if("space"!==i[0]&&"comment"!==i[0])break}e.some(e=>"space"!==e[0]&&"comment"!==e[0])&&(n.raws.between+=s.map(e=>e[1]).join(""),s=[]),this.raw(n,"value",s.concat(e),t),n.value.includes(":")&&!t&&this.checkMissedSemicolon(e)}atrule(e){let t,n,r,i=new a;i.name=e[1].slice(1),""===i.name&&this.unnamedAtrule(i,e),this.init(i,e[2]);let o=!1,s=!1,l=[],c=[];for(;!this.tokenizer.endOfFile();){if(t=(e=this.tokenizer.nextToken())[0],"("===t||"["===t?c.push("("===t?")":"]"):"{"===t&&c.length>0?c.push("}"):t===c[c.length-1]&&c.pop(),0===c.length){if(";"===t){i.source.end=this.getPosition(e[2]),this.semicolon=!0;break}if("{"===t){s=!0;break}if("}"===t){if(l.length>0){for(r=l.length-1,n=l[r];n&&"space"===n[0];)n=l[--r];n&&(i.source.end=this.getPosition(n[3]||n[2]))}this.end(e);break}l.push(e)}else l.push(e);if(this.tokenizer.endOfFile()){o=!0;break}}i.raws.between=this.spacesAndCommentsFromEnd(l),l.length?(i.raws.afterName=this.spacesAndCommentsFromStart(l),this.raw(i,"params",l),o&&(e=l[l.length-1],i.source.end=this.getPosition(e[3]||e[2]),this.spaces=i.raws.between,i.raws.between="")):(i.raws.afterName="",i.params=""),s&&(i.nodes=[],this.current=i)}end(e){this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.semicolon=!1,this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.spaces="",this.current.parent?(this.current.source.end=this.getPosition(e[2]),this.current=this.current.parent):this.unexpectedClose(e)}endFile(){this.current.parent&&this.unclosedBlock(),this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.current.raws.after=(this.current.raws.after||"")+this.spaces}freeSemicolon(e){if(this.spaces+=e[1],this.current.nodes){let e=this.current.nodes[this.current.nodes.length-1];e&&"rule"===e.type&&!e.raws.ownSemicolon&&(e.raws.ownSemicolon=this.spaces,this.spaces="")}}getPosition(e){let t=this.input.fromOffset(e);return{offset:e,line:t.line,column:t.col}}init(e,t){this.current.push(e),e.source={start:this.getPosition(t),input:this.input},e.raws.before=this.spaces,this.spaces="","comment"!==e.type&&(this.semicolon=!1)}raw(e,t,n,r){let i,o,a,s,l=n.length,c="",u=!0;for(let e=0;e<l;e+=1)i=n[e],o=i[0],"space"!==o||e!==l-1||r?"comment"===o?(s=n[e-1],a=n[e+1],s&&a&&"space"!==s[0]&&"space"!==a[0]?c+=i[1]:u=!1):c+=i[1]:u=!1;if(!u){let r=n.reduce((e,t)=>e+t[1],"");e.raws[t]={value:c,raw:r}}e[t]=c}spacesAndCommentsFromEnd(e){let t,n="";for(;e.length&&(t=e[e.length-1][0],"space"===t||"comment"===t);)n=e.pop()[1]+n;return n}spacesAndCommentsFromStart(e){let t,n="";for(;e.length&&(t=e[0][0],"space"===t||"comment"===t);)n+=e.shift()[1];return n}spacesFromEnd(e){let t,n="";for(;e.length&&(t=e[e.length-1][0],"space"===t);)n=e.pop()[1]+n;return n}stringFrom(e,t){let n="";for(let r=t;r<e.length;r++)n+=e[r][1];return e.splice(t,e.length-t),n}colon(e){let t,n,r,i=0;for(let[o,a]of e.entries()){if(t=a,n=t[0],"("===n&&(i+=1),")"===n&&(i-=1),0===i&&":"===n){if(r){if("word"===r[0]&&"progid"===r[1])continue;return o}this.doubleColon(t)}r=t}return!1}unclosedBracket(e){throw this.input.error("Unclosed bracket",{offset:e[2]},{offset:e[2]+1})}unknownWord(e){throw this.input.error("Unknown word",{offset:e[0][2]},{offset:e[0][2]+e[0][1].length})}unexpectedClose(e){throw this.input.error("Unexpected }",{offset:e[2]},{offset:e[2]+1})}unclosedBlock(){let e=this.current.source.start;throw this.input.error("Unclosed block",e.line,e.column)}doubleColon(e){throw this.input.error("Double colon",{offset:e[2]},{offset:e[2]+e[1].length})}unnamedAtrule(e,t){throw this.input.error("At-rule without name",{offset:t[2]},{offset:t[2]+t[1].length})}precheckMissedSemicolon(){}checkMissedSemicolon(e){let t=this.colon(e);if(!1===t)return;let n,r=0;for(let i=t-1;i>=0&&(n=e[i],"space"===n[0]||(r+=1,2!==r));i--);throw this.input.error("Missed semicolon","word"===n[0]?n[3]+1:n[2])}}},function(e,t,n){"use strict";const r="'".charCodeAt(0),i='"'.charCodeAt(0),o="\\".charCodeAt(0),a="/".charCodeAt(0),s="\n".charCodeAt(0),l=" ".charCodeAt(0),c="\f".charCodeAt(0),u="\t".charCodeAt(0),d="\r".charCodeAt(0),h="[".charCodeAt(0),p="]".charCodeAt(0),f="(".charCodeAt(0),m=")".charCodeAt(0),g="{".charCodeAt(0),v="}".charCodeAt(0),y=";".charCodeAt(0),_="*".charCodeAt(0),b=":".charCodeAt(0),M="@".charCodeAt(0),w=/[\t\n\f\r "#'()/;[\\\]{}]/g,A=/[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g,C=/.[\n"'(/\\]/,x=/[\da-f]/i;e.exports=function(e,t={}){let n,E,L,S,T,O,I,k,D,N,j=e.css.valueOf(),P=t.ignoreErrors,z=j.length,R=0,B=[],H=[];function F(t){throw e.error("Unclosed "+t,R)}return{back:function(e){H.push(e)},nextToken:function(e){if(H.length)return H.pop();if(R>=z)return;let t=!!e&&e.ignoreUnclosed;switch(n=j.charCodeAt(R),n){case s:case l:case u:case d:case c:E=R;do{E+=1,n=j.charCodeAt(E)}while(n===l||n===s||n===u||n===d||n===c);N=["space",j.slice(R,E)],R=E-1;break;case h:case p:case g:case v:case b:case y:case m:{let e=String.fromCharCode(n);N=[e,e,R];break}case f:if(k=B.length?B.pop()[1]:"",D=j.charCodeAt(R+1),"url"===k&&D!==r&&D!==i&&D!==l&&D!==s&&D!==u&&D!==c&&D!==d){E=R;do{if(O=!1,E=j.indexOf(")",E+1),-1===E){if(P||t){E=R;break}F("bracket")}for(I=E;j.charCodeAt(I-1)===o;)I-=1,O=!O}while(O);N=["brackets",j.slice(R,E+1),R,E],R=E}else E=j.indexOf(")",R+1),S=j.slice(R,E+1),-1===E||C.test(S)?N=["(","(",R]:(N=["brackets",S,R,E],R=E);break;case r:case i:L=n===r?"'":'"',E=R;do{if(O=!1,E=j.indexOf(L,E+1),-1===E){if(P||t){E=R+1;break}F("string")}for(I=E;j.charCodeAt(I-1)===o;)I-=1,O=!O}while(O);N=["string",j.slice(R,E+1),R,E],R=E;break;case M:w.lastIndex=R+1,w.test(j),E=0===w.lastIndex?j.length-1:w.lastIndex-2,N=["at-word",j.slice(R,E+1),R,E],R=E;break;case o:for(E=R,T=!0;j.charCodeAt(E+1)===o;)E+=1,T=!T;if(n=j.charCodeAt(E+1),T&&n!==a&&n!==l&&n!==s&&n!==u&&n!==d&&n!==c&&(E+=1,x.test(j.charAt(E)))){for(;x.test(j.charAt(E+1));)E+=1;j.charCodeAt(E+1)===l&&(E+=1)}N=["word",j.slice(R,E+1),R,E],R=E;break;default:n===a&&j.charCodeAt(R+1)===_?(E=j.indexOf("*/",R+2)+1,0===E&&(P||t?E=j.length:F("comment")),N=["comment",j.slice(R,E+1),R,E],R=E):(A.lastIndex=R+1,A.test(j),E=0===A.lastIndex?j.length-1:A.lastIndex-2,N=["word",j.slice(R,E+1),R,E],B.push(N),R=E)}return R++,N},endOfFile:function(){return 0===H.length&&R>=z},position:function(){return R}}}},function(e,t,n){"use strict";let r=n(668),i=n(369),o=n(163),a=n(103);class s{constructor(e=[]){this.version="8.4.6",this.plugins=this.normalize(e)}use(e){return this.plugins=this.plugins.concat(this.normalize([e])),this}process(e,t={}){return 0===this.plugins.length&&void 0===t.parser&&void 0===t.stringifier&&void 0===t.syntax?new r(this,e,t):new i(this,e,t)}normalize(e){let t=[];for(let n of e)if(!0===n.postcss?n=n():n.postcss&&(n=n.postcss),"object"==typeof n&&Array.isArray(n.plugins))t=t.concat(n.plugins);else if("object"==typeof n&&n.postcssPlugin)t.push(n);else if("function"==typeof n)t.push(n);else{if("object"!=typeof n||!n.parse&&!n.stringify)throw new Error(n+" is not a PostCSS plugin")}return t}}e.exports=s,s.default=s,a.registerProcessor(s),o.registerProcessor(s)},function(e,t,n){"use strict";let r=n(370),i=n(125),o=(n(373),n(165));const a=n(164);class s{constructor(e,t,n){t=t.toString(),this.stringified=!1,this._processor=e,this._css=t,this._opts=n,this._map=void 0;let o=i;this.result=new a(this._processor,void 0,this._opts),this.result.css=t;let s=this;Object.defineProperty(this.result,"root",{get:()=>s.root});let l=new r(o,void 0,this._opts,t);if(l.isMap()){let[e,t]=l.generate();e&&(this.result.css=e),t&&(this.result.map=t)}}get[Symbol.toStringTag](){return"NoWorkResult"}get processor(){return this.result.processor}get opts(){return this.result.opts}get css(){return this.result.css}get content(){return this.result.css}get map(){return this.result.map}get root(){if(this._root)return this._root;let e,t=o;try{e=t(this._css,this._opts)}catch(e){this.error=e}if(this.error)throw this.error;return this._root=e,e}get messages(){return[]}warnings(){return[]}toString(){return this._css}then(e,t){return this.async().then(e,t)}catch(e){return this.async().catch(e)}finally(e){return this.async().then(e,e)}async(){return this.error?Promise.reject(this.error):Promise.resolve(this.result)}sync(){if(this.error)throw this.error;return this.result}}e.exports=s,s.default=s},function(e,t,n){"use strict";let r=n(123),i=n(372),o=n(127),a=n(166),s=n(126),l=n(103),c=n(167);function u(e,t){if(Array.isArray(e))return e.map(e=>u(e));let{inputs:n,...d}=e;if(n){t=[];for(let e of n){let n={...e,__proto__:s.prototype};n.map&&(n.map={...n.map,__proto__:i.prototype}),t.push(n)}}if(d.nodes&&(d.nodes=e.nodes.map(e=>u(e,t))),d.source){let{inputId:e,...n}=d.source;d.source=n,null!=e&&(d.source.input=t[e])}if("root"===d.type)return new l(d);if("decl"===d.type)return new r(d);if("rule"===d.type)return new c(d);if("comment"===d.type)return new o(d);if("atrule"===d.type)return new a(d);throw new Error("Unknown node type: "+e.type)}e.exports=u,u.default=u},function(e,t,n){!function(e){"use strict";var t={},n=/[^\s\u00a0]/,r=e.Pos,i=e.cmpPos;function o(e){var t=e.search(n);return-1==t?0:t}function a(e,t){var n=e.getMode();return!1!==n.useInnerComments&&n.innerMode?e.getModeAt(t):n}e.commands.toggleComment=function(e){e.toggleComment()},e.defineExtension("toggleComment",(function(e){e||(e=t);for(var n=1/0,i=this.listSelections(),o=null,a=i.length-1;a>=0;a--){var s=i[a].from(),l=i[a].to();s.line>=n||(l.line>=n&&(l=r(n,0)),n=s.line,null==o?this.uncomment(s,l,e)?o="un":(this.lineComment(s,l,e),o="line"):"un"==o?this.uncomment(s,l,e):this.lineComment(s,l,e))}})),e.defineExtension("lineComment",(function(e,i,s){s||(s=t);var l=this,c=a(l,e),u=l.getLine(e.line);if(null!=u&&(d=e,h=u,!/\bstring\b/.test(l.getTokenTypeAt(r(d.line,0)))||/^[\'\"\`]/.test(h))){var d,h,p=s.lineComment||c.lineComment;if(p){var f=Math.min(0!=i.ch||i.line==e.line?i.line+1:i.line,l.lastLine()+1),m=null==s.padding?" ":s.padding,g=s.commentBlankLines||e.line==i.line;l.operation((function(){if(s.indent){for(var t=null,i=e.line;i<f;++i){var a=(c=l.getLine(i)).slice(0,o(c));(null==t||t.length>a.length)&&(t=a)}for(i=e.line;i<f;++i){var c=l.getLine(i),u=t.length;(g||n.test(c))&&(c.slice(0,u)!=t&&(u=o(c)),l.replaceRange(t+p+m,r(i,0),r(i,u)))}}else for(i=e.line;i<f;++i)(g||n.test(l.getLine(i)))&&l.replaceRange(p+m,r(i,0))}))}else(s.blockCommentStart||c.blockCommentStart)&&(s.fullLines=!0,l.blockComment(e,i,s))}})),e.defineExtension("blockComment",(function(e,o,s){s||(s=t);var l=this,c=a(l,e),u=s.blockCommentStart||c.blockCommentStart,d=s.blockCommentEnd||c.blockCommentEnd;if(u&&d){if(!/\bcomment\b/.test(l.getTokenTypeAt(r(e.line,0)))){var h=Math.min(o.line,l.lastLine());h!=e.line&&0==o.ch&&n.test(l.getLine(h))&&--h;var p=null==s.padding?" ":s.padding;e.line>h||l.operation((function(){if(0!=s.fullLines){var t=n.test(l.getLine(h));l.replaceRange(p+d,r(h)),l.replaceRange(u+p,r(e.line,0));var a=s.blockCommentLead||c.blockCommentLead;if(null!=a)for(var f=e.line+1;f<=h;++f)(f!=h||t)&&l.replaceRange(a+p,r(f,0))}else{var m=0==i(l.getCursor("to"),o),g=!l.somethingSelected();l.replaceRange(d,o),m&&l.setSelection(g?o:l.getCursor("from"),o),l.replaceRange(u,e)}}))}}else(s.lineComment||c.lineComment)&&0!=s.fullLines&&l.lineComment(e,o,s)})),e.defineExtension("uncomment",(function(e,i,o){o||(o=t);var s,l=this,c=a(l,e),u=Math.min(0!=i.ch||i.line==e.line?i.line:i.line-1,l.lastLine()),d=Math.min(e.line,u),h=o.lineComment||c.lineComment,p=[],f=null==o.padding?" ":o.padding;e:if(h){for(var m=d;m<=u;++m){var g=l.getLine(m),v=g.indexOf(h);if(v>-1&&!/comment/.test(l.getTokenTypeAt(r(m,v+1)))&&(v=-1),-1==v&&n.test(g))break e;if(v>-1&&n.test(g.slice(0,v)))break e;p.push(g)}if(l.operation((function(){for(var e=d;e<=u;++e){var t=p[e-d],n=t.indexOf(h),i=n+h.length;n<0||(t.slice(i,i+f.length)==f&&(i+=f.length),s=!0,l.replaceRange("",r(e,n),r(e,i)))}})),s)return!0}var y=o.blockCommentStart||c.blockCommentStart,_=o.blockCommentEnd||c.blockCommentEnd;if(!y||!_)return!1;var b=o.blockCommentLead||c.blockCommentLead,M=l.getLine(d),w=M.indexOf(y);if(-1==w)return!1;var A=u==d?M:l.getLine(u),C=A.indexOf(_,u==d?w+y.length:0),x=r(d,w+1),E=r(u,C+1);if(-1==C||!/comment/.test(l.getTokenTypeAt(x))||!/comment/.test(l.getTokenTypeAt(E))||l.getRange(x,E,"\n").indexOf(_)>-1)return!1;var L=M.lastIndexOf(y,e.ch),S=-1==L?-1:M.slice(0,e.ch).indexOf(_,L+y.length);if(-1!=L&&-1!=S&&S+_.length!=e.ch)return!1;S=A.indexOf(_,i.ch);var T=A.slice(i.ch).lastIndexOf(y,S-i.ch);return L=-1==S||-1==T?-1:i.ch+T,(-1==S||-1==L||L==i.ch)&&(l.operation((function(){l.replaceRange("",r(u,C-(f&&A.slice(C-f.length,C)==f?f.length:0)),r(u,C+_.length));var e=w+y.length;if(f&&M.slice(e,e+f.length)==f&&(e+=f.length),l.replaceRange("",r(d,w),r(d,e)),b)for(var t=d+1;t<=u;++t){var i=l.getLine(t),o=i.indexOf(b);if(-1!=o&&!n.test(i.slice(0,o))){var a=o+b.length;f&&i.slice(a,a+f.length)==f&&(a+=f.length),l.replaceRange("",r(t,o),r(t,a))}}})),!0)}))}(n(14))},function(e,t,n){!function(e){"use strict";function t(t){t.state.rulerDiv.textContent="";var n=t.getOption("rulers"),r=t.defaultCharWidth(),i=t.charCoords(e.Pos(t.firstLine(),0),"div").left;t.state.rulerDiv.style.minHeight=t.display.scroller.offsetHeight+30+"px";for(var o=0;o<n.length;o++){var a=document.createElement("div");a.className="CodeMirror-ruler";var s,l=n[o];"number"==typeof l?s=l:(s=l.column,l.className&&(a.className+=" "+l.className),l.color&&(a.style.borderColor=l.color),l.lineStyle&&(a.style.borderLeftStyle=l.lineStyle),l.width&&(a.style.borderLeftWidth=l.width)),a.style.left=i+s*r+"px",t.state.rulerDiv.appendChild(a)}}e.defineOption("rulers",!1,(function(e,n){e.state.rulerDiv&&(e.state.rulerDiv.parentElement.removeChild(e.state.rulerDiv),e.state.rulerDiv=null,e.off("refresh",t)),n&&n.length&&(e.state.rulerDiv=e.display.lineSpace.parentElement.insertBefore(document.createElement("div"),e.display.lineSpace),e.state.rulerDiv.className="CodeMirror-rulers",t(e),e.on("refresh",t))}))}(n(14))},function(e,t,n){!function(e){var t={pairs:"()[]{}''\"\"",closeBefore:")]}'\":;>",triples:"",explode:"[]{}"},n=e.Pos;function r(e,n){return"pairs"==n&&"string"==typeof e?e:"object"==typeof e&&null!=e[n]?e[n]:t[n]}e.defineOption("autoCloseBrackets",!1,(function(t,n,a){a&&a!=e.Init&&(t.removeKeyMap(i),t.state.closeBrackets=null),n&&(o(r(n,"pairs")),t.state.closeBrackets=n,t.addKeyMap(i))}));var i={Backspace:function(t){var i=s(t);if(!i||t.getOption("disableInput"))return e.Pass;for(var o=r(i,"pairs"),a=t.listSelections(),l=0;l<a.length;l++){if(!a[l].empty())return e.Pass;var u=c(t,a[l].head);if(!u||o.indexOf(u)%2!=0)return e.Pass}for(l=a.length-1;l>=0;l--){var d=a[l].head;t.replaceRange("",n(d.line,d.ch-1),n(d.line,d.ch+1),"+delete")}},Enter:function(t){var n=s(t),i=n&&r(n,"explode");if(!i||t.getOption("disableInput"))return e.Pass;for(var o=t.listSelections(),a=0;a<o.length;a++){if(!o[a].empty())return e.Pass;var u=c(t,o[a].head);if(!u||i.indexOf(u)%2!=0)return e.Pass}t.operation((function(){var e=t.lineSeparator()||"\n";t.replaceSelection(e+e,null),l(t,-1),o=t.listSelections();for(var n=0;n<o.length;n++){var r=o[n].head.line;t.indentLine(r,null,!0),t.indentLine(r+1,null,!0)}}))}};function o(e){for(var t=0;t<e.length;t++){var n=e.charAt(t),r="'"+n+"'";i[r]||(i[r]=a(n))}}function a(t){return function(i){return function(t,i){var o=s(t);if(!o||t.getOption("disableInput"))return e.Pass;var a=r(o,"pairs"),c=a.indexOf(i);if(-1==c)return e.Pass;for(var d,h=r(o,"closeBefore"),p=r(o,"triples"),f=a.charAt(c+1)==i,m=t.listSelections(),g=c%2==0,v=0;v<m.length;v++){var y,_=m[v],b=_.head,M=t.getRange(b,n(b.line,b.ch+1));if(g&&!_.empty())y="surround";else if(!f&&g||M!=i)if(f&&b.ch>1&&p.indexOf(i)>=0&&t.getRange(n(b.line,b.ch-2),b)==i+i){if(b.ch>2&&/\bstring/.test(t.getTokenTypeAt(n(b.line,b.ch-2))))return e.Pass;y="addFour"}else if(f){var w=0==b.ch?" ":t.getRange(n(b.line,b.ch-1),b);if(e.isWordChar(M)||w==i||e.isWordChar(w))return e.Pass;y="both"}else{if(!g||!(0===M.length||/\s/.test(M)||h.indexOf(M)>-1))return e.Pass;y="both"}else y=f&&u(t,b)?"both":p.indexOf(i)>=0&&t.getRange(b,n(b.line,b.ch+3))==i+i+i?"skipThree":"skip";if(d){if(d!=y)return e.Pass}else d=y}var A=c%2?a.charAt(c-1):i,C=c%2?i:a.charAt(c+1);t.operation((function(){if("skip"==d)l(t,1);else if("skipThree"==d)l(t,3);else if("surround"==d){for(var r=t.getSelections(),i=0;i<r.length;i++)r[i]=A+r[i]+C;for(t.replaceSelections(r,"around"),r=t.listSelections().slice(),i=0;i<r.length;i++)r[i]=(o=r[i],a=void 0,a=e.cmpPos(o.anchor,o.head)>0,{anchor:new n(o.anchor.line,o.anchor.ch+(a?-1:1)),head:new n(o.head.line,o.head.ch+(a?1:-1))});t.setSelections(r)}else"both"==d?(t.replaceSelection(A+C,null),t.triggerElectric(A+C),l(t,-1)):"addFour"==d&&(t.replaceSelection(A+A+A+A,"before"),l(t,1));var o,a}))}(i,t)}}function s(e){var t=e.state.closeBrackets;return!t||t.override?t:e.getModeAt(e.getCursor()).closeBrackets||t}function l(e,t){for(var n=[],r=e.listSelections(),i=0,o=0;o<r.length;o++){var a=r[o];a.head==e.getCursor()&&(i=o);var s=a.head.ch||t>0?{line:a.head.line,ch:a.head.ch+t}:{line:a.head.line-1};n.push({anchor:s,head:s})}e.setSelections(n,i)}function c(e,t){var r=e.getRange(n(t.line,t.ch-1),n(t.line,t.ch+1));return 2==r.length?r:null}function u(e,t){var r=e.getTokenAt(n(t.line,t.ch+1));return/\bstring/.test(r.type)&&r.start==t.ch&&(0==t.ch||!/\bstring/.test(e.getTokenTypeAt(t)))}o(t.pairs+"`")}(n(14))},function(e,t,n){!function(e){"use strict";e.registerHelper("fold","brace",(function(t,n){var r,i=n.line,o=t.getLine(i);function a(a){for(var s=n.ch,l=0;;){var c=s<=0?-1:o.lastIndexOf(a,s-1);if(-1!=c){if(1==l&&c<n.ch)break;if(r=t.getTokenTypeAt(e.Pos(i,c+1)),!/^(comment|string)/.test(r))return c+1;s=c-1}else{if(1==l)break;l=1,s=o.length}}}var s,l,c,u=a("{"),d=a("[");if(null!=u&&(null==d||d>u))c=u,s="{",l="}";else{if(null==d)return;c=d,s="[",l="]"}var h,p,f=1,m=t.lastLine();e:for(var g=i;g<=m;++g)for(var v=t.getLine(g),y=g==i?c:0;;){var _=v.indexOf(s,y),b=v.indexOf(l,y);if(_<0&&(_=v.length),b<0&&(b=v.length),(y=Math.min(_,b))==v.length)break;if(t.getTokenTypeAt(e.Pos(g,y+1))==r)if(y==_)++f;else if(!--f){h=g,p=y;break e}++y}if(null!=h&&i!=h)return{from:e.Pos(i,c),to:e.Pos(h,p)}})),e.registerHelper("fold","import",(function(t,n){function r(n){if(n<t.firstLine()||n>t.lastLine())return null;var r=t.getTokenAt(e.Pos(n,1));if(/\S/.test(r.string)||(r=t.getTokenAt(e.Pos(n,r.end+1))),"keyword"!=r.type||"import"!=r.string)return null;for(var i=n,o=Math.min(t.lastLine(),n+10);i<=o;++i){var a=t.getLine(i).indexOf(";");if(-1!=a)return{startCh:r.end,end:e.Pos(i,a)}}}var i,o=n.line,a=r(o);if(!a||r(o-1)||(i=r(o-2))&&i.end.line==o-1)return null;for(var s=a.end;;){var l=r(s.line+1);if(null==l)break;s=l.end}return{from:t.clipPos(e.Pos(o,a.startCh+1)),to:s}})),e.registerHelper("fold","include",(function(t,n){function r(n){if(n<t.firstLine()||n>t.lastLine())return null;var r=t.getTokenAt(e.Pos(n,1));return/\S/.test(r.string)||(r=t.getTokenAt(e.Pos(n,r.end+1))),"meta"==r.type&&"#include"==r.string.slice(0,8)?r.start+8:void 0}var i=n.line,o=r(i);if(null==o||null!=r(i-1))return null;for(var a=i;null!=r(a+1);)++a;return{from:e.Pos(i,o+1),to:t.clipPos(e.Pos(a))}}))}(n(14))},function(e,t,n){!function(e){"use strict";e.registerGlobalHelper("fold","comment",(function(e){return e.blockCommentStart&&e.blockCommentEnd}),(function(t,n){var r=t.getModeAt(n),i=r.blockCommentStart,o=r.blockCommentEnd;if(i&&o){for(var a,s=n.line,l=t.getLine(s),c=n.ch,u=0;;){var d=c<=0?-1:l.lastIndexOf(i,c-1);if(-1!=d){if(1==u&&d<n.ch)return;if(/comment/.test(t.getTokenTypeAt(e.Pos(s,d+1)))&&(0==d||l.slice(d-o.length,d)==o||!/comment/.test(t.getTokenTypeAt(e.Pos(s,d))))){a=d+i.length;break}c=d-1}else{if(1==u)return;u=1,c=l.length}}var h,p,f=1,m=t.lastLine();e:for(var g=s;g<=m;++g)for(var v=t.getLine(g),y=g==s?a:0;;){var _=v.indexOf(i,y),b=v.indexOf(o,y);if(_<0&&(_=v.length),b<0&&(b=v.length),(y=Math.min(_,b))==v.length)break;if(y==_)++f;else if(!--f){h=g,p=y;break e}++y}if(null!=h&&(s!=h||p!=a))return{from:e.Pos(s,a),to:e.Pos(h,p)}}}))}(n(14))},function(e,t,n){!function(e){"use strict";e.defineOption("foldGutter",!1,(function(t,r,i){var o;i&&i!=e.Init&&(t.clearGutter(t.state.foldGutter.options.gutter),t.state.foldGutter=null,t.off("gutterClick",l),t.off("changes",c),t.off("viewportChange",u),t.off("fold",d),t.off("unfold",d),t.off("swapDoc",c)),r&&(t.state.foldGutter=new n((!0===(o=r)&&(o={}),null==o.gutter&&(o.gutter="CodeMirror-foldgutter"),null==o.indicatorOpen&&(o.indicatorOpen="CodeMirror-foldgutter-open"),null==o.indicatorFolded&&(o.indicatorFolded="CodeMirror-foldgutter-folded"),o)),s(t),t.on("gutterClick",l),t.on("changes",c),t.on("viewportChange",u),t.on("fold",d),t.on("unfold",d),t.on("swapDoc",c))}));var t=e.Pos;function n(e){this.options=e,this.from=this.to=0}function r(e,n){for(var r=e.findMarks(t(n,0),t(n+1,0)),i=0;i<r.length;++i)if(r[i].__isFold){var o=r[i].find(-1);if(o&&o.line===n)return r[i]}}function i(e){if("string"==typeof e){var t=document.createElement("div");return t.className=e+" CodeMirror-guttermarker-subtle",t}return e.cloneNode(!0)}function o(e,n,o){var s=e.state.foldGutter.options,l=n-1,c=e.foldOption(s,"minFoldSize"),u=e.foldOption(s,"rangeFinder"),d="string"==typeof s.indicatorFolded&&a(s.indicatorFolded),h="string"==typeof s.indicatorOpen&&a(s.indicatorOpen);e.eachLine(n,o,(function(n){++l;var o=null,a=n.gutterMarkers;if(a&&(a=a[s.gutter]),r(e,l)){if(d&&a&&d.test(a.className))return;o=i(s.indicatorFolded)}else{var p=t(l,0),f=u&&u(e,p);if(f&&f.to.line-f.from.line>=c){if(h&&a&&h.test(a.className))return;o=i(s.indicatorOpen)}}(o||a)&&e.setGutterMarker(n,s.gutter,o)}))}function a(e){return new RegExp("(^|\\s)"+e+"(?:$|\\s)\\s*")}function s(e){var t=e.getViewport(),n=e.state.foldGutter;n&&(e.operation((function(){o(e,t.from,t.to)})),n.from=t.from,n.to=t.to)}function l(e,n,i){var o=e.state.foldGutter;if(o){var a=o.options;if(i==a.gutter){var s=r(e,n);s?s.clear():e.foldCode(t(n,0),a)}}}function c(e){var t=e.state.foldGutter;if(t){var n=t.options;t.from=t.to=0,clearTimeout(t.changeUpdate),t.changeUpdate=setTimeout((function(){s(e)}),n.foldOnChangeTimeSpan||600)}}function u(e){var t=e.state.foldGutter;if(t){var n=t.options;clearTimeout(t.changeUpdate),t.changeUpdate=setTimeout((function(){var n=e.getViewport();t.from==t.to||n.from-t.to>20||t.from-n.to>20?s(e):e.operation((function(){n.from<t.from&&(o(e,n.from,t.from),t.from=n.from),n.to>t.to&&(o(e,t.to,n.to),t.to=n.to)}))}),n.updateViewportTimeSpan||400)}}function d(e,t){var n=e.state.foldGutter;if(n){var r=t.line;r>=n.from&&r<n.to&&o(e,r,r+1)}}}(n(14),n(377))},function(e,t,n){!function(e){"use strict";function t(t,n){var r=t.getLine(n),i=r.search(/\S/);return-1==i||/\bcomment\b/.test(t.getTokenTypeAt(e.Pos(n,i+1)))?-1:e.countColumn(r,null,t.getOption("tabSize"))}e.registerHelper("fold","indent",(function(n,r){var i=t(n,r.line);if(!(i<0)){for(var o=null,a=r.line+1,s=n.lastLine();a<=s;++a){var l=t(n,a);if(-1==l);else{if(!(l>i))break;o=a}}return o?{from:e.Pos(r.line,n.getLine(r.line).length),to:e.Pos(o,n.getLine(o).length)}:void 0}}))}(n(14))},function(e,t,n){!function(e){"use strict";e.registerHelper("fold","markdown",(function(t,n){function r(n){var r=t.getTokenTypeAt(e.Pos(n,0));return r&&/\bheader\b/.test(r)}function i(e,t,n){var i=t&&t.match(/^#+/);return i&&r(e)?i[0].length:(i=n&&n.match(/^[=\-]+\s*$/))&&r(e+1)?"="==n[0]?1:2:100}var o=t.getLine(n.line),a=t.getLine(n.line+1),s=i(n.line,o,a);if(100!==s){for(var l=t.lastLine(),c=n.line,u=t.getLine(c+2);c<l&&!(i(c+1,a,u)<=s);)++c,a=u,u=t.getLine(c+2);return{from:e.Pos(n.line,o.length),to:e.Pos(c,t.getLine(c).length)}}}))}(n(14))},function(e,t,n){!function(e){"use strict";var t=e.Pos;function n(e,t){return e.line-t.line||e.ch-t.ch}var r="A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD",i=new RegExp("<(/?)(["+r+"]["+r+"-:.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*)","g");function o(e,t,n,r){this.line=t,this.ch=n,this.cm=e,this.text=e.getLine(t),this.min=r?Math.max(r.from,e.firstLine()):e.firstLine(),this.max=r?Math.min(r.to-1,e.lastLine()):e.lastLine()}function a(e,n){var r=e.cm.getTokenTypeAt(t(e.line,n));return r&&/\btag\b/.test(r)}function s(e){if(!(e.line>=e.max))return e.ch=0,e.text=e.cm.getLine(++e.line),!0}function l(e){if(!(e.line<=e.min))return e.text=e.cm.getLine(--e.line),e.ch=e.text.length,!0}function c(e){for(;;){var t=e.text.indexOf(">",e.ch);if(-1==t){if(s(e))continue;return}if(a(e,t+1)){var n=e.text.lastIndexOf("/",t),r=n>-1&&!/\S/.test(e.text.slice(n+1,t));return e.ch=t+1,r?"selfClose":"regular"}e.ch=t+1}}function u(e){for(;;){var t=e.ch?e.text.lastIndexOf("<",e.ch-1):-1;if(-1==t){if(l(e))continue;return}if(a(e,t+1)){i.lastIndex=t,e.ch=t;var n=i.exec(e.text);if(n&&n.index==t)return n}else e.ch=t}}function d(e){for(;;){i.lastIndex=e.ch;var t=i.exec(e.text);if(!t){if(s(e))continue;return}if(a(e,t.index+1))return e.ch=t.index+t[0].length,t;e.ch=t.index+1}}function h(e){for(;;){var t=e.ch?e.text.lastIndexOf(">",e.ch-1):-1;if(-1==t){if(l(e))continue;return}if(a(e,t+1)){var n=e.text.lastIndexOf("/",t),r=n>-1&&!/\S/.test(e.text.slice(n+1,t));return e.ch=t+1,r?"selfClose":"regular"}e.ch=t}}function p(e,n){for(var r=[];;){var i,o=d(e),a=e.line,s=e.ch-(o?o[0].length:0);if(!o||!(i=c(e)))return;if("selfClose"!=i)if(o[1]){for(var l=r.length-1;l>=0;--l)if(r[l]==o[2]){r.length=l;break}if(l<0&&(!n||n==o[2]))return{tag:o[2],from:t(a,s),to:t(e.line,e.ch)}}else r.push(o[2])}}function f(e,n){for(var r=[];;){var i=h(e);if(!i)return;if("selfClose"!=i){var o=e.line,a=e.ch,s=u(e);if(!s)return;if(s[1])r.push(s[2]);else{for(var l=r.length-1;l>=0;--l)if(r[l]==s[2]){r.length=l;break}if(l<0&&(!n||n==s[2]))return{tag:s[2],from:t(e.line,e.ch),to:t(o,a)}}}else u(e)}}e.registerHelper("fold","xml",(function(e,r){for(var i=new o(e,r.line,0);;){var a=d(i);if(!a||i.line!=r.line)return;var s=c(i);if(!s)return;if(!a[1]&&"selfClose"!=s){var l=t(i.line,i.ch),u=p(i,a[2]);return u&&n(u.from,l)>0?{from:l,to:u.from}:null}}})),e.findMatchingTag=function(e,r,i){var a=new o(e,r.line,r.ch,i);if(-1!=a.text.indexOf(">")||-1!=a.text.indexOf("<")){var s=c(a),l=s&&t(a.line,a.ch),d=s&&u(a);if(s&&d&&!(n(a,r)>0)){var h={from:t(a.line,a.ch),to:l,tag:d[2]};return"selfClose"==s?{open:h,close:null,at:"open"}:d[1]?{open:f(a,d[2]),close:h,at:"close"}:{open:h,close:p(a=new o(e,l.line,l.ch,i),d[2]),at:"open"}}}},e.findEnclosingTag=function(e,t,n,r){for(var i=new o(e,t.line,t.ch,n);;){var a=f(i,r);if(!a)break;var s=p(new o(e,t.line,t.ch,n),a.tag);if(s)return{open:a,close:s}}},e.scanForClosingTag=function(e,t,n,r){return p(new o(e,t.line,t.ch,r?{from:0,to:r}:null),n)}}(n(14))},function(e,t,n){!function(e){"use strict";function t(t,r){e.changeEnd(r).line==t.lastLine()&&n(t)}function n(e){var t="";e.lineCount()>1&&(t=e.display.scroller.clientHeight-30-e.getLineHandle(e.lastLine()).height+"px"),e.state.scrollPastEndPadding!=t&&(e.state.scrollPastEndPadding=t,e.display.lineSpace.parentNode.style.paddingBottom=t,e.off("refresh",n),e.setSize(),e.on("refresh",n))}e.defineOption("scrollPastEnd",!1,(function(r,i,o){o&&o!=e.Init&&(r.off("change",t),r.off("refresh",n),r.display.lineSpace.parentNode.style.paddingBottom="",r.state.scrollPastEndPadding=null),i&&(r.on("change",t),r.on("refresh",n),n(r))}))}(n(14))},function(e,t,n){!function(e){"use strict";function t(e,t){var n=Number(t);return/^[-+]/.test(t)?e.getCursor().line+n:n-1}e.defineOption("search",{bottom:!1}),e.commands.jumpToLine=function(e){var n=e.getCursor();!function(e,t,n,r,i){e.openDialog?e.openDialog(t,i,{value:r,selectValueOnOpen:!0,bottom:e.options.search.bottom}):i(prompt(n,r))}(e,function(e){return e.phrase("Jump to line:")+' <input type="text" style="width: 10em" class="CodeMirror-search-field"/> <span style="color: #888" class="CodeMirror-search-hint">'+e.phrase("(Use line:column or scroll% syntax)")+"</span>"}(e),e.phrase("Jump to line:"),n.line+1+":"+n.ch,(function(r){var i;if(r)if(i=/^\s*([\+\-]?\d+)\s*\:\s*(\d+)\s*$/.exec(r))e.setCursor(t(e,i[1]),Number(i[2]));else if(i=/^\s*([\+\-]?\d+(\.\d+)?)\%\s*/.exec(r)){var o=Math.round(e.lineCount()*Number(i[1])/100);/^[-+]/.test(i[1])&&(o=n.line+o+1),e.setCursor(o-1,n.ch)}else(i=/^\s*\:?\s*([\+\-]?\d+)\s*/.exec(r))&&e.setCursor(t(e,i[1]),n.ch)}))},e.keyMap.default["Alt-G"]="jumpToLine"}(n(14),n(378))},function(e,t,n){!function(e){"use strict";function t(){this.posFrom=this.posTo=this.lastQuery=this.query=null,this.overlay=null}function n(e){return e.state.search||(e.state.search=new t)}function r(e){return"string"==typeof e&&e==e.toLowerCase()}function i(e,t,n){return e.getSearchCursor(t,n,{caseFold:r(t),multiline:!0})}function o(e,t,n,r,i){e.openDialog?e.openDialog(t,i,{value:r,selectValueOnOpen:!0,bottom:e.options.search.bottom}):i(prompt(n,r))}function a(e){return e.replace(/\\([nrt\\])/g,(function(e,t){return"n"==t?"\n":"r"==t?"\r":"t"==t?"\t":"\\"==t?"\\":e}))}function s(e){var t=e.match(/^\/(.*)\/([a-z]*)$/);if(t)try{e=new RegExp(t[1],-1==t[2].indexOf("i")?"":"i")}catch(e){}else e=a(e);return("string"==typeof e?""==e:e.test(""))&&(e=/x^/),e}function l(e,t,n){t.queryText=n,t.query=s(n),e.removeOverlay(t.overlay,r(t.query)),t.overlay=function(e,t){return"string"==typeof e?e=new RegExp(e.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&"),t?"gi":"g"):e.global||(e=new RegExp(e.source,e.ignoreCase?"gi":"g")),{token:function(t){e.lastIndex=t.pos;var n=e.exec(t.string);if(n&&n.index==t.pos)return t.pos+=n[0].length||1,"searching";n?t.pos=n.index:t.skipToEnd()}}}(t.query,r(t.query)),e.addOverlay(t.overlay),e.showMatchesOnScrollbar&&(t.annotate&&(t.annotate.clear(),t.annotate=null),t.annotate=e.showMatchesOnScrollbar(t.query,r(t.query)))}function c(t,r,i,a){var s=n(t);if(s.query)return u(t,r);var c=t.getSelection()||s.lastQuery;if(c instanceof RegExp&&"x^"==c.source&&(c=null),i&&t.openDialog){var p=null,f=function(n,r){e.e_stop(r),n&&(n!=s.queryText&&(l(t,s,n),s.posFrom=s.posTo=t.getCursor()),p&&(p.style.opacity=1),u(t,r.shiftKey,(function(e,n){var r;n.line<3&&document.querySelector&&(r=t.display.wrapper.querySelector(".CodeMirror-dialog"))&&r.getBoundingClientRect().bottom-4>t.cursorCoords(n,"window").top&&((p=r).style.opacity=.4)})))};!function(e,t,n,r,i){e.openDialog(t,r,{value:n,selectValueOnOpen:!0,closeOnEnter:!1,onClose:function(){d(e)},onKeyDown:i,bottom:e.options.search.bottom})}(t,h(t),c,f,(function(r,i){var o=e.keyName(r),a=t.getOption("extraKeys"),s=a&&a[o]||e.keyMap[t.getOption("keyMap")][o];"findNext"==s||"findPrev"==s||"findPersistentNext"==s||"findPersistentPrev"==s?(e.e_stop(r),l(t,n(t),i),t.execCommand(s)):"find"!=s&&"findPersistent"!=s||(e.e_stop(r),f(i,r))})),a&&c&&(l(t,s,c),u(t,r))}else o(t,h(t),"Search for:",c,(function(e){e&&!s.query&&t.operation((function(){l(t,s,e),s.posFrom=s.posTo=t.getCursor(),u(t,r)}))}))}function u(t,r,o){t.operation((function(){var a=n(t),s=i(t,a.query,r?a.posFrom:a.posTo);(s.find(r)||(s=i(t,a.query,r?e.Pos(t.lastLine()):e.Pos(t.firstLine(),0))).find(r))&&(t.setSelection(s.from(),s.to()),t.scrollIntoView({from:s.from(),to:s.to()},20),a.posFrom=s.from(),a.posTo=s.to(),o&&o(s.from(),s.to()))}))}function d(e){e.operation((function(){var t=n(e);t.lastQuery=t.query,t.query&&(t.query=t.queryText=null,e.removeOverlay(t.overlay),t.annotate&&(t.annotate.clear(),t.annotate=null))}))}function h(e){return'<span class="CodeMirror-search-label">'+e.phrase("Search:")+'</span> <input type="text" style="width: 10em" class="CodeMirror-search-field"/> <span style="color: #888" class="CodeMirror-search-hint">'+e.phrase("(Use /re/ syntax for regexp search)")+"</span>"}function p(e,t,n){e.operation((function(){for(var r=i(e,t);r.findNext();)if("string"!=typeof t){var o=e.getRange(r.from(),r.to()).match(t);r.replace(n.replace(/\$(\d)/g,(function(e,t){return o[t]})))}else r.replace(n)}))}function f(e,t){if(!e.getOption("readOnly")){var r=e.getSelection()||n(e).lastQuery,l='<span class="CodeMirror-search-label">'+(t?e.phrase("Replace all:"):e.phrase("Replace:"))+"</span>";o(e,l+function(e){return' <input type="text" style="width: 10em" class="CodeMirror-search-field"/> <span style="color: #888" class="CodeMirror-search-hint">'+e.phrase("(Use /re/ syntax for regexp search)")+"</span>"}(e),l,r,(function(n){n&&(n=s(n),o(e,function(e){return'<span class="CodeMirror-search-label">'+e.phrase("With:")+'</span> <input type="text" style="width: 10em" class="CodeMirror-search-field"/>'}(e),e.phrase("Replace with:"),"",(function(r){if(r=a(r),t)p(e,n,r);else{d(e);var o=i(e,n,e.getCursor("from")),s=function(){var t,a=o.from();!(t=o.findNext())&&(o=i(e,n),!(t=o.findNext())||a&&o.from().line==a.line&&o.from().ch==a.ch)||(e.setSelection(o.from(),o.to()),e.scrollIntoView({from:o.from(),to:o.to()}),function(e,t,n,r){e.openConfirm?e.openConfirm(t,r):confirm(n)&&r[0]()}(e,function(e){return'<span class="CodeMirror-search-label">'+e.phrase("Replace?")+"</span> <button>"+e.phrase("Yes")+"</button> <button>"+e.phrase("No")+"</button> <button>"+e.phrase("All")+"</button> <button>"+e.phrase("Stop")+"</button> "}(e),e.phrase("Replace?"),[function(){l(t)},s,function(){p(e,n,r)}]))},l=function(e){o.replace("string"==typeof n?r:r.replace(/\$(\d)/g,(function(t,n){return e[n]}))),s()};s()}})))}))}}e.defineOption("search",{bottom:!1}),e.commands.find=function(e){d(e),c(e)},e.commands.findPersistent=function(e){d(e),c(e,!1,!0)},e.commands.findPersistentNext=function(e){c(e,!1,!0,!0)},e.commands.findPersistentPrev=function(e){c(e,!0,!0,!0)},e.commands.findNext=c,e.commands.findPrev=function(e){c(e,!0)},e.commands.clearSearch=d,e.commands.replace=f,e.commands.replaceAll=function(e){f(e,!0)}}(n(14),n(168),n(378))},function(e,t,n){!function(e){"use strict";var t="CodeMirror-activeline-background";function n(e){for(var n=0;n<e.state.activeLines.length;n++)e.removeLineClass(e.state.activeLines[n],"wrap","CodeMirror-activeline"),e.removeLineClass(e.state.activeLines[n],"background",t),e.removeLineClass(e.state.activeLines[n],"gutter","CodeMirror-activeline-gutter")}function r(e,r){for(var i=[],o=0;o<r.length;o++){var a=r[o],s=e.getOption("styleActiveLine");if("object"==typeof s&&s.nonEmpty?a.anchor.line==a.head.line:a.empty()){var l=e.getLineHandleVisualStart(a.head.line);i[i.length-1]!=l&&i.push(l)}}(function(e,t){if(e.length!=t.length)return!1;for(var n=0;n<e.length;n++)if(e[n]!=t[n])return!1;return!0})(e.state.activeLines,i)||e.operation((function(){n(e);for(var r=0;r<i.length;r++)e.addLineClass(i[r],"wrap","CodeMirror-activeline"),e.addLineClass(i[r],"background",t),e.addLineClass(i[r],"gutter","CodeMirror-activeline-gutter");e.state.activeLines=i}))}function i(e,t){r(e,t.ranges)}e.defineOption("styleActiveLine",!1,(function(t,o,a){var s=a!=e.Init&&a;o!=s&&(s&&(t.off("beforeSelectionChange",i),n(t),delete t.state.activeLines),o&&(t.state.activeLines=[],r(t,t.listSelections()),t.on("beforeSelectionChange",i)))}))}(n(14))},function(e,t,n){!function(e){"use strict";function t(e){e.state.markedSelection&&e.operation((function(){!function(e){if(!e.somethingSelected())return a(e);if(e.listSelections().length>1)return s(e);var t=e.getCursor("start"),n=e.getCursor("end"),r=e.state.markedSelection;if(!r.length)return o(e,t,n);var l=r[0].find(),c=r[r.length-1].find();if(!l||!c||n.line-t.line<=8||i(t,c.to)>=0||i(n,l.from)<=0)return s(e);for(;i(t,l.from)>0;)r.shift().clear(),l=r[0].find();for(i(t,l.from)<0&&(l.to.line-t.line<8?(r.shift().clear(),o(e,t,l.to,0)):o(e,t,l.from,0));i(n,c.to)<0;)r.pop().clear(),c=r[r.length-1].find();i(n,c.to)>0&&(n.line-c.from.line<8?(r.pop().clear(),o(e,c.from,n)):o(e,c.to,n))}(e)}))}function n(e){e.state.markedSelection&&e.state.markedSelection.length&&e.operation((function(){a(e)}))}e.defineOption("styleSelectedText",!1,(function(r,i,o){var l=o&&o!=e.Init;i&&!l?(r.state.markedSelection=[],r.state.markedSelectionStyle="string"==typeof i?i:"CodeMirror-selectedtext",s(r),r.on("cursorActivity",t),r.on("change",n)):!i&&l&&(r.off("cursorActivity",t),r.off("change",n),a(r),r.state.markedSelection=r.state.markedSelectionStyle=null)}));var r=e.Pos,i=e.cmpPos;function o(e,t,n,o){if(0!=i(t,n))for(var a=e.state.markedSelection,s=e.state.markedSelectionStyle,l=t.line;;){var c=l==t.line?t:r(l,0),u=l+8,d=u>=n.line,h=d?n:r(u,0),p=e.markText(c,h,{className:s});if(null==o?a.push(p):a.splice(o++,0,p),d)break;l=u}}function a(e){for(var t=e.state.markedSelection,n=0;n<t.length;++n)t[n].clear();t.length=0}function s(e){a(e);for(var t=e.listSelections(),n=0;n<t.length;n++)o(e,t[n].from(),t[n].to())}}(n(14))},function(e,t,n){!function(e){"use strict";function t(e){e.state.selectionPointer.rects=null,n(e)}function n(e){e.state.selectionPointer.willUpdate||(e.state.selectionPointer.willUpdate=!0,setTimeout((function(){!function(e){var t=e.state.selectionPointer;if(t){if(null==t.rects&&null!=t.mouseX&&(t.rects=[],e.somethingSelected()))for(var n=e.display.selectionDiv.firstChild;n;n=n.nextSibling)t.rects.push(n.getBoundingClientRect());var r=!1;if(null!=t.mouseX)for(var i=0;i<t.rects.length;i++){var o=t.rects[i];o.left<=t.mouseX&&o.right>=t.mouseX&&o.top<=t.mouseY&&o.bottom>=t.mouseY&&(r=!0)}var a=r?t.value:"";e.display.lineDiv.style.cursor!=a&&(e.display.lineDiv.style.cursor=a)}}(e),e.state.selectionPointer.willUpdate=!1}),50))}e.defineOption("selectionPointer",!1,(function(r,i){var o=r.state.selectionPointer;o&&(e.off(r.getWrapperElement(),"mousemove",o.mousemove),e.off(r.getWrapperElement(),"mouseout",o.mouseout),e.off(window,"scroll",o.windowScroll),r.off("cursorActivity",t),r.off("scroll",t),r.state.selectionPointer=null,r.display.lineDiv.style.cursor=""),i&&(o=r.state.selectionPointer={value:"string"==typeof i?i:"default",mousemove:function(e){!function(e,t){var r=e.state.selectionPointer;(null==t.buttons?t.which:t.buttons)?r.mouseX=r.mouseY=null:(r.mouseX=t.clientX,r.mouseY=t.clientY),n(e)}(r,e)},mouseout:function(e){!function(e,t){if(!e.getWrapperElement().contains(t.relatedTarget)){var r=e.state.selectionPointer;r.mouseX=r.mouseY=null,n(e)}}(r,e)},windowScroll:function(){t(r)},rects:null,mouseX:null,mouseY:null,willUpdate:!1},e.on(r.getWrapperElement(),"mousemove",o.mousemove),e.on(r.getWrapperElement(),"mouseout",o.mouseout),e.on(window,"scroll",o.windowScroll),r.on("cursorActivity",t),r.on("scroll",t))}))}(n(14))},function(e,t,n){var r;(r=n(14)).defineOption("showTrailingSpace",!1,(function(e,t,n){n==r.Init&&(n=!1),n&&!t?e.removeOverlay("trailingspace"):!n&&t&&e.addOverlay({token:function(e){for(var t=e.string.length,n=t;n&&/\s/.test(e.string.charAt(n-1));--n);return n>e.pos?(e.pos=n,null):(e.pos=t,"trailingspace")},name:"trailingspace"})}))},function(e,t,n){!function(e){"use strict";var t=e.commands,n=e.Pos;function r(e,t){return e.line==t.line&&e.ch==t.ch}var i=[];function o(e){i.push(e),i.length>50&&i.shift()}function a(e){return i[i.length-(e?Math.min(e,1):1)]||""}var s=null;function l(e,t,n,a,l){null==l&&(l=e.getRange(t,n)),"grow"==a&&s&&s.cm==e&&r(t,s.pos)&&e.isClean(s.gen)?function(e){if(!i.length)return o(e);i[i.length-1]+=e}(l):!1!==a&&o(l),e.replaceRange("",t,n,"+delete"),s="grow"==a?{cm:e,pos:t,gen:e.changeGeneration()}:null}function c(e,t,n){return e.findPosH(t,n,"char",!0)}function u(e,t,n){return e.findPosH(t,n,"word",!0)}function d(e,t,n){return e.findPosV(t,n,"line",e.doc.sel.goalColumn)}function h(e,t,n){return e.findPosV(t,n,"page",e.doc.sel.goalColumn)}function p(e,t,r){for(var i=t.line,o=e.getLine(i),a=/\S/.test(r<0?o.slice(0,t.ch):o.slice(t.ch)),s=e.firstLine(),l=e.lastLine();;){if((i+=r)<s||i>l)return e.clipPos(n(i-r,r<0?0:null));if(o=e.getLine(i),/\S/.test(o))a=!0;else if(a)return n(i,0)}}function f(e,t,r){for(var i=t.line,o=t.ch,a=e.getLine(t.line),s=!1;;){var l=a.charAt(o+(r<0?-1:0));if(l){if(s&&/[!?.]/.test(l))return n(i,o+(r>0?1:0));s||(s=/\w/.test(l)),o+=r}else{if(i==(r<0?e.firstLine():e.lastLine()))return n(i,o);if(a=e.getLine(i+r),!/\S/.test(a))return n(i,o);i+=r,o=r<0?a.length:0}}}function m(e,t,i){var o;if(e.findMatchingBracket&&(o=e.findMatchingBracket(t,{strict:!0}))&&o.match&&(o.forward?1:-1)==i)return i>0?n(o.to.line,o.to.ch+1):o.to;for(var a=!0;;a=!1){var s=e.getTokenAt(t),l=n(t.line,i<0?s.start:s.end);if(!(a&&i>0&&s.end==t.ch)&&/\w/.test(s.string))return l;var c=e.findPosH(l,i,"char");if(r(l,c))return t;t=c}}function g(e,t){var n=e.state.emacsPrefix;return n?(x(e),"-"==n?-1:Number(n)):t?null:1}function v(e){var t="string"==typeof e?function(t){t.execCommand(e)}:e;return function(e){var n=g(e);t(e);for(var r=1;r<n;++r)t(e)}}function y(e,t,n,i){var o=g(e);o<0&&(i=-i,o=-o);for(var a=0;a<o;++a){var s=n(e,t,i);if(r(s,t))break;t=s}return t}function _(e,t){var n=function(n){n.extendSelection(y(n,n.getCursor(),e,t))};return n.motion=!0,n}function b(e,t,n,r){for(var i,o=e.listSelections(),a=o.length;a--;)l(e,i=o[a].head,y(e,i,t,n),r)}function M(e,t){if(e.somethingSelected()){for(var n,r=e.listSelections(),i=r.length;i--;)l(e,(n=r[i]).anchor,n.head,t);return!0}}function w(e,t){e.state.emacsPrefix?"-"!=t&&(e.state.emacsPrefix+=t):(e.state.emacsPrefix=t,e.on("keyHandled",C),e.on("inputRead",E))}var A={"Alt-G":!0,"Ctrl-X":!0,"Ctrl-Q":!0,"Ctrl-U":!0};function C(e,t){e.state.emacsPrefixMap||A.hasOwnProperty(t)||x(e)}function x(e){e.state.emacsPrefix=null,e.off("keyHandled",C),e.off("inputRead",E)}function E(e,t){var n=g(e);if(n>1&&"+input"==t.origin){for(var r=t.text.join("\n"),i="",o=1;o<n;++o)i+=r;e.replaceSelection(i)}}function L(e,t){("string"!=typeof t||!/^\d$/.test(t)&&"Ctrl-U"!=t)&&(e.removeKeyMap(k),e.state.emacsPrefixMap=!1,e.off("keyHandled",L),e.off("inputRead",L))}function S(e){e.setExtending(!1),e.setCursor(e.getCursor())}function T(e,t,n){e.openDialog?e.openDialog(function(e){var t=document.createDocumentFragment(),n=document.createElement("input");return n.setAttribute("type","text"),n.style.width="10em",t.appendChild(document.createTextNode(e+": ")),t.appendChild(n),t}(t),n,{bottom:!0}):n(prompt(t,""))}function O(e,t){var n=e.getCursor(),r=e.findPosH(n,1,"word");e.replaceRange(t(e.getRange(n,r)),n,r),e.setCursor(r)}t.setMark=function(e){e.setCursor(e.getCursor()),e.setExtending(!e.getExtending()),e.on("change",(function(){e.setExtending(!1)}))},t.killRegion=function(e){l(e,e.getCursor("start"),e.getCursor("end"),!0)},t.killLineEmacs=v((function(e){var t=e.getCursor(),r=e.clipPos(n(t.line)),i=e.getRange(t,r);/\S/.test(i)||(i+="\n",r=n(t.line+1,0)),l(e,t,r,"grow",i)})),t.killRingSave=function(e){o(e.getSelection()),S(e)},t.yank=function(e){var t=e.getCursor();e.replaceRange(a(g(e)),t,t,"paste"),e.setSelection(t,e.getCursor())},t.yankPop=function(e){e.replaceSelection((i.length>1&&i.pop(),a()),"around","paste")},t.forwardChar=_(c,1),t.backwardChar=_(c,-1),t.deleteChar=function(e){b(e,c,1,!1)},t.deleteForwardChar=function(e){M(e,!1)||b(e,c,1,!1)},t.deleteBackwardChar=function(e){M(e,!1)||b(e,c,-1,!1)},t.forwardWord=_(u,1),t.backwardWord=_(u,-1),t.killWord=function(e){b(e,u,1,"grow")},t.backwardKillWord=function(e){b(e,u,-1,"grow")},t.nextLine=_(d,1),t.previousLine=_(d,-1),t.scrollDownCommand=_(h,1),t.scrollUpCommand=_(h,-1),t.backwardParagraph=_(p,-1),t.forwardParagraph=_(p,1),t.backwardSentence=_(f,-1),t.forwardSentence=_(f,1),t.killSentence=function(e){b(e,f,1,"grow")},t.backwardKillSentence=function(e){l(e,e.getCursor(),f(e,e.getCursor(),1),"grow")},t.killSexp=function(e){b(e,m,1,"grow")},t.backwardKillSexp=function(e){b(e,m,-1,"grow")},t.forwardSexp=_(m,1),t.backwardSexp=_(m,-1),t.markSexp=function(e){var t=e.getCursor();e.setSelection(y(e,t,m,1),t)},t.transposeSexps=function(e){var t=m(e,e.getCursor(),-1),n=m(e,t,1),r=m(e,n,1),i=m(e,r,-1);e.replaceRange(e.getRange(i,r)+e.getRange(n,i)+e.getRange(t,n),t,r)},t.backwardUpList=v((function(e){for(var t=e.getCursor(),r=t.line,i=t.ch,o=[];r>=e.firstLine();){for(var a=e.getLine(r),s=null==i?a.length:i;s>0;)if(")"==(i=a.charAt(--s)))o.push("(");else if("]"==i)o.push("[");else if("}"==i)o.push("{");else if(/[\(\{\[]/.test(i)&&(!o.length||o.pop()!=i))return e.extendSelection(n(r,s));--r,i=null}})),t.justOneSpace=function(e){for(var t=e.getCursor(),r=t.ch,i=t.ch,o=e.getLine(t.line);r&&/\s/.test(o.charAt(r-1));)--r;for(;i<o.length&&/\s/.test(o.charAt(i));)++i;e.replaceRange(" ",n(t.line,r),n(t.line,i))},t.openLine=v((function(e){e.replaceSelection("\n","start")})),t.transposeCharsRepeatable=v((function(e){e.execCommand("transposeChars")})),t.capitalizeWord=v((function(e){O(e,(function(e){var t=e.search(/\w/);return-1==t?e:e.slice(0,t)+e.charAt(t).toUpperCase()+e.slice(t+1).toLowerCase()}))})),t.upcaseWord=v((function(e){O(e,(function(e){return e.toUpperCase()}))})),t.downcaseWord=v((function(e){O(e,(function(e){return e.toLowerCase()}))})),t.undoRepeatable=v("undo"),t.keyboardQuit=function(e){e.execCommand("clearSearch"),S(e)},t.newline=v((function(e){e.replaceSelection("\n","end")})),t.gotoLine=function(e){var t=g(e,!0);if(null!=t&&t>0)return e.setCursor(t-1);T(e,"Goto line",(function(t){var n;t&&!isNaN(n=Number(t))&&n==(0|n)&&n>0&&e.setCursor(n-1)}))},t.indentRigidly=function(e){e.indentSelection(g(e,!0)||e.getOption("indentUnit"))},t.exchangePointAndMark=function(e){e.setSelection(e.getCursor("head"),e.getCursor("anchor"))},t.quotedInsertTab=v("insertTab"),t.universalArgument=function(e){e.state.emacsPrefixMap=!0,e.addKeyMap(k),e.on("keyHandled",L),e.on("inputRead",L)},e.emacs={kill:l,killRegion:M,repeated:v};var I=e.keyMap.emacs=e.normalizeKeyMap({"Ctrl-W":"killRegion","Ctrl-K":"killLineEmacs","Alt-W":"killRingSave","Ctrl-Y":"yank","Alt-Y":"yankPop","Ctrl-Space":"setMark","Ctrl-Shift-2":"setMark","Ctrl-F":"forwardChar","Ctrl-B":"backwardChar",Right:"forwardChar",Left:"backwardChar","Ctrl-D":"deleteChar",Delete:"deleteForwardChar","Ctrl-H":"deleteBackwardChar",Backspace:"deleteBackwardChar","Alt-F":"forwardWord","Alt-B":"backwardWord","Alt-Right":"forwardWord","Alt-Left":"backwardWord","Alt-D":"killWord","Alt-Backspace":"backwardKillWord","Ctrl-N":"nextLine","Ctrl-P":"previousLine",Down:"nextLine",Up:"previousLine","Ctrl-A":"goLineStart","Ctrl-E":"goLineEnd",End:"goLineEnd",Home:"goLineStart","Alt-V":"scrollDownCommand","Ctrl-V":"scrollUpCommand",PageUp:"scrollUpCommand",PageDown:"scrollDownCommand","Ctrl-Up":"backwardParagraph","Ctrl-Down":"forwardParagraph","Alt-{":"backwardParagraph","Alt-}":"forwardParagraph","Alt-A":"backwardSentence","Alt-E":"forwardSentence","Alt-K":"killSentence","Ctrl-X Delete":"backwardKillSentence","Ctrl-Alt-K":"killSexp","Ctrl-Alt-Backspace":"backwardKillSexp","Ctrl-Alt-F":"forwardSexp","Ctrl-Alt-B":"backwardSexp","Shift-Ctrl-Alt-2":"markSexp","Ctrl-Alt-T":"transposeSexps","Ctrl-Alt-U":"backwardUpList","Alt-Space":"justOneSpace","Ctrl-O":"openLine","Ctrl-T":"transposeCharsRepeatable","Alt-C":"capitalizeWord","Alt-U":"upcaseWord","Alt-L":"downcaseWord","Alt-;":"toggleComment","Ctrl-/":"undoRepeatable","Shift-Ctrl--":"undoRepeatable","Ctrl-Z":"undoRepeatable","Cmd-Z":"undoRepeatable","Ctrl-X U":"undoRepeatable","Shift-Ctrl-Z":"redo","Shift-Alt-,":"goDocStart","Shift-Alt-.":"goDocEnd","Ctrl-S":"findPersistentNext","Ctrl-R":"findPersistentPrev","Ctrl-G":"keyboardQuit","Shift-Alt-5":"replace","Alt-/":"autocomplete",Enter:"newlineAndIndent","Ctrl-J":"newline",Tab:"indentAuto","Alt-G G":"gotoLine","Ctrl-X Tab":"indentRigidly","Ctrl-X Ctrl-X":"exchangePointAndMark","Ctrl-X Ctrl-S":"save","Ctrl-X Ctrl-W":"save","Ctrl-X S":"saveAll","Ctrl-X F":"open","Ctrl-X K":"close","Ctrl-X H":"selectAll","Ctrl-Q Tab":"quotedInsertTab","Ctrl-U":"universalArgument",fallthrough:"default"}),k={"Ctrl-G":x};function D(e){k[e]=function(t){w(t,e)},I["Ctrl-"+e]=function(t){w(t,e)},A["Ctrl-"+e]=!0}for(var N=0;N<10;++N)D(String(N));D("-")}(n(14))},function(e,t,n){!function(e){"use strict";var t=e.commands,n=e.Pos;function r(t,r){t.extendSelectionsBy((function(i){return t.display.shift||t.doc.extend||i.empty()?function(t,r,i){if(i<0&&0==r.ch)return t.clipPos(n(r.line-1));var o=t.getLine(r.line);if(i>0&&r.ch>=o.length)return t.clipPos(n(r.line+1,0));for(var a,s="start",l=r.ch,c=l,u=i<0?0:o.length,d=0;c!=u;c+=i,d++){var h=o.charAt(i<0?c-1:c),p="_"!=h&&e.isWordChar(h)?"w":"o";if("w"==p&&h.toUpperCase()==h&&(p="W"),"start"==s)"o"!=p?(s="in",a=p):l=c+i;else if("in"==s&&a!=p){if("w"==a&&"W"==p&&i<0&&c--,"W"==a&&"w"==p&&i>0){if(c==l+1){a="w";continue}c--}break}}return n(r.line,c)}(t.doc,i.head,r):r<0?i.from():i.to()}))}function i(t,r){if(t.isReadOnly())return e.Pass;t.operation((function(){for(var e=t.listSelections().length,i=[],o=-1,a=0;a<e;a++){var s=t.listSelections()[a].head;if(!(s.line<=o)){var l=n(s.line+(r?0:1),0);t.replaceRange("\n",l,null,"+insertLine"),t.indentLine(l.line,null,!0),i.push({head:l,anchor:l}),o=s.line+1}}t.setSelections(i)})),t.execCommand("indentAuto")}function o(t,r){for(var i=r.ch,o=i,a=t.getLine(r.line);i&&e.isWordChar(a.charAt(i-1));)--i;for(;o<a.length&&e.isWordChar(a.charAt(o));)++o;return{from:n(r.line,i),to:n(r.line,o),word:a.slice(i,o)}}function a(e,t){for(var n=e.listSelections(),r=[],i=0;i<n.length;i++){var o=n[i],a=e.findPosV(o.anchor,t,"line",o.anchor.goalColumn),s=e.findPosV(o.head,t,"line",o.head.goalColumn);a.goalColumn=null!=o.anchor.goalColumn?o.anchor.goalColumn:e.cursorCoords(o.anchor,"div").left,s.goalColumn=null!=o.head.goalColumn?o.head.goalColumn:e.cursorCoords(o.head,"div").left;var l={anchor:a,head:s};r.push(o),r.push(l)}e.setSelections(r)}function s(t){for(var r=t.listSelections(),i=[],o=0;o<r.length;o++){var a=r[o],s=a.head,l=t.scanForBracket(s,-1);if(!l)return!1;for(;;){var c=t.scanForBracket(s,1);if(!c)return!1;if(c.ch=="(){}[]".charAt("(){}[]".indexOf(l.ch)+1)){var u=n(l.pos.line,l.pos.ch+1);if(0!=e.cmpPos(u,a.from())||0!=e.cmpPos(c.pos,a.to())){i.push({anchor:u,head:c.pos});break}if(!(l=t.scanForBracket(l.pos,-1)))return!1}s=n(c.pos.line,c.pos.ch+1)}}return t.setSelections(i),!0}function l(e){return e?/\bpunctuation\b/.test(e)?e:void 0:null}function c(t,r,i){if(t.isReadOnly())return e.Pass;for(var o,a=t.listSelections(),s=[],l=0;l<a.length;l++){var c=a[l];if(!c.empty()){for(var u=c.from().line,d=c.to().line;l<a.length-1&&a[l+1].from().line==d;)d=a[++l].to().line;a[l].to().ch||d--,s.push(u,d)}}s.length?o=!0:s.push(t.firstLine(),t.lastLine()),t.operation((function(){for(var e=[],a=0;a<s.length;a+=2){var l=s[a],c=s[a+1],u=n(l,0),d=n(c),h=t.getRange(u,d,!1);r?h.sort((function(e,t){return e<t?-i:e==t?0:i})):h.sort((function(e,t){var n=e.toUpperCase(),r=t.toUpperCase();return n!=r&&(e=n,t=r),e<t?-i:e==t?0:i})),t.replaceRange(h,u,d),o&&e.push({anchor:u,head:n(c+1,0)})}o&&t.setSelections(e,0)}))}function u(t,n){t.operation((function(){for(var r=t.listSelections(),i=[],a=[],s=0;s<r.length;s++)(c=r[s]).empty()?(i.push(s),a.push("")):a.push(n(t.getRange(c.from(),c.to())));var l;for(t.replaceSelections(a,"around","case"),s=i.length-1;s>=0;s--){var c=r[i[s]];if(!(l&&e.cmpPos(c.head,l)>0)){var u=o(t,c.head);l=u.from,t.replaceRange(n(u.word),u.from,u.to)}}}))}function d(t){var n=t.getCursor("from"),r=t.getCursor("to");if(0==e.cmpPos(n,r)){var i=o(t,n);if(!i.word)return;n=i.from,r=i.to}return{from:n,to:r,query:t.getRange(n,r),word:i}}function h(e,t){var r=d(e);if(r){var i=r.query,o=e.getSearchCursor(i,t?r.to:r.from);(t?o.findNext():o.findPrevious())?e.setSelection(o.from(),o.to()):(o=e.getSearchCursor(i,t?n(e.firstLine(),0):e.clipPos(n(e.lastLine()))),(t?o.findNext():o.findPrevious())?e.setSelection(o.from(),o.to()):r.word&&e.setSelection(r.from,r.to))}}t.goSubwordLeft=function(e){r(e,-1)},t.goSubwordRight=function(e){r(e,1)},t.scrollLineUp=function(e){var t=e.getScrollInfo();if(!e.somethingSelected()){var n=e.lineAtHeight(t.top+t.clientHeight,"local");e.getCursor().line>=n&&e.execCommand("goLineUp")}e.scrollTo(null,t.top-e.defaultTextHeight())},t.scrollLineDown=function(e){var t=e.getScrollInfo();if(!e.somethingSelected()){var n=e.lineAtHeight(t.top,"local")+1;e.getCursor().line<=n&&e.execCommand("goLineDown")}e.scrollTo(null,t.top+e.defaultTextHeight())},t.splitSelectionByLine=function(e){for(var t=e.listSelections(),r=[],i=0;i<t.length;i++)for(var o=t[i].from(),a=t[i].to(),s=o.line;s<=a.line;++s)a.line>o.line&&s==a.line&&0==a.ch||r.push({anchor:s==o.line?o:n(s,0),head:s==a.line?a:n(s)});e.setSelections(r,0)},t.singleSelectionTop=function(e){var t=e.listSelections()[0];e.setSelection(t.anchor,t.head,{scroll:!1})},t.selectLine=function(e){for(var t=e.listSelections(),r=[],i=0;i<t.length;i++){var o=t[i];r.push({anchor:n(o.from().line,0),head:n(o.to().line+1,0)})}e.setSelections(r)},t.insertLineAfter=function(e){return i(e,!1)},t.insertLineBefore=function(e){return i(e,!0)},t.selectNextOccurrence=function(t){var r=t.getCursor("from"),i=t.getCursor("to"),a=t.state.sublimeFindFullWord==t.doc.sel;if(0==e.cmpPos(r,i)){var s=o(t,r);if(!s.word)return;t.setSelection(s.from,s.to),a=!0}else{var l=t.getRange(r,i),c=a?new RegExp("\\b"+l+"\\b"):l,u=t.getSearchCursor(c,i),d=u.findNext();if(d||(d=(u=t.getSearchCursor(c,n(t.firstLine(),0))).findNext()),!d||function(t,n,r){for(var i=0;i<t.length;i++)if(0==e.cmpPos(t[i].from(),n)&&0==e.cmpPos(t[i].to(),r))return!0;return!1}(t.listSelections(),u.from(),u.to()))return;t.addSelection(u.from(),u.to())}a&&(t.state.sublimeFindFullWord=t.doc.sel)},t.skipAndSelectNextOccurrence=function(n){var r=n.getCursor("anchor"),i=n.getCursor("head");t.selectNextOccurrence(n),0!=e.cmpPos(r,i)&&n.doc.setSelections(n.doc.listSelections().filter((function(e){return e.anchor!=r||e.head!=i})))},t.addCursorToPrevLine=function(e){a(e,-1)},t.addCursorToNextLine=function(e){a(e,1)},t.selectScope=function(e){s(e)||e.execCommand("selectAll")},t.selectBetweenBrackets=function(t){if(!s(t))return e.Pass},t.goToBracket=function(t){t.extendSelectionsBy((function(r){var i=t.scanForBracket(r.head,1,l(t.getTokenTypeAt(r.head)));if(i&&0!=e.cmpPos(i.pos,r.head))return i.pos;var o=t.scanForBracket(r.head,-1,l(t.getTokenTypeAt(n(r.head.line,r.head.ch+1))));return o&&n(o.pos.line,o.pos.ch+1)||r.head}))},t.swapLineUp=function(t){if(t.isReadOnly())return e.Pass;for(var r=t.listSelections(),i=[],o=t.firstLine()-1,a=[],s=0;s<r.length;s++){var l=r[s],c=l.from().line-1,u=l.to().line;a.push({anchor:n(l.anchor.line-1,l.anchor.ch),head:n(l.head.line-1,l.head.ch)}),0!=l.to().ch||l.empty()||--u,c>o?i.push(c,u):i.length&&(i[i.length-1]=u),o=u}t.operation((function(){for(var e=0;e<i.length;e+=2){var r=i[e],o=i[e+1],s=t.getLine(r);t.replaceRange("",n(r,0),n(r+1,0),"+swapLine"),o>t.lastLine()?t.replaceRange("\n"+s,n(t.lastLine()),null,"+swapLine"):t.replaceRange(s+"\n",n(o,0),null,"+swapLine")}t.setSelections(a),t.scrollIntoView()}))},t.swapLineDown=function(t){if(t.isReadOnly())return e.Pass;for(var r=t.listSelections(),i=[],o=t.lastLine()+1,a=r.length-1;a>=0;a--){var s=r[a],l=s.to().line+1,c=s.from().line;0!=s.to().ch||s.empty()||l--,l<o?i.push(l,c):i.length&&(i[i.length-1]=c),o=c}t.operation((function(){for(var e=i.length-2;e>=0;e-=2){var r=i[e],o=i[e+1],a=t.getLine(r);r==t.lastLine()?t.replaceRange("",n(r-1),n(r),"+swapLine"):t.replaceRange("",n(r,0),n(r+1,0),"+swapLine"),t.replaceRange(a+"\n",n(o,0),null,"+swapLine")}t.scrollIntoView()}))},t.toggleCommentIndented=function(e){e.toggleComment({indent:!0})},t.joinLines=function(e){for(var t=e.listSelections(),r=[],i=0;i<t.length;i++){for(var o=t[i],a=o.from(),s=a.line,l=o.to().line;i<t.length-1&&t[i+1].from().line==l;)l=t[++i].to().line;r.push({start:s,end:l,anchor:!o.empty()&&a})}e.operation((function(){for(var t=0,i=[],o=0;o<r.length;o++){for(var a,s=r[o],l=s.anchor&&n(s.anchor.line-t,s.anchor.ch),c=s.start;c<=s.end;c++){var u=c-t;c==s.end&&(a=n(u,e.getLine(u).length+1)),u<e.lastLine()&&(e.replaceRange(" ",n(u),n(u+1,/^\s*/.exec(e.getLine(u+1))[0].length)),++t)}i.push({anchor:l||a,head:a})}e.setSelections(i,0)}))},t.duplicateLine=function(e){e.operation((function(){for(var t=e.listSelections().length,r=0;r<t;r++){var i=e.listSelections()[r];i.empty()?e.replaceRange(e.getLine(i.head.line)+"\n",n(i.head.line,0)):e.replaceRange(e.getRange(i.from(),i.to()),i.from())}e.scrollIntoView()}))},t.sortLines=function(e){c(e,!0,1)},t.reverseSortLines=function(e){c(e,!0,-1)},t.sortLinesInsensitive=function(e){c(e,!1,1)},t.reverseSortLinesInsensitive=function(e){c(e,!1,-1)},t.nextBookmark=function(e){var t=e.state.sublimeBookmarks;if(t)for(;t.length;){var n=t.shift(),r=n.find();if(r)return t.push(n),e.setSelection(r.from,r.to)}},t.prevBookmark=function(e){var t=e.state.sublimeBookmarks;if(t)for(;t.length;){t.unshift(t.pop());var n=t[t.length-1].find();if(n)return e.setSelection(n.from,n.to);t.pop()}},t.toggleBookmark=function(e){for(var t=e.listSelections(),n=e.state.sublimeBookmarks||(e.state.sublimeBookmarks=[]),r=0;r<t.length;r++){for(var i=t[r].from(),o=t[r].to(),a=t[r].empty()?e.findMarksAt(i):e.findMarks(i,o),s=0;s<a.length;s++)if(a[s].sublimeBookmark){a[s].clear();for(var l=0;l<n.length;l++)n[l]==a[s]&&n.splice(l--,1);break}s==a.length&&n.push(e.markText(i,o,{sublimeBookmark:!0,clearWhenEmpty:!1}))}},t.clearBookmarks=function(e){var t=e.state.sublimeBookmarks;if(t)for(var n=0;n<t.length;n++)t[n].clear();t.length=0},t.selectBookmarks=function(e){var t=e.state.sublimeBookmarks,n=[];if(t)for(var r=0;r<t.length;r++){var i=t[r].find();i?n.push({anchor:i.from,head:i.to}):t.splice(r--,0)}n.length&&e.setSelections(n,0)},t.smartBackspace=function(t){if(t.somethingSelected())return e.Pass;t.operation((function(){for(var r=t.listSelections(),i=t.getOption("indentUnit"),o=r.length-1;o>=0;o--){var a=r[o].head,s=t.getRange({line:a.line,ch:0},a),l=e.countColumn(s,null,t.getOption("tabSize")),c=t.findPosH(a,-1,"char",!1);if(s&&!/\S/.test(s)&&l%i==0){var u=new n(a.line,e.findColumn(s,l-i,i));u.ch!=a.ch&&(c=u)}t.replaceRange("",c,a,"+delete")}}))},t.delLineRight=function(e){e.operation((function(){for(var t=e.listSelections(),r=t.length-1;r>=0;r--)e.replaceRange("",t[r].anchor,n(t[r].to().line),"+delete");e.scrollIntoView()}))},t.upcaseAtCursor=function(e){u(e,(function(e){return e.toUpperCase()}))},t.downcaseAtCursor=function(e){u(e,(function(e){return e.toLowerCase()}))},t.setSublimeMark=function(e){e.state.sublimeMark&&e.state.sublimeMark.clear(),e.state.sublimeMark=e.setBookmark(e.getCursor())},t.selectToSublimeMark=function(e){var t=e.state.sublimeMark&&e.state.sublimeMark.find();t&&e.setSelection(e.getCursor(),t)},t.deleteToSublimeMark=function(t){var n=t.state.sublimeMark&&t.state.sublimeMark.find();if(n){var r=t.getCursor(),i=n;if(e.cmpPos(r,i)>0){var o=i;i=r,r=o}t.state.sublimeKilled=t.getRange(r,i),t.replaceRange("",r,i)}},t.swapWithSublimeMark=function(e){var t=e.state.sublimeMark&&e.state.sublimeMark.find();t&&(e.state.sublimeMark.clear(),e.state.sublimeMark=e.setBookmark(e.getCursor()),e.setCursor(t))},t.sublimeYank=function(e){null!=e.state.sublimeKilled&&e.replaceSelection(e.state.sublimeKilled,null,"paste")},t.showInCenter=function(e){var t=e.cursorCoords(null,"local");e.scrollTo(null,(t.top+t.bottom)/2-e.getScrollInfo().clientHeight/2)},t.findUnder=function(e){h(e,!0)},t.findUnderPrevious=function(e){h(e,!1)},t.findAllUnder=function(e){var t=d(e);if(t){for(var n=e.getSearchCursor(t.query),r=[],i=-1;n.findNext();)r.push({anchor:n.from(),head:n.to()}),n.from().line<=t.from.line&&n.from().ch<=t.from.ch&&i++;e.setSelections(r,i)}};var p=e.keyMap;p.macSublime={"Cmd-Left":"goLineStartSmart","Shift-Tab":"indentLess","Shift-Ctrl-K":"deleteLine","Alt-Q":"wrapLines","Ctrl-Left":"goSubwordLeft","Ctrl-Right":"goSubwordRight","Ctrl-Alt-Up":"scrollLineUp","Ctrl-Alt-Down":"scrollLineDown","Cmd-L":"selectLine","Shift-Cmd-L":"splitSelectionByLine",Esc:"singleSelectionTop","Cmd-Enter":"insertLineAfter","Shift-Cmd-Enter":"insertLineBefore","Cmd-D":"selectNextOccurrence","Shift-Cmd-Space":"selectScope","Shift-Cmd-M":"selectBetweenBrackets","Cmd-M":"goToBracket","Cmd-Ctrl-Up":"swapLineUp","Cmd-Ctrl-Down":"swapLineDown","Cmd-/":"toggleCommentIndented","Cmd-J":"joinLines","Shift-Cmd-D":"duplicateLine",F5:"sortLines","Shift-F5":"reverseSortLines","Cmd-F5":"sortLinesInsensitive","Shift-Cmd-F5":"reverseSortLinesInsensitive",F2:"nextBookmark","Shift-F2":"prevBookmark","Cmd-F2":"toggleBookmark","Shift-Cmd-F2":"clearBookmarks","Alt-F2":"selectBookmarks",Backspace:"smartBackspace","Cmd-K Cmd-D":"skipAndSelectNextOccurrence","Cmd-K Cmd-K":"delLineRight","Cmd-K Cmd-U":"upcaseAtCursor","Cmd-K Cmd-L":"downcaseAtCursor","Cmd-K Cmd-Space":"setSublimeMark","Cmd-K Cmd-A":"selectToSublimeMark","Cmd-K Cmd-W":"deleteToSublimeMark","Cmd-K Cmd-X":"swapWithSublimeMark","Cmd-K Cmd-Y":"sublimeYank","Cmd-K Cmd-C":"showInCenter","Cmd-K Cmd-G":"clearBookmarks","Cmd-K Cmd-Backspace":"delLineLeft","Cmd-K Cmd-1":"foldAll","Cmd-K Cmd-0":"unfoldAll","Cmd-K Cmd-J":"unfoldAll","Ctrl-Shift-Up":"addCursorToPrevLine","Ctrl-Shift-Down":"addCursorToNextLine","Cmd-F3":"findUnder","Shift-Cmd-F3":"findUnderPrevious","Alt-F3":"findAllUnder","Shift-Cmd-[":"fold","Shift-Cmd-]":"unfold","Cmd-I":"findIncremental","Shift-Cmd-I":"findIncrementalReverse","Cmd-H":"replace",F3:"findNext","Shift-F3":"findPrev",fallthrough:"macDefault"},e.normalizeKeyMap(p.macSublime),p.pcSublime={"Shift-Tab":"indentLess","Shift-Ctrl-K":"deleteLine","Alt-Q":"wrapLines","Ctrl-T":"transposeChars","Alt-Left":"goSubwordLeft","Alt-Right":"goSubwordRight","Ctrl-Up":"scrollLineUp","Ctrl-Down":"scrollLineDown","Ctrl-L":"selectLine","Shift-Ctrl-L":"splitSelectionByLine",Esc:"singleSelectionTop","Ctrl-Enter":"insertLineAfter","Shift-Ctrl-Enter":"insertLineBefore","Ctrl-D":"selectNextOccurrence","Shift-Ctrl-Space":"selectScope","Shift-Ctrl-M":"selectBetweenBrackets","Ctrl-M":"goToBracket","Shift-Ctrl-Up":"swapLineUp","Shift-Ctrl-Down":"swapLineDown","Ctrl-/":"toggleCommentIndented","Ctrl-J":"joinLines","Shift-Ctrl-D":"duplicateLine",F9:"sortLines","Shift-F9":"reverseSortLines","Ctrl-F9":"sortLinesInsensitive","Shift-Ctrl-F9":"reverseSortLinesInsensitive",F2:"nextBookmark","Shift-F2":"prevBookmark","Ctrl-F2":"toggleBookmark","Shift-Ctrl-F2":"clearBookmarks","Alt-F2":"selectBookmarks",Backspace:"smartBackspace","Ctrl-K Ctrl-D":"skipAndSelectNextOccurrence","Ctrl-K Ctrl-K":"delLineRight","Ctrl-K Ctrl-U":"upcaseAtCursor","Ctrl-K Ctrl-L":"downcaseAtCursor","Ctrl-K Ctrl-Space":"setSublimeMark","Ctrl-K Ctrl-A":"selectToSublimeMark","Ctrl-K Ctrl-W":"deleteToSublimeMark","Ctrl-K Ctrl-X":"swapWithSublimeMark","Ctrl-K Ctrl-Y":"sublimeYank","Ctrl-K Ctrl-C":"showInCenter","Ctrl-K Ctrl-G":"clearBookmarks","Ctrl-K Ctrl-Backspace":"delLineLeft","Ctrl-K Ctrl-1":"foldAll","Ctrl-K Ctrl-0":"unfoldAll","Ctrl-K Ctrl-J":"unfoldAll","Ctrl-Alt-Up":"addCursorToPrevLine","Ctrl-Alt-Down":"addCursorToNextLine","Ctrl-F3":"findUnder","Shift-Ctrl-F3":"findUnderPrevious","Alt-F3":"findAllUnder","Shift-Ctrl-[":"fold","Shift-Ctrl-]":"unfold","Ctrl-I":"findIncremental","Shift-Ctrl-I":"findIncrementalReverse","Ctrl-H":"replace",F3:"findNext","Shift-F3":"findPrev",fallthrough:"pcDefault"},e.normalizeKeyMap(p.pcSublime);var f=p.default==p.macDefault;p.sublime=f?p.macSublime:p.pcSublime}(n(14),n(168),n(376))},function(e,t,n){!function(e){"use strict";e.runMode=function(t,n,r,i){var o=e.getMode(e.defaults,n),a=i&&i.tabSize||e.defaults.tabSize;if(r.appendChild){var s=/MSIE \d/.test(navigator.userAgent)&&(null==document.documentMode||document.documentMode<9),l=r,c=0;l.innerHTML="",r=function(e,t){if("\n"==e)return l.appendChild(document.createTextNode(s?"\r":e)),void(c=0);for(var n="",r=0;;){var i=e.indexOf("\t",r);if(-1==i){n+=e.slice(r),c+=e.length-r;break}c+=i-r,n+=e.slice(r,i);var o=a-c%a;c+=o;for(var u=0;u<o;++u)n+=" ";r=i+1}if(t){var d=l.appendChild(document.createElement("span"));d.className="cm-"+t.replace(/ +/g," cm-"),d.appendChild(document.createTextNode(n))}else l.appendChild(document.createTextNode(n))}}for(var u=e.splitLines(t),d=i&&i.state||e.startState(o),h=0,p=u.length;h<p;++h){h&&r("\n");var f=new e.StringStream(u[h],null,{lookAhead:function(e){return u[h+e]},baseToken:function(){}});for(!f.string&&o.blankLine&&o.blankLine(d);!f.eol();){var m=o.token(f,d);r(f.current(),m,h,f.start,d,o),f.start=f.pos}}}}(n(14))},function(e,t,n){"use strict";
/** @license React v17.0.2
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var r=n(379),i=60103,o=60106;t.Fragment=60107,t.StrictMode=60108,t.Profiler=60114;var a=60109,s=60110,l=60112;t.Suspense=60113;var c=60115,u=60116;if("function"==typeof Symbol&&Symbol.for){var d=Symbol.for;i=d("react.element"),o=d("react.portal"),t.Fragment=d("react.fragment"),t.StrictMode=d("react.strict_mode"),t.Profiler=d("react.profiler"),a=d("react.provider"),s=d("react.context"),l=d("react.forward_ref"),t.Suspense=d("react.suspense"),c=d("react.memo"),u=d("react.lazy")}var h="function"==typeof Symbol&&Symbol.iterator;function p(e){for(var t="https://reactjs.org/docs/error-decoder.html?invariant="+e,n=1;n<arguments.length;n++)t+="&args[]="+encodeURIComponent(arguments[n]);return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var f={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},m={};function g(e,t,n){this.props=e,this.context=t,this.refs=m,this.updater=n||f}function v(){}function y(e,t,n){this.props=e,this.context=t,this.refs=m,this.updater=n||f}g.prototype.isReactComponent={},g.prototype.setState=function(e,t){if("object"!=typeof e&&"function"!=typeof e&&null!=e)throw Error(p(85));this.updater.enqueueSetState(this,e,t,"setState")},g.prototype.forceUpdate=function(e){this.updater.enqueueForceUpdate(this,e,"forceUpdate")},v.prototype=g.prototype;var _=y.prototype=new v;_.constructor=y,r(_,g.prototype),_.isPureReactComponent=!0;var b={current:null},M=Object.prototype.hasOwnProperty,w={key:!0,ref:!0,__self:!0,__source:!0};function A(e,t,n){var r,o={},a=null,s=null;if(null!=t)for(r in void 0!==t.ref&&(s=t.ref),void 0!==t.key&&(a=""+t.key),t)M.call(t,r)&&!w.hasOwnProperty(r)&&(o[r]=t[r]);var l=arguments.length-2;if(1===l)o.children=n;else if(1<l){for(var c=Array(l),u=0;u<l;u++)c[u]=arguments[u+2];o.children=c}if(e&&e.defaultProps)for(r in l=e.defaultProps)void 0===o[r]&&(o[r]=l[r]);return{$$typeof:i,type:e,key:a,ref:s,props:o,_owner:b.current}}function C(e){return"object"==typeof e&&null!==e&&e.$$typeof===i}var x=/\/+/g;function E(e,t){return"object"==typeof e&&null!==e&&null!=e.key?function(e){var t={"=":"=0",":":"=2"};return"$"+e.replace(/[=:]/g,(function(e){return t[e]}))}(""+e.key):t.toString(36)}function L(e,t,n,r,a){var s=typeof e;"undefined"!==s&&"boolean"!==s||(e=null);var l=!1;if(null===e)l=!0;else switch(s){case"string":case"number":l=!0;break;case"object":switch(e.$$typeof){case i:case o:l=!0}}if(l)return a=a(l=e),e=""===r?"."+E(l,0):r,Array.isArray(a)?(n="",null!=e&&(n=e.replace(x,"$&/")+"/"),L(a,t,n,"",(function(e){return e}))):null!=a&&(C(a)&&(a=function(e,t){return{$$typeof:i,type:e.type,key:t,ref:e.ref,props:e.props,_owner:e._owner}}(a,n+(!a.key||l&&l.key===a.key?"":(""+a.key).replace(x,"$&/")+"/")+e)),t.push(a)),1;if(l=0,r=""===r?".":r+":",Array.isArray(e))for(var c=0;c<e.length;c++){var u=r+E(s=e[c],c);l+=L(s,t,n,u,a)}else if("function"==typeof(u=function(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=h&&e[h]||e["@@iterator"])?e:null}(e)))for(e=u.call(e),c=0;!(s=e.next()).done;)l+=L(s=s.value,t,n,u=r+E(s,c++),a);else if("object"===s)throw t=""+e,Error(p(31,"[object Object]"===t?"object with keys {"+Object.keys(e).join(", ")+"}":t));return l}function S(e,t,n){if(null==e)return e;var r=[],i=0;return L(e,r,"","",(function(e){return t.call(n,e,i++)})),r}function T(e){if(-1===e._status){var t=e._result;t=t(),e._status=0,e._result=t,t.then((function(t){0===e._status&&(t=t.default,e._status=1,e._result=t)}),(function(t){0===e._status&&(e._status=2,e._result=t)}))}if(1===e._status)return e._result;throw e._result}var O={current:null};function I(){var e=O.current;if(null===e)throw Error(p(321));return e}var k={ReactCurrentDispatcher:O,ReactCurrentBatchConfig:{transition:0},ReactCurrentOwner:b,IsSomeRendererActing:{current:!1},assign:r};t.Children={map:S,forEach:function(e,t,n){S(e,(function(){t.apply(this,arguments)}),n)},count:function(e){var t=0;return S(e,(function(){t++})),t},toArray:function(e){return S(e,(function(e){return e}))||[]},only:function(e){if(!C(e))throw Error(p(143));return e}},t.Component=g,t.PureComponent=y,t.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=k,t.cloneElement=function(e,t,n){if(null==e)throw Error(p(267,e));var o=r({},e.props),a=e.key,s=e.ref,l=e._owner;if(null!=t){if(void 0!==t.ref&&(s=t.ref,l=b.current),void 0!==t.key&&(a=""+t.key),e.type&&e.type.defaultProps)var c=e.type.defaultProps;for(u in t)M.call(t,u)&&!w.hasOwnProperty(u)&&(o[u]=void 0===t[u]&&void 0!==c?c[u]:t[u])}var u=arguments.length-2;if(1===u)o.children=n;else if(1<u){c=Array(u);for(var d=0;d<u;d++)c[d]=arguments[d+2];o.children=c}return{$$typeof:i,type:e.type,key:a,ref:s,props:o,_owner:l}},t.createContext=function(e,t){return void 0===t&&(t=null),(e={$$typeof:s,_calculateChangedBits:t,_currentValue:e,_currentValue2:e,_threadCount:0,Provider:null,Consumer:null}).Provider={$$typeof:a,_context:e},e.Consumer=e},t.createElement=A,t.createFactory=function(e){var t=A.bind(null,e);return t.type=e,t},t.createRef=function(){return{current:null}},t.forwardRef=function(e){return{$$typeof:l,render:e}},t.isValidElement=C,t.lazy=function(e){return{$$typeof:u,_payload:{_status:-1,_result:e},_init:T}},t.memo=function(e,t){return{$$typeof:c,type:e,compare:void 0===t?null:t}},t.useCallback=function(e,t){return I().useCallback(e,t)},t.useContext=function(e,t){return I().useContext(e,t)},t.useDebugValue=function(){},t.useEffect=function(e,t){return I().useEffect(e,t)},t.useImperativeHandle=function(e,t,n){return I().useImperativeHandle(e,t,n)},t.useLayoutEffect=function(e,t){return I().useLayoutEffect(e,t)},t.useMemo=function(e,t){return I().useMemo(e,t)},t.useReducer=function(e,t,n){return I().useReducer(e,t,n)},t.useRef=function(e){return I().useRef(e)},t.useState=function(e){return I().useState(e)},t.version="17.0.2"},function(e,t,n){"use strict";
/** @license React v17.0.2
 * react-dom.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var r=n(0),i=n(379),o=n(691);function a(e){for(var t="https://reactjs.org/docs/error-decoder.html?invariant="+e,n=1;n<arguments.length;n++)t+="&args[]="+encodeURIComponent(arguments[n]);return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}if(!r)throw Error(a(227));var s=new Set,l={};function c(e,t){u(e,t),u(e+"Capture",t)}function u(e,t){for(l[e]=t,e=0;e<t.length;e++)s.add(t[e])}var d=!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement),h=/^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/,p=Object.prototype.hasOwnProperty,f={},m={};function g(e,t,n,r,i,o,a){this.acceptsBooleans=2===t||3===t||4===t,this.attributeName=r,this.attributeNamespace=i,this.mustUseProperty=n,this.propertyName=e,this.type=t,this.sanitizeURL=o,this.removeEmptyString=a}var v={};"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach((function(e){v[e]=new g(e,0,!1,e,null,!1,!1)})),[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach((function(e){var t=e[0];v[t]=new g(t,1,!1,e[1],null,!1,!1)})),["contentEditable","draggable","spellCheck","value"].forEach((function(e){v[e]=new g(e,2,!1,e.toLowerCase(),null,!1,!1)})),["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach((function(e){v[e]=new g(e,2,!1,e,null,!1,!1)})),"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach((function(e){v[e]=new g(e,3,!1,e.toLowerCase(),null,!1,!1)})),["checked","multiple","muted","selected"].forEach((function(e){v[e]=new g(e,3,!0,e,null,!1,!1)})),["capture","download"].forEach((function(e){v[e]=new g(e,4,!1,e,null,!1,!1)})),["cols","rows","size","span"].forEach((function(e){v[e]=new g(e,6,!1,e,null,!1,!1)})),["rowSpan","start"].forEach((function(e){v[e]=new g(e,5,!1,e.toLowerCase(),null,!1,!1)}));var y=/[\-:]([a-z])/g;function _(e){return e[1].toUpperCase()}function b(e,t,n,r){var i=v.hasOwnProperty(t)?v[t]:null;(null!==i?0===i.type:!r&&(2<t.length&&("o"===t[0]||"O"===t[0])&&("n"===t[1]||"N"===t[1])))||(function(e,t,n,r){if(null==t||function(e,t,n,r){if(null!==n&&0===n.type)return!1;switch(typeof t){case"function":case"symbol":return!0;case"boolean":return!r&&(null!==n?!n.acceptsBooleans:"data-"!==(e=e.toLowerCase().slice(0,5))&&"aria-"!==e);default:return!1}}(e,t,n,r))return!0;if(r)return!1;if(null!==n)switch(n.type){case 3:return!t;case 4:return!1===t;case 5:return isNaN(t);case 6:return isNaN(t)||1>t}return!1}(t,n,i,r)&&(n=null),r||null===i?function(e){return!!p.call(m,e)||!p.call(f,e)&&(h.test(e)?m[e]=!0:(f[e]=!0,!1))}(t)&&(null===n?e.removeAttribute(t):e.setAttribute(t,""+n)):i.mustUseProperty?e[i.propertyName]=null===n?3!==i.type&&"":n:(t=i.attributeName,r=i.attributeNamespace,null===n?e.removeAttribute(t):(n=3===(i=i.type)||4===i&&!0===n?"":""+n,r?e.setAttributeNS(r,t,n):e.setAttribute(t,n))))}"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach((function(e){var t=e.replace(y,_);v[t]=new g(t,1,!1,e,null,!1,!1)})),"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach((function(e){var t=e.replace(y,_);v[t]=new g(t,1,!1,e,"http://www.w3.org/1999/xlink",!1,!1)})),["xml:base","xml:lang","xml:space"].forEach((function(e){var t=e.replace(y,_);v[t]=new g(t,1,!1,e,"http://www.w3.org/XML/1998/namespace",!1,!1)})),["tabIndex","crossOrigin"].forEach((function(e){v[e]=new g(e,1,!1,e.toLowerCase(),null,!1,!1)})),v.xlinkHref=new g("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0,!1),["src","href","action","formAction"].forEach((function(e){v[e]=new g(e,1,!1,e.toLowerCase(),null,!0,!0)}));var M=r.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED,w=60103,A=60106,C=60107,x=60108,E=60114,L=60109,S=60110,T=60112,O=60113,I=60120,k=60115,D=60116,N=60121,j=60128,P=60129,z=60130,R=60131;if("function"==typeof Symbol&&Symbol.for){var B=Symbol.for;w=B("react.element"),A=B("react.portal"),C=B("react.fragment"),x=B("react.strict_mode"),E=B("react.profiler"),L=B("react.provider"),S=B("react.context"),T=B("react.forward_ref"),O=B("react.suspense"),I=B("react.suspense_list"),k=B("react.memo"),D=B("react.lazy"),N=B("react.block"),B("react.scope"),j=B("react.opaque.id"),P=B("react.debug_trace_mode"),z=B("react.offscreen"),R=B("react.legacy_hidden")}var H,F="function"==typeof Symbol&&Symbol.iterator;function Y(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=F&&e[F]||e["@@iterator"])?e:null}function V(e){if(void 0===H)try{throw Error()}catch(e){var t=e.stack.trim().match(/\n( *(at )?)/);H=t&&t[1]||""}return"\n"+H+e}var U=!1;function W(e,t){if(!e||U)return"";U=!0;var n=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{if(t)if(t=function(){throw Error()},Object.defineProperty(t.prototype,"props",{set:function(){throw Error()}}),"object"==typeof Reflect&&Reflect.construct){try{Reflect.construct(t,[])}catch(e){var r=e}Reflect.construct(e,[],t)}else{try{t.call()}catch(e){r=e}e.call(t.prototype)}else{try{throw Error()}catch(e){r=e}e()}}catch(e){if(e&&r&&"string"==typeof e.stack){for(var i=e.stack.split("\n"),o=r.stack.split("\n"),a=i.length-1,s=o.length-1;1<=a&&0<=s&&i[a]!==o[s];)s--;for(;1<=a&&0<=s;a--,s--)if(i[a]!==o[s]){if(1!==a||1!==s)do{if(a--,0>--s||i[a]!==o[s])return"\n"+i[a].replace(" at new "," at ")}while(1<=a&&0<=s);break}}}finally{U=!1,Error.prepareStackTrace=n}return(e=e?e.displayName||e.name:"")?V(e):""}function G(e){switch(e.tag){case 5:return V(e.type);case 16:return V("Lazy");case 13:return V("Suspense");case 19:return V("SuspenseList");case 0:case 2:case 15:return e=W(e.type,!1);case 11:return e=W(e.type.render,!1);case 22:return e=W(e.type._render,!1);case 1:return e=W(e.type,!0);default:return""}}function q(e){if(null==e)return null;if("function"==typeof e)return e.displayName||e.name||null;if("string"==typeof e)return e;switch(e){case C:return"Fragment";case A:return"Portal";case E:return"Profiler";case x:return"StrictMode";case O:return"Suspense";case I:return"SuspenseList"}if("object"==typeof e)switch(e.$$typeof){case S:return(e.displayName||"Context")+".Consumer";case L:return(e._context.displayName||"Context")+".Provider";case T:var t=e.render;return t=t.displayName||t.name||"",e.displayName||(""!==t?"ForwardRef("+t+")":"ForwardRef");case k:return q(e.type);case N:return q(e._render);case D:t=e._payload,e=e._init;try{return q(e(t))}catch(e){}}return null}function K(e){switch(typeof e){case"boolean":case"number":case"object":case"string":case"undefined":return e;default:return""}}function X(e){var t=e.type;return(e=e.nodeName)&&"input"===e.toLowerCase()&&("checkbox"===t||"radio"===t)}function J(e){e._valueTracker||(e._valueTracker=function(e){var t=X(e)?"checked":"value",n=Object.getOwnPropertyDescriptor(e.constructor.prototype,t),r=""+e[t];if(!e.hasOwnProperty(t)&&void 0!==n&&"function"==typeof n.get&&"function"==typeof n.set){var i=n.get,o=n.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return i.call(this)},set:function(e){r=""+e,o.call(this,e)}}),Object.defineProperty(e,t,{enumerable:n.enumerable}),{getValue:function(){return r},setValue:function(e){r=""+e},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}(e))}function Q(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var n=t.getValue(),r="";return e&&(r=X(e)?e.checked?"true":"false":e.value),(e=r)!==n&&(t.setValue(e),!0)}function Z(e){if(void 0===(e=e||("undefined"!=typeof document?document:void 0)))return null;try{return e.activeElement||e.body}catch(t){return e.body}}function $(e,t){var n=t.checked;return i({},t,{defaultChecked:void 0,defaultValue:void 0,value:void 0,checked:null!=n?n:e._wrapperState.initialChecked})}function ee(e,t){var n=null==t.defaultValue?"":t.defaultValue,r=null!=t.checked?t.checked:t.defaultChecked;n=K(null!=t.value?t.value:n),e._wrapperState={initialChecked:r,initialValue:n,controlled:"checkbox"===t.type||"radio"===t.type?null!=t.checked:null!=t.value}}function te(e,t){null!=(t=t.checked)&&b(e,"checked",t,!1)}function ne(e,t){te(e,t);var n=K(t.value),r=t.type;if(null!=n)"number"===r?(0===n&&""===e.value||e.value!=n)&&(e.value=""+n):e.value!==""+n&&(e.value=""+n);else if("submit"===r||"reset"===r)return void e.removeAttribute("value");t.hasOwnProperty("value")?ie(e,t.type,n):t.hasOwnProperty("defaultValue")&&ie(e,t.type,K(t.defaultValue)),null==t.checked&&null!=t.defaultChecked&&(e.defaultChecked=!!t.defaultChecked)}function re(e,t,n){if(t.hasOwnProperty("value")||t.hasOwnProperty("defaultValue")){var r=t.type;if(!("submit"!==r&&"reset"!==r||void 0!==t.value&&null!==t.value))return;t=""+e._wrapperState.initialValue,n||t===e.value||(e.value=t),e.defaultValue=t}""!==(n=e.name)&&(e.name=""),e.defaultChecked=!!e._wrapperState.initialChecked,""!==n&&(e.name=n)}function ie(e,t,n){"number"===t&&Z(e.ownerDocument)===e||(null==n?e.defaultValue=""+e._wrapperState.initialValue:e.defaultValue!==""+n&&(e.defaultValue=""+n))}function oe(e,t){return e=i({children:void 0},t),(t=function(e){var t="";return r.Children.forEach(e,(function(e){null!=e&&(t+=e)})),t}(t.children))&&(e.children=t),e}function ae(e,t,n,r){if(e=e.options,t){t={};for(var i=0;i<n.length;i++)t["$"+n[i]]=!0;for(n=0;n<e.length;n++)i=t.hasOwnProperty("$"+e[n].value),e[n].selected!==i&&(e[n].selected=i),i&&r&&(e[n].defaultSelected=!0)}else{for(n=""+K(n),t=null,i=0;i<e.length;i++){if(e[i].value===n)return e[i].selected=!0,void(r&&(e[i].defaultSelected=!0));null!==t||e[i].disabled||(t=e[i])}null!==t&&(t.selected=!0)}}function se(e,t){if(null!=t.dangerouslySetInnerHTML)throw Error(a(91));return i({},t,{value:void 0,defaultValue:void 0,children:""+e._wrapperState.initialValue})}function le(e,t){var n=t.value;if(null==n){if(n=t.children,t=t.defaultValue,null!=n){if(null!=t)throw Error(a(92));if(Array.isArray(n)){if(!(1>=n.length))throw Error(a(93));n=n[0]}t=n}null==t&&(t=""),n=t}e._wrapperState={initialValue:K(n)}}function ce(e,t){var n=K(t.value),r=K(t.defaultValue);null!=n&&((n=""+n)!==e.value&&(e.value=n),null==t.defaultValue&&e.defaultValue!==n&&(e.defaultValue=n)),null!=r&&(e.defaultValue=""+r)}function ue(e){var t=e.textContent;t===e._wrapperState.initialValue&&""!==t&&null!==t&&(e.value=t)}var de="http://www.w3.org/1999/xhtml",he="http://www.w3.org/2000/svg";function pe(e){switch(e){case"svg":return"http://www.w3.org/2000/svg";case"math":return"http://www.w3.org/1998/Math/MathML";default:return"http://www.w3.org/1999/xhtml"}}function fe(e,t){return null==e||"http://www.w3.org/1999/xhtml"===e?pe(t):"http://www.w3.org/2000/svg"===e&&"foreignObject"===t?"http://www.w3.org/1999/xhtml":e}var me,ge=function(e){return"undefined"!=typeof MSApp&&MSApp.execUnsafeLocalFunction?function(t,n,r,i){MSApp.execUnsafeLocalFunction((function(){return e(t,n)}))}:e}((function(e,t){if(e.namespaceURI!==he||"innerHTML"in e)e.innerHTML=t;else{for((me=me||document.createElement("div")).innerHTML="<svg>"+t.valueOf().toString()+"</svg>",t=me.firstChild;e.firstChild;)e.removeChild(e.firstChild);for(;t.firstChild;)e.appendChild(t.firstChild)}}));function ve(e,t){if(t){var n=e.firstChild;if(n&&n===e.lastChild&&3===n.nodeType)return void(n.nodeValue=t)}e.textContent=t}var ye={animationIterationCount:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,columns:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridArea:!0,gridRow:!0,gridRowEnd:!0,gridRowSpan:!0,gridRowStart:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnSpan:!0,gridColumnStart:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},_e=["Webkit","ms","Moz","O"];function be(e,t,n){return null==t||"boolean"==typeof t||""===t?"":n||"number"!=typeof t||0===t||ye.hasOwnProperty(e)&&ye[e]?(""+t).trim():t+"px"}function Me(e,t){for(var n in e=e.style,t)if(t.hasOwnProperty(n)){var r=0===n.indexOf("--"),i=be(n,t[n],r);"float"===n&&(n="cssFloat"),r?e.setProperty(n,i):e[n]=i}}Object.keys(ye).forEach((function(e){_e.forEach((function(t){t=t+e.charAt(0).toUpperCase()+e.substring(1),ye[t]=ye[e]}))}));var we=i({menuitem:!0},{area:!0,base:!0,br:!0,col:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0});function Ae(e,t){if(t){if(we[e]&&(null!=t.children||null!=t.dangerouslySetInnerHTML))throw Error(a(137,e));if(null!=t.dangerouslySetInnerHTML){if(null!=t.children)throw Error(a(60));if("object"!=typeof t.dangerouslySetInnerHTML||!("__html"in t.dangerouslySetInnerHTML))throw Error(a(61))}if(null!=t.style&&"object"!=typeof t.style)throw Error(a(62))}}function Ce(e,t){if(-1===e.indexOf("-"))return"string"==typeof t.is;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}function xe(e){return(e=e.target||e.srcElement||window).correspondingUseElement&&(e=e.correspondingUseElement),3===e.nodeType?e.parentNode:e}var Ee=null,Le=null,Se=null;function Te(e){if(e=Zr(e)){if("function"!=typeof Ee)throw Error(a(280));var t=e.stateNode;t&&(t=ei(t),Ee(e.stateNode,e.type,t))}}function Oe(e){Le?Se?Se.push(e):Se=[e]:Le=e}function Ie(){if(Le){var e=Le,t=Se;if(Se=Le=null,Te(e),t)for(e=0;e<t.length;e++)Te(t[e])}}function ke(e,t){return e(t)}function De(e,t,n,r,i){return e(t,n,r,i)}function Ne(){}var je=ke,Pe=!1,ze=!1;function Re(){null===Le&&null===Se||(Ne(),Ie())}function Be(e,t){var n=e.stateNode;if(null===n)return null;var r=ei(n);if(null===r)return null;n=r[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(r=!r.disabled)||(r=!("button"===(e=e.type)||"input"===e||"select"===e||"textarea"===e)),e=!r;break e;default:e=!1}if(e)return null;if(n&&"function"!=typeof n)throw Error(a(231,t,typeof n));return n}var He=!1;if(d)try{var Fe={};Object.defineProperty(Fe,"passive",{get:function(){He=!0}}),window.addEventListener("test",Fe,Fe),window.removeEventListener("test",Fe,Fe)}catch(e){He=!1}function Ye(e,t,n,r,i,o,a,s,l){var c=Array.prototype.slice.call(arguments,3);try{t.apply(n,c)}catch(e){this.onError(e)}}var Ve=!1,Ue=null,We=!1,Ge=null,qe={onError:function(e){Ve=!0,Ue=e}};function Ke(e,t,n,r,i,o,a,s,l){Ve=!1,Ue=null,Ye.apply(qe,arguments)}function Xe(e){var t=e,n=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do{0!=(1026&(t=e).flags)&&(n=t.return),e=t.return}while(e)}return 3===t.tag?n:null}function Je(e){if(13===e.tag){var t=e.memoizedState;if(null===t&&(null!==(e=e.alternate)&&(t=e.memoizedState)),null!==t)return t.dehydrated}return null}function Qe(e){if(Xe(e)!==e)throw Error(a(188))}function Ze(e){if(!(e=function(e){var t=e.alternate;if(!t){if(null===(t=Xe(e)))throw Error(a(188));return t!==e?null:e}for(var n=e,r=t;;){var i=n.return;if(null===i)break;var o=i.alternate;if(null===o){if(null!==(r=i.return)){n=r;continue}break}if(i.child===o.child){for(o=i.child;o;){if(o===n)return Qe(i),e;if(o===r)return Qe(i),t;o=o.sibling}throw Error(a(188))}if(n.return!==r.return)n=i,r=o;else{for(var s=!1,l=i.child;l;){if(l===n){s=!0,n=i,r=o;break}if(l===r){s=!0,r=i,n=o;break}l=l.sibling}if(!s){for(l=o.child;l;){if(l===n){s=!0,n=o,r=i;break}if(l===r){s=!0,r=o,n=i;break}l=l.sibling}if(!s)throw Error(a(189))}}if(n.alternate!==r)throw Error(a(190))}if(3!==n.tag)throw Error(a(188));return n.stateNode.current===n?e:t}(e)))return null;for(var t=e;;){if(5===t.tag||6===t.tag)return t;if(t.child)t.child.return=t,t=t.child;else{if(t===e)break;for(;!t.sibling;){if(!t.return||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}}return null}function $e(e,t){for(var n=e.alternate;null!==t;){if(t===e||t===n)return!0;t=t.return}return!1}var et,tt,nt,rt,it=!1,ot=[],at=null,st=null,lt=null,ct=new Map,ut=new Map,dt=[],ht="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset submit".split(" ");function pt(e,t,n,r,i){return{blockedOn:e,domEventName:t,eventSystemFlags:16|n,nativeEvent:i,targetContainers:[r]}}function ft(e,t){switch(e){case"focusin":case"focusout":at=null;break;case"dragenter":case"dragleave":st=null;break;case"mouseover":case"mouseout":lt=null;break;case"pointerover":case"pointerout":ct.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":ut.delete(t.pointerId)}}function mt(e,t,n,r,i,o){return null===e||e.nativeEvent!==o?(e=pt(t,n,r,i,o),null!==t&&(null!==(t=Zr(t))&&tt(t)),e):(e.eventSystemFlags|=r,t=e.targetContainers,null!==i&&-1===t.indexOf(i)&&t.push(i),e)}function gt(e){var t=Qr(e.target);if(null!==t){var n=Xe(t);if(null!==n)if(13===(t=n.tag)){if(null!==(t=Je(n)))return e.blockedOn=t,void rt(e.lanePriority,(function(){o.unstable_runWithPriority(e.priority,(function(){nt(n)}))}))}else if(3===t&&n.stateNode.hydrate)return void(e.blockedOn=3===n.tag?n.stateNode.containerInfo:null)}e.blockedOn=null}function vt(e){if(null!==e.blockedOn)return!1;for(var t=e.targetContainers;0<t.length;){var n=Zt(e.domEventName,e.eventSystemFlags,t[0],e.nativeEvent);if(null!==n)return null!==(t=Zr(n))&&tt(t),e.blockedOn=n,!1;t.shift()}return!0}function yt(e,t,n){vt(e)&&n.delete(t)}function _t(){for(it=!1;0<ot.length;){var e=ot[0];if(null!==e.blockedOn){null!==(e=Zr(e.blockedOn))&&et(e);break}for(var t=e.targetContainers;0<t.length;){var n=Zt(e.domEventName,e.eventSystemFlags,t[0],e.nativeEvent);if(null!==n){e.blockedOn=n;break}t.shift()}null===e.blockedOn&&ot.shift()}null!==at&&vt(at)&&(at=null),null!==st&&vt(st)&&(st=null),null!==lt&&vt(lt)&&(lt=null),ct.forEach(yt),ut.forEach(yt)}function bt(e,t){e.blockedOn===t&&(e.blockedOn=null,it||(it=!0,o.unstable_scheduleCallback(o.unstable_NormalPriority,_t)))}function Mt(e){function t(t){return bt(t,e)}if(0<ot.length){bt(ot[0],e);for(var n=1;n<ot.length;n++){var r=ot[n];r.blockedOn===e&&(r.blockedOn=null)}}for(null!==at&&bt(at,e),null!==st&&bt(st,e),null!==lt&&bt(lt,e),ct.forEach(t),ut.forEach(t),n=0;n<dt.length;n++)(r=dt[n]).blockedOn===e&&(r.blockedOn=null);for(;0<dt.length&&null===(n=dt[0]).blockedOn;)gt(n),null===n.blockedOn&&dt.shift()}function wt(e,t){var n={};return n[e.toLowerCase()]=t.toLowerCase(),n["Webkit"+e]="webkit"+t,n["Moz"+e]="moz"+t,n}var At={animationend:wt("Animation","AnimationEnd"),animationiteration:wt("Animation","AnimationIteration"),animationstart:wt("Animation","AnimationStart"),transitionend:wt("Transition","TransitionEnd")},Ct={},xt={};function Et(e){if(Ct[e])return Ct[e];if(!At[e])return e;var t,n=At[e];for(t in n)if(n.hasOwnProperty(t)&&t in xt)return Ct[e]=n[t];return e}d&&(xt=document.createElement("div").style,"AnimationEvent"in window||(delete At.animationend.animation,delete At.animationiteration.animation,delete At.animationstart.animation),"TransitionEvent"in window||delete At.transitionend.transition);var Lt=Et("animationend"),St=Et("animationiteration"),Tt=Et("animationstart"),Ot=Et("transitionend"),It=new Map,kt=new Map,Dt=["abort","abort",Lt,"animationEnd",St,"animationIteration",Tt,"animationStart","canplay","canPlay","canplaythrough","canPlayThrough","durationchange","durationChange","emptied","emptied","encrypted","encrypted","ended","ended","error","error","gotpointercapture","gotPointerCapture","load","load","loadeddata","loadedData","loadedmetadata","loadedMetadata","loadstart","loadStart","lostpointercapture","lostPointerCapture","playing","playing","progress","progress","seeking","seeking","stalled","stalled","suspend","suspend","timeupdate","timeUpdate",Ot,"transitionEnd","waiting","waiting"];function Nt(e,t){for(var n=0;n<e.length;n+=2){var r=e[n],i=e[n+1];i="on"+(i[0].toUpperCase()+i.slice(1)),kt.set(r,t),It.set(r,i),c(i,[r])}}(0,o.unstable_now)();var jt=8;function Pt(e){if(0!=(1&e))return jt=15,1;if(0!=(2&e))return jt=14,2;if(0!=(4&e))return jt=13,4;var t=24&e;return 0!==t?(jt=12,t):0!=(32&e)?(jt=11,32):0!==(t=192&e)?(jt=10,t):0!=(256&e)?(jt=9,256):0!==(t=3584&e)?(jt=8,t):0!=(4096&e)?(jt=7,4096):0!==(t=4186112&e)?(jt=6,t):0!==(t=62914560&e)?(jt=5,t):67108864&e?(jt=4,67108864):0!=(134217728&e)?(jt=3,134217728):0!==(t=805306368&e)?(jt=2,t):0!=(1073741824&e)?(jt=1,1073741824):(jt=8,e)}function zt(e,t){var n=e.pendingLanes;if(0===n)return jt=0;var r=0,i=0,o=e.expiredLanes,a=e.suspendedLanes,s=e.pingedLanes;if(0!==o)r=o,i=jt=15;else if(0!==(o=134217727&n)){var l=o&~a;0!==l?(r=Pt(l),i=jt):0!==(s&=o)&&(r=Pt(s),i=jt)}else 0!==(o=n&~a)?(r=Pt(o),i=jt):0!==s&&(r=Pt(s),i=jt);if(0===r)return 0;if(r=n&((0>(r=31-Vt(r))?0:1<<r)<<1)-1,0!==t&&t!==r&&0==(t&a)){if(Pt(t),i<=jt)return t;jt=i}if(0!==(t=e.entangledLanes))for(e=e.entanglements,t&=r;0<t;)i=1<<(n=31-Vt(t)),r|=e[n],t&=~i;return r}function Rt(e){return 0!==(e=-1073741825&e.pendingLanes)?e:1073741824&e?1073741824:0}function Bt(e,t){switch(e){case 15:return 1;case 14:return 2;case 12:return 0===(e=Ht(24&~t))?Bt(10,t):e;case 10:return 0===(e=Ht(192&~t))?Bt(8,t):e;case 8:return 0===(e=Ht(3584&~t))&&(0===(e=Ht(4186112&~t))&&(e=512)),e;case 2:return 0===(t=Ht(805306368&~t))&&(t=268435456),t}throw Error(a(358,e))}function Ht(e){return e&-e}function Ft(e){for(var t=[],n=0;31>n;n++)t.push(e);return t}function Yt(e,t,n){e.pendingLanes|=t;var r=t-1;e.suspendedLanes&=r,e.pingedLanes&=r,(e=e.eventTimes)[t=31-Vt(t)]=n}var Vt=Math.clz32?Math.clz32:function(e){return 0===e?32:31-(Ut(e)/Wt|0)|0},Ut=Math.log,Wt=Math.LN2;var Gt=o.unstable_UserBlockingPriority,qt=o.unstable_runWithPriority,Kt=!0;function Xt(e,t,n,r){Pe||Ne();var i=Qt,o=Pe;Pe=!0;try{De(i,e,t,n,r)}finally{(Pe=o)||Re()}}function Jt(e,t,n,r){qt(Gt,Qt.bind(null,e,t,n,r))}function Qt(e,t,n,r){var i;if(Kt)if((i=0==(4&t))&&0<ot.length&&-1<ht.indexOf(e))e=pt(null,e,t,n,r),ot.push(e);else{var o=Zt(e,t,n,r);if(null===o)i&&ft(e,r);else{if(i){if(-1<ht.indexOf(e))return e=pt(o,e,t,n,r),void ot.push(e);if(function(e,t,n,r,i){switch(t){case"focusin":return at=mt(at,e,t,n,r,i),!0;case"dragenter":return st=mt(st,e,t,n,r,i),!0;case"mouseover":return lt=mt(lt,e,t,n,r,i),!0;case"pointerover":var o=i.pointerId;return ct.set(o,mt(ct.get(o)||null,e,t,n,r,i)),!0;case"gotpointercapture":return o=i.pointerId,ut.set(o,mt(ut.get(o)||null,e,t,n,r,i)),!0}return!1}(o,e,t,n,r))return;ft(e,r)}Or(e,t,r,null,n)}}}function Zt(e,t,n,r){var i=xe(r);if(null!==(i=Qr(i))){var o=Xe(i);if(null===o)i=null;else{var a=o.tag;if(13===a){if(null!==(i=Je(o)))return i;i=null}else if(3===a){if(o.stateNode.hydrate)return 3===o.tag?o.stateNode.containerInfo:null;i=null}else o!==i&&(i=null)}}return Or(e,t,r,i,n),null}var $t=null,en=null,tn=null;function nn(){if(tn)return tn;var e,t,n=en,r=n.length,i="value"in $t?$t.value:$t.textContent,o=i.length;for(e=0;e<r&&n[e]===i[e];e++);var a=r-e;for(t=1;t<=a&&n[r-t]===i[o-t];t++);return tn=i.slice(e,1<t?1-t:void 0)}function rn(e){var t=e.keyCode;return"charCode"in e?0===(e=e.charCode)&&13===t&&(e=13):e=t,10===e&&(e=13),32<=e||13===e?e:0}function on(){return!0}function an(){return!1}function sn(e){function t(t,n,r,i,o){for(var a in this._reactName=t,this._targetInst=r,this.type=n,this.nativeEvent=i,this.target=o,this.currentTarget=null,e)e.hasOwnProperty(a)&&(t=e[a],this[a]=t?t(i):i[a]);return this.isDefaultPrevented=(null!=i.defaultPrevented?i.defaultPrevented:!1===i.returnValue)?on:an,this.isPropagationStopped=an,this}return i(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var e=this.nativeEvent;e&&(e.preventDefault?e.preventDefault():"unknown"!=typeof e.returnValue&&(e.returnValue=!1),this.isDefaultPrevented=on)},stopPropagation:function(){var e=this.nativeEvent;e&&(e.stopPropagation?e.stopPropagation():"unknown"!=typeof e.cancelBubble&&(e.cancelBubble=!0),this.isPropagationStopped=on)},persist:function(){},isPersistent:on}),t}var ln,cn,un,dn={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},hn=sn(dn),pn=i({},dn,{view:0,detail:0}),fn=sn(pn),mn=i({},pn,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:En,button:0,buttons:0,relatedTarget:function(e){return void 0===e.relatedTarget?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==un&&(un&&"mousemove"===e.type?(ln=e.screenX-un.screenX,cn=e.screenY-un.screenY):cn=ln=0,un=e),ln)},movementY:function(e){return"movementY"in e?e.movementY:cn}}),gn=sn(mn),vn=sn(i({},mn,{dataTransfer:0})),yn=sn(i({},pn,{relatedTarget:0})),_n=sn(i({},dn,{animationName:0,elapsedTime:0,pseudoElement:0})),bn=sn(i({},dn,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}})),Mn=sn(i({},dn,{data:0})),wn={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},An={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Cn={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function xn(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):!!(e=Cn[e])&&!!t[e]}function En(){return xn}var Ln=sn(i({},pn,{key:function(e){if(e.key){var t=wn[e.key]||e.key;if("Unidentified"!==t)return t}return"keypress"===e.type?13===(e=rn(e))?"Enter":String.fromCharCode(e):"keydown"===e.type||"keyup"===e.type?An[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:En,charCode:function(e){return"keypress"===e.type?rn(e):0},keyCode:function(e){return"keydown"===e.type||"keyup"===e.type?e.keyCode:0},which:function(e){return"keypress"===e.type?rn(e):"keydown"===e.type||"keyup"===e.type?e.keyCode:0}})),Sn=sn(i({},mn,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0})),Tn=sn(i({},pn,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:En})),On=sn(i({},dn,{propertyName:0,elapsedTime:0,pseudoElement:0})),In=sn(i({},mn,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0})),kn=[9,13,27,32],Dn=d&&"CompositionEvent"in window,Nn=null;d&&"documentMode"in document&&(Nn=document.documentMode);var jn=d&&"TextEvent"in window&&!Nn,Pn=d&&(!Dn||Nn&&8<Nn&&11>=Nn),zn=String.fromCharCode(32),Rn=!1;function Bn(e,t){switch(e){case"keyup":return-1!==kn.indexOf(t.keyCode);case"keydown":return 229!==t.keyCode;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Hn(e){return"object"==typeof(e=e.detail)&&"data"in e?e.data:null}var Fn=!1;var Yn={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Vn(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return"input"===t?!!Yn[e.type]:"textarea"===t}function Un(e,t,n,r){Oe(r),0<(t=kr(t,"onChange")).length&&(n=new hn("onChange","change",null,n,r),e.push({event:n,listeners:t}))}var Wn=null,Gn=null;function qn(e){Cr(e,0)}function Kn(e){if(Q($r(e)))return e}function Xn(e,t){if("change"===e)return t}var Jn=!1;if(d){var Qn;if(d){var Zn="oninput"in document;if(!Zn){var $n=document.createElement("div");$n.setAttribute("oninput","return;"),Zn="function"==typeof $n.oninput}Qn=Zn}else Qn=!1;Jn=Qn&&(!document.documentMode||9<document.documentMode)}function er(){Wn&&(Wn.detachEvent("onpropertychange",tr),Gn=Wn=null)}function tr(e){if("value"===e.propertyName&&Kn(Gn)){var t=[];if(Un(t,Gn,e,xe(e)),e=qn,Pe)e(t);else{Pe=!0;try{ke(e,t)}finally{Pe=!1,Re()}}}}function nr(e,t,n){"focusin"===e?(er(),Gn=n,(Wn=t).attachEvent("onpropertychange",tr)):"focusout"===e&&er()}function rr(e){if("selectionchange"===e||"keyup"===e||"keydown"===e)return Kn(Gn)}function ir(e,t){if("click"===e)return Kn(t)}function or(e,t){if("input"===e||"change"===e)return Kn(t)}var ar="function"==typeof Object.is?Object.is:function(e,t){return e===t&&(0!==e||1/e==1/t)||e!=e&&t!=t},sr=Object.prototype.hasOwnProperty;function lr(e,t){if(ar(e,t))return!0;if("object"!=typeof e||null===e||"object"!=typeof t||null===t)return!1;var n=Object.keys(e),r=Object.keys(t);if(n.length!==r.length)return!1;for(r=0;r<n.length;r++)if(!sr.call(t,n[r])||!ar(e[n[r]],t[n[r]]))return!1;return!0}function cr(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function ur(e,t){var n,r=cr(e);for(e=0;r;){if(3===r.nodeType){if(n=e+r.textContent.length,e<=t&&n>=t)return{node:r,offset:t-e};e=n}e:{for(;r;){if(r.nextSibling){r=r.nextSibling;break e}r=r.parentNode}r=void 0}r=cr(r)}}function dr(){for(var e=window,t=Z();t instanceof e.HTMLIFrameElement;){try{var n="string"==typeof t.contentWindow.location.href}catch(e){n=!1}if(!n)break;t=Z((e=t.contentWindow).document)}return t}function hr(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&("input"===t&&("text"===e.type||"search"===e.type||"tel"===e.type||"url"===e.type||"password"===e.type)||"textarea"===t||"true"===e.contentEditable)}var pr=d&&"documentMode"in document&&11>=document.documentMode,fr=null,mr=null,gr=null,vr=!1;function yr(e,t,n){var r=n.window===n?n.document:9===n.nodeType?n:n.ownerDocument;vr||null==fr||fr!==Z(r)||("selectionStart"in(r=fr)&&hr(r)?r={start:r.selectionStart,end:r.selectionEnd}:r={anchorNode:(r=(r.ownerDocument&&r.ownerDocument.defaultView||window).getSelection()).anchorNode,anchorOffset:r.anchorOffset,focusNode:r.focusNode,focusOffset:r.focusOffset},gr&&lr(gr,r)||(gr=r,0<(r=kr(mr,"onSelect")).length&&(t=new hn("onSelect","select",null,t,n),e.push({event:t,listeners:r}),t.target=fr)))}Nt("cancel cancel click click close close contextmenu contextMenu copy copy cut cut auxclick auxClick dblclick doubleClick dragend dragEnd dragstart dragStart drop drop focusin focus focusout blur input input invalid invalid keydown keyDown keypress keyPress keyup keyUp mousedown mouseDown mouseup mouseUp paste paste pause pause play play pointercancel pointerCancel pointerdown pointerDown pointerup pointerUp ratechange rateChange reset reset seeked seeked submit submit touchcancel touchCancel touchend touchEnd touchstart touchStart volumechange volumeChange".split(" "),0),Nt("drag drag dragenter dragEnter dragexit dragExit dragleave dragLeave dragover dragOver mousemove mouseMove mouseout mouseOut mouseover mouseOver pointermove pointerMove pointerout pointerOut pointerover pointerOver scroll scroll toggle toggle touchmove touchMove wheel wheel".split(" "),1),Nt(Dt,2);for(var _r="change selectionchange textInput compositionstart compositionend compositionupdate".split(" "),br=0;br<_r.length;br++)kt.set(_r[br],0);u("onMouseEnter",["mouseout","mouseover"]),u("onMouseLeave",["mouseout","mouseover"]),u("onPointerEnter",["pointerout","pointerover"]),u("onPointerLeave",["pointerout","pointerover"]),c("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),c("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),c("onBeforeInput",["compositionend","keypress","textInput","paste"]),c("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),c("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),c("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Mr="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),wr=new Set("cancel close invalid load scroll toggle".split(" ").concat(Mr));function Ar(e,t,n){var r=e.type||"unknown-event";e.currentTarget=n,function(e,t,n,r,i,o,s,l,c){if(Ke.apply(this,arguments),Ve){if(!Ve)throw Error(a(198));var u=Ue;Ve=!1,Ue=null,We||(We=!0,Ge=u)}}(r,t,void 0,e),e.currentTarget=null}function Cr(e,t){t=0!=(4&t);for(var n=0;n<e.length;n++){var r=e[n],i=r.event;r=r.listeners;e:{var o=void 0;if(t)for(var a=r.length-1;0<=a;a--){var s=r[a],l=s.instance,c=s.currentTarget;if(s=s.listener,l!==o&&i.isPropagationStopped())break e;Ar(i,s,c),o=l}else for(a=0;a<r.length;a++){if(l=(s=r[a]).instance,c=s.currentTarget,s=s.listener,l!==o&&i.isPropagationStopped())break e;Ar(i,s,c),o=l}}}if(We)throw e=Ge,We=!1,Ge=null,e}function xr(e,t){var n=ti(t),r=e+"__bubble";n.has(r)||(Tr(t,e,2,!1),n.add(r))}var Er="_reactListening"+Math.random().toString(36).slice(2);function Lr(e){e[Er]||(e[Er]=!0,s.forEach((function(t){wr.has(t)||Sr(t,!1,e,null),Sr(t,!0,e,null)})))}function Sr(e,t,n,r){var i=4<arguments.length&&void 0!==arguments[4]?arguments[4]:0,o=n;if("selectionchange"===e&&9!==n.nodeType&&(o=n.ownerDocument),null!==r&&!t&&wr.has(e)){if("scroll"!==e)return;i|=2,o=r}var a=ti(o),s=e+"__"+(t?"capture":"bubble");a.has(s)||(t&&(i|=4),Tr(o,e,i,t),a.add(s))}function Tr(e,t,n,r){var i=kt.get(t);switch(void 0===i?2:i){case 0:i=Xt;break;case 1:i=Jt;break;default:i=Qt}n=i.bind(null,t,n,e),i=void 0,!He||"touchstart"!==t&&"touchmove"!==t&&"wheel"!==t||(i=!0),r?void 0!==i?e.addEventListener(t,n,{capture:!0,passive:i}):e.addEventListener(t,n,!0):void 0!==i?e.addEventListener(t,n,{passive:i}):e.addEventListener(t,n,!1)}function Or(e,t,n,r,i){var o=r;if(0==(1&t)&&0==(2&t)&&null!==r)e:for(;;){if(null===r)return;var a=r.tag;if(3===a||4===a){var s=r.stateNode.containerInfo;if(s===i||8===s.nodeType&&s.parentNode===i)break;if(4===a)for(a=r.return;null!==a;){var l=a.tag;if((3===l||4===l)&&((l=a.stateNode.containerInfo)===i||8===l.nodeType&&l.parentNode===i))return;a=a.return}for(;null!==s;){if(null===(a=Qr(s)))return;if(5===(l=a.tag)||6===l){r=o=a;continue e}s=s.parentNode}}r=r.return}!function(e,t,n){if(ze)return e(t,n);ze=!0;try{je(e,t,n)}finally{ze=!1,Re()}}((function(){var r=o,i=xe(n),a=[];e:{var s=It.get(e);if(void 0!==s){var l=hn,c=e;switch(e){case"keypress":if(0===rn(n))break e;case"keydown":case"keyup":l=Ln;break;case"focusin":c="focus",l=yn;break;case"focusout":c="blur",l=yn;break;case"beforeblur":case"afterblur":l=yn;break;case"click":if(2===n.button)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":l=gn;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":l=vn;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":l=Tn;break;case Lt:case St:case Tt:l=_n;break;case Ot:l=On;break;case"scroll":l=fn;break;case"wheel":l=In;break;case"copy":case"cut":case"paste":l=bn;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":l=Sn}var u=0!=(4&t),d=!u&&"scroll"===e,h=u?null!==s?s+"Capture":null:s;u=[];for(var p,f=r;null!==f;){var m=(p=f).stateNode;if(5===p.tag&&null!==m&&(p=m,null!==h&&(null!=(m=Be(f,h))&&u.push(Ir(f,m,p)))),d)break;f=f.return}0<u.length&&(s=new l(s,c,null,n,i),a.push({event:s,listeners:u}))}}if(0==(7&t)){if(l="mouseout"===e||"pointerout"===e,(!(s="mouseover"===e||"pointerover"===e)||0!=(16&t)||!(c=n.relatedTarget||n.fromElement)||!Qr(c)&&!c[Xr])&&(l||s)&&(s=i.window===i?i:(s=i.ownerDocument)?s.defaultView||s.parentWindow:window,l?(l=r,null!==(c=(c=n.relatedTarget||n.toElement)?Qr(c):null)&&(c!==(d=Xe(c))||5!==c.tag&&6!==c.tag)&&(c=null)):(l=null,c=r),l!==c)){if(u=gn,m="onMouseLeave",h="onMouseEnter",f="mouse","pointerout"!==e&&"pointerover"!==e||(u=Sn,m="onPointerLeave",h="onPointerEnter",f="pointer"),d=null==l?s:$r(l),p=null==c?s:$r(c),(s=new u(m,f+"leave",l,n,i)).target=d,s.relatedTarget=p,m=null,Qr(i)===r&&((u=new u(h,f+"enter",c,n,i)).target=p,u.relatedTarget=d,m=u),d=m,l&&c)e:{for(h=c,f=0,p=u=l;p;p=Dr(p))f++;for(p=0,m=h;m;m=Dr(m))p++;for(;0<f-p;)u=Dr(u),f--;for(;0<p-f;)h=Dr(h),p--;for(;f--;){if(u===h||null!==h&&u===h.alternate)break e;u=Dr(u),h=Dr(h)}u=null}else u=null;null!==l&&Nr(a,s,l,u,!1),null!==c&&null!==d&&Nr(a,d,c,u,!0)}if("select"===(l=(s=r?$r(r):window).nodeName&&s.nodeName.toLowerCase())||"input"===l&&"file"===s.type)var g=Xn;else if(Vn(s))if(Jn)g=or;else{g=rr;var v=nr}else(l=s.nodeName)&&"input"===l.toLowerCase()&&("checkbox"===s.type||"radio"===s.type)&&(g=ir);switch(g&&(g=g(e,r))?Un(a,g,n,i):(v&&v(e,s,r),"focusout"===e&&(v=s._wrapperState)&&v.controlled&&"number"===s.type&&ie(s,"number",s.value)),v=r?$r(r):window,e){case"focusin":(Vn(v)||"true"===v.contentEditable)&&(fr=v,mr=r,gr=null);break;case"focusout":gr=mr=fr=null;break;case"mousedown":vr=!0;break;case"contextmenu":case"mouseup":case"dragend":vr=!1,yr(a,n,i);break;case"selectionchange":if(pr)break;case"keydown":case"keyup":yr(a,n,i)}var y;if(Dn)e:{switch(e){case"compositionstart":var _="onCompositionStart";break e;case"compositionend":_="onCompositionEnd";break e;case"compositionupdate":_="onCompositionUpdate";break e}_=void 0}else Fn?Bn(e,n)&&(_="onCompositionEnd"):"keydown"===e&&229===n.keyCode&&(_="onCompositionStart");_&&(Pn&&"ko"!==n.locale&&(Fn||"onCompositionStart"!==_?"onCompositionEnd"===_&&Fn&&(y=nn()):(en="value"in($t=i)?$t.value:$t.textContent,Fn=!0)),0<(v=kr(r,_)).length&&(_=new Mn(_,e,null,n,i),a.push({event:_,listeners:v}),y?_.data=y:null!==(y=Hn(n))&&(_.data=y))),(y=jn?function(e,t){switch(e){case"compositionend":return Hn(t);case"keypress":return 32!==t.which?null:(Rn=!0,zn);case"textInput":return(e=t.data)===zn&&Rn?null:e;default:return null}}(e,n):function(e,t){if(Fn)return"compositionend"===e||!Dn&&Bn(e,t)?(e=nn(),tn=en=$t=null,Fn=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Pn&&"ko"!==t.locale?null:t.data;default:return null}}(e,n))&&(0<(r=kr(r,"onBeforeInput")).length&&(i=new Mn("onBeforeInput","beforeinput",null,n,i),a.push({event:i,listeners:r}),i.data=y))}Cr(a,t)}))}function Ir(e,t,n){return{instance:e,listener:t,currentTarget:n}}function kr(e,t){for(var n=t+"Capture",r=[];null!==e;){var i=e,o=i.stateNode;5===i.tag&&null!==o&&(i=o,null!=(o=Be(e,n))&&r.unshift(Ir(e,o,i)),null!=(o=Be(e,t))&&r.push(Ir(e,o,i))),e=e.return}return r}function Dr(e){if(null===e)return null;do{e=e.return}while(e&&5!==e.tag);return e||null}function Nr(e,t,n,r,i){for(var o=t._reactName,a=[];null!==n&&n!==r;){var s=n,l=s.alternate,c=s.stateNode;if(null!==l&&l===r)break;5===s.tag&&null!==c&&(s=c,i?null!=(l=Be(n,o))&&a.unshift(Ir(n,l,s)):i||null!=(l=Be(n,o))&&a.push(Ir(n,l,s))),n=n.return}0!==a.length&&e.push({event:t,listeners:a})}function jr(){}var Pr=null,zr=null;function Rr(e,t){switch(e){case"button":case"input":case"select":case"textarea":return!!t.autoFocus}return!1}function Br(e,t){return"textarea"===e||"option"===e||"noscript"===e||"string"==typeof t.children||"number"==typeof t.children||"object"==typeof t.dangerouslySetInnerHTML&&null!==t.dangerouslySetInnerHTML&&null!=t.dangerouslySetInnerHTML.__html}var Hr="function"==typeof setTimeout?setTimeout:void 0,Fr="function"==typeof clearTimeout?clearTimeout:void 0;function Yr(e){1===e.nodeType?e.textContent="":9===e.nodeType&&(null!=(e=e.body)&&(e.textContent=""))}function Vr(e){for(;null!=e;e=e.nextSibling){var t=e.nodeType;if(1===t||3===t)break}return e}function Ur(e){e=e.previousSibling;for(var t=0;e;){if(8===e.nodeType){var n=e.data;if("$"===n||"$!"===n||"$?"===n){if(0===t)return e;t--}else"/$"===n&&t++}e=e.previousSibling}return null}var Wr=0;var Gr=Math.random().toString(36).slice(2),qr="__reactFiber$"+Gr,Kr="__reactProps$"+Gr,Xr="__reactContainer$"+Gr,Jr="__reactEvents$"+Gr;function Qr(e){var t=e[qr];if(t)return t;for(var n=e.parentNode;n;){if(t=n[Xr]||n[qr]){if(n=t.alternate,null!==t.child||null!==n&&null!==n.child)for(e=Ur(e);null!==e;){if(n=e[qr])return n;e=Ur(e)}return t}n=(e=n).parentNode}return null}function Zr(e){return!(e=e[qr]||e[Xr])||5!==e.tag&&6!==e.tag&&13!==e.tag&&3!==e.tag?null:e}function $r(e){if(5===e.tag||6===e.tag)return e.stateNode;throw Error(a(33))}function ei(e){return e[Kr]||null}function ti(e){var t=e[Jr];return void 0===t&&(t=e[Jr]=new Set),t}var ni=[],ri=-1;function ii(e){return{current:e}}function oi(e){0>ri||(e.current=ni[ri],ni[ri]=null,ri--)}function ai(e,t){ri++,ni[ri]=e.current,e.current=t}var si={},li=ii(si),ci=ii(!1),ui=si;function di(e,t){var n=e.type.contextTypes;if(!n)return si;var r=e.stateNode;if(r&&r.__reactInternalMemoizedUnmaskedChildContext===t)return r.__reactInternalMemoizedMaskedChildContext;var i,o={};for(i in n)o[i]=t[i];return r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=t,e.__reactInternalMemoizedMaskedChildContext=o),o}function hi(e){return null!=(e=e.childContextTypes)}function pi(){oi(ci),oi(li)}function fi(e,t,n){if(li.current!==si)throw Error(a(168));ai(li,t),ai(ci,n)}function mi(e,t,n){var r=e.stateNode;if(e=t.childContextTypes,"function"!=typeof r.getChildContext)return n;for(var o in r=r.getChildContext())if(!(o in e))throw Error(a(108,q(t)||"Unknown",o));return i({},n,r)}function gi(e){return e=(e=e.stateNode)&&e.__reactInternalMemoizedMergedChildContext||si,ui=li.current,ai(li,e),ai(ci,ci.current),!0}function vi(e,t,n){var r=e.stateNode;if(!r)throw Error(a(169));n?(e=mi(e,t,ui),r.__reactInternalMemoizedMergedChildContext=e,oi(ci),oi(li),ai(li,e)):oi(ci),ai(ci,n)}var yi=null,_i=null,bi=o.unstable_runWithPriority,Mi=o.unstable_scheduleCallback,wi=o.unstable_cancelCallback,Ai=o.unstable_shouldYield,Ci=o.unstable_requestPaint,xi=o.unstable_now,Ei=o.unstable_getCurrentPriorityLevel,Li=o.unstable_ImmediatePriority,Si=o.unstable_UserBlockingPriority,Ti=o.unstable_NormalPriority,Oi=o.unstable_LowPriority,Ii=o.unstable_IdlePriority,ki={},Di=void 0!==Ci?Ci:function(){},Ni=null,ji=null,Pi=!1,zi=xi(),Ri=1e4>zi?xi:function(){return xi()-zi};function Bi(){switch(Ei()){case Li:return 99;case Si:return 98;case Ti:return 97;case Oi:return 96;case Ii:return 95;default:throw Error(a(332))}}function Hi(e){switch(e){case 99:return Li;case 98:return Si;case 97:return Ti;case 96:return Oi;case 95:return Ii;default:throw Error(a(332))}}function Fi(e,t){return e=Hi(e),bi(e,t)}function Yi(e,t,n){return e=Hi(e),Mi(e,t,n)}function Vi(){if(null!==ji){var e=ji;ji=null,wi(e)}Ui()}function Ui(){if(!Pi&&null!==Ni){Pi=!0;var e=0;try{var t=Ni;Fi(99,(function(){for(;e<t.length;e++){var n=t[e];do{n=n(!0)}while(null!==n)}})),Ni=null}catch(t){throw null!==Ni&&(Ni=Ni.slice(e+1)),Mi(Li,Vi),t}finally{Pi=!1}}}var Wi=M.ReactCurrentBatchConfig;function Gi(e,t){if(e&&e.defaultProps){for(var n in t=i({},t),e=e.defaultProps)void 0===t[n]&&(t[n]=e[n]);return t}return t}var qi=ii(null),Ki=null,Xi=null,Ji=null;function Qi(){Ji=Xi=Ki=null}function Zi(e){var t=qi.current;oi(qi),e.type._context._currentValue=t}function $i(e,t){for(;null!==e;){var n=e.alternate;if((e.childLanes&t)===t){if(null===n||(n.childLanes&t)===t)break;n.childLanes|=t}else e.childLanes|=t,null!==n&&(n.childLanes|=t);e=e.return}}function eo(e,t){Ki=e,Ji=Xi=null,null!==(e=e.dependencies)&&null!==e.firstContext&&(0!=(e.lanes&t)&&(ka=!0),e.firstContext=null)}function to(e,t){if(Ji!==e&&!1!==t&&0!==t)if("number"==typeof t&&1073741823!==t||(Ji=e,t=1073741823),t={context:e,observedBits:t,next:null},null===Xi){if(null===Ki)throw Error(a(308));Xi=t,Ki.dependencies={lanes:0,firstContext:t,responders:null}}else Xi=Xi.next=t;return e._currentValue}var no=!1;function ro(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null},effects:null}}function io(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,effects:e.effects})}function oo(e,t){return{eventTime:e,lane:t,tag:0,payload:null,callback:null,next:null}}function ao(e,t){if(null!==(e=e.updateQueue)){var n=(e=e.shared).pending;null===n?t.next=t:(t.next=n.next,n.next=t),e.pending=t}}function so(e,t){var n=e.updateQueue,r=e.alternate;if(null!==r&&n===(r=r.updateQueue)){var i=null,o=null;if(null!==(n=n.firstBaseUpdate)){do{var a={eventTime:n.eventTime,lane:n.lane,tag:n.tag,payload:n.payload,callback:n.callback,next:null};null===o?i=o=a:o=o.next=a,n=n.next}while(null!==n);null===o?i=o=t:o=o.next=t}else i=o=t;return n={baseState:r.baseState,firstBaseUpdate:i,lastBaseUpdate:o,shared:r.shared,effects:r.effects},void(e.updateQueue=n)}null===(e=n.lastBaseUpdate)?n.firstBaseUpdate=t:e.next=t,n.lastBaseUpdate=t}function lo(e,t,n,r){var o=e.updateQueue;no=!1;var a=o.firstBaseUpdate,s=o.lastBaseUpdate,l=o.shared.pending;if(null!==l){o.shared.pending=null;var c=l,u=c.next;c.next=null,null===s?a=u:s.next=u,s=c;var d=e.alternate;if(null!==d){var h=(d=d.updateQueue).lastBaseUpdate;h!==s&&(null===h?d.firstBaseUpdate=u:h.next=u,d.lastBaseUpdate=c)}}if(null!==a){for(h=o.baseState,s=0,d=u=c=null;;){l=a.lane;var p=a.eventTime;if((r&l)===l){null!==d&&(d=d.next={eventTime:p,lane:0,tag:a.tag,payload:a.payload,callback:a.callback,next:null});e:{var f=e,m=a;switch(l=t,p=n,m.tag){case 1:if("function"==typeof(f=m.payload)){h=f.call(p,h,l);break e}h=f;break e;case 3:f.flags=-4097&f.flags|64;case 0:if(null==(l="function"==typeof(f=m.payload)?f.call(p,h,l):f))break e;h=i({},h,l);break e;case 2:no=!0}}null!==a.callback&&(e.flags|=32,null===(l=o.effects)?o.effects=[a]:l.push(a))}else p={eventTime:p,lane:l,tag:a.tag,payload:a.payload,callback:a.callback,next:null},null===d?(u=d=p,c=h):d=d.next=p,s|=l;if(null===(a=a.next)){if(null===(l=o.shared.pending))break;a=l.next,l.next=null,o.lastBaseUpdate=l,o.shared.pending=null}}null===d&&(c=h),o.baseState=c,o.firstBaseUpdate=u,o.lastBaseUpdate=d,Ns|=s,e.lanes=s,e.memoizedState=h}}function co(e,t,n){if(e=t.effects,t.effects=null,null!==e)for(t=0;t<e.length;t++){var r=e[t],i=r.callback;if(null!==i){if(r.callback=null,r=n,"function"!=typeof i)throw Error(a(191,i));i.call(r)}}}var uo=(new r.Component).refs;function ho(e,t,n,r){n=null==(n=n(r,t=e.memoizedState))?t:i({},t,n),e.memoizedState=n,0===e.lanes&&(e.updateQueue.baseState=n)}var po={isMounted:function(e){return!!(e=e._reactInternals)&&Xe(e)===e},enqueueSetState:function(e,t,n){e=e._reactInternals;var r=ol(),i=al(e),o=oo(r,i);o.payload=t,null!=n&&(o.callback=n),ao(e,o),sl(e,i,r)},enqueueReplaceState:function(e,t,n){e=e._reactInternals;var r=ol(),i=al(e),o=oo(r,i);o.tag=1,o.payload=t,null!=n&&(o.callback=n),ao(e,o),sl(e,i,r)},enqueueForceUpdate:function(e,t){e=e._reactInternals;var n=ol(),r=al(e),i=oo(n,r);i.tag=2,null!=t&&(i.callback=t),ao(e,i),sl(e,r,n)}};function fo(e,t,n,r,i,o,a){return"function"==typeof(e=e.stateNode).shouldComponentUpdate?e.shouldComponentUpdate(r,o,a):!t.prototype||!t.prototype.isPureReactComponent||(!lr(n,r)||!lr(i,o))}function mo(e,t,n){var r=!1,i=si,o=t.contextType;return"object"==typeof o&&null!==o?o=to(o):(i=hi(t)?ui:li.current,o=(r=null!=(r=t.contextTypes))?di(e,i):si),t=new t(n,o),e.memoizedState=null!==t.state&&void 0!==t.state?t.state:null,t.updater=po,e.stateNode=t,t._reactInternals=e,r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=i,e.__reactInternalMemoizedMaskedChildContext=o),t}function go(e,t,n,r){e=t.state,"function"==typeof t.componentWillReceiveProps&&t.componentWillReceiveProps(n,r),"function"==typeof t.UNSAFE_componentWillReceiveProps&&t.UNSAFE_componentWillReceiveProps(n,r),t.state!==e&&po.enqueueReplaceState(t,t.state,null)}function vo(e,t,n,r){var i=e.stateNode;i.props=n,i.state=e.memoizedState,i.refs=uo,ro(e);var o=t.contextType;"object"==typeof o&&null!==o?i.context=to(o):(o=hi(t)?ui:li.current,i.context=di(e,o)),lo(e,n,i,r),i.state=e.memoizedState,"function"==typeof(o=t.getDerivedStateFromProps)&&(ho(e,t,o,n),i.state=e.memoizedState),"function"==typeof t.getDerivedStateFromProps||"function"==typeof i.getSnapshotBeforeUpdate||"function"!=typeof i.UNSAFE_componentWillMount&&"function"!=typeof i.componentWillMount||(t=i.state,"function"==typeof i.componentWillMount&&i.componentWillMount(),"function"==typeof i.UNSAFE_componentWillMount&&i.UNSAFE_componentWillMount(),t!==i.state&&po.enqueueReplaceState(i,i.state,null),lo(e,n,i,r),i.state=e.memoizedState),"function"==typeof i.componentDidMount&&(e.flags|=4)}var yo=Array.isArray;function _o(e,t,n){if(null!==(e=n.ref)&&"function"!=typeof e&&"object"!=typeof e){if(n._owner){if(n=n._owner){if(1!==n.tag)throw Error(a(309));var r=n.stateNode}if(!r)throw Error(a(147,e));var i=""+e;return null!==t&&null!==t.ref&&"function"==typeof t.ref&&t.ref._stringRef===i?t.ref:((t=function(e){var t=r.refs;t===uo&&(t=r.refs={}),null===e?delete t[i]:t[i]=e})._stringRef=i,t)}if("string"!=typeof e)throw Error(a(284));if(!n._owner)throw Error(a(290,e))}return e}function bo(e,t){if("textarea"!==e.type)throw Error(a(31,"[object Object]"===Object.prototype.toString.call(t)?"object with keys {"+Object.keys(t).join(", ")+"}":t))}function Mo(e){function t(t,n){if(e){var r=t.lastEffect;null!==r?(r.nextEffect=n,t.lastEffect=n):t.firstEffect=t.lastEffect=n,n.nextEffect=null,n.flags=8}}function n(n,r){if(!e)return null;for(;null!==r;)t(n,r),r=r.sibling;return null}function r(e,t){for(e=new Map;null!==t;)null!==t.key?e.set(t.key,t):e.set(t.index,t),t=t.sibling;return e}function i(e,t){return(e=Bl(e,t)).index=0,e.sibling=null,e}function o(t,n,r){return t.index=r,e?null!==(r=t.alternate)?(r=r.index)<n?(t.flags=2,n):r:(t.flags=2,n):n}function s(t){return e&&null===t.alternate&&(t.flags=2),t}function l(e,t,n,r){return null===t||6!==t.tag?((t=Vl(n,e.mode,r)).return=e,t):((t=i(t,n)).return=e,t)}function c(e,t,n,r){return null!==t&&t.elementType===n.type?((r=i(t,n.props)).ref=_o(e,t,n),r.return=e,r):((r=Hl(n.type,n.key,n.props,null,e.mode,r)).ref=_o(e,t,n),r.return=e,r)}function u(e,t,n,r){return null===t||4!==t.tag||t.stateNode.containerInfo!==n.containerInfo||t.stateNode.implementation!==n.implementation?((t=Ul(n,e.mode,r)).return=e,t):((t=i(t,n.children||[])).return=e,t)}function d(e,t,n,r,o){return null===t||7!==t.tag?((t=Fl(n,e.mode,r,o)).return=e,t):((t=i(t,n)).return=e,t)}function h(e,t,n){if("string"==typeof t||"number"==typeof t)return(t=Vl(""+t,e.mode,n)).return=e,t;if("object"==typeof t&&null!==t){switch(t.$$typeof){case w:return(n=Hl(t.type,t.key,t.props,null,e.mode,n)).ref=_o(e,null,t),n.return=e,n;case A:return(t=Ul(t,e.mode,n)).return=e,t}if(yo(t)||Y(t))return(t=Fl(t,e.mode,n,null)).return=e,t;bo(e,t)}return null}function p(e,t,n,r){var i=null!==t?t.key:null;if("string"==typeof n||"number"==typeof n)return null!==i?null:l(e,t,""+n,r);if("object"==typeof n&&null!==n){switch(n.$$typeof){case w:return n.key===i?n.type===C?d(e,t,n.props.children,r,i):c(e,t,n,r):null;case A:return n.key===i?u(e,t,n,r):null}if(yo(n)||Y(n))return null!==i?null:d(e,t,n,r,null);bo(e,n)}return null}function f(e,t,n,r,i){if("string"==typeof r||"number"==typeof r)return l(t,e=e.get(n)||null,""+r,i);if("object"==typeof r&&null!==r){switch(r.$$typeof){case w:return e=e.get(null===r.key?n:r.key)||null,r.type===C?d(t,e,r.props.children,i,r.key):c(t,e,r,i);case A:return u(t,e=e.get(null===r.key?n:r.key)||null,r,i)}if(yo(r)||Y(r))return d(t,e=e.get(n)||null,r,i,null);bo(t,r)}return null}function m(i,a,s,l){for(var c=null,u=null,d=a,m=a=0,g=null;null!==d&&m<s.length;m++){d.index>m?(g=d,d=null):g=d.sibling;var v=p(i,d,s[m],l);if(null===v){null===d&&(d=g);break}e&&d&&null===v.alternate&&t(i,d),a=o(v,a,m),null===u?c=v:u.sibling=v,u=v,d=g}if(m===s.length)return n(i,d),c;if(null===d){for(;m<s.length;m++)null!==(d=h(i,s[m],l))&&(a=o(d,a,m),null===u?c=d:u.sibling=d,u=d);return c}for(d=r(i,d);m<s.length;m++)null!==(g=f(d,i,m,s[m],l))&&(e&&null!==g.alternate&&d.delete(null===g.key?m:g.key),a=o(g,a,m),null===u?c=g:u.sibling=g,u=g);return e&&d.forEach((function(e){return t(i,e)})),c}function g(i,s,l,c){var u=Y(l);if("function"!=typeof u)throw Error(a(150));if(null==(l=u.call(l)))throw Error(a(151));for(var d=u=null,m=s,g=s=0,v=null,y=l.next();null!==m&&!y.done;g++,y=l.next()){m.index>g?(v=m,m=null):v=m.sibling;var _=p(i,m,y.value,c);if(null===_){null===m&&(m=v);break}e&&m&&null===_.alternate&&t(i,m),s=o(_,s,g),null===d?u=_:d.sibling=_,d=_,m=v}if(y.done)return n(i,m),u;if(null===m){for(;!y.done;g++,y=l.next())null!==(y=h(i,y.value,c))&&(s=o(y,s,g),null===d?u=y:d.sibling=y,d=y);return u}for(m=r(i,m);!y.done;g++,y=l.next())null!==(y=f(m,i,g,y.value,c))&&(e&&null!==y.alternate&&m.delete(null===y.key?g:y.key),s=o(y,s,g),null===d?u=y:d.sibling=y,d=y);return e&&m.forEach((function(e){return t(i,e)})),u}return function(e,r,o,l){var c="object"==typeof o&&null!==o&&o.type===C&&null===o.key;c&&(o=o.props.children);var u="object"==typeof o&&null!==o;if(u)switch(o.$$typeof){case w:e:{for(u=o.key,c=r;null!==c;){if(c.key===u){switch(c.tag){case 7:if(o.type===C){n(e,c.sibling),(r=i(c,o.props.children)).return=e,e=r;break e}break;default:if(c.elementType===o.type){n(e,c.sibling),(r=i(c,o.props)).ref=_o(e,c,o),r.return=e,e=r;break e}}n(e,c);break}t(e,c),c=c.sibling}o.type===C?((r=Fl(o.props.children,e.mode,l,o.key)).return=e,e=r):((l=Hl(o.type,o.key,o.props,null,e.mode,l)).ref=_o(e,r,o),l.return=e,e=l)}return s(e);case A:e:{for(c=o.key;null!==r;){if(r.key===c){if(4===r.tag&&r.stateNode.containerInfo===o.containerInfo&&r.stateNode.implementation===o.implementation){n(e,r.sibling),(r=i(r,o.children||[])).return=e,e=r;break e}n(e,r);break}t(e,r),r=r.sibling}(r=Ul(o,e.mode,l)).return=e,e=r}return s(e)}if("string"==typeof o||"number"==typeof o)return o=""+o,null!==r&&6===r.tag?(n(e,r.sibling),(r=i(r,o)).return=e,e=r):(n(e,r),(r=Vl(o,e.mode,l)).return=e,e=r),s(e);if(yo(o))return m(e,r,o,l);if(Y(o))return g(e,r,o,l);if(u&&bo(e,o),void 0===o&&!c)switch(e.tag){case 1:case 22:case 0:case 11:case 15:throw Error(a(152,q(e.type)||"Component"))}return n(e,r)}}var wo=Mo(!0),Ao=Mo(!1),Co={},xo=ii(Co),Eo=ii(Co),Lo=ii(Co);function So(e){if(e===Co)throw Error(a(174));return e}function To(e,t){switch(ai(Lo,t),ai(Eo,e),ai(xo,Co),e=t.nodeType){case 9:case 11:t=(t=t.documentElement)?t.namespaceURI:fe(null,"");break;default:t=fe(t=(e=8===e?t.parentNode:t).namespaceURI||null,e=e.tagName)}oi(xo),ai(xo,t)}function Oo(){oi(xo),oi(Eo),oi(Lo)}function Io(e){So(Lo.current);var t=So(xo.current),n=fe(t,e.type);t!==n&&(ai(Eo,e),ai(xo,n))}function ko(e){Eo.current===e&&(oi(xo),oi(Eo))}var Do=ii(0);function No(e){for(var t=e;null!==t;){if(13===t.tag){var n=t.memoizedState;if(null!==n&&(null===(n=n.dehydrated)||"$?"===n.data||"$!"===n.data))return t}else if(19===t.tag&&void 0!==t.memoizedProps.revealOrder){if(0!=(64&t.flags))return t}else if(null!==t.child){t.child.return=t,t=t.child;continue}if(t===e)break;for(;null===t.sibling;){if(null===t.return||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var jo=null,Po=null,zo=!1;function Ro(e,t){var n=zl(5,null,null,0);n.elementType="DELETED",n.type="DELETED",n.stateNode=t,n.return=e,n.flags=8,null!==e.lastEffect?(e.lastEffect.nextEffect=n,e.lastEffect=n):e.firstEffect=e.lastEffect=n}function Bo(e,t){switch(e.tag){case 5:var n=e.type;return null!==(t=1!==t.nodeType||n.toLowerCase()!==t.nodeName.toLowerCase()?null:t)&&(e.stateNode=t,!0);case 6:return null!==(t=""===e.pendingProps||3!==t.nodeType?null:t)&&(e.stateNode=t,!0);case 13:default:return!1}}function Ho(e){if(zo){var t=Po;if(t){var n=t;if(!Bo(e,t)){if(!(t=Vr(n.nextSibling))||!Bo(e,t))return e.flags=-1025&e.flags|2,zo=!1,void(jo=e);Ro(jo,n)}jo=e,Po=Vr(t.firstChild)}else e.flags=-1025&e.flags|2,zo=!1,jo=e}}function Fo(e){for(e=e.return;null!==e&&5!==e.tag&&3!==e.tag&&13!==e.tag;)e=e.return;jo=e}function Yo(e){if(e!==jo)return!1;if(!zo)return Fo(e),zo=!0,!1;var t=e.type;if(5!==e.tag||"head"!==t&&"body"!==t&&!Br(t,e.memoizedProps))for(t=Po;t;)Ro(e,t),t=Vr(t.nextSibling);if(Fo(e),13===e.tag){if(!(e=null!==(e=e.memoizedState)?e.dehydrated:null))throw Error(a(317));e:{for(e=e.nextSibling,t=0;e;){if(8===e.nodeType){var n=e.data;if("/$"===n){if(0===t){Po=Vr(e.nextSibling);break e}t--}else"$"!==n&&"$!"!==n&&"$?"!==n||t++}e=e.nextSibling}Po=null}}else Po=jo?Vr(e.stateNode.nextSibling):null;return!0}function Vo(){Po=jo=null,zo=!1}var Uo=[];function Wo(){for(var e=0;e<Uo.length;e++)Uo[e]._workInProgressVersionPrimary=null;Uo.length=0}var Go=M.ReactCurrentDispatcher,qo=M.ReactCurrentBatchConfig,Ko=0,Xo=null,Jo=null,Qo=null,Zo=!1,$o=!1;function ea(){throw Error(a(321))}function ta(e,t){if(null===t)return!1;for(var n=0;n<t.length&&n<e.length;n++)if(!ar(e[n],t[n]))return!1;return!0}function na(e,t,n,r,i,o){if(Ko=o,Xo=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,Go.current=null===e||null===e.memoizedState?Sa:Ta,e=n(r,i),$o){o=0;do{if($o=!1,!(25>o))throw Error(a(301));o+=1,Qo=Jo=null,t.updateQueue=null,Go.current=Oa,e=n(r,i)}while($o)}if(Go.current=La,t=null!==Jo&&null!==Jo.next,Ko=0,Qo=Jo=Xo=null,Zo=!1,t)throw Error(a(300));return e}function ra(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return null===Qo?Xo.memoizedState=Qo=e:Qo=Qo.next=e,Qo}function ia(){if(null===Jo){var e=Xo.alternate;e=null!==e?e.memoizedState:null}else e=Jo.next;var t=null===Qo?Xo.memoizedState:Qo.next;if(null!==t)Qo=t,Jo=e;else{if(null===e)throw Error(a(310));e={memoizedState:(Jo=e).memoizedState,baseState:Jo.baseState,baseQueue:Jo.baseQueue,queue:Jo.queue,next:null},null===Qo?Xo.memoizedState=Qo=e:Qo=Qo.next=e}return Qo}function oa(e,t){return"function"==typeof t?t(e):t}function aa(e){var t=ia(),n=t.queue;if(null===n)throw Error(a(311));n.lastRenderedReducer=e;var r=Jo,i=r.baseQueue,o=n.pending;if(null!==o){if(null!==i){var s=i.next;i.next=o.next,o.next=s}r.baseQueue=i=o,n.pending=null}if(null!==i){i=i.next,r=r.baseState;var l=s=o=null,c=i;do{var u=c.lane;if((Ko&u)===u)null!==l&&(l=l.next={lane:0,action:c.action,eagerReducer:c.eagerReducer,eagerState:c.eagerState,next:null}),r=c.eagerReducer===e?c.eagerState:e(r,c.action);else{var d={lane:u,action:c.action,eagerReducer:c.eagerReducer,eagerState:c.eagerState,next:null};null===l?(s=l=d,o=r):l=l.next=d,Xo.lanes|=u,Ns|=u}c=c.next}while(null!==c&&c!==i);null===l?o=r:l.next=s,ar(r,t.memoizedState)||(ka=!0),t.memoizedState=r,t.baseState=o,t.baseQueue=l,n.lastRenderedState=r}return[t.memoizedState,n.dispatch]}function sa(e){var t=ia(),n=t.queue;if(null===n)throw Error(a(311));n.lastRenderedReducer=e;var r=n.dispatch,i=n.pending,o=t.memoizedState;if(null!==i){n.pending=null;var s=i=i.next;do{o=e(o,s.action),s=s.next}while(s!==i);ar(o,t.memoizedState)||(ka=!0),t.memoizedState=o,null===t.baseQueue&&(t.baseState=o),n.lastRenderedState=o}return[o,r]}function la(e,t,n){var r=t._getVersion;r=r(t._source);var i=t._workInProgressVersionPrimary;if(null!==i?e=i===r:(e=e.mutableReadLanes,(e=(Ko&e)===e)&&(t._workInProgressVersionPrimary=r,Uo.push(t))),e)return n(t._source);throw Uo.push(t),Error(a(350))}function ca(e,t,n,r){var i=Es;if(null===i)throw Error(a(349));var o=t._getVersion,s=o(t._source),l=Go.current,c=l.useState((function(){return la(i,t,n)})),u=c[1],d=c[0];c=Qo;var h=e.memoizedState,p=h.refs,f=p.getSnapshot,m=h.source;h=h.subscribe;var g=Xo;return e.memoizedState={refs:p,source:t,subscribe:r},l.useEffect((function(){p.getSnapshot=n,p.setSnapshot=u;var e=o(t._source);if(!ar(s,e)){e=n(t._source),ar(d,e)||(u(e),e=al(g),i.mutableReadLanes|=e&i.pendingLanes),e=i.mutableReadLanes,i.entangledLanes|=e;for(var r=i.entanglements,a=e;0<a;){var l=31-Vt(a),c=1<<l;r[l]|=e,a&=~c}}}),[n,t,r]),l.useEffect((function(){return r(t._source,(function(){var e=p.getSnapshot,n=p.setSnapshot;try{n(e(t._source));var r=al(g);i.mutableReadLanes|=r&i.pendingLanes}catch(e){n((function(){throw e}))}}))}),[t,r]),ar(f,n)&&ar(m,t)&&ar(h,r)||((e={pending:null,dispatch:null,lastRenderedReducer:oa,lastRenderedState:d}).dispatch=u=Ea.bind(null,Xo,e),c.queue=e,c.baseQueue=null,d=la(i,t,n),c.memoizedState=c.baseState=d),d}function ua(e,t,n){return ca(ia(),e,t,n)}function da(e){var t=ra();return"function"==typeof e&&(e=e()),t.memoizedState=t.baseState=e,e=(e=t.queue={pending:null,dispatch:null,lastRenderedReducer:oa,lastRenderedState:e}).dispatch=Ea.bind(null,Xo,e),[t.memoizedState,e]}function ha(e,t,n,r){return e={tag:e,create:t,destroy:n,deps:r,next:null},null===(t=Xo.updateQueue)?(t={lastEffect:null},Xo.updateQueue=t,t.lastEffect=e.next=e):null===(n=t.lastEffect)?t.lastEffect=e.next=e:(r=n.next,n.next=e,e.next=r,t.lastEffect=e),e}function pa(e){return e={current:e},ra().memoizedState=e}function fa(){return ia().memoizedState}function ma(e,t,n,r){var i=ra();Xo.flags|=e,i.memoizedState=ha(1|t,n,void 0,void 0===r?null:r)}function ga(e,t,n,r){var i=ia();r=void 0===r?null:r;var o=void 0;if(null!==Jo){var a=Jo.memoizedState;if(o=a.destroy,null!==r&&ta(r,a.deps))return void ha(t,n,o,r)}Xo.flags|=e,i.memoizedState=ha(1|t,n,o,r)}function va(e,t){return ma(516,4,e,t)}function ya(e,t){return ga(516,4,e,t)}function _a(e,t){return ga(4,2,e,t)}function ba(e,t){return"function"==typeof t?(e=e(),t(e),function(){t(null)}):null!=t?(e=e(),t.current=e,function(){t.current=null}):void 0}function Ma(e,t,n){return n=null!=n?n.concat([e]):null,ga(4,2,ba.bind(null,t,e),n)}function wa(){}function Aa(e,t){var n=ia();t=void 0===t?null:t;var r=n.memoizedState;return null!==r&&null!==t&&ta(t,r[1])?r[0]:(n.memoizedState=[e,t],e)}function Ca(e,t){var n=ia();t=void 0===t?null:t;var r=n.memoizedState;return null!==r&&null!==t&&ta(t,r[1])?r[0]:(e=e(),n.memoizedState=[e,t],e)}function xa(e,t){var n=Bi();Fi(98>n?98:n,(function(){e(!0)})),Fi(97<n?97:n,(function(){var n=qo.transition;qo.transition=1;try{e(!1),t()}finally{qo.transition=n}}))}function Ea(e,t,n){var r=ol(),i=al(e),o={lane:i,action:n,eagerReducer:null,eagerState:null,next:null},a=t.pending;if(null===a?o.next=o:(o.next=a.next,a.next=o),t.pending=o,a=e.alternate,e===Xo||null!==a&&a===Xo)$o=Zo=!0;else{if(0===e.lanes&&(null===a||0===a.lanes)&&null!==(a=t.lastRenderedReducer))try{var s=t.lastRenderedState,l=a(s,n);if(o.eagerReducer=a,o.eagerState=l,ar(l,s))return}catch(e){}sl(e,i,r)}}var La={readContext:to,useCallback:ea,useContext:ea,useEffect:ea,useImperativeHandle:ea,useLayoutEffect:ea,useMemo:ea,useReducer:ea,useRef:ea,useState:ea,useDebugValue:ea,useDeferredValue:ea,useTransition:ea,useMutableSource:ea,useOpaqueIdentifier:ea,unstable_isNewReconciler:!1},Sa={readContext:to,useCallback:function(e,t){return ra().memoizedState=[e,void 0===t?null:t],e},useContext:to,useEffect:va,useImperativeHandle:function(e,t,n){return n=null!=n?n.concat([e]):null,ma(4,2,ba.bind(null,t,e),n)},useLayoutEffect:function(e,t){return ma(4,2,e,t)},useMemo:function(e,t){var n=ra();return t=void 0===t?null:t,e=e(),n.memoizedState=[e,t],e},useReducer:function(e,t,n){var r=ra();return t=void 0!==n?n(t):t,r.memoizedState=r.baseState=t,e=(e=r.queue={pending:null,dispatch:null,lastRenderedReducer:e,lastRenderedState:t}).dispatch=Ea.bind(null,Xo,e),[r.memoizedState,e]},useRef:pa,useState:da,useDebugValue:wa,useDeferredValue:function(e){var t=da(e),n=t[0],r=t[1];return va((function(){var t=qo.transition;qo.transition=1;try{r(e)}finally{qo.transition=t}}),[e]),n},useTransition:function(){var e=da(!1),t=e[0];return pa(e=xa.bind(null,e[1])),[e,t]},useMutableSource:function(e,t,n){var r=ra();return r.memoizedState={refs:{getSnapshot:t,setSnapshot:null},source:e,subscribe:n},ca(r,e,t,n)},useOpaqueIdentifier:function(){if(zo){var e=!1,t=function(e){return{$$typeof:j,toString:e,valueOf:e}}((function(){throw e||(e=!0,n("r:"+(Wr++).toString(36))),Error(a(355))})),n=da(t)[1];return 0==(2&Xo.mode)&&(Xo.flags|=516,ha(5,(function(){n("r:"+(Wr++).toString(36))}),void 0,null)),t}return da(t="r:"+(Wr++).toString(36)),t},unstable_isNewReconciler:!1},Ta={readContext:to,useCallback:Aa,useContext:to,useEffect:ya,useImperativeHandle:Ma,useLayoutEffect:_a,useMemo:Ca,useReducer:aa,useRef:fa,useState:function(){return aa(oa)},useDebugValue:wa,useDeferredValue:function(e){var t=aa(oa),n=t[0],r=t[1];return ya((function(){var t=qo.transition;qo.transition=1;try{r(e)}finally{qo.transition=t}}),[e]),n},useTransition:function(){var e=aa(oa)[0];return[fa().current,e]},useMutableSource:ua,useOpaqueIdentifier:function(){return aa(oa)[0]},unstable_isNewReconciler:!1},Oa={readContext:to,useCallback:Aa,useContext:to,useEffect:ya,useImperativeHandle:Ma,useLayoutEffect:_a,useMemo:Ca,useReducer:sa,useRef:fa,useState:function(){return sa(oa)},useDebugValue:wa,useDeferredValue:function(e){var t=sa(oa),n=t[0],r=t[1];return ya((function(){var t=qo.transition;qo.transition=1;try{r(e)}finally{qo.transition=t}}),[e]),n},useTransition:function(){var e=sa(oa)[0];return[fa().current,e]},useMutableSource:ua,useOpaqueIdentifier:function(){return sa(oa)[0]},unstable_isNewReconciler:!1},Ia=M.ReactCurrentOwner,ka=!1;function Da(e,t,n,r){t.child=null===e?Ao(t,null,n,r):wo(t,e.child,n,r)}function Na(e,t,n,r,i){n=n.render;var o=t.ref;return eo(t,i),r=na(e,t,n,r,o,i),null===e||ka?(t.flags|=1,Da(e,t,r,i),t.child):(t.updateQueue=e.updateQueue,t.flags&=-517,e.lanes&=~i,es(e,t,i))}function ja(e,t,n,r,i,o){if(null===e){var a=n.type;return"function"!=typeof a||Rl(a)||void 0!==a.defaultProps||null!==n.compare||void 0!==n.defaultProps?((e=Hl(n.type,null,r,t,t.mode,o)).ref=t.ref,e.return=t,t.child=e):(t.tag=15,t.type=a,Pa(e,t,a,r,i,o))}return a=e.child,0==(i&o)&&(i=a.memoizedProps,(n=null!==(n=n.compare)?n:lr)(i,r)&&e.ref===t.ref)?es(e,t,o):(t.flags|=1,(e=Bl(a,r)).ref=t.ref,e.return=t,t.child=e)}function Pa(e,t,n,r,i,o){if(null!==e&&lr(e.memoizedProps,r)&&e.ref===t.ref){if(ka=!1,0==(o&i))return t.lanes=e.lanes,es(e,t,o);0!=(16384&e.flags)&&(ka=!0)}return Ba(e,t,n,r,o)}function za(e,t,n){var r=t.pendingProps,i=r.children,o=null!==e?e.memoizedState:null;if("hidden"===r.mode||"unstable-defer-without-hiding"===r.mode)if(0==(4&t.mode))t.memoizedState={baseLanes:0},ml(t,n);else{if(0==(1073741824&n))return e=null!==o?o.baseLanes|n:n,t.lanes=t.childLanes=1073741824,t.memoizedState={baseLanes:e},ml(t,e),null;t.memoizedState={baseLanes:0},ml(t,null!==o?o.baseLanes:n)}else null!==o?(r=o.baseLanes|n,t.memoizedState=null):r=n,ml(t,r);return Da(e,t,i,n),t.child}function Ra(e,t){var n=t.ref;(null===e&&null!==n||null!==e&&e.ref!==n)&&(t.flags|=128)}function Ba(e,t,n,r,i){var o=hi(n)?ui:li.current;return o=di(t,o),eo(t,i),n=na(e,t,n,r,o,i),null===e||ka?(t.flags|=1,Da(e,t,n,i),t.child):(t.updateQueue=e.updateQueue,t.flags&=-517,e.lanes&=~i,es(e,t,i))}function Ha(e,t,n,r,i){if(hi(n)){var o=!0;gi(t)}else o=!1;if(eo(t,i),null===t.stateNode)null!==e&&(e.alternate=null,t.alternate=null,t.flags|=2),mo(t,n,r),vo(t,n,r,i),r=!0;else if(null===e){var a=t.stateNode,s=t.memoizedProps;a.props=s;var l=a.context,c=n.contextType;"object"==typeof c&&null!==c?c=to(c):c=di(t,c=hi(n)?ui:li.current);var u=n.getDerivedStateFromProps,d="function"==typeof u||"function"==typeof a.getSnapshotBeforeUpdate;d||"function"!=typeof a.UNSAFE_componentWillReceiveProps&&"function"!=typeof a.componentWillReceiveProps||(s!==r||l!==c)&&go(t,a,r,c),no=!1;var h=t.memoizedState;a.state=h,lo(t,r,a,i),l=t.memoizedState,s!==r||h!==l||ci.current||no?("function"==typeof u&&(ho(t,n,u,r),l=t.memoizedState),(s=no||fo(t,n,s,r,h,l,c))?(d||"function"!=typeof a.UNSAFE_componentWillMount&&"function"!=typeof a.componentWillMount||("function"==typeof a.componentWillMount&&a.componentWillMount(),"function"==typeof a.UNSAFE_componentWillMount&&a.UNSAFE_componentWillMount()),"function"==typeof a.componentDidMount&&(t.flags|=4)):("function"==typeof a.componentDidMount&&(t.flags|=4),t.memoizedProps=r,t.memoizedState=l),a.props=r,a.state=l,a.context=c,r=s):("function"==typeof a.componentDidMount&&(t.flags|=4),r=!1)}else{a=t.stateNode,io(e,t),s=t.memoizedProps,c=t.type===t.elementType?s:Gi(t.type,s),a.props=c,d=t.pendingProps,h=a.context,"object"==typeof(l=n.contextType)&&null!==l?l=to(l):l=di(t,l=hi(n)?ui:li.current);var p=n.getDerivedStateFromProps;(u="function"==typeof p||"function"==typeof a.getSnapshotBeforeUpdate)||"function"!=typeof a.UNSAFE_componentWillReceiveProps&&"function"!=typeof a.componentWillReceiveProps||(s!==d||h!==l)&&go(t,a,r,l),no=!1,h=t.memoizedState,a.state=h,lo(t,r,a,i);var f=t.memoizedState;s!==d||h!==f||ci.current||no?("function"==typeof p&&(ho(t,n,p,r),f=t.memoizedState),(c=no||fo(t,n,c,r,h,f,l))?(u||"function"!=typeof a.UNSAFE_componentWillUpdate&&"function"!=typeof a.componentWillUpdate||("function"==typeof a.componentWillUpdate&&a.componentWillUpdate(r,f,l),"function"==typeof a.UNSAFE_componentWillUpdate&&a.UNSAFE_componentWillUpdate(r,f,l)),"function"==typeof a.componentDidUpdate&&(t.flags|=4),"function"==typeof a.getSnapshotBeforeUpdate&&(t.flags|=256)):("function"!=typeof a.componentDidUpdate||s===e.memoizedProps&&h===e.memoizedState||(t.flags|=4),"function"!=typeof a.getSnapshotBeforeUpdate||s===e.memoizedProps&&h===e.memoizedState||(t.flags|=256),t.memoizedProps=r,t.memoizedState=f),a.props=r,a.state=f,a.context=l,r=c):("function"!=typeof a.componentDidUpdate||s===e.memoizedProps&&h===e.memoizedState||(t.flags|=4),"function"!=typeof a.getSnapshotBeforeUpdate||s===e.memoizedProps&&h===e.memoizedState||(t.flags|=256),r=!1)}return Fa(e,t,n,r,o,i)}function Fa(e,t,n,r,i,o){Ra(e,t);var a=0!=(64&t.flags);if(!r&&!a)return i&&vi(t,n,!1),es(e,t,o);r=t.stateNode,Ia.current=t;var s=a&&"function"!=typeof n.getDerivedStateFromError?null:r.render();return t.flags|=1,null!==e&&a?(t.child=wo(t,e.child,null,o),t.child=wo(t,null,s,o)):Da(e,t,s,o),t.memoizedState=r.state,i&&vi(t,n,!0),t.child}function Ya(e){var t=e.stateNode;t.pendingContext?fi(0,t.pendingContext,t.pendingContext!==t.context):t.context&&fi(0,t.context,!1),To(e,t.containerInfo)}var Va,Ua,Wa,Ga={dehydrated:null,retryLane:0};function qa(e,t,n){var r,i=t.pendingProps,o=Do.current,a=!1;return(r=0!=(64&t.flags))||(r=(null===e||null!==e.memoizedState)&&0!=(2&o)),r?(a=!0,t.flags&=-65):null!==e&&null===e.memoizedState||void 0===i.fallback||!0===i.unstable_avoidThisFallback||(o|=1),ai(Do,1&o),null===e?(void 0!==i.fallback&&Ho(t),e=i.children,o=i.fallback,a?(e=Ka(t,e,o,n),t.child.memoizedState={baseLanes:n},t.memoizedState=Ga,e):"number"==typeof i.unstable_expectedLoadTime?(e=Ka(t,e,o,n),t.child.memoizedState={baseLanes:n},t.memoizedState=Ga,t.lanes=33554432,e):((n=Yl({mode:"visible",children:e},t.mode,n,null)).return=t,t.child=n)):(e.memoizedState,a?(i=Ja(e,t,i.children,i.fallback,n),a=t.child,o=e.child.memoizedState,a.memoizedState=null===o?{baseLanes:n}:{baseLanes:o.baseLanes|n},a.childLanes=e.childLanes&~n,t.memoizedState=Ga,i):(n=Xa(e,t,i.children,n),t.memoizedState=null,n))}function Ka(e,t,n,r){var i=e.mode,o=e.child;return t={mode:"hidden",children:t},0==(2&i)&&null!==o?(o.childLanes=0,o.pendingProps=t):o=Yl(t,i,0,null),n=Fl(n,i,r,null),o.return=e,n.return=e,o.sibling=n,e.child=o,n}function Xa(e,t,n,r){var i=e.child;return e=i.sibling,n=Bl(i,{mode:"visible",children:n}),0==(2&t.mode)&&(n.lanes=r),n.return=t,n.sibling=null,null!==e&&(e.nextEffect=null,e.flags=8,t.firstEffect=t.lastEffect=e),t.child=n}function Ja(e,t,n,r,i){var o=t.mode,a=e.child;e=a.sibling;var s={mode:"hidden",children:n};return 0==(2&o)&&t.child!==a?((n=t.child).childLanes=0,n.pendingProps=s,null!==(a=n.lastEffect)?(t.firstEffect=n.firstEffect,t.lastEffect=a,a.nextEffect=null):t.firstEffect=t.lastEffect=null):n=Bl(a,s),null!==e?r=Bl(e,r):(r=Fl(r,o,i,null)).flags|=2,r.return=t,n.return=t,n.sibling=r,t.child=n,r}function Qa(e,t){e.lanes|=t;var n=e.alternate;null!==n&&(n.lanes|=t),$i(e.return,t)}function Za(e,t,n,r,i,o){var a=e.memoizedState;null===a?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:r,tail:n,tailMode:i,lastEffect:o}:(a.isBackwards=t,a.rendering=null,a.renderingStartTime=0,a.last=r,a.tail=n,a.tailMode=i,a.lastEffect=o)}function $a(e,t,n){var r=t.pendingProps,i=r.revealOrder,o=r.tail;if(Da(e,t,r.children,n),0!=(2&(r=Do.current)))r=1&r|2,t.flags|=64;else{if(null!==e&&0!=(64&e.flags))e:for(e=t.child;null!==e;){if(13===e.tag)null!==e.memoizedState&&Qa(e,n);else if(19===e.tag)Qa(e,n);else if(null!==e.child){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;null===e.sibling;){if(null===e.return||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}r&=1}if(ai(Do,r),0==(2&t.mode))t.memoizedState=null;else switch(i){case"forwards":for(n=t.child,i=null;null!==n;)null!==(e=n.alternate)&&null===No(e)&&(i=n),n=n.sibling;null===(n=i)?(i=t.child,t.child=null):(i=n.sibling,n.sibling=null),Za(t,!1,i,n,o,t.lastEffect);break;case"backwards":for(n=null,i=t.child,t.child=null;null!==i;){if(null!==(e=i.alternate)&&null===No(e)){t.child=i;break}e=i.sibling,i.sibling=n,n=i,i=e}Za(t,!0,n,null,o,t.lastEffect);break;case"together":Za(t,!1,null,null,void 0,t.lastEffect);break;default:t.memoizedState=null}return t.child}function es(e,t,n){if(null!==e&&(t.dependencies=e.dependencies),Ns|=t.lanes,0!=(n&t.childLanes)){if(null!==e&&t.child!==e.child)throw Error(a(153));if(null!==t.child){for(n=Bl(e=t.child,e.pendingProps),t.child=n,n.return=t;null!==e.sibling;)e=e.sibling,(n=n.sibling=Bl(e,e.pendingProps)).return=t;n.sibling=null}return t.child}return null}function ts(e,t){if(!zo)switch(e.tailMode){case"hidden":t=e.tail;for(var n=null;null!==t;)null!==t.alternate&&(n=t),t=t.sibling;null===n?e.tail=null:n.sibling=null;break;case"collapsed":n=e.tail;for(var r=null;null!==n;)null!==n.alternate&&(r=n),n=n.sibling;null===r?t||null===e.tail?e.tail=null:e.tail.sibling=null:r.sibling=null}}function ns(e,t,n){var r=t.pendingProps;switch(t.tag){case 2:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return null;case 1:return hi(t.type)&&pi(),null;case 3:return Oo(),oi(ci),oi(li),Wo(),(r=t.stateNode).pendingContext&&(r.context=r.pendingContext,r.pendingContext=null),null!==e&&null!==e.child||(Yo(t)?t.flags|=4:r.hydrate||(t.flags|=256)),null;case 5:ko(t);var o=So(Lo.current);if(n=t.type,null!==e&&null!=t.stateNode)Ua(e,t,n,r),e.ref!==t.ref&&(t.flags|=128);else{if(!r){if(null===t.stateNode)throw Error(a(166));return null}if(e=So(xo.current),Yo(t)){r=t.stateNode,n=t.type;var s=t.memoizedProps;switch(r[qr]=t,r[Kr]=s,n){case"dialog":xr("cancel",r),xr("close",r);break;case"iframe":case"object":case"embed":xr("load",r);break;case"video":case"audio":for(e=0;e<Mr.length;e++)xr(Mr[e],r);break;case"source":xr("error",r);break;case"img":case"image":case"link":xr("error",r),xr("load",r);break;case"details":xr("toggle",r);break;case"input":ee(r,s),xr("invalid",r);break;case"select":r._wrapperState={wasMultiple:!!s.multiple},xr("invalid",r);break;case"textarea":le(r,s),xr("invalid",r)}for(var c in Ae(n,s),e=null,s)s.hasOwnProperty(c)&&(o=s[c],"children"===c?"string"==typeof o?r.textContent!==o&&(e=["children",o]):"number"==typeof o&&r.textContent!==""+o&&(e=["children",""+o]):l.hasOwnProperty(c)&&null!=o&&"onScroll"===c&&xr("scroll",r));switch(n){case"input":J(r),re(r,s,!0);break;case"textarea":J(r),ue(r);break;case"select":case"option":break;default:"function"==typeof s.onClick&&(r.onclick=jr)}r=e,t.updateQueue=r,null!==r&&(t.flags|=4)}else{switch(c=9===o.nodeType?o:o.ownerDocument,e===de&&(e=pe(n)),e===de?"script"===n?((e=c.createElement("div")).innerHTML="<script><\/script>",e=e.removeChild(e.firstChild)):"string"==typeof r.is?e=c.createElement(n,{is:r.is}):(e=c.createElement(n),"select"===n&&(c=e,r.multiple?c.multiple=!0:r.size&&(c.size=r.size))):e=c.createElementNS(e,n),e[qr]=t,e[Kr]=r,Va(e,t),t.stateNode=e,c=Ce(n,r),n){case"dialog":xr("cancel",e),xr("close",e),o=r;break;case"iframe":case"object":case"embed":xr("load",e),o=r;break;case"video":case"audio":for(o=0;o<Mr.length;o++)xr(Mr[o],e);o=r;break;case"source":xr("error",e),o=r;break;case"img":case"image":case"link":xr("error",e),xr("load",e),o=r;break;case"details":xr("toggle",e),o=r;break;case"input":ee(e,r),o=$(e,r),xr("invalid",e);break;case"option":o=oe(e,r);break;case"select":e._wrapperState={wasMultiple:!!r.multiple},o=i({},r,{value:void 0}),xr("invalid",e);break;case"textarea":le(e,r),o=se(e,r),xr("invalid",e);break;default:o=r}Ae(n,o);var u=o;for(s in u)if(u.hasOwnProperty(s)){var d=u[s];"style"===s?Me(e,d):"dangerouslySetInnerHTML"===s?null!=(d=d?d.__html:void 0)&&ge(e,d):"children"===s?"string"==typeof d?("textarea"!==n||""!==d)&&ve(e,d):"number"==typeof d&&ve(e,""+d):"suppressContentEditableWarning"!==s&&"suppressHydrationWarning"!==s&&"autoFocus"!==s&&(l.hasOwnProperty(s)?null!=d&&"onScroll"===s&&xr("scroll",e):null!=d&&b(e,s,d,c))}switch(n){case"input":J(e),re(e,r,!1);break;case"textarea":J(e),ue(e);break;case"option":null!=r.value&&e.setAttribute("value",""+K(r.value));break;case"select":e.multiple=!!r.multiple,null!=(s=r.value)?ae(e,!!r.multiple,s,!1):null!=r.defaultValue&&ae(e,!!r.multiple,r.defaultValue,!0);break;default:"function"==typeof o.onClick&&(e.onclick=jr)}Rr(n,r)&&(t.flags|=4)}null!==t.ref&&(t.flags|=128)}return null;case 6:if(e&&null!=t.stateNode)Wa(0,t,e.memoizedProps,r);else{if("string"!=typeof r&&null===t.stateNode)throw Error(a(166));n=So(Lo.current),So(xo.current),Yo(t)?(r=t.stateNode,n=t.memoizedProps,r[qr]=t,r.nodeValue!==n&&(t.flags|=4)):((r=(9===n.nodeType?n:n.ownerDocument).createTextNode(r))[qr]=t,t.stateNode=r)}return null;case 13:return oi(Do),r=t.memoizedState,0!=(64&t.flags)?(t.lanes=n,t):(r=null!==r,n=!1,null===e?void 0!==t.memoizedProps.fallback&&Yo(t):n=null!==e.memoizedState,r&&!n&&0!=(2&t.mode)&&(null===e&&!0!==t.memoizedProps.unstable_avoidThisFallback||0!=(1&Do.current)?0===Is&&(Is=3):(0!==Is&&3!==Is||(Is=4),null===Es||0==(134217727&Ns)&&0==(134217727&js)||dl(Es,Ss))),(r||n)&&(t.flags|=4),null);case 4:return Oo(),null===e&&Lr(t.stateNode.containerInfo),null;case 10:return Zi(t),null;case 17:return hi(t.type)&&pi(),null;case 19:if(oi(Do),null===(r=t.memoizedState))return null;if(s=0!=(64&t.flags),null===(c=r.rendering))if(s)ts(r,!1);else{if(0!==Is||null!==e&&0!=(64&e.flags))for(e=t.child;null!==e;){if(null!==(c=No(e))){for(t.flags|=64,ts(r,!1),null!==(s=c.updateQueue)&&(t.updateQueue=s,t.flags|=4),null===r.lastEffect&&(t.firstEffect=null),t.lastEffect=r.lastEffect,r=n,n=t.child;null!==n;)e=r,(s=n).flags&=2,s.nextEffect=null,s.firstEffect=null,s.lastEffect=null,null===(c=s.alternate)?(s.childLanes=0,s.lanes=e,s.child=null,s.memoizedProps=null,s.memoizedState=null,s.updateQueue=null,s.dependencies=null,s.stateNode=null):(s.childLanes=c.childLanes,s.lanes=c.lanes,s.child=c.child,s.memoizedProps=c.memoizedProps,s.memoizedState=c.memoizedState,s.updateQueue=c.updateQueue,s.type=c.type,e=c.dependencies,s.dependencies=null===e?null:{lanes:e.lanes,firstContext:e.firstContext}),n=n.sibling;return ai(Do,1&Do.current|2),t.child}e=e.sibling}null!==r.tail&&Ri()>Bs&&(t.flags|=64,s=!0,ts(r,!1),t.lanes=33554432)}else{if(!s)if(null!==(e=No(c))){if(t.flags|=64,s=!0,null!==(n=e.updateQueue)&&(t.updateQueue=n,t.flags|=4),ts(r,!0),null===r.tail&&"hidden"===r.tailMode&&!c.alternate&&!zo)return null!==(t=t.lastEffect=r.lastEffect)&&(t.nextEffect=null),null}else 2*Ri()-r.renderingStartTime>Bs&&1073741824!==n&&(t.flags|=64,s=!0,ts(r,!1),t.lanes=33554432);r.isBackwards?(c.sibling=t.child,t.child=c):(null!==(n=r.last)?n.sibling=c:t.child=c,r.last=c)}return null!==r.tail?(n=r.tail,r.rendering=n,r.tail=n.sibling,r.lastEffect=t.lastEffect,r.renderingStartTime=Ri(),n.sibling=null,t=Do.current,ai(Do,s?1&t|2:1&t),n):null;case 23:case 24:return gl(),null!==e&&null!==e.memoizedState!=(null!==t.memoizedState)&&"unstable-defer-without-hiding"!==r.mode&&(t.flags|=4),null}throw Error(a(156,t.tag))}function rs(e){switch(e.tag){case 1:hi(e.type)&&pi();var t=e.flags;return 4096&t?(e.flags=-4097&t|64,e):null;case 3:if(Oo(),oi(ci),oi(li),Wo(),0!=(64&(t=e.flags)))throw Error(a(285));return e.flags=-4097&t|64,e;case 5:return ko(e),null;case 13:return oi(Do),4096&(t=e.flags)?(e.flags=-4097&t|64,e):null;case 19:return oi(Do),null;case 4:return Oo(),null;case 10:return Zi(e),null;case 23:case 24:return gl(),null;default:return null}}function is(e,t){try{var n="",r=t;do{n+=G(r),r=r.return}while(r);var i=n}catch(e){i="\nError generating stack: "+e.message+"\n"+e.stack}return{value:e,source:t,stack:i}}function os(e,t){try{console.error(t.value)}catch(e){setTimeout((function(){throw e}))}}Va=function(e,t){for(var n=t.child;null!==n;){if(5===n.tag||6===n.tag)e.appendChild(n.stateNode);else if(4!==n.tag&&null!==n.child){n.child.return=n,n=n.child;continue}if(n===t)break;for(;null===n.sibling;){if(null===n.return||n.return===t)return;n=n.return}n.sibling.return=n.return,n=n.sibling}},Ua=function(e,t,n,r){var o=e.memoizedProps;if(o!==r){e=t.stateNode,So(xo.current);var a,s=null;switch(n){case"input":o=$(e,o),r=$(e,r),s=[];break;case"option":o=oe(e,o),r=oe(e,r),s=[];break;case"select":o=i({},o,{value:void 0}),r=i({},r,{value:void 0}),s=[];break;case"textarea":o=se(e,o),r=se(e,r),s=[];break;default:"function"!=typeof o.onClick&&"function"==typeof r.onClick&&(e.onclick=jr)}for(d in Ae(n,r),n=null,o)if(!r.hasOwnProperty(d)&&o.hasOwnProperty(d)&&null!=o[d])if("style"===d){var c=o[d];for(a in c)c.hasOwnProperty(a)&&(n||(n={}),n[a]="")}else"dangerouslySetInnerHTML"!==d&&"children"!==d&&"suppressContentEditableWarning"!==d&&"suppressHydrationWarning"!==d&&"autoFocus"!==d&&(l.hasOwnProperty(d)?s||(s=[]):(s=s||[]).push(d,null));for(d in r){var u=r[d];if(c=null!=o?o[d]:void 0,r.hasOwnProperty(d)&&u!==c&&(null!=u||null!=c))if("style"===d)if(c){for(a in c)!c.hasOwnProperty(a)||u&&u.hasOwnProperty(a)||(n||(n={}),n[a]="");for(a in u)u.hasOwnProperty(a)&&c[a]!==u[a]&&(n||(n={}),n[a]=u[a])}else n||(s||(s=[]),s.push(d,n)),n=u;else"dangerouslySetInnerHTML"===d?(u=u?u.__html:void 0,c=c?c.__html:void 0,null!=u&&c!==u&&(s=s||[]).push(d,u)):"children"===d?"string"!=typeof u&&"number"!=typeof u||(s=s||[]).push(d,""+u):"suppressContentEditableWarning"!==d&&"suppressHydrationWarning"!==d&&(l.hasOwnProperty(d)?(null!=u&&"onScroll"===d&&xr("scroll",e),s||c===u||(s=[])):"object"==typeof u&&null!==u&&u.$$typeof===j?u.toString():(s=s||[]).push(d,u))}n&&(s=s||[]).push("style",n);var d=s;(t.updateQueue=d)&&(t.flags|=4)}},Wa=function(e,t,n,r){n!==r&&(t.flags|=4)};var as="function"==typeof WeakMap?WeakMap:Map;function ss(e,t,n){(n=oo(-1,n)).tag=3,n.payload={element:null};var r=t.value;return n.callback=function(){Vs||(Vs=!0,Us=r),os(0,t)},n}function ls(e,t,n){(n=oo(-1,n)).tag=3;var r=e.type.getDerivedStateFromError;if("function"==typeof r){var i=t.value;n.payload=function(){return os(0,t),r(i)}}var o=e.stateNode;return null!==o&&"function"==typeof o.componentDidCatch&&(n.callback=function(){"function"!=typeof r&&(null===Ws?Ws=new Set([this]):Ws.add(this),os(0,t));var e=t.stack;this.componentDidCatch(t.value,{componentStack:null!==e?e:""})}),n}var cs="function"==typeof WeakSet?WeakSet:Set;function us(e){var t=e.ref;if(null!==t)if("function"==typeof t)try{t(null)}catch(t){Dl(e,t)}else t.current=null}function ds(e,t){switch(t.tag){case 0:case 11:case 15:case 22:return;case 1:if(256&t.flags&&null!==e){var n=e.memoizedProps,r=e.memoizedState;t=(e=t.stateNode).getSnapshotBeforeUpdate(t.elementType===t.type?n:Gi(t.type,n),r),e.__reactInternalSnapshotBeforeUpdate=t}return;case 3:return void(256&t.flags&&Yr(t.stateNode.containerInfo));case 5:case 6:case 4:case 17:return}throw Error(a(163))}function hs(e,t,n){switch(n.tag){case 0:case 11:case 15:case 22:if(null!==(t=null!==(t=n.updateQueue)?t.lastEffect:null)){e=t=t.next;do{if(3==(3&e.tag)){var r=e.create;e.destroy=r()}e=e.next}while(e!==t)}if(null!==(t=null!==(t=n.updateQueue)?t.lastEffect:null)){e=t=t.next;do{var i=e;r=i.next,0!=(4&(i=i.tag))&&0!=(1&i)&&(Ol(n,e),Tl(n,e)),e=r}while(e!==t)}return;case 1:return e=n.stateNode,4&n.flags&&(null===t?e.componentDidMount():(r=n.elementType===n.type?t.memoizedProps:Gi(n.type,t.memoizedProps),e.componentDidUpdate(r,t.memoizedState,e.__reactInternalSnapshotBeforeUpdate))),void(null!==(t=n.updateQueue)&&co(n,t,e));case 3:if(null!==(t=n.updateQueue)){if(e=null,null!==n.child)switch(n.child.tag){case 5:e=n.child.stateNode;break;case 1:e=n.child.stateNode}co(n,t,e)}return;case 5:return e=n.stateNode,void(null===t&&4&n.flags&&Rr(n.type,n.memoizedProps)&&e.focus());case 6:case 4:case 12:return;case 13:return void(null===n.memoizedState&&(n=n.alternate,null!==n&&(n=n.memoizedState,null!==n&&(n=n.dehydrated,null!==n&&Mt(n)))));case 19:case 17:case 20:case 21:case 23:case 24:return}throw Error(a(163))}function ps(e,t){for(var n=e;;){if(5===n.tag){var r=n.stateNode;if(t)"function"==typeof(r=r.style).setProperty?r.setProperty("display","none","important"):r.display="none";else{r=n.stateNode;var i=n.memoizedProps.style;i=null!=i&&i.hasOwnProperty("display")?i.display:null,r.style.display=be("display",i)}}else if(6===n.tag)n.stateNode.nodeValue=t?"":n.memoizedProps;else if((23!==n.tag&&24!==n.tag||null===n.memoizedState||n===e)&&null!==n.child){n.child.return=n,n=n.child;continue}if(n===e)break;for(;null===n.sibling;){if(null===n.return||n.return===e)return;n=n.return}n.sibling.return=n.return,n=n.sibling}}function fs(e,t){if(_i&&"function"==typeof _i.onCommitFiberUnmount)try{_i.onCommitFiberUnmount(yi,t)}catch(e){}switch(t.tag){case 0:case 11:case 14:case 15:case 22:if(null!==(e=t.updateQueue)&&null!==(e=e.lastEffect)){var n=e=e.next;do{var r=n,i=r.destroy;if(r=r.tag,void 0!==i)if(0!=(4&r))Ol(t,n);else{r=t;try{i()}catch(e){Dl(r,e)}}n=n.next}while(n!==e)}break;case 1:if(us(t),"function"==typeof(e=t.stateNode).componentWillUnmount)try{e.props=t.memoizedProps,e.state=t.memoizedState,e.componentWillUnmount()}catch(e){Dl(t,e)}break;case 5:us(t);break;case 4:ys(e,t)}}function ms(e){e.alternate=null,e.child=null,e.dependencies=null,e.firstEffect=null,e.lastEffect=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.return=null,e.updateQueue=null}function gs(e){return 5===e.tag||3===e.tag||4===e.tag}function vs(e){e:{for(var t=e.return;null!==t;){if(gs(t))break e;t=t.return}throw Error(a(160))}var n=t;switch(t=n.stateNode,n.tag){case 5:var r=!1;break;case 3:case 4:t=t.containerInfo,r=!0;break;default:throw Error(a(161))}16&n.flags&&(ve(t,""),n.flags&=-17);e:t:for(n=e;;){for(;null===n.sibling;){if(null===n.return||gs(n.return)){n=null;break e}n=n.return}for(n.sibling.return=n.return,n=n.sibling;5!==n.tag&&6!==n.tag&&18!==n.tag;){if(2&n.flags)continue t;if(null===n.child||4===n.tag)continue t;n.child.return=n,n=n.child}if(!(2&n.flags)){n=n.stateNode;break e}}r?function e(t,n,r){var i=t.tag,o=5===i||6===i;if(o)t=o?t.stateNode:t.stateNode.instance,n?8===r.nodeType?r.parentNode.insertBefore(t,n):r.insertBefore(t,n):(8===r.nodeType?(n=r.parentNode).insertBefore(t,r):(n=r).appendChild(t),null!==(r=r._reactRootContainer)&&void 0!==r||null!==n.onclick||(n.onclick=jr));else if(4!==i&&null!==(t=t.child))for(e(t,n,r),t=t.sibling;null!==t;)e(t,n,r),t=t.sibling}(e,n,t):function e(t,n,r){var i=t.tag,o=5===i||6===i;if(o)t=o?t.stateNode:t.stateNode.instance,n?r.insertBefore(t,n):r.appendChild(t);else if(4!==i&&null!==(t=t.child))for(e(t,n,r),t=t.sibling;null!==t;)e(t,n,r),t=t.sibling}(e,n,t)}function ys(e,t){for(var n,r,i=t,o=!1;;){if(!o){o=i.return;e:for(;;){if(null===o)throw Error(a(160));switch(n=o.stateNode,o.tag){case 5:r=!1;break e;case 3:case 4:n=n.containerInfo,r=!0;break e}o=o.return}o=!0}if(5===i.tag||6===i.tag){e:for(var s=e,l=i,c=l;;)if(fs(s,c),null!==c.child&&4!==c.tag)c.child.return=c,c=c.child;else{if(c===l)break e;for(;null===c.sibling;){if(null===c.return||c.return===l)break e;c=c.return}c.sibling.return=c.return,c=c.sibling}r?(s=n,l=i.stateNode,8===s.nodeType?s.parentNode.removeChild(l):s.removeChild(l)):n.removeChild(i.stateNode)}else if(4===i.tag){if(null!==i.child){n=i.stateNode.containerInfo,r=!0,i.child.return=i,i=i.child;continue}}else if(fs(e,i),null!==i.child){i.child.return=i,i=i.child;continue}if(i===t)break;for(;null===i.sibling;){if(null===i.return||i.return===t)return;4===(i=i.return).tag&&(o=!1)}i.sibling.return=i.return,i=i.sibling}}function _s(e,t){switch(t.tag){case 0:case 11:case 14:case 15:case 22:var n=t.updateQueue;if(null!==(n=null!==n?n.lastEffect:null)){var r=n=n.next;do{3==(3&r.tag)&&(e=r.destroy,r.destroy=void 0,void 0!==e&&e()),r=r.next}while(r!==n)}return;case 1:return;case 5:if(null!=(n=t.stateNode)){r=t.memoizedProps;var i=null!==e?e.memoizedProps:r;e=t.type;var o=t.updateQueue;if(t.updateQueue=null,null!==o){for(n[Kr]=r,"input"===e&&"radio"===r.type&&null!=r.name&&te(n,r),Ce(e,i),t=Ce(e,r),i=0;i<o.length;i+=2){var s=o[i],l=o[i+1];"style"===s?Me(n,l):"dangerouslySetInnerHTML"===s?ge(n,l):"children"===s?ve(n,l):b(n,s,l,t)}switch(e){case"input":ne(n,r);break;case"textarea":ce(n,r);break;case"select":e=n._wrapperState.wasMultiple,n._wrapperState.wasMultiple=!!r.multiple,null!=(o=r.value)?ae(n,!!r.multiple,o,!1):e!==!!r.multiple&&(null!=r.defaultValue?ae(n,!!r.multiple,r.defaultValue,!0):ae(n,!!r.multiple,r.multiple?[]:"",!1))}}}return;case 6:if(null===t.stateNode)throw Error(a(162));return void(t.stateNode.nodeValue=t.memoizedProps);case 3:return void((n=t.stateNode).hydrate&&(n.hydrate=!1,Mt(n.containerInfo)));case 12:return;case 13:return null!==t.memoizedState&&(Rs=Ri(),ps(t.child,!0)),void bs(t);case 19:return void bs(t);case 17:return;case 23:case 24:return void ps(t,null!==t.memoizedState)}throw Error(a(163))}function bs(e){var t=e.updateQueue;if(null!==t){e.updateQueue=null;var n=e.stateNode;null===n&&(n=e.stateNode=new cs),t.forEach((function(t){var r=jl.bind(null,e,t);n.has(t)||(n.add(t),t.then(r,r))}))}}function Ms(e,t){return null!==e&&(null===(e=e.memoizedState)||null!==e.dehydrated)&&(null!==(t=t.memoizedState)&&null===t.dehydrated)}var ws=Math.ceil,As=M.ReactCurrentDispatcher,Cs=M.ReactCurrentOwner,xs=0,Es=null,Ls=null,Ss=0,Ts=0,Os=ii(0),Is=0,ks=null,Ds=0,Ns=0,js=0,Ps=0,zs=null,Rs=0,Bs=1/0;function Hs(){Bs=Ri()+500}var Fs,Ys=null,Vs=!1,Us=null,Ws=null,Gs=!1,qs=null,Ks=90,Xs=[],Js=[],Qs=null,Zs=0,$s=null,el=-1,tl=0,nl=0,rl=null,il=!1;function ol(){return 0!=(48&xs)?Ri():-1!==el?el:el=Ri()}function al(e){if(0==(2&(e=e.mode)))return 1;if(0==(4&e))return 99===Bi()?1:2;if(0===tl&&(tl=Ds),0!==Wi.transition){0!==nl&&(nl=null!==zs?zs.pendingLanes:0),e=tl;var t=4186112&~nl;return 0===(t&=-t)&&(0===(t=(e=4186112&~e)&-e)&&(t=8192)),t}return e=Bi(),0!=(4&xs)&&98===e?e=Bt(12,tl):e=Bt(e=function(e){switch(e){case 99:return 15;case 98:return 10;case 97:case 96:return 8;case 95:return 2;default:return 0}}(e),tl),e}function sl(e,t,n){if(50<Zs)throw Zs=0,$s=null,Error(a(185));if(null===(e=ll(e,t)))return null;Yt(e,t,n),e===Es&&(js|=t,4===Is&&dl(e,Ss));var r=Bi();1===t?0!=(8&xs)&&0==(48&xs)?hl(e):(cl(e,n),0===xs&&(Hs(),Vi())):(0==(4&xs)||98!==r&&99!==r||(null===Qs?Qs=new Set([e]):Qs.add(e)),cl(e,n)),zs=e}function ll(e,t){e.lanes|=t;var n=e.alternate;for(null!==n&&(n.lanes|=t),n=e,e=e.return;null!==e;)e.childLanes|=t,null!==(n=e.alternate)&&(n.childLanes|=t),n=e,e=e.return;return 3===n.tag?n.stateNode:null}function cl(e,t){for(var n=e.callbackNode,r=e.suspendedLanes,i=e.pingedLanes,o=e.expirationTimes,s=e.pendingLanes;0<s;){var l=31-Vt(s),c=1<<l,u=o[l];if(-1===u){if(0==(c&r)||0!=(c&i)){u=t,Pt(c);var d=jt;o[l]=10<=d?u+250:6<=d?u+5e3:-1}}else u<=t&&(e.expiredLanes|=c);s&=~c}if(r=zt(e,e===Es?Ss:0),t=jt,0===r)null!==n&&(n!==ki&&wi(n),e.callbackNode=null,e.callbackPriority=0);else{if(null!==n){if(e.callbackPriority===t)return;n!==ki&&wi(n)}15===t?(n=hl.bind(null,e),null===Ni?(Ni=[n],ji=Mi(Li,Ui)):Ni.push(n),n=ki):14===t?n=Yi(99,hl.bind(null,e)):n=Yi(n=function(e){switch(e){case 15:case 14:return 99;case 13:case 12:case 11:case 10:return 98;case 9:case 8:case 7:case 6:case 4:case 5:return 97;case 3:case 2:case 1:return 95;case 0:return 90;default:throw Error(a(358,e))}}(t),ul.bind(null,e)),e.callbackPriority=t,e.callbackNode=n}}function ul(e){if(el=-1,nl=tl=0,0!=(48&xs))throw Error(a(327));var t=e.callbackNode;if(Sl()&&e.callbackNode!==t)return null;var n=zt(e,e===Es?Ss:0);if(0===n)return null;var r=n,i=xs;xs|=16;var o=_l();for(Es===e&&Ss===r||(Hs(),vl(e,r));;)try{wl();break}catch(t){yl(e,t)}if(Qi(),As.current=o,xs=i,null!==Ls?r=0:(Es=null,Ss=0,r=Is),0!=(Ds&js))vl(e,0);else if(0!==r){if(2===r&&(xs|=64,e.hydrate&&(e.hydrate=!1,Yr(e.containerInfo)),0!==(n=Rt(e))&&(r=bl(e,n))),1===r)throw t=ks,vl(e,0),dl(e,n),cl(e,Ri()),t;switch(e.finishedWork=e.current.alternate,e.finishedLanes=n,r){case 0:case 1:throw Error(a(345));case 2:xl(e);break;case 3:if(dl(e,n),(62914560&n)===n&&10<(r=Rs+500-Ri())){if(0!==zt(e,0))break;if(((i=e.suspendedLanes)&n)!==n){ol(),e.pingedLanes|=e.suspendedLanes&i;break}e.timeoutHandle=Hr(xl.bind(null,e),r);break}xl(e);break;case 4:if(dl(e,n),(4186112&n)===n)break;for(r=e.eventTimes,i=-1;0<n;){var s=31-Vt(n);o=1<<s,(s=r[s])>i&&(i=s),n&=~o}if(n=i,10<(n=(120>(n=Ri()-n)?120:480>n?480:1080>n?1080:1920>n?1920:3e3>n?3e3:4320>n?4320:1960*ws(n/1960))-n)){e.timeoutHandle=Hr(xl.bind(null,e),n);break}xl(e);break;case 5:xl(e);break;default:throw Error(a(329))}}return cl(e,Ri()),e.callbackNode===t?ul.bind(null,e):null}function dl(e,t){for(t&=~Ps,t&=~js,e.suspendedLanes|=t,e.pingedLanes&=~t,e=e.expirationTimes;0<t;){var n=31-Vt(t),r=1<<n;e[n]=-1,t&=~r}}function hl(e){if(0!=(48&xs))throw Error(a(327));if(Sl(),e===Es&&0!=(e.expiredLanes&Ss)){var t=Ss,n=bl(e,t);0!=(Ds&js)&&(n=bl(e,t=zt(e,t)))}else n=bl(e,t=zt(e,0));if(0!==e.tag&&2===n&&(xs|=64,e.hydrate&&(e.hydrate=!1,Yr(e.containerInfo)),0!==(t=Rt(e))&&(n=bl(e,t))),1===n)throw n=ks,vl(e,0),dl(e,t),cl(e,Ri()),n;return e.finishedWork=e.current.alternate,e.finishedLanes=t,xl(e),cl(e,Ri()),null}function pl(e,t){var n=xs;xs|=1;try{return e(t)}finally{0===(xs=n)&&(Hs(),Vi())}}function fl(e,t){var n=xs;xs&=-2,xs|=8;try{return e(t)}finally{0===(xs=n)&&(Hs(),Vi())}}function ml(e,t){ai(Os,Ts),Ts|=t,Ds|=t}function gl(){Ts=Os.current,oi(Os)}function vl(e,t){e.finishedWork=null,e.finishedLanes=0;var n=e.timeoutHandle;if(-1!==n&&(e.timeoutHandle=-1,Fr(n)),null!==Ls)for(n=Ls.return;null!==n;){var r=n;switch(r.tag){case 1:null!=(r=r.type.childContextTypes)&&pi();break;case 3:Oo(),oi(ci),oi(li),Wo();break;case 5:ko(r);break;case 4:Oo();break;case 13:case 19:oi(Do);break;case 10:Zi(r);break;case 23:case 24:gl()}n=n.return}Es=e,Ls=Bl(e.current,null),Ss=Ts=Ds=t,Is=0,ks=null,Ps=js=Ns=0}function yl(e,t){for(;;){var n=Ls;try{if(Qi(),Go.current=La,Zo){for(var r=Xo.memoizedState;null!==r;){var i=r.queue;null!==i&&(i.pending=null),r=r.next}Zo=!1}if(Ko=0,Qo=Jo=Xo=null,$o=!1,Cs.current=null,null===n||null===n.return){Is=1,ks=t,Ls=null;break}e:{var o=e,a=n.return,s=n,l=t;if(t=Ss,s.flags|=2048,s.firstEffect=s.lastEffect=null,null!==l&&"object"==typeof l&&"function"==typeof l.then){var c=l;if(0==(2&s.mode)){var u=s.alternate;u?(s.updateQueue=u.updateQueue,s.memoizedState=u.memoizedState,s.lanes=u.lanes):(s.updateQueue=null,s.memoizedState=null)}var d=0!=(1&Do.current),h=a;do{var p;if(p=13===h.tag){var f=h.memoizedState;if(null!==f)p=null!==f.dehydrated;else{var m=h.memoizedProps;p=void 0!==m.fallback&&(!0!==m.unstable_avoidThisFallback||!d)}}if(p){var g=h.updateQueue;if(null===g){var v=new Set;v.add(c),h.updateQueue=v}else g.add(c);if(0==(2&h.mode)){if(h.flags|=64,s.flags|=16384,s.flags&=-2981,1===s.tag)if(null===s.alternate)s.tag=17;else{var y=oo(-1,1);y.tag=2,ao(s,y)}s.lanes|=1;break e}l=void 0,s=t;var _=o.pingCache;if(null===_?(_=o.pingCache=new as,l=new Set,_.set(c,l)):void 0===(l=_.get(c))&&(l=new Set,_.set(c,l)),!l.has(s)){l.add(s);var b=Nl.bind(null,o,c,s);c.then(b,b)}h.flags|=4096,h.lanes=t;break e}h=h.return}while(null!==h);l=Error((q(s.type)||"A React component")+" suspended while rendering, but no fallback UI was specified.\n\nAdd a <Suspense fallback=...> component higher in the tree to provide a loading indicator or placeholder to display.")}5!==Is&&(Is=2),l=is(l,s),h=a;do{switch(h.tag){case 3:o=l,h.flags|=4096,t&=-t,h.lanes|=t,so(h,ss(0,o,t));break e;case 1:o=l;var M=h.type,w=h.stateNode;if(0==(64&h.flags)&&("function"==typeof M.getDerivedStateFromError||null!==w&&"function"==typeof w.componentDidCatch&&(null===Ws||!Ws.has(w)))){h.flags|=4096,t&=-t,h.lanes|=t,so(h,ls(h,o,t));break e}}h=h.return}while(null!==h)}Cl(n)}catch(e){t=e,Ls===n&&null!==n&&(Ls=n=n.return);continue}break}}function _l(){var e=As.current;return As.current=La,null===e?La:e}function bl(e,t){var n=xs;xs|=16;var r=_l();for(Es===e&&Ss===t||vl(e,t);;)try{Ml();break}catch(t){yl(e,t)}if(Qi(),xs=n,As.current=r,null!==Ls)throw Error(a(261));return Es=null,Ss=0,Is}function Ml(){for(;null!==Ls;)Al(Ls)}function wl(){for(;null!==Ls&&!Ai();)Al(Ls)}function Al(e){var t=Fs(e.alternate,e,Ts);e.memoizedProps=e.pendingProps,null===t?Cl(e):Ls=t,Cs.current=null}function Cl(e){var t=e;do{var n=t.alternate;if(e=t.return,0==(2048&t.flags)){if(null!==(n=ns(n,t,Ts)))return void(Ls=n);if(24!==(n=t).tag&&23!==n.tag||null===n.memoizedState||0!=(1073741824&Ts)||0==(4&n.mode)){for(var r=0,i=n.child;null!==i;)r|=i.lanes|i.childLanes,i=i.sibling;n.childLanes=r}null!==e&&0==(2048&e.flags)&&(null===e.firstEffect&&(e.firstEffect=t.firstEffect),null!==t.lastEffect&&(null!==e.lastEffect&&(e.lastEffect.nextEffect=t.firstEffect),e.lastEffect=t.lastEffect),1<t.flags&&(null!==e.lastEffect?e.lastEffect.nextEffect=t:e.firstEffect=t,e.lastEffect=t))}else{if(null!==(n=rs(t)))return n.flags&=2047,void(Ls=n);null!==e&&(e.firstEffect=e.lastEffect=null,e.flags|=2048)}if(null!==(t=t.sibling))return void(Ls=t);Ls=t=e}while(null!==t);0===Is&&(Is=5)}function xl(e){var t=Bi();return Fi(99,El.bind(null,e,t)),null}function El(e,t){do{Sl()}while(null!==qs);if(0!=(48&xs))throw Error(a(327));var n=e.finishedWork;if(null===n)return null;if(e.finishedWork=null,e.finishedLanes=0,n===e.current)throw Error(a(177));e.callbackNode=null;var r=n.lanes|n.childLanes,i=r,o=e.pendingLanes&~i;e.pendingLanes=i,e.suspendedLanes=0,e.pingedLanes=0,e.expiredLanes&=i,e.mutableReadLanes&=i,e.entangledLanes&=i,i=e.entanglements;for(var s=e.eventTimes,l=e.expirationTimes;0<o;){var c=31-Vt(o),u=1<<c;i[c]=0,s[c]=-1,l[c]=-1,o&=~u}if(null!==Qs&&0==(24&r)&&Qs.has(e)&&Qs.delete(e),e===Es&&(Ls=Es=null,Ss=0),1<n.flags?null!==n.lastEffect?(n.lastEffect.nextEffect=n,r=n.firstEffect):r=n:r=n.firstEffect,null!==r){if(i=xs,xs|=32,Cs.current=null,Pr=Kt,hr(s=dr())){if("selectionStart"in s)l={start:s.selectionStart,end:s.selectionEnd};else e:if(l=(l=s.ownerDocument)&&l.defaultView||window,(u=l.getSelection&&l.getSelection())&&0!==u.rangeCount){l=u.anchorNode,o=u.anchorOffset,c=u.focusNode,u=u.focusOffset;try{l.nodeType,c.nodeType}catch(e){l=null;break e}var d=0,h=-1,p=-1,f=0,m=0,g=s,v=null;t:for(;;){for(var y;g!==l||0!==o&&3!==g.nodeType||(h=d+o),g!==c||0!==u&&3!==g.nodeType||(p=d+u),3===g.nodeType&&(d+=g.nodeValue.length),null!==(y=g.firstChild);)v=g,g=y;for(;;){if(g===s)break t;if(v===l&&++f===o&&(h=d),v===c&&++m===u&&(p=d),null!==(y=g.nextSibling))break;v=(g=v).parentNode}g=y}l=-1===h||-1===p?null:{start:h,end:p}}else l=null;l=l||{start:0,end:0}}else l=null;zr={focusedElem:s,selectionRange:l},Kt=!1,rl=null,il=!1,Ys=r;do{try{Ll()}catch(e){if(null===Ys)throw Error(a(330));Dl(Ys,e),Ys=Ys.nextEffect}}while(null!==Ys);rl=null,Ys=r;do{try{for(s=e;null!==Ys;){var _=Ys.flags;if(16&_&&ve(Ys.stateNode,""),128&_){var b=Ys.alternate;if(null!==b){var M=b.ref;null!==M&&("function"==typeof M?M(null):M.current=null)}}switch(1038&_){case 2:vs(Ys),Ys.flags&=-3;break;case 6:vs(Ys),Ys.flags&=-3,_s(Ys.alternate,Ys);break;case 1024:Ys.flags&=-1025;break;case 1028:Ys.flags&=-1025,_s(Ys.alternate,Ys);break;case 4:_s(Ys.alternate,Ys);break;case 8:ys(s,l=Ys);var w=l.alternate;ms(l),null!==w&&ms(w)}Ys=Ys.nextEffect}}catch(e){if(null===Ys)throw Error(a(330));Dl(Ys,e),Ys=Ys.nextEffect}}while(null!==Ys);if(M=zr,b=dr(),_=M.focusedElem,s=M.selectionRange,b!==_&&_&&_.ownerDocument&&function e(t,n){return!(!t||!n)&&(t===n||(!t||3!==t.nodeType)&&(n&&3===n.nodeType?e(t,n.parentNode):"contains"in t?t.contains(n):!!t.compareDocumentPosition&&!!(16&t.compareDocumentPosition(n))))}(_.ownerDocument.documentElement,_)){null!==s&&hr(_)&&(b=s.start,void 0===(M=s.end)&&(M=b),"selectionStart"in _?(_.selectionStart=b,_.selectionEnd=Math.min(M,_.value.length)):(M=(b=_.ownerDocument||document)&&b.defaultView||window).getSelection&&(M=M.getSelection(),l=_.textContent.length,w=Math.min(s.start,l),s=void 0===s.end?w:Math.min(s.end,l),!M.extend&&w>s&&(l=s,s=w,w=l),l=ur(_,w),o=ur(_,s),l&&o&&(1!==M.rangeCount||M.anchorNode!==l.node||M.anchorOffset!==l.offset||M.focusNode!==o.node||M.focusOffset!==o.offset)&&((b=b.createRange()).setStart(l.node,l.offset),M.removeAllRanges(),w>s?(M.addRange(b),M.extend(o.node,o.offset)):(b.setEnd(o.node,o.offset),M.addRange(b))))),b=[];for(M=_;M=M.parentNode;)1===M.nodeType&&b.push({element:M,left:M.scrollLeft,top:M.scrollTop});for("function"==typeof _.focus&&_.focus(),_=0;_<b.length;_++)(M=b[_]).element.scrollLeft=M.left,M.element.scrollTop=M.top}Kt=!!Pr,zr=Pr=null,e.current=n,Ys=r;do{try{for(_=e;null!==Ys;){var A=Ys.flags;if(36&A&&hs(_,Ys.alternate,Ys),128&A){b=void 0;var C=Ys.ref;if(null!==C){var x=Ys.stateNode;switch(Ys.tag){case 5:b=x;break;default:b=x}"function"==typeof C?C(b):C.current=b}}Ys=Ys.nextEffect}}catch(e){if(null===Ys)throw Error(a(330));Dl(Ys,e),Ys=Ys.nextEffect}}while(null!==Ys);Ys=null,Di(),xs=i}else e.current=n;if(Gs)Gs=!1,qs=e,Ks=t;else for(Ys=r;null!==Ys;)t=Ys.nextEffect,Ys.nextEffect=null,8&Ys.flags&&((A=Ys).sibling=null,A.stateNode=null),Ys=t;if(0===(r=e.pendingLanes)&&(Ws=null),1===r?e===$s?Zs++:(Zs=0,$s=e):Zs=0,n=n.stateNode,_i&&"function"==typeof _i.onCommitFiberRoot)try{_i.onCommitFiberRoot(yi,n,void 0,64==(64&n.current.flags))}catch(e){}if(cl(e,Ri()),Vs)throw Vs=!1,e=Us,Us=null,e;return 0!=(8&xs)||Vi(),null}function Ll(){for(;null!==Ys;){var e=Ys.alternate;il||null===rl||(0!=(8&Ys.flags)?$e(Ys,rl)&&(il=!0):13===Ys.tag&&Ms(e,Ys)&&$e(Ys,rl)&&(il=!0));var t=Ys.flags;0!=(256&t)&&ds(e,Ys),0==(512&t)||Gs||(Gs=!0,Yi(97,(function(){return Sl(),null}))),Ys=Ys.nextEffect}}function Sl(){if(90!==Ks){var e=97<Ks?97:Ks;return Ks=90,Fi(e,Il)}return!1}function Tl(e,t){Xs.push(t,e),Gs||(Gs=!0,Yi(97,(function(){return Sl(),null})))}function Ol(e,t){Js.push(t,e),Gs||(Gs=!0,Yi(97,(function(){return Sl(),null})))}function Il(){if(null===qs)return!1;var e=qs;if(qs=null,0!=(48&xs))throw Error(a(331));var t=xs;xs|=32;var n=Js;Js=[];for(var r=0;r<n.length;r+=2){var i=n[r],o=n[r+1],s=i.destroy;if(i.destroy=void 0,"function"==typeof s)try{s()}catch(e){if(null===o)throw Error(a(330));Dl(o,e)}}for(n=Xs,Xs=[],r=0;r<n.length;r+=2){i=n[r],o=n[r+1];try{var l=i.create;i.destroy=l()}catch(e){if(null===o)throw Error(a(330));Dl(o,e)}}for(l=e.current.firstEffect;null!==l;)e=l.nextEffect,l.nextEffect=null,8&l.flags&&(l.sibling=null,l.stateNode=null),l=e;return xs=t,Vi(),!0}function kl(e,t,n){ao(e,t=ss(0,t=is(n,t),1)),t=ol(),null!==(e=ll(e,1))&&(Yt(e,1,t),cl(e,t))}function Dl(e,t){if(3===e.tag)kl(e,e,t);else for(var n=e.return;null!==n;){if(3===n.tag){kl(n,e,t);break}if(1===n.tag){var r=n.stateNode;if("function"==typeof n.type.getDerivedStateFromError||"function"==typeof r.componentDidCatch&&(null===Ws||!Ws.has(r))){var i=ls(n,e=is(t,e),1);if(ao(n,i),i=ol(),null!==(n=ll(n,1)))Yt(n,1,i),cl(n,i);else if("function"==typeof r.componentDidCatch&&(null===Ws||!Ws.has(r)))try{r.componentDidCatch(t,e)}catch(e){}break}}n=n.return}}function Nl(e,t,n){var r=e.pingCache;null!==r&&r.delete(t),t=ol(),e.pingedLanes|=e.suspendedLanes&n,Es===e&&(Ss&n)===n&&(4===Is||3===Is&&(62914560&Ss)===Ss&&500>Ri()-Rs?vl(e,0):Ps|=n),cl(e,t)}function jl(e,t){var n=e.stateNode;null!==n&&n.delete(t),0===(t=0)&&(0==(2&(t=e.mode))?t=1:0==(4&t)?t=99===Bi()?1:2:(0===tl&&(tl=Ds),0===(t=Ht(62914560&~tl))&&(t=4194304))),n=ol(),null!==(e=ll(e,t))&&(Yt(e,t,n),cl(e,n))}function Pl(e,t,n,r){this.tag=e,this.key=n,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=r,this.flags=0,this.lastEffect=this.firstEffect=this.nextEffect=null,this.childLanes=this.lanes=0,this.alternate=null}function zl(e,t,n,r){return new Pl(e,t,n,r)}function Rl(e){return!(!(e=e.prototype)||!e.isReactComponent)}function Bl(e,t){var n=e.alternate;return null===n?((n=zl(e.tag,t,e.key,e.mode)).elementType=e.elementType,n.type=e.type,n.stateNode=e.stateNode,n.alternate=e,e.alternate=n):(n.pendingProps=t,n.type=e.type,n.flags=0,n.nextEffect=null,n.firstEffect=null,n.lastEffect=null),n.childLanes=e.childLanes,n.lanes=e.lanes,n.child=e.child,n.memoizedProps=e.memoizedProps,n.memoizedState=e.memoizedState,n.updateQueue=e.updateQueue,t=e.dependencies,n.dependencies=null===t?null:{lanes:t.lanes,firstContext:t.firstContext},n.sibling=e.sibling,n.index=e.index,n.ref=e.ref,n}function Hl(e,t,n,r,i,o){var s=2;if(r=e,"function"==typeof e)Rl(e)&&(s=1);else if("string"==typeof e)s=5;else e:switch(e){case C:return Fl(n.children,i,o,t);case P:s=8,i|=16;break;case x:s=8,i|=1;break;case E:return(e=zl(12,n,t,8|i)).elementType=E,e.type=E,e.lanes=o,e;case O:return(e=zl(13,n,t,i)).type=O,e.elementType=O,e.lanes=o,e;case I:return(e=zl(19,n,t,i)).elementType=I,e.lanes=o,e;case z:return Yl(n,i,o,t);case R:return(e=zl(24,n,t,i)).elementType=R,e.lanes=o,e;default:if("object"==typeof e&&null!==e)switch(e.$$typeof){case L:s=10;break e;case S:s=9;break e;case T:s=11;break e;case k:s=14;break e;case D:s=16,r=null;break e;case N:s=22;break e}throw Error(a(130,null==e?e:typeof e,""))}return(t=zl(s,n,t,i)).elementType=e,t.type=r,t.lanes=o,t}function Fl(e,t,n,r){return(e=zl(7,e,r,t)).lanes=n,e}function Yl(e,t,n,r){return(e=zl(23,e,r,t)).elementType=z,e.lanes=n,e}function Vl(e,t,n){return(e=zl(6,e,null,t)).lanes=n,e}function Ul(e,t,n){return(t=zl(4,null!==e.children?e.children:[],e.key,t)).lanes=n,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}function Wl(e,t,n){this.tag=t,this.containerInfo=e,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.pendingContext=this.context=null,this.hydrate=n,this.callbackNode=null,this.callbackPriority=0,this.eventTimes=Ft(0),this.expirationTimes=Ft(-1),this.entangledLanes=this.finishedLanes=this.mutableReadLanes=this.expiredLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ft(0),this.mutableSourceEagerHydrationData=null}function Gl(e,t,n){var r=3<arguments.length&&void 0!==arguments[3]?arguments[3]:null;return{$$typeof:A,key:null==r?null:""+r,children:e,containerInfo:t,implementation:n}}function ql(e,t,n,r){var i=t.current,o=ol(),s=al(i);e:if(n){t:{if(Xe(n=n._reactInternals)!==n||1!==n.tag)throw Error(a(170));var l=n;do{switch(l.tag){case 3:l=l.stateNode.context;break t;case 1:if(hi(l.type)){l=l.stateNode.__reactInternalMemoizedMergedChildContext;break t}}l=l.return}while(null!==l);throw Error(a(171))}if(1===n.tag){var c=n.type;if(hi(c)){n=mi(n,c,l);break e}}n=l}else n=si;return null===t.context?t.context=n:t.pendingContext=n,(t=oo(o,s)).payload={element:e},null!==(r=void 0===r?null:r)&&(t.callback=r),ao(i,t),sl(i,s,o),s}function Kl(e){if(!(e=e.current).child)return null;switch(e.child.tag){case 5:default:return e.child.stateNode}}function Xl(e,t){if(null!==(e=e.memoizedState)&&null!==e.dehydrated){var n=e.retryLane;e.retryLane=0!==n&&n<t?n:t}}function Jl(e,t){Xl(e,t),(e=e.alternate)&&Xl(e,t)}function Ql(e,t,n){var r=null!=n&&null!=n.hydrationOptions&&n.hydrationOptions.mutableSources||null;if(n=new Wl(e,t,null!=n&&!0===n.hydrate),t=zl(3,null,null,2===t?7:1===t?3:0),n.current=t,t.stateNode=n,ro(t),e[Xr]=n.current,Lr(8===e.nodeType?e.parentNode:e),r)for(e=0;e<r.length;e++){var i=(t=r[e])._getVersion;i=i(t._source),null==n.mutableSourceEagerHydrationData?n.mutableSourceEagerHydrationData=[t,i]:n.mutableSourceEagerHydrationData.push(t,i)}this._internalRoot=n}function Zl(e){return!(!e||1!==e.nodeType&&9!==e.nodeType&&11!==e.nodeType&&(8!==e.nodeType||" react-mount-point-unstable "!==e.nodeValue))}function $l(e,t,n,r,i){var o=n._reactRootContainer;if(o){var a=o._internalRoot;if("function"==typeof i){var s=i;i=function(){var e=Kl(a);s.call(e)}}ql(t,a,e,i)}else{if(o=n._reactRootContainer=function(e,t){if(t||(t=!(!(t=e?9===e.nodeType?e.documentElement:e.firstChild:null)||1!==t.nodeType||!t.hasAttribute("data-reactroot"))),!t)for(var n;n=e.lastChild;)e.removeChild(n);return new Ql(e,0,t?{hydrate:!0}:void 0)}(n,r),a=o._internalRoot,"function"==typeof i){var l=i;i=function(){var e=Kl(a);l.call(e)}}fl((function(){ql(t,a,e,i)}))}return Kl(a)}function ec(e,t){var n=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null;if(!Zl(t))throw Error(a(200));return Gl(e,t,null,n)}Fs=function(e,t,n){var r=t.lanes;if(null!==e)if(e.memoizedProps!==t.pendingProps||ci.current)ka=!0;else{if(0==(n&r)){switch(ka=!1,t.tag){case 3:Ya(t),Vo();break;case 5:Io(t);break;case 1:hi(t.type)&&gi(t);break;case 4:To(t,t.stateNode.containerInfo);break;case 10:r=t.memoizedProps.value;var i=t.type._context;ai(qi,i._currentValue),i._currentValue=r;break;case 13:if(null!==t.memoizedState)return 0!=(n&t.child.childLanes)?qa(e,t,n):(ai(Do,1&Do.current),null!==(t=es(e,t,n))?t.sibling:null);ai(Do,1&Do.current);break;case 19:if(r=0!=(n&t.childLanes),0!=(64&e.flags)){if(r)return $a(e,t,n);t.flags|=64}if(null!==(i=t.memoizedState)&&(i.rendering=null,i.tail=null,i.lastEffect=null),ai(Do,Do.current),r)break;return null;case 23:case 24:return t.lanes=0,za(e,t,n)}return es(e,t,n)}ka=0!=(16384&e.flags)}else ka=!1;switch(t.lanes=0,t.tag){case 2:if(r=t.type,null!==e&&(e.alternate=null,t.alternate=null,t.flags|=2),e=t.pendingProps,i=di(t,li.current),eo(t,n),i=na(null,t,r,e,i,n),t.flags|=1,"object"==typeof i&&null!==i&&"function"==typeof i.render&&void 0===i.$$typeof){if(t.tag=1,t.memoizedState=null,t.updateQueue=null,hi(r)){var o=!0;gi(t)}else o=!1;t.memoizedState=null!==i.state&&void 0!==i.state?i.state:null,ro(t);var s=r.getDerivedStateFromProps;"function"==typeof s&&ho(t,r,s,e),i.updater=po,t.stateNode=i,i._reactInternals=t,vo(t,r,e,n),t=Fa(null,t,r,!0,o,n)}else t.tag=0,Da(null,t,i,n),t=t.child;return t;case 16:i=t.elementType;e:{switch(null!==e&&(e.alternate=null,t.alternate=null,t.flags|=2),e=t.pendingProps,i=(o=i._init)(i._payload),t.type=i,o=t.tag=function(e){if("function"==typeof e)return Rl(e)?1:0;if(null!=e){if((e=e.$$typeof)===T)return 11;if(e===k)return 14}return 2}(i),e=Gi(i,e),o){case 0:t=Ba(null,t,i,e,n);break e;case 1:t=Ha(null,t,i,e,n);break e;case 11:t=Na(null,t,i,e,n);break e;case 14:t=ja(null,t,i,Gi(i.type,e),r,n);break e}throw Error(a(306,i,""))}return t;case 0:return r=t.type,i=t.pendingProps,Ba(e,t,r,i=t.elementType===r?i:Gi(r,i),n);case 1:return r=t.type,i=t.pendingProps,Ha(e,t,r,i=t.elementType===r?i:Gi(r,i),n);case 3:if(Ya(t),r=t.updateQueue,null===e||null===r)throw Error(a(282));if(r=t.pendingProps,i=null!==(i=t.memoizedState)?i.element:null,io(e,t),lo(t,r,null,n),(r=t.memoizedState.element)===i)Vo(),t=es(e,t,n);else{if((o=(i=t.stateNode).hydrate)&&(Po=Vr(t.stateNode.containerInfo.firstChild),jo=t,o=zo=!0),o){if(null!=(e=i.mutableSourceEagerHydrationData))for(i=0;i<e.length;i+=2)(o=e[i])._workInProgressVersionPrimary=e[i+1],Uo.push(o);for(n=Ao(t,null,r,n),t.child=n;n;)n.flags=-3&n.flags|1024,n=n.sibling}else Da(e,t,r,n),Vo();t=t.child}return t;case 5:return Io(t),null===e&&Ho(t),r=t.type,i=t.pendingProps,o=null!==e?e.memoizedProps:null,s=i.children,Br(r,i)?s=null:null!==o&&Br(r,o)&&(t.flags|=16),Ra(e,t),Da(e,t,s,n),t.child;case 6:return null===e&&Ho(t),null;case 13:return qa(e,t,n);case 4:return To(t,t.stateNode.containerInfo),r=t.pendingProps,null===e?t.child=wo(t,null,r,n):Da(e,t,r,n),t.child;case 11:return r=t.type,i=t.pendingProps,Na(e,t,r,i=t.elementType===r?i:Gi(r,i),n);case 7:return Da(e,t,t.pendingProps,n),t.child;case 8:case 12:return Da(e,t,t.pendingProps.children,n),t.child;case 10:e:{r=t.type._context,i=t.pendingProps,s=t.memoizedProps,o=i.value;var l=t.type._context;if(ai(qi,l._currentValue),l._currentValue=o,null!==s)if(l=s.value,0===(o=ar(l,o)?0:0|("function"==typeof r._calculateChangedBits?r._calculateChangedBits(l,o):1073741823))){if(s.children===i.children&&!ci.current){t=es(e,t,n);break e}}else for(null!==(l=t.child)&&(l.return=t);null!==l;){var c=l.dependencies;if(null!==c){s=l.child;for(var u=c.firstContext;null!==u;){if(u.context===r&&0!=(u.observedBits&o)){1===l.tag&&((u=oo(-1,n&-n)).tag=2,ao(l,u)),l.lanes|=n,null!==(u=l.alternate)&&(u.lanes|=n),$i(l.return,n),c.lanes|=n;break}u=u.next}}else s=10===l.tag&&l.type===t.type?null:l.child;if(null!==s)s.return=l;else for(s=l;null!==s;){if(s===t){s=null;break}if(null!==(l=s.sibling)){l.return=s.return,s=l;break}s=s.return}l=s}Da(e,t,i.children,n),t=t.child}return t;case 9:return i=t.type,r=(o=t.pendingProps).children,eo(t,n),r=r(i=to(i,o.unstable_observedBits)),t.flags|=1,Da(e,t,r,n),t.child;case 14:return o=Gi(i=t.type,t.pendingProps),ja(e,t,i,o=Gi(i.type,o),r,n);case 15:return Pa(e,t,t.type,t.pendingProps,r,n);case 17:return r=t.type,i=t.pendingProps,i=t.elementType===r?i:Gi(r,i),null!==e&&(e.alternate=null,t.alternate=null,t.flags|=2),t.tag=1,hi(r)?(e=!0,gi(t)):e=!1,eo(t,n),mo(t,r,i),vo(t,r,i,n),Fa(null,t,r,!0,e,n);case 19:return $a(e,t,n);case 23:case 24:return za(e,t,n)}throw Error(a(156,t.tag))},Ql.prototype.render=function(e){ql(e,this._internalRoot,null,null)},Ql.prototype.unmount=function(){var e=this._internalRoot,t=e.containerInfo;ql(null,e,null,(function(){t[Xr]=null}))},et=function(e){13===e.tag&&(sl(e,4,ol()),Jl(e,4))},tt=function(e){13===e.tag&&(sl(e,67108864,ol()),Jl(e,67108864))},nt=function(e){if(13===e.tag){var t=ol(),n=al(e);sl(e,n,t),Jl(e,n)}},rt=function(e,t){return t()},Ee=function(e,t,n){switch(t){case"input":if(ne(e,n),t=n.name,"radio"===n.type&&null!=t){for(n=e;n.parentNode;)n=n.parentNode;for(n=n.querySelectorAll("input[name="+JSON.stringify(""+t)+'][type="radio"]'),t=0;t<n.length;t++){var r=n[t];if(r!==e&&r.form===e.form){var i=ei(r);if(!i)throw Error(a(90));Q(r),ne(r,i)}}}break;case"textarea":ce(e,n);break;case"select":null!=(t=n.value)&&ae(e,!!n.multiple,t,!1)}},ke=pl,De=function(e,t,n,r,i){var o=xs;xs|=4;try{return Fi(98,e.bind(null,t,n,r,i))}finally{0===(xs=o)&&(Hs(),Vi())}},Ne=function(){0==(49&xs)&&(function(){if(null!==Qs){var e=Qs;Qs=null,e.forEach((function(e){e.expiredLanes|=24&e.pendingLanes,cl(e,Ri())}))}Vi()}(),Sl())},je=function(e,t){var n=xs;xs|=2;try{return e(t)}finally{0===(xs=n)&&(Hs(),Vi())}};var tc={Events:[Zr,$r,ei,Oe,Ie,Sl,{current:!1}]},nc={findFiberByHostInstance:Qr,bundleType:0,version:"17.0.2",rendererPackageName:"react-dom"},rc={bundleType:nc.bundleType,version:nc.version,rendererPackageName:nc.rendererPackageName,rendererConfig:nc.rendererConfig,overrideHookState:null,overrideHookStateDeletePath:null,overrideHookStateRenamePath:null,overrideProps:null,overridePropsDeletePath:null,overridePropsRenamePath:null,setSuspenseHandler:null,scheduleUpdate:null,currentDispatcherRef:M.ReactCurrentDispatcher,findHostInstanceByFiber:function(e){return null===(e=Ze(e))?null:e.stateNode},findFiberByHostInstance:nc.findFiberByHostInstance||function(){return null},findHostInstancesForRefresh:null,scheduleRefresh:null,scheduleRoot:null,setRefreshHandler:null,getCurrentFiber:null};if("undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__){var ic=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!ic.isDisabled&&ic.supportsFiber)try{yi=ic.inject(rc),_i=ic}catch(e){}}t.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=tc,t.createPortal=ec,t.findDOMNode=function(e){if(null==e)return null;if(1===e.nodeType)return e;var t=e._reactInternals;if(void 0===t){if("function"==typeof e.render)throw Error(a(188));throw Error(a(268,Object.keys(e)))}return e=null===(e=Ze(t))?null:e.stateNode},t.flushSync=function(e,t){var n=xs;if(0!=(48&n))return e(t);xs|=1;try{if(e)return Fi(99,e.bind(null,t))}finally{xs=n,Vi()}},t.hydrate=function(e,t,n){if(!Zl(t))throw Error(a(200));return $l(null,e,t,!0,n)},t.render=function(e,t,n){if(!Zl(t))throw Error(a(200));return $l(null,e,t,!1,n)},t.unmountComponentAtNode=function(e){if(!Zl(e))throw Error(a(40));return!!e._reactRootContainer&&(fl((function(){$l(null,null,e,!1,(function(){e._reactRootContainer=null,e[Xr]=null}))})),!0)},t.unstable_batchedUpdates=pl,t.unstable_createPortal=function(e,t){return ec(e,t,2<arguments.length&&void 0!==arguments[2]?arguments[2]:null)},t.unstable_renderSubtreeIntoContainer=function(e,t,n,r){if(!Zl(n))throw Error(a(200));if(null==e||void 0===e._reactInternals)throw Error(a(38));return $l(e,t,n,!1,r)},t.version="17.0.2"},function(e,t,n){"use strict";e.exports=n(692)},function(e,t,n){"use strict";
/** @license React v0.20.2
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var r,i,o,a;if("object"==typeof performance&&"function"==typeof performance.now){var s=performance;t.unstable_now=function(){return s.now()}}else{var l=Date,c=l.now();t.unstable_now=function(){return l.now()-c}}if("undefined"==typeof window||"function"!=typeof MessageChannel){var u=null,d=null,h=function(){if(null!==u)try{var e=t.unstable_now();u(!0,e),u=null}catch(e){throw setTimeout(h,0),e}};r=function(e){null!==u?setTimeout(r,0,e):(u=e,setTimeout(h,0))},i=function(e,t){d=setTimeout(e,t)},o=function(){clearTimeout(d)},t.unstable_shouldYield=function(){return!1},a=t.unstable_forceFrameRate=function(){}}else{var p=window.setTimeout,f=window.clearTimeout;if("undefined"!=typeof console){var m=window.cancelAnimationFrame;"function"!=typeof window.requestAnimationFrame&&console.error("This browser doesn't support requestAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills"),"function"!=typeof m&&console.error("This browser doesn't support cancelAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills")}var g=!1,v=null,y=-1,_=5,b=0;t.unstable_shouldYield=function(){return t.unstable_now()>=b},a=function(){},t.unstable_forceFrameRate=function(e){0>e||125<e?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):_=0<e?Math.floor(1e3/e):5};var M=new MessageChannel,w=M.port2;M.port1.onmessage=function(){if(null!==v){var e=t.unstable_now();b=e+_;try{v(!0,e)?w.postMessage(null):(g=!1,v=null)}catch(e){throw w.postMessage(null),e}}else g=!1},r=function(e){v=e,g||(g=!0,w.postMessage(null))},i=function(e,n){y=p((function(){e(t.unstable_now())}),n)},o=function(){f(y),y=-1}}function A(e,t){var n=e.length;e.push(t);e:for(;;){var r=n-1>>>1,i=e[r];if(!(void 0!==i&&0<E(i,t)))break e;e[r]=t,e[n]=i,n=r}}function C(e){return void 0===(e=e[0])?null:e}function x(e){var t=e[0];if(void 0!==t){var n=e.pop();if(n!==t){e[0]=n;e:for(var r=0,i=e.length;r<i;){var o=2*(r+1)-1,a=e[o],s=o+1,l=e[s];if(void 0!==a&&0>E(a,n))void 0!==l&&0>E(l,a)?(e[r]=l,e[s]=n,r=s):(e[r]=a,e[o]=n,r=o);else{if(!(void 0!==l&&0>E(l,n)))break e;e[r]=l,e[s]=n,r=s}}}return t}return null}function E(e,t){var n=e.sortIndex-t.sortIndex;return 0!==n?n:e.id-t.id}var L=[],S=[],T=1,O=null,I=3,k=!1,D=!1,N=!1;function j(e){for(var t=C(S);null!==t;){if(null===t.callback)x(S);else{if(!(t.startTime<=e))break;x(S),t.sortIndex=t.expirationTime,A(L,t)}t=C(S)}}function P(e){if(N=!1,j(e),!D)if(null!==C(L))D=!0,r(z);else{var t=C(S);null!==t&&i(P,t.startTime-e)}}function z(e,n){D=!1,N&&(N=!1,o()),k=!0;var r=I;try{for(j(n),O=C(L);null!==O&&(!(O.expirationTime>n)||e&&!t.unstable_shouldYield());){var a=O.callback;if("function"==typeof a){O.callback=null,I=O.priorityLevel;var s=a(O.expirationTime<=n);n=t.unstable_now(),"function"==typeof s?O.callback=s:O===C(L)&&x(L),j(n)}else x(L);O=C(L)}if(null!==O)var l=!0;else{var c=C(S);null!==c&&i(P,c.startTime-n),l=!1}return l}finally{O=null,I=r,k=!1}}var R=a;t.unstable_IdlePriority=5,t.unstable_ImmediatePriority=1,t.unstable_LowPriority=4,t.unstable_NormalPriority=3,t.unstable_Profiling=null,t.unstable_UserBlockingPriority=2,t.unstable_cancelCallback=function(e){e.callback=null},t.unstable_continueExecution=function(){D||k||(D=!0,r(z))},t.unstable_getCurrentPriorityLevel=function(){return I},t.unstable_getFirstCallbackNode=function(){return C(L)},t.unstable_next=function(e){switch(I){case 1:case 2:case 3:var t=3;break;default:t=I}var n=I;I=t;try{return e()}finally{I=n}},t.unstable_pauseExecution=function(){},t.unstable_requestPaint=R,t.unstable_runWithPriority=function(e,t){switch(e){case 1:case 2:case 3:case 4:case 5:break;default:e=3}var n=I;I=e;try{return t()}finally{I=n}},t.unstable_scheduleCallback=function(e,n,a){var s=t.unstable_now();switch("object"==typeof a&&null!==a?a="number"==typeof(a=a.delay)&&0<a?s+a:s:a=s,e){case 1:var l=-1;break;case 2:l=250;break;case 5:l=1073741823;break;case 4:l=1e4;break;default:l=5e3}return e={id:T++,callback:n,priorityLevel:e,startTime:a,expirationTime:l=a+l,sortIndex:-1},a>s?(e.sortIndex=a,A(S,e),null===C(L)&&e===C(S)&&(N?o():N=!0,i(P,a-s))):(e.sortIndex=l,A(L,e),D||k||(D=!0,r(z))),e},t.unstable_wrapCallback=function(e){var t=I;return function(){var n=I;I=t;try{return e.apply(this,arguments)}finally{I=n}}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractButton=void 0;var r=n(1),i=r.__importDefault(n(5)),o=r.__importStar(n(0)),a=n(91),s=n(385),l=n(711),c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={isActive:!1},t.handleKeyDown=function(e){var n,r;a.Keys.isKeyboardClick(e.which)&&(e.preventDefault(),e.which!==t.currentKeyDown&&t.setState({isActive:!0})),t.currentKeyDown=e.which,null===(r=(n=t.props).onKeyDown)||void 0===r||r.call(n,e)},t.handleKeyUp=function(e){var n,r,i;a.Keys.isKeyboardClick(e.which)&&(t.setState({isActive:!1}),null===(n=t.buttonRef)||void 0===n||n.click()),t.currentKeyDown=void 0,null===(i=(r=t.props).onKeyUp)||void 0===i||i.call(r,e)},t.handleBlur=function(e){var n,r;t.state.isActive&&t.setState({isActive:!1}),null===(r=(n=t.props).onBlur)||void 0===r||r.call(n,e)},t}return r.__extends(t,e),t.prototype.getCommonButtonProps=function(){var e,t=this.props,n=t.active,r=t.alignText,o=t.fill,s=t.large,l=t.loading,c=t.outlined,u=t.minimal,d=t.small,h=t.tabIndex,p=this.props.disabled||l;return{className:i.default(a.Classes.BUTTON,((e={})[a.Classes.ACTIVE]=!p&&(n||this.state.isActive),e[a.Classes.DISABLED]=p,e[a.Classes.FILL]=o,e[a.Classes.LARGE]=s,e[a.Classes.LOADING]=l,e[a.Classes.MINIMAL]=u,e[a.Classes.OUTLINED]=c,e[a.Classes.SMALL]=d,e),a.Classes.alignmentClass(r),a.Classes.intentClass(this.props.intent),this.props.className),disabled:p,onBlur:this.handleBlur,onClick:p?void 0:this.props.onClick,onKeyDown:this.handleKeyDown,onKeyUp:this.handleKeyUp,tabIndex:p?-1:h}},t.prototype.renderChildren=function(){var e=this.props,t=e.children,n=e.icon,r=e.loading,i=e.rightIcon,c=e.text;return[r&&o.createElement(l.Spinner,{key:"loading",className:a.Classes.BUTTON_SPINNER,size:s.IconSize.LARGE}),o.createElement(s.Icon,{key:"leftIcon",icon:n}),(!a.Utils.isReactNodeEmpty(c)||!a.Utils.isReactNodeEmpty(t))&&o.createElement("span",{key:"text",className:a.Classes.BUTTON_TEXT},c,t),o.createElement(s.Icon,{key:"rightIcon",icon:i})]},t}(a.AbstractPureComponent2);t.AbstractButton=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractComponent=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(92),a=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},o.isNodeEnv("production")||r.validateProps(r.props),r}return r.__extends(t,e),t.prototype.componentWillReceiveProps=function(e){o.isNodeEnv("production")||this.validateProps(e)},t.prototype.componentWillUnmount=function(){this.clearTimeouts()},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(i.Component);t.AbstractComponent=a},function(e,t,n){"use strict";function r(e,t,n){return void 0===n&&(n=function(e,t){return e===t}),null==e&&null==t||null!=e&&null!=t&&e.length===t.length&&e.every((function(e,r){return n(e,t[r])}))}function i(e,t,n){if(e===t)return!0;if(null==e&&null==t)return!0;if(null==e||null==t)return!1;if(Array.isArray(e)||Array.isArray(t))return r(e,t,i);if(s(e)||s(t))return e===t;if(null!=n)return a(e,t,n);if(e.constructor!==t.constructor)return!1;var o=Object.keys(e),l=Object.keys(t);return null!=o&&null!=l&&(0===o.length&&0===l.length||r(o,l)&&a(e,t,o))}function o(e,t,n){return function(e,t,n){if(function(e){return null!=e&&null!=e.include}(n))return n.include;if(function(e){return null!=e&&null!=e.exclude}(n)){var r=Object.keys(e),i=Object.keys(t),o=l(r.concat(i));return n.exclude.forEach((function(e){return delete o[e]})),Object.keys(o)}return[]}(e,t,n).every((function(n){return e.hasOwnProperty(n)===t.hasOwnProperty(n)&&e[n]===t[n]}))}function a(e,t,n){return n.every((function(n){return e.hasOwnProperty(n)===t.hasOwnProperty(n)&&i(e[n],t[n])}))}function s(e){return"number"==typeof e||"string"==typeof e||"boolean"==typeof e}function l(e){return e.reduce((function(e,t){return e[t]=!0,e}),{})}Object.defineProperty(t,"__esModule",{value:!0}),t.getDeepUnequalKeyValues=t.deepCompareKeys=t.shallowCompareKeys=t.arraysEqual=void 0,t.arraysEqual=r,t.shallowCompareKeys=function(e,t,n){if(null==e&&null==t)return!0;if(null==e||null==t)return!1;if(Array.isArray(e)||Array.isArray(t))return!1;if(null!=n)return o(e,t,n);var r=Object.keys(e),i=Object.keys(t);return o(e,t,{include:r})&&o(e,t,{include:i})},t.deepCompareKeys=i,t.getDeepUnequalKeyValues=function(e,t,n){return void 0===e&&(e={}),void 0===t&&(t={}),function(e,t,n,r){return n.filter((function(n){return!r(e,t,n)})).map((function(n){return{key:n,valueA:e[n],valueB:t[n]}}))}(e,t,null==n?function(e,t){var n=Object.keys(e),r=Object.keys(t),i=l(n.concat(r));return Object.keys(i)}(e,t):n,(function(e,t,n){return i(e,t,[n])}))}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.throttle=t.throttleReactEventCallback=t.throttleEvent=t.elementIsOrContains=void 0;var r=n(171);function i(e,t,n){var i=!1;return function(){for(var o=[],a=0;a<arguments.length;a++)o[a]=arguments[a];r.isFunction(t)&&t.apply(void 0,o),i||(i=!0,r.isFunction(n)&&n.apply(void 0,o),requestAnimationFrame((function(){e.apply(void 0,o),i=!1})))}}t.elementIsOrContains=function(e,t){return e===t||e.contains(t)},t.throttleEvent=function(e,t,n){var r=i((function(t){e.dispatchEvent(new CustomEvent(n,t))}));return e.addEventListener(t,r),r},t.throttleReactEventCallback=function(e,t){return void 0===t&&(t={}),i(e,(function(e){t.preventDefault&&e.preventDefault()}),(function(e){return e.persist()}))},t.throttle=function(e){return i(e)}},function(e,t,n){"use strict";(function(e){Object.defineProperty(t,"__esModule",{value:!0}),t.uniqueId=t.countDecimalPlaces=t.clamp=t.approxEqual=t.arrayLengthCompare=t.isNodeEnv=void 0;var r=n(172);t.isNodeEnv=function(t){return void 0!==e&&e.env&&"production"===t},t.arrayLengthCompare=function(e,t){return void 0===e&&(e=[]),void 0===t&&(t=[]),e.length-t.length},t.approxEqual=function(e,t,n){return void 0===n&&(n=1e-5),Math.abs(e-t)<=n},t.clamp=function(e,t,n){if(null==e)return e;if(n<t)throw new Error(r.CLAMP_MIN_MAX);return Math.min(Math.max(e,t),n)},t.countDecimalPlaces=function(e){if(!isFinite(e))return 0;for(var t=1,n=0;Math.round(e*t)/t!==e;)t*=10,n++;return n};var i=new Map;t.uniqueId=function(e){var t,n=null!==(t=i.get(e))&&void 0!==t?t:0;return i.set(e,n+1),e+"-"+n}}).call(this,n(61))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.createReactRef=t.isElementOfType=t.getDisplayName=t.ensureElement=t.isReactChildrenElementOrElements=t.isReactNodeEmpty=void 0;var r=n(1).__importStar(n(0));function i(e,t){return void 0===t&&(t=!1),null==e||""===e||!1===e||!t&&Array.isArray(e)&&(0===e.length||e.every((function(e){return i(e,!0)})))}t.isReactNodeEmpty=i,t.isReactChildrenElementOrElements=function(e){return!i(e,!0)&&!0!==e},t.ensureElement=function(e,t){return void 0===t&&(t="span"),null==e||"boolean"==typeof e?void 0:"string"==typeof e?e.trim().length>0?r.createElement(t,{},e):void 0:"number"==typeof e||"symbol"==typeof e.type||Array.isArray(e)?r.createElement(t,{},e):function(e){return"object"==typeof e&&void 0!==e.type&&void 0!==e.props}(e)?e:void 0},t.getDisplayName=function(e){return e.displayName||e.name||"Unknown"},t.isElementOfType=function(e,t){return null!=e&&null!=e.type&&null!=e.type.displayName&&e.type.displayName===t.displayName},t.createReactRef=function(){return void 0!==r.createRef?r.createRef():{current:null}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.safeInvokeMember=void 0;var r=n(171);t.safeInvokeMember=function(e,t){for(var n=[],i=2;i<arguments.length;i++)n[i-2]=arguments[i];if(null!=e){var o=e[t];if(r.isFunction(o))return o.apply(void 0,n)}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.isDarkTheme=void 0;var r=n(1);n(701);var i=r.__importStar(n(381));t.isDarkTheme=function(e){return null!=e&&e instanceof Element&&null!=e.closest("."+i.DARK)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),"undefined"!=typeof window&&"undefined"!=typeof document&&n(380)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractComponent2=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(92),a=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.requestIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},r.cancelAnimationFrames=function(){if(r.requestIds.length>0){for(var e=0,t=r.requestIds;e<t.length;e++){var n=t[e];window.cancelAnimationFrame(n)}r.requestIds=[]}},o.isNodeEnv("production")||r.validateProps(r.props),r}return r.__extends(t,e),t.prototype.componentDidUpdate=function(e,t,n){o.isNodeEnv("production")||this.validateProps(this.props)},t.prototype.componentWillUnmount=function(){this.clearTimeouts(),this.cancelAnimationFrames()},t.prototype.requestAnimationFrame=function(e){var t=window.requestAnimationFrame(e);return this.requestIds.push(t),function(){return window.cancelAnimationFrame(t)}},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(i.Component);t.AbstractComponent2=a},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractPureComponent=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(92),a=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},o.isNodeEnv("production")||r.validateProps(r.props),r}return r.__extends(t,e),t.prototype.componentWillReceiveProps=function(e){o.isNodeEnv("production")||this.validateProps(e)},t.prototype.componentWillUnmount=function(){this.clearTimeouts()},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(i.PureComponent);t.AbstractPureComponent=a},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractPureComponent2=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(92),a=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.timeoutIds=[],r.requestIds=[],r.clearTimeouts=function(){if(r.timeoutIds.length>0){for(var e=0,t=r.timeoutIds;e<t.length;e++){var n=t[e];window.clearTimeout(n)}r.timeoutIds=[]}},r.cancelAnimationFrames=function(){if(r.requestIds.length>0){for(var e=0,t=r.requestIds;e<t.length;e++){var n=t[e];window.cancelAnimationFrame(n)}r.requestIds=[]}},o.isNodeEnv("production")||r.validateProps(r.props),r}return r.__extends(t,e),t.prototype.componentDidUpdate=function(e,t,n){o.isNodeEnv("production")||this.validateProps(this.props)},t.prototype.componentWillUnmount=function(){this.clearTimeouts(),this.cancelAnimationFrames()},t.prototype.requestAnimationFrame=function(e){var t=window.requestAnimationFrame(e);return this.requestIds.push(t),function(){return window.cancelAnimationFrame(t)}},t.prototype.setTimeout=function(e,t){var n=window.setTimeout(e,t);return this.timeoutIds.push(n),function(){return window.clearTimeout(n)}},t.prototype.validateProps=function(e){},t}(i.PureComponent);t.AbstractPureComponent2=a},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Boundary=void 0,t.Boundary={START:"start",END:"end"}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Colors=void 0;var r=n(1),i=n(81);t.Colors=r.__assign(r.__assign({},i.LegacyColors),{CERULEAN1:i.LegacyColors.COBALT1,CERULEAN2:i.LegacyColors.COBALT2,CERULEAN3:i.LegacyColors.COBALT3,CERULEAN4:i.LegacyColors.COBALT4,CERULEAN5:i.LegacyColors.COBALT5})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Colors=void 0;t.Colors=Object.assign(Object.assign(Object.assign({},{BLACK:"#111418",DARK_GRAY1:"#1C2127",DARK_GRAY2:"#252A31",DARK_GRAY3:"#2F343C",DARK_GRAY4:"#383E47",DARK_GRAY5:"#404854",GRAY1:"#626E7F",GRAY2:"#738091",GRAY3:"#8F99A8",GRAY4:"#ABB3BF",GRAY5:"#C5CBD3",LIGHT_GRAY1:"#D3D8DE",LIGHT_GRAY2:"#DCE0E5",LIGHT_GRAY3:"#E5E8EB",LIGHT_GRAY4:"#EDEFF2",LIGHT_GRAY5:"#F6F7F9",WHITE:"#FFFFFF"}),{BLUE1:"#184A90",BLUE2:"#1A5BB7",BLUE3:"#1A69D5",BLUE4:"#498FF3",BLUE5:"#8ABBFF",GREEN1:"#165A32",GREEN2:"#176D3A",GREEN3:"#168845",GREEN4:"#30A660",GREEN5:"#72CA96",ORANGE1:"#77450D",ORANGE2:"#935610",ORANGE3:"#C4761C",ORANGE4:"#EA9A3E",ORANGE5:"#F7B264",RED1:"#942427",RED2:"#B3292D",RED3:"#D33136",RED4:"#E96367",RED5:"#F99498"}),{CERULEAN1:"#0C5174",CERULEAN2:"#0F6894",CERULEAN3:"#147EB3",CERULEAN4:"#3FA6DA",CERULEAN5:"#68C1EE",FOREST1:"#1D7324",FOREST2:"#238C2C",FOREST3:"#29A634",FOREST4:"#43BF4D",FOREST5:"#62D96B",GOLD1:"#5C4405",GOLD2:"#866103",GOLD3:"#D1980B",GOLD4:"#F0B726",GOLD5:"#FBD065",INDIGO1:"#5642A6",INDIGO2:"#634DBF",INDIGO3:"#7961DB",INDIGO4:"#9881F3",INDIGO5:"#BDADFF",LIME1:"#43501B",LIME2:"#5A701A",LIME3:"#8EB125",LIME4:"#B6D94C",LIME5:"#D4F17E",ROSE1:"#A82255",ROSE2:"#C22762",ROSE3:"#DB2C6F",ROSE4:"#F5498B",ROSE5:"#FF66A1",SEPIA1:"#5E4123",SEPIA2:"#7A542E",SEPIA3:"#946638",SEPIA4:"#AF855A",SEPIA5:"#D0B090",TURQUOISE1:"#004D46",TURQUOISE2:"#007067",TURQUOISE3:"#00A396",TURQUOISE4:"#13C9BA",TURQUOISE5:"#7AE1D8",VERMILION1:"#96290D",VERMILION2:"#B83211",VERMILION3:"#D33D17",VERMILION4:"#EB6847",VERMILION5:"#FF9980",VIOLET1:"#5C255C",VIOLET2:"#7C327C",VIOLET3:"#9D3F9D",VIOLET4:"#BD6BBD",VIOLET5:"#D69FD6"})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.LegacyColors=void 0,t.LegacyColors={BLACK:"#10161A",BLUE1:"#0E5A8A",BLUE2:"#106BA3",BLUE3:"#137CBD",BLUE4:"#2B95D6",BLUE5:"#48AFF0",COBALT1:"#1F4B99",COBALT2:"#2458B3",COBALT3:"#2965CC",COBALT4:"#4580E6",COBALT5:"#669EFF",DARK_GRAY1:"#182026",DARK_GRAY2:"#202B33",DARK_GRAY3:"#293742",DARK_GRAY4:"#30404D",DARK_GRAY5:"#394B59",FOREST1:"#1D7324",FOREST2:"#238C2C",FOREST3:"#29A634",FOREST4:"#43BF4D",FOREST5:"#62D96B",GOLD1:"#A67908",GOLD2:"#BF8C0A",GOLD3:"#D99E0B",GOLD4:"#F2B824",GOLD5:"#FFC940",GRAY1:"#5C7080",GRAY2:"#738694",GRAY3:"#8A9BA8",GRAY4:"#A7B6C2",GRAY5:"#BFCCD6",GREEN1:"#0A6640",GREEN2:"#0D8050",GREEN3:"#0F9960",GREEN4:"#15B371",GREEN5:"#3DCC91",INDIGO1:"#5642A6",INDIGO2:"#634DBF",INDIGO3:"#7157D9",INDIGO4:"#9179F2",INDIGO5:"#AD99FF",LIGHT_GRAY1:"#CED9E0",LIGHT_GRAY2:"#D8E1E8",LIGHT_GRAY3:"#E1E8ED",LIGHT_GRAY4:"#EBF1F5",LIGHT_GRAY5:"#F5F8FA",LIME1:"#728C23",LIME2:"#87A629",LIME3:"#9BBF30",LIME4:"#B6D94C",LIME5:"#D1F26D",ORANGE1:"#A66321",ORANGE2:"#BF7326",ORANGE3:"#D9822B",ORANGE4:"#F29D49",ORANGE5:"#FFB366",RED1:"#A82A2A",RED2:"#C23030",RED3:"#DB3737",RED4:"#F55656",RED5:"#FF7373",ROSE1:"#A82255",ROSE2:"#C22762",ROSE3:"#DB2C6F",ROSE4:"#F5498B",ROSE5:"#FF66A1",SEPIA1:"#63411E",SEPIA2:"#7D5125",SEPIA3:"#96622D",SEPIA4:"#B07B46",SEPIA5:"#C99765",TURQUOISE1:"#008075",TURQUOISE2:"#00998C",TURQUOISE3:"#00B3A4",TURQUOISE4:"#14CCBD",TURQUOISE5:"#2EE6D6",VERMILION1:"#9E2B0E",VERMILION2:"#B83211",VERMILION3:"#D13913",VERMILION4:"#EB532D",VERMILION5:"#FF6E4A",VIOLET1:"#5C255C",VIOLET2:"#752F75",VIOLET3:"#8F398F",VIOLET4:"#A854A8",VIOLET5:"#C274C2",WHITE:"#FFFFFF"}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.isKeyboardClick=t.DELETE=t.ARROW_DOWN=t.ARROW_RIGHT=t.ARROW_UP=t.ARROW_LEFT=t.SPACE=t.ESCAPE=t.SHIFT=t.ENTER=t.TAB=t.BACKSPACE=void 0,t.BACKSPACE=8,t.TAB=9,t.ENTER=13,t.SHIFT=16,t.ESCAPE=27,t.SPACE=32,t.ARROW_LEFT=37,t.ARROW_UP=38,t.ARROW_RIGHT=39,t.ARROW_DOWN=40,t.DELETE=46,t.isKeyboardClick=function(e){return e===t.ENTER||e===t.SPACE}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Spinner=t.SpinnerSize=void 0;var r,i=n(1),o=i.__importDefault(n(5)),a=i.__importStar(n(0)),s=n(9),l=n(91),c=n(172),u=n(84),d=n(92);!function(e){e[e.SMALL=20]="SMALL",e[e.STANDARD=50]="STANDARD",e[e.LARGE=100]="LARGE"}(r=t.SpinnerSize||(t.SpinnerSize={}));var h=45,p="M 50,50 m 0,-45 a 45,45 0 1 1 0,90 a 45,45 0 1 1 0,-90",f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i.__extends(t,e),t.prototype.componentDidUpdate=function(e){e.value!==this.props.value&&this.forceUpdate()},t.prototype.render=function(){var e,t=this.props,n=t.className,i=t.intent,s=t.value,c=t.tagName,u=void 0===c?"div":c,h=this.getSize(),f=o.default(l.Classes.SPINNER,l.Classes.intentClass(i),((e={})[l.Classes.SPINNER_NO_SPIN]=null!=s,e),n),m=Math.min(16,4*r.LARGE/h),g=280-280*(null==s?.25:d.clamp(s,0,1));return a.createElement(u,{className:f,role:"progressbar"},a.createElement(u,{className:l.Classes.SPINNER_ANIMATION},a.createElement("svg",{width:h,height:h,strokeWidth:m.toFixed(2),viewBox:this.getViewBox(m)},a.createElement("path",{className:l.Classes.SPINNER_TRACK,d:p}),a.createElement("path",{className:l.Classes.SPINNER_HEAD,d:p,pathLength:280,strokeDasharray:"280 280",strokeDashoffset:g}))))},t.prototype.validateProps=function(e){var t=e.className,n=void 0===t?"":t;null!=e.size&&(n.indexOf(l.Classes.SMALL)>=0||n.indexOf(l.Classes.LARGE)>=0)&&console.warn(c.SPINNER_WARN_CLASSES_SIZE)},t.prototype.getSize=function(){var e=this.props,t=e.className,n=void 0===t?"":t,i=e.size;return null==i?n.indexOf(l.Classes.SMALL)>=0?r.SMALL:n.indexOf(l.Classes.LARGE)>=0?r.LARGE:r.STANDARD:Math.max(10,i)},t.prototype.getViewBox=function(e){var t=h+e/2,n=(50-t).toFixed(2),r=(2*t).toFixed(2);return n+" "+n+" "+r+" "+r},t.displayName=u.DISPLAYNAME_PREFIX+".Spinner",t.SIZE_SMALL=r.SMALL,t.SIZE_STANDARD=r.STANDARD,t.SIZE_LARGE=r.LARGE,t=i.__decorate([s.polyfill],t)}(l.AbstractPureComponent2);t.Spinner=f},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AsyncControllableInput=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(9),a=n(84),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={hasPendingUpdate:!1,isComposing:!1,nextValue:t.props.value,value:t.props.value},t.handleCompositionStart=function(e){var n,r;t.setState({isComposing:!0,nextValue:t.state.value}),null===(r=(n=t.props).onCompositionStart)||void 0===r||r.call(n,e)},t.handleCompositionEnd=function(e){var n,r;t.setState({isComposing:!1}),null===(r=(n=t.props).onCompositionEnd)||void 0===r||r.call(n,e)},t.handleChange=function(e){var n,r,i=e.target.value;t.setState({nextValue:i}),null===(r=(n=t.props).onChange)||void 0===r||r.call(n,e)},t}return r.__extends(t,e),t.getDerivedStateFromProps=function(e,t){return t.isComposing||void 0===e.value?null:t.nextValue!==t.value?e.value===t.nextValue?t.hasPendingUpdate?{value:e.value,hasPendingUpdate:!1}:{value:t.nextValue}:e.value===t.value?{hasPendingUpdate:!0}:{value:e.value,nextValue:e.value,hasPendingUpdate:!1}:{value:e.value,nextValue:e.value,hasPendingUpdate:!1}},t.prototype.render=function(){var e=this.state,t=e.isComposing,n=e.hasPendingUpdate,o=e.value,a=e.nextValue,s=this.props,l=s.inputRef,c=r.__rest(s,["inputRef"]);return i.createElement("input",r.__assign({},c,{ref:l,value:t||n?a:o,onCompositionStart:this.handleCompositionStart,onCompositionEnd:this.handleCompositionEnd,onChange:this.handleChange}))},t.displayName=a.DISPLAYNAME_PREFIX+".AsyncControllableInput",t=r.__decorate([o.polyfill],t)}(i.PureComponent);t.AsyncControllableInput=s},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(714),i=n(715),o=n(386),a=function(){return r.create()},s=function(){function e(e){var t=this,n=e.autoGenerateTag;this.cssRaw=function(e){e&&(t._raw+=e||"",t._pendingRawChange=!0,t._styleUpdated())},this.cssRule=function(e){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var a=i.convertToStyles(o.extend.apply(void 0,n));t._freeStyle.registerRule(e,a),t._styleUpdated()},this.forceRenderStyles=function(){var e=t._getTag();e&&(e.textContent=t.getStyles())},this.fontFace=function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];for(var r=t._freeStyle,i=0,o=e;i<o.length;i++){var a=o[i];r.registerRule("@font-face",a)}t._styleUpdated()},this.getStyles=function(){return(t._raw||"")+t._freeStyle.getStyles()},this.keyframes=function(e){var n=i.convertToKeyframes(e),r=t._freeStyle.registerKeyframes(n);return t._styleUpdated(),r},this.reinit=function(){var e=a();t._freeStyle=e,t._lastFreeStyleChangeId=e.changeId,t._raw="",t._pendingRawChange=!1;var n=t._getTag();n&&(n.textContent="")},this.setStylesTarget=function(e){t._tag&&(t._tag.textContent=""),t._tag=e,t.forceRenderStyles()},this.stylesheet=function(e){for(var n={},r=0,i=Object.getOwnPropertyNames(e);r<i.length;r++){var o=i[r],a=e[o];a&&(a.$debugName=o,n[o]=t.style(a))}return n};var r=a();this._autoGenerateTag=n,this._freeStyle=r,this._lastFreeStyleChangeId=r.changeId,this._pending=0,this._pendingRawChange=!1,this._raw="",this._tag=void 0,this.style=this.style.bind(this)}return e.prototype._afterAllSync=function(e){var t=this;this._pending++;var n=this._pending;o.raf((function(){n===t._pending&&e()}))},e.prototype._getTag=function(){if(this._tag)return this._tag;if(this._autoGenerateTag){var e="undefined"==typeof window?{textContent:""}:document.createElement("style");return"undefined"!=typeof document&&document.head.appendChild(e),this._tag=e,e}},e.prototype._styleUpdated=function(){var e=this,t=this._freeStyle.changeId,n=this._lastFreeStyleChangeId;(this._pendingRawChange||t!==n)&&(this._lastFreeStyleChangeId=t,this._pendingRawChange=!1,this._afterAllSync((function(){return e.forceRenderStyles()})))},e.prototype.style=function(){var e=this._freeStyle.registerStyle(i.convertToStyles(o.extend.apply(void 0,arguments)));return this._styleUpdated(),e},e}();t.TypeStyle=s},function(e,t,n){"use strict";n.r(t),n.d(t,"Cache",(function(){return f})),n.d(t,"Selector",(function(){return m})),n.d(t,"Style",(function(){return g})),n.d(t,"Rule",(function(){return v})),n.d(t,"FreeStyle",(function(){return _})),n.d(t,"create",(function(){return b}));let r=0;const i=Object.create(null),o=["animation-iteration-count","border-image-outset","border-image-slice","border-image-width","box-flex","box-flex-group","box-ordinal-group","column-count","columns","counter-increment","counter-reset","flex","flex-grow","flex-positive","flex-shrink","flex-negative","flex-order","font-weight","grid-area","grid-column","grid-column-end","grid-column-span","grid-column-start","grid-row","grid-row-end","grid-row-span","grid-row-start","line-clamp","line-height","opacity","order","orphans","tab-size","widows","z-index","zoom","fill-opacity","flood-opacity","stop-opacity","stroke-dasharray","stroke-dashoffset","stroke-miterlimit","stroke-opacity","stroke-width"];for(const e of o)for(const t of["-webkit-","-ms-","-moz-","-o-",""])i[t+e]=!0;function a(e,t){return t&&"number"==typeof t&&!i[e]?`${e}:${t}px`:`${e}:${t}`}function s(e){return e.sort((e,t)=>e[0]>t[0]?1:-1)}function l(e){return e.map(([e,t])=>Array.isArray(t)?t.map(t=>a(e,t)).join(";"):a(e,t)).join(";")}function c(e,t){return-1===e.indexOf("&")?`${t} ${e}`:e.replace(/&/g,t)}function u(e,t,n,r,i){const{style:o,nested:a,isUnique:d}=function(e,t){const n=[],r=[];for(const t of Object.keys(e)){const o=t.trim(),a=e[t];36!==o.charCodeAt(0)&&null!=a&&("object"!=typeof a||Array.isArray(a)?n.push([(i=o,i.replace(/[A-Z]/g,e=>"-"+e.toLowerCase()).replace(/^ms-/,"-ms-")),a]):r.push([o,a]))}var i;return{style:l(s(n)),nested:t?r:s(r),isUnique:!!e.$unique}}(t,""!==e);let h=o;if(64===e.charCodeAt(0)){const t={selector:e,styles:[],rules:[],style:i?"":o};n.push(t),o&&i&&t.styles.push({selector:i,style:o,isUnique:d});for(const[e,n]of a)h+=e+u(e,n,t.rules,t.styles,i)}else{const t=i?c(e,i):e;o&&r.push({selector:t,style:o,isUnique:d});for(const[e,i]of a)h+=e+u(e,i,n,r,t)}return h}function d(e,t,n,i,o,a){for(const{selector:n,style:s,isUnique:l}of i){const i=a?c(n,o):n,u=l?"u\0"+(++r).toString(36):`s\0${t}\0${s}`,d=new g(s,u);d.add(new m(i,`k\0${t}\0${i}`)),e.add(d)}for(const{selector:r,style:i,rules:s,styles:l}of n){const n=new v(r,i,`r\0${t}\0${r}\0${i}`);d(n,t,s,l,o,a),e.add(n)}}function h(e){let t="";for(let n=0;n<e.length;n++)t+=e[n];return t}const p={add:()=>{},change:()=>{},remove:()=>{}};class f{constructor(e=p){this.changes=e,this.sheet=[],this.changeId=0,this._keys=[],this._children=Object.create(null),this._counters=Object.create(null)}add(e){const t=this._counters[e.id]||0,n=this._children[e.id]||e.clone();if(this._counters[e.id]=t+1,0===t)this._children[n.id]=n,this._keys.push(n.id),this.sheet.push(n.getStyles()),this.changeId++,this.changes.add(n,this._keys.length-1);else if(n instanceof f&&e instanceof f){const t=this._keys.indexOf(e.id),r=n.changeId;n.merge(e),n.changeId!==r&&(this.sheet.splice(t,1,n.getStyles()),this.changeId++,this.changes.change(n,t,t))}}remove(e){const t=this._counters[e.id];if(t){this._counters[e.id]=t-1;const n=this._children[e.id],r=this._keys.indexOf(n.id);if(1===t)delete this._counters[e.id],delete this._children[e.id],this._keys.splice(r,1),this.sheet.splice(r,1),this.changeId++,this.changes.remove(n,r);else if(n instanceof f&&e instanceof f){const t=n.changeId;n.unmerge(e),n.changeId!==t&&(this.sheet.splice(r,1,n.getStyles()),this.changeId++,this.changes.change(n,r,r))}}}values(){return this._keys.map(e=>this._children[e])}merge(e){for(const t of e.values())this.add(t);return this}unmerge(e){for(const t of e.values())this.remove(t);return this}clone(){return(new f).merge(this)}}class m{constructor(e,t){this.selector=e,this.id=t}getStyles(){return this.selector}clone(){return this}}class g extends f{constructor(e,t){super(),this.style=e,this.id=t}getStyles(){return`${this.sheet.join(",")}{${this.style}}`}clone(){return new g(this.style,this.id).merge(this)}}class v extends f{constructor(e,t,n){super(),this.rule=e,this.style=t,this.id=n}getStyles(){return`${this.rule}{${this.style}${h(this.sheet)}}`}clone(){return new v(this.rule,this.style,this.id).merge(this)}}function y(e,t){const n="f"+function(e){let t=5381,n=e.length;for(;n--;)t=33*t^e.charCodeAt(n);return(t>>>0).toString(36)}(e);return n}class _ extends f{constructor(e,t){super(t),this.id=e}registerStyle(e){const t=[],n=[],r=u("&",e,t,n),i=y(r);return d(this,r,t,n,"."+i,!0),i}registerKeyframes(e){return this.registerHashRule("@keyframes",e)}registerHashRule(e,t){const n=[],r=[],i=u("",t,n,r),o=y(i),a=new v(`${e} ${o}`,"",`h\0${i}\0${e}`);return d(a,i,n,r,"",!1),this.add(a),o}registerRule(e,t){const n=[],r=[];d(this,u(e,t,n,r),n,r,"",!1)}registerCss(e){return this.registerRule("",e)}getStyles(){return h(this.sheet)}clone(){return new _(this.id,this.changes).merge(this)}}function b(e){return new _("f"+(++r).toString(36),e)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.convertToStyles=function e(t){var n={};for(var r in t){var i=t[r];if("$nest"===r){var o=i;for(var a in o){var s=o[a];n[a]=e(s)}}else"$debugName"===r?n.$displayName=i:n[r]=i}return n},t.convertToKeyframes=function(e){var t={};for(var n in e)"$debugName"!==n&&(t[n]=e[n]);return e.$debugName&&(t.$displayName=e.$debugName),t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t){function n(t,r){return e.exports=n=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e},e.exports.__esModule=!0,e.exports.default=e.exports,n(t,r)}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){"use strict";t.__esModule=!0;var r=n(0),i=(a(r),a(n(93))),o=a(n(721));a(n(193));function a(e){return e&&e.__esModule?e:{default:e}}function s(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function l(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function c(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}function u(e){var t=[];return{on:function(e){t.push(e)},off:function(e){t=t.filter((function(t){return t!==e}))},get:function(){return e},set:function(n,r){e=n,t.forEach((function(t){return t(e,r)}))}}}t.default=function(e,t){var n,a,d="__create-react-context-"+(0,o.default)()+"__",h=function(e){function n(){var t,r;s(this,n);for(var i=arguments.length,o=Array(i),a=0;a<i;a++)o[a]=arguments[a];return t=r=l(this,e.call.apply(e,[this].concat(o))),r.emitter=u(r.props.value),l(r,t)}return c(n,e),n.prototype.getChildContext=function(){var e;return(e={})[d]=this.emitter,e},n.prototype.componentWillReceiveProps=function(e){if(this.props.value!==e.value){var n=this.props.value,r=e.value,i=void 0;((o=n)===(a=r)?0!==o||1/o==1/a:o!=o&&a!=a)?i=0:(i="function"==typeof t?t(n,r):1073741823,0!==(i|=0)&&this.emitter.set(e.value,i))}var o,a},n.prototype.render=function(){return this.props.children},n}(r.Component);h.childContextTypes=((n={})[d]=i.default.object.isRequired,n);var p=function(t){function n(){var e,r;s(this,n);for(var i=arguments.length,o=Array(i),a=0;a<i;a++)o[a]=arguments[a];return e=r=l(this,t.call.apply(t,[this].concat(o))),r.state={value:r.getValue()},r.onUpdate=function(e,t){0!=((0|r.observedBits)&t)&&r.setState({value:r.getValue()})},l(r,e)}return c(n,t),n.prototype.componentWillReceiveProps=function(e){var t=e.observedBits;this.observedBits=null==t?1073741823:t},n.prototype.componentDidMount=function(){this.context[d]&&this.context[d].on(this.onUpdate);var e=this.props.observedBits;this.observedBits=null==e?1073741823:e},n.prototype.componentWillUnmount=function(){this.context[d]&&this.context[d].off(this.onUpdate)},n.prototype.getValue=function(){return this.context[d]?this.context[d].get():e},n.prototype.render=function(){return(e=this.props.children,Array.isArray(e)?e[0]:e)(this.state.value);var e},n}(r.Component);return p.contextTypes=((a={})[d]=i.default.object,a),{Provider:h,Consumer:p}},e.exports=t.default},function(e,t,n){"use strict";var r=n(720);function i(){}function o(){}o.resetWarningCache=i,e.exports=function(){function e(e,t,n,i,o,a){if(a!==r){var s=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw s.name="Invariant Violation",s}}function t(){return e}e.isRequired=e;var n={array:e,bigint:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:t,element:e,elementType:e,instanceOf:t,node:e,objectOf:t,oneOf:t,oneOfType:t,shape:t,exact:t,checkPropTypes:o,resetWarningCache:i};return n.PropTypes=n,n}},function(e,t,n){"use strict";e.exports="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED"},function(e,t,n){"use strict";(function(t){var n="__global_unique_id__";e.exports=function(){return t[n]=(t[n]||0)+1}}).call(this,n(55))},function(e,t,n){"use strict";t.__esModule=!0,t.default=void 0;!function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var n in e)if(Object.prototype.hasOwnProperty.call(e,n)){var r=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,n):{};r.get||r.set?Object.defineProperty(t,n,r):t[n]=e[n]}t.default=e}(n(93));var r=s(n(723)),i=s(n(726)),o=s(n(0)),a=s(n(388));n(389);function s(e){return e&&e.__esModule?e:{default:e}}function l(){return(l=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}var c=function(e,t){return e&&t&&t.split(" ").forEach((function(t){return(0,r.default)(e,t)}))},u=function(e,t){return e&&t&&t.split(" ").forEach((function(t){return(0,i.default)(e,t)}))},d=function(e){var t,n;function r(){for(var t,n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return(t=e.call.apply(e,[this].concat(r))||this).onEnter=function(e,n){var r=t.getClassNames(n?"appear":"enter").className;t.removeClasses(e,"exit"),c(e,r),t.props.onEnter&&t.props.onEnter(e,n)},t.onEntering=function(e,n){var r=t.getClassNames(n?"appear":"enter").activeClassName;t.reflowAndAddClass(e,r),t.props.onEntering&&t.props.onEntering(e,n)},t.onEntered=function(e,n){var r=t.getClassNames("appear").doneClassName,i=t.getClassNames("enter").doneClassName,o=n?r+" "+i:i;t.removeClasses(e,n?"appear":"enter"),c(e,o),t.props.onEntered&&t.props.onEntered(e,n)},t.onExit=function(e){var n=t.getClassNames("exit").className;t.removeClasses(e,"appear"),t.removeClasses(e,"enter"),c(e,n),t.props.onExit&&t.props.onExit(e)},t.onExiting=function(e){var n=t.getClassNames("exit").activeClassName;t.reflowAndAddClass(e,n),t.props.onExiting&&t.props.onExiting(e)},t.onExited=function(e){var n=t.getClassNames("exit").doneClassName;t.removeClasses(e,"exit"),c(e,n),t.props.onExited&&t.props.onExited(e)},t.getClassNames=function(e){var n=t.props.classNames,r="string"==typeof n,i=r?(r&&n?n+"-":"")+e:n[e];return{className:i,activeClassName:r?i+"-active":n[e+"Active"],doneClassName:r?i+"-done":n[e+"Done"]}},t}n=e,(t=r).prototype=Object.create(n.prototype),t.prototype.constructor=t,t.__proto__=n;var i=r.prototype;return i.removeClasses=function(e,t){var n=this.getClassNames(t),r=n.className,i=n.activeClassName,o=n.doneClassName;r&&u(e,r),i&&u(e,i),o&&u(e,o)},i.reflowAndAddClass=function(e,t){t&&(e&&e.scrollTop,c(e,t))},i.render=function(){var e=l({},this.props);return delete e.classNames,o.default.createElement(a.default,l({},e,{onEnter:this.onEnter,onEntered:this.onEntered,onEntering:this.onEntering,onExit:this.onExit,onExiting:this.onExiting,onExited:this.onExited}))},r}(o.default.Component);d.defaultProps={classNames:""},d.propTypes={};var h=d;t.default=h,e.exports=t.default},function(e,t,n){"use strict";var r=n(724);t.__esModule=!0,t.default=function(e,t){e.classList?e.classList.add(t):(0,i.default)(e,t)||("string"==typeof e.className?e.className=e.className+" "+t:e.setAttribute("class",(e.className&&e.className.baseVal||"")+" "+t))};var i=r(n(725));e.exports=t.default},function(e,t){e.exports=function(e){return e&&e.__esModule?e:{default:e}},e.exports.__esModule=!0,e.exports.default=e.exports},function(e,t,n){"use strict";t.__esModule=!0,t.default=function(e,t){return e.classList?!!t&&e.classList.contains(t):-1!==(" "+(e.className.baseVal||e.className)+" ").indexOf(" "+t+" ")},e.exports=t.default},function(e,t,n){"use strict";function r(e,t){return e.replace(new RegExp("(^|\\s)"+t+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}e.exports=function(e,t){e.classList?e.classList.remove(t):"string"==typeof e.className?e.className=r(e.className,t):e.setAttribute("class",r(e.className&&e.className.baseVal||"",t))}},function(e,t,n){"use strict";t.__esModule=!0,t.default=void 0;a(n(93));var r=a(n(0)),i=n(34),o=a(n(390));function a(e){return e&&e.__esModule?e:{default:e}}var s=function(e){var t,n;function a(){for(var t,n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return(t=e.call.apply(e,[this].concat(r))||this).handleEnter=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onEnter",0,n)},t.handleEntering=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onEntering",0,n)},t.handleEntered=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onEntered",0,n)},t.handleExit=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onExit",1,n)},t.handleExiting=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onExiting",1,n)},t.handleExited=function(){for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return t.handleLifecycle("onExited",1,n)},t}n=e,(t=a).prototype=Object.create(n.prototype),t.prototype.constructor=t,t.__proto__=n;var s=a.prototype;return s.handleLifecycle=function(e,t,n){var o,a=this.props.children,s=r.default.Children.toArray(a)[t];s.props[e]&&(o=s.props)[e].apply(o,n),this.props[e]&&this.props[e]((0,i.findDOMNode)(this))},s.render=function(){var e=this.props,t=e.children,n=e.in,i=function(e,t){if(null==e)return{};var n,r,i={},o=Object.keys(e);for(r=0;r<o.length;r++)n=o[r],t.indexOf(n)>=0||(i[n]=e[n]);return i}(e,["children","in"]),a=r.default.Children.toArray(t),s=a[0],l=a[1];return delete i.onEnter,delete i.onEntering,delete i.onEntered,delete i.onExit,delete i.onExiting,delete i.onExited,r.default.createElement(o.default,i,n?r.default.cloneElement(s,{key:"first",onEnter:this.handleEnter,onEntering:this.handleEntering,onEntered:this.handleEntered}):r.default.cloneElement(l,{key:"second",onEnter:this.handleExit,onEntering:this.handleExiting,onEntered:this.handleExited}))},a}(r.default.Component);s.propTypes={};var l=s;t.default=l,e.exports=t.default},function(e,t,n){"use strict";t.__esModule=!0,t.getChildMapping=i,t.mergeChildMappings=o,t.getInitialChildMapping=function(e,t){return i(e.children,(function(n){return(0,r.cloneElement)(n,{onExited:t.bind(null,n),in:!0,appear:a(n,"appear",e),enter:a(n,"enter",e),exit:a(n,"exit",e)})}))},t.getNextChildMapping=function(e,t,n){var s=i(e.children),l=o(t,s);return Object.keys(l).forEach((function(i){var o=l[i];if((0,r.isValidElement)(o)){var c=i in t,u=i in s,d=t[i],h=(0,r.isValidElement)(d)&&!d.props.in;!u||c&&!h?u||!c||h?u&&c&&(0,r.isValidElement)(d)&&(l[i]=(0,r.cloneElement)(o,{onExited:n.bind(null,o),in:d.props.in,exit:a(o,"exit",e),enter:a(o,"enter",e)})):l[i]=(0,r.cloneElement)(o,{in:!1}):l[i]=(0,r.cloneElement)(o,{onExited:n.bind(null,o),in:!0,exit:a(o,"exit",e),enter:a(o,"enter",e)})}})),l};var r=n(0);function i(e,t){var n=Object.create(null);return e&&r.Children.map(e,(function(e){return e})).forEach((function(e){n[e.key]=function(e){return t&&(0,r.isValidElement)(e)?t(e):e}(e)})),n}function o(e,t){function n(n){return n in t?t[n]:e[n]}e=e||{},t=t||{};var r,i=Object.create(null),o=[];for(var a in e)a in t?o.length&&(i[a]=o,o=[]):o.push(a);var s={};for(var l in t){if(i[l])for(r=0;r<i[l].length;r++){var c=i[l][r];s[i[l][r]]=n(c)}s[l]=n(l)}for(r=0;r<o.length;r++)s[o[r]]=n(o[r]);return s}function a(e,t,n){return null!=n[t]?n[t]:e.props[t]}},function(e,t,n){"use strict";var r;if(!Object.keys){var i=Object.prototype.hasOwnProperty,o=Object.prototype.toString,a=n(392),s=Object.prototype.propertyIsEnumerable,l=!s.call({toString:null},"toString"),c=s.call((function(){}),"prototype"),u=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],d=function(e){var t=e.constructor;return t&&t.prototype===e},h={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},p=function(){if("undefined"==typeof window)return!1;for(var e in window)try{if(!h["$"+e]&&i.call(window,e)&&null!==window[e]&&"object"==typeof window[e])try{d(window[e])}catch(e){return!0}}catch(e){return!0}return!1}();r=function(e){var t=null!==e&&"object"==typeof e,n="[object Function]"===o.call(e),r=a(e),s=t&&"[object String]"===o.call(e),h=[];if(!t&&!n&&!r)throw new TypeError("Object.keys called on a non-object");var f=c&&n;if(s&&e.length>0&&!i.call(e,0))for(var m=0;m<e.length;++m)h.push(String(m));if(r&&e.length>0)for(var g=0;g<e.length;++g)h.push(String(g));else for(var v in e)f&&"prototype"===v||!i.call(e,v)||h.push(String(v));if(l)for(var y=function(e){if("undefined"==typeof window||!p)return d(e);try{return d(e)}catch(e){return!1}}(e),_=0;_<u.length;++_)y&&"constructor"===u[_]||!i.call(e,u[_])||h.push(u[_]);return h}}e.exports=r},function(e,t,n){"use strict";var r=n(174)(),i=n(394)("Object.prototype.toString"),o=function(e){return!(r&&e&&"object"==typeof e&&Symbol.toStringTag in e)&&"[object Arguments]"===i(e)},a=function(e){return!!o(e)||null!==e&&"object"==typeof e&&"number"==typeof e.length&&e.length>=0&&"[object Array]"!==i(e)&&"[object Function]"===i(e.callee)},s=function(){return o(arguments)}();o.isLegacyArguments=a,e.exports=s?o:a},function(e,t,n){"use strict";var r="undefined"!=typeof Symbol&&Symbol,i=n(393);e.exports=function(){return"function"==typeof r&&("function"==typeof Symbol&&("symbol"==typeof r("foo")&&("symbol"==typeof Symbol("bar")&&i())))}},function(e,t,n){"use strict";var r="Function.prototype.bind called on incompatible ",i=Array.prototype.slice,o=Object.prototype.toString;e.exports=function(e){var t=this;if("function"!=typeof t||"[object Function]"!==o.call(t))throw new TypeError(r+t);for(var n,a=i.call(arguments,1),s=function(){if(this instanceof n){var r=t.apply(this,a.concat(i.call(arguments)));return Object(r)===r?r:this}return t.apply(e,a.concat(i.call(arguments)))},l=Math.max(0,t.length-a.length),c=[],u=0;u<l;u++)c.push("$"+u);if(n=Function("binder","return function ("+c.join(",")+"){ return binder.apply(this,arguments); }")(s),t.prototype){var d=function(){};d.prototype=t.prototype,n.prototype=new d,d.prototype=null}return n}},function(e,t,n){"use strict";var r=n(175);e.exports=r.call(Function.call,Object.prototype.hasOwnProperty)},function(e,t,n){"use strict";var r=n(104),i=n(176),o=n(396),a=n(397),s=n(735),l=i(a(),Object);r(l,{getPolyfill:a,implementation:o,shim:s}),e.exports=l},function(e,t,n){"use strict";var r=n(397),i=n(104);e.exports=function(){var e=r();return i(Object,{is:e},{is:function(){return Object.is!==e}}),e}},function(e,t,n){"use strict";var r,i,o,a,s=n(394),l=n(174)();if(l){r=s("Object.prototype.hasOwnProperty"),i=s("RegExp.prototype.exec"),o={};var c=function(){throw o};a={toString:c,valueOf:c},"symbol"==typeof Symbol.toPrimitive&&(a[Symbol.toPrimitive]=c)}var u=s("Object.prototype.toString"),d=Object.getOwnPropertyDescriptor;e.exports=l?function(e){if(!e||"object"!=typeof e)return!1;var t=d(e,"lastIndex");if(!(t&&r(t,"value")))return!1;try{i(e,a)}catch(e){return e===o}}:function(e){return!(!e||"object"!=typeof e&&"function"!=typeof e)&&"[object RegExp]"===u(e)}},function(e,t,n){"use strict";var r=n(104),i=n(176),o=n(398),a=n(399),s=n(738),l=i(a());r(l,{getPolyfill:a,implementation:o,shim:s}),e.exports=l},function(e,t,n){"use strict";var r=n(104).supportsDescriptors,i=n(399),o=Object.getOwnPropertyDescriptor,a=Object.defineProperty,s=TypeError,l=Object.getPrototypeOf,c=/a/;e.exports=function(){if(!r||!l)throw new s("RegExp.prototype.flags requires a true ES5 environment that supports property descriptors");var e=i(),t=l(c),n=o(t,"flags");return n&&n.get===e||a(t,"flags",{configurable:!0,enumerable:!1,get:e}),e}},function(e,t,n){"use strict";var r=Date.prototype.getDay,i=Object.prototype.toString,o=n(174)();e.exports=function(e){return"object"==typeof e&&null!==e&&(o?function(e){try{return r.call(e),!0}catch(e){return!1}}(e):"[object Date]"===i.call(e))}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.SELECT_MATCH_TARGET_WIDTH=t.SELECT_POPOVER=t.SELECT=t.OMNIBAR_OVERLAY=t.OMNIBAR=t.MULTISELECT_TAG_INPUT_INPUT=t.MULTISELECT_POPOVER=t.MULTISELECT=void 0;var r=n(138).Classes.getClassNamespace();t.MULTISELECT=r+"-multi-select",t.MULTISELECT_POPOVER=t.MULTISELECT+"-popover",t.MULTISELECT_TAG_INPUT_INPUT=t.MULTISELECT+"-tag-input-input",t.OMNIBAR=r+"-omnibar",t.OMNIBAR_OVERLAY=t.OMNIBAR+"-overlay",t.SELECT=r+"-select",t.SELECT_POPOVER=t.SELECT+"-popover",t.SELECT_MATCH_TARGET_WIDTH=t.SELECT+"-match-target-width"},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.renderFilteredItems=void 0,t.renderFilteredItems=function(e,t,n){if(0===e.query.length&&void 0!==n)return n;var r=e.filteredItems.map(e.renderItem).filter((function(e){return null!=e}));return r.length>0?r:t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.executeItemsEqual=void 0;var r=n(138);t.executeItemsEqual=function(e,t,n){return void 0===e||null==t||null==n?t===n:r.Utils.isFunction(e)?e(t,n):t[e]===n[e]}},function(e,t,n){"use strict";function r(e){if(null==e)return!1;var t=Object.keys(e);return 1===t.length&&"__blueprintCreateNewItemBrand"===t[0]&&"blueprint-create-new-item"===e.__blueprintCreateNewItemBrand}Object.defineProperty(t,"__esModule",{value:!0}),t.getActiveItem=t.isCreateNewItem=t.getCreateNewItem=void 0,t.getCreateNewItem=function(){return{__blueprintCreateNewItemBrand:"blueprint-create-new-item"}},t.isCreateNewItem=r,t.getActiveItem=function(e){return null==e||r(e)?null:e}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.getFirstEnabledItem=t.QueryList=void 0;var r=n(1),i=r.__importStar(n(0)),o=n(138),a=n(400),s=function(e){function t(t,n){var r,s,l=e.call(this,t,n)||this;l.refHandlers={itemsParent:function(e){return l.itemsParentRef=e}},l.shouldCheckActiveItemInViewport=!1,l.expectedNextActiveItem=null,l.isEnterKeyPressed=!1,l.renderItemList=function(e){var t=l.props,n=t.initialContent,r=t.noResults,s=e.renderCreateItem(),c=null!=s?null:r,u=a.renderFilteredItems(e,c,n);if(null==u&&null==s)return null;var d=l.isCreateItemFirst();return i.createElement(o.Menu,{ulRef:e.itemsParentRef},d&&s,u,!d&&s)},l.renderItem=function(e,t){if(!0!==l.props.disabled){var n=l.state,r=n.activeItem,i=n.query,o=l.state.filteredItems.indexOf(e)>=0,s={active:a.executeItemsEqual(l.props.itemsEqual,a.getActiveItem(r),e),disabled:d(e,t,l.props.itemDisabled),matchesPredicate:o};return l.props.itemRenderer(e,{handleClick:function(t){return l.handleItemSelect(e,t)},index:t,modifiers:s,query:i})}return null},l.renderCreateItemMenuItem=function(){if(l.isCreateItemRendered()){var e=l.state,t=e.activeItem,n=e.query.trim(),r=a.isCreateNewItem(t);return l.props.createNewItemRenderer(n,r,(function(e){l.handleItemCreate(n,e)}))}return null},l.handleItemCreate=function(e,t){var n,r,i,o,a=null===(r=(n=l.props).createNewItemFromQuery)||void 0===r?void 0:r.call(n,e);null!=a&&(null===(o=(i=l.props).onItemSelect)||void 0===o||o.call(i,a,t),l.maybeResetQuery())},l.handleItemSelect=function(e,t){var n,r;l.setActiveItem(e),null===(r=(n=l.props).onItemSelect)||void 0===r||r.call(n,e,t),l.maybeResetQuery()},l.handlePaste=function(e){for(var t,n=l.props,r=n.createNewItemFromQuery,i=n.onItemsPaste,o=[],a=[],s=0,u=e;s<u.length;s++){var d=u[s],h=c(d,l.props);if(void 0!==h)t=h,a.push(h);else if(l.canCreateItems()){var p=null==r?void 0:r(d);void 0!==p&&a.push(p)}else o.push(d)}l.setQuery(o.join(", "),!1),void 0!==t&&l.setActiveItem(t),null==i||i(a)},l.handleKeyDown=function(e){var t,n,r=e.keyCode;if(r===o.Keys.ARROW_UP||r===o.Keys.ARROW_DOWN){e.preventDefault();var i=l.getNextActiveItem(r===o.Keys.ARROW_UP?-1:1);null!=i&&l.setActiveItem(i)}else r===o.Keys.ENTER&&(l.isEnterKeyPressed=!0);null===(n=(t=l.props).onKeyDown)||void 0===n||n.call(t,e)},l.handleKeyUp=function(e){var t=l.props.onKeyUp,n=l.state.activeItem;e.keyCode===o.Keys.ENTER&&l.isEnterKeyPressed&&(e.preventDefault(),null==n||a.isCreateNewItem(n)?l.handleItemCreate(l.state.query,e):l.handleItemSelect(n,e),l.isEnterKeyPressed=!1),null==t||t(e)},l.handleInputQueryChange=function(e){var t,n,r=null==e?"":e.target.value;l.setQuery(r),null===(n=(t=l.props).onQueryChange)||void 0===n||n.call(t,r,e)};var p=t.query,f=void 0===p?"":p,m=null===(r=t.createNewItemFromQuery)||void 0===r?void 0:r.call(t,f),g=u(f,t);return l.state={activeItem:void 0!==t.activeItem?t.activeItem:null!==(s=t.initialActiveItem)&&void 0!==s?s:h(g,t.itemDisabled),createNewItem:m,filteredItems:g,query:f},l}return r.__extends(t,e),t.ofType=function(){return t},t.prototype.render=function(){var e=this.props,t=e.className,n=e.items,i=e.renderer,o=e.itemListRenderer,a=void 0===o?this.renderItemList:o,s=this.state,l=(s.createNewItem,r.__rest(s,["createNewItem"]));return i(r.__assign(r.__assign({},l),{className:t,handleItemSelect:this.handleItemSelect,handleKeyDown:this.handleKeyDown,handleKeyUp:this.handleKeyUp,handlePaste:this.handlePaste,handleQueryChange:this.handleInputQueryChange,itemList:a(r.__assign(r.__assign({},l),{items:n,itemsParentRef:this.refHandlers.itemsParent,renderCreateItem:this.renderCreateItemMenuItem,renderItem:this.renderItem}))}))},t.prototype.componentDidUpdate=function(e){var t=this;void 0!==this.props.activeItem&&this.props.activeItem!==this.state.activeItem&&(this.shouldCheckActiveItemInViewport=!0,this.setState({activeItem:this.props.activeItem})),null!=this.props.query&&this.props.query!==e.query?this.setQuery(this.props.query,this.props.resetOnQuery,this.props):o.Utils.shallowCompareKeys(this.props,e,{include:["items","itemListPredicate","itemPredicate"]})||this.setQuery(this.state.query),this.shouldCheckActiveItemInViewport&&(this.requestAnimationFrame((function(){return t.scrollActiveItemIntoView()})),this.shouldCheckActiveItemInViewport=!1)},t.prototype.scrollActiveItemIntoView=function(){var e=!1!==this.props.scrollToActiveItem,t=!a.executeItemsEqual(this.props.itemsEqual,a.getActiveItem(this.expectedNextActiveItem),a.getActiveItem(this.props.activeItem));if(this.expectedNextActiveItem=null,e||!t){var n=this.getActiveElement();if(null!=this.itemsParentRef&&null!=n){var r=n.offsetTop,i=n.offsetHeight,o=this.itemsParentRef,s=o.offsetTop,l=o.scrollTop,c=o.clientHeight,u=this.getItemsParentPadding(),d=u.paddingTop,h=r+i+u.paddingBottom-s,p=r-d-s;h>=l+c?this.itemsParentRef.scrollTop=h+i-c:p<=l&&(this.itemsParentRef.scrollTop=p-i)}}},t.prototype.setQuery=function(e,t,n){var r;void 0===t&&(t=this.props.resetOnQuery),void 0===n&&(n=this.props);var i=n.createNewItemFromQuery;this.shouldCheckActiveItemInViewport=!0,e!==this.state.query&&(null===(r=n.onQueryChange)||void 0===r||r.call(n,e));var o=e.trim(),s=u(o,n),l=null!=i&&""!==o?i(o):void 0;this.setState({createNewItem:l,filteredItems:s,query:e});var c=this.getActiveIndex(s);(t||c<0||d(a.getActiveItem(this.state.activeItem),c,n.itemDisabled))&&(this.isCreateItemRendered()&&this.isCreateItemFirst()?this.setActiveItem(a.getCreateNewItem()):this.setActiveItem(h(s,n.itemDisabled)))},t.prototype.setActiveItem=function(e){var t,n,r,i;this.expectedNextActiveItem=e,void 0===this.props.activeItem&&(this.shouldCheckActiveItemInViewport=!0,this.setState({activeItem:e})),a.isCreateNewItem(e)?null===(n=(t=this.props).onActiveItemChange)||void 0===n||n.call(t,null,!0):null===(i=(r=this.props).onActiveItemChange)||void 0===i||i.call(r,e,!1)},t.prototype.getActiveElement=function(){var e=this.state.activeItem;if(null!=this.itemsParentRef){if(a.isCreateNewItem(e)){var t=this.isCreateItemFirst()?0:this.state.filteredItems.length;return this.itemsParentRef.children.item(t)}var n=this.getActiveIndex();return this.itemsParentRef.children.item(n)}},t.prototype.getActiveIndex=function(e){void 0===e&&(e=this.state.filteredItems);var t=this.state.activeItem;if(null==t||a.isCreateNewItem(t))return-1;for(var n=0;n<e.length;++n)if(a.executeItemsEqual(this.props.itemsEqual,e[n],t))return n;return-1},t.prototype.getItemsParentPadding=function(){var e=getComputedStyle(this.itemsParentRef),t=e.paddingTop;return{paddingBottom:l(e.paddingBottom),paddingTop:l(t)}},t.prototype.getNextActiveItem=function(e,t){if((void 0===t&&(t=this.getActiveIndex()),this.isCreateItemRendered())&&(0===t&&-1===e||t===this.state.filteredItems.length-1&&1===e))return a.getCreateNewItem();return h(this.state.filteredItems,this.props.itemDisabled,e,t)},t.prototype.isCreateItemRendered=function(){return this.canCreateItems()&&""!==this.state.query&&!this.wouldCreatedItemMatchSomeExistingItem()},t.prototype.isCreateItemFirst=function(){return"first"===this.props.createNewItemPosition},t.prototype.canCreateItems=function(){return null!=this.props.createNewItemFromQuery&&null!=this.props.createNewItemRenderer},t.prototype.wouldCreatedItemMatchSomeExistingItem=function(){var e=this;return this.state.filteredItems.some((function(t){return a.executeItemsEqual(e.props.itemsEqual,t,e.state.createNewItem)}))},t.prototype.maybeResetQuery=function(){this.props.resetOnSelect&&this.setQuery("",!0)},t.displayName=o.DISPLAYNAME_PREFIX+".QueryList",t.defaultProps={disabled:!1,resetOnQuery:!0},t}(o.AbstractComponent2);function l(e){return null==e?0:parseInt(e.slice(0,-2),10)}function c(e,t){var n=t.items,r=t.itemPredicate;if(o.Utils.isFunction(r))for(var i=0;i<n.length;i++){var a=n[i];if(r(e,a,i,!0))return a}}function u(e,t){var n=t.items,r=t.itemPredicate,i=t.itemListPredicate;return o.Utils.isFunction(i)?i(e,n):o.Utils.isFunction(r)?n.filter((function(t,n){return r(e,t,n)})):n}function d(e,t,n){return null!=n&&null!=e&&(o.Utils.isFunction(n)?n(e,t):!!e[n])}function h(e,t,n,r){if(void 0===n&&(n=1),void 0===r&&(r=e.length-1),0===e.length)return null;var i,o,a,s=r,l=e.length-1;do{if(a=l,!d(e[s=(i=s+n)<(o=0)?a:i>a?o:i],s,t))return e[s]}while(s!==r&&-1!==r);return null}t.QueryList=s,t.getFirstEnabledItem=h},function(e,t,n){var r=n(748),i=n(106);e.exports=function e(t,n,o,a,s){return t===n||(null==t||null==n||!i(t)&&!i(n)?t!=t&&n!=n:r(t,n,o,a,e,s))}},function(e,t,n){var r=n(749),i=n(408),o=n(783),a=n(787),s=n(808),l=n(179),c=n(409),u=n(410),d="[object Object]",h=Object.prototype.hasOwnProperty;e.exports=function(e,t,n,p,f,m){var g=l(e),v=l(t),y=g?"[object Array]":s(e),_=v?"[object Array]":s(t),b=(y="[object Arguments]"==y?d:y)==d,M=(_="[object Arguments]"==_?d:_)==d,w=y==_;if(w&&c(e)){if(!c(t))return!1;g=!0,b=!1}if(w&&!b)return m||(m=new r),g||u(e)?i(e,t,n,p,f,m):o(e,t,y,n,p,f,m);if(!(1&n)){var A=b&&h.call(e,"__wrapped__"),C=M&&h.call(t,"__wrapped__");if(A||C){var x=A?e.value():e,E=C?t.value():t;return m||(m=new r),f(x,E,n,p,m)}}return!!w&&(m||(m=new r),a(e,t,n,p,f,m))}},function(e,t,n){var r=n(129),i=n(755),o=n(756),a=n(757),s=n(758),l=n(759);function c(e){var t=this.__data__=new r(e);this.size=t.size}c.prototype.clear=i,c.prototype.delete=o,c.prototype.get=a,c.prototype.has=s,c.prototype.set=l,e.exports=c},function(e,t){e.exports=function(){this.__data__=[],this.size=0}},function(e,t,n){var r=n(130),i=Array.prototype.splice;e.exports=function(e){var t=this.__data__,n=r(t,e);return!(n<0)&&(n==t.length-1?t.pop():i.call(t,n,1),--this.size,!0)}},function(e,t,n){var r=n(130);e.exports=function(e){var t=this.__data__,n=r(t,e);return n<0?void 0:t[n][1]}},function(e,t,n){var r=n(130);e.exports=function(e){return r(this.__data__,e)>-1}},function(e,t,n){var r=n(130);e.exports=function(e,t){var n=this.__data__,i=r(n,e);return i<0?(++this.size,n.push([e,t])):n[i][1]=t,this}},function(e,t,n){var r=n(129);e.exports=function(){this.__data__=new r,this.size=0}},function(e,t){e.exports=function(e){var t=this.__data__,n=t.delete(e);return this.size=t.size,n}},function(e,t){e.exports=function(e){return this.__data__.get(e)}},function(e,t){e.exports=function(e){return this.__data__.has(e)}},function(e,t,n){var r=n(129),i=n(177),o=n(407);e.exports=function(e,t){var n=this.__data__;if(n instanceof r){var a=n.__data__;if(!i||a.length<199)return a.push([e,t]),this.size=++n.size,this;n=this.__data__=new o(a)}return n.set(e,t),this.size=n.size,this}},function(e,t,n){var r=n(403),i=n(763),o=n(405),a=n(406),s=/^\[object .+?Constructor\]$/,l=Function.prototype,c=Object.prototype,u=l.toString,d=c.hasOwnProperty,h=RegExp("^"+u.call(d).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");e.exports=function(e){return!(!o(e)||i(e))&&(r(e)?h:s).test(a(e))}},function(e,t,n){var r=n(178),i=Object.prototype,o=i.hasOwnProperty,a=i.toString,s=r?r.toStringTag:void 0;e.exports=function(e){var t=o.call(e,s),n=e[s];try{e[s]=void 0;var r=!0}catch(e){}var i=a.call(e);return r&&(t?e[s]=n:delete e[s]),i}},function(e,t){var n=Object.prototype.toString;e.exports=function(e){return n.call(e)}},function(e,t,n){var r,i=n(764),o=(r=/[^.]+$/.exec(i&&i.keys&&i.keys.IE_PROTO||""))?"Symbol(src)_1."+r:"";e.exports=function(e){return!!o&&o in e}},function(e,t,n){var r=n(67)["__core-js_shared__"];e.exports=r},function(e,t){e.exports=function(e,t){return null==e?void 0:e[t]}},function(e,t,n){var r=n(767),i=n(129),o=n(177);e.exports=function(){this.size=0,this.__data__={hash:new r,map:new(o||i),string:new r}}},function(e,t,n){var r=n(768),i=n(769),o=n(770),a=n(771),s=n(772);function l(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}l.prototype.clear=r,l.prototype.delete=i,l.prototype.get=o,l.prototype.has=a,l.prototype.set=s,e.exports=l},function(e,t,n){var r=n(131);e.exports=function(){this.__data__=r?r(null):{},this.size=0}},function(e,t){e.exports=function(e){var t=this.has(e)&&delete this.__data__[e];return this.size-=t?1:0,t}},function(e,t,n){var r=n(131),i=Object.prototype.hasOwnProperty;e.exports=function(e){var t=this.__data__;if(r){var n=t[e];return"__lodash_hash_undefined__"===n?void 0:n}return i.call(t,e)?t[e]:void 0}},function(e,t,n){var r=n(131),i=Object.prototype.hasOwnProperty;e.exports=function(e){var t=this.__data__;return r?void 0!==t[e]:i.call(t,e)}},function(e,t,n){var r=n(131);e.exports=function(e,t){var n=this.__data__;return this.size+=this.has(e)?0:1,n[e]=r&&void 0===t?"__lodash_hash_undefined__":t,this}},function(e,t,n){var r=n(132);e.exports=function(e){var t=r(this,e).delete(e);return this.size-=t?1:0,t}},function(e,t){e.exports=function(e){var t=typeof e;return"string"==t||"number"==t||"symbol"==t||"boolean"==t?"__proto__"!==e:null===e}},function(e,t,n){var r=n(132);e.exports=function(e){return r(this,e).get(e)}},function(e,t,n){var r=n(132);e.exports=function(e){return r(this,e).has(e)}},function(e,t,n){var r=n(132);e.exports=function(e,t){var n=r(this,e),i=n.size;return n.set(e,t),this.size+=n.size==i?0:1,this}},function(e,t,n){var r=n(407),i=n(779),o=n(780);function a(e){var t=-1,n=null==e?0:e.length;for(this.__data__=new r;++t<n;)this.add(e[t])}a.prototype.add=a.prototype.push=i,a.prototype.has=o,e.exports=a},function(e,t){e.exports=function(e){return this.__data__.set(e,"__lodash_hash_undefined__"),this}},function(e,t){e.exports=function(e){return this.__data__.has(e)}},function(e,t){e.exports=function(e,t){for(var n=-1,r=null==e?0:e.length;++n<r;)if(t(e[n],n,e))return!0;return!1}},function(e,t){e.exports=function(e,t){return e.has(t)}},function(e,t,n){var r=n(178),i=n(784),o=n(402),a=n(408),s=n(785),l=n(786),c=r?r.prototype:void 0,u=c?c.valueOf:void 0;e.exports=function(e,t,n,r,c,d,h){switch(n){case"[object DataView]":if(e.byteLength!=t.byteLength||e.byteOffset!=t.byteOffset)return!1;e=e.buffer,t=t.buffer;case"[object ArrayBuffer]":return!(e.byteLength!=t.byteLength||!d(new i(e),new i(t)));case"[object Boolean]":case"[object Date]":case"[object Number]":return o(+e,+t);case"[object Error]":return e.name==t.name&&e.message==t.message;case"[object RegExp]":case"[object String]":return e==t+"";case"[object Map]":var p=s;case"[object Set]":var f=1&r;if(p||(p=l),e.size!=t.size&&!f)return!1;var m=h.get(e);if(m)return m==t;r|=2,h.set(e,t);var g=a(p(e),p(t),r,c,d,h);return h.delete(e),g;case"[object Symbol]":if(u)return u.call(e)==u.call(t)}return!1}},function(e,t,n){var r=n(67).Uint8Array;e.exports=r},function(e,t){e.exports=function(e){var t=-1,n=Array(e.size);return e.forEach((function(e,r){n[++t]=[r,e]})),n}},function(e,t){e.exports=function(e){var t=-1,n=Array(e.size);return e.forEach((function(e){n[++t]=e})),n}},function(e,t,n){var r=n(788),i=Object.prototype.hasOwnProperty;e.exports=function(e,t,n,o,a,s){var l=1&n,c=r(e),u=c.length;if(u!=r(t).length&&!l)return!1;for(var d=u;d--;){var h=c[d];if(!(l?h in t:i.call(t,h)))return!1}var p=s.get(e),f=s.get(t);if(p&&f)return p==t&&f==e;var m=!0;s.set(e,t),s.set(t,e);for(var g=l;++d<u;){var v=e[h=c[d]],y=t[h];if(o)var _=l?o(y,v,h,t,e,s):o(v,y,h,e,t,s);if(!(void 0===_?v===y||a(v,y,n,o,s):_)){m=!1;break}g||(g="constructor"==h)}if(m&&!g){var b=e.constructor,M=t.constructor;b==M||!("constructor"in e)||!("constructor"in t)||"function"==typeof b&&b instanceof b&&"function"==typeof M&&M instanceof M||(m=!1)}return s.delete(e),s.delete(t),m}},function(e,t,n){var r=n(789),i=n(791),o=n(794);e.exports=function(e){return r(e,o,i)}},function(e,t,n){var r=n(790),i=n(179);e.exports=function(e,t,n){var o=t(e);return i(e)?o:r(o,n(e))}},function(e,t){e.exports=function(e,t){for(var n=-1,r=t.length,i=e.length;++n<r;)e[i+n]=t[n];return e}},function(e,t,n){var r=n(792),i=n(793),o=Object.prototype.propertyIsEnumerable,a=Object.getOwnPropertySymbols,s=a?function(e){return null==e?[]:(e=Object(e),r(a(e),(function(t){return o.call(e,t)})))}:i;e.exports=s},function(e,t){e.exports=function(e,t){for(var n=-1,r=null==e?0:e.length,i=0,o=[];++n<r;){var a=e[n];t(a,n,e)&&(o[i++]=a)}return o}},function(e,t){e.exports=function(){return[]}},function(e,t,n){var r=n(795),i=n(804),o=n(807);e.exports=function(e){return o(e)?r(e):i(e)}},function(e,t,n){var r=n(796),i=n(797),o=n(179),a=n(409),s=n(800),l=n(410),c=Object.prototype.hasOwnProperty;e.exports=function(e,t){var n=o(e),u=!n&&i(e),d=!n&&!u&&a(e),h=!n&&!u&&!d&&l(e),p=n||u||d||h,f=p?r(e.length,String):[],m=f.length;for(var g in e)!t&&!c.call(e,g)||p&&("length"==g||d&&("offset"==g||"parent"==g)||h&&("buffer"==g||"byteLength"==g||"byteOffset"==g)||s(g,m))||f.push(g);return f}},function(e,t){e.exports=function(e,t){for(var n=-1,r=Array(e);++n<e;)r[n]=t(n);return r}},function(e,t,n){var r=n(798),i=n(106),o=Object.prototype,a=o.hasOwnProperty,s=o.propertyIsEnumerable,l=r(function(){return arguments}())?r:function(e){return i(e)&&a.call(e,"callee")&&!s.call(e,"callee")};e.exports=l},function(e,t,n){var r=n(105),i=n(106);e.exports=function(e){return i(e)&&"[object Arguments]"==r(e)}},function(e,t){e.exports=function(){return!1}},function(e,t){var n=/^(?:0|[1-9]\d*)$/;e.exports=function(e,t){var r=typeof e;return!!(t=null==t?9007199254740991:t)&&("number"==r||"symbol"!=r&&n.test(e))&&e>-1&&e%1==0&&e<t}},function(e,t,n){var r=n(105),i=n(411),o=n(106),a={};a["[object Float32Array]"]=a["[object Float64Array]"]=a["[object Int8Array]"]=a["[object Int16Array]"]=a["[object Int32Array]"]=a["[object Uint8Array]"]=a["[object Uint8ClampedArray]"]=a["[object Uint16Array]"]=a["[object Uint32Array]"]=!0,a["[object Arguments]"]=a["[object Array]"]=a["[object ArrayBuffer]"]=a["[object Boolean]"]=a["[object DataView]"]=a["[object Date]"]=a["[object Error]"]=a["[object Function]"]=a["[object Map]"]=a["[object Number]"]=a["[object Object]"]=a["[object RegExp]"]=a["[object Set]"]=a["[object String]"]=a["[object WeakMap]"]=!1,e.exports=function(e){return o(e)&&i(e.length)&&!!a[r(e)]}},function(e,t){e.exports=function(e){return function(t){return e(t)}}},function(e,t,n){(function(e){var r=n(404),i=t&&!t.nodeType&&t,o=i&&"object"==typeof e&&e&&!e.nodeType&&e,a=o&&o.exports===i&&r.process,s=function(){try{var e=o&&o.require&&o.require("util").types;return e||a&&a.binding&&a.binding("util")}catch(e){}}();e.exports=s}).call(this,n(151)(e))},function(e,t,n){var r=n(805),i=n(806),o=Object.prototype.hasOwnProperty;e.exports=function(e){if(!r(e))return i(e);var t=[];for(var n in Object(e))o.call(e,n)&&"constructor"!=n&&t.push(n);return t}},function(e,t){var n=Object.prototype;e.exports=function(e){var t=e&&e.constructor;return e===("function"==typeof t&&t.prototype||n)}},function(e,t,n){var r=n(412)(Object.keys,Object);e.exports=r},function(e,t,n){var r=n(403),i=n(411);e.exports=function(e){return null!=e&&i(e.length)&&!r(e)}},function(e,t,n){var r=n(809),i=n(177),o=n(810),a=n(811),s=n(812),l=n(105),c=n(406),u=c(r),d=c(i),h=c(o),p=c(a),f=c(s),m=l;(r&&"[object DataView]"!=m(new r(new ArrayBuffer(1)))||i&&"[object Map]"!=m(new i)||o&&"[object Promise]"!=m(o.resolve())||a&&"[object Set]"!=m(new a)||s&&"[object WeakMap]"!=m(new s))&&(m=function(e){var t=l(e),n="[object Object]"==t?e.constructor:void 0,r=n?c(n):"";if(r)switch(r){case u:return"[object DataView]";case d:return"[object Map]";case h:return"[object Promise]";case p:return"[object Set]";case f:return"[object WeakMap]"}return t}),e.exports=m},function(e,t,n){var r=n(94)(n(67),"DataView");e.exports=r},function(e,t,n){var r=n(94)(n(67),"Promise");e.exports=r},function(e,t,n){var r=n(94)(n(67),"Set");e.exports=r},function(e,t,n){var r=n(94)(n(67),"WeakMap");e.exports=r},function(e,t,n){var r=n(412)(Object.getPrototypeOf,Object);e.exports=r},function(e,t,n){var r,i,o;
/*!
 * jQuery UI Slider 1.13.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */!function(a){"use strict";i=[n(41),n(815),n(817),n(107),n(413)],void 0===(o="function"==typeof(r=function(e){return e.widget("ui.slider",e.ui.mouse,{version:"1.13.1",widgetEventPrefix:"slide",options:{animate:!1,classes:{"ui-slider":"ui-corner-all","ui-slider-handle":"ui-corner-all","ui-slider-range":"ui-corner-all ui-widget-header"},distance:0,max:100,min:0,orientation:"horizontal",range:!1,step:1,value:0,values:null,change:null,slide:null,start:null,stop:null},numPages:5,_create:function(){this._keySliding=!1,this._mouseSliding=!1,this._animateOff=!0,this._handleIndex=null,this._detectOrientation(),this._mouseInit(),this._calculateNewMax(),this._addClass("ui-slider ui-slider-"+this.orientation,"ui-widget ui-widget-content"),this._refresh(),this._animateOff=!1},_refresh:function(){this._createRange(),this._createHandles(),this._setupEvents(),this._refreshValue()},_createHandles:function(){var t,n,r=this.options,i=this.element.find(".ui-slider-handle"),o=[];for(n=r.values&&r.values.length||1,i.length>n&&(i.slice(n).remove(),i=i.slice(0,n)),t=i.length;t<n;t++)o.push("<span tabindex='0'></span>");this.handles=i.add(e(o.join("")).appendTo(this.element)),this._addClass(this.handles,"ui-slider-handle","ui-state-default"),this.handle=this.handles.eq(0),this.handles.each((function(t){e(this).data("ui-slider-handle-index",t).attr("tabIndex",0)}))},_createRange:function(){var t=this.options;t.range?(!0===t.range&&(t.values?t.values.length&&2!==t.values.length?t.values=[t.values[0],t.values[0]]:Array.isArray(t.values)&&(t.values=t.values.slice(0)):t.values=[this._valueMin(),this._valueMin()]),this.range&&this.range.length?(this._removeClass(this.range,"ui-slider-range-min ui-slider-range-max"),this.range.css({left:"",bottom:""})):(this.range=e("<div>").appendTo(this.element),this._addClass(this.range,"ui-slider-range")),"min"!==t.range&&"max"!==t.range||this._addClass(this.range,"ui-slider-range-"+t.range)):(this.range&&this.range.remove(),this.range=null)},_setupEvents:function(){this._off(this.handles),this._on(this.handles,this._handleEvents),this._hoverable(this.handles),this._focusable(this.handles)},_destroy:function(){this.handles.remove(),this.range&&this.range.remove(),this._mouseDestroy()},_mouseCapture:function(t){var n,r,i,o,a,s,l,c=this,u=this.options;return!u.disabled&&(this.elementSize={width:this.element.outerWidth(),height:this.element.outerHeight()},this.elementOffset=this.element.offset(),n={x:t.pageX,y:t.pageY},r=this._normValueFromMouse(n),i=this._valueMax()-this._valueMin()+1,this.handles.each((function(t){var n=Math.abs(r-c.values(t));(i>n||i===n&&(t===c._lastChangedValue||c.values(t)===u.min))&&(i=n,o=e(this),a=t)})),!1!==this._start(t,a)&&(this._mouseSliding=!0,this._handleIndex=a,this._addClass(o,null,"ui-state-active"),o.trigger("focus"),s=o.offset(),l=!e(t.target).parents().addBack().is(".ui-slider-handle"),this._clickOffset=l?{left:0,top:0}:{left:t.pageX-s.left-o.width()/2,top:t.pageY-s.top-o.height()/2-(parseInt(o.css("borderTopWidth"),10)||0)-(parseInt(o.css("borderBottomWidth"),10)||0)+(parseInt(o.css("marginTop"),10)||0)},this.handles.hasClass("ui-state-hover")||this._slide(t,a,r),this._animateOff=!0,!0))},_mouseStart:function(){return!0},_mouseDrag:function(e){var t={x:e.pageX,y:e.pageY},n=this._normValueFromMouse(t);return this._slide(e,this._handleIndex,n),!1},_mouseStop:function(e){return this._removeClass(this.handles,null,"ui-state-active"),this._mouseSliding=!1,this._stop(e,this._handleIndex),this._change(e,this._handleIndex),this._handleIndex=null,this._clickOffset=null,this._animateOff=!1,!1},_detectOrientation:function(){this.orientation="vertical"===this.options.orientation?"vertical":"horizontal"},_normValueFromMouse:function(e){var t,n,r,i,o;return"horizontal"===this.orientation?(t=this.elementSize.width,n=e.x-this.elementOffset.left-(this._clickOffset?this._clickOffset.left:0)):(t=this.elementSize.height,n=e.y-this.elementOffset.top-(this._clickOffset?this._clickOffset.top:0)),(r=n/t)>1&&(r=1),r<0&&(r=0),"vertical"===this.orientation&&(r=1-r),i=this._valueMax()-this._valueMin(),o=this._valueMin()+r*i,this._trimAlignValue(o)},_uiHash:function(e,t,n){var r={handle:this.handles[e],handleIndex:e,value:void 0!==t?t:this.value()};return this._hasMultipleValues()&&(r.value=void 0!==t?t:this.values(e),r.values=n||this.values()),r},_hasMultipleValues:function(){return this.options.values&&this.options.values.length},_start:function(e,t){return this._trigger("start",e,this._uiHash(t))},_slide:function(e,t,n){var r,i=this.value(),o=this.values();this._hasMultipleValues()&&(r=this.values(t?0:1),i=this.values(t),2===this.options.values.length&&!0===this.options.range&&(n=0===t?Math.min(r,n):Math.max(r,n)),o[t]=n),n!==i&&!1!==this._trigger("slide",e,this._uiHash(t,n,o))&&(this._hasMultipleValues()?this.values(t,n):this.value(n))},_stop:function(e,t){this._trigger("stop",e,this._uiHash(t))},_change:function(e,t){this._keySliding||this._mouseSliding||(this._lastChangedValue=t,this._trigger("change",e,this._uiHash(t)))},value:function(e){return arguments.length?(this.options.value=this._trimAlignValue(e),this._refreshValue(),void this._change(null,0)):this._value()},values:function(e,t){var n,r,i;if(arguments.length>1)return this.options.values[e]=this._trimAlignValue(t),this._refreshValue(),void this._change(null,e);if(!arguments.length)return this._values();if(!Array.isArray(arguments[0]))return this._hasMultipleValues()?this._values(e):this.value();for(n=this.options.values,r=arguments[0],i=0;i<n.length;i+=1)n[i]=this._trimAlignValue(r[i]),this._change(null,i);this._refreshValue()},_setOption:function(e,t){var n,r=0;switch("range"===e&&!0===this.options.range&&("min"===t?(this.options.value=this._values(0),this.options.values=null):"max"===t&&(this.options.value=this._values(this.options.values.length-1),this.options.values=null)),Array.isArray(this.options.values)&&(r=this.options.values.length),this._super(e,t),e){case"orientation":this._detectOrientation(),this._removeClass("ui-slider-horizontal ui-slider-vertical")._addClass("ui-slider-"+this.orientation),this._refreshValue(),this.options.range&&this._refreshRange(t),this.handles.css("horizontal"===t?"bottom":"left","");break;case"value":this._animateOff=!0,this._refreshValue(),this._change(null,0),this._animateOff=!1;break;case"values":for(this._animateOff=!0,this._refreshValue(),n=r-1;n>=0;n--)this._change(null,n);this._animateOff=!1;break;case"step":case"min":case"max":this._animateOff=!0,this._calculateNewMax(),this._refreshValue(),this._animateOff=!1;break;case"range":this._animateOff=!0,this._refresh(),this._animateOff=!1}},_setOptionDisabled:function(e){this._super(e),this._toggleClass(null,"ui-state-disabled",!!e)},_value:function(){var e=this.options.value;return e=this._trimAlignValue(e)},_values:function(e){var t,n,r;if(arguments.length)return t=this.options.values[e],t=this._trimAlignValue(t);if(this._hasMultipleValues()){for(n=this.options.values.slice(),r=0;r<n.length;r+=1)n[r]=this._trimAlignValue(n[r]);return n}return[]},_trimAlignValue:function(e){if(e<=this._valueMin())return this._valueMin();if(e>=this._valueMax())return this._valueMax();var t=this.options.step>0?this.options.step:1,n=(e-this._valueMin())%t,r=e-n;return 2*Math.abs(n)>=t&&(r+=n>0?t:-t),parseFloat(r.toFixed(5))},_calculateNewMax:function(){var e=this.options.max,t=this._valueMin(),n=this.options.step;(e=Math.round((e-t)/n)*n+t)>this.options.max&&(e-=n),this.max=parseFloat(e.toFixed(this._precision()))},_precision:function(){var e=this._precisionOf(this.options.step);return null!==this.options.min&&(e=Math.max(e,this._precisionOf(this.options.min))),e},_precisionOf:function(e){var t=e.toString(),n=t.indexOf(".");return-1===n?0:t.length-n-1},_valueMin:function(){return this.options.min},_valueMax:function(){return this.max},_refreshRange:function(e){"vertical"===e&&this.range.css({width:"",left:""}),"horizontal"===e&&this.range.css({height:"",bottom:""})},_refreshValue:function(){var t,n,r,i,o,a=this.options.range,s=this.options,l=this,c=!this._animateOff&&s.animate,u={};this._hasMultipleValues()?this.handles.each((function(r){n=(l.values(r)-l._valueMin())/(l._valueMax()-l._valueMin())*100,u["horizontal"===l.orientation?"left":"bottom"]=n+"%",e(this).stop(1,1)[c?"animate":"css"](u,s.animate),!0===l.options.range&&("horizontal"===l.orientation?(0===r&&l.range.stop(1,1)[c?"animate":"css"]({left:n+"%"},s.animate),1===r&&l.range[c?"animate":"css"]({width:n-t+"%"},{queue:!1,duration:s.animate})):(0===r&&l.range.stop(1,1)[c?"animate":"css"]({bottom:n+"%"},s.animate),1===r&&l.range[c?"animate":"css"]({height:n-t+"%"},{queue:!1,duration:s.animate}))),t=n})):(r=this.value(),i=this._valueMin(),o=this._valueMax(),n=o!==i?(r-i)/(o-i)*100:0,u["horizontal"===this.orientation?"left":"bottom"]=n+"%",this.handle.stop(1,1)[c?"animate":"css"](u,s.animate),"min"===a&&"horizontal"===this.orientation&&this.range.stop(1,1)[c?"animate":"css"]({width:n+"%"},s.animate),"max"===a&&"horizontal"===this.orientation&&this.range.stop(1,1)[c?"animate":"css"]({width:100-n+"%"},s.animate),"min"===a&&"vertical"===this.orientation&&this.range.stop(1,1)[c?"animate":"css"]({height:n+"%"},s.animate),"max"===a&&"vertical"===this.orientation&&this.range.stop(1,1)[c?"animate":"css"]({height:100-n+"%"},s.animate))},_handleEvents:{keydown:function(t){var n,r,i,o=e(t.target).data("ui-slider-handle-index");switch(t.keyCode){case e.ui.keyCode.HOME:case e.ui.keyCode.END:case e.ui.keyCode.PAGE_UP:case e.ui.keyCode.PAGE_DOWN:case e.ui.keyCode.UP:case e.ui.keyCode.RIGHT:case e.ui.keyCode.DOWN:case e.ui.keyCode.LEFT:if(t.preventDefault(),!this._keySliding&&(this._keySliding=!0,this._addClass(e(t.target),null,"ui-state-active"),!1===this._start(t,o)))return}switch(i=this.options.step,n=r=this._hasMultipleValues()?this.values(o):this.value(),t.keyCode){case e.ui.keyCode.HOME:r=this._valueMin();break;case e.ui.keyCode.END:r=this._valueMax();break;case e.ui.keyCode.PAGE_UP:r=this._trimAlignValue(n+(this._valueMax()-this._valueMin())/this.numPages);break;case e.ui.keyCode.PAGE_DOWN:r=this._trimAlignValue(n-(this._valueMax()-this._valueMin())/this.numPages);break;case e.ui.keyCode.UP:case e.ui.keyCode.RIGHT:if(n===this._valueMax())return;r=this._trimAlignValue(n+i);break;case e.ui.keyCode.DOWN:case e.ui.keyCode.LEFT:if(n===this._valueMin())return;r=this._trimAlignValue(n-i)}this._slide(t,o,r)},keyup:function(t){var n=e(t.target).data("ui-slider-handle-index");this._keySliding&&(this._keySliding=!1,this._stop(t,n),this._change(t,n),this._removeClass(e(t.target),null,"ui-state-active"))}}})})?r.apply(t,i):r)||(e.exports=o)}()},function(e,t,n){var r,i,o;
/*!
 * jQuery UI Mouse 1.13.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */!function(a){"use strict";i=[n(41),n(816),n(107),n(413)],void 0===(o="function"==typeof(r=function(e){var t=!1;return e(document).on("mouseup",(function(){t=!1})),e.widget("ui.mouse",{version:"1.13.1",options:{cancel:"input, textarea, button, select, option",distance:1,delay:0},_mouseInit:function(){var t=this;this.element.on("mousedown."+this.widgetName,(function(e){return t._mouseDown(e)})).on("click."+this.widgetName,(function(n){if(!0===e.data(n.target,t.widgetName+".preventClickEvent"))return e.removeData(n.target,t.widgetName+".preventClickEvent"),n.stopImmediatePropagation(),!1})),this.started=!1},_mouseDestroy:function(){this.element.off("."+this.widgetName),this._mouseMoveDelegate&&this.document.off("mousemove."+this.widgetName,this._mouseMoveDelegate).off("mouseup."+this.widgetName,this._mouseUpDelegate)},_mouseDown:function(n){if(!t){this._mouseMoved=!1,this._mouseStarted&&this._mouseUp(n),this._mouseDownEvent=n;var r=this,i=1===n.which,o=!("string"!=typeof this.options.cancel||!n.target.nodeName)&&e(n.target).closest(this.options.cancel).length;return!(i&&!o&&this._mouseCapture(n))||(this.mouseDelayMet=!this.options.delay,this.mouseDelayMet||(this._mouseDelayTimer=setTimeout((function(){r.mouseDelayMet=!0}),this.options.delay)),this._mouseDistanceMet(n)&&this._mouseDelayMet(n)&&(this._mouseStarted=!1!==this._mouseStart(n),!this._mouseStarted)?(n.preventDefault(),!0):(!0===e.data(n.target,this.widgetName+".preventClickEvent")&&e.removeData(n.target,this.widgetName+".preventClickEvent"),this._mouseMoveDelegate=function(e){return r._mouseMove(e)},this._mouseUpDelegate=function(e){return r._mouseUp(e)},this.document.on("mousemove."+this.widgetName,this._mouseMoveDelegate).on("mouseup."+this.widgetName,this._mouseUpDelegate),n.preventDefault(),t=!0,!0))}},_mouseMove:function(t){if(this._mouseMoved){if(e.ui.ie&&(!document.documentMode||document.documentMode<9)&&!t.button)return this._mouseUp(t);if(!t.which)if(t.originalEvent.altKey||t.originalEvent.ctrlKey||t.originalEvent.metaKey||t.originalEvent.shiftKey)this.ignoreMissingWhich=!0;else if(!this.ignoreMissingWhich)return this._mouseUp(t)}return(t.which||t.button)&&(this._mouseMoved=!0),this._mouseStarted?(this._mouseDrag(t),t.preventDefault()):(this._mouseDistanceMet(t)&&this._mouseDelayMet(t)&&(this._mouseStarted=!1!==this._mouseStart(this._mouseDownEvent,t),this._mouseStarted?this._mouseDrag(t):this._mouseUp(t)),!this._mouseStarted)},_mouseUp:function(n){this.document.off("mousemove."+this.widgetName,this._mouseMoveDelegate).off("mouseup."+this.widgetName,this._mouseUpDelegate),this._mouseStarted&&(this._mouseStarted=!1,n.target===this._mouseDownEvent.target&&e.data(n.target,this.widgetName+".preventClickEvent",!0),this._mouseStop(n)),this._mouseDelayTimer&&(clearTimeout(this._mouseDelayTimer),delete this._mouseDelayTimer),this.ignoreMissingWhich=!1,t=!1,n.preventDefault()},_mouseDistanceMet:function(e){return Math.max(Math.abs(this._mouseDownEvent.pageX-e.pageX),Math.abs(this._mouseDownEvent.pageY-e.pageY))>=this.options.distance},_mouseDelayMet:function(){return this.mouseDelayMet},_mouseStart:function(){},_mouseDrag:function(){},_mouseStop:function(){},_mouseCapture:function(){return!0}})})?r.apply(t,i):r)||(e.exports=o)}()},function(e,t,n){var r,i,o;!function(a){"use strict";i=[n(41),n(107)],void 0===(o="function"==typeof(r=function(e){return e.ui.ie=!!/msie [\w.]+/.exec(navigator.userAgent.toLowerCase())})?r.apply(t,i):r)||(e.exports=o)}()},function(e,t,n){var r,i,o;
/*!
 * jQuery UI Keycode 1.13.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */!function(a){"use strict";i=[n(41),n(107)],void 0===(o="function"==typeof(r=function(e){return e.ui.keyCode={BACKSPACE:8,COMMA:188,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,LEFT:37,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SPACE:32,TAB:9,UP:38}})?r.apply(t,i):r)||(e.exports=o)}()},function(e){e.exports=JSON.parse('{"name":"@jupyter-widgets/controls","version":"3.0.0","description":"Jupyter interactive widgets","repository":{"type":"git","url":"https://github.com/jupyter-widgets/ipywidgets.git"},"license":"BSD-3-Clause","author":"Project Jupyter","main":"lib/index.js","typings":"lib/index.d.ts","files":["lib/**/*.d.ts","lib/**/*.js","css/*.css","dist/"],"scripts":{"build":"npm run build:src && npm run build:css","build:css":"postcss --use postcss-import --use postcss-cssnext -o css/widgets.built.css css/widgets.css","build:src":"tsc","build:test":"tsc --project test && webpack --config test/webpack.conf.js","clean":"npm run clean:src","clean:src":"rimraf lib && rimraf tsconfig.tsbuildinfo","lint":"tslint --project tslint.json --format stylish","prepublish":"npm run clean && npm run build","test":"npm run test:unit","test:coverage":"npm run build:test && webpack --config test/webpack-cov.conf.js && karma start test/karma-cov.conf.js","test:unit":"npm run test:unit:firefox && npm run test:unit:chrome","test:unit:chrome":"npm run test:unit:default -- --browsers=Chrome","test:unit:default":"npm run build:test && karma start test/karma.conf.js --log-level debug","test:unit:firefox":"npm run test:unit:default -- --browsers=Firefox","test:unit:ie":"npm run test:unit:default -- --browsers=IE"},"dependencies":{"@jupyter-widgets/base":"^4.0.0","@lumino/algorithm":"^1.1.0","@lumino/domutils":"^1.1.0","@lumino/messaging":"^1.2.1","@lumino/signaling":"^1.2.0","@lumino/widgets":"^1.3.0","d3-format":"^1.3.0","jquery":"^3.1.1","jquery-ui":"^1.12.1","underscore":"^1.8.3"},"devDependencies":{"@jupyterlab/services":"^6.0.0","@types/d3-format":"^1.3.1","@types/expect.js":"^0.3.29","@types/mathjax":"^0.0.35","@types/mocha":"^5.2.7","@types/node":"^12.0.10","chai":"^4.0.0","css-loader":"^3.4.0","expect.js":"^0.3.1","file-loader":"^5.0.2","istanbul-instrumenter-loader":"^3.0.1","karma":"^4.1.0","karma-chrome-launcher":"^2.2.0","karma-coverage":"^1.1.2","karma-firefox-launcher":"^1.1.0","karma-ie-launcher":"^1.0.0","karma-mocha":"^1.3.0","karma-mocha-reporter":"^2.2.5","karma-webpack":"^4.0.2","mocha":"^6.1.4","npm-run-all":"^4.1.5","postcss-cli":"^6.1.2","postcss-cssnext":"^3.1.0","postcss-import":"^12.0.1","postcss-loader":"^3.0.0","rimraf":"^2.6.1","sinon":"^7.3.2","sinon-chai":"^3.3.0","style-loader":"^1.1.2","tslint":"^5.20.1","typescript":"~3.7.4","url-loader":"^3.0.0","webpack":"^4.41.5"},"gitHead":"8ec6746db708fc084102cabe34f706c204098009"}')},function(e,t,n){"use strict";const r=(e,...t)=>new Promise(n=>{n(e(...t))});e.exports=r,e.exports.default=r},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.HandlerList=void 0;var a=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.register=function(e){return this.add(e,e.priority)},t.prototype.unregister=function(e){this.remove(e)},t.prototype.handlesDocument=function(e){var t,n;try{for(var r=o(this),i=r.next();!i.done;i=r.next()){var a=i.value.item;if(a.handlesDocument(e))return a}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}throw new Error("Can't find handler for document")},t.prototype.document=function(e,t){return void 0===t&&(t=null),this.handlesDocument(e).create(e,t)},t}(n(108).PrioritizedList);t.HandlerList=a},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.FindTeX=void 0;var a=n(822),s=n(62),l=n(109),c=function(e){function t(t){var n=e.call(this,t)||this;return n.getPatterns(),n}return i(t,e),t.prototype.getPatterns=function(){var e=this,t=this.options,n=[],r=[],i=[];this.end={},this.env=this.sub=0;var o=1;t.inlineMath.forEach((function(t){return e.addPattern(n,t,!1)})),t.displayMath.forEach((function(t){return e.addPattern(n,t,!0)})),n.length&&r.push(n.sort(s.sortLength).join("|")),t.processEnvironments&&(r.push("\\\\begin\\s*\\{([^}]*)\\}"),this.env=o,o++),t.processEscapes&&i.push("\\\\([\\\\$])"),t.processRefs&&i.push("(\\\\(?:eq)?ref\\s*\\{[^}]*\\})"),i.length&&(r.push("("+i.join("|")+")"),this.sub=o),this.start=new RegExp(r.join("|"),"g"),this.hasPatterns=r.length>0},t.prototype.addPattern=function(e,t,n){var r=o(t,2),i=r[0],a=r[1];e.push(s.quotePattern(i)),this.end[i]=[a,n,this.endPattern(a)]},t.prototype.endPattern=function(e,t){return new RegExp((t||s.quotePattern(e))+"|\\\\(?:[a-zA-Z]|.)|[{}]","g")},t.prototype.findEnd=function(e,t,n,r){for(var i,a=o(r,3),s=a[0],c=a[1],u=a[2],d=u.lastIndex=n.index+n[0].length,h=0;i=u.exec(e);){if((i[1]||i[0])===s&&0===h)return l.protoItem(n[0],e.substr(d,i.index-d),i[0],t,n.index,i.index+i[0].length,c);"{"===i[0]?h++:"}"===i[0]&&h&&h--}return null},t.prototype.findMathInString=function(e,t,n){var r,i;for(this.start.lastIndex=0;r=this.start.exec(n);){if(void 0!==r[this.env]&&this.env){var o="\\\\end\\s*(\\{"+s.quotePattern(r[this.env])+"\\})";(i=this.findEnd(n,t,r,["{"+r[this.env]+"}",!0,this.endPattern(null,o)]))&&(i.math=i.open+i.math+i.close,i.open=i.close="")}else if(void 0!==r[this.sub]&&this.sub){var a=r[this.sub];o=r.index+r[this.sub].length;i=2===a.length?l.protoItem("",a.substr(1),"",t,r.index,o):l.protoItem("",a,"",t,r.index,o,!1)}else i=this.findEnd(n,t,r,this.end[r[0]]);i&&(e.push(i),this.start.lastIndex=i.end.n)}},t.prototype.findMath=function(e){var t=[];if(this.hasPatterns)for(var n=0,r=e.length;n<r;n++)this.findMathInString(t,n,e[n]);return t},t.OPTIONS={inlineMath:[["\\(","\\)"]],displayMath:[["$$","$$"],["\\[","\\]"]],processEscapes:!0,processEnvironments:!0,processRefs:!0},t}(a.AbstractFindMath);t.FindTeX=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractFindMath=void 0;var r=n(47),i=function(){function e(e){var t=this.constructor;this.options=r.userOptions(r.defaultOptions({},t.OPTIONS),e)}return e.OPTIONS={},e}();t.AbstractFindMath=i},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0});var i,o=n(23),a=n(39);!function(e){e.cleanStretchy=function(e){var t,n,i=e.data;try{for(var o=r(i.getList("fixStretchy")),s=o.next();!s.done;s=o.next()){var l=s.value;if(a.default.getProperty(l,"fixStretchy")){var c=a.default.getForm(l);c&&c[3]&&c[3].stretchy&&a.default.setAttribute(l,"stretchy",!1);var u=l.parent;if(!(a.default.getTexClass(l)||c&&c[2])){var d=i.nodeFactory.create("node","TeXAtom",[l]);u.replaceChild(d,l),d.inheritAttributesFrom(l)}a.default.removeProperties(l,"fixStretchy")}}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}},e.cleanAttributes=function(e){e.data.root.walkTree((function(e,t){var n,i,o=e.attributes;if(o)try{for(var a=r(o.getExplicitNames()),s=a.next();!s.done;s=a.next()){var l=s.value;o.attributes[l]===e.attributes.getInherited(l)&&delete o.attributes[l]}}catch(e){n={error:e}}finally{try{s&&!s.done&&(i=a.return)&&i.call(a)}finally{if(n)throw n.error}}}),{})},e.combineRelations=function(e){var i,s,l,c,u=[];try{for(var d=r(e.data.getList("mo")),h=d.next();!h.done;h=d.next()){var p=h.value;if(!p.getProperty("relationsCombined")&&p.parent&&(!p.parent||a.default.isType(p.parent,"mrow"))&&a.default.getTexClass(p)===o.TEXCLASS.REL){for(var f=p.parent,m=void 0,g=f.childNodes,v=g.indexOf(p)+1,y=a.default.getProperty(p,"variantForm");v<g.length&&(m=g[v])&&a.default.isType(m,"mo")&&a.default.getTexClass(m)===o.TEXCLASS.REL;){if(y!==a.default.getProperty(m,"variantForm")||!n(p,m)){null==p.attributes.getExplicit("rspace")&&a.default.setAttribute(p,"rspace","0pt"),null==m.attributes.getExplicit("lspace")&&a.default.setAttribute(m,"lspace","0pt");break}a.default.appendChildren(p,a.default.getChildren(m)),t(["stretchy","rspace"],p,m);try{for(var _=(l=void 0,r(m.getPropertyNames())),b=_.next();!b.done;b=_.next()){var M=b.value;p.setProperty(M,m.getProperty(M))}}catch(e){l={error:e}}finally{try{b&&!b.done&&(c=_.return)&&c.call(_)}finally{if(l)throw l.error}}g.splice(v,1),u.push(m),m.parent=null,m.setProperty("relationsCombined",!0)}p.attributes.setInherited("form",p.getForms()[0])}}}catch(e){i={error:e}}finally{try{h&&!h.done&&(s=d.return)&&s.call(d)}finally{if(i)throw i.error}}e.data.removeFromList("mo",u)};var t=function(e,t,n){var r=t.attributes,i=n.attributes;e.forEach((function(e){var t=i.getExplicit(e);null!=t&&r.set(e,t)}))},n=function(e,t){var n,i,o=function(e,t){return e.getExplicitNames().filter((function(n){return n!==t&&("stretchy"!==n||e.getExplicit("stretchy"))}))},a=e.attributes,s=t.attributes,l=o(a,"lspace"),c=o(s,"rspace");if(l.length!==c.length)return!1;try{for(var u=r(l),d=u.next();!d.done;d=u.next()){var h=d.value;if(a.getExplicit(h)!==s.getExplicit(h))return!1}}catch(e){n={error:e}}finally{try{d&&!d.done&&(i=u.return)&&i.call(u)}finally{if(n)throw n.error}}return!0},i=function(e,t,n){var i,o,s=[];try{for(var l=r(e.getList("m"+t+n)),c=l.next();!c.done;c=l.next()){var u=c.value,d=u.childNodes;if(!d[u[t]]||!d[u[n]]){var h=u.parent,p=d[u[t]]?e.nodeFactory.create("node","m"+t,[d[u.base],d[u[t]]]):e.nodeFactory.create("node","m"+n,[d[u.base],d[u[n]]]);a.default.copyAttributes(u,p),h?h.replaceChild(p,u):e.root=p,s.push(u)}}}catch(e){i={error:e}}finally{try{c&&!c.done&&(o=l.return)&&o.call(l)}finally{if(i)throw i.error}}e.removeFromList("m"+t+n,s)};e.cleanSubSup=function(e){var t=e.data;t.error||(i(t,"sub","sup"),i(t,"under","over"))};var s=function(e,t,n){var i,o,s=[];try{for(var l=r(e.getList(t)),c=l.next();!c.done;c=l.next()){var u=c.value;if(!u.attributes.get("displaystyle")){var d=u.childNodes[u.base],h=d.coreMO();if(d.getProperty("movablelimits")&&!h.attributes.getExplicit("movablelimits")){var p=e.nodeFactory.create("node",n,u.childNodes);a.default.copyAttributes(u,p),u.parent?u.parent.replaceChild(p,u):e.root=p,s.push(u)}}}}catch(e){i={error:e}}finally{try{c&&!c.done&&(o=l.return)&&o.call(l)}finally{if(i)throw i.error}}e.removeFromList(t,s)};e.moveLimits=function(e){var t=e.data;s(t,"munderover","msubsup"),s(t,"munder","msub"),s(t,"mover","msup")},e.setInherited=function(e){e.data.root.setInheritedAttributes({},e.math.display,0,!1)}}(i||(i={})),t.default=i},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractEmptyNode=t.AbstractNode=void 0;var s=function(){function e(e,t,n){var r,i;void 0===t&&(t={}),void 0===n&&(n=[]),this.factory=e,this.parent=null,this.properties={},this.childNodes=[];try{for(var o=a(Object.keys(t)),s=o.next();!s.done;s=o.next()){var l=s.value;this.setProperty(l,t[l])}}catch(e){r={error:e}}finally{try{s&&!s.done&&(i=o.return)&&i.call(o)}finally{if(r)throw r.error}}n.length&&this.setChildren(n)}return Object.defineProperty(e.prototype,"kind",{get:function(){return"unknown"},enumerable:!1,configurable:!0}),e.prototype.setProperty=function(e,t){this.properties[e]=t},e.prototype.getProperty=function(e){return this.properties[e]},e.prototype.getPropertyNames=function(){return Object.keys(this.properties)},e.prototype.getAllProperties=function(){return this.properties},e.prototype.removeProperty=function(){for(var e,t,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];try{for(var i=a(n),o=i.next();!o.done;o=i.next()){var s=o.value;delete this.properties[s]}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}},e.prototype.isKind=function(e){return this.factory.nodeIsKind(this,e)},e.prototype.setChildren=function(e){var t,n;this.childNodes=[];try{for(var r=a(e),i=r.next();!i.done;i=r.next()){var o=i.value;this.appendChild(o)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}},e.prototype.appendChild=function(e){return this.childNodes.push(e),e.parent=this,e},e.prototype.replaceChild=function(e,t){var n=this.childIndex(t);return null!==n&&(this.childNodes[n]=e,e.parent=this),e},e.prototype.childIndex=function(e){var t=this.childNodes.indexOf(e);return-1===t?null:t},e.prototype.copy=function(){var e,t,n=this.factory.create(this.kind);n.properties=o({},this.properties);try{for(var r=a(this.childNodes||[]),i=r.next();!i.done;i=r.next()){var s=i.value;s&&n.appendChild(s.copy())}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}return n},e.prototype.findNodes=function(e){var t=[];return this.walkTree((function(n){n.isKind(e)&&t.push(n)})),t},e.prototype.walkTree=function(e,t){var n,r;e(this,t);try{for(var i=a(this.childNodes),o=i.next();!o.done;o=i.next()){var s=o.value;s&&s.walkTree(e,t)}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return t},e.prototype.toString=function(){return this.kind+"("+this.childNodes.join(",")+")"},e}();t.AbstractNode=s;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.setChildren=function(e){},t.prototype.appendChild=function(e){return e},t.prototype.replaceChild=function(e,t){return t},t.prototype.childIndex=function(e){return null},t.prototype.walkTree=function(e,t){return e(this,t),t},t.prototype.toString=function(){return this.kind},t}(s);t.AbstractEmptyNode=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.asyncLoad=void 0;var r=n(142);t.asyncLoad=function(e){return r.mathjax.asyncLoad?new Promise((function(t,n){var i=r.mathjax.asyncLoad(e);i instanceof Promise?i.then((function(e){return t(e)})).catch((function(e){return n(e)})):t(i)})):Promise.reject("Can't load '"+e+"': No asyncLoad method specified")}},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0});var a=n(95),s=n(181),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(a.BaseItem),c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.defaultKind="dummy",t.configuration=null,t}return o(t,e),t.DefaultStackItems=((i={})[l.prototype.kind]=l,i),t}(s.AbstractFactory);t.default=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(50),o=n(57),a=n(73),s=n(37),l=n(23),c=n(58);new r.RegExpMap("letter",a.default.variable,/[a-z]/i),new r.RegExpMap("digit",a.default.digit,/[0-9.,]/),new r.RegExpMap("command",a.default.controlSequence,/^\\/),new r.MacroMap("special",{"{":"Open","}":"Close","~":"Tilde","^":"Superscript",_:"Subscript"," ":"Space","\t":"Space","\r":"Space","\n":"Space","'":"Prime","%":"Comment","&":"Entry","#":"Hash"," ":"Space","’":"Prime"},o.default),new r.CharacterMap("mathchar0mi",a.default.mathchar0mi,{alpha:"α",beta:"β",gamma:"γ",delta:"δ",epsilon:"ϵ",zeta:"ζ",eta:"η",theta:"θ",iota:"ι",kappa:"κ",lambda:"λ",mu:"μ",nu:"ν",xi:"ξ",omicron:"ο",pi:"π",rho:"ρ",sigma:"σ",tau:"τ",upsilon:"υ",phi:"ϕ",chi:"χ",psi:"ψ",omega:"ω",varepsilon:"ε",vartheta:"ϑ",varpi:"ϖ",varrho:"ϱ",varsigma:"ς",varphi:"φ",S:["§",{mathvariant:i.TexConstant.Variant.NORMAL}],aleph:["ℵ",{mathvariant:i.TexConstant.Variant.NORMAL}],hbar:["ℏ",{variantForm:!0}],imath:"ı",jmath:"ȷ",ell:"ℓ",wp:["℘",{mathvariant:i.TexConstant.Variant.NORMAL}],Re:["ℜ",{mathvariant:i.TexConstant.Variant.NORMAL}],Im:["ℑ",{mathvariant:i.TexConstant.Variant.NORMAL}],partial:["∂",{mathvariant:i.TexConstant.Variant.ITALIC}],infty:["∞",{mathvariant:i.TexConstant.Variant.NORMAL}],prime:["′",{variantForm:!0}],emptyset:["∅",{mathvariant:i.TexConstant.Variant.NORMAL}],nabla:["∇",{mathvariant:i.TexConstant.Variant.NORMAL}],top:["⊤",{mathvariant:i.TexConstant.Variant.NORMAL}],bot:["⊥",{mathvariant:i.TexConstant.Variant.NORMAL}],angle:["∠",{mathvariant:i.TexConstant.Variant.NORMAL}],triangle:["△",{mathvariant:i.TexConstant.Variant.NORMAL}],backslash:["∖",{mathvariant:i.TexConstant.Variant.NORMAL}],forall:["∀",{mathvariant:i.TexConstant.Variant.NORMAL}],exists:["∃",{mathvariant:i.TexConstant.Variant.NORMAL}],neg:["¬",{mathvariant:i.TexConstant.Variant.NORMAL}],lnot:["¬",{mathvariant:i.TexConstant.Variant.NORMAL}],flat:["♭",{mathvariant:i.TexConstant.Variant.NORMAL}],natural:["♮",{mathvariant:i.TexConstant.Variant.NORMAL}],sharp:["♯",{mathvariant:i.TexConstant.Variant.NORMAL}],clubsuit:["♣",{mathvariant:i.TexConstant.Variant.NORMAL}],diamondsuit:["♢",{mathvariant:i.TexConstant.Variant.NORMAL}],heartsuit:["♡",{mathvariant:i.TexConstant.Variant.NORMAL}],spadesuit:["♠",{mathvariant:i.TexConstant.Variant.NORMAL}]}),new r.CharacterMap("mathchar0mo",a.default.mathchar0mo,{surd:"√",coprod:["∐",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigvee:["⋁",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigwedge:["⋀",{texClass:l.TEXCLASS.OP,movesupsub:!0}],biguplus:["⨄",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigcap:["⋂",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigcup:["⋃",{texClass:l.TEXCLASS.OP,movesupsub:!0}],int:["∫",{texClass:l.TEXCLASS.OP}],intop:["∫",{texClass:l.TEXCLASS.OP,movesupsub:!0,movablelimits:!0}],iint:["∬",{texClass:l.TEXCLASS.OP}],iiint:["∭",{texClass:l.TEXCLASS.OP}],prod:["∏",{texClass:l.TEXCLASS.OP,movesupsub:!0}],sum:["∑",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigotimes:["⨂",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigoplus:["⨁",{texClass:l.TEXCLASS.OP,movesupsub:!0}],bigodot:["⨀",{texClass:l.TEXCLASS.OP,movesupsub:!0}],oint:["∮",{texClass:l.TEXCLASS.OP}],bigsqcup:["⨆",{texClass:l.TEXCLASS.OP,movesupsub:!0}],smallint:["∫",{largeop:!1}],triangleleft:"◃",triangleright:"▹",bigtriangleup:"△",bigtriangledown:"▽",wedge:"∧",land:"∧",vee:"∨",lor:"∨",cap:"∩",cup:"∪",ddagger:"‡",dagger:"†",sqcap:"⊓",sqcup:"⊔",uplus:"⊎",amalg:"⨿",diamond:"⋄",bullet:"∙",wr:"≀",div:"÷",divsymbol:"÷",odot:["⊙",{largeop:!1}],oslash:["⊘",{largeop:!1}],otimes:["⊗",{largeop:!1}],ominus:["⊖",{largeop:!1}],oplus:["⊕",{largeop:!1}],mp:"∓",pm:"±",circ:"∘",bigcirc:"◯",setminus:"∖",cdot:"⋅",ast:"∗",times:"×",star:"⋆",propto:"∝",sqsubseteq:"⊑",sqsupseteq:"⊒",parallel:"∥",mid:"∣",dashv:"⊣",vdash:"⊢",leq:"≤",le:"≤",geq:"≥",ge:"≥",lt:"<",gt:">",succ:"≻",prec:"≺",approx:"≈",succeq:"⪰",preceq:"⪯",supset:"⊃",subset:"⊂",supseteq:"⊇",subseteq:"⊆",in:"∈",ni:"∋",notin:"∉",owns:"∋",gg:"≫",ll:"≪",sim:"∼",simeq:"≃",perp:"⊥",equiv:"≡",asymp:"≍",smile:"⌣",frown:"⌢",ne:"≠",neq:"≠",cong:"≅",doteq:"≐",bowtie:"⋈",models:"⊨",notChar:"⧸",Leftrightarrow:"⇔",Leftarrow:"⇐",Rightarrow:"⇒",leftrightarrow:"↔",leftarrow:"←",gets:"←",rightarrow:"→",to:["→",{accent:!1}],mapsto:"↦",leftharpoonup:"↼",leftharpoondown:"↽",rightharpoonup:"⇀",rightharpoondown:"⇁",nearrow:"↗",searrow:"↘",nwarrow:"↖",swarrow:"↙",rightleftharpoons:"⇌",hookrightarrow:"↪",hookleftarrow:"↩",longleftarrow:"⟵",Longleftarrow:"⟸",longrightarrow:"⟶",Longrightarrow:"⟹",Longleftrightarrow:"⟺",longleftrightarrow:"⟷",longmapsto:"⟼",ldots:"…",cdots:"⋯",vdots:"⋮",ddots:"⋱",dotsc:"…",dotsb:"⋯",dotsm:"⋯",dotsi:"⋯",dotso:"…",ldotp:[".",{texClass:l.TEXCLASS.PUNCT}],cdotp:["⋅",{texClass:l.TEXCLASS.PUNCT}],colon:[":",{texClass:l.TEXCLASS.PUNCT}]}),new r.CharacterMap("mathchar7",a.default.mathchar7,{Gamma:"Γ",Delta:"Δ",Theta:"Θ",Lambda:"Λ",Xi:"Ξ",Pi:"Π",Sigma:"Σ",Upsilon:"Υ",Phi:"Φ",Psi:"Ψ",Omega:"Ω",_:"_","#":"#",$:"$","%":"%","&":"&",And:"&"}),new r.DelimiterMap("delimiter",a.default.delimiter,{"(":"(",")":")","[":"[","]":"]","<":"⟨",">":"⟩","\\lt":"⟨","\\gt":"⟩","/":"/","|":["|",{texClass:l.TEXCLASS.ORD}],".":"","\\\\":"\\","\\lmoustache":"⎰","\\rmoustache":"⎱","\\lgroup":"⟮","\\rgroup":"⟯","\\arrowvert":"⏐","\\Arrowvert":"‖","\\bracevert":"⎪","\\Vert":["‖",{texClass:l.TEXCLASS.ORD}],"\\|":["‖",{texClass:l.TEXCLASS.ORD}],"\\vert":["|",{texClass:l.TEXCLASS.ORD}],"\\uparrow":"↑","\\downarrow":"↓","\\updownarrow":"↕","\\Uparrow":"⇑","\\Downarrow":"⇓","\\Updownarrow":"⇕","\\backslash":"\\","\\rangle":"⟩","\\langle":"⟨","\\rbrace":"}","\\lbrace":"{","\\}":"}","\\{":"{","\\rceil":"⌉","\\lceil":"⌈","\\rfloor":"⌋","\\lfloor":"⌊","\\lbrack":"[","\\rbrack":"]"}),new r.CommandMap("macros",{displaystyle:["SetStyle","D",!0,0],textstyle:["SetStyle","T",!1,0],scriptstyle:["SetStyle","S",!1,1],scriptscriptstyle:["SetStyle","SS",!1,2],rm:["SetFont",i.TexConstant.Variant.NORMAL],mit:["SetFont",i.TexConstant.Variant.ITALIC],oldstyle:["SetFont",i.TexConstant.Variant.OLDSTYLE],cal:["SetFont",i.TexConstant.Variant.CALLIGRAPHIC],it:["SetFont",i.TexConstant.Variant.MATHITALIC],bf:["SetFont",i.TexConstant.Variant.BOLD],bbFont:["SetFont",i.TexConstant.Variant.DOUBLESTRUCK],scr:["SetFont",i.TexConstant.Variant.SCRIPT],frak:["SetFont",i.TexConstant.Variant.FRAKTUR],sf:["SetFont",i.TexConstant.Variant.SANSSERIF],tt:["SetFont",i.TexConstant.Variant.MONOSPACE],mathrm:["MathFont",i.TexConstant.Variant.NORMAL],mathup:["MathFont",i.TexConstant.Variant.NORMAL],mathnormal:["MathFont",""],mathbf:["MathFont",i.TexConstant.Variant.BOLD],mathbfup:["MathFont",i.TexConstant.Variant.BOLD],mathit:["MathFont",i.TexConstant.Variant.MATHITALIC],mathbfit:["MathFont",i.TexConstant.Variant.BOLDITALIC],mathbb:["MathFont",i.TexConstant.Variant.DOUBLESTRUCK],Bbb:["MathFont",i.TexConstant.Variant.DOUBLESTRUCK],mathfrak:["MathFont",i.TexConstant.Variant.FRAKTUR],mathbffrak:["MathFont",i.TexConstant.Variant.BOLDFRAKTUR],mathscr:["MathFont",i.TexConstant.Variant.SCRIPT],mathbfscr:["MathFont",i.TexConstant.Variant.BOLDSCRIPT],mathsf:["MathFont",i.TexConstant.Variant.SANSSERIF],mathsfup:["MathFont",i.TexConstant.Variant.SANSSERIF],mathbfsf:["MathFont",i.TexConstant.Variant.BOLDSANSSERIF],mathbfsfup:["MathFont",i.TexConstant.Variant.BOLDSANSSERIF],mathsfit:["MathFont",i.TexConstant.Variant.SANSSERIFITALIC],mathbfsfit:["MathFont",i.TexConstant.Variant.SANSSERIFBOLDITALIC],mathtt:["MathFont",i.TexConstant.Variant.MONOSPACE],mathcal:["MathFont",i.TexConstant.Variant.CALLIGRAPHIC],mathbfcal:["MathFont",i.TexConstant.Variant.BOLDCALLIGRAPHIC],symrm:["MathFont",i.TexConstant.Variant.NORMAL],symup:["MathFont",i.TexConstant.Variant.NORMAL],symnormal:["MathFont",""],symbf:["MathFont",i.TexConstant.Variant.BOLD],symbfup:["MathFont",i.TexConstant.Variant.BOLD],symit:["MathFont",i.TexConstant.Variant.ITALIC],symbfit:["MathFont",i.TexConstant.Variant.BOLDITALIC],symbb:["MathFont",i.TexConstant.Variant.DOUBLESTRUCK],symfrak:["MathFont",i.TexConstant.Variant.FRAKTUR],symbffrak:["MathFont",i.TexConstant.Variant.BOLDFRAKTUR],symscr:["MathFont",i.TexConstant.Variant.SCRIPT],symbfscr:["MathFont",i.TexConstant.Variant.BOLDSCRIPT],symsf:["MathFont",i.TexConstant.Variant.SANSSERIF],symsfup:["MathFont",i.TexConstant.Variant.SANSSERIF],symbfsf:["MathFont",i.TexConstant.Variant.BOLDSANSSERIF],symbfsfup:["MathFont",i.TexConstant.Variant.BOLDSANSSERIF],symsfit:["MathFont",i.TexConstant.Variant.SANSSERIFITALIC],symbfsfit:["MathFont",i.TexConstant.Variant.SANSSERIFBOLDITALIC],symtt:["MathFont",i.TexConstant.Variant.MONOSPACE],symcal:["MathFont",i.TexConstant.Variant.CALLIGRAPHIC],symbfcal:["MathFont",i.TexConstant.Variant.BOLDCALLIGRAPHIC],textrm:["HBox",null,i.TexConstant.Variant.NORMAL],textup:["HBox",null,i.TexConstant.Variant.NORMAL],textnormal:["HBox"],textit:["HBox",null,i.TexConstant.Variant.ITALIC],textbf:["HBox",null,i.TexConstant.Variant.BOLD],textsf:["HBox",null,i.TexConstant.Variant.SANSSERIF],texttt:["HBox",null,i.TexConstant.Variant.MONOSPACE],tiny:["SetSize",.5],Tiny:["SetSize",.6],scriptsize:["SetSize",.7],small:["SetSize",.85],normalsize:["SetSize",1],large:["SetSize",1.2],Large:["SetSize",1.44],LARGE:["SetSize",1.73],huge:["SetSize",2.07],Huge:["SetSize",2.49],arcsin:"NamedFn",arccos:"NamedFn",arctan:"NamedFn",arg:"NamedFn",cos:"NamedFn",cosh:"NamedFn",cot:"NamedFn",coth:"NamedFn",csc:"NamedFn",deg:"NamedFn",det:"NamedOp",dim:"NamedFn",exp:"NamedFn",gcd:"NamedOp",hom:"NamedFn",inf:"NamedOp",ker:"NamedFn",lg:"NamedFn",lim:"NamedOp",liminf:["NamedOp","lim&thinsp;inf"],limsup:["NamedOp","lim&thinsp;sup"],ln:"NamedFn",log:"NamedFn",max:"NamedOp",min:"NamedOp",Pr:"NamedOp",sec:"NamedFn",sin:"NamedFn",sinh:"NamedFn",sup:"NamedOp",tan:"NamedFn",tanh:"NamedFn",limits:["Limits",1],nolimits:["Limits",0],overline:["UnderOver","2015"],underline:["UnderOver","2015"],overbrace:["UnderOver","23DE",1],underbrace:["UnderOver","23DF",1],overparen:["UnderOver","23DC"],underparen:["UnderOver","23DD"],overrightarrow:["UnderOver","2192"],underrightarrow:["UnderOver","2192"],overleftarrow:["UnderOver","2190"],underleftarrow:["UnderOver","2190"],overleftrightarrow:["UnderOver","2194"],underleftrightarrow:["UnderOver","2194"],overset:"Overset",underset:"Underset",overunderset:"Overunderset",stackrel:["Macro","\\mathrel{\\mathop{#2}\\limits^{#1}}",2],stackbin:["Macro","\\mathbin{\\mathop{#2}\\limits^{#1}}",2],over:"Over",overwithdelims:"Over",atop:"Over",atopwithdelims:"Over",above:"Over",abovewithdelims:"Over",brace:["Over","{","}"],brack:["Over","[","]"],choose:["Over","(",")"],frac:"Frac",sqrt:"Sqrt",root:"Root",uproot:["MoveRoot","upRoot"],leftroot:["MoveRoot","leftRoot"],left:"LeftRight",right:"LeftRight",middle:"LeftRight",llap:"Lap",rlap:"Lap",raise:"RaiseLower",lower:"RaiseLower",moveleft:"MoveLeftRight",moveright:"MoveLeftRight",",":["Spacer",c.MATHSPACE.thinmathspace],":":["Spacer",c.MATHSPACE.mediummathspace],">":["Spacer",c.MATHSPACE.mediummathspace],";":["Spacer",c.MATHSPACE.thickmathspace],"!":["Spacer",c.MATHSPACE.negativethinmathspace],enspace:["Spacer",.5],quad:["Spacer",1],qquad:["Spacer",2],thinspace:["Spacer",c.MATHSPACE.thinmathspace],negthinspace:["Spacer",c.MATHSPACE.negativethinmathspace],hskip:"Hskip",hspace:"Hskip",kern:"Hskip",mskip:"Hskip",mspace:"Hskip",mkern:"Hskip",rule:"rule",Rule:["Rule"],Space:["Rule","blank"],nonscript:"Nonscript",big:["MakeBig",l.TEXCLASS.ORD,.85],Big:["MakeBig",l.TEXCLASS.ORD,1.15],bigg:["MakeBig",l.TEXCLASS.ORD,1.45],Bigg:["MakeBig",l.TEXCLASS.ORD,1.75],bigl:["MakeBig",l.TEXCLASS.OPEN,.85],Bigl:["MakeBig",l.TEXCLASS.OPEN,1.15],biggl:["MakeBig",l.TEXCLASS.OPEN,1.45],Biggl:["MakeBig",l.TEXCLASS.OPEN,1.75],bigr:["MakeBig",l.TEXCLASS.CLOSE,.85],Bigr:["MakeBig",l.TEXCLASS.CLOSE,1.15],biggr:["MakeBig",l.TEXCLASS.CLOSE,1.45],Biggr:["MakeBig",l.TEXCLASS.CLOSE,1.75],bigm:["MakeBig",l.TEXCLASS.REL,.85],Bigm:["MakeBig",l.TEXCLASS.REL,1.15],biggm:["MakeBig",l.TEXCLASS.REL,1.45],Biggm:["MakeBig",l.TEXCLASS.REL,1.75],mathord:["TeXAtom",l.TEXCLASS.ORD],mathop:["TeXAtom",l.TEXCLASS.OP],mathopen:["TeXAtom",l.TEXCLASS.OPEN],mathclose:["TeXAtom",l.TEXCLASS.CLOSE],mathbin:["TeXAtom",l.TEXCLASS.BIN],mathrel:["TeXAtom",l.TEXCLASS.REL],mathpunct:["TeXAtom",l.TEXCLASS.PUNCT],mathinner:["TeXAtom",l.TEXCLASS.INNER],vcenter:["TeXAtom",l.TEXCLASS.VCENTER],buildrel:"BuildRel",hbox:["HBox",0],text:"HBox",mbox:["HBox",0],fbox:"FBox",boxed:["Macro","\\fbox{$\\displaystyle{#1}$}",1],framebox:"FrameBox",strut:"Strut",mathstrut:["Macro","\\vphantom{(}"],phantom:"Phantom",vphantom:["Phantom",1,0],hphantom:["Phantom",0,1],smash:"Smash",acute:["Accent","00B4"],grave:["Accent","0060"],ddot:["Accent","00A8"],tilde:["Accent","007E"],bar:["Accent","00AF"],breve:["Accent","02D8"],check:["Accent","02C7"],hat:["Accent","005E"],vec:["Accent","2192"],dot:["Accent","02D9"],widetilde:["Accent","007E",1],widehat:["Accent","005E",1],matrix:"Matrix",array:"Matrix",pmatrix:["Matrix","(",")"],cases:["Matrix","{","","left left",null,".1em",null,!0],eqalign:["Matrix",null,null,"right left",c.em(c.MATHSPACE.thickmathspace),".5em","D"],displaylines:["Matrix",null,null,"center",null,".5em","D"],cr:"Cr","\\":"CrLaTeX",newline:["CrLaTeX",!0],hline:["HLine","solid"],hdashline:["HLine","dashed"],eqalignno:["Matrix",null,null,"right left",c.em(c.MATHSPACE.thickmathspace),".5em","D",null,"right"],leqalignno:["Matrix",null,null,"right left",c.em(c.MATHSPACE.thickmathspace),".5em","D",null,"left"],hfill:"HFill",hfil:"HFill",hfilll:"HFill",bmod:["Macro",'\\mmlToken{mo}[lspace="thickmathspace" rspace="thickmathspace"]{mod}'],pmod:["Macro","\\pod{\\mmlToken{mi}{mod}\\kern 6mu #1}",1],mod:["Macro","\\mathchoice{\\kern18mu}{\\kern12mu}{\\kern12mu}{\\kern12mu}\\mmlToken{mi}{mod}\\,\\,#1",1],pod:["Macro","\\mathchoice{\\kern18mu}{\\kern8mu}{\\kern8mu}{\\kern8mu}(#1)",1],iff:["Macro","\\;\\Longleftrightarrow\\;"],skew:["Macro","{{#2{#3\\mkern#1mu}\\mkern-#1mu}{}}",3],pmb:["Macro","\\rlap{#1}\\kern1px{#1}",1],TeX:["Macro","T\\kern-.14em\\lower.5ex{E}\\kern-.115em X"],LaTeX:["Macro","L\\kern-.325em\\raise.21em{\\scriptstyle{A}}\\kern-.17em\\TeX"]," ":["Macro","\\text{ }"],not:"Not",dots:"Dots",space:"Tilde"," ":"Tilde",begin:"BeginEnd",end:"BeginEnd",label:"HandleLabel",ref:"HandleRef",nonumber:"HandleNoTag",mathchoice:"MathChoice",mmlToken:"MmlToken"},o.default),new r.EnvironmentMap("environment",a.default.environment,{array:["AlignedArray"],equation:["Equation",null,!0],eqnarray:["EqnArray",null,!0,!0,"rcl",s.default.cols(0,c.MATHSPACE.thickmathspace),".5em"]},o.default),new r.CharacterMap("not_remap",null,{"←":"↚","→":"↛","↔":"↮","⇐":"⇍","⇒":"⇏","⇔":"⇎","∈":"∉","∋":"∌","∣":"∤","∥":"∦","∼":"≁","~":"≁","≃":"≄","≅":"≇","≈":"≉","≍":"≭","=":"≠","≡":"≢","<":"≮",">":"≯","≤":"≰","≥":"≱","≲":"≴","≳":"≵","≶":"≸","≷":"≹","≺":"⊀","≻":"⊁","⊂":"⊄","⊃":"⊅","⊆":"⊈","⊇":"⊉","⊢":"⊬","⊨":"⊭","⊩":"⊮","⊫":"⊯","≼":"⋠","≽":"⋡","⊑":"⋢","⊒":"⋣","⊲":"⋪","⊳":"⋫","⊴":"⋬","⊵":"⋭","∃":"∄"})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonOutputJax=void 0;var l=n(420),c=n(109),u=n(47),d=n(58),h=n(421),p=n(422),f=function(e){function t(t,n,r){void 0===t&&(t=null),void 0===n&&(n=null),void 0===r&&(r=null);var i=this,o=a(u.separateOptions(t,r.OPTIONS),2),s=o[0],l=o[1];return(i=e.call(this,s)||this).factory=i.options.wrapperFactory||new n,i.factory.jax=i,i.cssStyles=i.options.cssStyles||new p.CssStyles,i.font=i.options.font||new r(l),i.unknownCache=new Map,i}return i(t,e),t.prototype.typeset=function(e,t){this.setDocument(t);var n=this.createNode();return this.toDOM(e,n,t),n},t.prototype.createNode=function(){var e=this.constructor.NAME;return this.html("mjx-container",{class:"MathJax",jax:e})},t.prototype.setScale=function(e){var t=this.math.metrics.scale*this.options.scale;1!==t&&this.adaptor.setStyle(e,"fontSize",d.percent(t))},t.prototype.toDOM=function(e,t,n){void 0===n&&(n=null),this.setDocument(n),this.math=e,this.pxPerEm=e.metrics.ex/this.font.params.x_height,e.root.setTeXclass(null),this.setScale(t),this.nodeMap=new Map,this.container=t,this.processMath(e.root,t),this.nodeMap=null,this.executeFilters(this.postFilters,e,n,t)},t.prototype.getBBox=function(e,t){this.setDocument(t),this.math=e,e.root.setTeXclass(null),this.nodeMap=new Map;var n=this.factory.wrap(e.root).getBBox();return this.nodeMap=null,n},t.prototype.getMetrics=function(e){var t,n;this.setDocument(e);var r=this.adaptor,i=this.getMetricMaps(e);try{for(var o=s(e.math),a=o.next();!a.done;a=o.next()){var l=a.value,u=r.parent(l.start.node);if(l.state()<c.STATE.METRICS&&u){var d=i[l.display?1:0].get(u),h=d.em,p=d.ex,f=d.containerWidth,m=d.lineWidth,g=d.scale,v=d.family;l.setMetrics(h,p,f,m,g),this.options.mtextInheritFont&&(l.outputData.mtextFamily=v),this.options.merrorInheritFont&&(l.outputData.merrorFamily=v),l.state(c.STATE.METRICS)}}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}},t.prototype.getMetricsFor=function(e,t){var n=this.options.mtextInheritFont||this.options.merrorInheritFont,r=this.getTestElement(e,t),i=this.measureMetrics(r,n);return this.adaptor.remove(r),i},t.prototype.getMetricMaps=function(e){var t,n,r,i,o,a,l,u,d,h,p=this.adaptor,f=[new Map,new Map];try{for(var m=s(e.math),g=m.next();!g.done;g=m.next()){var v=g.value;if((E=p.parent(v.start.node))&&v.state()<c.STATE.METRICS){var y=f[v.display?1:0];y.has(E)||y.set(E,this.getTestElement(E,v.display))}}}catch(e){t={error:e}}finally{try{g&&!g.done&&(n=m.return)&&n.call(m)}finally{if(t)throw t.error}}var _=this.options.mtextInheritFont||this.options.merrorInheritFont,b=[new Map,new Map];try{for(var M=s(b.keys()),w=M.next();!w.done;w=M.next()){var A=w.value;try{for(var C=(o=void 0,s(f[A].keys())),x=C.next();!x.done;x=C.next()){var E=x.value;b[A].set(E,this.measureMetrics(f[A].get(E),_))}}catch(e){o={error:e}}finally{try{x&&!x.done&&(a=C.return)&&a.call(C)}finally{if(o)throw o.error}}}}catch(e){r={error:e}}finally{try{w&&!w.done&&(i=M.return)&&i.call(M)}finally{if(r)throw r.error}}try{for(var L=s(b.keys()),S=L.next();!S.done;S=L.next()){A=S.value;try{for(var T=(d=void 0,s(f[A].values())),O=T.next();!O.done;O=T.next()){E=O.value;p.remove(E)}}catch(e){d={error:e}}finally{try{O&&!O.done&&(h=T.return)&&h.call(T)}finally{if(d)throw d.error}}}}catch(e){l={error:e}}finally{try{S&&!S.done&&(u=L.return)&&u.call(L)}finally{if(l)throw l.error}}return b},t.prototype.getTestElement=function(e,t){var n=this.adaptor;if(!this.testInline){this.testInline=this.html("mjx-test",{style:{display:"inline-block",width:"100%","font-style":"normal","font-weight":"normal","font-size":"100%","font-size-adjust":"none","text-indent":0,"text-transform":"none","letter-spacing":"normal","word-spacing":"normal",overflow:"hidden",height:"1px","margin-right":"-1px"}},[this.html("mjx-left-box",{style:{display:"inline-block",width:0,float:"left"}}),this.html("mjx-ex-box",{style:{position:"absolute",overflow:"hidden",width:"1px",height:"60ex"}}),this.html("mjx-right-box",{style:{display:"inline-block",width:0,float:"right"}})]),this.testDisplay=n.clone(this.testInline),n.setStyle(this.testDisplay,"display","table"),n.setStyle(this.testDisplay,"margin-right",""),n.setStyle(n.firstChild(this.testDisplay),"display","none");var r=n.lastChild(this.testDisplay);n.setStyle(r,"display","table-cell"),n.setStyle(r,"width","10000em"),n.setStyle(r,"float","")}return n.append(e,n.clone(t?this.testDisplay:this.testInline))},t.prototype.measureMetrics=function(e,t){var n=this.adaptor,r=t?n.fontFamily(e):"",i=n.fontSize(e),o=a(n.nodeSize(n.childNode(e,1)),2),s=o[0],l=o[1],c=s?l/60:i*this.options.exFactor;return{em:i,ex:c,containerWidth:s?"table"===n.getStyle(e,"display")?n.nodeSize(n.lastChild(e))[0]-1:n.nodeBBox(n.lastChild(e)).left-n.nodeBBox(n.firstChild(e)).left-2:1e6,lineWidth:1e6,scale:Math.max(this.options.minScale,this.options.matchFontHeight?c/this.font.params.x_height/i:1),family:r}},t.prototype.styleSheet=function(e){var t,n;if(this.setDocument(e),this.cssStyles.clear(),this.cssStyles.addStyles(this.constructor.commonStyles),"getStyles"in e)try{for(var r=s(e.getStyles()),i=r.next();!i.done;i=r.next()){var o=i.value;this.cssStyles.addStyles(o)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return this.addWrapperStyles(this.cssStyles),this.addFontStyles(this.cssStyles),this.html("style",{id:"MJX-styles"},[this.text("\n"+this.cssStyles.cssText+"\n")])},t.prototype.addFontStyles=function(e){e.addStyles(this.font.styles)},t.prototype.addWrapperStyles=function(e){var t,n;try{for(var r=s(this.factory.getKinds()),i=r.next();!i.done;i=r.next()){var o=i.value;this.addClassStyles(this.factory.getNodeClass(o),e)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}},t.prototype.addClassStyles=function(e,t){t.addStyles(e.styles)},t.prototype.setDocument=function(e){e&&(this.document=e,this.adaptor.document=e.document)},t.prototype.html=function(e,t,n,r){return void 0===t&&(t={}),void 0===n&&(n=[]),this.adaptor.node(e,t,n,r)},t.prototype.text=function(e){return this.adaptor.text(e)},t.prototype.fixed=function(e,t){return void 0===t&&(t=3),Math.abs(e)<6e-4?"0":e.toFixed(t).replace(/\.?0+$/,"")},t.prototype.measureText=function(e,t,n){void 0===n&&(n=["",!1,!1]);var r=this.unknownText(e,t);if("-explicitFont"===t){var i=this.cssFontStyles(n);this.adaptor.setAttributes(r,{style:i})}return this.measureTextNodeWithCache(r,e,t,n)},t.prototype.measureTextNodeWithCache=function(e,t,n,r){void 0===r&&(r=["",!1,!1]),"-explicitFont"===n&&(n=[r[0],r[1]?"T":"F",r[2]?"T":"F",""].join("-")),this.unknownCache.has(n)||this.unknownCache.set(n,new Map);var i=this.unknownCache.get(n),o=i.get(t);if(o)return o;var a=this.measureTextNode(e);return i.set(t,a),a},t.prototype.measureXMLnode=function(e){var t=this.adaptor,n=this.html("mjx-xml-block",{style:{display:"inline-block"}},[t.clone(e)]),r=this.html("mjx-baseline",{style:{display:"inline-block",width:0,height:0}}),i=this.html("mjx-measure-xml",{style:{position:"absolute",display:"inline-block","font-family":"initial","line-height":"normal"}},[r,n]);t.append(t.parent(this.math.start.node),this.container),t.append(this.container,i);var o=this.math.metrics.em*this.math.metrics.scale,a=t.nodeBBox(n),s=a.left,l=a.right,c=a.bottom,u=a.top,d=(l-s)/o,h=(t.nodeBBox(r).top-u)/o,p=(c-u)/o-h;return t.remove(this.container),t.remove(i),{w:d,h:h,d:p}},t.prototype.cssFontStyles=function(e,t){void 0===t&&(t={});var n=a(e,3),r=n[0],i=n[1],o=n[2];return t["font-family"]=this.font.getFamily(r),i&&(t["font-style"]="italic"),o&&(t["font-weight"]="bold"),t},t.prototype.getFontData=function(e){return e||(e=new h.Styles),[this.font.getFamily(e.get("font-family")),"italic"===e.get("font-style"),"bold"===e.get("font-weight")]},t.NAME="Common",t.OPTIONS=o(o({},l.AbstractOutputJax.OPTIONS),{scale:1,minScale:.5,mtextInheritFont:!1,merrorInheritFont:!1,mtextFont:"",merrorFont:"serif",mathmlSpacing:!1,skipAttributes:{},exFactor:.5,displayAlign:"center",displayIndent:"0",wrapperFactory:null,font:null,cssStyles:null}),t.commonStyles={},t}(l.AbstractOutputJax);t.CommonOutputJax=f},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLWrapperFactory=void 0;var o=n(830),a=n(832),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.defaultNodes=a.CHTMLWrappers,t}(o.CommonWrapperFactory);t.CHTMLWrapperFactory=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonWrapperFactory=void 0;var o=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.jax=null,t}return i(t,e),Object.defineProperty(t.prototype,"Wrappers",{get:function(){return this.node},enumerable:!1,configurable:!0}),t.defaultNodes={},t}(n(831).AbstractWrapperFactory);t.CommonWrapperFactory=o},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractWrapperFactory=void 0;var s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.wrap=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return this.create.apply(this,a([e.kind,e],o(t)))},t}(n(181).AbstractFactory);t.AbstractWrapperFactory=s},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLWrappers=void 0;var i=n(40),o=n(835),a=n(837),s=n(839),l=n(841),c=n(843),u=n(845),d=n(847),h=n(849),p=n(851),f=n(854),m=n(855),g=n(857),v=n(435),y=n(860),_=n(185),b=n(864),M=n(865),w=n(867),A=n(870),C=n(871),x=n(873),E=n(874),L=n(876),S=n(878),T=n(880);t.CHTMLWrappers=((r={})[o.CHTMLmath.kind]=o.CHTMLmath,r[f.CHTMLmrow.kind]=f.CHTMLmrow,r[f.CHTMLinferredMrow.kind]=f.CHTMLinferredMrow,r[a.CHTMLmi.kind]=a.CHTMLmi,r[s.CHTMLmo.kind]=s.CHTMLmo,r[l.CHTMLmn.kind]=l.CHTMLmn,r[c.CHTMLms.kind]=c.CHTMLms,r[u.CHTMLmtext.kind]=u.CHTMLmtext,r[d.CHTMLmspace.kind]=d.CHTMLmspace,r[h.CHTMLmpadded.kind]=h.CHTMLmpadded,r[p.CHTMLmenclose.kind]=p.CHTMLmenclose,r[g.CHTMLmfrac.kind]=g.CHTMLmfrac,r[v.CHTMLmsqrt.kind]=v.CHTMLmsqrt,r[y.CHTMLmroot.kind]=y.CHTMLmroot,r[_.CHTMLmsub.kind]=_.CHTMLmsub,r[_.CHTMLmsup.kind]=_.CHTMLmsup,r[_.CHTMLmsubsup.kind]=_.CHTMLmsubsup,r[b.CHTMLmunder.kind]=b.CHTMLmunder,r[b.CHTMLmover.kind]=b.CHTMLmover,r[b.CHTMLmunderover.kind]=b.CHTMLmunderover,r[M.CHTMLmmultiscripts.kind]=M.CHTMLmmultiscripts,r[m.CHTMLmfenced.kind]=m.CHTMLmfenced,r[w.CHTMLmtable.kind]=w.CHTMLmtable,r[A.CHTMLmtr.kind]=A.CHTMLmtr,r[A.CHTMLmlabeledtr.kind]=A.CHTMLmlabeledtr,r[C.CHTMLmtd.kind]=C.CHTMLmtd,r[x.CHTMLmaction.kind]=x.CHTMLmaction,r[E.CHTMLmglyph.kind]=E.CHTMLmglyph,r[L.CHTMLsemantics.kind]=L.CHTMLsemantics,r[L.CHTMLannotation.kind]=L.CHTMLannotation,r[L.CHTMLannotationXML.kind]=L.CHTMLannotationXML,r[L.CHTMLxml.kind]=L.CHTMLxml,r[S.CHTMLTeXAtom.kind]=S.CHTMLTeXAtom,r[T.CHTMLTextNode.kind]=T.CHTMLTextNode,r[i.CHTMLWrapper.kind]=i.CHTMLWrapper,r)},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonWrapper=void 0;var l=n(834),c=n(23),u=n(62),d=n(58),h=n(421),p=n(74),f=n(111);function m(e,t){return e?t<2/18?0:2/18:t}var g=function(e){function t(t,n,r){void 0===r&&(r=null);var i=e.call(this,t,n)||this;return i.parent=null,i.removedStyles=null,i.styles=null,i.variant="",i.bboxComputed=!1,i.stretch=f.NOSTRETCH,i.font=null,i.parent=r,i.font=t.jax.font,i.bbox=p.BBox.zero(),i.getStyles(),i.getVariant(),i.getScale(),i.getSpace(),i.childNodes=n.childNodes.map((function(e){var t=i.wrap(e);return t.bbox.pwidth&&(n.notParent||n.isKind("math"))&&(i.bbox.pwidth=p.BBox.fullWidth),t})),i}return i(t,e),Object.defineProperty(t.prototype,"jax",{get:function(){return this.factory.jax},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"adaptor",{get:function(){return this.factory.jax.adaptor},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"metrics",{get:function(){return this.factory.jax.math.metrics},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"fixesPWidth",{get:function(){return!this.node.notParent&&!this.node.isToken},enumerable:!1,configurable:!0}),t.prototype.wrap=function(e,t){void 0===t&&(t=null);var n=this.factory.wrap(e,t||this);return t&&t.childNodes.push(n),this.jax.nodeMap.set(e,n),n},t.prototype.getBBox=function(e){if(void 0===e&&(e=!0),this.bboxComputed)return this.bbox;var t=e?this.bbox:p.BBox.zero();return this.computeBBox(t),this.bboxComputed=e,t},t.prototype.computeBBox=function(e,t){var n,r;void 0===t&&(t=!1),e.empty();try{for(var i=o(this.childNodes),a=i.next();!a.done;a=i.next()){var s=a.value;e.append(s.getBBox())}}catch(e){n={error:e}}finally{try{a&&!a.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}e.clean(),this.fixesPWidth&&this.setChildPWidths(t)&&this.computeBBox(e,!0)},t.prototype.setChildPWidths=function(e,t,n){var r,i;if(void 0===t&&(t=null),void 0===n&&(n=!0),e)return!1;n&&(this.bbox.pwidth="");var a=!1;try{for(var s=o(this.childNodes),l=s.next();!l.done;l=s.next()){var c=l.value,u=c.getBBox();u.pwidth&&c.setChildPWidths(e,null===t?u.w:t,n)&&(a=!0)}}catch(e){r={error:e}}finally{try{l&&!l.done&&(i=s.return)&&i.call(s)}finally{if(r)throw r.error}}return a},t.prototype.invalidateBBox=function(){this.bboxComputed&&(this.bboxComputed=!1,this.parent&&this.parent.invalidateBBox())},t.prototype.copySkewIC=function(e){var t=this.childNodes[0];(null==t?void 0:t.bbox.sk)&&(e.sk=t.bbox.sk),(null==t?void 0:t.bbox.dx)&&(e.dx=t.bbox.dx);var n=this.childNodes[this.childNodes.length-1];(null==n?void 0:n.bbox.ic)&&(e.ic=n.bbox.ic,e.w+=e.ic)},t.prototype.getStyles=function(){var e=this.node.attributes.getExplicit("style");if(e)for(var n=this.styles=new h.Styles(e),r=0,i=t.removeStyles.length;r<i;r++){var o=t.removeStyles[r];n.get(o)&&(this.removedStyles||(this.removedStyles={}),this.removedStyles[o]=n.get(o),n.set(o,""))}},t.prototype.getVariant=function(){if(this.node.isToken){var e=this.node.attributes,n=e.get("mathvariant");if(!e.getExplicit("mathvariant")){var r=e.getList("fontfamily","fontweight","fontstyle");if(this.removedStyles){var i=this.removedStyles;i.fontFamily&&(r.family=i.fontFamily),i.fontWeight&&(r.weight=i.fontWeight),i.fontStyle&&(r.style=i.fontStyle)}r.fontfamily&&(r.family=r.fontfamily),r.fontweight&&(r.weight=r.fontweight),r.fontstyle&&(r.style=r.fontstyle),r.weight&&r.weight.match(/^\d+$/)&&(r.weight=parseInt(r.weight)>600?"bold":"normal"),r.family?n=this.explicitVariant(r.family,r.weight,r.style):(this.node.getProperty("variantForm")&&(n="-tex-variant"),n=(t.BOLDVARIANTS[r.weight]||{})[n]||n,n=(t.ITALICVARIANTS[r.style]||{})[n]||n)}this.variant=n}},t.prototype.explicitVariant=function(e,t,n){var r=this.styles;return r||(r=this.styles=new h.Styles),r.set("fontFamily",e),t&&r.set("fontWeight",t),n&&r.set("fontStyle",n),"-explicitFont"},t.prototype.getScale=function(){var e=1,t=this.parent,n=t?t.bbox.scale:1,r=this.node.attributes,i=Math.min(r.get("scriptlevel"),2),o=r.get("fontsize"),a=this.node.isToken||this.node.isKind("mstyle")?r.get("mathsize"):r.getInherited("mathsize");if(0!==i){e=Math.pow(r.get("scriptsizemultiplier"),i);var s=this.length2em(r.get("scriptminsize"),.8,1);e<s&&(e=s)}this.removedStyles&&this.removedStyles.fontSize&&!o&&(o=this.removedStyles.fontSize),o&&!r.getExplicit("mathsize")&&(a=o),"1"!==a&&(e*=this.length2em(a,1,1)),this.bbox.scale=e,this.bbox.rscale=e/n},t.prototype.getSpace=function(){var e=this.isTopEmbellished(),t=this.node.hasSpacingAttributes();this.jax.options.mathmlSpacing||t?e&&this.getMathMLSpacing():this.getTeXSpacing(e,t)},t.prototype.getMathMLSpacing=function(){var e=this.node.coreMO(),t=e.coreParent(),n=t.parent;if(n&&n.isKind("mrow")&&1!==n.childNodes.length){var r=e.attributes,i=r.get("scriptlevel")>0;this.bbox.L=r.isSet("lspace")?Math.max(0,this.length2em(r.get("lspace"))):m(i,e.lspace),this.bbox.R=r.isSet("rspace")?Math.max(0,this.length2em(r.get("rspace"))):m(i,e.rspace);var o=n.childIndex(t);if(0!==o){var a=n.childNodes[o-1];if(a.isEmbellished){var s=this.jax.nodeMap.get(a).getBBox();s.R&&(this.bbox.L=Math.max(0,this.bbox.L-s.R))}}}},t.prototype.getTeXSpacing=function(e,t){if(!t){var n=this.node.texSpacing();n&&(this.bbox.L=this.length2em(n))}if(e||t){var r=this.node.coreMO().attributes;r.isSet("lspace")&&(this.bbox.L=Math.max(0,this.length2em(r.get("lspace")))),r.isSet("rspace")&&(this.bbox.R=Math.max(0,this.length2em(r.get("rspace"))))}},t.prototype.isTopEmbellished=function(){return this.node.isEmbellished&&!(this.node.parent&&this.node.parent.isEmbellished)},t.prototype.core=function(){return this.jax.nodeMap.get(this.node.core())},t.prototype.coreMO=function(){return this.jax.nodeMap.get(this.node.coreMO())},t.prototype.getText=function(){var e,t,n="";if(this.node.isToken)try{for(var r=o(this.node.childNodes),i=r.next();!i.done;i=r.next()){var a=i.value;a instanceof c.TextNode&&(n+=a.getText())}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}return n},t.prototype.canStretch=function(e){if(this.stretch=f.NOSTRETCH,this.node.isEmbellished){var t=this.core();t&&t.node!==this.node&&t.canStretch(e)&&(this.stretch=t.stretch)}return 0!==this.stretch.dir},t.prototype.getAlignShift=function(){var e,t=(e=this.node.attributes).getList.apply(e,s([],a(c.indentAttributes))),n=t.indentalign,r=t.indentshift,i=t.indentalignfirst,o=t.indentshiftfirst;return"indentalign"!==i&&(n=i),"auto"===n&&(n=this.jax.options.displayAlign),"indentshift"!==o&&(r=o),"auto"===r&&(r=this.jax.options.displayIndent,"right"!==n||r.match(/^\s*0[a-z]*\s*$/)||(r=("-"+r.trim()).replace(/^--/,""))),[n,this.length2em(r,this.metrics.containerWidth)]},t.prototype.getAlignX=function(e,t,n){return"right"===n?e-(t.w+t.R)*t.rscale:"left"===n?t.L*t.rscale:(e-t.w*t.rscale)/2},t.prototype.getAlignY=function(e,t,n,r,i){return"top"===i?e-n:"bottom"===i?r-t:"center"===i?(e-n-(t-r))/2:0},t.prototype.getWrapWidth=function(e){return this.childNodes[e].getBBox().w},t.prototype.getChildAlign=function(e){return"left"},t.prototype.percent=function(e){return d.percent(e)},t.prototype.em=function(e){return d.em(e)},t.prototype.px=function(e,t){return void 0===t&&(t=-d.BIGDIMEN),d.px(e,t,this.metrics.em)},t.prototype.length2em=function(e,t,n){return void 0===t&&(t=1),void 0===n&&(n=null),null===n&&(n=this.bbox.scale),d.length2em(e,t,n,this.jax.pxPerEm)},t.prototype.unicodeChars=function(e,t){void 0===t&&(t=this.variant);var n=u.unicodeChars(e),r=this.font.getVariant(t);if(r&&r.chars){var i=r.chars;n=n.map((function(e){return((i[e]||[])[3]||{}).smp||e}))}return n},t.prototype.remapChars=function(e){return e},t.prototype.mmlText=function(e){return this.node.factory.create("text").setText(e)},t.prototype.mmlNode=function(e,t,n){return void 0===t&&(t={}),void 0===n&&(n=[]),this.node.factory.create(e,t,n)},t.prototype.createMo=function(e){var t=this.node.factory,n=t.create("text").setText(e),r=t.create("mo",{stretchy:!0},[n]);r.inheritAttributesFrom(this.node);var i=this.wrap(r);return i.parent=this,i},t.prototype.getVariantChar=function(e,t){var n=this.font.getChar(e,t)||[0,0,0,{unknown:!0}];return 3===n.length&&(n[3]={}),n},t.kind="unknown",t.styles={},t.removeStyles=["fontSize","fontFamily","fontWeight","fontStyle","fontVariant","font"],t.skipAttributes={fontfamily:!0,fontsize:!0,fontweight:!0,fontstyle:!0,color:!0,background:!0,class:!0,href:!0,style:!0,xmlns:!0},t.BOLDVARIANTS={bold:{normal:"bold",italic:"bold-italic",fraktur:"bold-fraktur",script:"bold-script","sans-serif":"bold-sans-serif","sans-serif-italic":"sans-serif-bold-italic"},normal:{bold:"normal","bold-italic":"italic","bold-fraktur":"fraktur","bold-script":"script","bold-sans-serif":"sans-serif","sans-serif-bold-italic":"sans-serif-italic"}},t.ITALICVARIANTS={italic:{normal:"italic",bold:"bold-italic","sans-serif":"sans-serif-italic","bold-sans-serif":"sans-serif-bold-italic"},normal:{italic:"normal","bold-italic":"bold","sans-serif-italic":"sans-serif","sans-serif-bold-italic":"bold-sans-serif"}},t}(l.AbstractWrapper);t.CommonWrapper=g},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractWrapper=void 0;var r=function(){function e(e,t){this.factory=e,this.node=t}return Object.defineProperty(e.prototype,"kind",{get:function(){return this.node.kind},enumerable:!1,configurable:!0}),e.prototype.wrap=function(e){return this.factory.wrap(e)},e}();t.AbstractWrapper=r},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmath=void 0;var a=n(40),s=n(836),l=n(423),c=n(74),u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){e.prototype.toCHTML.call(this,t);var n=this.chtml,r=this.adaptor;"block"===this.node.attributes.get("display")?(r.setAttribute(n,"display","true"),r.setAttribute(t,"display","true"),this.handleDisplay(t)):this.handleInline(t),r.addClass(n,"MJX-TEX")},t.prototype.handleDisplay=function(e){var t=this.adaptor,n=o(this.getAlignShift(),2),r=n[0],i=n[1];if("center"!==r&&t.setAttribute(e,"justify",r),this.bbox.pwidth===c.BBox.fullWidth){if(t.setAttribute(e,"width","full"),this.jax.table){var a=this.jax.table.getBBox(),s=a.L,l=a.w,u=a.R;"right"===r?u=Math.max(u||-i,-i):"left"===r?s=Math.max(s||i,i):"center"===r&&(l+=2*Math.abs(i));var d=this.em(Math.max(0,s+l+u));t.setStyle(e,"min-width",d),t.setStyle(this.jax.table.chtml,"min-width",d)}}else this.setIndent(this.chtml,r,i)},t.prototype.handleInline=function(e){var t=this.adaptor,n=t.getStyle(this.chtml,"margin-right");n&&(t.setStyle(this.chtml,"margin-right",""),t.setStyle(e,"margin-right",n),t.setStyle(e,"width","0"))},t.prototype.setChildPWidths=function(t,n,r){return void 0===n&&(n=null),void 0===r&&(r=!0),!!this.parent&&e.prototype.setChildPWidths.call(this,t,n,r)},t.kind=l.MmlMath.prototype.kind,t.styles={"mjx-math":{"line-height":0,"text-align":"left","text-indent":0,"font-style":"normal","font-weight":"normal","font-size":"100%","font-size-adjust":"none","letter-spacing":"normal","word-wrap":"normal","word-spacing":"normal","white-space":"nowrap",direction:"ltr",padding:"1px 0"},'mjx-container[jax="CHTML"][display="true"]':{display:"block","text-align":"center",margin:"1em 0"},'mjx-container[jax="CHTML"][display="true"][width="full"]':{display:"flex"},'mjx-container[jax="CHTML"][display="true"] mjx-math':{padding:0},'mjx-container[jax="CHTML"][justify="left"]':{"text-align":"left"},'mjx-container[jax="CHTML"][justify="right"]':{"text-align":"right"}},t}(s.CommonMathMixin(a.CHTMLWrapper));t.CHTMLmath=u},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMathMixin=void 0,t.CommonMathMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.getWrapWidth=function(e){return this.parent?this.getBBox().w:this.metrics.containerWidth/this.jax.pxPerEm},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmi=void 0;var o=n(40),a=n(838),s=n(424),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=s.MmlMi.prototype.kind,t}(a.CommonMiMixin(o.CHTMLWrapper));t.CHTMLmi=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMiMixin=void 0,t.CommonMiMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.computeBBox=function(t,n){void 0===n&&(n=!1),e.prototype.computeBBox.call(this,t),this.copySkewIC(t)},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmo=void 0;var a=n(40),s=n(840),l=n(134),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n,r=this.node.attributes,i=r.get("symmetric")&&2!==this.stretch.dir,a=0!==this.stretch.dir;a&&null===this.size&&this.getStretchedVariant([]);var s=this.standardCHTMLnode(e);if(a&&this.size<0)this.stretchHTML(s);else{if(i||r.get("largeop")){var l=this.em(this.getCenterOffset());"0"!==l&&this.adaptor.setStyle(s,"verticalAlign",l)}this.node.getProperty("mathaccent")&&(this.adaptor.setStyle(s,"width","0"),this.adaptor.setStyle(s,"margin-left",this.em(this.getAccentOffset())));try{for(var c=o(this.childNodes),u=c.next();!u.done;u=c.next()){u.value.toCHTML(s)}}catch(e){t={error:e}}finally{try{u&&!u.done&&(n=c.return)&&n.call(c)}finally{if(t)throw t.error}}}},t.prototype.stretchHTML=function(e){var t=this.getText().codePointAt(0);this.font.delimUsage.add(t),this.childNodes[0].markUsed();var n=this.stretch,r=n.stretch,i=[];r[0]&&i.push(this.html("mjx-beg",{},[this.html("mjx-c")])),i.push(this.html("mjx-ext",{},[this.html("mjx-c")])),4===r.length&&i.push(this.html("mjx-mid",{},[this.html("mjx-c")]),this.html("mjx-ext",{},[this.html("mjx-c")])),r[2]&&i.push(this.html("mjx-end",{},[this.html("mjx-c")]));var o={},a=this.bbox,l=a.h,c=a.d,u=a.w;1===n.dir?(i.push(this.html("mjx-mark")),o.height=this.em(l+c),o.verticalAlign=this.em(-c)):o.width=this.em(u);var d=s.DirectionVH[n.dir],h={class:this.char(n.c||t),style:o},p=this.html("mjx-stretchy-"+d,h,i);this.adaptor.append(e,p)},t.kind=l.MmlMo.prototype.kind,t.styles={"mjx-stretchy-h":{display:"inline-table",width:"100%"},"mjx-stretchy-h > *":{display:"table-cell",width:0},"mjx-stretchy-h > * > mjx-c":{display:"inline-block",transform:"scalex(1.0000001)"},"mjx-stretchy-h > * > mjx-c::before":{display:"inline-block",width:"initial"},"mjx-stretchy-h > mjx-ext":{"/* IE */ overflow":"hidden","/* others */ overflow":"clip visible",width:"100%"},"mjx-stretchy-h > mjx-ext > mjx-c::before":{transform:"scalex(500)"},"mjx-stretchy-h > mjx-ext > mjx-c":{width:0},"mjx-stretchy-h > mjx-beg > mjx-c":{"margin-right":"-.1em"},"mjx-stretchy-h > mjx-end > mjx-c":{"margin-left":"-.1em"},"mjx-stretchy-v":{display:"inline-block"},"mjx-stretchy-v > *":{display:"block"},"mjx-stretchy-v > mjx-beg":{height:0},"mjx-stretchy-v > mjx-end > mjx-c":{display:"block"},"mjx-stretchy-v > * > mjx-c":{transform:"scaley(1.0000001)","transform-origin":"left center",overflow:"hidden"},"mjx-stretchy-v > mjx-ext":{display:"block",height:"100%","box-sizing":"border-box",border:"0px solid transparent","/* IE */ overflow":"hidden","/* others */ overflow":"visible clip"},"mjx-stretchy-v > mjx-ext > mjx-c::before":{width:"initial","box-sizing":"border-box"},"mjx-stretchy-v > mjx-ext > mjx-c":{transform:"scaleY(500) translateY(.075em)",overflow:"visible"},"mjx-mark":{display:"inline-block",height:"0px"}},t}(s.CommonMoMixin(a.CHTMLWrapper));t.CHTMLmo=c},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),a=this&&this.__assign||function(){return(a=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},s=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},l=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},c=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMoMixin=t.DirectionVH=void 0;var u=n(74),d=n(62),h=n(111);t.DirectionVH=((i={})[1]="v",i[2]="h",i),t.CommonMoMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,l([],s(t)))||this;return r.size=null,r.isAccent=r.node.isAccent,r}return o(t,e),t.prototype.computeBBox=function(e,t){if(void 0===t&&(t=!1),this.protoBBox(e),this.node.attributes.get("symmetric")&&2!==this.stretch.dir){var n=this.getCenterOffset(e);e.h+=n,e.d-=n}this.node.getProperty("mathaccent")&&(0===this.stretch.dir||this.size>=0)&&(e.w=0)},t.prototype.protoBBox=function(t){var n=0!==this.stretch.dir;n&&null===this.size&&this.getStretchedVariant([0]),n&&this.size<0||(e.prototype.computeBBox.call(this,t),this.copySkewIC(t))},t.prototype.getAccentOffset=function(){var e=u.BBox.empty();return this.protoBBox(e),-e.w/2},t.prototype.getCenterOffset=function(t){return void 0===t&&(t=null),t||(t=u.BBox.empty(),e.prototype.computeBBox.call(this,t)),(t.h+t.d)/2+this.font.params.axis_height-t.h},t.prototype.getVariant=function(){this.node.attributes.get("largeop")?this.variant=this.node.attributes.get("displaystyle")?"-largeop":"-smallop":this.node.attributes.getExplicit("mathvariant")||!1!==this.node.getProperty("pseudoscript")?e.prototype.getVariant.call(this):this.variant="-tex-variant"},t.prototype.canStretch=function(e){if(0!==this.stretch.dir)return this.stretch.dir===e;if(!this.node.attributes.get("stretchy"))return!1;var t=this.getText();if(1!==Array.from(t).length)return!1;var n=this.font.getDelimiter(t.codePointAt(0));return this.stretch=n&&n.dir===e?n:h.NOSTRETCH,0!==this.stretch.dir},t.prototype.getStretchedVariant=function(e,t){var n,r;if(void 0===t&&(t=!1),0!==this.stretch.dir){var i=this.getWH(e),o=this.getSize("minsize",0),s=this.getSize("maxsize",1/0),l=this.node.getProperty("mathaccent");i=Math.max(o,Math.min(s,i));var u=this.font.params.delimiterfactor/1e3,d=this.font.params.delimitershortfall,h=o||t?i:l?Math.min(i/u,i+d):Math.max(i*u,i-d),p=this.stretch,f=p.c||this.getText().codePointAt(0),m=0;if(p.sizes)try{for(var g=c(p.sizes),v=g.next();!v.done;v=g.next()){if(v.value>=h)return l&&m&&m--,this.variant=this.font.getSizeVariant(f,m),this.size=m,void(p.schar&&p.schar[m]&&(this.stretch=a(a({},this.stretch),{c:p.schar[m]})));m++}}catch(e){n={error:e}}finally{try{v&&!v.done&&(r=g.return)&&r.call(g)}finally{if(n)throw n.error}}p.stretch?(this.size=-1,this.invalidateBBox(),this.getStretchBBox(e,this.checkExtendedHeight(i,p),p)):(this.variant=this.font.getSizeVariant(f,m-1),this.size=m-1)}},t.prototype.getSize=function(e,t){var n=this.node.attributes;return n.isSet(e)&&(t=this.length2em(n.get(e),1,1)),t},t.prototype.getWH=function(e){if(0===e.length)return 0;if(1===e.length)return e[0];var t=s(e,2),n=t[0],r=t[1],i=this.font.params.axis_height;return this.node.attributes.get("symmetric")?2*Math.max(n-i,r+i):n+r},t.prototype.getStretchBBox=function(e,t,n){var r;n.hasOwnProperty("min")&&n.min>t&&(t=n.min);var i=s(n.HDW,3),o=i[0],a=i[1],l=i[2];1===this.stretch.dir?(o=(r=s(this.getBaseline(e,t,n),2))[0],a=r[1]):l=t,this.bbox.h=o,this.bbox.d=a,this.bbox.w=l},t.prototype.getBaseline=function(e,t,n){var r=2===e.length&&e[0]+e[1]===t,i=this.node.attributes.get("symmetric"),o=s(r?e:[t,0],2),a=o[0],l=o[1],c=s([a+l,0],2),u=c[0],d=c[1];if(i){var h=this.font.params.axis_height;r&&(u=2*Math.max(a-h,l+h)),d=u/2-h}else if(r)d=l;else{var p=s(n.HDW||[.75,.25],2),f=p[0],m=p[1];d=m*(u/(f+m))}return[u-d,d]},t.prototype.checkExtendedHeight=function(e,t){if(t.fullExt){var n=s(t.fullExt,2),r=n[0],i=n[1];e=i+Math.ceil(Math.max(0,e-i)/r)*r}return e},t.prototype.remapChars=function(e){var t=this.node.getProperty("primes");if(t)return d.unicodeChars(t);if(1===e.length){var n=this.node.coreParent().parent,r=this.isAccent&&!n.isKind("mrow")?"accent":"mo",i=this.font.getRemappedChar(r,e[0]);i&&(e=this.unicodeChars(i,this.variant))}return e},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmn=void 0;var o=n(40),a=n(842),s=n(425),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=s.MmlMn.prototype.kind,t}(a.CommonMnMixin(o.CHTMLWrapper));t.CHTMLmn=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMnMixin=void 0,t.CommonMnMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.remapChars=function(e){if(e.length){var t=this.font.getRemappedChar("mn",e[0]);if(t){var n=this.unicodeChars(t,this.variant);1===n.length?e[0]=n[0]:e=n.concat(e.slice(1))}}return e},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLms=void 0;var o=n(40),a=n(844),s=n(426),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=s.MmlMs.prototype.kind,t}(a.CommonMsMixin(o.CHTMLWrapper));t.CHTMLms=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMsMixin=void 0,t.CommonMsMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this,i=r.node.attributes,s=i.getList("lquote","rquote");return"monospace"!==r.variant&&(i.isSet("lquote")||'"'!==s.lquote||(s.lquote="“"),i.isSet("rquote")||'"'!==s.rquote||(s.rquote="”")),r.childNodes.unshift(r.createText(s.lquote)),r.childNodes.push(r.createText(s.rquote)),r}return i(t,e),t.prototype.createText=function(e){var t=this.wrap(this.mmlText(e));return t.parent=this,t},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmtext=void 0;var o=n(40),a=n(846),s=n(427),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=s.MmlMtext.prototype.kind,t}(a.CommonMtextMixin(o.CHTMLWrapper));t.CHTMLmtext=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMtextMixin=void 0,t.CommonMtextMixin=function(e){var t;return(t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.getVariant=function(){var t=this.jax.options,n=this.jax.math.outputData,r=(!!n.merrorFamily||!!t.merrorFont)&&this.node.Parent.isKind("merror");if(n.mtextFamily||t.mtextFont||r){var i=this.node.attributes.get("mathvariant"),o=this.constructor.INHERITFONTS[i]||this.jax.font.getCssFont(i),a=o[0]||(r?n.merrorFamily||t.merrorFont:n.mtextFamily||t.mtextFont);this.variant=this.explicitVariant(a,o[2]?"bold":"",o[1]?"italic":"")}else e.prototype.getVariant.call(this)},t}(e)).INHERITFONTS={normal:["",!1,!1],bold:["",!1,!0],italic:["",!0,!1],"bold-italic":["",!0,!0]},t}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmspace=void 0;var o=n(40),a=n(848),s=n(428),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e),n=this.getBBox(),r=n.w,i=n.h,o=n.d;r<0&&(this.adaptor.setStyle(t,"marginRight",this.em(r)),r=0),r&&this.adaptor.setStyle(t,"width",this.em(r)),(i=Math.max(0,i+o))&&this.adaptor.setStyle(t,"height",this.em(Math.max(0,i))),o&&this.adaptor.setStyle(t,"verticalAlign",this.em(-o))},t.kind=s.MmlMspace.prototype.kind,t}(a.CommonMspaceMixin(o.CHTMLWrapper));t.CHTMLmspace=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMspaceMixin=void 0,t.CommonMspaceMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.node.attributes;e.w=this.length2em(n.get("width"),0),e.h=this.length2em(n.get("height"),0),e.d=this.length2em(n.get("depth"),0)},t.prototype.handleVariant=function(){},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmpadded=void 0;var s=n(40),l=n(850),c=n(429),u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n,r=this.standardCHTMLnode(e),i=[],s={},l=o(this.getDimens(),9),c=l[2],u=l[3],d=l[4],h=l[5],p=l[6],f=l[7],m=l[8];if(h&&(s.width=this.em(c+h)),(u||d)&&(s.margin=this.em(u)+" 0 "+this.em(d)),p+m||f){s.position="relative";var g=this.html("mjx-rbox",{style:{left:this.em(p+m),top:this.em(-f),"max-width":s.width}});p+m&&this.childNodes[0].getBBox().pwidth&&(this.adaptor.setAttribute(g,"width","full"),this.adaptor.setStyle(g,"left",this.em(p))),i.push(g)}r=this.adaptor.append(r,this.html("mjx-block",{style:s},i));try{for(var v=a(this.childNodes),y=v.next();!y.done;y=v.next()){y.value.toCHTML(i[0]||r)}}catch(e){t={error:e}}finally{try{y&&!y.done&&(n=v.return)&&n.call(v)}finally{if(t)throw t.error}}},t.kind=c.MmlMpadded.prototype.kind,t.styles={"mjx-mpadded":{display:"inline-block"},"mjx-rbox":{display:"inline-block",position:"relative"}},t}(l.CommonMpaddedMixin(s.CHTMLWrapper));t.CHTMLmpadded=u},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMpaddedMixin=void 0,t.CommonMpaddedMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.getDimens=function(){var e=this.node.attributes.getList("width","height","depth","lspace","voffset"),t=this.childNodes[0].getBBox(),n=t.w,r=t.h,i=t.d,o=n,a=r,s=i,l=0,c=0,u=0;""!==e.width&&(n=this.dimen(e.width,t,"w",0)),""!==e.height&&(r=this.dimen(e.height,t,"h",0)),""!==e.depth&&(i=this.dimen(e.depth,t,"d",0)),""!==e.voffset&&(c=this.dimen(e.voffset,t)),""!==e.lspace&&(l=this.dimen(e.lspace,t));var d=this.node.attributes.get("data-align");return d&&(u=this.getAlignX(n,t,d)),[a,s,o,r-a,i-s,n-o,l,c,u]},t.prototype.dimen=function(e,t,n,r){void 0===n&&(n=""),void 0===r&&(r=null);var i=(e=String(e)).match(/width|height|depth/),o=i?t[i[0].charAt(0)]:n?t[n]:0,a=this.length2em(e,o)||0;return e.match(/^[-+]/)&&n&&(a+=o),null!=r&&(a=Math.max(r,a)),a},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=o(this.getDimens(),6),r=n[0],i=n[1],a=n[2],s=n[3],l=n[4],c=n[5];e.w=a+c,e.h=r+s,e.d=i+l,this.setChildPWidths(t,e.w)},t.prototype.getWrapWidth=function(e){return this.getBBox().w},t.prototype.getChildAlign=function(e){return this.node.attributes.get("data-align")||"left"},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmenclose=void 0;var s=n(40),l=n(852),c=n(853),u=n(430),d=n(58);function h(e,t){return Math.atan2(e,t).toFixed(3).replace(/\.?0+$/,"")}var p=h(c.ARROWDX,c.ARROWY),f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n,r,i,a=this.adaptor,s=this.standardCHTMLnode(e),l=a.append(s,this.html("mjx-box"));this.renderChild?this.renderChild(this,l):this.childNodes[0].toCHTML(l);try{for(var u=o(Object.keys(this.notations)),d=u.next();!d.done;d=u.next()){var h=d.value,p=this.notations[h];!p.renderChild&&p.renderer(this,l)}}catch(e){t={error:e}}finally{try{d&&!d.done&&(n=u.return)&&n.call(u)}finally{if(t)throw t.error}}var f=this.getPadding();try{for(var m=o(c.sideNames),g=m.next();!g.done;g=m.next()){var v=g.value,y=c.sideIndex[v];f[y]>0&&a.setStyle(l,"padding-"+v,this.em(f[y]))}}catch(e){r={error:e}}finally{try{g&&!g.done&&(i=m.return)&&i.call(m)}finally{if(r)throw r.error}}},t.prototype.arrow=function(e,t,n,r,i){void 0===r&&(r=""),void 0===i&&(i=0);var o=this.getBBox().w,a={width:this.em(e)};o!==e&&(a.left=this.em((o-e)/2)),t&&(a.transform="rotate("+this.fixed(t)+"rad)");var s=this.html("mjx-arrow",{style:a},[this.html("mjx-aline"),this.html("mjx-rthead"),this.html("mjx-rbhead")]);return n&&(this.adaptor.append(s,this.html("mjx-lthead")),this.adaptor.append(s,this.html("mjx-lbhead")),this.adaptor.setAttribute(s,"double","true")),this.adjustArrow(s,n),this.moveArrow(s,r,i),s},t.prototype.adjustArrow=function(e,t){var n=this,r=this.thickness,i=this.arrowhead;if(i.x!==c.ARROWX||i.y!==c.ARROWY||i.dx!==c.ARROWDX||r!==c.THICKNESS){var o=a([r*i.x,r*i.y].map((function(e){return n.em(e)})),2),s=o[0],l=o[1],u=h(i.dx,i.y),d=a(this.adaptor.childNodes(e),5),p=d[0],f=d[1],m=d[2],g=d[3],v=d[4];this.adjustHead(f,[l,"0","1px",s],u),this.adjustHead(m,["1px","0",l,s],"-"+u),this.adjustHead(g,[l,s,"1px","0"],"-"+u),this.adjustHead(v,["1px",s,l,"0"],u),this.adjustLine(p,r,i.x,t)}},t.prototype.adjustHead=function(e,t,n){e&&(this.adaptor.setStyle(e,"border-width",t.join(" ")),this.adaptor.setStyle(e,"transform","skewX("+n+"rad)"))},t.prototype.adjustLine=function(e,t,n,r){this.adaptor.setStyle(e,"borderTop",this.em(t)+" solid"),this.adaptor.setStyle(e,"top",this.em(-t/2)),this.adaptor.setStyle(e,"right",this.em(t*(n-1))),r&&this.adaptor.setStyle(e,"left",this.em(t*(n-1)))},t.prototype.moveArrow=function(e,t,n){if(n){var r=this.adaptor.getStyle(e,"transform");this.adaptor.setStyle(e,"transform","translate"+t+"("+this.em(-n)+")"+(r?" "+r:""))}},t.prototype.adjustBorder=function(e){return this.thickness!==c.THICKNESS&&this.adaptor.setStyle(e,"borderWidth",this.em(this.thickness)),e},t.prototype.adjustThickness=function(e){return this.thickness!==c.THICKNESS&&this.adaptor.setStyle(e,"strokeWidth",this.fixed(this.thickness)),e},t.prototype.fixed=function(e,t){return void 0===t&&(t=3),Math.abs(e)<6e-4?"0":e.toFixed(t).replace(/\.?0+$/,"")},t.prototype.em=function(t){return e.prototype.em.call(this,t)},t.kind=u.MmlMenclose.prototype.kind,t.styles={"mjx-menclose":{position:"relative"},"mjx-menclose > mjx-dstrike":{display:"inline-block",left:0,top:0,position:"absolute","border-top":c.SOLID,"transform-origin":"top left"},"mjx-menclose > mjx-ustrike":{display:"inline-block",left:0,bottom:0,position:"absolute","border-top":c.SOLID,"transform-origin":"bottom left"},"mjx-menclose > mjx-hstrike":{"border-top":c.SOLID,position:"absolute",left:0,right:0,bottom:"50%",transform:"translateY("+d.em(c.THICKNESS/2)+")"},"mjx-menclose > mjx-vstrike":{"border-left":c.SOLID,position:"absolute",top:0,bottom:0,right:"50%",transform:"translateX("+d.em(c.THICKNESS/2)+")"},"mjx-menclose > mjx-rbox":{position:"absolute",top:0,bottom:0,right:0,left:0,border:c.SOLID,"border-radius":d.em(c.THICKNESS+c.PADDING)},"mjx-menclose > mjx-cbox":{position:"absolute",top:0,bottom:0,right:0,left:0,border:c.SOLID,"border-radius":"50%"},"mjx-menclose > mjx-arrow":{position:"absolute",left:0,bottom:"50%",height:0,width:0},"mjx-menclose > mjx-arrow > *":{display:"block",position:"absolute","transform-origin":"bottom","border-left":d.em(c.THICKNESS*c.ARROWX)+" solid","border-right":0,"box-sizing":"border-box"},"mjx-menclose > mjx-arrow > mjx-aline":{left:0,top:d.em(-c.THICKNESS/2),right:d.em(c.THICKNESS*(c.ARROWX-1)),height:0,"border-top":d.em(c.THICKNESS)+" solid","border-left":0},"mjx-menclose > mjx-arrow[double] > mjx-aline":{left:d.em(c.THICKNESS*(c.ARROWX-1)),height:0},"mjx-menclose > mjx-arrow > mjx-rthead":{transform:"skewX("+p+"rad)",right:0,bottom:"-1px","border-bottom":"1px solid transparent","border-top":d.em(c.THICKNESS*c.ARROWY)+" solid transparent"},"mjx-menclose > mjx-arrow > mjx-rbhead":{transform:"skewX(-"+p+"rad)","transform-origin":"top",right:0,top:"-1px","border-top":"1px solid transparent","border-bottom":d.em(c.THICKNESS*c.ARROWY)+" solid transparent"},"mjx-menclose > mjx-arrow > mjx-lthead":{transform:"skewX(-"+p+"rad)",left:0,bottom:"-1px","border-left":0,"border-right":d.em(c.THICKNESS*c.ARROWX)+" solid","border-bottom":"1px solid transparent","border-top":d.em(c.THICKNESS*c.ARROWY)+" solid transparent"},"mjx-menclose > mjx-arrow > mjx-lbhead":{transform:"skewX("+p+"rad)","transform-origin":"top",left:0,top:"-1px","border-left":0,"border-right":d.em(c.THICKNESS*c.ARROWX)+" solid","border-top":"1px solid transparent","border-bottom":d.em(c.THICKNESS*c.ARROWY)+" solid transparent"},"mjx-menclose > dbox":{position:"absolute",top:0,bottom:0,left:d.em(-1.5*c.PADDING),width:d.em(3*c.PADDING),border:d.em(c.THICKNESS)+" solid","border-radius":"50%","clip-path":"inset(0 0 0 "+d.em(1.5*c.PADDING)+")","box-sizing":"border-box"}},t.notations=new Map([c.Border("top"),c.Border("right"),c.Border("bottom"),c.Border("left"),c.Border2("actuarial","top","right"),c.Border2("madruwb","bottom","right"),c.DiagonalStrike("up",1),c.DiagonalStrike("down",-1),["horizontalstrike",{renderer:c.RenderElement("hstrike","Y"),bbox:function(e){return[0,e.padding,0,e.padding]}}],["verticalstrike",{renderer:c.RenderElement("vstrike","X"),bbox:function(e){return[e.padding,0,e.padding,0]}}],["box",{renderer:function(e,t){e.adaptor.setStyle(t,"border",e.em(e.thickness)+" solid")},bbox:c.fullBBox,border:c.fullBorder,remove:"left right top bottom"}],["roundedbox",{renderer:c.RenderElement("rbox"),bbox:c.fullBBox}],["circle",{renderer:c.RenderElement("cbox"),bbox:c.fullBBox}],["phasorangle",{renderer:function(e,t){var n=e.getBBox(),r=n.h,i=n.d,o=a(e.getArgMod(1.75*e.padding,r+i),2),s=o[0],l=o[1],c=e.thickness*Math.sin(s)*.9;e.adaptor.setStyle(t,"border-bottom",e.em(e.thickness)+" solid");var u=e.adjustBorder(e.html("mjx-ustrike",{style:{width:e.em(l),transform:"translateX("+e.em(c)+") rotate("+e.fixed(-s)+"rad)"}}));e.adaptor.append(e.chtml,u)},bbox:function(e){var t=e.padding/2,n=e.thickness;return[2*t,t,t+n,3*t+n]},border:function(e){return[0,0,e.thickness,0]},remove:"bottom"}],c.Arrow("up"),c.Arrow("down"),c.Arrow("left"),c.Arrow("right"),c.Arrow("updown"),c.Arrow("leftright"),c.DiagonalArrow("updiagonal"),c.DiagonalArrow("northeast"),c.DiagonalArrow("southeast"),c.DiagonalArrow("northwest"),c.DiagonalArrow("southwest"),c.DiagonalArrow("northeastsouthwest"),c.DiagonalArrow("northwestsoutheast"),["longdiv",{renderer:function(e,t){var n=e.adaptor;n.setStyle(t,"border-top",e.em(e.thickness)+" solid");var r=n.append(e.chtml,e.html("dbox")),i=e.thickness,o=e.padding;i!==c.THICKNESS&&n.setStyle(r,"border-width",e.em(i)),o!==c.PADDING&&(n.setStyle(r,"left",e.em(-1.5*o)),n.setStyle(r,"width",e.em(3*o)),n.setStyle(r,"clip-path","inset(0 0 0 "+e.em(1.5*o)+")"))},bbox:function(e){var t=e.padding,n=e.thickness;return[t+n,t,t,2*t+n/2]}}],["radical",{renderer:function(e,t){e.msqrt.toCHTML(t);var n=e.sqrtTRBL();e.adaptor.setStyle(e.msqrt.chtml,"margin",n.map((function(t){return e.em(-t)})).join(" "))},init:function(e){e.msqrt=e.createMsqrt(e.childNodes[0])},bbox:function(e){return e.sqrtTRBL()},renderChild:!0}]]),t}(l.CommonMencloseMixin(s.CHTMLWrapper));t.CHTMLmenclose=f},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMencloseMixin=void 0;var l=n(184),c=n(62);t.CommonMencloseMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.notations={},r.renderChild=null,r.msqrt=null,r.padding=l.PADDING,r.thickness=l.THICKNESS,r.arrowhead={x:l.ARROWX,y:l.ARROWY,dx:l.ARROWDX},r.TRBL=[0,0,0,0],r.getParameters(),r.getNotations(),r.removeRedundantNotations(),r.initializeNotations(),r.TRBL=r.getBBoxExtenders(),r}return i(t,e),t.prototype.getParameters=function(){var e=this.node.attributes,t=e.get("data-padding");void 0!==t&&(this.padding=this.length2em(t,l.PADDING));var n=e.get("data-thickness");void 0!==n&&(this.thickness=this.length2em(n,l.THICKNESS));var r=e.get("data-arrowhead");if(void 0!==r){var i=o(c.split(r),3),a=i[0],s=i[1],u=i[2];this.arrowhead={x:a?parseFloat(a):l.ARROWX,y:s?parseFloat(s):l.ARROWY,dx:u?parseFloat(u):l.ARROWDX}}},t.prototype.getNotations=function(){var e,t,n=this.constructor.notations;try{for(var r=s(c.split(this.node.attributes.get("notation"))),i=r.next();!i.done;i=r.next()){var o=i.value,a=n.get(o);a&&(this.notations[o]=a,a.renderChild&&(this.renderChild=a.renderer))}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}},t.prototype.removeRedundantNotations=function(){var e,t,n,r;try{for(var i=s(Object.keys(this.notations)),o=i.next();!o.done;o=i.next()){var a=o.value;if(this.notations[a]){var l=this.notations[a].remove||"";try{for(var c=(n=void 0,s(l.split(/ /))),u=c.next();!u.done;u=c.next()){var d=u.value;delete this.notations[d]}}catch(e){n={error:e}}finally{try{u&&!u.done&&(r=c.return)&&r.call(c)}finally{if(n)throw n.error}}}}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}},t.prototype.initializeNotations=function(){var e,t;try{for(var n=s(Object.keys(this.notations)),r=n.next();!r.done;r=n.next()){var i=r.value,o=this.notations[i].init;o&&o(this)}}catch(t){e={error:t}}finally{try{r&&!r.done&&(t=n.return)&&t.call(n)}finally{if(e)throw e.error}}},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=o(this.TRBL,4),r=n[0],i=n[1],a=n[2],s=n[3],l=this.childNodes[0].getBBox();e.combine(l,s,0),e.h+=r,e.d+=a,e.w+=i,this.setChildPWidths(t)},t.prototype.getBBoxExtenders=function(){var e,t,n=[0,0,0,0];try{for(var r=s(Object.keys(this.notations)),i=r.next();!i.done;i=r.next()){var o=i.value;this.maximizeEntries(n,this.notations[o].bbox(this))}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}return n},t.prototype.getPadding=function(){var e,t,n=this,r=[0,0,0,0];try{for(var i=s(Object.keys(this.notations)),o=i.next();!o.done;o=i.next()){var a=o.value,l=this.notations[a].border;l&&this.maximizeEntries(r,l(this))}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return[0,1,2,3].map((function(e){return n.TRBL[e]-r[e]}))},t.prototype.maximizeEntries=function(e,t){for(var n=0;n<e.length;n++)e[n]<t[n]&&(e[n]=t[n])},t.prototype.getOffset=function(e){var t=o(this.TRBL,4),n=t[0],r=t[1],i=t[2],a=t[3],s=("X"===e?r-a:i-n)/2;return Math.abs(s)>.001?s:0},t.prototype.getArgMod=function(e,t){return[Math.atan2(t,e),Math.sqrt(e*e+t*t)]},t.prototype.arrow=function(e,t,n,r,i){return void 0===r&&(r=""),void 0===i&&(i=0),null},t.prototype.arrowData=function(){var e=o([this.padding,this.thickness],2),t=e[0],n=e[1]*(this.arrowhead.x+Math.max(1,this.arrowhead.dx)),r=this.childNodes[0].getBBox(),i=r.h,a=r.d,s=r.w,l=i+a,c=Math.sqrt(l*l+s*s),u=Math.max(t,n*s/c),d=Math.max(t,n*l/c),h=o(this.getArgMod(s+2*u,l+2*d),2);return{a:h[0],W:h[1],x:u,y:d}},t.prototype.arrowAW=function(){var e=this.childNodes[0].getBBox(),t=e.h,n=e.d,r=e.w,i=o(this.TRBL,4),a=i[0],s=i[1],l=i[2],c=i[3];return this.getArgMod(c+r+s,a+t+n+l)},t.prototype.createMsqrt=function(e){var t=this.node.factory.create("msqrt");t.inheritAttributesFrom(this.node),t.childNodes[0]=e.node;var n=this.wrap(t);return n.parent=this,n},t.prototype.sqrtTRBL=function(){var e=this.msqrt.getBBox(),t=this.msqrt.childNodes[0].getBBox();return[e.h-t.h,0,e.d-t.d,e.w-t.w]},t}(e)}},function(e,t,n){"use strict";var r=this&&this.__createBinding||(Object.create?function(e,t,n,r){void 0===r&&(r=n),Object.defineProperty(e,r,{enumerable:!0,get:function(){return t[n]}})}:function(e,t,n,r){void 0===r&&(r=n),e[r]=t[n]}),i=this&&this.__exportStar||function(e,t){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(t,n)||r(t,e,n)},o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.Arrow=t.DiagonalArrow=t.DiagonalStrike=t.Border2=t.Border=t.RenderElement=void 0;var a=n(184);i(n(184),t);t.RenderElement=function(e,t){return void 0===t&&(t=""),function(n,r){var i=n.adjustBorder(n.html("mjx-"+e));if(t){var o=n.getOffset(t);if(n.thickness!==a.THICKNESS||o){var s="translate"+t+"("+n.em(n.thickness/2-o)+")";n.adaptor.setStyle(i,"transform",s)}}n.adaptor.append(n.chtml,i)}};t.Border=function(e){return a.CommonBorder((function(t,n){t.adaptor.setStyle(n,"border-"+e,t.em(t.thickness)+" solid")}))(e)};t.Border2=function(e,t,n){return a.CommonBorder2((function(e,r){var i=e.em(e.thickness)+" solid";e.adaptor.setStyle(r,"border-"+t,i),e.adaptor.setStyle(r,"border-"+n,i)}))(e,t,n)};t.DiagonalStrike=function(e,t){return a.CommonDiagonalStrike((function(e){return function(n,r){var i=n.getBBox(),a=i.w,s=i.h,l=i.d,c=o(n.getArgMod(a,s+l),2),u=c[0],d=c[1],h=t*n.thickness/2,p=n.adjustBorder(n.html(e,{style:{width:n.em(d),transform:"rotate("+n.fixed(-t*u)+"rad) translateY("+h+"em)"}}));n.adaptor.append(n.chtml,p)}}))(e)};t.DiagonalArrow=function(e){return a.CommonDiagonalArrow((function(e,t){e.adaptor.append(e.chtml,t)}))(e)};t.Arrow=function(e){return a.CommonArrow((function(e,t){e.adaptor.append(e.chtml,t)}))(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLinferredMrow=t.CHTMLmrow=void 0;var a=n(40),s=n(431),l=n(431),c=n(432),u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n,r=this.node.isInferred?this.chtml=e:this.standardCHTMLnode(e),i=!1;try{for(var a=o(this.childNodes),s=a.next();!s.done;s=a.next()){var l=s.value;l.toCHTML(r),l.bbox.w<0&&(i=!0)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}if(i){var c=this.getBBox().w;c&&(this.adaptor.setStyle(r,"width",this.em(Math.max(0,c))),c<0&&this.adaptor.setStyle(r,"marginRight",this.em(c)))}},t.kind=c.MmlMrow.prototype.kind,t}(s.CommonMrowMixin(a.CHTMLWrapper));t.CHTMLmrow=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=c.MmlInferredMrow.prototype.kind,t}(l.CommonInferredMrowMixin(u));t.CHTMLinferredMrow=d},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmfenced=void 0;var o=n(40),a=n(856),s=n(433),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e);this.mrow.toCHTML(t)},t.kind=s.MmlMfenced.prototype.kind,t}(a.CommonMfencedMixin(o.CHTMLWrapper));t.CHTMLmfenced=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMfencedMixin=void 0,t.CommonMfencedMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.mrow=null,r.createMrow(),r.addMrowChildren(),r}return i(t,e),t.prototype.createMrow=function(){var e=this.node.factory.create("inferredMrow");e.inheritAttributesFrom(this.node),this.mrow=this.wrap(e),this.mrow.parent=this},t.prototype.addMrowChildren=function(){var e,t,n=this.node,r=this.mrow;this.addMo(n.open),this.childNodes.length&&r.childNodes.push(this.childNodes[0]);var i=0;try{for(var o=s(this.childNodes.slice(1)),a=o.next();!a.done;a=o.next()){var l=a.value;this.addMo(n.separators[i++]),r.childNodes.push(l)}}catch(t){e={error:t}}finally{try{a&&!a.done&&(t=o.return)&&t.call(o)}finally{if(e)throw e.error}}this.addMo(n.close),r.stretchChildren()},t.prototype.addMo=function(e){if(e){var t=this.wrap(e);this.mrow.childNodes.push(t),t.parent=this.mrow}},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1),e.updateFrom(this.mrow.getBBox()),this.setChildPWidths(t)},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmfrac=void 0;var a=n(40),s=n(858),l=n(434),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){this.standardCHTMLnode(e);var t=this.node.attributes.getList("linethickness","bevelled"),n=t.linethickness,r=t.bevelled,i=this.isDisplay();if(r)this.makeBevelled(i);else{var o=this.length2em(String(n),.06);0===o?this.makeAtop(i):this.makeFraction(i,o)}},t.prototype.makeFraction=function(e,t){var n,r,i=this.node.attributes.getList("numalign","denomalign"),a=i.numalign,s=i.denomalign,l=e?{type:"d"}:{},c=this.node.getProperty("withDelims")?o(o({},l),{delims:"true"}):o({},l),u="center"!==a?{align:a}:{},d="center"!==s?{align:s}:{},h=o({},l),p=o({},l),f=this.font.params;if(.06!==t){var m=f.axis_height,g=this.em(t),v=this.getTUV(e,t),y=v.T,_=v.u,b=v.v,M=(e?this.em(3*t):g)+" -.1em";l.style={height:g,"border-top":g+" solid",margin:M};var w=this.em(Math.max(0,_));p.style={height:w,"vertical-align":"-"+w},h.style={height:this.em(Math.max(0,b))},c.style={"vertical-align":this.em(m-y)}}this.adaptor.append(this.chtml,this.html("mjx-frac",c,[n=this.html("mjx-num",u,[this.html("mjx-nstrut",p)]),this.html("mjx-dbox",{},[this.html("mjx-dtable",{},[this.html("mjx-line",l),this.html("mjx-row",{},[r=this.html("mjx-den",d,[this.html("mjx-dstrut",h)])])])])])),this.childNodes[0].toCHTML(n),this.childNodes[1].toCHTML(r)},t.prototype.makeAtop=function(e){var t,n,r=this.node.attributes.getList("numalign","denomalign"),i=r.numalign,a=r.denomalign,s=e?{type:"d",atop:!0}:{atop:!0},l=this.node.getProperty("withDelims")?o(o({},s),{delims:!0}):o({},s),c="center"!==i?{align:i}:{},u="center"!==a?{align:a}:{},d=this.getUVQ(e),h=d.v,p=d.q;c.style={"padding-bottom":this.em(p)},l.style={"vertical-align":this.em(-h)},this.adaptor.append(this.chtml,this.html("mjx-frac",l,[t=this.html("mjx-num",c),n=this.html("mjx-den",u)])),this.childNodes[0].toCHTML(t),this.childNodes[1].toCHTML(n)},t.prototype.makeBevelled=function(e){var t=this.adaptor;t.setAttribute(this.chtml,"bevelled","ture");var n=t.append(this.chtml,this.html("mjx-num"));this.childNodes[0].toCHTML(n),this.bevel.toCHTML(this.chtml);var r=t.append(this.chtml,this.html("mjx-den"));this.childNodes[1].toCHTML(r);var i=this.getBevelData(e),o=i.u,a=i.v,s=i.delta,l=i.nbox,c=i.dbox;o&&t.setStyle(n,"verticalAlign",this.em(o/l.scale)),a&&t.setStyle(r,"verticalAlign",this.em(a/c.scale));var u=this.em(-s/2);t.setStyle(this.bevel.chtml,"marginLeft",u),t.setStyle(this.bevel.chtml,"marginRight",u)},t.kind=l.MmlMfrac.prototype.kind,t.styles={"mjx-frac":{display:"inline-block","vertical-align":"0.17em",padding:"0 .22em"},'mjx-frac[type="d"]':{"vertical-align":".04em"},"mjx-frac[delims]":{padding:"0 .1em"},"mjx-frac[atop]":{padding:"0 .12em"},"mjx-frac[atop][delims]":{padding:"0"},"mjx-dtable":{display:"inline-table",width:"100%"},"mjx-dtable > *":{"font-size":"2000%"},"mjx-dbox":{display:"block","font-size":"5%"},"mjx-num":{display:"block","text-align":"center"},"mjx-den":{display:"block","text-align":"center"},"mjx-mfrac[bevelled] > mjx-num":{display:"inline-block"},"mjx-mfrac[bevelled] > mjx-den":{display:"inline-block"},'mjx-den[align="right"], mjx-num[align="right"]':{"text-align":"right"},'mjx-den[align="left"], mjx-num[align="left"]':{"text-align":"left"},"mjx-nstrut":{display:"inline-block",height:".054em",width:0,"vertical-align":"-.054em"},'mjx-nstrut[type="d"]':{height:".217em","vertical-align":"-.217em"},"mjx-dstrut":{display:"inline-block",height:".505em",width:0},'mjx-dstrut[type="d"]':{height:".726em"},"mjx-line":{display:"block","box-sizing":"border-box","min-height":"1px",height:".06em","border-top":".06em solid",margin:".06em -.1em",overflow:"hidden"},'mjx-line[type="d"]':{margin:".18em -.1em"}},t}(s.CommonMfracMixin(a.CHTMLWrapper));t.CHTMLmfrac=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMfracMixin=void 0,t.CommonMfracMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;if(r.bevel=null,r.pad=r.node.getProperty("withDelims")?0:r.font.params.nulldelimiterspace,r.node.attributes.get("bevelled")){var i=r.getBevelData(r.isDisplay()).H,s=r.bevel=r.createMo("/");s.node.attributes.set("symmetric",!0),s.canStretch(1),s.getStretchedVariant([i],!0)}return r}return i(t,e),t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1),e.empty();var n=this.node.attributes.getList("linethickness","bevelled"),r=n.linethickness,i=n.bevelled,o=this.isDisplay(),a=null;if(i)this.getBevelledBBox(e,o);else{var s=this.length2em(String(r),.06);a=-2*this.pad,0===s?this.getAtopBBox(e,o):(this.getFractionBBox(e,o,s),a-=.2),a+=e.w}e.clean(),this.setChildPWidths(t,a)},t.prototype.getFractionBBox=function(e,t,n){var r=this.childNodes[0].getBBox(),i=this.childNodes[1].getBBox(),o=this.font.params.axis_height,a=this.getTUV(t,n),s=a.T,l=a.u,c=a.v;e.combine(r,0,o+s+Math.max(r.d*r.rscale,l)),e.combine(i,0,o-s-Math.max(i.h*i.rscale,c)),e.w+=2*this.pad+.2},t.prototype.getTUV=function(e,t){var n=this.font.params,r=n.axis_height,i=(e?3.5:1.5)*t;return{T:(e?3.5:1.5)*t,u:(e?n.num1:n.num2)-r-i,v:(e?n.denom1:n.denom2)+r-i}},t.prototype.getAtopBBox=function(e,t){var n=this.getUVQ(t),r=n.u,i=n.v,o=n.nbox,a=n.dbox;e.combine(o,0,r),e.combine(a,0,-i),e.w+=2*this.pad},t.prototype.getUVQ=function(e){var t=this.childNodes[0].getBBox(),n=this.childNodes[1].getBBox(),r=this.font.params,i=o(e?[r.num1,r.denom1]:[r.num3,r.denom2],2),a=i[0],s=i[1],l=(e?7:3)*r.rule_thickness,c=a-t.d*t.scale-(n.h*n.scale-s);return c<l&&(a+=(l-c)/2,s+=(l-c)/2,c=l),{u:a,v:s,q:c,nbox:t,dbox:n}},t.prototype.getBevelledBBox=function(e,t){var n=this.getBevelData(t),r=n.u,i=n.v,o=n.delta,a=n.nbox,s=n.dbox,l=this.bevel.getBBox();e.combine(a,0,r),e.combine(l,e.w-o/2,0),e.combine(s,e.w-o/2,i)},t.prototype.getBevelData=function(e){var t=this.childNodes[0].getBBox(),n=this.childNodes[1].getBBox(),r=e?.4:.15,i=Math.max(t.scale*(t.h+t.d),n.scale*(n.h+n.d))+2*r,o=this.font.params.axis_height;return{H:i,delta:r,u:t.scale*(t.d-t.h)/2+o+r,v:n.scale*(n.d-n.h)/2+o-r,nbox:t,dbox:n}},t.prototype.canStretch=function(e){return!1},t.prototype.isDisplay=function(){var e=this.node.attributes.getList("displaystyle","scriptlevel"),t=e.displaystyle,n=e.scriptlevel;return t&&0===n},t.prototype.getWrapWidth=function(e){var t=this.node.attributes;return t.get("bevelled")?this.childNodes[e].getBBox().w:this.getBBox().w-(this.length2em(t.get("linethickness"))?.2:0)-2*this.pad},t.prototype.getChildAlign=function(e){var t=this.node.attributes;return t.get("bevelled")?"left":t.get(["numalign","denomalign"][e])},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMsqrtMixin=void 0;var s=n(74);t.CommonMsqrtMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this,i=r.createMo("√");i.canStretch(1);var s=r.childNodes[r.base].getBBox(),l=s.h,c=s.d,u=r.font.params.rule_thickness,d=r.node.attributes.get("displaystyle")?r.font.params.x_height:u;return r.surdH=l+c+2*u+d/4,i.getStretchedVariant([r.surdH-c,c],!0),r}return i(t,e),Object.defineProperty(t.prototype,"base",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"surd",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"root",{get:function(){return null},enumerable:!1,configurable:!0}),t.prototype.createMo=function(t){var n=e.prototype.createMo.call(this,t);return this.childNodes.push(n),n},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.childNodes[this.surd].getBBox(),r=new s.BBox(this.childNodes[this.base].getBBox()),i=this.getPQ(n)[1],a=this.font.params.rule_thickness,l=r.h+i+a,c=o(this.getRootDimens(n,l),1)[0];e.h=l+a,this.combineRootBBox(e,n,l),e.combine(n,c,l-n.h),e.combine(r,c+n.w,0),e.clean(),this.setChildPWidths(t)},t.prototype.combineRootBBox=function(e,t,n){},t.prototype.getPQ=function(e){var t=this.font.params.rule_thickness,n=this.node.attributes.get("displaystyle")?this.font.params.x_height:t;return[n,e.h+e.d>this.surdH?(e.h+e.d-(this.surdH-2*t-n/2))/2:t+n/4]},t.prototype.getRootDimens=function(e,t){return[0,0,0,0]},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmroot=void 0;var a=n(435),s=n(861),l=n(437),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.addRoot=function(e,t,n,r){t.toCHTML(e);var i=o(this.getRootDimens(n,r),3),a=i[0],s=i[1],l=i[2];this.adaptor.setStyle(e,"verticalAlign",this.em(s)),this.adaptor.setStyle(e,"width",this.em(a)),l&&this.adaptor.setStyle(this.adaptor.firstChild(e),"paddingLeft",this.em(l))},t.kind=l.MmlMroot.prototype.kind,t}(s.CommonMrootMixin(a.CHTMLmsqrt));t.CHTMLmroot=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMrootMixin=void 0,t.CommonMrootMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"surd",{get:function(){return 2},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"root",{get:function(){return 1},enumerable:!1,configurable:!0}),t.prototype.combineRootBBox=function(e,t,n){var r=this.childNodes[this.root].getBBox(),i=this.getRootDimens(t,n)[1];e.combine(r,0,i)},t.prototype.getRootDimens=function(e,t){var n=this.childNodes[this.surd],r=this.childNodes[this.root].getBBox(),i=(n.size<0?.5:.6)*e.w,o=r.w,a=r.rscale,s=Math.max(o,i/a),l=Math.max(0,s-o);return[s*a-i,this.rootHeight(r,e,n.size,t),l]},t.prototype.rootHeight=function(e,t,n,r){var i=t.h+t.d;return(n<0?1.9:.55*i)-(i-r)+Math.max(0,e.d*e.rscale)},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLscriptbase=void 0;var s=n(40),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){this.chtml=this.standardCHTMLnode(e);var t=o(this.getOffset(),2),n=t[0],r=t[1],i=n-(this.baseRemoveIc?this.baseIc:0),a={"vertical-align":this.em(r)};i&&(a["margin-left"]=this.em(i)),this.baseChild.toCHTML(this.chtml),this.scriptChild.toCHTML(this.adaptor.append(this.chtml,this.html("mjx-script",{style:a})))},t.prototype.setDeltaW=function(e,t){for(var n=0;n<t.length;n++)t[n]&&this.adaptor.setStyle(e[n],"paddingLeft",this.em(t[n]))},t.prototype.adjustOverDepth=function(e,t){t.d>=0||this.adaptor.setStyle(e,"marginBottom",this.em(t.d*t.rscale))},t.prototype.adjustUnderDepth=function(e,t){var n,r;if(!(t.d>=0)){var i=this.adaptor,o=this.em(t.d),s=this.html("mjx-box",{style:{"margin-bottom":o,"vertical-align":o}});try{for(var l=a(i.childNodes(i.firstChild(e))),c=l.next();!c.done;c=l.next()){var u=c.value;i.append(s,u)}}catch(e){n={error:e}}finally{try{c&&!c.done&&(r=l.return)&&r.call(l)}finally{if(n)throw n.error}}i.append(i.firstChild(e),s)}},t.kind="scriptbase",t}(n(863).CommonScriptbaseMixin(s.CHTMLWrapper));t.CHTMLscriptbase=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonScriptbaseMixin=void 0,t.CommonScriptbaseMixin=function(e){var t;return(t=function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;r.baseScale=1,r.baseIc=0,r.baseRemoveIc=!1,r.baseIsChar=!1,r.baseHasAccentOver=null,r.baseHasAccentUnder=null,r.isLineAbove=!1,r.isLineBelow=!1,r.isMathAccent=!1;var i=r.baseCore=r.getBaseCore();return i?(r.setBaseAccentsFor(i),r.baseScale=r.getBaseScale(),r.baseIc=r.getBaseIc(),r.baseIsChar=r.isCharBase(),r.isMathAccent=r.baseIsChar&&r.scriptChild&&!!r.scriptChild.coreMO().node.getProperty("mathaccent"),r.checkLineAccents(),r.baseRemoveIc=!r.isLineAbove&&!r.isLineBelow&&(!r.constructor.useIC||r.isMathAccent),r):r}return i(t,e),Object.defineProperty(t.prototype,"baseChild",{get:function(){return this.childNodes[this.node.base]},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"scriptChild",{get:function(){return this.childNodes[1]},enumerable:!1,configurable:!0}),t.prototype.getBaseCore=function(){for(var e=this.getSemanticBase()||this.childNodes[0];e&&(1===e.childNodes.length&&(e.node.isKind("mrow")||e.node.isKind("TeXAtom")||e.node.isKind("mstyle")||e.node.isKind("mpadded")||e.node.isKind("mphantom")||e.node.isKind("semantics"))||e.node.isKind("munderover")&&e.isMathAccent);)this.setBaseAccentsFor(e),e=e.childNodes[0];return e||(this.baseHasAccentOver=this.baseHasAccentUnder=!1),e||this.childNodes[0]},t.prototype.setBaseAccentsFor=function(e){e.node.isKind("munderover")&&(null===this.baseHasAccentOver&&(this.baseHasAccentOver=!!e.node.attributes.get("accent")),null===this.baseHasAccentUnder&&(this.baseHasAccentUnder=!!e.node.attributes.get("accentunder")))},t.prototype.getSemanticBase=function(){var e=this.node.attributes.getExplicit("data-semantic-fencepointer");return this.getBaseFence(this.baseChild,e)},t.prototype.getBaseFence=function(e,t){var n,r;if(!e||!e.node.attributes||!t)return null;if(e.node.attributes.getExplicit("data-semantic-id")===t)return e;try{for(var i=s(e.childNodes),o=i.next();!o.done;o=i.next()){var a=o.value,l=this.getBaseFence(a,t);if(l)return l}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return null},t.prototype.getBaseScale=function(){for(var e=this.baseCore,t=1;e&&e!==this;){t*=e.getBBox().rscale,e=e.parent}return t},t.prototype.getBaseIc=function(){return this.baseCore.getBBox().ic*this.baseScale},t.prototype.getAdjustedIc=function(){var e=this.baseCore.getBBox();return(e.ic?1.05*e.ic+.05:0)*this.baseScale},t.prototype.isCharBase=function(){var e=this.baseCore;return(e.node.isKind("mo")&&null===e.size||e.node.isKind("mi")||e.node.isKind("mn"))&&1===e.bbox.rscale&&1===Array.from(e.getText()).length},t.prototype.checkLineAccents=function(){if(this.node.isKind("munderover"))if(this.node.isKind("mover"))this.isLineAbove=this.isLineAccent(this.scriptChild);else if(this.node.isKind("munder"))this.isLineBelow=this.isLineAccent(this.scriptChild);else{this.isLineAbove=this.isLineAccent(this.overChild),this.isLineBelow=this.isLineAccent(this.underChild)}},t.prototype.isLineAccent=function(e){var t=e.coreMO().node;return t.isToken&&"―"===t.getText()},t.prototype.getBaseWidth=function(){var e=this.baseChild.getBBox();return e.w*e.rscale-(this.baseRemoveIc?this.baseIc:0)+this.font.params.extra_ic},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.getBaseWidth(),r=o(this.getOffset(),2),i=r[0],a=r[1];e.append(this.baseChild.getBBox()),e.combine(this.scriptChild.getBBox(),n+i,a),e.w+=this.font.params.scriptspace,e.clean(),this.setChildPWidths(t)},t.prototype.getOffset=function(){return[0,0]},t.prototype.baseCharZero=function(e){var t=!!this.baseCore.node.attributes.get("largeop"),n=this.baseScale;return this.baseIsChar&&!t&&1===n?0:e},t.prototype.getV=function(){var e=this.baseCore.getBBox(),t=this.scriptChild.getBBox(),n=this.font.params,r=this.length2em(this.node.attributes.get("subscriptshift"),n.sub1);return Math.max(this.baseCharZero(e.d*this.baseScale+n.sub_drop*t.rscale),r,t.h*t.rscale-.8*n.x_height)},t.prototype.getU=function(){var e=this.baseCore.getBBox(),t=this.scriptChild.getBBox(),n=this.font.params,r=this.node.attributes.getList("displaystyle","superscriptshift"),i=this.node.getProperty("texprimestyle")?n.sup3:r.displaystyle?n.sup1:n.sup2,o=this.length2em(r.superscriptshift,i);return Math.max(this.baseCharZero(e.h*this.baseScale-n.sup_drop*t.rscale),o,t.d*t.rscale+1/4*n.x_height)},t.prototype.hasMovableLimits=function(){var e=this.node.attributes.get("displaystyle"),t=this.baseChild.coreMO().node;return!e&&!!t.attributes.get("movablelimits")},t.prototype.getOverKU=function(e,t){var n=this.node.attributes.get("accent"),r=this.font.params,i=t.d*t.rscale,o=r.rule_thickness*r.separation_factor,a=this.baseHasAccentOver?o:0,s=this.isLineAbove?3*r.rule_thickness:o,l=(n?s:Math.max(r.big_op_spacing1,r.big_op_spacing3-Math.max(0,i)))-a;return[l,e.h*e.rscale+l+i]},t.prototype.getUnderKV=function(e,t){var n=this.node.attributes.get("accentunder"),r=this.font.params,i=t.h*t.rscale,o=r.rule_thickness*r.separation_factor,a=this.baseHasAccentUnder?o:0,s=this.isLineBelow?3*r.rule_thickness:o,l=(n?s:Math.max(r.big_op_spacing2,r.big_op_spacing4-i))-a;return[l,-(e.d*e.rscale+l+i)]},t.prototype.getDeltaW=function(e,t){var n,r,i,l;void 0===t&&(t=[0,0,0]);var c=this.node.attributes.get("align"),u=e.map((function(e){return e.w*e.rscale}));u[0]-=this.baseRemoveIc&&!this.baseCore.node.attributes.get("largeop")?this.baseIc:0;var d=Math.max.apply(Math,a([],o(u))),h=[],p=0;try{for(var f=s(u.keys()),m=f.next();!m.done;m=f.next()){var g=m.value;h[g]=("center"===c?(d-u[g])/2:"right"===c?d-u[g]:0)+t[g],h[g]<p&&(p=-h[g])}}catch(e){n={error:e}}finally{try{m&&!m.done&&(r=f.return)&&r.call(f)}finally{if(n)throw n.error}}if(p)try{for(var v=s(h.keys()),y=v.next();!y.done;y=v.next()){g=y.value;h[g]+=p}}catch(e){i={error:e}}finally{try{y&&!y.done&&(l=v.return)&&l.call(v)}finally{if(i)throw i.error}}return[1,2].map((function(t){return h[t]+=e[t]?e[t].dx*e[0].scale:0})),h},t.prototype.getDelta=function(e){void 0===e&&(e=!1);var t=this.node.attributes.get("accent"),n=this.baseCore.getBBox(),r=n.sk,i=n.ic;return((t&&!e?r:0)+this.font.skewIcFactor*i)*this.baseScale},t.prototype.stretchChildren=function(){var e,t,n,r,i,o,a=[];try{for(var l=s(this.childNodes),c=l.next();!c.done;c=l.next()){(w=c.value).canStretch(2)&&a.push(w)}}catch(t){e={error:t}}finally{try{c&&!c.done&&(t=l.return)&&t.call(l)}finally{if(e)throw e.error}}var u=a.length,d=this.childNodes.length;if(u&&d>1){var h=0,p=u>1&&u===d;try{for(var f=s(this.childNodes),m=f.next();!m.done;m=f.next()){var g=0===(w=m.value).stretch.dir;if(p||g){var v=w.getBBox(g),y=v.w,_=v.rscale;y*_>h&&(h=y*_)}}}catch(e){n={error:e}}finally{try{m&&!m.done&&(r=f.return)&&r.call(f)}finally{if(n)throw n.error}}try{for(var b=s(a),M=b.next();!M.done;M=b.next()){var w;(w=M.value).coreMO().getStretchedVariant([h/w.bbox.rscale])}}catch(e){i={error:e}}finally{try{M&&!M.done&&(o=b.return)&&o.call(b)}finally{if(i)throw i.error}}}},t}(e)).useIC=!0,t}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmunderover=t.CHTMLmover=t.CHTMLmunder=void 0;var o=n(185),a=n(188),s=n(188),l=n(188),c=n(438),u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){if(this.hasMovableLimits())return e.prototype.toCHTML.call(this,t),void this.adaptor.setAttribute(this.chtml,"limits","false");this.chtml=this.standardCHTMLnode(t);var n=this.adaptor.append(this.adaptor.append(this.chtml,this.html("mjx-row")),this.html("mjx-base")),r=this.adaptor.append(this.adaptor.append(this.chtml,this.html("mjx-row")),this.html("mjx-under"));this.baseChild.toCHTML(n),this.scriptChild.toCHTML(r);var i=this.baseChild.getBBox(),o=this.scriptChild.getBBox(),a=this.getUnderKV(i,o)[0],s=this.isLineBelow?0:this.getDelta(!0);this.adaptor.setStyle(r,"paddingTop",this.em(a)),this.setDeltaW([n,r],this.getDeltaW([i,o],[0,-s])),this.adjustUnderDepth(r,o)},t.kind=c.MmlMunder.prototype.kind,t.styles={"mjx-over":{"text-align":"left"},'mjx-munder:not([limits="false"])':{display:"inline-table"},"mjx-munder > mjx-row":{"text-align":"left"},"mjx-under":{"padding-bottom":".1em"}},t}(a.CommonMunderMixin(o.CHTMLmsub));t.CHTMLmunder=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){if(this.hasMovableLimits())return e.prototype.toCHTML.call(this,t),void this.adaptor.setAttribute(this.chtml,"limits","false");this.chtml=this.standardCHTMLnode(t);var n=this.adaptor.append(this.chtml,this.html("mjx-over")),r=this.adaptor.append(this.chtml,this.html("mjx-base"));this.scriptChild.toCHTML(n),this.baseChild.toCHTML(r);var i=this.scriptChild.getBBox(),o=this.baseChild.getBBox(),a=this.getOverKU(o,i)[0],s=this.isLineAbove?0:this.getDelta();this.adaptor.setStyle(n,"paddingBottom",this.em(a)),this.setDeltaW([r,n],this.getDeltaW([o,i],[0,s])),this.adjustOverDepth(n,i)},t.kind=c.MmlMover.prototype.kind,t.styles={'mjx-mover:not([limits="false"])':{"padding-top":".1em"},'mjx-mover:not([limits="false"]) > *':{display:"block","text-align":"left"}},t}(s.CommonMoverMixin(o.CHTMLmsup));t.CHTMLmover=d;var h=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){if(this.hasMovableLimits())return e.prototype.toCHTML.call(this,t),void this.adaptor.setAttribute(this.chtml,"limits","false");this.chtml=this.standardCHTMLnode(t);var n=this.adaptor.append(this.chtml,this.html("mjx-over")),r=this.adaptor.append(this.adaptor.append(this.chtml,this.html("mjx-box")),this.html("mjx-munder")),i=this.adaptor.append(this.adaptor.append(r,this.html("mjx-row")),this.html("mjx-base")),o=this.adaptor.append(this.adaptor.append(r,this.html("mjx-row")),this.html("mjx-under"));this.overChild.toCHTML(n),this.baseChild.toCHTML(i),this.underChild.toCHTML(o);var a=this.overChild.getBBox(),s=this.baseChild.getBBox(),l=this.underChild.getBBox(),c=this.getOverKU(s,a)[0],u=this.getUnderKV(s,l)[0],d=this.getDelta();this.adaptor.setStyle(n,"paddingBottom",this.em(c)),this.adaptor.setStyle(o,"paddingTop",this.em(u)),this.setDeltaW([i,o,n],this.getDeltaW([s,l,a],[0,this.isLineBelow?0:-d,this.isLineAbove?0:d])),this.adjustOverDepth(n,a),this.adjustUnderDepth(o,l)},t.prototype.markUsed=function(){e.prototype.markUsed.call(this),this.jax.wrapperUsage.add(o.CHTMLmsubsup.kind)},t.kind=c.MmlMunderover.prototype.kind,t.styles={'mjx-munderover:not([limits="false"])':{"padding-top":".1em"},'mjx-munderover:not([limits="false"]) > *':{display:"block"}},t}(l.CommonMunderoverMixin(o.CHTMLmsubsup));t.CHTMLmunderover=h},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmmultiscripts=void 0;var a=n(185),s=n(866),l=n(439),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e),n=this.scriptData,r=this.combinePrePost(n.sub,n.psub),i=this.combinePrePost(n.sup,n.psup),a=o(this.getUVQ(r,i),2),s=a[0],l=a[1];n.numPrescripts&&this.addScripts(s,-l,!0,n.psub,n.psup,this.firstPrescript,n.numPrescripts),this.childNodes[0].toCHTML(t),n.numScripts&&this.addScripts(s,-l,!1,n.sub,n.sup,1,n.numScripts)},t.prototype.addScripts=function(e,t,n,r,i,o,a){var s=this.adaptor,l=e-i.d+(t-r.h),c=e<0&&0===t?r.h+e:e,u=l>0?{style:{height:this.em(l)}}:{},d=c?{style:{"vertical-align":this.em(c)}}:{},h=this.html("mjx-row"),p=this.html("mjx-row",u),f=this.html("mjx-row"),m="mjx-"+(n?"pre":"")+"scripts";s.append(this.chtml,this.html(m,d,[h,p,f]));for(var g=o+2*a;o<g;)this.childNodes[o++].toCHTML(s.append(f,this.html("mjx-cell"))),this.childNodes[o++].toCHTML(s.append(h,this.html("mjx-cell")))},t.kind=l.MmlMmultiscripts.prototype.kind,t.styles={"mjx-prescripts":{display:"inline-table","padding-left":".05em"},"mjx-scripts":{display:"inline-table","padding-right":".05em"},"mjx-prescripts > mjx-row > mjx-cell":{"text-align":"right"}},t}(s.CommonMmultiscriptsMixin(a.CHTMLmsubsup));t.CHTMLmmultiscripts=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMmultiscriptsMixin=t.ScriptNames=t.NextScript=void 0;var l=n(74);t.NextScript={base:"subList",subList:"supList",supList:"subList",psubList:"psupList",psupList:"psubList"},t.ScriptNames=["sup","sup","psup","psub"],t.CommonMmultiscriptsMixin=function(e){return function(e){function n(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.scriptData=null,r.firstPrescript=0,r.getScriptData(),r}return i(n,e),n.prototype.combinePrePost=function(e,t){var n=new l.BBox(e);return n.combine(t,0,0),n},n.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.font.params.scriptspace,r=this.scriptData,i=this.combinePrePost(r.sub,r.psub),a=this.combinePrePost(r.sup,r.psup),s=o(this.getUVQ(i,a),2),l=s[0],c=s[1];if(e.empty(),r.numPrescripts&&(e.combine(r.psup,n,l),e.combine(r.psub,n,c)),e.append(r.base),r.numScripts){var u=e.w;e.combine(r.sup,u,l),e.combine(r.sub,u,c),e.w+=n}e.clean(),this.setChildPWidths(t)},n.prototype.getScriptData=function(){var e=this.scriptData={base:null,sub:l.BBox.empty(),sup:l.BBox.empty(),psub:l.BBox.empty(),psup:l.BBox.empty(),numPrescripts:0,numScripts:0},t=this.getScriptBBoxLists();this.combineBBoxLists(e.sub,e.sup,t.subList,t.supList),this.combineBBoxLists(e.psub,e.psup,t.psubList,t.psupList),e.base=t.base[0],e.numPrescripts=t.psubList.length,e.numScripts=t.subList.length},n.prototype.getScriptBBoxLists=function(){var e,n,r={base:[],subList:[],supList:[],psubList:[],psupList:[]},i="base";try{for(var o=s(this.childNodes),a=o.next();!a.done;a=o.next()){var l=a.value;l.node.isKind("mprescripts")?i="psubList":(r[i].push(l.getBBox()),i=t.NextScript[i])}}catch(t){e={error:t}}finally{try{a&&!a.done&&(n=o.return)&&n.call(o)}finally{if(e)throw e.error}}return this.firstPrescript=r.subList.length+r.supList.length+2,this.padLists(r.subList,r.supList),this.padLists(r.psubList,r.psupList),r},n.prototype.padLists=function(e,t){e.length>t.length&&t.push(l.BBox.empty())},n.prototype.combineBBoxLists=function(e,t,n,r){for(var i=0;i<n.length;i++){var a=o(this.getScaledWHD(n[i]),3),s=a[0],l=a[1],c=a[2],u=o(this.getScaledWHD(r[i]),3),d=u[0],h=u[1],p=u[2],f=Math.max(s,d);e.w+=f,t.w+=f,l>e.h&&(e.h=l),c>e.d&&(e.d=c),h>t.h&&(t.h=h),p>t.d&&(t.d=p)}},n.prototype.getScaledWHD=function(e){var t=e.w,n=e.h,r=e.d,i=e.rscale;return[t*i,n*i,r*i]},n.prototype.getUVQ=function(t,n){var r;if(!this.UVQ){var i=o([0,0,0],3),a=i[0],s=i[1],l=i[2];0===t.h&&0===t.d?a=this.getU():0===n.h&&0===n.d?a=-this.getV():(a=(r=o(e.prototype.getUVQ.call(this,t,n),3))[0],s=r[1],l=r[2]),this.UVQ=[a,s,l]}return this.UVQ},n}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmtable=void 0;var s=n(40),l=n(868),c=n(440),u=n(62),d=function(e){function t(t,n,r){void 0===r&&(r=null);var i=e.call(this,t,n,r)||this;return i.itable=i.html("mjx-itable"),i.labels=i.html("mjx-itable"),i}return i(t,e),t.prototype.getAlignShift=function(){var t=e.prototype.getAlignShift.call(this);return this.isTop||(t[1]=0),t},t.prototype.toCHTML=function(e){var t,n,r=this.standardCHTMLnode(e);this.adaptor.append(r,this.html("mjx-table",{},[this.itable]));try{for(var i=o(this.childNodes),a=i.next();!a.done;a=i.next()){a.value.toCHTML(this.itable)}}catch(e){t={error:e}}finally{try{a&&!a.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}this.padRows(),this.handleColumnSpacing(),this.handleColumnLines(),this.handleColumnWidths(),this.handleRowSpacing(),this.handleRowLines(),this.handleRowHeights(),this.handleFrame(),this.handleWidth(),this.handleLabels(),this.handleAlign(),this.handleJustify(),this.shiftColor()},t.prototype.shiftColor=function(){var e=this.adaptor,t=e.getStyle(this.chtml,"backgroundColor");t&&(e.setStyle(this.chtml,"backgroundColor",""),e.setStyle(this.itable,"backgroundColor",t))},t.prototype.padRows=function(){var e,t,n=this.adaptor;try{for(var r=o(n.childNodes(this.itable)),i=r.next();!i.done;i=r.next())for(var a=i.value;n.childNodes(a).length<this.numCols;)n.append(a,this.html("mjx-mtd",{extra:!0}))}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}},t.prototype.handleColumnSpacing=function(){var e,t,n,r,i=this.childNodes[0]?1/this.childNodes[0].getBBox().rscale:1,a=this.getEmHalfSpacing(this.fSpace[0],this.cSpace,i),s=this.frame;try{for(var l=o(this.tableRows),c=l.next();!c.done;c=l.next()){var u=c.value,d=0;try{for(var h=(n=void 0,o(u.tableCells)),p=h.next();!p.done;p=h.next()){var f=p.value,m=a[d++],g=a[d],v=f?f.chtml:this.adaptor.childNodes(u.chtml)[d];(d>1&&"0.4em"!==m||s&&1===d)&&this.adaptor.setStyle(v,"paddingLeft",m),(d<this.numCols&&"0.4em"!==g||s&&d===this.numCols)&&this.adaptor.setStyle(v,"paddingRight",g)}}catch(e){n={error:e}}finally{try{p&&!p.done&&(r=h.return)&&r.call(h)}finally{if(n)throw n.error}}}}catch(t){e={error:t}}finally{try{c&&!c.done&&(t=l.return)&&t.call(l)}finally{if(e)throw e.error}}},t.prototype.handleColumnLines=function(){var e,t,n,r;if("none"!==this.node.attributes.get("columnlines")){var i=this.getColumnAttributes("columnlines");try{for(var a=o(this.childNodes),s=a.next();!s.done;s=a.next()){var l=s.value,c=0;try{for(var u=(n=void 0,o(this.adaptor.childNodes(l.chtml).slice(1))),d=u.next();!d.done;d=u.next()){var h=d.value,p=i[c++];"none"!==p&&this.adaptor.setStyle(h,"borderLeft",".07em "+p)}}catch(e){n={error:e}}finally{try{d&&!d.done&&(r=u.return)&&r.call(u)}finally{if(n)throw n.error}}}}catch(t){e={error:t}}finally{try{s&&!s.done&&(t=a.return)&&t.call(a)}finally{if(e)throw e.error}}}},t.prototype.handleColumnWidths=function(){var e,t,n,r;try{for(var i=o(this.childNodes),a=i.next();!a.done;a=i.next()){var s=a.value,l=0;try{for(var c=(n=void 0,o(this.adaptor.childNodes(s.chtml))),u=c.next();!u.done;u=c.next()){var d=u.value,h=this.cWidths[l++];if(null!==h){var p="number"==typeof h?this.em(h):h;this.adaptor.setStyle(d,"width",p),this.adaptor.setStyle(d,"maxWidth",p),this.adaptor.setStyle(d,"minWidth",p)}}}catch(e){n={error:e}}finally{try{u&&!u.done&&(r=c.return)&&r.call(c)}finally{if(n)throw n.error}}}}catch(t){e={error:t}}finally{try{a&&!a.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}},t.prototype.handleRowSpacing=function(){var e,t,n,r,i=this.childNodes[0]?1/this.childNodes[0].getBBox().rscale:1,a=this.getEmHalfSpacing(this.fSpace[1],this.rSpace,i),s=this.frame,l=0;try{for(var c=o(this.childNodes),u=c.next();!u.done;u=c.next()){var d=u.value,h=a[l++],p=a[l];try{for(var f=(n=void 0,o(d.childNodes)),m=f.next();!m.done;m=f.next()){var g=m.value;(l>1&&"0.215em"!==h||s&&1===l)&&this.adaptor.setStyle(g.chtml,"paddingTop",h),(l<this.numRows&&"0.215em"!==p||s&&l===this.numRows)&&this.adaptor.setStyle(g.chtml,"paddingBottom",p)}}catch(e){n={error:e}}finally{try{m&&!m.done&&(r=f.return)&&r.call(f)}finally{if(n)throw n.error}}}}catch(t){e={error:t}}finally{try{u&&!u.done&&(t=c.return)&&t.call(c)}finally{if(e)throw e.error}}},t.prototype.handleRowLines=function(){var e,t,n,r;if("none"!==this.node.attributes.get("rowlines")){var i=this.getRowAttributes("rowlines"),a=0;try{for(var s=o(this.childNodes.slice(1)),l=s.next();!l.done;l=s.next()){var c=l.value,u=i[a++];if("none"!==u)try{for(var d=(n=void 0,o(this.adaptor.childNodes(c.chtml))),h=d.next();!h.done;h=d.next()){var p=h.value;this.adaptor.setStyle(p,"borderTop",".07em "+u)}}catch(e){n={error:e}}finally{try{h&&!h.done&&(r=d.return)&&r.call(d)}finally{if(n)throw n.error}}}}catch(t){e={error:t}}finally{try{l&&!l.done&&(t=s.return)&&t.call(s)}finally{if(e)throw e.error}}}},t.prototype.handleRowHeights=function(){this.node.attributes.get("equalrows")&&this.handleEqualRows()},t.prototype.handleEqualRows=function(){for(var e=this.getRowHalfSpacing(),t=this.getTableData(),n=t.H,r=t.D,i=t.NH,o=t.ND,a=this.getEqualRowHeight(),s=0;s<this.numRows;s++){var l=this.childNodes[s];this.setRowHeight(l,a+e[s]+e[s+1]+this.rLines[s]),a!==i[s]+o[s]&&this.setRowBaseline(l,a,(a-n[s]+r[s])/2)}},t.prototype.setRowHeight=function(e,t){this.adaptor.setStyle(e.chtml,"height",this.em(t))},t.prototype.setRowBaseline=function(e,t,n){var r,i,a=e.node.attributes.get("rowalign");try{for(var s=o(e.childNodes),l=s.next();!l.done;l=s.next()){var c=l.value;if(this.setCellBaseline(c,a,t,n))break}}catch(e){r={error:e}}finally{try{l&&!l.done&&(i=s.return)&&i.call(s)}finally{if(r)throw r.error}}},t.prototype.setCellBaseline=function(e,t,n,r){var i=e.node.attributes.get("rowalign");if("baseline"===i||"axis"===i){var o=this.adaptor,a=o.lastChild(e.chtml);o.setStyle(a,"height",this.em(n)),o.setStyle(a,"verticalAlign",this.em(-r));var s=e.parent;if(!(s.node.isKind("mlabeledtr")&&e===s.childNodes[0]||"baseline"!==t&&"axis"!==t))return!0}return!1},t.prototype.handleFrame=function(){this.frame&&this.fLine&&this.adaptor.setStyle(this.itable,"border",".07em "+this.node.attributes.get("frame"))},t.prototype.handleWidth=function(){var e=this.adaptor,t=this.getBBox(),n=t.w,r=t.L,i=t.R;e.setStyle(this.chtml,"minWidth",this.em(r+n+i));var o=this.node.attributes.get("width");if(u.isPercent(o))e.setStyle(this.chtml,"width",""),e.setAttribute(this.chtml,"width","full");else if(!this.hasLabels){if("auto"===o)return;o=this.em(this.length2em(o)+2*this.fLine)}var a=e.firstChild(this.chtml);if(e.setStyle(a,"width",o),e.setStyle(a,"minWidth",this.em(n)),r||i){e.setStyle(this.chtml,"margin","");var s=this.node.attributes.get("data-width-includes-label")?"padding":"margin";r===i?e.setStyle(a,s,"0 "+this.em(i)):e.setStyle(a,s,"0 "+this.em(i)+" 0 "+this.em(r))}e.setAttribute(this.itable,"width","full")},t.prototype.handleAlign=function(){var e=a(this.getAlignmentRow(),2),t=e[0],n=e[1];if(null===n)"axis"!==t&&this.adaptor.setAttribute(this.chtml,"align",t);else{var r=this.getVerticalPosition(n,t);this.adaptor.setAttribute(this.chtml,"align","top"),this.adaptor.setStyle(this.chtml,"verticalAlign",this.em(r))}},t.prototype.handleJustify=function(){var e=this.getAlignShift()[0];"center"!==e&&this.adaptor.setAttribute(this.chtml,"justify",e)},t.prototype.handleLabels=function(){if(this.hasLabels){var e=this.labels,t=this.node.attributes,n=this.adaptor,r=t.get("side");n.setAttribute(this.chtml,"side",r),n.setAttribute(e,"align",r),n.setStyle(e,r,"0");var i=a(this.addLabelPadding(r),2),o=i[0],s=i[1];if(s){var l=n.firstChild(this.chtml);this.setIndent(l,o,s)}this.updateRowHeights(),this.addLabelSpacing()}},t.prototype.addLabelPadding=function(e){var t=a(this.getPadAlignShift(e),3),n=t[1],r=t[2],i={};if("right"===e&&!this.node.attributes.get("data-width-includes-label")){var o=this.node.attributes.get("width"),s=this.getBBox(),l=s.w,c=s.L,d=s.R;i.style={width:u.isPercent(o)?"calc("+o+" + "+this.em(c+d)+")":this.em(c+l+d)}}return this.adaptor.append(this.chtml,this.html("mjx-labels",i,[this.labels])),[n,r]},t.prototype.updateRowHeights=function(){for(var e=this.getTableData(),t=e.H,n=e.D,r=e.NH,i=e.ND,o=this.getRowHalfSpacing(),a=0;a<this.numRows;a++){var s=this.childNodes[a];this.setRowHeight(s,t[a]+n[a]+o[a]+o[a+1]+this.rLines[a]),t[a]!==r[a]||n[a]!==i[a]?this.setRowBaseline(s,t[a]+n[a],n[a]):s.node.isKind("mlabeledtr")&&this.setCellBaseline(s.childNodes[0],"",t[a]+n[a],n[a])}},t.prototype.addLabelSpacing=function(){for(var e=this.adaptor,t=this.node.attributes.get("equalrows"),n=this.getTableData(),r=n.H,i=n.D,o=t?this.getEqualRowHeight():0,a=this.getRowHalfSpacing(),s=this.fLine,l=e.firstChild(this.labels),c=0;c<this.numRows;c++){this.childNodes[c].node.isKind("mlabeledtr")?(s&&e.insert(this.html("mjx-mtr",{style:{height:this.em(s)}}),l),e.setStyle(l,"height",this.em((t?o:r[c]+i[c])+a[c]+a[c+1])),l=e.next(l),s=this.rLines[c]):s+=a[c]+(t?o:r[c]+i[c])+a[c+1]+this.rLines[c]}},t.kind=c.MmlMtable.prototype.kind,t.styles={"mjx-mtable":{"vertical-align":".25em","text-align":"center",position:"relative","box-sizing":"border-box","border-spacing":0,"border-collapse":"collapse"},'mjx-mstyle[size="s"] mjx-mtable':{"vertical-align":".354em"},"mjx-labels":{position:"absolute",left:0,top:0},"mjx-table":{display:"inline-block","vertical-align":"-.5ex","box-sizing":"border-box"},"mjx-table > mjx-itable":{"vertical-align":"middle","text-align":"left","box-sizing":"border-box"},"mjx-labels > mjx-itable":{position:"absolute",top:0},'mjx-mtable[justify="left"]':{"text-align":"left"},'mjx-mtable[justify="right"]':{"text-align":"right"},'mjx-mtable[justify="left"][side="left"]':{"padding-right":"0 ! important"},'mjx-mtable[justify="left"][side="right"]':{"padding-left":"0 ! important"},'mjx-mtable[justify="right"][side="left"]':{"padding-right":"0 ! important"},'mjx-mtable[justify="right"][side="right"]':{"padding-left":"0 ! important"},"mjx-mtable[align]":{"vertical-align":"baseline"},'mjx-mtable[align="top"] > mjx-table':{"vertical-align":"top"},'mjx-mtable[align="bottom"] > mjx-table':{"vertical-align":"bottom"},'mjx-mtable[side="right"] mjx-labels':{"min-width":"100%"}},t}(l.CommonMtableMixin(s.CHTMLWrapper));t.CHTMLmtable=d},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMtableMixin=void 0;var l=n(74),c=n(62),u=n(869);t.CommonMtableMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;r.numCols=0,r.numRows=0,r.data=null,r.pwidthCells=[],r.pWidth=0,r.numCols=u.max(r.tableRows.map((function(e){return e.numCells}))),r.numRows=r.childNodes.length,r.hasLabels=r.childNodes.reduce((function(e,t){return e||t.node.isKind("mlabeledtr")}),!1),r.findContainer(),r.isTop=!r.container||r.container.node.isKind("math")&&!r.container.parent,r.isTop&&(r.jax.table=r),r.getPercentageWidth();var i=r.node.attributes;return r.frame="none"!==i.get("frame"),r.fLine=r.frame&&i.get("frame")?.07:0,r.fSpace=r.frame?r.convertLengths(r.getAttributeArray("framespacing")):[0,0],r.cSpace=r.convertLengths(r.getColumnAttributes("columnspacing")),r.rSpace=r.convertLengths(r.getRowAttributes("rowspacing")),r.cLines=r.getColumnAttributes("columnlines").map((function(e){return"none"===e?0:.07})),r.rLines=r.getRowAttributes("rowlines").map((function(e){return"none"===e?0:.07})),r.cWidths=r.getColumnWidths(),r.stretchRows(),r.stretchColumns(),r}return i(t,e),Object.defineProperty(t.prototype,"tableRows",{get:function(){return this.childNodes},enumerable:!1,configurable:!0}),t.prototype.findContainer=function(){for(var e=this,t=e.parent;t&&(t.node.notParent||t.node.isKind("mrow"));)e=t,t=t.parent;this.container=t,this.containerI=e.node.childPosition()},t.prototype.getPercentageWidth=function(){if(this.hasLabels)this.bbox.pwidth=l.BBox.fullWidth;else{var e=this.node.attributes.get("width");c.isPercent(e)&&(this.bbox.pwidth=e)}},t.prototype.stretchRows=function(){for(var e=this.node.attributes.get("equalrows"),t=e?this.getEqualRowHeight():0,n=e?this.getTableData():{H:[0],D:[0]},r=n.H,i=n.D,o=this.tableRows,a=0;a<this.numRows;a++){var s=e?[(t+r[a]-i[a])/2,(t-r[a]+i[a])/2]:null;o[a].stretchChildren(s)}},t.prototype.stretchColumns=function(){for(var e=0;e<this.numCols;e++){var t="number"==typeof this.cWidths[e]?this.cWidths[e]:null;this.stretchColumn(e,t)}},t.prototype.stretchColumn=function(e,t){var n,r,i,o,a,l,c=[];try{for(var u=s(this.tableRows),d=u.next();!d.done;d=u.next()){if(v=d.value.getChild(e))0===(w=v.childNodes[0]).stretch.dir&&w.canStretch(2)&&c.push(w)}}catch(e){n={error:e}}finally{try{d&&!d.done&&(r=u.return)&&r.call(u)}finally{if(n)throw n.error}}var h=c.length,p=this.childNodes.length;if(h&&p>1){if(null===t){t=0;var f=h>1&&h===p;try{for(var m=s(this.tableRows),g=m.next();!g.done;g=m.next()){var v;if(v=g.value.getChild(e)){var y=0===(w=v.childNodes[0]).stretch.dir;if(f||y){var _=w.getBBox(y).w;_>t&&(t=_)}}}}catch(e){i={error:e}}finally{try{g&&!g.done&&(o=m.return)&&o.call(m)}finally{if(i)throw i.error}}}try{for(var b=s(c),M=b.next();!M.done;M=b.next()){var w;(w=M.value).coreMO().getStretchedVariant([t])}}catch(e){a={error:e}}finally{try{M&&!M.done&&(l=b.return)&&l.call(b)}finally{if(a)throw a.error}}}},t.prototype.getTableData=function(){if(this.data)return this.data;for(var e=new Array(this.numRows).fill(0),t=new Array(this.numRows).fill(0),n=new Array(this.numCols).fill(0),r=new Array(this.numRows),i=new Array(this.numRows),o=[0],a=this.tableRows,s=0;s<a.length;s++){for(var l=0,c=a[s],u=c.node.attributes.get("rowalign"),d=0;d<c.numCells;d++){var h=c.getChild(d);l=this.updateHDW(h,d,s,u,e,t,n,l),this.recordPWidthCell(h,d)}r[s]=e[s],i[s]=t[s],c.labeled&&(l=this.updateHDW(c.childNodes[0],0,s,u,e,t,o,l)),this.extendHD(s,e,t,l),this.extendHD(s,r,i,l)}var p=o[0];return this.data={H:e,D:t,W:n,NH:r,ND:i,L:p},this.data},t.prototype.updateHDW=function(e,t,n,r,i,o,a,s){var l=e.getBBox(),c=l.h,u=l.d,d=l.w,h=e.parent.bbox.rscale;1!==e.parent.bbox.rscale&&(c*=h,u*=h,d*=h),this.node.getProperty("useHeight")&&(c<.75&&(c=.75),u<.25&&(u=.25));var p=0;return"baseline"!==(r=e.node.attributes.get("rowalign")||r)&&"axis"!==r&&(p=c+u,c=u=0),c>i[n]&&(i[n]=c),u>o[n]&&(o[n]=u),p>s&&(s=p),a&&d>a[t]&&(a[t]=d),s},t.prototype.extendHD=function(e,t,n,r){var i=(r-(t[e]+n[e]))/2;i<1e-5||(t[e]+=i,n[e]+=i)},t.prototype.recordPWidthCell=function(e,t){e.childNodes[0]&&e.childNodes[0].getBBox().pwidth&&this.pwidthCells.push([e,t])},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n,r,i=this.getTableData(),a=i.H,s=i.D;if(this.node.attributes.get("equalrows")){var l=this.getEqualRowHeight();n=u.sum([].concat(this.rLines,this.rSpace))+l*this.numRows}else n=u.sum(a.concat(s,this.rLines,this.rSpace));n+=2*(this.fLine+this.fSpace[1]);var d=this.getComputedWidths();r=u.sum(d.concat(this.cLines,this.cSpace))+2*(this.fLine+this.fSpace[0]);var h=this.node.attributes.get("width");"auto"!==h&&(r=Math.max(this.length2em(h,0)+2*this.fLine,r));var p=o(this.getBBoxHD(n),2),f=p[0],m=p[1];e.h=f,e.d=m,e.w=r;var g=o(this.getBBoxLR(),2),v=g[0],y=g[1];e.L=v,e.R=y,c.isPercent(h)||this.setColumnPWidths()},t.prototype.setChildPWidths=function(e,t,n){var r=this.node.attributes.get("width");if(!c.isPercent(r))return!1;this.hasLabels||(this.bbox.pwidth="",this.container.bbox.pwidth="");var i=this.bbox,o=i.w,a=i.L,s=i.R,l=this.node.attributes.get("data-width-includes-label"),d=Math.max(o,this.length2em(r,Math.max(t,a+o+s)))-(l?a+s:0),h=this.node.attributes.get("equalcolumns")?Array(this.numCols).fill(this.percent(1/Math.max(1,this.numCols))):this.getColumnAttributes("columnwidth",0);this.cWidths=this.getColumnWidthsFixed(h,d);var p=this.getComputedWidths();return this.pWidth=u.sum(p.concat(this.cLines,this.cSpace))+2*(this.fLine+this.fSpace[0]),this.isTop&&(this.bbox.w=this.pWidth),this.setColumnPWidths(),this.pWidth!==o&&this.parent.invalidateBBox(),this.pWidth!==o},t.prototype.setColumnPWidths=function(){var e,t,n=this.cWidths;try{for(var r=s(this.pwidthCells),i=r.next();!i.done;i=r.next()){var a=o(i.value,2),l=a[0],c=a[1];l.setChildPWidths(!1,n[c])&&(l.invalidateBBox(),l.getBBox())}}catch(t){e={error:t}}finally{try{i&&!i.done&&(t=r.return)&&t.call(r)}finally{if(e)throw e.error}}},t.prototype.getBBoxHD=function(e){var t=o(this.getAlignmentRow(),2),n=t[0],r=t[1];if(null===r){var i=this.font.params.axis_height,a=e/2;return{top:[0,e],center:[a,a],bottom:[e,0],baseline:[a,a],axis:[a+i,a-i]}[n]||[a,a]}var s=this.getVerticalPosition(r,n);return[s,e-s]},t.prototype.getBBoxLR=function(){if(this.hasLabels){var e=this.node.attributes,t=e.get("side"),n=o(this.getPadAlignShift(t),2),r=n[0],i=n[1],a=this.hasLabels&&!!e.get("data-width-includes-label");return a&&this.frame&&this.fSpace[0]&&(r-=this.fSpace[0]),"center"!==i||a?"left"===t?[r,0]:[0,r]:[r,r]}return[0,0]},t.prototype.getPadAlignShift=function(e){var t=this.getTableData().L+this.length2em(this.node.attributes.get("minlabelspacing")),n=o(null==this.styles?["",""]:[this.styles.get("padding-left"),this.styles.get("padding-right")],2),r=n[0],i=n[1];(r||i)&&(t=Math.max(t,this.length2em(r||"0"),this.length2em(i||"0")));var a=o(this.getAlignShift(),2),s=a[0],l=a[1];return s===e&&(l="left"===e?Math.max(t,l)-t:Math.min(-t,l)+t),[t,s,l]},t.prototype.getAlignShift=function(){return this.isTop?e.prototype.getAlignShift.call(this):[this.container.getChildAlign(this.containerI),0]},t.prototype.getWidth=function(){return this.pWidth||this.getBBox().w},t.prototype.getEqualRowHeight=function(){var e=this.getTableData(),t=e.H,n=e.D,r=Array.from(t.keys()).map((function(e){return t[e]+n[e]}));return Math.max.apply(Math,r)},t.prototype.getComputedWidths=function(){var e=this,t=this.getTableData().W,n=Array.from(t.keys()).map((function(n){return"number"==typeof e.cWidths[n]?e.cWidths[n]:t[n]}));return this.node.attributes.get("equalcolumns")&&(n=Array(n.length).fill(u.max(n))),n},t.prototype.getColumnWidths=function(){var e=this.node.attributes.get("width");if(this.node.attributes.get("equalcolumns"))return this.getEqualColumns(e);var t=this.getColumnAttributes("columnwidth",0);return"auto"===e?this.getColumnWidthsAuto(t):c.isPercent(e)?this.getColumnWidthsPercent(t):this.getColumnWidthsFixed(t,this.length2em(e))},t.prototype.getEqualColumns=function(e){var t,n=Math.max(1,this.numCols);if("auto"===e){var r=this.getTableData().W;t=u.max(r)}else if(c.isPercent(e))t=this.percent(1/n);else{var i=u.sum([].concat(this.cLines,this.cSpace))+2*this.fSpace[0];t=Math.max(0,this.length2em(e)-i)/n}return Array(this.numCols).fill(t)},t.prototype.getColumnWidthsAuto=function(e){var t=this;return e.map((function(e){return"auto"===e||"fit"===e?null:c.isPercent(e)?e:t.length2em(e)}))},t.prototype.getColumnWidthsPercent=function(e){var t=this,n=e.indexOf("fit")>=0,r=(n?this.getTableData():{W:null}).W;return Array.from(e.keys()).map((function(i){var o=e[i];return"fit"===o?null:"auto"===o?n?r[i]:null:c.isPercent(o)?o:t.length2em(o)}))},t.prototype.getColumnWidthsFixed=function(e,t){var n=this,r=Array.from(e.keys()),i=r.filter((function(t){return"fit"===e[t]})),o=r.filter((function(t){return"auto"===e[t]})),a=i.length||o.length,s=(a?this.getTableData():{W:null}).W,l=t-u.sum([].concat(this.cLines,this.cSpace))-2*this.fSpace[0],c=l;r.forEach((function(t){var r=e[t];c-="fit"===r||"auto"===r?s[t]:n.length2em(r,l)}));var d=a&&c>0?c/a:0;return r.map((function(t){var r=e[t];return"fit"===r?s[t]+d:"auto"===r?s[t]+(0===i.length?d:0):n.length2em(r,l)}))},t.prototype.getVerticalPosition=function(e,t){for(var n=this.node.attributes.get("equalrows"),r=this.getTableData(),i=r.H,a=r.D,s=n?this.getEqualRowHeight():0,l=this.getRowHalfSpacing(),c=this.fLine,u=0;u<e;u++)c+=l[u]+(n?s:i[u]+a[u])+l[u+1]+this.rLines[u];var d=o(n?[(s+i[e]-a[e])/2,(s-i[e]+a[e])/2]:[i[e],a[e]],2),h=d[0],p=d[1];return c+={top:0,center:l[e]+(h+p)/2,bottom:l[e]+h+p+l[e+1],baseline:l[e]+h,axis:l[e]+h-.25}[t]||0},t.prototype.getEmHalfSpacing=function(e,t,n){void 0===n&&(n=1);var r=this.em(e*n),i=this.addEm(t,2/n);return i.unshift(r),i.push(r),i},t.prototype.getRowHalfSpacing=function(){var e=this.rSpace.map((function(e){return e/2}));return e.unshift(this.fSpace[1]),e.push(this.fSpace[1]),e},t.prototype.getColumnHalfSpacing=function(){var e=this.cSpace.map((function(e){return e/2}));return e.unshift(this.fSpace[0]),e.push(this.fSpace[0]),e},t.prototype.getAlignmentRow=function(){var e=o(c.split(this.node.attributes.get("align")),2),t=e[0],n=e[1];if(null==n)return[t,null];var r=parseInt(n);return r<0&&(r+=this.numRows+1),[t,r<1||r>this.numRows?null:r-1]},t.prototype.getColumnAttributes=function(e,t){void 0===t&&(t=1);var n=this.numCols-t,r=this.getAttributeArray(e);if(0===r.length)return null;for(;r.length<n;)r.push(r[r.length-1]);return r.length>n&&r.splice(n),r},t.prototype.getRowAttributes=function(e,t){void 0===t&&(t=1);var n=this.numRows-t,r=this.getAttributeArray(e);if(0===r.length)return null;for(;r.length<n;)r.push(r[r.length-1]);return r.length>n&&r.splice(n),r},t.prototype.getAttributeArray=function(e){var t=this.node.attributes.get(e);return t?c.split(t):[this.node.attributes.getDefault(e)]},t.prototype.addEm=function(e,t){var n=this;return void 0===t&&(t=1),e?e.map((function(e){return n.em(e/t)})):null},t.prototype.convertLengths=function(e){var t=this;return e?e.map((function(e){return t.length2em(e)})):null},t}(e)}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.max=t.sum=void 0,t.sum=function(e){return e.reduce((function(e,t){return e+t}),0)},t.max=function(e){return e.reduce((function(e,t){return Math.max(e,t)}),0)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmlabeledtr=t.CHTMLmtr=void 0;var o=n(40),a=n(441),s=n(441),l=n(442),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){e.prototype.toCHTML.call(this,t);var n=this.node.attributes.get("rowalign");"baseline"!==n&&this.adaptor.setAttribute(this.chtml,"rowalign",n)},t.kind=l.MmlMtr.prototype.kind,t.styles={"mjx-mtr":{display:"table-row"},'mjx-mtr[rowalign="top"] > mjx-mtd':{"vertical-align":"top"},'mjx-mtr[rowalign="center"] > mjx-mtd':{"vertical-align":"middle"},'mjx-mtr[rowalign="bottom"] > mjx-mtd':{"vertical-align":"bottom"},'mjx-mtr[rowalign="baseline"] > mjx-mtd':{"vertical-align":"baseline"},'mjx-mtr[rowalign="axis"] > mjx-mtd':{"vertical-align":".25em"}},t}(a.CommonMtrMixin(o.CHTMLWrapper));t.CHTMLmtr=c;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){e.prototype.toCHTML.call(this,t);var n=this.adaptor.firstChild(this.chtml);if(n){this.adaptor.remove(n);var r=this.node.attributes.get("rowalign"),i="baseline"!==r&&"axis"!==r?{rowalign:r}:{},o=this.html("mjx-mtr",i,[n]);this.adaptor.append(this.parent.labels,o)}},t.prototype.markUsed=function(){e.prototype.markUsed.call(this),this.jax.wrapperUsage.add(c.kind)},t.kind=l.MmlMlabeledtr.prototype.kind,t.styles={"mjx-mlabeledtr":{display:"table-row"},'mjx-mlabeledtr[rowalign="top"] > mjx-mtd':{"vertical-align":"top"},'mjx-mlabeledtr[rowalign="center"] > mjx-mtd':{"vertical-align":"middle"},'mjx-mlabeledtr[rowalign="bottom"] > mjx-mtd':{"vertical-align":"bottom"},'mjx-mlabeledtr[rowalign="baseline"] > mjx-mtd':{"vertical-align":"baseline"},'mjx-mlabeledtr[rowalign="axis"] > mjx-mtd':{"vertical-align":".25em"}},t}(s.CommonMlabeledtrMixin(c));t.CHTMLmlabeledtr=u},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmtd=void 0;var o=n(40),a=n(872),s=n(443),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){e.prototype.toCHTML.call(this,t);var n=this.node.attributes.get("rowalign"),r=this.node.attributes.get("columnalign");n!==this.parent.node.attributes.get("rowalign")&&this.adaptor.setAttribute(this.chtml,"rowalign",n),"center"===r||"mlabeledtr"===this.parent.kind&&this===this.parent.childNodes[0]&&r===this.parent.parent.node.attributes.get("side")||this.adaptor.setStyle(this.chtml,"textAlign",r),this.parent.parent.node.getProperty("useHeight")&&this.adaptor.append(this.chtml,this.html("mjx-tstrut"))},t.kind=s.MmlMtd.prototype.kind,t.styles={"mjx-mtd":{display:"table-cell","text-align":"center",padding:".215em .4em"},"mjx-mtd:first-child":{"padding-left":0},"mjx-mtd:last-child":{"padding-right":0},"mjx-mtable > * > mjx-itable > *:first-child > mjx-mtd":{"padding-top":0},"mjx-mtable > * > mjx-itable > *:last-child > mjx-mtd":{"padding-bottom":0},"mjx-tstrut":{display:"inline-block",height:"1em","vertical-align":"-.25em"},'mjx-labels[align="left"] > mjx-mtr > mjx-mtd':{"text-align":"left"},'mjx-labels[align="right"] > mjx-mtr > mjx-mtd':{"text-align":"right"},"mjx-mtd[extra]":{padding:0},'mjx-mtd[rowalign="top"]':{"vertical-align":"top"},'mjx-mtd[rowalign="center"]':{"vertical-align":"middle"},'mjx-mtd[rowalign="bottom"]':{"vertical-align":"bottom"},'mjx-mtd[rowalign="baseline"]':{"vertical-align":"baseline"},'mjx-mtd[rowalign="axis"]':{"vertical-align":".25em"}},t}(a.CommonMtdMixin(o.CHTMLWrapper));t.CHTMLmtd=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMtdMixin=void 0,t.CommonMtdMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"fixesPWidth",{get:function(){return!1},enumerable:!1,configurable:!0}),t.prototype.invalidateBBox=function(){this.bboxComputed=!1},t.prototype.getWrapWidth=function(e){var t=this.parent.parent,n=this.parent,r=this.node.childPosition()-(n.labeled?1:0);return"number"==typeof t.cWidths[r]?t.cWidths[r]:t.getTableData().W[r]},t.prototype.getChildAlign=function(e){return this.node.attributes.get("columnalign")},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmaction=void 0;var o=n(40),a=n(444),s=n(444),l=n(445),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e);this.selected.toCHTML(t),this.action(this,this.data)},t.prototype.setEventHandler=function(e,t){this.chtml.addEventListener(e,t)},t.kind=l.MmlMaction.prototype.kind,t.styles={"mjx-maction":{position:"relative"},"mjx-maction > mjx-tool":{display:"none",position:"absolute",bottom:0,right:0,width:0,height:0,"z-index":500},"mjx-tool > mjx-tip":{display:"inline-block",padding:".2em",border:"1px solid #888","font-size":"70%","background-color":"#F8F8F8",color:"black","box-shadow":"2px 2px 5px #AAAAAA"},"mjx-maction[toggle]":{cursor:"pointer"},"mjx-status":{display:"block",position:"fixed",left:"1em",bottom:"1em","min-width":"25%",padding:".2em .4em",border:"1px solid #888","font-size":"90%","background-color":"#F8F8F8",color:"black"}},t.actions=new Map([["toggle",[function(e,t){e.adaptor.setAttribute(e.chtml,"toggle",e.node.attributes.get("selection"));var n=e.factory.jax.math,r=e.factory.jax.document,i=e.node;e.setEventHandler("click",(function(e){n.end.node||(n.start.node=n.end.node=n.typesetRoot,n.start.n=n.end.n=0),i.nextToggleSelection(),n.rerender(r),e.stopPropagation()}))},{}]],["tooltip",[function(e,t){var n=e.childNodes[1];if(n)if(n.node.isKind("mtext")){var r=n.node.getText();e.adaptor.setAttribute(e.chtml,"title",r)}else{var i=e.adaptor,o=i.append(e.chtml,e.html("mjx-tool",{style:{bottom:e.em(-e.dy),right:e.em(-e.dx)}},[e.html("mjx-tip")]));n.toCHTML(i.firstChild(o)),e.setEventHandler("mouseover",(function(n){t.stopTimers(e,t);var r=setTimeout((function(){return i.setStyle(o,"display","block")}),t.postDelay);t.hoverTimer.set(e,r),n.stopPropagation()})),e.setEventHandler("mouseout",(function(n){t.stopTimers(e,t);var r=setTimeout((function(){return i.setStyle(o,"display","")}),t.clearDelay);t.clearTimer.set(e,r),n.stopPropagation()}))}},s.TooltipData]],["statusline",[function(e,t){var n=e.childNodes[1];if(n&&n.node.isKind("mtext")){var r=e.adaptor,i=n.node.getText();r.setAttribute(e.chtml,"statusline",i),e.setEventHandler("mouseover",(function(n){if(null===t.status){var o=r.body(r.document);t.status=r.append(o,e.html("mjx-status",{},[e.text(i)]))}n.stopPropagation()})),e.setEventHandler("mouseout",(function(e){t.status&&(r.remove(t.status),t.status=null),e.stopPropagation()}))}},{status:null}]]]),t}(a.CommonMactionMixin(o.CHTMLWrapper));t.CHTMLmaction=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLmglyph=void 0;var o=n(40),a=n(875),s=n(446),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e),n=this.node.attributes.getList("src","alt"),r=n.src,i=n.alt,o={width:this.em(this.width),height:this.em(this.height)};this.valign&&(o.verticalAlign=this.em(this.valign));var a=this.html("img",{src:r,style:o,alt:i,title:i});this.adaptor.append(t,a)},t.kind=s.MmlMglyph.prototype.kind,t.styles={"mjx-mglyph > img":{display:"inline-block",border:0,padding:0}},t}(a.CommonMglyphMixin(o.CHTMLWrapper));t.CHTMLmglyph=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},a=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonMglyphMixin=void 0,t.CommonMglyphMixin=function(e){return function(e){function t(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];var r=e.apply(this,a([],o(t)))||this;return r.getParameters(),r}return i(t,e),t.prototype.getParameters=function(){var e=this.node.attributes.getList("width","height","valign"),t=e.width,n=e.height,r=e.valign;this.width="auto"===t?1:this.length2em(t),this.height="auto"===n?1:this.length2em(n),this.valign=this.length2em(r||"0")},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1),e.w=this.width,e.h=this.height+this.valign,e.d=-this.valign},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLxml=t.CHTMLannotationXML=t.CHTMLannotation=t.CHTMLsemantics=void 0;var o=n(40),a=n(877),s=n(447),l=n(23),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t=this.standardCHTMLnode(e);this.childNodes.length&&this.childNodes[0].toCHTML(t)},t.kind=s.MmlSemantics.prototype.kind,t}(a.CommonSemanticsMixin(o.CHTMLWrapper));t.CHTMLsemantics=c;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){e.prototype.toCHTML.call(this,t)},t.prototype.computeBBox=function(){return this.bbox},t.kind=s.MmlAnnotation.prototype.kind,t}(o.CHTMLWrapper);t.CHTMLannotation=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.kind=s.MmlAnnotationXML.prototype.kind,t.styles={"mjx-annotation-xml":{"font-family":"initial","line-height":"normal"}},t}(o.CHTMLWrapper);t.CHTMLannotationXML=d;var h=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){this.chtml=this.adaptor.append(e,this.adaptor.clone(this.node.getXML()))},t.prototype.computeBBox=function(e,t){void 0===t&&(t=!1);var n=this.jax.measureXMLnode(this.node.getXML()),r=n.w,i=n.h,o=n.d;e.w=r,e.h=i,e.d=o},t.prototype.getStyles=function(){},t.prototype.getScale=function(){},t.prototype.getVariant=function(){},t.kind=l.XMLNode.prototype.kind,t.autoStyle=!1,t}(o.CHTMLWrapper);t.CHTMLxml=h},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonSemanticsMixin=void 0,t.CommonSemanticsMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.computeBBox=function(e,t){if(void 0===t&&(t=!1),this.childNodes.length){var n=this.childNodes[0].getBBox(),r=n.w,i=n.h,o=n.d;e.w=r,e.h=i,e.d=o}},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLTeXAtom=void 0;var o=n(40),a=n(879),s=n(448),l=n(23),c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(t){if(e.prototype.toCHTML.call(this,t),this.adaptor.setAttribute(this.chtml,"texclass",l.TEXCLASSNAMES[this.node.texClass]),this.node.texClass===l.TEXCLASS.VCENTER){var n=this.childNodes[0].getBBox(),r=n.h,i=(r+n.d)/2+this.font.params.axis_height-r;this.adaptor.setStyle(this.chtml,"verticalAlign",this.em(i))}},t.kind=s.TeXAtom.prototype.kind,t}(a.CommonTeXAtomMixin(o.CHTMLWrapper));t.CHTMLTeXAtom=c},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CommonTeXAtomMixin=void 0;var o=n(23);t.CommonTeXAtomMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.computeBBox=function(t,n){if(void 0===n&&(n=!1),e.prototype.computeBBox.call(this,t,n),this.childNodes[0]&&this.childNodes[0].bbox.ic&&(t.ic=this.childNodes[0].bbox.ic),this.node.texClass===o.TEXCLASS.VCENTER){var r=t.h,i=(r+t.d)/2+this.font.params.axis_height-r;t.h+=i,t.d-=i}},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CHTMLTextNode=void 0;var a=n(23),s=n(40),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.toCHTML=function(e){var t,n;this.markUsed();var r=this.adaptor,i=this.parent.variant,a=this.node.getText();if("-explicitFont"===i)r.append(e,this.jax.unknownText(a,i,this.getBBox().w));else{var s=this.remappedText(a,i);try{for(var l=o(s),c=l.next();!c.done;c=l.next()){var u=c.value,d=this.getVariantChar(i,u)[3],h=d.f?" TEX-"+d.f:"",p=d.unknown?this.jax.unknownText(String.fromCodePoint(u),i):this.html("mjx-c",{class:this.char(u)+h});r.append(e,p),!d.unknown&&this.font.charUsage.add([i,u])}}catch(e){t={error:e}}finally{try{c&&!c.done&&(n=l.return)&&n.call(l)}finally{if(t)throw t.error}}}},t.kind=a.TextNode.prototype.kind,t.autoStyle=!1,t.styles={"mjx-c":{display:"inline-block"},"mjx-utext":{display:"inline-block",padding:".75em 0 .2em 0"}},t}(n(881).CommonTextNodeMixin(s.CHTMLWrapper));t.CHTMLTextNode=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonTextNodeMixin=void 0,t.CommonTextNodeMixin=function(e){return function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.computeBBox=function(e,t){var n,r;void 0===t&&(t=!1);var i=this.parent.variant,s=this.node.getText();if("-explicitFont"===i){var l=this.jax.getFontData(this.parent.styles),c=this.jax.measureText(s,i,l),u=c.w,d=c.h,h=c.d;e.h=d,e.d=h,e.w=u}else{var p=this.remappedText(s,i);e.empty();try{for(var f=o(p),m=f.next();!m.done;m=f.next()){var g=m.value,v=a(this.getVariantChar(i,g),4),y=(d=v[0],h=v[1],u=v[2],v[3]);if(y.unknown){var _=this.jax.measureText(String.fromCodePoint(g),i);u=_.w,d=_.h,h=_.d}e.w+=u,d>e.h&&(e.h=d),h>e.d&&(e.d=h),e.ic=y.ic||0,e.sk=y.sk||0,e.dx=y.dx||0}}catch(e){n={error:e}}finally{try{m&&!m.done&&(r=f.return)&&r.call(f)}finally{if(n)throw n.error}}p.length>1&&(e.sk=0),e.clean()}},t.prototype.remappedText=function(e,t){var n=this.parent.stretch.c;return n?[n]:this.parent.remapChars(this.unicodeChars(e,t))},t.prototype.getStyles=function(){},t.prototype.getVariant=function(){},t.prototype.getScale=function(){},t.prototype.getSpace=function(){},t}(e)}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.CommonTeXFontMixin=void 0,t.CommonTeXFontMixin=function(e){var t;return(t=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.getDelimiterData=function(e){return this.getChar("-smallop",e)||this.getChar("-size4",e)},t}(e)).defaultVariants=s(s([],a(e.defaultVariants)),[["-smallop","normal"],["-largeop","normal"],["-size3","normal"],["-size4","normal"],["-tex-calligraphic","italic"],["-tex-bold-calligraphic","bold-italic"],["-tex-oldstyle","normal"],["-tex-bold-oldstyle","bold"],["-tex-mathit","italic"],["-tex-variant","normal"]]),t.defaultCssFonts=o(o({},e.defaultCssFonts),{"-smallop":["serif",!1,!1],"-largeop":["serif",!1,!1],"-size3":["serif",!1,!1],"-size4":["serif",!1,!1],"-tex-calligraphic":["cursive",!0,!1],"-tex-bold-calligraphic":["cursive",!0,!0],"-tex-oldstyle":["serif",!1,!1],"-tex-bold-oldstyle":["serif",!1,!0],"-tex-mathit":["serif",!0,!1]}),t.defaultSizeVariants=["normal","-smallop","-largeop","-size3","-size4","-tex-variant"],t.defaultStretchVariants=["-size4"],t}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.boldItalic=void 0;var r=n(46),i=n(884);t.boldItalic=r.AddCSS(i.boldItalic,{305:{f:"B"},567:{f:"B"},8260:{c:"/"},8710:{c:"\\394"},10744:{c:"/"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.boldItalic=void 0,t.boldItalic={47:[.711,.21,.894],305:[.452,.008,.394,{sk:.0319}],567:[.451,.201,.439,{sk:.0958}],8260:[.711,.21,.894],8710:[.711,0,.958,{sk:.192}],10744:[.711,.21,.894]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.bold=void 0;var r=n(46),i=n(886);t.bold=r.AddCSS(i.bold,{183:{c:"\\22C5"},305:{f:""},567:{f:""},697:{c:"\\2032"},8194:{c:""},8195:{c:""},8196:{c:""},8197:{c:""},8198:{c:""},8201:{c:""},8202:{c:""},8213:{c:"\\2014"},8214:{c:"\\2225"},8215:{c:"_"},8226:{c:"\\2219"},8243:{c:"\\2032\\2032"},8244:{c:"\\2032\\2032\\2032"},8254:{c:"\\2C9"},8260:{c:"/"},8279:{c:"\\2032\\2032\\2032\\2032"},8407:{c:"\\2192",f:"VB"},8602:{c:"\\2190\\338"},8603:{c:"\\2192\\338"},8622:{c:"\\2194\\338"},8653:{c:"\\21D0\\338"},8654:{c:"\\21D4\\338"},8655:{c:"\\21D2\\338"},8708:{c:"\\2203\\338"},8710:{c:"\\394"},8716:{c:"\\220B\\338"},8740:{c:"\\2223\\338"},8742:{c:"\\2225\\338"},8769:{c:"\\223C\\338"},8772:{c:"\\2243\\338"},8775:{c:"\\2245\\338"},8777:{c:"\\2248\\338"},8802:{c:"\\2261\\338"},8813:{c:"\\224D\\338"},8814:{c:"<\\338"},8815:{c:">\\338"},8816:{c:"\\2264\\338"},8817:{c:"\\2265\\338"},8832:{c:"\\227A\\338"},8833:{c:"\\227B\\338"},8836:{c:"\\2282\\338"},8837:{c:"\\2283\\338"},8840:{c:"\\2286\\338"},8841:{c:"\\2287\\338"},8876:{c:"\\22A2\\338"},8877:{c:"\\22A8\\338"},8930:{c:"\\2291\\338"},8931:{c:"\\2292\\338"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},9653:{c:"\\25B3"},9663:{c:"\\25BD"},10072:{c:"\\2223"},10744:{c:"/",f:"BI"},10799:{c:"\\D7"},12296:{c:"\\27E8"},12297:{c:"\\27E9"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.bold=void 0,t.bold={33:[.705,0,.35],34:[.694,-.329,.603],35:[.694,.193,.958],36:[.75,.056,.575],37:[.75,.056,.958],38:[.705,.011,.894],39:[.694,-.329,.319],40:[.75,.249,.447],41:[.75,.249,.447],42:[.75,-.306,.575],43:[.633,.131,.894],44:[.171,.194,.319],45:[.278,-.166,.383],46:[.171,0,.319],47:[.75,.25,.575],58:[.444,0,.319],59:[.444,.194,.319],60:[.587,.085,.894],61:[.393,-.109,.894],62:[.587,.085,.894],63:[.7,0,.543],64:[.699,.006,.894],91:[.75,.25,.319],92:[.75,.25,.575],93:[.75,.25,.319],94:[.694,-.52,.575],95:[-.01,.061,.575],96:[.706,-.503,.575],123:[.75,.25,.575],124:[.75,.249,.319],125:[.75,.25,.575],126:[.344,-.202,.575],168:[.695,-.535,.575],172:[.371,-.061,.767],175:[.607,-.54,.575],176:[.702,-.536,.575],177:[.728,.035,.894],180:[.706,-.503,.575],183:[.336,-.166,.319],215:[.53,.028,.894],247:[.597,.096,.894],305:[.442,0,.278,{sk:.0278}],567:[.442,.205,.306,{sk:.0833}],697:[.563,-.033,.344],710:[.694,-.52,.575],711:[.66,-.515,.575],713:[.607,-.54,.575],714:[.706,-.503,.575],715:[.706,-.503,.575],728:[.694,-.5,.575],729:[.695,-.525,.575],730:[.702,-.536,.575],732:[.694,-.552,.575],768:[.706,-.503,0],769:[.706,-.503,0],770:[.694,-.52,0],771:[.694,-.552,0],772:[.607,-.54,0],774:[.694,-.5,0],775:[.695,-.525,0],776:[.695,-.535,0],778:[.702,-.536,0],779:[.714,-.511,0],780:[.66,-.515,0],824:[.711,.21,0],8194:[0,0,.5],8195:[0,0,.999],8196:[0,0,.333],8197:[0,0,.25],8198:[0,0,.167],8201:[0,0,.167],8202:[0,0,.083],8211:[.3,-.249,.575],8212:[.3,-.249,1.15],8213:[.3,-.249,1.15],8214:[.75,.248,.575],8215:[-.01,.061,.575],8216:[.694,-.329,.319],8217:[.694,-.329,.319],8220:[.694,-.329,.603],8221:[.694,-.329,.603],8224:[.702,.211,.511],8225:[.702,.202,.511],8226:[.474,-.028,.575],8230:[.171,0,1.295],8242:[.563,-.033,.344],8243:[.563,0,.688],8244:[.563,0,1.032],8254:[.607,-.54,.575],8260:[.75,.25,.575],8279:[.563,0,1.376],8407:[.723,-.513,.575],8463:[.694,.008,.668,{sk:-.0319}],8467:[.702,.019,.474,{sk:.128}],8472:[.461,.21,.74],8501:[.694,0,.703],8592:[.518,.017,1.15],8593:[.694,.193,.575],8594:[.518,.017,1.15],8595:[.694,.194,.575],8596:[.518,.017,1.15],8597:[.767,.267,.575],8598:[.724,.194,1.15],8599:[.724,.193,1.15],8600:[.694,.224,1.15],8601:[.694,.224,1.15],8602:[.711,.21,1.15],8603:[.711,.21,1.15],8614:[.518,.017,1.15],8617:[.518,.017,1.282],8618:[.518,.017,1.282],8622:[.711,.21,1.15],8636:[.518,-.22,1.15],8637:[.281,.017,1.15],8640:[.518,-.22,1.15],8641:[.281,.017,1.15],8652:[.718,.017,1.15],8653:[.711,.21,1.15],8654:[.711,.21,1.15],8655:[.711,.21,1.15],8656:[.547,.046,1.15],8657:[.694,.193,.703],8658:[.547,.046,1.15],8659:[.694,.194,.703],8660:[.547,.046,1.15],8661:[.767,.267,.703],8704:[.694,.016,.639],8707:[.694,0,.639],8708:[.711,.21,.639],8709:[.767,.073,.575],8710:[.698,0,.958],8712:[.587,.086,.767],8713:[.711,.21,.767],8715:[.587,.086,.767],8716:[.711,.21,.767],8722:[.281,-.221,.894],8723:[.537,.227,.894],8725:[.75,.25,.575],8726:[.75,.25,.575],8727:[.472,-.028,.575],8728:[.474,-.028,.575],8729:[.474,-.028,.575],8730:[.82,.18,.958,{ic:.03}],8733:[.451,.008,.894],8734:[.452,.008,1.15],8736:[.714,0,.722],8739:[.75,.249,.319],8740:[.75,.249,.319],8741:[.75,.248,.575],8742:[.75,.248,.575],8743:[.604,.017,.767],8744:[.604,.016,.767],8745:[.603,.016,.767],8746:[.604,.016,.767],8747:[.711,.211,.569,{ic:.063}],8764:[.391,-.109,.894],8768:[.583,.082,.319],8769:[.711,.21,.894],8771:[.502,0,.894],8772:[.711,.21,.894],8773:[.638,.027,.894],8775:[.711,.21,.894],8776:[.524,-.032,.894],8777:[.711,.21,.894],8781:[.533,.032,.894],8784:[.721,-.109,.894],8800:[.711,.21,.894],8801:[.505,0,.894],8802:[.711,.21,.894],8804:[.697,.199,.894],8805:[.697,.199,.894],8810:[.617,.116,1.15],8811:[.618,.116,1.15],8813:[.711,.21,.894],8814:[.711,.21,.894],8815:[.711,.21,.894],8816:[.711,.21,.894],8817:[.711,.21,.894],8826:[.585,.086,.894],8827:[.586,.086,.894],8832:[.711,.21,.894],8833:[.711,.21,.894],8834:[.587,.085,.894],8835:[.587,.086,.894],8836:[.711,.21,.894],8837:[.711,.21,.894],8838:[.697,.199,.894],8839:[.697,.199,.894],8840:[.711,.21,.894],8841:[.711,.21,.894],8846:[.604,.016,.767],8849:[.697,.199,.894],8850:[.697,.199,.894],8851:[.604,0,.767],8852:[.604,0,.767],8853:[.632,.132,.894],8854:[.632,.132,.894],8855:[.632,.132,.894],8856:[.632,.132,.894],8857:[.632,.132,.894],8866:[.693,0,.703],8867:[.693,0,.703],8868:[.694,0,.894],8869:[.693,0,.894],8872:[.75,.249,.974],8876:[.711,.21,.703],8877:[.75,.249,.974],8900:[.523,.021,.575],8901:[.336,-.166,.319],8902:[.502,0,.575],8904:[.54,.039,1],8930:[.711,.21,.894],8931:[.711,.21,.894],8942:[.951,.029,.319],8943:[.336,-.166,1.295],8945:[.871,-.101,1.323],8968:[.75,.248,.511],8969:[.75,.248,.511],8970:[.749,.248,.511],8971:[.749,.248,.511],8994:[.405,-.108,1.15],8995:[.392,-.126,1.15],9001:[.75,.249,.447],9002:[.75,.249,.447],9651:[.711,0,1.022],9653:[.711,0,1.022],9657:[.54,.039,.575],9661:[.5,.21,1.022],9663:[.5,.21,1.022],9667:[.539,.038,.575],9711:[.711,.211,1.15],9824:[.719,.129,.894],9825:[.711,.024,.894],9826:[.719,.154,.894],9827:[.719,.129,.894],9837:[.75,.017,.447],9838:[.741,.223,.447],9839:[.724,.224,.447],10072:[.75,.249,.319],10216:[.75,.249,.447],10217:[.75,.249,.447],10229:[.518,.017,1.805],10230:[.518,.017,1.833],10231:[.518,.017,2.126],10232:[.547,.046,1.868],10233:[.547,.046,1.87],10234:[.547,.046,2.126],10236:[.518,.017,1.833],10744:[.711,.21,.894],10799:[.53,.028,.894],10815:[.686,0,.9],10927:[.696,.199,.894],10928:[.697,.199,.894],12296:[.75,.249,.447],12297:[.75,.249,.447]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.doubleStruck=void 0;var r=n(888);Object.defineProperty(t,"doubleStruck",{enumerable:!0,get:function(){return r.doubleStruck}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.doubleStruck=void 0,t.doubleStruck={}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.frakturBold=void 0;var r=n(46),i=n(890);t.frakturBold=r.AddCSS(i.frakturBold,{8260:{c:"/"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.frakturBold=void 0,t.frakturBold={33:[.689,.012,.349],34:[.695,-.432,.254],38:[.696,.016,.871],39:[.695,-.436,.25],40:[.737,.186,.459],41:[.735,.187,.459],42:[.692,-.449,.328],43:[.598,.082,.893],44:[.107,.191,.328],45:[.275,-.236,.893],46:[.102,.015,.328],47:[.721,.182,.593],48:[.501,.012,.593],49:[.489,0,.593],50:[.491,0,.593],51:[.487,.193,.593],52:[.495,.196,.593],53:[.481,.19,.593],54:[.704,.012,.593],55:[.479,.197,.593],56:[.714,.005,.593],57:[.487,.195,.593],58:[.457,.012,.255],59:[.458,.19,.255],61:[.343,-.168,.582],63:[.697,.014,.428],91:[.74,.13,.257],93:[.738,.132,.257],94:[.734,-.452,.59],8216:[.708,-.411,.254],8217:[.692,-.394,.254],8260:[.721,.182,.593],58113:[.63,.027,.587],58114:[.693,.212,.394,{ic:.014}],58115:[.681,.219,.387],58116:[.473,.212,.593],58117:[.684,.027,.393],58120:[.679,.22,.981],58121:[.717,.137,.727]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.fraktur=void 0;var r=n(46),i=n(892);t.fraktur=r.AddCSS(i.fraktur,{8260:{c:"/"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.fraktur=void 0,t.fraktur={33:[.689,.012,.296],34:[.695,-.432,.215],38:[.698,.011,.738],39:[.695,-.436,.212],40:[.737,.186,.389],41:[.735,.187,.389],42:[.692,-.449,.278],43:[.598,.082,.756],44:[.107,.191,.278],45:[.275,-.236,.756],46:[.102,.015,.278],47:[.721,.182,.502],48:[.492,.013,.502],49:[.468,0,.502],50:[.474,0,.502],51:[.473,.182,.502],52:[.476,.191,.502],53:[.458,.184,.502],54:[.7,.013,.502],55:[.468,.181,.502],56:[.705,.01,.502],57:[.469,.182,.502],58:[.457,.012,.216],59:[.458,.189,.216],61:[.368,-.132,.756],63:[.693,.011,.362],91:[.74,.13,.278],93:[.738,.131,.278],94:[.734,-.452,.5],8216:[.708,-.41,.215],8217:[.692,-.395,.215],8260:[.721,.182,.502],58112:[.683,.032,.497],58113:[.616,.03,.498],58114:[.68,.215,.333],58115:[.679,.224,.329],58116:[.471,.214,.503],58117:[.686,.02,.333],58118:[.577,.021,.334,{ic:.013}],58119:[.475,.022,.501,{ic:.013}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.italic=void 0;var r=n(46),i=n(894);t.italic=r.AddCSS(i.italic,{47:{f:"I"},989:{c:"\\E008",f:"A"},8213:{c:"\\2014"},8215:{c:"_"},8260:{c:"/",f:"I"},8710:{c:"\\394",f:"I"},10744:{c:"/",f:"I"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.italic=void 0,t.italic={33:[.716,0,.307,{ic:.073}],34:[.694,-.379,.514,{ic:.024}],35:[.694,.194,.818,{ic:.01}],37:[.75,.056,.818,{ic:.029}],38:[.716,.022,.767,{ic:.035}],39:[.694,-.379,.307,{ic:.07}],40:[.75,.25,.409,{ic:.108}],41:[.75,.25,.409],42:[.75,-.32,.511,{ic:.073}],43:[.557,.057,.767],44:[.121,.194,.307],45:[.251,-.18,.358],46:[.121,0,.307],47:[.716,.215,.778],48:[.665,.021,.511,{ic:.051}],49:[.666,0,.511],50:[.666,.022,.511,{ic:.04}],51:[.666,.022,.511,{ic:.051}],52:[.666,.194,.511],53:[.666,.022,.511,{ic:.056}],54:[.665,.022,.511,{ic:.054}],55:[.666,.022,.511,{ic:.123}],56:[.666,.021,.511,{ic:.042}],57:[.666,.022,.511,{ic:.042}],58:[.431,0,.307],59:[.431,.194,.307],61:[.367,-.133,.767],63:[.716,0,.511,{ic:.04}],64:[.705,.011,.767,{ic:.022}],91:[.75,.25,.307,{ic:.139}],93:[.75,.25,.307,{ic:.052}],94:[.694,-.527,.511,{ic:.017}],95:[-.025,.062,.511,{ic:.043}],126:[.318,-.208,.511,{ic:.06}],305:[.441,.01,.307,{ic:.033}],567:[.442,.204,.332],768:[.697,-.5,0],769:[.697,-.5,0,{ic:.039}],770:[.694,-.527,0,{ic:.017}],771:[.668,-.558,0,{ic:.06}],772:[.589,-.544,0,{ic:.054}],774:[.694,-.515,0,{ic:.062}],775:[.669,-.548,0],776:[.669,-.554,0,{ic:.045}],778:[.716,-.542,0],779:[.697,-.503,0,{ic:.065}],780:[.638,-.502,0,{ic:.029}],989:[.605,.085,.778],8211:[.285,-.248,.511,{ic:.043}],8212:[.285,-.248,1.022,{ic:.016}],8213:[.285,-.248,1.022,{ic:.016}],8215:[-.025,.062,.511,{ic:.043}],8216:[.694,-.379,.307,{ic:.055}],8217:[.694,-.379,.307,{ic:.07}],8220:[.694,-.379,.514,{ic:.092}],8221:[.694,-.379,.514,{ic:.024}],8260:[.716,.215,.778],8463:[.695,.013,.54,{ic:.022}],8710:[.716,0,.833,{sk:.167}],10744:[.716,.215,.778]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.largeop=void 0;var r=n(46),i=n(896);t.largeop=r.AddCSS(i.largeop,{8214:{f:"S1"},8260:{c:"/"},8593:{f:"S1"},8595:{f:"S1"},8657:{f:"S1"},8659:{f:"S1"},8739:{f:"S1"},8741:{f:"S1"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},9168:{f:"S1"},10072:{c:"\\2223",f:"S1"},10764:{c:"\\222C\\222C"},12296:{c:"\\27E8"},12297:{c:"\\27E9"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.largeop=void 0,t.largeop={40:[1.15,.649,.597],41:[1.15,.649,.597],47:[1.15,.649,.811],91:[1.15,.649,.472],92:[1.15,.649,.811],93:[1.15,.649,.472],123:[1.15,.649,.667],125:[1.15,.649,.667],710:[.772,-.565,1],732:[.75,-.611,1],770:[.772,-.565,0],771:[.75,-.611,0],8214:[.602,0,.778],8260:[1.15,.649,.811],8593:[.6,0,.667],8595:[.6,0,.667],8657:[.599,0,.778],8659:[.6,0,.778],8719:[.95,.45,1.278],8720:[.95,.45,1.278],8721:[.95,.45,1.444],8730:[1.15,.65,1,{ic:.02}],8739:[.627,.015,.333],8741:[.627,.015,.556],8747:[1.36,.862,.556,{ic:.388}],8748:[1.36,.862,1.084,{ic:.388}],8749:[1.36,.862,1.592,{ic:.388}],8750:[1.36,.862,.556,{ic:.388}],8896:[.95,.45,1.111],8897:[.95,.45,1.111],8898:[.949,.45,1.111],8899:[.95,.449,1.111],8968:[1.15,.649,.528],8969:[1.15,.649,.528],8970:[1.15,.649,.528],8971:[1.15,.649,.528],9001:[1.15,.649,.611],9002:[1.15,.649,.611],9168:[.602,0,.667],10072:[.627,.015,.333],10216:[1.15,.649,.611],10217:[1.15,.649,.611],10752:[.949,.449,1.511],10753:[.949,.449,1.511],10754:[.949,.449,1.511],10756:[.95,.449,1.111],10758:[.95,.45,1.111],10764:[1.36,.862,2.168,{ic:.388}],12296:[1.15,.649,.611],12297:[1.15,.649,.611]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.monospace=void 0;var r=n(46),i=n(898);t.monospace=r.AddCSS(i.monospace,{697:{c:"\\2032"},913:{c:"A"},914:{c:"B"},917:{c:"E"},918:{c:"Z"},919:{c:"H"},921:{c:"I"},922:{c:"K"},924:{c:"M"},925:{c:"N"},927:{c:"O"},929:{c:"P"},932:{c:"T"},935:{c:"X"},8215:{c:"_"},8243:{c:"\\2032\\2032"},8244:{c:"\\2032\\2032\\2032"},8260:{c:"/"},8279:{c:"\\2032\\2032\\2032\\2032"},8710:{c:"\\394"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.monospace=void 0,t.monospace={32:[0,0,.525],33:[.622,0,.525],34:[.623,-.333,.525],35:[.611,0,.525],36:[.694,.082,.525],37:[.694,.083,.525],38:[.622,.011,.525],39:[.611,-.287,.525],40:[.694,.082,.525],41:[.694,.082,.525],42:[.52,-.09,.525],43:[.531,-.081,.525],44:[.14,.139,.525],45:[.341,-.271,.525],46:[.14,0,.525],47:[.694,.083,.525],58:[.431,0,.525],59:[.431,.139,.525],60:[.557,-.055,.525],61:[.417,-.195,.525],62:[.557,-.055,.525],63:[.617,0,.525],64:[.617,.006,.525],91:[.694,.082,.525],92:[.694,.083,.525],93:[.694,.082,.525],94:[.611,-.46,.525],95:[-.025,.095,.525],96:[.681,-.357,.525],123:[.694,.083,.525],124:[.694,.082,.525],125:[.694,.083,.525],126:[.611,-.466,.525],127:[.612,-.519,.525],160:[0,0,.525],305:[.431,0,.525],567:[.431,.228,.525],697:[.623,-.334,.525],768:[.611,-.485,0],769:[.611,-.485,0],770:[.611,-.46,0],771:[.611,-.466,0],772:[.577,-.5,0],774:[.611,-.504,0],776:[.612,-.519,0],778:[.619,-.499,0],780:[.577,-.449,0],913:[.623,0,.525],914:[.611,0,.525],915:[.611,0,.525],916:[.623,0,.525],917:[.611,0,.525],918:[.611,0,.525],919:[.611,0,.525],920:[.621,.01,.525],921:[.611,0,.525],922:[.611,0,.525],923:[.623,0,.525],924:[.611,0,.525],925:[.611,0,.525],926:[.611,0,.525],927:[.621,.01,.525],928:[.611,0,.525],929:[.611,0,.525],931:[.611,0,.525],932:[.611,0,.525],933:[.622,0,.525],934:[.611,0,.525],935:[.611,0,.525],936:[.611,0,.525],937:[.622,0,.525],8215:[-.025,.095,.525],8242:[.623,-.334,.525],8243:[.623,0,1.05],8244:[.623,0,1.575],8260:[.694,.083,.525],8279:[.623,0,2.1],8710:[.623,0,.525]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.normal=void 0;var r=n(46),i=n(900);t.normal=r.AddCSS(i.normal,{163:{f:"MI"},165:{f:"A"},174:{f:"A"},183:{c:"\\22C5"},240:{f:"A"},697:{c:"\\2032"},913:{c:"A"},914:{c:"B"},917:{c:"E"},918:{c:"Z"},919:{c:"H"},921:{c:"I"},922:{c:"K"},924:{c:"M"},925:{c:"N"},927:{c:"O"},929:{c:"P"},932:{c:"T"},935:{c:"X"},8192:{c:""},8193:{c:""},8194:{c:""},8195:{c:""},8196:{c:""},8197:{c:""},8198:{c:""},8201:{c:""},8202:{c:""},8203:{c:""},8204:{c:""},8213:{c:"\\2014"},8214:{c:"\\2225"},8215:{c:"_"},8226:{c:"\\2219"},8243:{c:"\\2032\\2032"},8244:{c:"\\2032\\2032\\2032"},8245:{f:"A"},8246:{c:"\\2035\\2035",f:"A"},8247:{c:"\\2035\\2035\\2035",f:"A"},8254:{c:"\\2C9"},8260:{c:"/"},8279:{c:"\\2032\\2032\\2032\\2032"},8288:{c:""},8289:{c:""},8290:{c:""},8291:{c:""},8292:{c:""},8407:{c:"\\2192",f:"V"},8450:{c:"C",f:"A"},8459:{c:"H",f:"SC"},8460:{c:"H",f:"FR"},8461:{c:"H",f:"A"},8462:{c:"h",f:"I"},8463:{f:"A"},8464:{c:"I",f:"SC"},8465:{c:"I",f:"FR"},8466:{c:"L",f:"SC"},8469:{c:"N",f:"A"},8473:{c:"P",f:"A"},8474:{c:"Q",f:"A"},8475:{c:"R",f:"SC"},8476:{c:"R",f:"FR"},8477:{c:"R",f:"A"},8484:{c:"Z",f:"A"},8486:{c:"\\3A9"},8487:{f:"A"},8488:{c:"Z",f:"FR"},8492:{c:"B",f:"SC"},8493:{c:"C",f:"FR"},8496:{c:"E",f:"SC"},8497:{c:"F",f:"SC"},8498:{f:"A"},8499:{c:"M",f:"SC"},8502:{f:"A"},8503:{f:"A"},8504:{f:"A"},8513:{f:"A"},8602:{f:"A"},8603:{f:"A"},8606:{f:"A"},8608:{f:"A"},8610:{f:"A"},8611:{f:"A"},8619:{f:"A"},8620:{f:"A"},8621:{f:"A"},8622:{f:"A"},8624:{f:"A"},8625:{f:"A"},8630:{f:"A"},8631:{f:"A"},8634:{f:"A"},8635:{f:"A"},8638:{f:"A"},8639:{f:"A"},8642:{f:"A"},8643:{f:"A"},8644:{f:"A"},8646:{f:"A"},8647:{f:"A"},8648:{f:"A"},8649:{f:"A"},8650:{f:"A"},8651:{f:"A"},8653:{f:"A"},8654:{f:"A"},8655:{f:"A"},8666:{f:"A"},8667:{f:"A"},8669:{f:"A"},8672:{f:"A"},8674:{f:"A"},8705:{f:"A"},8708:{c:"\\2203\\338"},8710:{c:"\\394"},8716:{c:"\\220B\\338"},8717:{f:"A"},8719:{f:"S1"},8720:{f:"S1"},8721:{f:"S1"},8724:{f:"A"},8737:{f:"A"},8738:{f:"A"},8740:{f:"A"},8742:{f:"A"},8748:{f:"S1"},8749:{f:"S1"},8750:{f:"S1"},8756:{f:"A"},8757:{f:"A"},8765:{f:"A"},8769:{f:"A"},8770:{f:"A"},8772:{c:"\\2243\\338"},8775:{c:"\\2246",f:"A"},8777:{c:"\\2248\\338"},8778:{f:"A"},8782:{f:"A"},8783:{f:"A"},8785:{f:"A"},8786:{f:"A"},8787:{f:"A"},8790:{f:"A"},8791:{f:"A"},8796:{f:"A"},8802:{c:"\\2261\\338"},8806:{f:"A"},8807:{f:"A"},8808:{f:"A"},8809:{f:"A"},8812:{f:"A"},8813:{c:"\\224D\\338"},8814:{f:"A"},8815:{f:"A"},8816:{f:"A"},8817:{f:"A"},8818:{f:"A"},8819:{f:"A"},8820:{c:"\\2272\\338"},8821:{c:"\\2273\\338"},8822:{f:"A"},8823:{f:"A"},8824:{c:"\\2276\\338"},8825:{c:"\\2277\\338"},8828:{f:"A"},8829:{f:"A"},8830:{f:"A"},8831:{f:"A"},8832:{f:"A"},8833:{f:"A"},8836:{c:"\\2282\\338"},8837:{c:"\\2283\\338"},8840:{f:"A"},8841:{f:"A"},8842:{f:"A"},8843:{f:"A"},8847:{f:"A"},8848:{f:"A"},8858:{f:"A"},8859:{f:"A"},8861:{f:"A"},8862:{f:"A"},8863:{f:"A"},8864:{f:"A"},8865:{f:"A"},8873:{f:"A"},8874:{f:"A"},8876:{f:"A"},8877:{f:"A"},8878:{f:"A"},8879:{f:"A"},8882:{f:"A"},8883:{f:"A"},8884:{f:"A"},8885:{f:"A"},8888:{f:"A"},8890:{f:"A"},8891:{f:"A"},8892:{f:"A"},8896:{f:"S1"},8897:{f:"S1"},8898:{f:"S1"},8899:{f:"S1"},8903:{f:"A"},8905:{f:"A"},8906:{f:"A"},8907:{f:"A"},8908:{f:"A"},8909:{f:"A"},8910:{f:"A"},8911:{f:"A"},8912:{f:"A"},8913:{f:"A"},8914:{f:"A"},8915:{f:"A"},8916:{f:"A"},8918:{f:"A"},8919:{f:"A"},8920:{f:"A"},8921:{f:"A"},8922:{f:"A"},8923:{f:"A"},8926:{f:"A"},8927:{f:"A"},8928:{f:"A"},8929:{f:"A"},8930:{c:"\\2291\\338"},8931:{c:"\\2292\\338"},8934:{f:"A"},8935:{f:"A"},8936:{f:"A"},8937:{f:"A"},8938:{f:"A"},8939:{f:"A"},8940:{f:"A"},8941:{f:"A"},8965:{c:"\\22BC",f:"A"},8966:{c:"\\2A5E",f:"A"},8988:{c:"\\250C",f:"A"},8989:{c:"\\2510",f:"A"},8990:{c:"\\2514",f:"A"},8991:{c:"\\2518",f:"A"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},9168:{f:"S1"},9416:{f:"A"},9484:{f:"A"},9488:{f:"A"},9492:{f:"A"},9496:{f:"A"},9585:{f:"A"},9586:{f:"A"},9632:{f:"A"},9633:{f:"A"},9642:{c:"\\25A0",f:"A"},9650:{f:"A"},9652:{c:"\\25B2",f:"A"},9653:{c:"\\25B3"},9654:{f:"A"},9656:{c:"\\25B6",f:"A"},9660:{f:"A"},9662:{c:"\\25BC",f:"A"},9663:{c:"\\25BD"},9664:{f:"A"},9666:{c:"\\25C0",f:"A"},9674:{f:"A"},9723:{c:"\\25A1",f:"A"},9724:{c:"\\25A0",f:"A"},9733:{f:"A"},10003:{f:"A"},10016:{f:"A"},10072:{c:"\\2223"},10731:{f:"A"},10744:{c:"/",f:"I"},10752:{f:"S1"},10753:{f:"S1"},10754:{f:"S1"},10756:{f:"S1"},10758:{f:"S1"},10764:{c:"\\222C\\222C",f:"S1"},10799:{c:"\\D7"},10846:{f:"A"},10877:{f:"A"},10878:{f:"A"},10885:{f:"A"},10886:{f:"A"},10887:{f:"A"},10888:{f:"A"},10889:{f:"A"},10890:{f:"A"},10891:{f:"A"},10892:{f:"A"},10901:{f:"A"},10902:{f:"A"},10933:{f:"A"},10934:{f:"A"},10935:{f:"A"},10936:{f:"A"},10937:{f:"A"},10938:{f:"A"},10949:{f:"A"},10950:{f:"A"},10955:{f:"A"},10956:{f:"A"},12296:{c:"\\27E8"},12297:{c:"\\27E9"},57350:{f:"A"},57351:{f:"A"},57352:{f:"A"},57353:{f:"A"},57356:{f:"A"},57357:{f:"A"},57358:{f:"A"},57359:{f:"A"},57360:{f:"A"},57361:{f:"A"},57366:{f:"A"},57367:{f:"A"},57368:{f:"A"},57369:{f:"A"},57370:{f:"A"},57371:{f:"A"},119808:{c:"A",f:"B"},119809:{c:"B",f:"B"},119810:{c:"C",f:"B"},119811:{c:"D",f:"B"},119812:{c:"E",f:"B"},119813:{c:"F",f:"B"},119814:{c:"G",f:"B"},119815:{c:"H",f:"B"},119816:{c:"I",f:"B"},119817:{c:"J",f:"B"},119818:{c:"K",f:"B"},119819:{c:"L",f:"B"},119820:{c:"M",f:"B"},119821:{c:"N",f:"B"},119822:{c:"O",f:"B"},119823:{c:"P",f:"B"},119824:{c:"Q",f:"B"},119825:{c:"R",f:"B"},119826:{c:"S",f:"B"},119827:{c:"T",f:"B"},119828:{c:"U",f:"B"},119829:{c:"V",f:"B"},119830:{c:"W",f:"B"},119831:{c:"X",f:"B"},119832:{c:"Y",f:"B"},119833:{c:"Z",f:"B"},119834:{c:"a",f:"B"},119835:{c:"b",f:"B"},119836:{c:"c",f:"B"},119837:{c:"d",f:"B"},119838:{c:"e",f:"B"},119839:{c:"f",f:"B"},119840:{c:"g",f:"B"},119841:{c:"h",f:"B"},119842:{c:"i",f:"B"},119843:{c:"j",f:"B"},119844:{c:"k",f:"B"},119845:{c:"l",f:"B"},119846:{c:"m",f:"B"},119847:{c:"n",f:"B"},119848:{c:"o",f:"B"},119849:{c:"p",f:"B"},119850:{c:"q",f:"B"},119851:{c:"r",f:"B"},119852:{c:"s",f:"B"},119853:{c:"t",f:"B"},119854:{c:"u",f:"B"},119855:{c:"v",f:"B"},119856:{c:"w",f:"B"},119857:{c:"x",f:"B"},119858:{c:"y",f:"B"},119859:{c:"z",f:"B"},119860:{c:"A",f:"I"},119861:{c:"B",f:"I"},119862:{c:"C",f:"I"},119863:{c:"D",f:"I"},119864:{c:"E",f:"I"},119865:{c:"F",f:"I"},119866:{c:"G",f:"I"},119867:{c:"H",f:"I"},119868:{c:"I",f:"I"},119869:{c:"J",f:"I"},119870:{c:"K",f:"I"},119871:{c:"L",f:"I"},119872:{c:"M",f:"I"},119873:{c:"N",f:"I"},119874:{c:"O",f:"I"},119875:{c:"P",f:"I"},119876:{c:"Q",f:"I"},119877:{c:"R",f:"I"},119878:{c:"S",f:"I"},119879:{c:"T",f:"I"},119880:{c:"U",f:"I"},119881:{c:"V",f:"I"},119882:{c:"W",f:"I"},119883:{c:"X",f:"I"},119884:{c:"Y",f:"I"},119885:{c:"Z",f:"I"},119886:{c:"a",f:"I"},119887:{c:"b",f:"I"},119888:{c:"c",f:"I"},119889:{c:"d",f:"I"},119890:{c:"e",f:"I"},119891:{c:"f",f:"I"},119892:{c:"g",f:"I"},119894:{c:"i",f:"I"},119895:{c:"j",f:"I"},119896:{c:"k",f:"I"},119897:{c:"l",f:"I"},119898:{c:"m",f:"I"},119899:{c:"n",f:"I"},119900:{c:"o",f:"I"},119901:{c:"p",f:"I"},119902:{c:"q",f:"I"},119903:{c:"r",f:"I"},119904:{c:"s",f:"I"},119905:{c:"t",f:"I"},119906:{c:"u",f:"I"},119907:{c:"v",f:"I"},119908:{c:"w",f:"I"},119909:{c:"x",f:"I"},119910:{c:"y",f:"I"},119911:{c:"z",f:"I"},119912:{c:"A",f:"BI"},119913:{c:"B",f:"BI"},119914:{c:"C",f:"BI"},119915:{c:"D",f:"BI"},119916:{c:"E",f:"BI"},119917:{c:"F",f:"BI"},119918:{c:"G",f:"BI"},119919:{c:"H",f:"BI"},119920:{c:"I",f:"BI"},119921:{c:"J",f:"BI"},119922:{c:"K",f:"BI"},119923:{c:"L",f:"BI"},119924:{c:"M",f:"BI"},119925:{c:"N",f:"BI"},119926:{c:"O",f:"BI"},119927:{c:"P",f:"BI"},119928:{c:"Q",f:"BI"},119929:{c:"R",f:"BI"},119930:{c:"S",f:"BI"},119931:{c:"T",f:"BI"},119932:{c:"U",f:"BI"},119933:{c:"V",f:"BI"},119934:{c:"W",f:"BI"},119935:{c:"X",f:"BI"},119936:{c:"Y",f:"BI"},119937:{c:"Z",f:"BI"},119938:{c:"a",f:"BI"},119939:{c:"b",f:"BI"},119940:{c:"c",f:"BI"},119941:{c:"d",f:"BI"},119942:{c:"e",f:"BI"},119943:{c:"f",f:"BI"},119944:{c:"g",f:"BI"},119945:{c:"h",f:"BI"},119946:{c:"i",f:"BI"},119947:{c:"j",f:"BI"},119948:{c:"k",f:"BI"},119949:{c:"l",f:"BI"},119950:{c:"m",f:"BI"},119951:{c:"n",f:"BI"},119952:{c:"o",f:"BI"},119953:{c:"p",f:"BI"},119954:{c:"q",f:"BI"},119955:{c:"r",f:"BI"},119956:{c:"s",f:"BI"},119957:{c:"t",f:"BI"},119958:{c:"u",f:"BI"},119959:{c:"v",f:"BI"},119960:{c:"w",f:"BI"},119961:{c:"x",f:"BI"},119962:{c:"y",f:"BI"},119963:{c:"z",f:"BI"},119964:{c:"A",f:"SC"},119966:{c:"C",f:"SC"},119967:{c:"D",f:"SC"},119970:{c:"G",f:"SC"},119973:{c:"J",f:"SC"},119974:{c:"K",f:"SC"},119977:{c:"N",f:"SC"},119978:{c:"O",f:"SC"},119979:{c:"P",f:"SC"},119980:{c:"Q",f:"SC"},119982:{c:"S",f:"SC"},119983:{c:"T",f:"SC"},119984:{c:"U",f:"SC"},119985:{c:"V",f:"SC"},119986:{c:"W",f:"SC"},119987:{c:"X",f:"SC"},119988:{c:"Y",f:"SC"},119989:{c:"Z",f:"SC"},120068:{c:"A",f:"FR"},120069:{c:"B",f:"FR"},120071:{c:"D",f:"FR"},120072:{c:"E",f:"FR"},120073:{c:"F",f:"FR"},120074:{c:"G",f:"FR"},120077:{c:"J",f:"FR"},120078:{c:"K",f:"FR"},120079:{c:"L",f:"FR"},120080:{c:"M",f:"FR"},120081:{c:"N",f:"FR"},120082:{c:"O",f:"FR"},120083:{c:"P",f:"FR"},120084:{c:"Q",f:"FR"},120086:{c:"S",f:"FR"},120087:{c:"T",f:"FR"},120088:{c:"U",f:"FR"},120089:{c:"V",f:"FR"},120090:{c:"W",f:"FR"},120091:{c:"X",f:"FR"},120092:{c:"Y",f:"FR"},120094:{c:"a",f:"FR"},120095:{c:"b",f:"FR"},120096:{c:"c",f:"FR"},120097:{c:"d",f:"FR"},120098:{c:"e",f:"FR"},120099:{c:"f",f:"FR"},120100:{c:"g",f:"FR"},120101:{c:"h",f:"FR"},120102:{c:"i",f:"FR"},120103:{c:"j",f:"FR"},120104:{c:"k",f:"FR"},120105:{c:"l",f:"FR"},120106:{c:"m",f:"FR"},120107:{c:"n",f:"FR"},120108:{c:"o",f:"FR"},120109:{c:"p",f:"FR"},120110:{c:"q",f:"FR"},120111:{c:"r",f:"FR"},120112:{c:"s",f:"FR"},120113:{c:"t",f:"FR"},120114:{c:"u",f:"FR"},120115:{c:"v",f:"FR"},120116:{c:"w",f:"FR"},120117:{c:"x",f:"FR"},120118:{c:"y",f:"FR"},120119:{c:"z",f:"FR"},120120:{c:"A",f:"A"},120121:{c:"B",f:"A"},120123:{c:"D",f:"A"},120124:{c:"E",f:"A"},120125:{c:"F",f:"A"},120126:{c:"G",f:"A"},120128:{c:"I",f:"A"},120129:{c:"J",f:"A"},120130:{c:"K",f:"A"},120131:{c:"L",f:"A"},120132:{c:"M",f:"A"},120134:{c:"O",f:"A"},120138:{c:"S",f:"A"},120139:{c:"T",f:"A"},120140:{c:"U",f:"A"},120141:{c:"V",f:"A"},120142:{c:"W",f:"A"},120143:{c:"X",f:"A"},120144:{c:"Y",f:"A"},120172:{c:"A",f:"FRB"},120173:{c:"B",f:"FRB"},120174:{c:"C",f:"FRB"},120175:{c:"D",f:"FRB"},120176:{c:"E",f:"FRB"},120177:{c:"F",f:"FRB"},120178:{c:"G",f:"FRB"},120179:{c:"H",f:"FRB"},120180:{c:"I",f:"FRB"},120181:{c:"J",f:"FRB"},120182:{c:"K",f:"FRB"},120183:{c:"L",f:"FRB"},120184:{c:"M",f:"FRB"},120185:{c:"N",f:"FRB"},120186:{c:"O",f:"FRB"},120187:{c:"P",f:"FRB"},120188:{c:"Q",f:"FRB"},120189:{c:"R",f:"FRB"},120190:{c:"S",f:"FRB"},120191:{c:"T",f:"FRB"},120192:{c:"U",f:"FRB"},120193:{c:"V",f:"FRB"},120194:{c:"W",f:"FRB"},120195:{c:"X",f:"FRB"},120196:{c:"Y",f:"FRB"},120197:{c:"Z",f:"FRB"},120198:{c:"a",f:"FRB"},120199:{c:"b",f:"FRB"},120200:{c:"c",f:"FRB"},120201:{c:"d",f:"FRB"},120202:{c:"e",f:"FRB"},120203:{c:"f",f:"FRB"},120204:{c:"g",f:"FRB"},120205:{c:"h",f:"FRB"},120206:{c:"i",f:"FRB"},120207:{c:"j",f:"FRB"},120208:{c:"k",f:"FRB"},120209:{c:"l",f:"FRB"},120210:{c:"m",f:"FRB"},120211:{c:"n",f:"FRB"},120212:{c:"o",f:"FRB"},120213:{c:"p",f:"FRB"},120214:{c:"q",f:"FRB"},120215:{c:"r",f:"FRB"},120216:{c:"s",f:"FRB"},120217:{c:"t",f:"FRB"},120218:{c:"u",f:"FRB"},120219:{c:"v",f:"FRB"},120220:{c:"w",f:"FRB"},120221:{c:"x",f:"FRB"},120222:{c:"y",f:"FRB"},120223:{c:"z",f:"FRB"},120224:{c:"A",f:"SS"},120225:{c:"B",f:"SS"},120226:{c:"C",f:"SS"},120227:{c:"D",f:"SS"},120228:{c:"E",f:"SS"},120229:{c:"F",f:"SS"},120230:{c:"G",f:"SS"},120231:{c:"H",f:"SS"},120232:{c:"I",f:"SS"},120233:{c:"J",f:"SS"},120234:{c:"K",f:"SS"},120235:{c:"L",f:"SS"},120236:{c:"M",f:"SS"},120237:{c:"N",f:"SS"},120238:{c:"O",f:"SS"},120239:{c:"P",f:"SS"},120240:{c:"Q",f:"SS"},120241:{c:"R",f:"SS"},120242:{c:"S",f:"SS"},120243:{c:"T",f:"SS"},120244:{c:"U",f:"SS"},120245:{c:"V",f:"SS"},120246:{c:"W",f:"SS"},120247:{c:"X",f:"SS"},120248:{c:"Y",f:"SS"},120249:{c:"Z",f:"SS"},120250:{c:"a",f:"SS"},120251:{c:"b",f:"SS"},120252:{c:"c",f:"SS"},120253:{c:"d",f:"SS"},120254:{c:"e",f:"SS"},120255:{c:"f",f:"SS"},120256:{c:"g",f:"SS"},120257:{c:"h",f:"SS"},120258:{c:"i",f:"SS"},120259:{c:"j",f:"SS"},120260:{c:"k",f:"SS"},120261:{c:"l",f:"SS"},120262:{c:"m",f:"SS"},120263:{c:"n",f:"SS"},120264:{c:"o",f:"SS"},120265:{c:"p",f:"SS"},120266:{c:"q",f:"SS"},120267:{c:"r",f:"SS"},120268:{c:"s",f:"SS"},120269:{c:"t",f:"SS"},120270:{c:"u",f:"SS"},120271:{c:"v",f:"SS"},120272:{c:"w",f:"SS"},120273:{c:"x",f:"SS"},120274:{c:"y",f:"SS"},120275:{c:"z",f:"SS"},120276:{c:"A",f:"SSB"},120277:{c:"B",f:"SSB"},120278:{c:"C",f:"SSB"},120279:{c:"D",f:"SSB"},120280:{c:"E",f:"SSB"},120281:{c:"F",f:"SSB"},120282:{c:"G",f:"SSB"},120283:{c:"H",f:"SSB"},120284:{c:"I",f:"SSB"},120285:{c:"J",f:"SSB"},120286:{c:"K",f:"SSB"},120287:{c:"L",f:"SSB"},120288:{c:"M",f:"SSB"},120289:{c:"N",f:"SSB"},120290:{c:"O",f:"SSB"},120291:{c:"P",f:"SSB"},120292:{c:"Q",f:"SSB"},120293:{c:"R",f:"SSB"},120294:{c:"S",f:"SSB"},120295:{c:"T",f:"SSB"},120296:{c:"U",f:"SSB"},120297:{c:"V",f:"SSB"},120298:{c:"W",f:"SSB"},120299:{c:"X",f:"SSB"},120300:{c:"Y",f:"SSB"},120301:{c:"Z",f:"SSB"},120302:{c:"a",f:"SSB"},120303:{c:"b",f:"SSB"},120304:{c:"c",f:"SSB"},120305:{c:"d",f:"SSB"},120306:{c:"e",f:"SSB"},120307:{c:"f",f:"SSB"},120308:{c:"g",f:"SSB"},120309:{c:"h",f:"SSB"},120310:{c:"i",f:"SSB"},120311:{c:"j",f:"SSB"},120312:{c:"k",f:"SSB"},120313:{c:"l",f:"SSB"},120314:{c:"m",f:"SSB"},120315:{c:"n",f:"SSB"},120316:{c:"o",f:"SSB"},120317:{c:"p",f:"SSB"},120318:{c:"q",f:"SSB"},120319:{c:"r",f:"SSB"},120320:{c:"s",f:"SSB"},120321:{c:"t",f:"SSB"},120322:{c:"u",f:"SSB"},120323:{c:"v",f:"SSB"},120324:{c:"w",f:"SSB"},120325:{c:"x",f:"SSB"},120326:{c:"y",f:"SSB"},120327:{c:"z",f:"SSB"},120328:{c:"A",f:"SSI"},120329:{c:"B",f:"SSI"},120330:{c:"C",f:"SSI"},120331:{c:"D",f:"SSI"},120332:{c:"E",f:"SSI"},120333:{c:"F",f:"SSI"},120334:{c:"G",f:"SSI"},120335:{c:"H",f:"SSI"},120336:{c:"I",f:"SSI"},120337:{c:"J",f:"SSI"},120338:{c:"K",f:"SSI"},120339:{c:"L",f:"SSI"},120340:{c:"M",f:"SSI"},120341:{c:"N",f:"SSI"},120342:{c:"O",f:"SSI"},120343:{c:"P",f:"SSI"},120344:{c:"Q",f:"SSI"},120345:{c:"R",f:"SSI"},120346:{c:"S",f:"SSI"},120347:{c:"T",f:"SSI"},120348:{c:"U",f:"SSI"},120349:{c:"V",f:"SSI"},120350:{c:"W",f:"SSI"},120351:{c:"X",f:"SSI"},120352:{c:"Y",f:"SSI"},120353:{c:"Z",f:"SSI"},120354:{c:"a",f:"SSI"},120355:{c:"b",f:"SSI"},120356:{c:"c",f:"SSI"},120357:{c:"d",f:"SSI"},120358:{c:"e",f:"SSI"},120359:{c:"f",f:"SSI"},120360:{c:"g",f:"SSI"},120361:{c:"h",f:"SSI"},120362:{c:"i",f:"SSI"},120363:{c:"j",f:"SSI"},120364:{c:"k",f:"SSI"},120365:{c:"l",f:"SSI"},120366:{c:"m",f:"SSI"},120367:{c:"n",f:"SSI"},120368:{c:"o",f:"SSI"},120369:{c:"p",f:"SSI"},120370:{c:"q",f:"SSI"},120371:{c:"r",f:"SSI"},120372:{c:"s",f:"SSI"},120373:{c:"t",f:"SSI"},120374:{c:"u",f:"SSI"},120375:{c:"v",f:"SSI"},120376:{c:"w",f:"SSI"},120377:{c:"x",f:"SSI"},120378:{c:"y",f:"SSI"},120379:{c:"z",f:"SSI"},120432:{c:"A",f:"T"},120433:{c:"B",f:"T"},120434:{c:"C",f:"T"},120435:{c:"D",f:"T"},120436:{c:"E",f:"T"},120437:{c:"F",f:"T"},120438:{c:"G",f:"T"},120439:{c:"H",f:"T"},120440:{c:"I",f:"T"},120441:{c:"J",f:"T"},120442:{c:"K",f:"T"},120443:{c:"L",f:"T"},120444:{c:"M",f:"T"},120445:{c:"N",f:"T"},120446:{c:"O",f:"T"},120447:{c:"P",f:"T"},120448:{c:"Q",f:"T"},120449:{c:"R",f:"T"},120450:{c:"S",f:"T"},120451:{c:"T",f:"T"},120452:{c:"U",f:"T"},120453:{c:"V",f:"T"},120454:{c:"W",f:"T"},120455:{c:"X",f:"T"},120456:{c:"Y",f:"T"},120457:{c:"Z",f:"T"},120458:{c:"a",f:"T"},120459:{c:"b",f:"T"},120460:{c:"c",f:"T"},120461:{c:"d",f:"T"},120462:{c:"e",f:"T"},120463:{c:"f",f:"T"},120464:{c:"g",f:"T"},120465:{c:"h",f:"T"},120466:{c:"i",f:"T"},120467:{c:"j",f:"T"},120468:{c:"k",f:"T"},120469:{c:"l",f:"T"},120470:{c:"m",f:"T"},120471:{c:"n",f:"T"},120472:{c:"o",f:"T"},120473:{c:"p",f:"T"},120474:{c:"q",f:"T"},120475:{c:"r",f:"T"},120476:{c:"s",f:"T"},120477:{c:"t",f:"T"},120478:{c:"u",f:"T"},120479:{c:"v",f:"T"},120480:{c:"w",f:"T"},120481:{c:"x",f:"T"},120482:{c:"y",f:"T"},120483:{c:"z",f:"T"},120488:{c:"A",f:"B"},120489:{c:"B",f:"B"},120490:{c:"\\393",f:"B"},120491:{c:"\\394",f:"B"},120492:{c:"E",f:"B"},120493:{c:"Z",f:"B"},120494:{c:"H",f:"B"},120495:{c:"\\398",f:"B"},120496:{c:"I",f:"B"},120497:{c:"K",f:"B"},120498:{c:"\\39B",f:"B"},120499:{c:"M",f:"B"},120500:{c:"N",f:"B"},120501:{c:"\\39E",f:"B"},120502:{c:"O",f:"B"},120503:{c:"\\3A0",f:"B"},120504:{c:"P",f:"B"},120506:{c:"\\3A3",f:"B"},120507:{c:"T",f:"B"},120508:{c:"\\3A5",f:"B"},120509:{c:"\\3A6",f:"B"},120510:{c:"X",f:"B"},120511:{c:"\\3A8",f:"B"},120512:{c:"\\3A9",f:"B"},120513:{c:"\\2207",f:"B"},120546:{c:"A",f:"I"},120547:{c:"B",f:"I"},120548:{c:"\\393",f:"I"},120549:{c:"\\394",f:"I"},120550:{c:"E",f:"I"},120551:{c:"Z",f:"I"},120552:{c:"H",f:"I"},120553:{c:"\\398",f:"I"},120554:{c:"I",f:"I"},120555:{c:"K",f:"I"},120556:{c:"\\39B",f:"I"},120557:{c:"M",f:"I"},120558:{c:"N",f:"I"},120559:{c:"\\39E",f:"I"},120560:{c:"O",f:"I"},120561:{c:"\\3A0",f:"I"},120562:{c:"P",f:"I"},120564:{c:"\\3A3",f:"I"},120565:{c:"T",f:"I"},120566:{c:"\\3A5",f:"I"},120567:{c:"\\3A6",f:"I"},120568:{c:"X",f:"I"},120569:{c:"\\3A8",f:"I"},120570:{c:"\\3A9",f:"I"},120572:{c:"\\3B1",f:"I"},120573:{c:"\\3B2",f:"I"},120574:{c:"\\3B3",f:"I"},120575:{c:"\\3B4",f:"I"},120576:{c:"\\3B5",f:"I"},120577:{c:"\\3B6",f:"I"},120578:{c:"\\3B7",f:"I"},120579:{c:"\\3B8",f:"I"},120580:{c:"\\3B9",f:"I"},120581:{c:"\\3BA",f:"I"},120582:{c:"\\3BB",f:"I"},120583:{c:"\\3BC",f:"I"},120584:{c:"\\3BD",f:"I"},120585:{c:"\\3BE",f:"I"},120586:{c:"\\3BF",f:"I"},120587:{c:"\\3C0",f:"I"},120588:{c:"\\3C1",f:"I"},120589:{c:"\\3C2",f:"I"},120590:{c:"\\3C3",f:"I"},120591:{c:"\\3C4",f:"I"},120592:{c:"\\3C5",f:"I"},120593:{c:"\\3C6",f:"I"},120594:{c:"\\3C7",f:"I"},120595:{c:"\\3C8",f:"I"},120596:{c:"\\3C9",f:"I"},120597:{c:"\\2202"},120598:{c:"\\3F5",f:"I"},120599:{c:"\\3D1",f:"I"},120600:{c:"\\E009",f:"A"},120601:{c:"\\3D5",f:"I"},120602:{c:"\\3F1",f:"I"},120603:{c:"\\3D6",f:"I"},120604:{c:"A",f:"BI"},120605:{c:"B",f:"BI"},120606:{c:"\\393",f:"BI"},120607:{c:"\\394",f:"BI"},120608:{c:"E",f:"BI"},120609:{c:"Z",f:"BI"},120610:{c:"H",f:"BI"},120611:{c:"\\398",f:"BI"},120612:{c:"I",f:"BI"},120613:{c:"K",f:"BI"},120614:{c:"\\39B",f:"BI"},120615:{c:"M",f:"BI"},120616:{c:"N",f:"BI"},120617:{c:"\\39E",f:"BI"},120618:{c:"O",f:"BI"},120619:{c:"\\3A0",f:"BI"},120620:{c:"P",f:"BI"},120622:{c:"\\3A3",f:"BI"},120623:{c:"T",f:"BI"},120624:{c:"\\3A5",f:"BI"},120625:{c:"\\3A6",f:"BI"},120626:{c:"X",f:"BI"},120627:{c:"\\3A8",f:"BI"},120628:{c:"\\3A9",f:"BI"},120630:{c:"\\3B1",f:"BI"},120631:{c:"\\3B2",f:"BI"},120632:{c:"\\3B3",f:"BI"},120633:{c:"\\3B4",f:"BI"},120634:{c:"\\3B5",f:"BI"},120635:{c:"\\3B6",f:"BI"},120636:{c:"\\3B7",f:"BI"},120637:{c:"\\3B8",f:"BI"},120638:{c:"\\3B9",f:"BI"},120639:{c:"\\3BA",f:"BI"},120640:{c:"\\3BB",f:"BI"},120641:{c:"\\3BC",f:"BI"},120642:{c:"\\3BD",f:"BI"},120643:{c:"\\3BE",f:"BI"},120644:{c:"\\3BF",f:"BI"},120645:{c:"\\3C0",f:"BI"},120646:{c:"\\3C1",f:"BI"},120647:{c:"\\3C2",f:"BI"},120648:{c:"\\3C3",f:"BI"},120649:{c:"\\3C4",f:"BI"},120650:{c:"\\3C5",f:"BI"},120651:{c:"\\3C6",f:"BI"},120652:{c:"\\3C7",f:"BI"},120653:{c:"\\3C8",f:"BI"},120654:{c:"\\3C9",f:"BI"},120655:{c:"\\2202",f:"B"},120656:{c:"\\3F5",f:"BI"},120657:{c:"\\3D1",f:"BI"},120658:{c:"\\E009",f:"A"},120659:{c:"\\3D5",f:"BI"},120660:{c:"\\3F1",f:"BI"},120661:{c:"\\3D6",f:"BI"},120662:{c:"A",f:"SSB"},120663:{c:"B",f:"SSB"},120664:{c:"\\393",f:"SSB"},120665:{c:"\\394",f:"SSB"},120666:{c:"E",f:"SSB"},120667:{c:"Z",f:"SSB"},120668:{c:"H",f:"SSB"},120669:{c:"\\398",f:"SSB"},120670:{c:"I",f:"SSB"},120671:{c:"K",f:"SSB"},120672:{c:"\\39B",f:"SSB"},120673:{c:"M",f:"SSB"},120674:{c:"N",f:"SSB"},120675:{c:"\\39E",f:"SSB"},120676:{c:"O",f:"SSB"},120677:{c:"\\3A0",f:"SSB"},120678:{c:"P",f:"SSB"},120680:{c:"\\3A3",f:"SSB"},120681:{c:"T",f:"SSB"},120682:{c:"\\3A5",f:"SSB"},120683:{c:"\\3A6",f:"SSB"},120684:{c:"X",f:"SSB"},120685:{c:"\\3A8",f:"SSB"},120686:{c:"\\3A9",f:"SSB"},120782:{c:"0",f:"B"},120783:{c:"1",f:"B"},120784:{c:"2",f:"B"},120785:{c:"3",f:"B"},120786:{c:"4",f:"B"},120787:{c:"5",f:"B"},120788:{c:"6",f:"B"},120789:{c:"7",f:"B"},120790:{c:"8",f:"B"},120791:{c:"9",f:"B"},120802:{c:"0",f:"SS"},120803:{c:"1",f:"SS"},120804:{c:"2",f:"SS"},120805:{c:"3",f:"SS"},120806:{c:"4",f:"SS"},120807:{c:"5",f:"SS"},120808:{c:"6",f:"SS"},120809:{c:"7",f:"SS"},120810:{c:"8",f:"SS"},120811:{c:"9",f:"SS"},120812:{c:"0",f:"SSB"},120813:{c:"1",f:"SSB"},120814:{c:"2",f:"SSB"},120815:{c:"3",f:"SSB"},120816:{c:"4",f:"SSB"},120817:{c:"5",f:"SSB"},120818:{c:"6",f:"SSB"},120819:{c:"7",f:"SSB"},120820:{c:"8",f:"SSB"},120821:{c:"9",f:"SSB"},120822:{c:"0",f:"T"},120823:{c:"1",f:"T"},120824:{c:"2",f:"T"},120825:{c:"3",f:"T"},120826:{c:"4",f:"T"},120827:{c:"5",f:"T"},120828:{c:"6",f:"T"},120829:{c:"7",f:"T"},120830:{c:"8",f:"T"},120831:{c:"9",f:"T"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.normal=void 0,t.normal={32:[0,0,.25],33:[.716,0,.278],34:[.694,-.379,.5],35:[.694,.194,.833],36:[.75,.056,.5],37:[.75,.056,.833],38:[.716,.022,.778],39:[.694,-.379,.278],40:[.75,.25,.389],41:[.75,.25,.389],42:[.75,-.32,.5],43:[.583,.082,.778],44:[.121,.194,.278],45:[.252,-.179,.333],46:[.12,0,.278],47:[.75,.25,.5],48:[.666,.022,.5],49:[.666,0,.5],50:[.666,0,.5],51:[.665,.022,.5],52:[.677,0,.5],53:[.666,.022,.5],54:[.666,.022,.5],55:[.676,.022,.5],56:[.666,.022,.5],57:[.666,.022,.5],58:[.43,0,.278],59:[.43,.194,.278],60:[.54,.04,.778],61:[.583,.082,.778],62:[.54,.04,.778],63:[.705,0,.472],64:[.705,.011,.778],65:[.716,0,.75],66:[.683,0,.708],67:[.705,.021,.722],68:[.683,0,.764],69:[.68,0,.681],70:[.68,0,.653],71:[.705,.022,.785],72:[.683,0,.75],73:[.683,0,.361],74:[.683,.022,.514],75:[.683,0,.778],76:[.683,0,.625],77:[.683,0,.917],78:[.683,0,.75],79:[.705,.022,.778],80:[.683,0,.681],81:[.705,.193,.778],82:[.683,.022,.736],83:[.705,.022,.556],84:[.677,0,.722],85:[.683,.022,.75],86:[.683,.022,.75],87:[.683,.022,1.028],88:[.683,0,.75],89:[.683,0,.75],90:[.683,0,.611],91:[.75,.25,.278],92:[.75,.25,.5],93:[.75,.25,.278],94:[.694,-.531,.5],95:[-.025,.062,.5],96:[.699,-.505,.5],97:[.448,.011,.5],98:[.694,.011,.556],99:[.448,.011,.444],100:[.694,.011,.556],101:[.448,.011,.444],102:[.705,0,.306,{ic:.066}],103:[.453,.206,.5],104:[.694,0,.556],105:[.669,0,.278],106:[.669,.205,.306],107:[.694,0,.528],108:[.694,0,.278],109:[.442,0,.833],110:[.442,0,.556],111:[.448,.01,.5],112:[.442,.194,.556],113:[.442,.194,.528],114:[.442,0,.392],115:[.448,.011,.394],116:[.615,.01,.389],117:[.442,.011,.556],118:[.431,.011,.528],119:[.431,.011,.722],120:[.431,0,.528],121:[.431,.204,.528],122:[.431,0,.444],123:[.75,.25,.5],124:[.75,.249,.278],125:[.75,.25,.5],126:[.318,-.215,.5],160:[0,0,.25],163:[.714,.011,.769],165:[.683,0,.75],168:[.669,-.554,.5],172:[.356,-.089,.667],174:[.709,.175,.947],175:[.59,-.544,.5],176:[.715,-.542,.5],177:[.666,0,.778],180:[.699,-.505,.5],183:[.31,-.19,.278],215:[.491,-.009,.778],240:[.749,.021,.556],247:[.537,.036,.778],305:[.442,0,.278,{sk:.0278}],567:[.442,.205,.306,{sk:.0833}],697:[.56,-.043,.275],710:[.694,-.531,.5],711:[.644,-.513,.5],713:[.59,-.544,.5],714:[.699,-.505,.5],715:[.699,-.505,.5],728:[.694,-.515,.5],729:[.669,-.549,.5],730:[.715,-.542,.5],732:[.668,-.565,.5],768:[.699,-.505,0],769:[.699,-.505,0],770:[.694,-.531,0],771:[.668,-.565,0],772:[.59,-.544,0],774:[.694,-.515,0],775:[.669,-.549,0],776:[.669,-.554,0],778:[.715,-.542,0],779:[.701,-.51,0],780:[.644,-.513,0],824:[.716,.215,0],913:[.716,0,.75],914:[.683,0,.708],915:[.68,0,.625],916:[.716,0,.833],917:[.68,0,.681],918:[.683,0,.611],919:[.683,0,.75],920:[.705,.022,.778],921:[.683,0,.361],922:[.683,0,.778],923:[.716,0,.694],924:[.683,0,.917],925:[.683,0,.75],926:[.677,0,.667],927:[.705,.022,.778],928:[.68,0,.75],929:[.683,0,.681],931:[.683,0,.722],932:[.677,0,.722],933:[.705,0,.778],934:[.683,0,.722],935:[.683,0,.75],936:[.683,0,.778],937:[.704,0,.722],8192:[0,0,.5],8193:[0,0,1],8194:[0,0,.5],8195:[0,0,1],8196:[0,0,.333],8197:[0,0,.25],8198:[0,0,.167],8201:[0,0,.167],8202:[0,0,.1],8203:[0,0,0],8204:[0,0,0],8211:[.285,-.248,.5],8212:[.285,-.248,1],8213:[.285,-.248,1],8214:[.75,.25,.5],8215:[-.025,.062,.5],8216:[.694,-.379,.278],8217:[.694,-.379,.278],8220:[.694,-.379,.5],8221:[.694,-.379,.5],8224:[.705,.216,.444],8225:[.705,.205,.444],8226:[.444,-.055,.5],8230:[.12,0,1.172],8242:[.56,-.043,.275],8243:[.56,0,.55],8244:[.56,0,.825],8245:[.56,-.043,.275],8246:[.56,0,.55],8247:[.56,0,.825],8254:[.59,-.544,.5],8260:[.75,.25,.5],8279:[.56,0,1.1],8288:[0,0,0],8289:[0,0,0],8290:[0,0,0],8291:[0,0,0],8292:[0,0,0],8407:[.714,-.516,.5],8450:[.702,.019,.722],8459:[.717,.036,.969,{ic:.272,sk:.333}],8460:[.666,.133,.72],8461:[.683,0,.778],8462:[.694,.011,.576,{sk:-.0278}],8463:[.695,.013,.54,{ic:.022}],8464:[.717,.017,.809,{ic:.137,sk:.333}],8465:[.686,.026,.554],8466:[.717,.017,.874,{ic:.161,sk:.306}],8467:[.705,.02,.417,{sk:.111}],8469:[.683,.02,.722],8472:[.453,.216,.636,{sk:.111}],8473:[.683,0,.611],8474:[.701,.181,.778],8475:[.717,.017,.85,{ic:.037,sk:.194}],8476:[.686,.026,.828],8477:[.683,0,.722],8484:[.683,0,.667],8486:[.704,0,.722],8487:[.684,.022,.722],8488:[.729,.139,.602],8492:[.708,.028,.908,{ic:.02,sk:.194}],8493:[.685,.024,.613],8496:[.707,.008,.562,{ic:.156,sk:.139}],8497:[.735,.036,.895,{ic:.095,sk:.222}],8498:[.695,0,.556],8499:[.721,.05,1.08,{ic:.136,sk:.444}],8501:[.694,0,.611],8502:[.763,.021,.667,{ic:.02}],8503:[.764,.043,.444],8504:[.764,.043,.667],8513:[.705,.023,.639],8592:[.511,.011,1],8593:[.694,.193,.5],8594:[.511,.011,1],8595:[.694,.194,.5],8596:[.511,.011,1],8597:[.772,.272,.5],8598:[.72,.195,1],8599:[.72,.195,1],8600:[.695,.22,1],8601:[.695,.22,1],8602:[.437,-.06,1],8603:[.437,-.06,1],8606:[.417,-.083,1],8608:[.417,-.083,1],8610:[.417,-.083,1.111],8611:[.417,-.083,1.111],8614:[.511,.011,1],8617:[.511,.011,1.126],8618:[.511,.011,1.126],8619:[.575,.041,1],8620:[.575,.041,1],8621:[.417,-.083,1.389],8622:[.437,-.06,1],8624:[.722,0,.5],8625:[.722,0,.5],8630:[.461,0,1],8631:[.46,0,1],8634:[.65,.083,.778],8635:[.65,.083,.778],8636:[.511,-.23,1],8637:[.27,.011,1],8638:[.694,.194,.417],8639:[.694,.194,.417],8640:[.511,-.23,1],8641:[.27,.011,1],8642:[.694,.194,.417],8643:[.694,.194,.417],8644:[.667,0,1],8646:[.667,0,1],8647:[.583,.083,1],8648:[.694,.193,.833],8649:[.583,.083,1],8650:[.694,.194,.833],8651:[.514,.014,1],8652:[.671,.011,1],8653:[.534,.035,1],8654:[.534,.037,1],8655:[.534,.035,1],8656:[.525,.024,1],8657:[.694,.194,.611],8658:[.525,.024,1],8659:[.694,.194,.611],8660:[.526,.025,1],8661:[.772,.272,.611],8666:[.611,.111,1],8667:[.611,.111,1],8669:[.417,-.083,1],8672:[.437,-.064,1.334],8674:[.437,-.064,1.334],8704:[.694,.022,.556],8705:[.846,.021,.5],8706:[.715,.022,.531,{ic:.035,sk:.0833}],8707:[.694,0,.556],8708:[.716,.215,.556],8709:[.772,.078,.5],8710:[.716,0,.833],8711:[.683,.033,.833],8712:[.54,.04,.667],8713:[.716,.215,.667],8715:[.54,.04,.667],8716:[.716,.215,.667],8717:[.44,0,.429,{ic:.027}],8719:[.75,.25,.944],8720:[.75,.25,.944],8721:[.75,.25,1.056],8722:[.583,.082,.778],8723:[.5,.166,.778],8724:[.766,.093,.778],8725:[.75,.25,.5],8726:[.75,.25,.5],8727:[.465,-.035,.5],8728:[.444,-.055,.5],8729:[.444,-.055,.5],8730:[.8,.2,.833,{ic:.02}],8733:[.442,.011,.778],8734:[.442,.011,1],8736:[.694,0,.722],8737:[.714,.02,.722],8738:[.551,.051,.722],8739:[.75,.249,.278],8740:[.75,.252,.278,{ic:.019}],8741:[.75,.25,.5],8742:[.75,.25,.5,{ic:.018}],8743:[.598,.022,.667],8744:[.598,.022,.667],8745:[.598,.022,.667],8746:[.598,.022,.667],8747:[.716,.216,.417,{ic:.055}],8748:[.805,.306,.819,{ic:.138}],8749:[.805,.306,1.166,{ic:.138}],8750:[.805,.306,.472,{ic:.138}],8756:[.471,.082,.667],8757:[.471,.082,.667],8764:[.367,-.133,.778],8765:[.367,-.133,.778],8768:[.583,.083,.278],8769:[.467,-.032,.778],8770:[.463,-.034,.778],8771:[.464,-.036,.778],8772:[.716,.215,.778],8773:[.589,-.022,.778],8775:[.652,.155,.778],8776:[.483,-.055,.778],8777:[.716,.215,.778],8778:[.579,.039,.778],8781:[.484,-.016,.778],8782:[.492,-.008,.778],8783:[.492,-.133,.778],8784:[.67,-.133,.778],8785:[.609,.108,.778],8786:[.601,.101,.778],8787:[.601,.102,.778],8790:[.367,-.133,.778],8791:[.721,-.133,.778],8796:[.859,-.133,.778],8800:[.716,.215,.778],8801:[.464,-.036,.778],8802:[.716,.215,.778],8804:[.636,.138,.778],8805:[.636,.138,.778],8806:[.753,.175,.778],8807:[.753,.175,.778],8808:[.752,.286,.778],8809:[.752,.286,.778],8810:[.568,.067,1],8811:[.567,.067,1],8812:[.75,.25,.5],8813:[.716,.215,.778],8814:[.708,.209,.778],8815:[.708,.209,.778],8816:[.801,.303,.778],8817:[.801,.303,.778],8818:[.732,.228,.778],8819:[.732,.228,.778],8820:[.732,.228,.778],8821:[.732,.228,.778],8822:[.681,.253,.778],8823:[.681,.253,.778],8824:[.716,.253,.778],8825:[.716,.253,.778],8826:[.539,.041,.778],8827:[.539,.041,.778],8828:[.58,.153,.778],8829:[.58,.154,.778],8830:[.732,.228,.778],8831:[.732,.228,.778],8832:[.705,.208,.778],8833:[.705,.208,.778],8834:[.54,.04,.778],8835:[.54,.04,.778],8836:[.716,.215,.778],8837:[.716,.215,.778],8838:[.636,.138,.778],8839:[.636,.138,.778],8840:[.801,.303,.778],8841:[.801,.303,.778],8842:[.635,.241,.778],8843:[.635,.241,.778],8846:[.598,.022,.667],8847:[.539,.041,.778],8848:[.539,.041,.778],8849:[.636,.138,.778],8850:[.636,.138,.778],8851:[.598,0,.667],8852:[.598,0,.667],8853:[.583,.083,.778],8854:[.583,.083,.778],8855:[.583,.083,.778],8856:[.583,.083,.778],8857:[.583,.083,.778],8858:[.582,.082,.778],8859:[.582,.082,.778],8861:[.582,.082,.778],8862:[.689,0,.778],8863:[.689,0,.778],8864:[.689,0,.778],8865:[.689,0,.778],8866:[.694,0,.611],8867:[.694,0,.611],8868:[.668,0,.778],8869:[.668,0,.778],8872:[.75,.249,.867],8873:[.694,0,.722],8874:[.694,0,.889],8876:[.695,0,.611],8877:[.695,0,.611],8878:[.695,0,.722],8879:[.695,0,.722],8882:[.539,.041,.778],8883:[.539,.041,.778],8884:[.636,.138,.778],8885:[.636,.138,.778],8888:[.408,-.092,1.111],8890:[.431,.212,.556],8891:[.716,0,.611],8892:[.716,0,.611],8896:[.75,.249,.833],8897:[.75,.249,.833],8898:[.75,.249,.833],8899:[.75,.249,.833],8900:[.488,-.012,.5],8901:[.31,-.19,.278],8902:[.486,-.016,.5],8903:[.545,.044,.778],8904:[.505,.005,.9],8905:[.492,-.008,.778],8906:[.492,-.008,.778],8907:[.694,.022,.778],8908:[.694,.022,.778],8909:[.464,-.036,.778],8910:[.578,.021,.76],8911:[.578,.022,.76],8912:[.54,.04,.778],8913:[.54,.04,.778],8914:[.598,.022,.667],8915:[.598,.022,.667],8916:[.736,.022,.667],8918:[.541,.041,.778],8919:[.541,.041,.778],8920:[.568,.067,1.333],8921:[.568,.067,1.333],8922:[.886,.386,.778],8923:[.886,.386,.778],8926:[.734,0,.778],8927:[.734,0,.778],8928:[.801,.303,.778],8929:[.801,.303,.778],8930:[.716,.215,.778],8931:[.716,.215,.778],8934:[.73,.359,.778],8935:[.73,.359,.778],8936:[.73,.359,.778],8937:[.73,.359,.778],8938:[.706,.208,.778],8939:[.706,.208,.778],8940:[.802,.303,.778],8941:[.801,.303,.778],8942:[1.3,.03,.278],8943:[.31,-.19,1.172],8945:[1.52,-.1,1.282],8965:[.716,0,.611],8966:[.813,.097,.611],8968:[.75,.25,.444],8969:[.75,.25,.444],8970:[.75,.25,.444],8971:[.75,.25,.444],8988:[.694,-.306,.5],8989:[.694,-.306,.5],8990:[.366,.022,.5],8991:[.366,.022,.5],8994:[.388,-.122,1],8995:[.378,-.134,1],9001:[.75,.25,.389],9002:[.75,.25,.389],9136:[.744,.244,.412],9137:[.744,.244,.412],9168:[.602,0,.667],9416:[.709,.175,.902],9484:[.694,-.306,.5],9488:[.694,-.306,.5],9492:[.366,.022,.5],9496:[.366,.022,.5],9585:[.694,.195,.889],9586:[.694,.195,.889],9632:[.689,0,.778],9633:[.689,0,.778],9642:[.689,0,.778],9650:[.575,.02,.722],9651:[.716,0,.889],9652:[.575,.02,.722],9653:[.716,0,.889],9654:[.539,.041,.778],9656:[.539,.041,.778],9657:[.505,.005,.5],9660:[.576,.019,.722],9661:[.5,.215,.889],9662:[.576,.019,.722],9663:[.5,.215,.889],9664:[.539,.041,.778],9666:[.539,.041,.778],9667:[.505,.005,.5],9674:[.716,.132,.667],9711:[.715,.215,1],9723:[.689,0,.778],9724:[.689,0,.778],9733:[.694,.111,.944],9824:[.727,.13,.778],9825:[.716,.033,.778],9826:[.727,.162,.778],9827:[.726,.13,.778],9837:[.75,.022,.389],9838:[.734,.223,.389],9839:[.723,.223,.389],10003:[.706,.034,.833],10016:[.716,.022,.833],10072:[.75,.249,.278],10216:[.75,.25,.389],10217:[.75,.25,.389],10222:[.744,.244,.412],10223:[.744,.244,.412],10229:[.511,.011,1.609],10230:[.511,.011,1.638],10231:[.511,.011,1.859],10232:[.525,.024,1.609],10233:[.525,.024,1.638],10234:[.525,.024,1.858],10236:[.511,.011,1.638],10731:[.716,.132,.667],10744:[.716,.215,.778],10752:[.75,.25,1.111],10753:[.75,.25,1.111],10754:[.75,.25,1.111],10756:[.75,.249,.833],10758:[.75,.249,.833],10764:[.805,.306,1.638,{ic:.138}],10799:[.491,-.009,.778],10815:[.683,0,.75],10846:[.813,.097,.611],10877:[.636,.138,.778],10878:[.636,.138,.778],10885:[.762,.29,.778],10886:[.762,.29,.778],10887:[.635,.241,.778],10888:[.635,.241,.778],10889:[.761,.387,.778],10890:[.761,.387,.778],10891:[1.003,.463,.778],10892:[1.003,.463,.778],10901:[.636,.138,.778],10902:[.636,.138,.778],10927:[.636,.138,.778],10928:[.636,.138,.778],10933:[.752,.286,.778],10934:[.752,.286,.778],10935:[.761,.294,.778],10936:[.761,.294,.778],10937:[.761,.337,.778],10938:[.761,.337,.778],10949:[.753,.215,.778],10950:[.753,.215,.778],10955:[.783,.385,.778],10956:[.783,.385,.778],12296:[.75,.25,.389],12297:[.75,.25,.389],57350:[.43,.023,.222,{ic:.018}],57351:[.431,.024,.389,{ic:.018}],57352:[.605,.085,.778],57353:[.434,.006,.667,{ic:.067}],57356:[.752,.284,.778],57357:[.752,.284,.778],57358:[.919,.421,.778],57359:[.801,.303,.778],57360:[.801,.303,.778],57361:[.919,.421,.778],57366:[.828,.33,.778],57367:[.752,.332,.778],57368:[.828,.33,.778],57369:[.752,.333,.778],57370:[.634,.255,.778],57371:[.634,.254,.778],119808:[.698,0,.869],119809:[.686,0,.818],119810:[.697,.011,.831],119811:[.686,0,.882],119812:[.68,0,.756],119813:[.68,0,.724],119814:[.697,.01,.904],119815:[.686,0,.9],119816:[.686,0,.436],119817:[.686,.011,.594],119818:[.686,0,.901],119819:[.686,0,.692],119820:[.686,0,1.092],119821:[.686,0,.9],119822:[.696,.01,.864],119823:[.686,0,.786],119824:[.696,.193,.864],119825:[.686,.011,.862],119826:[.697,.011,.639],119827:[.675,0,.8],119828:[.686,.011,.885],119829:[.686,.007,.869],119830:[.686,.007,1.189],119831:[.686,0,.869],119832:[.686,0,.869],119833:[.686,0,.703],119834:[.453,.006,.559],119835:[.694,.006,.639],119836:[.453,.006,.511],119837:[.694,.006,.639],119838:[.452,.006,.527],119839:[.7,0,.351,{ic:.101}],119840:[.455,.201,.575],119841:[.694,0,.639],119842:[.695,0,.319],119843:[.695,.2,.351],119844:[.694,0,.607],119845:[.694,0,.319],119846:[.45,0,.958],119847:[.45,0,.639],119848:[.452,.005,.575],119849:[.45,.194,.639],119850:[.45,.194,.607],119851:[.45,0,.474],119852:[.453,.006,.454],119853:[.635,.005,.447],119854:[.45,.006,.639],119855:[.444,0,.607],119856:[.444,0,.831],119857:[.444,0,.607],119858:[.444,.2,.607],119859:[.444,0,.511],119860:[.716,0,.75,{sk:.139}],119861:[.683,0,.759,{sk:.0833}],119862:[.705,.022,.715,{ic:.045,sk:.0833}],119863:[.683,0,.828,{sk:.0556}],119864:[.68,0,.738,{ic:.026,sk:.0833}],119865:[.68,0,.643,{ic:.106,sk:.0833}],119866:[.705,.022,.786,{sk:.0833}],119867:[.683,0,.831,{ic:.057,sk:.0556}],119868:[.683,0,.44,{ic:.064,sk:.111}],119869:[.683,.022,.555,{ic:.078,sk:.167}],119870:[.683,0,.849,{ic:.04,sk:.0556}],119871:[.683,0,.681,{sk:.0278}],119872:[.683,0,.97,{ic:.081,sk:.0833}],119873:[.683,0,.803,{ic:.085,sk:.0833}],119874:[.704,.022,.763,{sk:.0833}],119875:[.683,0,.642,{ic:.109,sk:.0833}],119876:[.704,.194,.791,{sk:.0833}],119877:[.683,.021,.759,{sk:.0833}],119878:[.705,.022,.613,{ic:.032,sk:.0833}],119879:[.677,0,.584,{ic:.12,sk:.0833}],119880:[.683,.022,.683,{ic:.084,sk:.0278}],119881:[.683,.022,.583,{ic:.186}],119882:[.683,.022,.944,{ic:.104}],119883:[.683,0,.828,{ic:.024,sk:.0833}],119884:[.683,0,.581,{ic:.182}],119885:[.683,0,.683,{ic:.04,sk:.0833}],119886:[.441,.01,.529],119887:[.694,.011,.429],119888:[.442,.011,.433,{sk:.0556}],119889:[.694,.01,.52,{sk:.167}],119890:[.442,.011,.466,{sk:.0556}],119891:[.705,.205,.49,{ic:.06,sk:.167}],119892:[.442,.205,.477,{sk:.0278}],119894:[.661,.011,.345],119895:[.661,.204,.412],119896:[.694,.011,.521],119897:[.694,.011,.298,{sk:.0833}],119898:[.442,.011,.878],119899:[.442,.011,.6],119900:[.441,.011,.485,{sk:.0556}],119901:[.442,.194,.503,{sk:.0833}],119902:[.442,.194,.446,{ic:.014,sk:.0833}],119903:[.442,.011,.451,{sk:.0556}],119904:[.442,.01,.469,{sk:.0556}],119905:[.626,.011,.361,{sk:.0833}],119906:[.442,.011,.572,{sk:.0278}],119907:[.443,.011,.485,{sk:.0278}],119908:[.443,.011,.716,{sk:.0833}],119909:[.442,.011,.572,{sk:.0278}],119910:[.442,.205,.49,{sk:.0556}],119911:[.442,.011,.465,{sk:.0556}],119912:[.711,0,.869,{sk:.16}],119913:[.686,0,.866,{sk:.0958}],119914:[.703,.017,.817,{ic:.038,sk:.0958}],119915:[.686,0,.938,{sk:.0639}],119916:[.68,0,.81,{ic:.015,sk:.0958}],119917:[.68,0,.689,{ic:.12,sk:.0958}],119918:[.703,.016,.887,{sk:.0958}],119919:[.686,0,.982,{ic:.045,sk:.0639}],119920:[.686,0,.511,{ic:.062,sk:.128}],119921:[.686,.017,.631,{ic:.063,sk:.192}],119922:[.686,0,.971,{ic:.032,sk:.0639}],119923:[.686,0,.756,{sk:.0319}],119924:[.686,0,1.142,{ic:.077,sk:.0958}],119925:[.686,0,.95,{ic:.077,sk:.0958}],119926:[.703,.017,.837,{sk:.0958}],119927:[.686,0,.723,{ic:.124,sk:.0958}],119928:[.703,.194,.869,{sk:.0958}],119929:[.686,.017,.872,{sk:.0958}],119930:[.703,.017,.693,{ic:.021,sk:.0958}],119931:[.675,0,.637,{ic:.135,sk:.0958}],119932:[.686,.016,.8,{ic:.077,sk:.0319}],119933:[.686,.016,.678,{ic:.208}],119934:[.686,.017,1.093,{ic:.114}],119935:[.686,0,.947,{sk:.0958}],119936:[.686,0,.675,{ic:.201}],119937:[.686,0,.773,{ic:.032,sk:.0958}],119938:[.452,.008,.633],119939:[.694,.008,.521],119940:[.451,.008,.513,{sk:.0639}],119941:[.694,.008,.61,{sk:.192}],119942:[.452,.008,.554,{sk:.0639}],119943:[.701,.201,.568,{ic:.056,sk:.192}],119944:[.452,.202,.545,{sk:.0319}],119945:[.694,.008,.668,{sk:-.0319}],119946:[.694,.008,.405],119947:[.694,.202,.471],119948:[.694,.008,.604],119949:[.694,.008,.348,{sk:.0958}],119950:[.452,.008,1.032],119951:[.452,.008,.713],119952:[.452,.008,.585,{sk:.0639}],119953:[.452,.194,.601,{sk:.0958}],119954:[.452,.194,.542,{sk:.0958}],119955:[.452,.008,.529,{sk:.0639}],119956:[.451,.008,.531,{sk:.0639}],119957:[.643,.007,.415,{sk:.0958}],119958:[.452,.008,.681,{sk:.0319}],119959:[.453,.008,.567,{sk:.0319}],119960:[.453,.008,.831,{sk:.0958}],119961:[.452,.008,.659,{sk:.0319}],119962:[.452,.202,.59,{sk:.0639}],119963:[.452,.008,.555,{sk:.0639}],119964:[.717,.008,.803,{ic:.213,sk:.389}],119966:[.728,.026,.666,{ic:.153,sk:.278}],119967:[.708,.031,.774,{ic:.081,sk:.111}],119970:[.717,.037,.61,{ic:.128,sk:.25}],119973:[.717,.314,1.052,{ic:.081,sk:.417}],119974:[.717,.037,.914,{ic:.29,sk:.361}],119977:[.726,.036,.902,{ic:.306,sk:.389}],119978:[.707,.008,.738,{ic:.067,sk:.167}],119979:[.716,.037,1.013,{ic:.018,sk:.222}],119980:[.717,.017,.883,{sk:.278}],119982:[.708,.036,.868,{ic:.148,sk:.333}],119983:[.735,.037,.747,{ic:.249,sk:.222}],119984:[.717,.017,.8,{ic:.16,sk:.25}],119985:[.717,.017,.622,{ic:.228,sk:.222}],119986:[.717,.017,.805,{ic:.221,sk:.25}],119987:[.717,.017,.944,{ic:.187,sk:.278}],119988:[.716,.017,.71,{ic:.249,sk:.194}],119989:[.717,.016,.821,{ic:.211,sk:.306}],120068:[.696,.026,.718],120069:[.691,.027,.884],120071:[.685,.027,.832],120072:[.685,.024,.663],120073:[.686,.153,.611],120074:[.69,.026,.785],120077:[.686,.139,.552],120078:[.68,.027,.668,{ic:.014}],120079:[.686,.026,.666],120080:[.692,.027,1.05],120081:[.686,.025,.832],120082:[.729,.027,.827],120083:[.692,.218,.828],120084:[.729,.069,.827],120086:[.692,.027,.829],120087:[.701,.027,.669],120088:[.697,.027,.646,{ic:.019}],120089:[.686,.026,.831],120090:[.686,.027,1.046],120091:[.688,.027,.719],120092:[.686,.218,.833],120094:[.47,.035,.5],120095:[.685,.031,.513],120096:[.466,.029,.389],120097:[.609,.033,.499],120098:[.467,.03,.401],120099:[.681,.221,.326],120100:[.47,.209,.504],120101:[.688,.205,.521],120102:[.673,.02,.279],120103:[.672,.208,.281],120104:[.689,.025,.389],120105:[.685,.02,.28],120106:[.475,.026,.767],120107:[.475,.022,.527],120108:[.48,.028,.489],120109:[.541,.212,.5],120110:[.479,.219,.489],120111:[.474,.021,.389],120112:[.478,.029,.443],120113:[.64,.02,.333,{ic:.015}],120114:[.474,.023,.517],120115:[.53,.028,.512],120116:[.532,.028,.774],120117:[.472,.188,.389],120118:[.528,.218,.499],120119:[.471,.214,.391],120120:[.701,0,.722],120121:[.683,0,.667],120123:[.683,0,.722],120124:[.683,0,.667],120125:[.683,0,.611],120126:[.702,.019,.778],120128:[.683,0,.389],120129:[.683,.077,.5],120130:[.683,0,.778],120131:[.683,0,.667],120132:[.683,0,.944],120134:[.701,.019,.778],120138:[.702,.012,.556],120139:[.683,0,.667],120140:[.683,.019,.722],120141:[.683,.02,.722],120142:[.683,.019,1],120143:[.683,0,.722],120144:[.683,0,.722],120172:[.686,.031,.847],120173:[.684,.031,1.044],120174:[.676,.032,.723],120175:[.683,.029,.982],120176:[.686,.029,.783],120177:[.684,.146,.722],120178:[.687,.029,.927],120179:[.683,.126,.851],120180:[.681,.025,.655],120181:[.68,.141,.652],120182:[.681,.026,.789,{ic:.017}],120183:[.683,.028,.786],120184:[.683,.032,1.239],120185:[.679,.03,.983],120186:[.726,.03,.976],120187:[.688,.223,.977],120188:[.726,.083,.976],120189:[.688,.028,.978],120190:[.685,.031,.978],120191:[.686,.03,.79,{ic:.012}],120192:[.688,.039,.851,{ic:.02}],120193:[.685,.029,.982],120194:[.683,.03,1.235],120195:[.681,.035,.849],120196:[.688,.214,.984],120197:[.677,.148,.711],120198:[.472,.032,.603],120199:[.69,.032,.59],120200:[.473,.026,.464],120201:[.632,.028,.589],120202:[.471,.027,.472],120203:[.687,.222,.388],120204:[.472,.208,.595],120205:[.687,.207,.615],120206:[.686,.025,.331],120207:[.682,.203,.332],120208:[.682,.025,.464],120209:[.681,.024,.337],120210:[.476,.031,.921],120211:[.473,.028,.654],120212:[.482,.034,.609],120213:[.557,.207,.604],120214:[.485,.211,.596],120215:[.472,.026,.46],120216:[.479,.034,.523],120217:[.648,.027,.393,{ic:.014}],120218:[.472,.032,.589,{ic:.014}],120219:[.546,.027,.604],120220:[.549,.032,.918],120221:[.471,.188,.459],120222:[.557,.221,.589],120223:[.471,.214,.461],120224:[.694,0,.667],120225:[.694,0,.667],120226:[.705,.011,.639],120227:[.694,0,.722],120228:[.691,0,.597],120229:[.691,0,.569],120230:[.704,.011,.667],120231:[.694,0,.708],120232:[.694,0,.278],120233:[.694,.022,.472],120234:[.694,0,.694],120235:[.694,0,.542],120236:[.694,0,.875],120237:[.694,0,.708],120238:[.715,.022,.736],120239:[.694,0,.639],120240:[.715,.125,.736],120241:[.694,0,.646],120242:[.716,.022,.556],120243:[.688,0,.681],120244:[.694,.022,.688],120245:[.694,0,.667],120246:[.694,0,.944],120247:[.694,0,.667],120248:[.694,0,.667],120249:[.694,0,.611],120250:[.46,.01,.481],120251:[.694,.011,.517],120252:[.46,.01,.444],120253:[.694,.01,.517],120254:[.461,.01,.444],120255:[.705,0,.306,{ic:.041}],120256:[.455,.206,.5],120257:[.694,0,.517],120258:[.68,0,.239],120259:[.68,.205,.267],120260:[.694,0,.489],120261:[.694,0,.239],120262:[.455,0,.794],120263:[.455,0,.517],120264:[.46,.01,.5],120265:[.455,.194,.517],120266:[.455,.194,.517],120267:[.455,0,.342],120268:[.46,.01,.383],120269:[.571,.01,.361],120270:[.444,.01,.517],120271:[.444,0,.461],120272:[.444,0,.683],120273:[.444,0,.461],120274:[.444,.204,.461],120275:[.444,0,.435],120276:[.694,0,.733],120277:[.694,0,.733],120278:[.704,.011,.703],120279:[.694,0,.794],120280:[.691,0,.642],120281:[.691,0,.611],120282:[.705,.011,.733],120283:[.694,0,.794],120284:[.694,0,.331],120285:[.694,.022,.519],120286:[.694,0,.764],120287:[.694,0,.581],120288:[.694,0,.978],120289:[.694,0,.794],120290:[.716,.022,.794],120291:[.694,0,.703],120292:[.716,.106,.794],120293:[.694,0,.703],120294:[.716,.022,.611],120295:[.688,0,.733],120296:[.694,.022,.764],120297:[.694,0,.733],120298:[.694,0,1.039],120299:[.694,0,.733],120300:[.694,0,.733],120301:[.694,0,.672],120302:[.475,.011,.525],120303:[.694,.01,.561],120304:[.475,.011,.489],120305:[.694,.011,.561],120306:[.474,.01,.511],120307:[.705,0,.336,{ic:.045}],120308:[.469,.206,.55],120309:[.694,0,.561],120310:[.695,0,.256],120311:[.695,.205,.286],120312:[.694,0,.531],120313:[.694,0,.256],120314:[.469,0,.867],120315:[.468,0,.561],120316:[.474,.011,.55],120317:[.469,.194,.561],120318:[.469,.194,.561],120319:[.469,0,.372],120320:[.474,.01,.422],120321:[.589,.01,.404],120322:[.458,.011,.561],120323:[.458,0,.5],120324:[.458,0,.744],120325:[.458,0,.5],120326:[.458,.205,.5],120327:[.458,0,.476],120328:[.694,0,.667],120329:[.694,0,.667,{ic:.029}],120330:[.705,.01,.639,{ic:.08}],120331:[.694,0,.722,{ic:.025}],120332:[.691,0,.597,{ic:.091}],120333:[.691,0,.569,{ic:.104}],120334:[.705,.011,.667,{ic:.063}],120335:[.694,0,.708,{ic:.06}],120336:[.694,0,.278,{ic:.06}],120337:[.694,.022,.472,{ic:.063}],120338:[.694,0,.694,{ic:.091}],120339:[.694,0,.542],120340:[.694,0,.875,{ic:.054}],120341:[.694,0,.708,{ic:.058}],120342:[.716,.022,.736,{ic:.027}],120343:[.694,0,.639,{ic:.051}],120344:[.716,.125,.736,{ic:.027}],120345:[.694,0,.646,{ic:.052}],120346:[.716,.022,.556,{ic:.053}],120347:[.688,0,.681,{ic:.109}],120348:[.694,.022,.688,{ic:.059}],120349:[.694,0,.667,{ic:.132}],120350:[.694,0,.944,{ic:.132}],120351:[.694,0,.667,{ic:.091}],120352:[.694,0,.667,{ic:.143}],120353:[.694,0,.611,{ic:.091}],120354:[.461,.01,.481],120355:[.694,.011,.517,{ic:.022}],120356:[.46,.011,.444,{ic:.055}],120357:[.694,.01,.517,{ic:.071}],120358:[.46,.011,.444,{ic:.028}],120359:[.705,0,.306,{ic:.188}],120360:[.455,.206,.5,{ic:.068}],120361:[.694,0,.517],120362:[.68,0,.239,{ic:.076}],120363:[.68,.204,.267,{ic:.069}],120364:[.694,0,.489,{ic:.054}],120365:[.694,0,.239,{ic:.072}],120366:[.455,0,.794],120367:[.454,0,.517],120368:[.461,.011,.5,{ic:.023}],120369:[.455,.194,.517,{ic:.021}],120370:[.455,.194,.517,{ic:.021}],120371:[.455,0,.342,{ic:.082}],120372:[.461,.011,.383,{ic:.053}],120373:[.571,.011,.361,{ic:.049}],120374:[.444,.01,.517,{ic:.02}],120375:[.444,0,.461,{ic:.079}],120376:[.444,0,.683,{ic:.079}],120377:[.444,0,.461,{ic:.076}],120378:[.444,.205,.461,{ic:.079}],120379:[.444,0,.435,{ic:.059}],120432:[.623,0,.525],120433:[.611,0,.525],120434:[.622,.011,.525],120435:[.611,0,.525],120436:[.611,0,.525],120437:[.611,0,.525],120438:[.622,.011,.525],120439:[.611,0,.525],120440:[.611,0,.525],120441:[.611,.011,.525],120442:[.611,0,.525],120443:[.611,0,.525],120444:[.611,0,.525],120445:[.611,0,.525],120446:[.621,.01,.525],120447:[.611,0,.525],120448:[.621,.138,.525],120449:[.611,.011,.525],120450:[.622,.011,.525],120451:[.611,0,.525],120452:[.611,.011,.525],120453:[.611,.007,.525],120454:[.611,.007,.525],120455:[.611,0,.525],120456:[.611,0,.525],120457:[.611,0,.525],120458:[.439,.006,.525],120459:[.611,.006,.525],120460:[.44,.006,.525],120461:[.611,.006,.525],120462:[.44,.006,.525],120463:[.617,0,.525],120464:[.442,.229,.525],120465:[.611,0,.525],120466:[.612,0,.525],120467:[.612,.228,.525],120468:[.611,0,.525],120469:[.611,0,.525],120470:[.436,0,.525,{ic:.011}],120471:[.436,0,.525],120472:[.44,.006,.525],120473:[.437,.221,.525],120474:[.437,.221,.525,{ic:.02}],120475:[.437,0,.525],120476:[.44,.006,.525],120477:[.554,.006,.525],120478:[.431,.005,.525],120479:[.431,0,.525],120480:[.431,0,.525],120481:[.431,0,.525],120482:[.431,.228,.525],120483:[.431,0,.525],120488:[.698,0,.869],120489:[.686,0,.818],120490:[.68,0,.692],120491:[.698,0,.958],120492:[.68,0,.756],120493:[.686,0,.703],120494:[.686,0,.9],120495:[.696,.01,.894],120496:[.686,0,.436],120497:[.686,0,.901],120498:[.698,0,.806],120499:[.686,0,1.092],120500:[.686,0,.9],120501:[.675,0,.767],120502:[.696,.01,.864],120503:[.68,0,.9],120504:[.686,0,.786],120506:[.686,0,.831],120507:[.675,0,.8],120508:[.697,0,.894],120509:[.686,0,.831],120510:[.686,0,.869],120511:[.686,0,.894],120512:[.696,0,.831],120513:[.686,.024,.958],120546:[.716,0,.75,{sk:.139}],120547:[.683,0,.759,{sk:.0833}],120548:[.68,0,.615,{ic:.106,sk:.0833}],120549:[.716,0,.833,{sk:.167}],120550:[.68,0,.738,{ic:.026,sk:.0833}],120551:[.683,0,.683,{ic:.04,sk:.0833}],120552:[.683,0,.831,{ic:.057,sk:.0556}],120553:[.704,.022,.763,{sk:.0833}],120554:[.683,0,.44,{ic:.064,sk:.111}],120555:[.683,0,.849,{ic:.04,sk:.0556}],120556:[.716,0,.694,{sk:.167}],120557:[.683,0,.97,{ic:.081,sk:.0833}],120558:[.683,0,.803,{ic:.085,sk:.0833}],120559:[.677,0,.742,{ic:.035,sk:.0833}],120560:[.704,.022,.763,{sk:.0833}],120561:[.68,0,.831,{ic:.056,sk:.0556}],120562:[.683,0,.642,{ic:.109,sk:.0833}],120564:[.683,0,.78,{ic:.026,sk:.0833}],120565:[.677,0,.584,{ic:.12,sk:.0833}],120566:[.705,0,.583,{ic:.117,sk:.0556}],120567:[.683,0,.667,{sk:.0833}],120568:[.683,0,.828,{ic:.024,sk:.0833}],120569:[.683,0,.612,{ic:.08,sk:.0556}],120570:[.704,0,.772,{ic:.014,sk:.0833}],120572:[.442,.011,.64,{sk:.0278}],120573:[.705,.194,.566,{sk:.0833}],120574:[.441,.216,.518,{ic:.025}],120575:[.717,.01,.444,{sk:.0556}],120576:[.452,.022,.466,{sk:.0833}],120577:[.704,.204,.438,{ic:.033,sk:.0833}],120578:[.442,.216,.497,{sk:.0556}],120579:[.705,.01,.469,{sk:.0833}],120580:[.442,.01,.354,{sk:.0556}],120581:[.442,.011,.576],120582:[.694,.012,.583],120583:[.442,.216,.603,{sk:.0278}],120584:[.442,0,.494,{ic:.036,sk:.0278}],120585:[.704,.205,.438,{sk:.111}],120586:[.441,.011,.485,{sk:.0556}],120587:[.431,.011,.57],120588:[.442,.216,.517,{sk:.0833}],120589:[.442,.107,.363,{ic:.042,sk:.0833}],120590:[.431,.011,.571],120591:[.431,.013,.437,{ic:.08,sk:.0278}],120592:[.443,.01,.54,{sk:.0278}],120593:[.442,.218,.654,{sk:.0833}],120594:[.442,.204,.626,{sk:.0556}],120595:[.694,.205,.651,{sk:.111}],120596:[.443,.011,.622],120597:[.715,.022,.531,{ic:.035,sk:.0833}],120598:[.431,.011,.406,{sk:.0556}],120599:[.705,.011,.591,{sk:.0833}],120600:[.434,.006,.667,{ic:.067}],120601:[.694,.205,.596,{sk:.0833}],120602:[.442,.194,.517,{sk:.0833}],120603:[.431,.01,.828],120604:[.711,0,.869,{sk:.16}],120605:[.686,0,.866,{sk:.0958}],120606:[.68,0,.657,{ic:.12,sk:.0958}],120607:[.711,0,.958,{sk:.192}],120608:[.68,0,.81,{ic:.015,sk:.0958}],120609:[.686,0,.773,{ic:.032,sk:.0958}],120610:[.686,0,.982,{ic:.045,sk:.0639}],120611:[.702,.017,.867,{sk:.0958}],120612:[.686,0,.511,{ic:.062,sk:.128}],120613:[.686,0,.971,{ic:.032,sk:.0639}],120614:[.711,0,.806,{sk:.192}],120615:[.686,0,1.142,{ic:.077,sk:.0958}],120616:[.686,0,.95,{ic:.077,sk:.0958}],120617:[.675,0,.841,{ic:.026,sk:.0958}],120618:[.703,.017,.837,{sk:.0958}],120619:[.68,0,.982,{ic:.044,sk:.0639}],120620:[.686,0,.723,{ic:.124,sk:.0958}],120622:[.686,0,.885,{ic:.017,sk:.0958}],120623:[.675,0,.637,{ic:.135,sk:.0958}],120624:[.703,0,.671,{ic:.131,sk:.0639}],120625:[.686,0,.767,{sk:.0958}],120626:[.686,0,.947,{sk:.0958}],120627:[.686,0,.714,{ic:.076,sk:.0639}],120628:[.703,0,.879,{sk:.0958}],120630:[.452,.008,.761,{sk:.0319}],120631:[.701,.194,.66,{sk:.0958}],120632:[.451,.211,.59,{ic:.027}],120633:[.725,.008,.522,{sk:.0639}],120634:[.461,.017,.529,{sk:.0958}],120635:[.711,.202,.508,{ic:.013,sk:.0958}],120636:[.452,.211,.6,{sk:.0639}],120637:[.702,.008,.562,{sk:.0958}],120638:[.452,.008,.412,{sk:.0639}],120639:[.452,.008,.668],120640:[.694,.013,.671],120641:[.452,.211,.708,{sk:.0319}],120642:[.452,0,.577,{ic:.031,sk:.0319}],120643:[.711,.201,.508,{sk:.128}],120644:[.452,.008,.585,{sk:.0639}],120645:[.444,.008,.682],120646:[.451,.211,.612,{sk:.0958}],120647:[.451,.105,.424,{ic:.033,sk:.0958}],120648:[.444,.008,.686],120649:[.444,.013,.521,{ic:.089,sk:.0319}],120650:[.453,.008,.631,{sk:.0319}],120651:[.452,.216,.747,{sk:.0958}],120652:[.452,.201,.718,{sk:.0639}],120653:[.694,.202,.758,{sk:.128}],120654:[.453,.008,.718],120655:[.71,.017,.628,{ic:.029,sk:.0958}],120656:[.444,.007,.483,{sk:.0639}],120657:[.701,.008,.692,{sk:.0958}],120658:[.434,.006,.667,{ic:.067}],120659:[.694,.202,.712,{sk:.0958}],120660:[.451,.194,.612,{sk:.0958}],120661:[.444,.008,.975],120662:[.694,0,.733],120663:[.694,0,.733],120664:[.691,0,.581],120665:[.694,0,.917],120666:[.691,0,.642],120667:[.694,0,.672],120668:[.694,0,.794],120669:[.716,.022,.856],120670:[.694,0,.331],120671:[.694,0,.764],120672:[.694,0,.672],120673:[.694,0,.978],120674:[.694,0,.794],120675:[.688,0,.733],120676:[.716,.022,.794],120677:[.691,0,.794],120678:[.694,0,.703],120680:[.694,0,.794],120681:[.688,0,.733],120682:[.715,0,.856],120683:[.694,0,.794],120684:[.694,0,.733],120685:[.694,0,.856],120686:[.716,0,.794],120782:[.654,.01,.575],120783:[.655,0,.575],120784:[.654,0,.575],120785:[.655,.011,.575],120786:[.656,0,.575],120787:[.655,.011,.575],120788:[.655,.011,.575],120789:[.676,.011,.575],120790:[.654,.011,.575],120791:[.654,.011,.575],120802:[.678,.022,.5],120803:[.678,0,.5],120804:[.677,0,.5],120805:[.678,.022,.5],120806:[.656,0,.5],120807:[.656,.021,.5],120808:[.677,.022,.5],120809:[.656,.011,.5],120810:[.678,.022,.5],120811:[.677,.022,.5],120812:[.715,.022,.55],120813:[.716,0,.55],120814:[.716,0,.55],120815:[.716,.022,.55],120816:[.694,0,.55],120817:[.694,.022,.55],120818:[.716,.022,.55],120819:[.695,.011,.55],120820:[.715,.022,.55],120821:[.716,.022,.55],120822:[.621,.01,.525],120823:[.622,0,.525],120824:[.622,0,.525],120825:[.622,.011,.525],120826:[.624,0,.525],120827:[.611,.01,.525],120828:[.622,.011,.525],120829:[.627,.01,.525],120830:[.621,.01,.525],120831:[.622,.011,.525]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifBoldItalic=void 0;var r=n(46),i=n(902);t.sansSerifBoldItalic=r.AddCSS(i.sansSerifBoldItalic,{305:{f:"SSB"},567:{f:"SSB"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifBoldItalic=void 0,t.sansSerifBoldItalic={305:[.458,0,.256],567:[.458,.205,.286]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifBold=void 0;var r=n(46),i=n(904);t.sansSerifBold=r.AddCSS(i.sansSerifBold,{8213:{c:"\\2014"},8215:{c:"_"},8260:{c:"/"},8710:{c:"\\394"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifBold=void 0,t.sansSerifBold={33:[.694,0,.367],34:[.694,-.442,.558],35:[.694,.193,.917],36:[.75,.056,.55],37:[.75,.056,1.029],38:[.716,.022,.831],39:[.694,-.442,.306],40:[.75,.249,.428],41:[.75,.25,.428],42:[.75,-.293,.55],43:[.617,.116,.856],44:[.146,.106,.306],45:[.273,-.186,.367],46:[.146,0,.306],47:[.75,.249,.55],58:[.458,0,.306],59:[.458,.106,.306],61:[.407,-.094,.856],63:[.705,0,.519],64:[.704,.011,.733],91:[.75,.25,.343],93:[.75,.25,.343],94:[.694,-.537,.55],95:[-.023,.11,.55],126:[.344,-.198,.55],305:[.458,0,.256],567:[.458,.205,.286],768:[.694,-.537,0],769:[.694,-.537,0],770:[.694,-.537,0],771:[.694,-.548,0],772:[.66,-.56,0],774:[.694,-.552,0],775:[.695,-.596,0],776:[.695,-.595,0],778:[.694,-.538,0],779:[.694,-.537,0],780:[.657,-.5,0],8211:[.327,-.24,.55],8212:[.327,-.24,1.1],8213:[.327,-.24,1.1],8215:[-.023,.11,.55],8216:[.694,-.443,.306],8217:[.694,-.442,.306],8220:[.694,-.443,.558],8221:[.694,-.442,.558],8260:[.75,.249,.55],8710:[.694,0,.917]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifItalic=void 0;var r=n(46),i=n(906);t.sansSerifItalic=r.AddCSS(i.sansSerifItalic,{913:{c:"A"},914:{c:"B"},917:{c:"E"},918:{c:"Z"},919:{c:"H"},921:{c:"I"},922:{c:"K"},924:{c:"M"},925:{c:"N"},927:{c:"O"},929:{c:"P"},932:{c:"T"},935:{c:"X"},8213:{c:"\\2014"},8215:{c:"_"},8260:{c:"/"},8710:{c:"\\394"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerifItalic=void 0,t.sansSerifItalic={33:[.694,0,.319,{ic:.036}],34:[.694,-.471,.5],35:[.694,.194,.833,{ic:.018}],36:[.75,.056,.5,{ic:.065}],37:[.75,.056,.833],38:[.716,.022,.758],39:[.694,-.471,.278,{ic:.057}],40:[.75,.25,.389,{ic:.102}],41:[.75,.25,.389],42:[.75,-.306,.5,{ic:.068}],43:[.583,.083,.778],44:[.098,.125,.278],45:[.259,-.186,.333],46:[.098,0,.278],47:[.75,.25,.5,{ic:.1}],48:[.678,.022,.5,{ic:.049}],49:[.678,0,.5],50:[.678,0,.5,{ic:.051}],51:[.678,.022,.5,{ic:.044}],52:[.656,0,.5,{ic:.021}],53:[.656,.022,.5,{ic:.055}],54:[.678,.022,.5,{ic:.048}],55:[.656,.011,.5,{ic:.096}],56:[.678,.022,.5,{ic:.054}],57:[.677,.022,.5,{ic:.045}],58:[.444,0,.278],59:[.444,.125,.278],61:[.37,-.13,.778,{ic:.018}],63:[.704,0,.472,{ic:.064}],64:[.705,.01,.667,{ic:.04}],91:[.75,.25,.289,{ic:.136}],93:[.75,.25,.289,{ic:.064}],94:[.694,-.527,.5,{ic:.033}],95:[-.038,.114,.5,{ic:.065}],126:[.327,-.193,.5,{ic:.06}],305:[.444,0,.239,{ic:.019}],567:[.444,.204,.267,{ic:.019}],768:[.694,-.527,0],769:[.694,-.527,0,{ic:.063}],770:[.694,-.527,0,{ic:.033}],771:[.677,-.543,0,{ic:.06}],772:[.631,-.552,0,{ic:.064}],774:[.694,-.508,0,{ic:.073}],775:[.68,-.576,0],776:[.68,-.582,0,{ic:.04}],778:[.693,-.527,0],779:[.694,-.527,0,{ic:.063}],780:[.654,-.487,0,{ic:.06}],913:[.694,0,.667],914:[.694,0,.667,{ic:.029}],915:[.691,0,.542,{ic:.104}],916:[.694,0,.833],917:[.691,0,.597,{ic:.091}],918:[.694,0,.611,{ic:.091}],919:[.694,0,.708,{ic:.06}],920:[.715,.022,.778,{ic:.026}],921:[.694,0,.278,{ic:.06}],922:[.694,0,.694,{ic:.091}],923:[.694,0,.611],924:[.694,0,.875,{ic:.054}],925:[.694,0,.708,{ic:.058}],926:[.688,0,.667,{ic:.098}],927:[.716,.022,.736,{ic:.027}],928:[.691,0,.708,{ic:.06}],929:[.694,0,.639,{ic:.051}],931:[.694,0,.722,{ic:.091}],932:[.688,0,.681,{ic:.109}],933:[.716,0,.778,{ic:.065}],934:[.694,0,.722,{ic:.021}],935:[.694,0,.667,{ic:.091}],936:[.694,0,.778,{ic:.076}],937:[.716,0,.722,{ic:.047}],8211:[.312,-.236,.5,{ic:.065}],8212:[.312,-.236,1,{ic:.065}],8213:[.312,-.236,1,{ic:.065}],8215:[-.038,.114,.5,{ic:.065}],8216:[.694,-.471,.278,{ic:.058}],8217:[.694,-.471,.278,{ic:.057}],8220:[.694,-.471,.5,{ic:.114}],8221:[.694,-.471,.5],8260:[.75,.25,.5,{ic:.1}],8710:[.694,0,.833]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerif=void 0;var r=n(46),i=n(908);t.sansSerif=r.AddCSS(i.sansSerif,{913:{c:"A"},914:{c:"B"},917:{c:"E"},918:{c:"Z"},919:{c:"H"},921:{c:"I"},922:{c:"K"},924:{c:"M"},925:{c:"N"},927:{c:"O"},929:{c:"P"},932:{c:"T"},935:{c:"X"},8213:{c:"\\2014"},8215:{c:"_"},8260:{c:"/"},8710:{c:"\\394"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.sansSerif=void 0,t.sansSerif={33:[.694,0,.319],34:[.694,-.471,.5],35:[.694,.194,.833],36:[.75,.056,.5],37:[.75,.056,.833],38:[.716,.022,.758],39:[.694,-.471,.278],40:[.75,.25,.389],41:[.75,.25,.389],42:[.75,-.306,.5],43:[.583,.082,.778],44:[.098,.125,.278],45:[.259,-.186,.333],46:[.098,0,.278],47:[.75,.25,.5],58:[.444,0,.278],59:[.444,.125,.278],61:[.37,-.13,.778],63:[.704,0,.472],64:[.704,.011,.667],91:[.75,.25,.289],93:[.75,.25,.289],94:[.694,-.527,.5],95:[-.038,.114,.5],126:[.327,-.193,.5],305:[.444,0,.239],567:[.444,.205,.267],768:[.694,-.527,0],769:[.694,-.527,0],770:[.694,-.527,0],771:[.677,-.543,0],772:[.631,-.552,0],774:[.694,-.508,0],775:[.68,-.576,0],776:[.68,-.582,0],778:[.694,-.527,0],779:[.694,-.527,0],780:[.654,-.487,0],913:[.694,0,.667],914:[.694,0,.667],915:[.691,0,.542],916:[.694,0,.833],917:[.691,0,.597],918:[.694,0,.611],919:[.694,0,.708],920:[.716,.021,.778],921:[.694,0,.278],922:[.694,0,.694],923:[.694,0,.611],924:[.694,0,.875],925:[.694,0,.708],926:[.688,0,.667],927:[.715,.022,.736],928:[.691,0,.708],929:[.694,0,.639],931:[.694,0,.722],932:[.688,0,.681],933:[.716,0,.778],934:[.694,0,.722],935:[.694,0,.667],936:[.694,0,.778],937:[.716,0,.722],8211:[.312,-.236,.5],8212:[.312,-.236,1],8213:[.312,-.236,1],8215:[-.038,.114,.5],8216:[.694,-.471,.278],8217:[.694,-.471,.278],8220:[.694,-.471,.5],8221:[.694,-.471,.5],8260:[.75,.25,.5],8710:[.694,0,.833]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.scriptBold=void 0;var r=n(910);Object.defineProperty(t,"scriptBold",{enumerable:!0,get:function(){return r.scriptBold}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.scriptBold=void 0,t.scriptBold={}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.script=void 0;var r=n(912);Object.defineProperty(t,"script",{enumerable:!0,get:function(){return r.script}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.script=void 0,t.script={}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.smallop=void 0;var r=n(46),i=n(914);t.smallop=r.AddCSS(i.smallop,{8260:{c:"/"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},10072:{c:"\\2223"},10764:{c:"\\222C\\222C"},12296:{c:"\\27E8"},12297:{c:"\\27E9"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.smallop=void 0,t.smallop={40:[.85,.349,.458],41:[.85,.349,.458],47:[.85,.349,.578],91:[.85,.349,.417],92:[.85,.349,.578],93:[.85,.349,.417],123:[.85,.349,.583],125:[.85,.349,.583],710:[.744,-.551,.556],732:[.722,-.597,.556],770:[.744,-.551,0],771:[.722,-.597,0],8214:[.602,0,.778],8260:[.85,.349,.578],8593:[.6,0,.667],8595:[.6,0,.667],8657:[.599,0,.778],8659:[.6,0,.778],8719:[.75,.25,.944],8720:[.75,.25,.944],8721:[.75,.25,1.056],8730:[.85,.35,1,{ic:.02}],8739:[.627,.015,.333],8741:[.627,.015,.556],8747:[.805,.306,.472,{ic:.138}],8748:[.805,.306,.819,{ic:.138}],8749:[.805,.306,1.166,{ic:.138}],8750:[.805,.306,.472,{ic:.138}],8896:[.75,.249,.833],8897:[.75,.249,.833],8898:[.75,.249,.833],8899:[.75,.249,.833],8968:[.85,.349,.472],8969:[.85,.349,.472],8970:[.85,.349,.472],8971:[.85,.349,.472],9001:[.85,.35,.472],9002:[.85,.35,.472],9168:[.602,0,.667],10072:[.627,.015,.333],10216:[.85,.35,.472],10217:[.85,.35,.472],10752:[.75,.25,1.111],10753:[.75,.25,1.111],10754:[.75,.25,1.111],10756:[.75,.249,.833],10758:[.75,.249,.833],10764:[.805,.306,1.638,{ic:.138}],12296:[.85,.35,.472],12297:[.85,.35,.472]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texCalligraphicBold=void 0;var r=n(46),i=n(916);t.texCalligraphicBold=r.AddCSS(i.texCalligraphicBold,{305:{f:"B"},567:{f:"B"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texCalligraphicBold=void 0,t.texCalligraphicBold={65:[.751,.049,.921,{ic:.068,sk:.224}],66:[.705,.017,.748,{sk:.16}],67:[.703,.02,.613,{sk:.16}],68:[.686,0,.892,{sk:.0958}],69:[.703,.016,.607,{ic:.02,sk:.128}],70:[.686,.03,.814,{ic:.116,sk:.128}],71:[.703,.113,.682,{sk:.128}],72:[.686,.048,.987,{sk:.128}],73:[.686,0,.642,{ic:.104,sk:.0319}],74:[.686,.114,.779,{ic:.158,sk:.192}],75:[.703,.017,.871,{sk:.0639}],76:[.703,.017,.788,{sk:.16}],77:[.703,.049,1.378,{sk:.16}],78:[.84,.049,.937,{ic:.168,sk:.0958}],79:[.703,.017,.906,{sk:.128}],80:[.686,.067,.81,{ic:.036,sk:.0958}],81:[.703,.146,.939,{sk:.128}],82:[.686,.017,.99,{sk:.0958}],83:[.703,.016,.696,{ic:.025,sk:.16}],84:[.72,.069,.644,{ic:.303,sk:.0319}],85:[.686,.024,.715,{ic:.056,sk:.0958}],86:[.686,.077,.737,{ic:.037,sk:.0319}],87:[.686,.077,1.169,{ic:.037,sk:.0958}],88:[.686,0,.817,{ic:.089,sk:.16}],89:[.686,.164,.759,{ic:.038,sk:.0958}],90:[.686,0,.818,{ic:.035,sk:.16}],305:[.452,.008,.394,{sk:.0319}],567:[.451,.201,.439,{sk:.0958}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texCalligraphic=void 0;var r=n(918);Object.defineProperty(t,"texCalligraphic",{enumerable:!0,get:function(){return r.texCalligraphic}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texCalligraphic=void 0,t.texCalligraphic={65:[.728,.05,.798,{ic:.021,sk:.194}],66:[.705,.022,.657,{sk:.139}],67:[.705,.025,.527,{sk:.139}],68:[.683,0,.771,{sk:.0833}],69:[.705,.022,.528,{ic:.036,sk:.111}],70:[.683,.032,.719,{ic:.11,sk:.111}],71:[.704,.119,.595,{sk:.111}],72:[.683,.048,.845,{sk:.111}],73:[.683,0,.545,{ic:.097,sk:.0278}],74:[.683,.119,.678,{ic:.161,sk:.167}],75:[.705,.022,.762,{sk:.0556}],76:[.705,.022,.69,{sk:.139}],77:[.705,.05,1.201,{sk:.139}],78:[.789,.05,.82,{ic:.159,sk:.0833}],79:[.705,.022,.796,{sk:.111}],80:[.683,.057,.696,{ic:.037,sk:.0833}],81:[.705,.131,.817,{sk:.111}],82:[.682,.022,.848,{sk:.0833}],83:[.705,.022,.606,{ic:.036,sk:.139}],84:[.717,.068,.545,{ic:.288,sk:.0278}],85:[.683,.028,.626,{ic:.061,sk:.0833}],86:[.683,.052,.613,{ic:.045,sk:.0278}],87:[.683,.053,.988,{ic:.046,sk:.0833}],88:[.683,0,.713,{ic:.094,sk:.139}],89:[.683,.143,.668,{ic:.046,sk:.0833}],90:[.683,0,.725,{ic:.042,sk:.139}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texMathit=void 0;var r=n(920);Object.defineProperty(t,"texMathit",{enumerable:!0,get:function(){return r.texMathit}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texMathit=void 0,t.texMathit={65:[.716,0,.743],66:[.683,0,.704],67:[.705,.021,.716],68:[.683,0,.755],69:[.68,0,.678],70:[.68,0,.653],71:[.705,.022,.774],72:[.683,0,.743],73:[.683,0,.386],74:[.683,.021,.525],75:[.683,0,.769],76:[.683,0,.627],77:[.683,0,.897],78:[.683,0,.743],79:[.704,.022,.767],80:[.683,0,.678],81:[.704,.194,.767],82:[.683,.022,.729],83:[.705,.022,.562],84:[.677,0,.716],85:[.683,.022,.743],86:[.683,.022,.743],87:[.683,.022,.999],88:[.683,0,.743],89:[.683,0,.743],90:[.683,0,.613],97:[.442,.011,.511],98:[.694,.011,.46],99:[.441,.01,.46],100:[.694,.011,.511],101:[.442,.01,.46],102:[.705,.204,.307],103:[.442,.205,.46],104:[.694,.011,.511],105:[.656,.01,.307],106:[.656,.204,.307],107:[.694,.011,.46],108:[.694,.011,.256],109:[.442,.011,.818],110:[.442,.011,.562],111:[.442,.011,.511],112:[.442,.194,.511],113:[.442,.194,.46],114:[.442,.011,.422],115:[.442,.011,.409],116:[.626,.011,.332],117:[.441,.011,.537],118:[.443,.01,.46],119:[.443,.011,.664],120:[.442,.011,.464],121:[.441,.205,.486],122:[.442,.011,.409]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texOldstyleBold=void 0;var r=n(922);Object.defineProperty(t,"texOldstyleBold",{enumerable:!0,get:function(){return r.texOldstyleBold}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texOldstyleBold=void 0,t.texOldstyleBold={48:[.46,.017,.575],49:[.461,0,.575],50:[.46,0,.575],51:[.461,.211,.575],52:[.469,.194,.575],53:[.461,.211,.575],54:[.66,.017,.575],55:[.476,.211,.575],56:[.661,.017,.575],57:[.461,.21,.575],65:[.751,.049,.921,{ic:.068,sk:.224}],66:[.705,.017,.748,{sk:.16}],67:[.703,.02,.613,{sk:.16}],68:[.686,0,.892,{sk:.0958}],69:[.703,.016,.607,{ic:.02,sk:.128}],70:[.686,.03,.814,{ic:.116,sk:.128}],71:[.703,.113,.682,{sk:.128}],72:[.686,.048,.987,{sk:.128}],73:[.686,0,.642,{ic:.104,sk:.0319}],74:[.686,.114,.779,{ic:.158,sk:.192}],75:[.703,.017,.871,{sk:.0639}],76:[.703,.017,.788,{sk:.16}],77:[.703,.049,1.378,{sk:.16}],78:[.84,.049,.937,{ic:.168,sk:.0958}],79:[.703,.017,.906,{sk:.128}],80:[.686,.067,.81,{ic:.036,sk:.0958}],81:[.703,.146,.939,{sk:.128}],82:[.686,.017,.99,{sk:.0958}],83:[.703,.016,.696,{ic:.025,sk:.16}],84:[.72,.069,.644,{ic:.303,sk:.0319}],85:[.686,.024,.715,{ic:.056,sk:.0958}],86:[.686,.077,.737,{ic:.037,sk:.0319}],87:[.686,.077,1.169,{ic:.037,sk:.0958}],88:[.686,0,.817,{ic:.089,sk:.16}],89:[.686,.164,.759,{ic:.038,sk:.0958}],90:[.686,0,.818,{ic:.035,sk:.16}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texOldstyle=void 0;var r=n(924);Object.defineProperty(t,"texOldstyle",{enumerable:!0,get:function(){return r.texOldstyle}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texOldstyle=void 0,t.texOldstyle={48:[.452,.022,.5],49:[.453,0,.5],50:[.453,0,.5],51:[.452,.216,.5],52:[.464,.194,.5],53:[.453,.216,.5],54:[.665,.022,.5],55:[.463,.216,.5],56:[.666,.021,.5],57:[.453,.216,.5],65:[.728,.05,.798,{ic:.021,sk:.194}],66:[.705,.022,.657,{sk:.139}],67:[.705,.025,.527,{sk:.139}],68:[.683,0,.771,{sk:.0833}],69:[.705,.022,.528,{ic:.036,sk:.111}],70:[.683,.032,.719,{ic:.11,sk:.111}],71:[.704,.119,.595,{sk:.111}],72:[.683,.048,.845,{sk:.111}],73:[.683,0,.545,{ic:.097,sk:.0278}],74:[.683,.119,.678,{ic:.161,sk:.167}],75:[.705,.022,.762,{sk:.0556}],76:[.705,.022,.69,{sk:.139}],77:[.705,.05,1.201,{sk:.139}],78:[.789,.05,.82,{ic:.159,sk:.0833}],79:[.705,.022,.796,{sk:.111}],80:[.683,.057,.696,{ic:.037,sk:.0833}],81:[.705,.131,.817,{sk:.111}],82:[.682,.022,.848,{sk:.0833}],83:[.705,.022,.606,{ic:.036,sk:.139}],84:[.717,.068,.545,{ic:.288,sk:.0278}],85:[.683,.028,.626,{ic:.061,sk:.0833}],86:[.683,.052,.613,{ic:.045,sk:.0278}],87:[.683,.053,.988,{ic:.046,sk:.0833}],88:[.683,0,.713,{ic:.094,sk:.139}],89:[.683,.143,.668,{ic:.046,sk:.0833}],90:[.683,0,.725,{ic:.042,sk:.139}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texSize3=void 0;var r=n(46),i=n(926);t.texSize3=r.AddCSS(i.texSize3,{8260:{c:"/"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},12296:{c:"\\27E8"},12297:{c:"\\27E9"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texSize3=void 0,t.texSize3={40:[1.45,.949,.736],41:[1.45,.949,.736],47:[1.45,.949,1.044],91:[1.45,.949,.528],92:[1.45,.949,1.044],93:[1.45,.949,.528],123:[1.45,.949,.75],125:[1.45,.949,.75],710:[.772,-.564,1.444],732:[.749,-.61,1.444],770:[.772,-.564,0],771:[.749,-.61,0],8260:[1.45,.949,1.044],8730:[1.45,.95,1,{ic:.02}],8968:[1.45,.949,.583],8969:[1.45,.949,.583],8970:[1.45,.949,.583],8971:[1.45,.949,.583],9001:[1.45,.95,.75],9002:[1.45,.949,.75],10216:[1.45,.95,.75],10217:[1.45,.949,.75],12296:[1.45,.95,.75],12297:[1.45,.949,.75]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texSize4=void 0;var r=n(46),i=n(928);t.texSize4=r.AddCSS(i.texSize4,{8260:{c:"/"},9001:{c:"\\27E8"},9002:{c:"\\27E9"},12296:{c:"\\27E8"},12297:{c:"\\27E9"},57685:{c:"\\E153\\E152"},57686:{c:"\\E151\\E150"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texSize4=void 0,t.texSize4={40:[1.75,1.249,.792],41:[1.75,1.249,.792],47:[1.75,1.249,1.278],91:[1.75,1.249,.583],92:[1.75,1.249,1.278],93:[1.75,1.249,.583],123:[1.75,1.249,.806],125:[1.75,1.249,.806],710:[.845,-.561,1.889,{ic:.013}],732:[.823,-.583,1.889],770:[.845,-.561,0,{ic:.013}],771:[.823,-.583,0],8260:[1.75,1.249,1.278],8730:[1.75,1.25,1,{ic:.02}],8968:[1.75,1.249,.639],8969:[1.75,1.249,.639],8970:[1.75,1.249,.639],8971:[1.75,1.249,.639],9001:[1.75,1.248,.806],9002:[1.75,1.248,.806],9115:[1.154,.655,.875],9116:[.61,.01,.875],9117:[1.165,.644,.875],9118:[1.154,.655,.875],9119:[.61,.01,.875],9120:[1.165,.644,.875],9121:[1.154,.645,.667],9122:[.602,0,.667],9123:[1.155,.644,.667],9124:[1.154,.645,.667],9125:[.602,0,.667],9126:[1.155,.644,.667],9127:[.899,.01,.889],9128:[1.16,.66,.889],9129:[.01,.899,.889],9130:[.29,.015,.889],9131:[.899,.01,.889],9132:[1.16,.66,.889],9133:[.01,.899,.889],9143:[.935,.885,1.056],10216:[1.75,1.248,.806],10217:[1.75,1.248,.806],12296:[1.75,1.248,.806],12297:[1.75,1.248,.806],57344:[.625,.014,1.056],57345:[.605,.014,1.056,{ic:.02}],57680:[.12,.213,.45,{ic:.01}],57681:[.12,.213,.45,{ic:.024}],57682:[.333,0,.45,{ic:.01}],57683:[.333,0,.45,{ic:.024}],57684:[.32,.2,.4,{ic:.01}],57685:[.333,0,.9,{ic:.01}],57686:[.12,.213,.9,{ic:.01}]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texVariant=void 0;var r=n(46),i=n(930);t.texVariant=r.AddCSS(i.texVariant,{1008:{c:"\\E009"},8463:{f:""},8740:{c:"\\E006"},8742:{c:"\\E007"},8808:{c:"\\E00C"},8809:{c:"\\E00D"},8816:{c:"\\E011"},8817:{c:"\\E00E"},8840:{c:"\\E016"},8841:{c:"\\E018"},8842:{c:"\\E01A"},8843:{c:"\\E01B"},10887:{c:"\\E010"},10888:{c:"\\E00F"},10955:{c:"\\E017"},10956:{c:"\\E019"}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.texVariant=void 0,t.texVariant={710:[.845,-.561,2.333,{ic:.013}],732:[.899,-.628,2.333],770:[.845,-.561,0,{ic:.013}],771:[.899,-.628,0],1008:[.434,.006,.667,{ic:.067}],8463:[.695,.013,.54,{ic:.022}],8592:[.437,-.064,.5],8594:[.437,-.064,.5],8652:[.514,.014,1],8708:[.86,.166,.556],8709:[.587,0,.778],8722:[.27,-.23,.5],8726:[.43,.023,.778],8733:[.472,-.028,.778],8739:[.43,.023,.222],8740:[.43,.023,.222,{ic:.018}],8741:[.431,.023,.389],8742:[.431,.024,.389,{ic:.018}],8764:[.365,-.132,.778],8776:[.481,-.05,.778],8808:[.752,.284,.778],8809:[.752,.284,.778],8816:[.919,.421,.778],8817:[.919,.421,.778],8840:[.828,.33,.778],8841:[.828,.33,.778],8842:[.634,.255,.778],8843:[.634,.254,.778],8872:[.694,0,.611],8901:[.189,0,.278],8994:[.378,-.122,.778],8995:[.378,-.143,.778],9651:[.575,.02,.722],9661:[.576,.019,.722],10887:[.801,.303,.778],10888:[.801,.303,.778],10955:[.752,.332,.778],10956:[.752,.333,.778]}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.delimiters=t.VSIZES=t.HDW3=t.HDW2=t.HDW1=void 0;var r=n(111);t.HDW1=[.75,.25,.875],t.HDW2=[.85,.349,.667],t.HDW3=[.583,.082,.5],t.VSIZES=[1,1.2,1.8,2.4,3];var i={c:47,dir:r.V,sizes:t.VSIZES},o={c:175,dir:r.H,sizes:[.5],stretch:[0,175],HDW:[.59,-.544,.5]},a={c:710,dir:r.H,sizes:[.5,.556,1,1.444,1.889]},s={c:732,dir:r.H,sizes:[.5,.556,1,1.444,1.889]},l={c:8211,dir:r.H,sizes:[.5],stretch:[0,8211],HDW:[.285,-.248,.5]},c={c:8592,dir:r.H,sizes:[1],stretch:[8592,8722],HDW:t.HDW3},u={c:8594,dir:r.H,sizes:[1],stretch:[0,8722,8594],HDW:t.HDW3},d={c:8596,dir:r.H,sizes:[1],stretch:[8592,8722,8594],HDW:t.HDW3},h={c:8612,dir:r.H,stretch:[8592,8722,8739],HDW:t.HDW3,min:1.278},p={c:8614,dir:r.H,sizes:[1],stretch:[8739,8722,8594],HDW:t.HDW3},f={c:8656,dir:r.H,sizes:[1],stretch:[8656,61],HDW:t.HDW3},m={c:8658,dir:r.H,sizes:[1],stretch:[0,61,8658],HDW:t.HDW3},g={c:8660,dir:r.H,sizes:[1],stretch:[8656,61,8658],HDW:t.HDW3},v={c:8722,dir:r.H,sizes:[.778],stretch:[0,8722],HDW:t.HDW3},y={c:8739,dir:r.V,sizes:[1],stretch:[0,8739],HDW:[.627,.015,.333]},_={c:9180,dir:r.H,sizes:[.778,1],schar:[8994,8994],variants:[5,0],stretch:[57680,57684,57681],HDW:[.32,.2,.5]},b={c:9181,dir:r.H,sizes:[.778,1],schar:[8995,8995],variants:[5,0],stretch:[57682,57684,57683],HDW:[.32,.2,.5]},M={c:9182,dir:r.H,stretch:[57680,57684,57681,57685],HDW:[.32,.2,.5],min:1.8},w={c:9183,dir:r.H,stretch:[57682,57684,57683,57686],HDW:[.32,.2,.5],min:1.8},A={c:10216,dir:r.V,sizes:t.VSIZES},C={c:10217,dir:r.V,sizes:t.VSIZES},x={c:10502,dir:r.H,stretch:[8656,61,8739],HDW:t.HDW3,min:1.278},E={c:10503,dir:r.H,stretch:[8872,61,8658],HDW:t.HDW3,min:1.278};t.delimiters={40:{dir:r.V,sizes:t.VSIZES,stretch:[9115,9116,9117],HDW:[.85,.349,.875]},41:{dir:r.V,sizes:t.VSIZES,stretch:[9118,9119,9120],HDW:[.85,.349,.875]},45:v,47:i,61:{dir:r.H,sizes:[.778],stretch:[0,61],HDW:t.HDW3},91:{dir:r.V,sizes:t.VSIZES,stretch:[9121,9122,9123],HDW:t.HDW2},92:{dir:r.V,sizes:t.VSIZES},93:{dir:r.V,sizes:t.VSIZES,stretch:[9124,9125,9126],HDW:t.HDW2},94:a,95:l,123:{dir:r.V,sizes:t.VSIZES,stretch:[9127,9130,9129,9128],HDW:[.85,.349,.889]},124:{dir:r.V,sizes:[1],stretch:[0,8739],HDW:[.75,.25,.333]},125:{dir:r.V,sizes:t.VSIZES,stretch:[9131,9130,9133,9132],HDW:[.85,.349,.889]},126:s,175:o,710:a,713:o,732:s,770:a,771:s,818:l,8211:l,8212:l,8213:l,8214:{dir:r.V,sizes:[.602,1],schar:[0,8741],variants:[1,0],stretch:[0,8741],HDW:[.602,0,.556]},8215:l,8254:o,8407:u,8592:c,8593:{dir:r.V,sizes:[.888],stretch:[8593,9168],HDW:[.6,0,.667]},8594:u,8595:{dir:r.V,sizes:[.888],stretch:[0,9168,8595],HDW:[.6,0,.667]},8596:d,8597:{dir:r.V,sizes:[1.044],stretch:[8593,9168,8595],HDW:t.HDW1},8606:{dir:r.H,sizes:[1],stretch:[8606,8722],HDW:t.HDW3},8608:{dir:r.H,sizes:[1],stretch:[0,8722,8608],HDW:t.HDW3},8612:h,8613:{dir:r.V,stretch:[8593,9168,8869],HDW:t.HDW1,min:1.555},8614:p,8615:{dir:r.V,stretch:[8868,9168,8595],HDW:t.HDW1,min:1.555},8624:{dir:r.V,sizes:[.722],stretch:[8624,9168],HDW:t.HDW1},8625:{dir:r.V,sizes:[.722],stretch:[8625,9168],HDW:t.HDW1},8636:{dir:r.H,sizes:[1],stretch:[8636,8722],HDW:t.HDW3},8637:{dir:r.H,sizes:[1],stretch:[8637,8722],HDW:t.HDW3},8638:{dir:r.V,sizes:[.888],stretch:[8638,9168],HDW:t.HDW1},8639:{dir:r.V,sizes:[.888],stretch:[8639,9168],HDW:t.HDW1},8640:{dir:r.H,sizes:[1],stretch:[0,8722,8640],HDW:t.HDW3},8641:{dir:r.H,sizes:[1],stretch:[0,8722,8641],HDW:t.HDW3},8642:{dir:r.V,sizes:[.888],stretch:[0,9168,8642],HDW:t.HDW1},8643:{dir:r.V,sizes:[.888],stretch:[0,9168,8643],HDW:t.HDW1},8656:f,8657:{dir:r.V,sizes:[.888],stretch:[8657,8214],HDW:[.599,0,.778]},8658:m,8659:{dir:r.V,sizes:[.888],stretch:[0,8214,8659],HDW:[.6,0,.778]},8660:g,8661:{dir:r.V,sizes:[1.044],stretch:[8657,8214,8659],HDW:[.75,.25,.778]},8666:{dir:r.H,sizes:[1],stretch:[8666,8801],HDW:[.464,-.036,.5]},8667:{dir:r.H,sizes:[1],stretch:[0,8801,8667],HDW:[.464,-.036,.5]},8722:v,8725:i,8730:{dir:r.V,sizes:t.VSIZES,stretch:[57345,57344,9143],fullExt:[.65,2.3],HDW:[.85,.35,1.056]},8739:y,8741:{dir:r.V,sizes:[1],stretch:[0,8741],HDW:[.627,.015,.556]},8968:{dir:r.V,sizes:t.VSIZES,stretch:[9121,9122],HDW:t.HDW2},8969:{dir:r.V,sizes:t.VSIZES,stretch:[9124,9125],HDW:t.HDW2},8970:{dir:r.V,sizes:t.VSIZES,stretch:[0,9122,9123],HDW:t.HDW2},8971:{dir:r.V,sizes:t.VSIZES,stretch:[0,9125,9126],HDW:t.HDW2},8978:_,8994:_,8995:b,9001:A,9002:C,9130:{dir:r.V,sizes:[.32],stretch:[9130,9130,9130],HDW:[.29,.015,.889]},9135:l,9136:{dir:r.V,sizes:[.989],stretch:[9127,9130,9133],HDW:[.75,.25,.889]},9137:{dir:r.V,sizes:[.989],stretch:[9131,9130,9129],HDW:[.75,.25,.889]},9140:{dir:r.H,stretch:[9484,8722,9488],HDW:t.HDW3,min:1},9141:{dir:r.H,stretch:[9492,8722,9496],HDW:t.HDW3,min:1},9168:{dir:r.V,sizes:[.602,1],schar:[0,8739],variants:[1,0],stretch:[0,8739],HDW:[.602,0,.333]},9180:_,9181:b,9182:M,9183:w,9184:{dir:r.H,stretch:[714,713,715],HDW:[.59,-.544,.5],min:1},9185:{dir:r.H,stretch:[715,713,714],HDW:[.59,-.544,.5],min:1},9472:l,10072:y,10216:A,10217:C,10222:{dir:r.V,sizes:[.989],stretch:[9127,9130,9129],HDW:[.75,.25,.889]},10223:{dir:r.V,sizes:[.989],stretch:[9131,9130,9133],HDW:[.75,.25,.889]},10229:c,10230:u,10231:d,10232:f,10233:m,10234:g,10235:h,10236:p,10237:x,10238:E,10502:x,10503:E,10574:{dir:r.H,stretch:[8636,8722,8640],HDW:t.HDW3,min:2},10575:{dir:r.V,stretch:[8638,9168,8642],HDW:t.HDW1,min:1.776},10576:{dir:r.H,stretch:[8637,8722,8641],HDW:t.HDW3,min:2},10577:{dir:r.V,stretch:[8639,9168,8643],HDW:t.HDW1,min:.5},10586:{dir:r.H,stretch:[8636,8722,8739],HDW:t.HDW3,min:1.278},10587:{dir:r.H,stretch:[8739,8722,8640],HDW:t.HDW3,min:1.278},10588:{dir:r.V,stretch:[8638,9168,8869],HDW:t.HDW1,min:1.556},10589:{dir:r.V,stretch:[8868,9168,8642],HDW:t.HDW1,min:1.556},10590:{dir:r.H,stretch:[8637,8722,8739],HDW:t.HDW3,min:1.278},10591:{dir:r.H,stretch:[8739,8722,8641],HDW:t.HDW3,min:1.278},10592:{dir:r.V,stretch:[8639,9168,8869],HDW:t.HDW1,min:1.776},10593:{dir:r.V,stretch:[8868,9168,8643],HDW:t.HDW1,min:1.776},12296:A,12297:C,65079:M,65080:w}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLAdaptor=void 0;var a=function(e){function t(t){var n=e.call(this,t.document)||this;return n.window=t,n.parser=new t.DOMParser,n}return i(t,e),t.prototype.parse=function(e,t){return void 0===t&&(t="text/html"),this.parser.parseFromString(e,t)},t.prototype.create=function(e,t){return t?this.document.createElementNS(t,e):this.document.createElement(e)},t.prototype.text=function(e){return this.document.createTextNode(e)},t.prototype.head=function(e){return e.head},t.prototype.body=function(e){return e.body},t.prototype.root=function(e){return e.documentElement},t.prototype.doctype=function(e){return e.doctype?"<!DOCTYPE "+e.doctype.name+">":""},t.prototype.tags=function(e,t,n){void 0===n&&(n=null);var r=n?e.getElementsByTagNameNS(n,t):e.getElementsByTagName(t);return Array.from(r)},t.prototype.getElements=function(e,t){var n,r,i=[];try{for(var a=o(e),s=a.next();!s.done;s=a.next()){var l=s.value;"string"==typeof l?i=i.concat(Array.from(this.document.querySelectorAll(l))):Array.isArray(l)||l instanceof this.window.NodeList||l instanceof this.window.HTMLCollection?i=i.concat(Array.from(l)):i.push(l)}}catch(e){n={error:e}}finally{try{s&&!s.done&&(r=a.return)&&r.call(a)}finally{if(n)throw n.error}}return i},t.prototype.contains=function(e,t){return e.contains(t)},t.prototype.parent=function(e){return e.parentNode},t.prototype.append=function(e,t){return e.appendChild(t)},t.prototype.insert=function(e,t){return this.parent(t).insertBefore(e,t)},t.prototype.remove=function(e){return this.parent(e).removeChild(e)},t.prototype.replace=function(e,t){return this.parent(t).replaceChild(e,t)},t.prototype.clone=function(e){return e.cloneNode(!0)},t.prototype.split=function(e,t){return e.splitText(t)},t.prototype.next=function(e){return e.nextSibling},t.prototype.previous=function(e){return e.previousSibling},t.prototype.firstChild=function(e){return e.firstChild},t.prototype.lastChild=function(e){return e.lastChild},t.prototype.childNodes=function(e){return Array.from(e.childNodes)},t.prototype.childNode=function(e,t){return e.childNodes[t]},t.prototype.kind=function(e){var t=e.nodeType;return 1===t||3===t||8===t?e.nodeName.toLowerCase():""},t.prototype.value=function(e){return e.nodeValue||""},t.prototype.textContent=function(e){return e.textContent},t.prototype.innerHTML=function(e){return e.innerHTML},t.prototype.outerHTML=function(e){return e.outerHTML},t.prototype.serializeXML=function(e){return(new this.window.XMLSerializer).serializeToString(e)},t.prototype.setAttribute=function(e,t,n,r){return void 0===r&&(r=null),r?(t=r.replace(/.*\//,"")+":"+t.replace(/^.*:/,""),e.setAttributeNS(r,t,n)):e.setAttribute(t,n)},t.prototype.getAttribute=function(e,t){return e.getAttribute(t)},t.prototype.removeAttribute=function(e,t){return e.removeAttribute(t)},t.prototype.hasAttribute=function(e,t){return e.hasAttribute(t)},t.prototype.allAttributes=function(e){return Array.from(e.attributes).map((function(e){return{name:e.name,value:e.value}}))},t.prototype.addClass=function(e,t){e.classList?e.classList.add(t):e.className=(e.className+" "+t).trim()},t.prototype.removeClass=function(e,t){e.classList?e.classList.remove(t):e.className=e.className.split(/ /).filter((function(e){return e!==t})).join(" ")},t.prototype.hasClass=function(e,t){return e.classList?e.classList.contains(t):e.className.split(/ /).indexOf(t)>=0},t.prototype.setStyle=function(e,t,n){e.style[t]=n},t.prototype.getStyle=function(e,t){return e.style[t]},t.prototype.allStyles=function(e){return e.style.cssText},t.prototype.insertRules=function(e,t){var n,r;try{for(var i=o(t.reverse()),a=i.next();!a.done;a=i.next()){var s=a.value;try{e.sheet.insertRule(s,0)}catch(e){console.warn("MathJax: can't insert css rule '"+s+"': "+e.message)}}}catch(e){n={error:e}}finally{try{a&&!a.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}},t.prototype.fontSize=function(e){var t=this.window.getComputedStyle(e);return parseFloat(t.fontSize)},t.prototype.fontFamily=function(e){return this.window.getComputedStyle(e).fontFamily||""},t.prototype.nodeSize=function(e,t,n){if(void 0===t&&(t=1),void 0===n&&(n=!1),n&&e.getBBox){var r=e.getBBox();return[r.width/t,r.height/t]}return[e.offsetWidth/t,e.offsetHeight/t]},t.prototype.nodeBBox=function(e){var t=e.getBoundingClientRect();return{left:t.left,right:t.right,top:t.top,bottom:t.bottom}},t}(n(933).AbstractDOMAdaptor);t.HTMLAdaptor=a},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractDOMAdaptor=void 0;var i=function(){function e(e){void 0===e&&(e=null),this.document=e}return e.prototype.node=function(e,t,n,i){var o,a;void 0===t&&(t={}),void 0===n&&(n=[]);var s=this.create(e,i);this.setAttributes(s,t);try{for(var l=r(n),c=l.next();!c.done;c=l.next()){var u=c.value;this.append(s,u)}}catch(e){o={error:e}}finally{try{c&&!c.done&&(a=l.return)&&a.call(l)}finally{if(o)throw o.error}}return s},e.prototype.setAttributes=function(e,t){var n,i,o,a,s,l;if(t.style&&"string"!=typeof t.style)try{for(var c=r(Object.keys(t.style)),u=c.next();!u.done;u=c.next()){var d=u.value;this.setStyle(e,d.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()})),t.style[d])}}catch(e){n={error:e}}finally{try{u&&!u.done&&(i=c.return)&&i.call(c)}finally{if(n)throw n.error}}if(t.properties)try{for(var h=r(Object.keys(t.properties)),p=h.next();!p.done;p=h.next()){e[d=p.value]=t.properties[d]}}catch(e){o={error:e}}finally{try{p&&!p.done&&(a=h.return)&&a.call(h)}finally{if(o)throw o.error}}try{for(var f=r(Object.keys(t)),m=f.next();!m.done;m=f.next()){"style"===(d=m.value)&&"string"!=typeof t.style||"properties"===d||this.setAttribute(e,d,t[d])}}catch(e){s={error:e}}finally{try{m&&!m.done&&(l=f.return)&&l.call(f)}finally{if(s)throw s.error}}},e.prototype.replace=function(e,t){return this.insert(e,t),this.remove(t),t},e.prototype.childNode=function(e,t){return this.childNodes(e)[t]},e.prototype.allClasses=function(e){var t=this.getAttribute(e,"class");return t?t.replace(/  +/g," ").replace(/^ /,"").replace(/ $/,"").split(/ /):[]},e}();t.AbstractDOMAdaptor=i},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLHandler=void 0;var o=n(935),a=n(947),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.documentClass=a.HTMLDocument,t}return i(t,e),t.prototype.handlesDocument=function(e){var t=this.adaptor;if("string"==typeof e)try{e=t.parse(e,"text/html")}catch(e){}return e instanceof t.window.Document||e instanceof t.window.HTMLElement||e instanceof t.window.DocumentFragment},t.prototype.create=function(t,n){var r=this.adaptor;if("string"==typeof t)t=r.parse(t,"text/html");else if(t instanceof r.window.HTMLElement||t instanceof r.window.DocumentFragment){var i=t;t=r.parse("","text/html"),r.append(r.body(t),i)}return e.prototype.create.call(this,t,n)},t}(o.AbstractHandler);t.HTMLHandler=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractHandler=void 0;var o=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t}(n(450).AbstractMathDocument),a=function(){function e(e,t){void 0===t&&(t=5),this.documentClass=o,this.adaptor=e,this.priority=t}return Object.defineProperty(e.prototype,"name",{get:function(){return this.constructor.NAME},enumerable:!1,configurable:!0}),e.prototype.handlesDocument=function(e){return!1},e.prototype.create=function(e,t){return new this.documentClass(e,this.adaptor,t)},e.NAME="generic",e}();t.AbstractHandler=a},function(e,t,n){"use strict";var r=this&&this.__generator||function(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}},i=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},o=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},a=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.LinkedList=t.ListItem=t.END=void 0,t.END=Symbol();var s=function(e){void 0===e&&(e=null),this.next=null,this.prev=null,this.data=e};t.ListItem=s;var l=function(){function e(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];this.list=new s(t.END),this.list.next=this.list.prev=this.list,this.push.apply(this,o([],i(e)))}return e.prototype.isBefore=function(e,t){return e<t},e.prototype.push=function(){for(var e,t,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];try{for(var i=a(n),o=i.next();!o.done;o=i.next()){var l=o.value,c=new s(l);c.next=this.list,c.prev=this.list.prev,this.list.prev=c,c.prev.next=c}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return this},e.prototype.pop=function(){var e=this.list.prev;return e.data===t.END?null:(this.list.prev=e.prev,e.prev.next=this.list,e.next=e.prev=null,e.data)},e.prototype.unshift=function(){for(var e,t,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];try{for(var i=a(n.slice(0).reverse()),o=i.next();!o.done;o=i.next()){var l=o.value,c=new s(l);c.next=this.list.next,c.prev=this.list,this.list.next=c,c.next.prev=c}}catch(t){e={error:t}}finally{try{o&&!o.done&&(t=i.return)&&t.call(i)}finally{if(e)throw e.error}}return this},e.prototype.shift=function(){var e=this.list.next;return e.data===t.END?null:(this.list.next=e.next,e.next.prev=this.list,e.next=e.prev=null,e.data)},e.prototype.remove=function(){for(var e,n,r=[],i=0;i<arguments.length;i++)r[i]=arguments[i];var o=new Map;try{for(var s=a(r),l=s.next();!l.done;l=s.next()){var c=l.value;o.set(c,!0)}}catch(t){e={error:t}}finally{try{l&&!l.done&&(n=s.return)&&n.call(s)}finally{if(e)throw e.error}}for(var u=this.list.next;u.data!==t.END;){var d=u.next;o.has(u.data)&&(u.prev.next=u.next,u.next.prev=u.prev,u.next=u.prev=null),u=d}},e.prototype.clear=function(){return this.list.next.prev=this.list.prev.next=null,this.list.next=this.list.prev=this.list,this},e.prototype[Symbol.iterator]=function(){var e;return r(this,(function(n){switch(n.label){case 0:e=this.list.next,n.label=1;case 1:return e.data===t.END?[3,3]:[4,e.data];case 2:return n.sent(),e=e.next,[3,1];case 3:return[2]}}))},e.prototype.reversed=function(){var e;return r(this,(function(n){switch(n.label){case 0:e=this.list.prev,n.label=1;case 1:return e.data===t.END?[3,3]:[4,e.data];case 2:return n.sent(),e=e.prev,[3,1];case 3:return[2]}}))},e.prototype.insert=function(e,n){void 0===n&&(n=null),null===n&&(n=this.isBefore.bind(this));for(var r=new s(e),i=this.list.next;i.data!==t.END&&n(i.data,r.data);)i=i.next;return r.prev=i.prev,r.next=i,i.prev.next=i.prev=r,this},e.prototype.sort=function(t){var n,r;void 0===t&&(t=null),null===t&&(t=this.isBefore.bind(this));var i=[];try{for(var o=a(this),s=o.next();!s.done;s=o.next()){var l=s.value;i.push(new e(l))}}catch(e){n={error:e}}finally{try{s&&!s.done&&(r=o.return)&&r.call(o)}finally{if(n)throw n.error}}for(this.list.next=this.list.prev=this.list;i.length>1;){var c=i.shift(),u=i.shift();c.merge(u,t),i.push(c)}return i.length&&(this.list=i[0].list),this},e.prototype.merge=function(e,n){var r,o,a,s,l;void 0===n&&(n=null),null===n&&(n=this.isBefore.bind(this));for(var c=this.list.next,u=e.list.next;c.data!==t.END&&u.data!==t.END;)n(u.data,c.data)?(r=i([c,u],2),u.prev.next=r[0],c.prev.next=r[1],o=i([c.prev,u.prev],2),u.prev=o[0],c.prev=o[1],a=i([e.list,this.list],2),this.list.prev.next=a[0],e.list.prev.next=a[1],s=i([e.list.prev,this.list.prev],2),this.list.prev=s[0],e.list.prev=s[1],c=(l=i([u.next,c],2))[0],u=l[1]):c=c.next;return u.data!==t.END&&(this.list.prev.next=e.list.next,e.list.next.prev=this.list.prev,e.list.prev.next=this.list,this.list.prev=e.list.prev,e.list.next=e.list.prev=e.list),this},e}();t.LinkedList=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.MmlFactory=void 0;var o=n(938),a=n(939),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"MML",{get:function(){return this.node},enumerable:!1,configurable:!0}),t.defaultNodes=a.MML,t}(o.AbstractNodeFactory);t.MmlFactory=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.AbstractNodeFactory=void 0;var o=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t.prototype.create=function(e,t,n){return void 0===t&&(t={}),void 0===n&&(n=[]),this.node[e](t,n)},t}(n(181).AbstractFactory);t.AbstractNodeFactory=o},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.MML=void 0;var i=n(23),o=n(423),a=n(424),s=n(425),l=n(134),c=n(427),u=n(428),d=n(426),h=n(432),p=n(434),f=n(436),m=n(437),g=n(940),v=n(941),y=n(429),_=n(942),b=n(433),M=n(430),w=n(445),A=n(187),C=n(438),x=n(439),E=n(440),L=n(442),S=n(443),T=n(943),O=n(944),I=n(446),k=n(447),D=n(448),N=n(945);t.MML=((r={})[o.MmlMath.prototype.kind]=o.MmlMath,r[a.MmlMi.prototype.kind]=a.MmlMi,r[s.MmlMn.prototype.kind]=s.MmlMn,r[l.MmlMo.prototype.kind]=l.MmlMo,r[c.MmlMtext.prototype.kind]=c.MmlMtext,r[u.MmlMspace.prototype.kind]=u.MmlMspace,r[d.MmlMs.prototype.kind]=d.MmlMs,r[h.MmlMrow.prototype.kind]=h.MmlMrow,r[h.MmlInferredMrow.prototype.kind]=h.MmlInferredMrow,r[p.MmlMfrac.prototype.kind]=p.MmlMfrac,r[f.MmlMsqrt.prototype.kind]=f.MmlMsqrt,r[m.MmlMroot.prototype.kind]=m.MmlMroot,r[g.MmlMstyle.prototype.kind]=g.MmlMstyle,r[v.MmlMerror.prototype.kind]=v.MmlMerror,r[y.MmlMpadded.prototype.kind]=y.MmlMpadded,r[_.MmlMphantom.prototype.kind]=_.MmlMphantom,r[b.MmlMfenced.prototype.kind]=b.MmlMfenced,r[M.MmlMenclose.prototype.kind]=M.MmlMenclose,r[w.MmlMaction.prototype.kind]=w.MmlMaction,r[A.MmlMsub.prototype.kind]=A.MmlMsub,r[A.MmlMsup.prototype.kind]=A.MmlMsup,r[A.MmlMsubsup.prototype.kind]=A.MmlMsubsup,r[C.MmlMunder.prototype.kind]=C.MmlMunder,r[C.MmlMover.prototype.kind]=C.MmlMover,r[C.MmlMunderover.prototype.kind]=C.MmlMunderover,r[x.MmlMmultiscripts.prototype.kind]=x.MmlMmultiscripts,r[x.MmlMprescripts.prototype.kind]=x.MmlMprescripts,r[x.MmlNone.prototype.kind]=x.MmlNone,r[E.MmlMtable.prototype.kind]=E.MmlMtable,r[L.MmlMlabeledtr.prototype.kind]=L.MmlMlabeledtr,r[L.MmlMtr.prototype.kind]=L.MmlMtr,r[S.MmlMtd.prototype.kind]=S.MmlMtd,r[T.MmlMaligngroup.prototype.kind]=T.MmlMaligngroup,r[O.MmlMalignmark.prototype.kind]=O.MmlMalignmark,r[I.MmlMglyph.prototype.kind]=I.MmlMglyph,r[k.MmlSemantics.prototype.kind]=k.MmlSemantics,r[k.MmlAnnotation.prototype.kind]=k.MmlAnnotation,r[k.MmlAnnotationXML.prototype.kind]=k.MmlAnnotationXML,r[D.TeXAtom.prototype.kind]=D.TeXAtom,r[N.MathChoice.prototype.kind]=N.MathChoice,r[i.TextNode.prototype.kind]=i.TextNode,r[i.XMLNode.prototype.kind]=i.XMLNode,r)},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMstyle=void 0;var a=n(23),s=n(110),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mstyle"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"notParent",{get:function(){return this.childNodes[0]&&1===this.childNodes[0].childNodes.length},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(e,t,n,r){var i=this.attributes.getExplicit("scriptlevel");null!=i&&((i=i.toString()).match(/^\s*[-+]/)?n+=parseInt(i):n=parseInt(i),r=!1);var o=this.attributes.getExplicit("displaystyle");null!=o&&(t=!0===o,r=!1);var a=this.attributes.getExplicit("data-cramped");null!=a&&(r=a),e=this.addInheritedAttributes(e,this.attributes.getAllAttributes()),this.childNodes[0].setInheritedAttributes(e,t,n,r)},t.defaults=o(o({},a.AbstractMmlLayoutNode.defaults),{scriptlevel:s.INHERIT,displaystyle:s.INHERIT,scriptsizemultiplier:1/Math.sqrt(2),scriptminsize:"8px",mathbackground:s.INHERIT,mathcolor:s.INHERIT,dir:s.INHERIT,infixlinebreakstyle:"before"}),t}(a.AbstractMmlLayoutNode);t.MmlMstyle=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMerror=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"merror"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return-1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"linebreakContainer",{get:function(){return!0},enumerable:!1,configurable:!0}),t.defaults=o({},a.AbstractMmlNode.defaults),t}(a.AbstractMmlNode);t.MmlMerror=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMphantom=void 0;var a=n(23),s=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.texclass=a.TEXCLASS.ORD,t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"mphantom"},enumerable:!1,configurable:!0}),t.defaults=o({},a.AbstractMmlLayoutNode.defaults),t}(a.AbstractMmlLayoutNode);t.MmlMphantom=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMaligngroup=void 0;var a=n(23),s=n(110),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"maligngroup"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setChildInheritedAttributes=function(t,n,r,i){t=this.addInheritedAttributes(t,this.attributes.getAllAttributes()),e.prototype.setChildInheritedAttributes.call(this,t,n,r,i)},t.defaults=o(o({},a.AbstractMmlLayoutNode.defaults),{groupalign:s.INHERIT}),t}(a.AbstractMmlLayoutNode);t.MmlMaligngroup=l},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MmlMalignmark=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"malignmark"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 0},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isSpacelike",{get:function(){return!0},enumerable:!1,configurable:!0}),t.defaults=o(o({},a.AbstractMmlNode.defaults),{edge:"left"}),t}(a.AbstractMmlNode);t.MmlMalignmark=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};Object.defineProperty(t,"__esModule",{value:!0}),t.MathChoice=void 0;var a=n(23),s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"MathChoice"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"arity",{get:function(){return 4},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"notParent",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.setInheritedAttributes=function(e,t,n,r){var i=t?0:Math.max(0,Math.min(n,2))+1,o=this.childNodes[i]||this.factory.create("mrow");this.parent.replaceChild(o,this),o.setInheritedAttributes(e,t,n,r)},t.defaults=o({},a.AbstractMmlBaseNode.defaults),t}(a.AbstractMmlBaseNode);t.MathChoice=s},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0}),t.BitFieldClass=t.BitField=void 0;var l=function(){function e(){this.bits=0}return e.allocate=function(){for(var t,n,r=[],i=0;i<arguments.length;i++)r[i]=arguments[i];try{for(var a=o(r),s=a.next();!s.done;s=a.next()){var l=s.value;if(this.has(l))throw new Error("Bit already allocated for "+l);if(this.next===e.MAXBIT)throw new Error("Maximum number of bits already allocated");this.names.set(l,this.next),this.next<<=1}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}},e.has=function(e){return this.names.has(e)},e.prototype.set=function(e){this.bits|=this.getBit(e)},e.prototype.clear=function(e){this.bits&=~this.getBit(e)},e.prototype.isSet=function(e){return!!(this.bits&this.getBit(e))},e.prototype.reset=function(){this.bits=0},e.prototype.getBit=function(e){var t=this.constructor.names.get(e);if(!t)throw new Error("Unknown bit-field name: "+e);return t},e.MAXBIT=1<<31,e.next=1,e.names=new Map,e}();t.BitField=l,t.BitFieldClass=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var n=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t}(l);return n.allocate.apply(n,s([],a(e))),n}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__assign||function(){return(o=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},s=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLDocument=void 0;var l=n(450),c=n(47),u=n(948),d=n(949),h=n(950),p=n(109),f=function(e){function t(t,n,r){var i=this,o=a(c.separateOptions(r,h.HTMLDomStrings.OPTIONS),2),s=o[0],l=o[1];return(i=e.call(this,t,n,s)||this).domStrings=i.options.DomStrings||new h.HTMLDomStrings(l),i.domStrings.adaptor=n,i.styles=[],i}return i(t,e),t.prototype.findPosition=function(e,t,n,r){var i,o,l=this.adaptor;try{for(var c=s(r[e]),u=c.next();!u.done;u=c.next()){var d=u.value,h=a(d,2),p=h[0],f=h[1];if(t<=f&&"#text"===l.kind(p))return{node:p,n:Math.max(t,0),delim:n};t-=f}}catch(e){i={error:e}}finally{try{u&&!u.done&&(o=c.return)&&o.call(c)}finally{if(i)throw i.error}}return{node:null,n:0,delim:n}},t.prototype.mathItem=function(e,t,n){var r=e.math,i=this.findPosition(e.n,e.start.n,e.open,n),o=this.findPosition(e.n,e.end.n,e.close,n);return new this.options.MathItem(r,t,e.display,i,o)},t.prototype.findMath=function(e){var t,n,r,i,o,l,u,d,h;if(!this.processed.isSet("findMath")){this.adaptor.document=this.document,e=c.userOptions({elements:this.options.elements||[this.adaptor.body(this.document)]},e);try{for(var p=s(this.adaptor.getElements(e.elements,this.document)),f=p.next();!f.done;f=p.next()){var m=f.value,g=a([null,null],2),v=g[0],y=g[1];try{for(var _=(r=void 0,s(this.inputJax)),b=_.next();!b.done;b=_.next()){var M=b.value,w=new this.options.MathList;if(M.processStrings){null===v&&(v=(o=a(this.domStrings.find(m),2))[0],y=o[1]);try{for(var A=(l=void 0,s(M.findMath(v))),C=A.next();!C.done;C=A.next()){var x=C.value;w.push(this.mathItem(x,M,y))}}catch(e){l={error:e}}finally{try{C&&!C.done&&(u=A.return)&&u.call(A)}finally{if(l)throw l.error}}}else try{for(var E=(d=void 0,s(M.findMath(m))),L=E.next();!L.done;L=E.next()){x=L.value;var S=new this.options.MathItem(x.math,M,x.display,x.start,x.end);w.push(S)}}catch(e){d={error:e}}finally{try{L&&!L.done&&(h=E.return)&&h.call(E)}finally{if(d)throw d.error}}this.math.merge(w)}}catch(e){r={error:e}}finally{try{b&&!b.done&&(i=_.return)&&i.call(_)}finally{if(r)throw r.error}}}}catch(e){t={error:e}}finally{try{f&&!f.done&&(n=p.return)&&n.call(p)}finally{if(t)throw t.error}}this.processed.set("findMath")}return this},t.prototype.updateDocument=function(){return this.processed.isSet("updateDocument")||(this.addPageElements(),this.addStyleSheet(),e.prototype.updateDocument.call(this),this.processed.set("updateDocument")),this},t.prototype.addPageElements=function(){var e=this.adaptor.body(this.document),t=this.documentPageElements();t&&this.adaptor.append(e,t)},t.prototype.addStyleSheet=function(){var e=this.documentStyleSheet(),t=this.adaptor;if(e&&!t.parent(e)){var n=t.head(this.document),r=this.findSheet(n,t.getAttribute(e,"id"));r?t.replace(e,r):t.append(n,e)}},t.prototype.findSheet=function(e,t){var n,r;if(t)try{for(var i=s(this.adaptor.tags(e,"style")),o=i.next();!o.done;o=i.next()){var a=o.value;if(this.adaptor.getAttribute(a,"id")===t)return a}}catch(e){n={error:e}}finally{try{o&&!o.done&&(r=i.return)&&r.call(i)}finally{if(n)throw n.error}}return null},t.prototype.removeFromDocument=function(e){var t,n;if(void 0===e&&(e=!1),this.processed.isSet("updateDocument"))try{for(var r=s(this.math),i=r.next();!i.done;i=r.next()){var o=i.value;o.state()>=p.STATE.INSERTED&&o.state(p.STATE.TYPESET,e)}}catch(e){t={error:e}}finally{try{i&&!i.done&&(n=r.return)&&n.call(r)}finally{if(t)throw t.error}}return this.processed.clear("updateDocument"),this},t.prototype.documentStyleSheet=function(){return this.outputJax.styleSheet(this)},t.prototype.documentPageElements=function(){return this.outputJax.pageElements(this)},t.prototype.addStyles=function(e){this.styles.push(e)},t.prototype.getStyles=function(){return this.styles},t.KIND="HTML",t.OPTIONS=o(o({},l.AbstractMathDocument.OPTIONS),{renderActions:c.expandable(o(o({},l.AbstractMathDocument.OPTIONS.renderActions),{styles:[p.STATE.INSERTED+1,"","updateStyleSheet",!1]})),MathList:d.HTMLMathList,MathItem:u.HTMLMathItem,DomStrings:null}),t}(l.AbstractMathDocument);t.HTMLDocument=f},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLMathItem=void 0;var o=n(109),a=function(e){function t(t,n,r,i,o){return void 0===r&&(r=!0),void 0===i&&(i={node:null,n:0,delim:""}),void 0===o&&(o={node:null,n:0,delim:""}),e.call(this,t,n,r,i,o)||this}return i(t,e),Object.defineProperty(t.prototype,"adaptor",{get:function(){return this.inputJax.adaptor},enumerable:!1,configurable:!0}),t.prototype.updateDocument=function(e){if(this.state()<o.STATE.INSERTED){if(this.inputJax.processStrings){var t=this.start.node;if(t===this.end.node)this.end.n&&this.end.n<this.adaptor.value(this.end.node).length&&this.adaptor.split(this.end.node,this.end.n),this.start.n&&(t=this.adaptor.split(this.start.node,this.start.n)),this.adaptor.replace(this.typesetRoot,t);else{for(this.start.n&&(t=this.adaptor.split(t,this.start.n));t!==this.end.node;){var n=this.adaptor.next(t);this.adaptor.remove(t),t=n}this.adaptor.insert(this.typesetRoot,t),this.end.n<this.adaptor.value(t).length&&this.adaptor.split(t,this.end.n),this.adaptor.remove(t)}}else this.adaptor.replace(this.typesetRoot,this.start.node);this.start.node=this.end.node=this.typesetRoot,this.start.n=this.end.n=0,this.state(o.STATE.INSERTED)}},t.prototype.updateStyleSheet=function(e){e.addStyleSheet()},t.prototype.removeFromDocument=function(e){if(void 0===e&&(e=!1),this.state()>=o.STATE.TYPESET){var t=this.adaptor,n=this.start.node,r=t.text("");if(e){var i=this.start.delim+this.math+this.end.delim;if(this.inputJax.processStrings)r=t.text(i);else{var a=t.parse(i,"text/html");r=t.firstChild(t.body(a))}}t.parent(n)&&t.replace(r,n),this.start.node=this.end.node=r,this.start.n=this.end.n=0}},t}(o.AbstractMathItem);t.HTMLMathItem=a},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLMathList=void 0;var o=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),t}(n(451).AbstractMathList);t.HTMLMathList=o},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.HTMLDomStrings=void 0;var i=n(47),o=function(){function e(e){void 0===e&&(e=null);var t=this.constructor;this.options=i.userOptions(i.defaultOptions({},t.OPTIONS),e),this.init(),this.getPatterns()}return e.prototype.init=function(){this.strings=[],this.string="",this.snodes=[],this.nodes=[],this.stack=[]},e.prototype.getPatterns=function(){var e=i.makeArray(this.options.skipHtmlTags),t=i.makeArray(this.options.ignoreHtmlClass),n=i.makeArray(this.options.processHtmlClass);this.skipHtmlTags=new RegExp("^(?:"+e.join("|")+")$","i"),this.ignoreHtmlClass=new RegExp("(?:^| )(?:"+t.join("|")+")(?: |$)"),this.processHtmlClass=new RegExp("(?:^| )(?:"+n+")(?: |$)")},e.prototype.pushString=function(){this.string.match(/\S/)&&(this.strings.push(this.string),this.nodes.push(this.snodes)),this.string="",this.snodes=[]},e.prototype.extendString=function(e,t){this.snodes.push([e,t.length]),this.string+=t},e.prototype.handleText=function(e,t){return t||this.extendString(e,this.adaptor.value(e)),this.adaptor.next(e)},e.prototype.handleTag=function(e,t){if(!t){var n=this.options.includeHtmlTags[this.adaptor.kind(e)];this.extendString(e,n)}return this.adaptor.next(e)},e.prototype.handleContainer=function(e,t){this.pushString();var n=this.adaptor.getAttribute(e,"class")||"",r=this.adaptor.kind(e)||"",i=this.processHtmlClass.exec(n),o=e;return!this.adaptor.firstChild(e)||this.adaptor.getAttribute(e,"data-MJX")||!i&&this.skipHtmlTags.exec(r)?o=this.adaptor.next(e):(this.adaptor.next(e)&&this.stack.push([this.adaptor.next(e),t]),o=this.adaptor.firstChild(e),t=(t||this.ignoreHtmlClass.exec(n))&&!i),[o,t]},e.prototype.handleOther=function(e,t){return this.pushString(),this.adaptor.next(e)},e.prototype.find=function(e){var t,n;this.init();for(var i=this.adaptor.next(e),o=!1,a=this.options.includeHtmlTags;e&&e!==i;){var s=this.adaptor.kind(e);"#text"===s?e=this.handleText(e,o):a.hasOwnProperty(s)?e=this.handleTag(e,o):s?(e=(t=r(this.handleContainer(e,o),2))[0],o=t[1]):e=this.handleOther(e,o),!e&&this.stack.length&&(this.pushString(),e=(n=r(this.stack.pop(),2))[0],o=n[1])}this.pushString();var l=[this.strings,this.nodes];return this.init(),l},e.OPTIONS={skipHtmlTags:["script","noscript","style","textarea","pre","code","annotation","annotation-xml"],includeHtmlTags:{br:"\n",wbr:"","#comment":""},ignoreHtmlClass:"mathjax_ignore",processHtmlClass:"mathjax_process"},e}();t.HTMLDomStrings=o},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ActionConfiguration=t.ActionMethods=void 0;var r=n(29),i=n(49),o=n(28),a=n(57);t.ActionMethods={},t.ActionMethods.Macro=a.default.Macro,t.ActionMethods.Toggle=function(e,t){for(var n,r=[];"\\endtoggle"!==(n=e.GetArgument(t));)r.push(new i.default(n,e.stack.env,e.configuration).mml());e.Push(e.create("node","maction",r,{actiontype:"toggle"}))},t.ActionMethods.Mathtip=function(e,t){var n=e.ParseArg(t),r=e.ParseArg(t);e.Push(e.create("node","maction",[n,r],{actiontype:"tooltip"}))},new o.CommandMap("action-macros",{toggle:"Toggle",mathtip:"Mathtip",texttip:["Macro","\\mathtip{#1}{\\text{#2}}",2]},t.ActionMethods),t.ActionConfiguration=r.Configuration.create("action",{handler:{macro:["action-macros"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(112),i=n(28),o=n(50),a=n(73),s=n(37),l=n(23),c=n(58);new i.CharacterMap("AMSmath-mathchar0mo",a.default.mathchar0mo,{iiiint:["⨌",{texClass:l.TEXCLASS.OP}]}),new i.CommandMap("AMSmath-macros",{mathring:["Accent","02DA"],nobreakspace:"Tilde",negmedspace:["Spacer",c.MATHSPACE.negativemediummathspace],negthickspace:["Spacer",c.MATHSPACE.negativethickmathspace],idotsint:["MultiIntegral","\\int\\cdots\\int"],dddot:["Accent","20DB"],ddddot:["Accent","20DC"],sideset:["Macro","\\mathop{\\mathop{\\rlap{\\phantom{#3}}}\\nolimits#1\\!\\mathop{#3}\\nolimits#2}",3],boxed:["Macro","\\fbox{$\\displaystyle{#1}$}",1],tag:"HandleTag",notag:"HandleNoTag",eqref:["HandleRef",!0],substack:["Macro","\\begin{subarray}{c}#1\\end{subarray}",1],injlim:["NamedOp","inj&thinsp;lim"],projlim:["NamedOp","proj&thinsp;lim"],varliminf:["Macro","\\mathop{\\underline{\\mmlToken{mi}{lim}}}"],varlimsup:["Macro","\\mathop{\\overline{\\mmlToken{mi}{lim}}}"],varinjlim:["Macro","\\mathop{\\underrightarrow{\\mmlToken{mi}{lim}}}"],varprojlim:["Macro","\\mathop{\\underleftarrow{\\mmlToken{mi}{lim}}}"],DeclareMathOperator:"HandleDeclareOp",operatorname:"HandleOperatorName",SkipLimits:"SkipLimits",genfrac:"Genfrac",frac:["Genfrac","","","",""],tfrac:["Genfrac","","","","1"],dfrac:["Genfrac","","","","0"],binom:["Genfrac","(",")","0",""],tbinom:["Genfrac","(",")","0","1"],dbinom:["Genfrac","(",")","0","0"],cfrac:"CFrac",shoveleft:["HandleShove",o.TexConstant.Align.LEFT],shoveright:["HandleShove",o.TexConstant.Align.RIGHT],xrightarrow:["xArrow",8594,5,10],xleftarrow:["xArrow",8592,10,5]},r.AmsMethods),new i.EnvironmentMap("AMSmath-environment",a.default.environment,{"equation*":["Equation",null,!1],"eqnarray*":["EqnArray",null,!1,!0,"rcl",s.default.cols(0,c.MATHSPACE.thickmathspace),".5em"],align:["EqnArray",null,!0,!0,"rl",s.default.cols(0,2)],"align*":["EqnArray",null,!1,!0,"rl",s.default.cols(0,2)],multline:["Multline",null,!0],"multline*":["Multline",null,!1],split:["EqnArray",null,!1,!1,"rl",s.default.cols(0)],gather:["EqnArray",null,!0,!0,"c"],"gather*":["EqnArray",null,!1,!0,"c"],alignat:["AlignAt",null,!0,!0],"alignat*":["AlignAt",null,!1,!0],alignedat:["AlignAt",null,!1,!1],aligned:["AmsEqnArray",null,null,null,"rl",s.default.cols(0,2),".5em","D"],gathered:["AmsEqnArray",null,null,null,"c",null,".5em","D"],xalignat:["XalignAt",null,!0,!0],"xalignat*":["XalignAt",null,!1,!0],xxalignat:["XalignAt",null,!1,!1],flalign:["FlalignArray",null,!0,!1,!0,"rlc","auto auto fit"],"flalign*":["FlalignArray",null,!1,!1,!0,"rlc","auto auto fit"],subarray:["Array",null,null,null,null,s.default.cols(0),"0.1em","S",1],smallmatrix:["Array",null,null,null,"c",s.default.cols(1/3),".2em","S",1],matrix:["Array",null,null,null,"c"],pmatrix:["Array",null,"(",")","c"],bmatrix:["Array",null,"[","]","c"],Bmatrix:["Array",null,"\\{","\\}","c"],vmatrix:["Array",null,"\\vert","\\vert","c"],Vmatrix:["Array",null,"\\Vert","\\Vert","c"],cases:["Array",null,"\\{",".","ll",null,".2em","T"]},r.AmsMethods),new i.DelimiterMap("AMSmath-delimiter",a.default.delimiter,{"\\lvert":["|",{texClass:l.TEXCLASS.OPEN}],"\\rvert":["|",{texClass:l.TEXCLASS.CLOSE}],"\\lVert":["‖",{texClass:l.TEXCLASS.OPEN}],"\\rVert":["‖",{texClass:l.TEXCLASS.CLOSE}]}),new i.CharacterMap("AMSsymbols-mathchar0mi",a.default.mathchar0mi,{digamma:"ϝ",varkappa:"ϰ",varGamma:["Γ",{mathvariant:o.TexConstant.Variant.ITALIC}],varDelta:["Δ",{mathvariant:o.TexConstant.Variant.ITALIC}],varTheta:["Θ",{mathvariant:o.TexConstant.Variant.ITALIC}],varLambda:["Λ",{mathvariant:o.TexConstant.Variant.ITALIC}],varXi:["Ξ",{mathvariant:o.TexConstant.Variant.ITALIC}],varPi:["Π",{mathvariant:o.TexConstant.Variant.ITALIC}],varSigma:["Σ",{mathvariant:o.TexConstant.Variant.ITALIC}],varUpsilon:["Υ",{mathvariant:o.TexConstant.Variant.ITALIC}],varPhi:["Φ",{mathvariant:o.TexConstant.Variant.ITALIC}],varPsi:["Ψ",{mathvariant:o.TexConstant.Variant.ITALIC}],varOmega:["Ω",{mathvariant:o.TexConstant.Variant.ITALIC}],beth:"ℶ",gimel:"ℷ",daleth:"ℸ",backprime:["‵",{variantForm:!0}],hslash:"ℏ",varnothing:["∅",{variantForm:!0}],blacktriangle:"▴",triangledown:["▽",{variantForm:!0}],blacktriangledown:"▾",square:"◻",Box:"◻",blacksquare:"◼",lozenge:"◊",Diamond:"◊",blacklozenge:"⧫",circledS:["Ⓢ",{mathvariant:o.TexConstant.Variant.NORMAL}],bigstar:"★",sphericalangle:"∢",measuredangle:"∡",nexists:"∄",complement:"∁",mho:"℧",eth:["ð",{mathvariant:o.TexConstant.Variant.NORMAL}],Finv:"Ⅎ",diagup:"╱",Game:"⅁",diagdown:"╲",Bbbk:["k",{mathvariant:o.TexConstant.Variant.DOUBLESTRUCK}],yen:"¥",circledR:"®",checkmark:"✓",maltese:"✠"}),new i.CharacterMap("AMSsymbols-mathchar0mo",a.default.mathchar0mo,{dotplus:"∔",ltimes:"⋉",smallsetminus:["∖",{variantForm:!0}],rtimes:"⋊",Cap:"⋒",doublecap:"⋒",leftthreetimes:"⋋",Cup:"⋓",doublecup:"⋓",rightthreetimes:"⋌",barwedge:"⊼",curlywedge:"⋏",veebar:"⊻",curlyvee:"⋎",doublebarwedge:"⩞",boxminus:"⊟",circleddash:"⊝",boxtimes:"⊠",circledast:"⊛",boxdot:"⊡",circledcirc:"⊚",boxplus:"⊞",centerdot:["⋅",{variantForm:!0}],divideontimes:"⋇",intercal:"⊺",leqq:"≦",geqq:"≧",leqslant:"⩽",geqslant:"⩾",eqslantless:"⪕",eqslantgtr:"⪖",lesssim:"≲",gtrsim:"≳",lessapprox:"⪅",gtrapprox:"⪆",approxeq:"≊",lessdot:"⋖",gtrdot:"⋗",lll:"⋘",llless:"⋘",ggg:"⋙",gggtr:"⋙",lessgtr:"≶",gtrless:"≷",lesseqgtr:"⋚",gtreqless:"⋛",lesseqqgtr:"⪋",gtreqqless:"⪌",doteqdot:"≑",Doteq:"≑",eqcirc:"≖",risingdotseq:"≓",circeq:"≗",fallingdotseq:"≒",triangleq:"≜",backsim:"∽",thicksim:["∼",{variantForm:!0}],backsimeq:"⋍",thickapprox:["≈",{variantForm:!0}],subseteqq:"⫅",supseteqq:"⫆",Subset:"⋐",Supset:"⋑",sqsubset:"⊏",sqsupset:"⊐",preccurlyeq:"≼",succcurlyeq:"≽",curlyeqprec:"⋞",curlyeqsucc:"⋟",precsim:"≾",succsim:"≿",precapprox:"⪷",succapprox:"⪸",vartriangleleft:"⊲",lhd:"⊲",vartriangleright:"⊳",rhd:"⊳",trianglelefteq:"⊴",unlhd:"⊴",trianglerighteq:"⊵",unrhd:"⊵",vDash:["⊨",{variantForm:!0}],Vdash:"⊩",Vvdash:"⊪",smallsmile:["⌣",{variantForm:!0}],shortmid:["∣",{variantForm:!0}],smallfrown:["⌢",{variantForm:!0}],shortparallel:["∥",{variantForm:!0}],bumpeq:"≏",between:"≬",Bumpeq:"≎",pitchfork:"⋔",varpropto:["∝",{variantForm:!0}],backepsilon:"∍",blacktriangleleft:"◂",blacktriangleright:"▸",therefore:"∴",because:"∵",eqsim:"≂",vartriangle:["△",{variantForm:!0}],Join:"⋈",nless:"≮",ngtr:"≯",nleq:"≰",ngeq:"≱",nleqslant:["⪇",{variantForm:!0}],ngeqslant:["⪈",{variantForm:!0}],nleqq:["≰",{variantForm:!0}],ngeqq:["≱",{variantForm:!0}],lneq:"⪇",gneq:"⪈",lneqq:"≨",gneqq:"≩",lvertneqq:["≨",{variantForm:!0}],gvertneqq:["≩",{variantForm:!0}],lnsim:"⋦",gnsim:"⋧",lnapprox:"⪉",gnapprox:"⪊",nprec:"⊀",nsucc:"⊁",npreceq:["⋠",{variantForm:!0}],nsucceq:["⋡",{variantForm:!0}],precneqq:"⪵",succneqq:"⪶",precnsim:"⋨",succnsim:"⋩",precnapprox:"⪹",succnapprox:"⪺",nsim:"≁",ncong:"≇",nshortmid:["∤",{variantForm:!0}],nshortparallel:["∦",{variantForm:!0}],nmid:"∤",nparallel:"∦",nvdash:"⊬",nvDash:"⊭",nVdash:"⊮",nVDash:"⊯",ntriangleleft:"⋪",ntriangleright:"⋫",ntrianglelefteq:"⋬",ntrianglerighteq:"⋭",nsubseteq:"⊈",nsupseteq:"⊉",nsubseteqq:["⊈",{variantForm:!0}],nsupseteqq:["⊉",{variantForm:!0}],subsetneq:"⊊",supsetneq:"⊋",varsubsetneq:["⊊",{variantForm:!0}],varsupsetneq:["⊋",{variantForm:!0}],subsetneqq:"⫋",supsetneqq:"⫌",varsubsetneqq:["⫋",{variantForm:!0}],varsupsetneqq:["⫌",{variantForm:!0}],leftleftarrows:"⇇",rightrightarrows:"⇉",leftrightarrows:"⇆",rightleftarrows:"⇄",Lleftarrow:"⇚",Rrightarrow:"⇛",twoheadleftarrow:"↞",twoheadrightarrow:"↠",leftarrowtail:"↢",rightarrowtail:"↣",looparrowleft:"↫",looparrowright:"↬",leftrightharpoons:"⇋",rightleftharpoons:["⇌",{variantForm:!0}],curvearrowleft:"↶",curvearrowright:"↷",circlearrowleft:"↺",circlearrowright:"↻",Lsh:"↰",Rsh:"↱",upuparrows:"⇈",downdownarrows:"⇊",upharpoonleft:"↿",upharpoonright:"↾",downharpoonleft:"⇃",restriction:"↾",multimap:"⊸",downharpoonright:"⇂",leftrightsquigarrow:"↭",rightsquigarrow:"⇝",leadsto:"⇝",dashrightarrow:"⇢",dashleftarrow:"⇠",nleftarrow:"↚",nrightarrow:"↛",nLeftarrow:"⇍",nRightarrow:"⇏",nleftrightarrow:"↮",nLeftrightarrow:"⇎"}),new i.DelimiterMap("AMSsymbols-delimiter",a.default.delimiter,{"\\ulcorner":"⌜","\\urcorner":"⌝","\\llcorner":"⌞","\\lrcorner":"⌟"}),new i.CommandMap("AMSsymbols-macros",{implies:["Macro","\\;\\Longrightarrow\\;"],impliedby:["Macro","\\;\\Longleftarrow\\;"]},r.AmsMethods)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AmsCdConfiguration=void 0;var r=n(29);n(954),t.AmsCdConfiguration=r.Configuration.create("amscd",{handler:{character:["amscd_special"],macro:["amscd_macros"],environment:["amscd_environment"]},options:{amscd:{colspace:"5pt",rowspace:"5pt",harrowsize:"2.75em",varrowsize:"1.75em",hideHorizontalLabels:!1}}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(73),o=n(955);new r.EnvironmentMap("amscd_environment",i.default.environment,{CD:"CD"},o.default),new r.CommandMap("amscd_macros",{minCDarrowwidth:"minCDarrowwidth",minCDarrowheight:"minCDarrowheight"},o.default),new r.MacroMap("amscd_special",{"@":"arrow"},o.default)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(49),i=n(183),o=n(23),a=n(39),s={CD:function(e,t){e.Push(t);var n=e.itemFactory.create("array"),r=e.configuration.options.amscd;return n.setProperties({minw:e.stack.env.CD_minw||r.harrowsize,minh:e.stack.env.CD_minh||r.varrowsize}),n.arraydef={columnalign:"center",columnspacing:r.colspace,rowspacing:r.rowspace,displaystyle:!0},n},arrow:function(e,t){var n=e.string.charAt(e.i);if(!n.match(/[><VA.|=]/))return i.Other(e,t);e.i++;var l=e.stack.Top();l.isKind("array")&&!l.Size()||(s.cell(e,t),l=e.stack.Top());for(var c,u=l,d=u.table.length%2==1,h=(u.row.length+(d?0:1))%2;h;)s.cell(e,t),h--;var p={minsize:u.getProperty("minw"),stretchy:!0},f={minsize:u.getProperty("minh"),stretchy:!0,symmetric:!0,lspace:0,rspace:0};if("."===n);else if("|"===n)c=e.create("token","mo",f,"∥");else if("="===n)c=e.create("token","mo",p,"=");else{var m={">":"→","<":"←",V:"↓",A:"↑"}[n],g=e.GetUpTo(t+n,n),v=e.GetUpTo(t+n,n);if(">"===n||"<"===n){if(c=e.create("token","mo",p,m),g||(g="\\kern "+u.getProperty("minw")),g||v){var y={width:".67em",lspace:".33em"};if(c=e.create("node","munderover",[c]),g){var _=new r.default(g,e.stack.env,e.configuration).mml(),b=e.create("node","mpadded",[_],y);a.default.setAttribute(b,"voffset",".1em"),a.default.setChild(c,c.over,b)}if(v){var M=new r.default(v,e.stack.env,e.configuration).mml();a.default.setChild(c,c.under,e.create("node","mpadded",[M],y))}e.configuration.options.amscd.hideHorizontalLabels&&(c=e.create("node","mpadded",c,{depth:0,height:".67em"}))}}else{var w=e.create("token","mo",f,m);c=w,(g||v)&&(c=e.create("node","mrow"),g&&a.default.appendChildren(c,[new r.default("\\scriptstyle\\llap{"+g+"}",e.stack.env,e.configuration).mml()]),w.texClass=o.TEXCLASS.ORD,a.default.appendChildren(c,[w]),v&&a.default.appendChildren(c,[new r.default("\\scriptstyle\\rlap{"+v+"}",e.stack.env,e.configuration).mml()]))}}c&&e.Push(c),s.cell(e,t)},cell:function(e,t){var n=e.stack.Top();(n.table||[]).length%2==0&&0===(n.row||[]).length&&e.Push(e.create("node","mpadded",[],{height:"8.5pt",depth:"2pt"})),e.Push(e.itemFactory.create("cell").setProperties({isEntry:!0,name:t}))},minCDarrowwidth:function(e,t){e.stack.env.CD_minw=e.GetDimen(t)},minCDarrowheight:function(e,t){e.stack.env.CD_minh=e.GetDimen(t)}};t.default=s},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.BboxConfiguration=t.BboxMethods=void 0;var r=n(29),i=n(28),o=n(31);t.BboxMethods={},t.BboxMethods.BBox=function(e,t){for(var n,r,i,l=e.GetBrackets(t,""),c=e.ParseArg(t),u=l.split(/,/),d=0,h=u.length;d<h;d++){var p=u[d].trim(),f=p.match(/^(\.\d+|\d+(\.\d*)?)(pt|em|ex|mu|px|in|cm|mm)$/);if(f){if(n)throw new o.default("MultipleBBoxProperty","%1 specified twice in %2","Padding",t);var m=s(f[1]+f[3]);m&&(n={height:"+"+m,depth:"+"+m,lspace:m,width:"+"+2*parseInt(f[1],10)+f[3]})}else if(p.match(/^([a-z0-9]+|\#[0-9a-f]{6}|\#[0-9a-f]{3})$/i)){if(r)throw new o.default("MultipleBBoxProperty","%1 specified twice in %2","Background",t);r=p}else if(p.match(/^[-a-z]+:/i)){if(i)throw new o.default("MultipleBBoxProperty","%1 specified twice in %2","Style",t);i=a(p)}else if(""!==p)throw new o.default("InvalidBBoxProperty",'"%1" doesn\'t look like a color, a padding dimension, or a style',p)}n&&(c=e.create("node","mpadded",[c],n)),(r||i)&&(n={},r&&Object.assign(n,{mathbackground:r}),i&&Object.assign(n,{style:i}),c=e.create("node","mstyle",[c],n)),e.Push(c)};var a=function(e){return e},s=function(e){return e};new i.CommandMap("bbox",{bbox:"BBox"},t.BboxMethods),t.BboxConfiguration=r.Configuration.create("bbox",{handler:{macro:["bbox"]}})},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.BoldsymbolConfiguration=t.rewriteBoldTokens=t.createBoldToken=t.BoldsymbolMethods=void 0;var i=n(29),o=n(39),a=n(50),s=n(28),l=n(182),c={};function u(e,t,n,r){var i=l.NodeFactory.createToken(e,t,n,r);return"mtext"!==t&&e.configuration.parser.stack.env.boldsymbol&&(o.default.setProperty(i,"fixBold",!0),e.configuration.addNode("fixBold",i)),i}function d(e){var t,n;try{for(var i=r(e.data.getList("fixBold")),s=i.next();!s.done;s=i.next()){var l=s.value;if(o.default.getProperty(l,"fixBold")){var u=o.default.getAttribute(l,"mathvariant");null==u?o.default.setAttribute(l,"mathvariant",a.TexConstant.Variant.BOLD):o.default.setAttribute(l,"mathvariant",c[u]||u),o.default.removeProperties(l,"fixBold")}}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=i.return)&&n.call(i)}finally{if(t)throw t.error}}}c[a.TexConstant.Variant.NORMAL]=a.TexConstant.Variant.BOLD,c[a.TexConstant.Variant.ITALIC]=a.TexConstant.Variant.BOLDITALIC,c[a.TexConstant.Variant.FRAKTUR]=a.TexConstant.Variant.BOLDFRAKTUR,c[a.TexConstant.Variant.SCRIPT]=a.TexConstant.Variant.BOLDSCRIPT,c[a.TexConstant.Variant.SANSSERIF]=a.TexConstant.Variant.BOLDSANSSERIF,c["-tex-calligraphic"]="-tex-bold-calligraphic",c["-tex-oldstyle"]="-tex-bold-oldstyle",c["-tex-mathit"]=a.TexConstant.Variant.BOLDITALIC,t.BoldsymbolMethods={},t.BoldsymbolMethods.Boldsymbol=function(e,t){var n=e.stack.env.boldsymbol;e.stack.env.boldsymbol=!0;var r=e.ParseArg(t);e.stack.env.boldsymbol=n,e.Push(r)},new s.CommandMap("boldsymbol",{boldsymbol:"Boldsymbol"},t.BoldsymbolMethods),t.createBoldToken=u,t.rewriteBoldTokens=d,t.BoldsymbolConfiguration=i.Configuration.create("boldsymbol",{handler:{macro:["boldsymbol"]},nodes:{token:u},postprocessors:[d]})},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.BraketConfiguration=void 0;var i=n(29),o=n(959);n(960),t.BraketConfiguration=i.Configuration.create("braket",{handler:{character:["Braket-characters"],macro:["Braket-macros"]},items:(r={},r[o.BraketItem.prototype.kind]=o.BraketItem,r)})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.BraketItem=void 0;var o=n(95),a=n(23),s=n(37),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"braket"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){return t.isKind("close")?[[this.factory.create("mml",this.toMml())],!0]:t.isKind("mml")?(this.Push(t.toMml()),this.getProperty("single")?[[this.toMml()],!0]:o.BaseItem.fail):e.prototype.checkItem.call(this,t)},t.prototype.toMml=function(){var t=e.prototype.toMml.call(this),n=this.getProperty("open"),r=this.getProperty("close");if(this.getProperty("stretchy"))return s.default.fenced(this.factory.configuration,n,t,r);var i={fence:!0,stretchy:!1,symmetric:!0,texClass:a.TEXCLASS.OPEN},o=this.create("token","mo",i,n);i.texClass=a.TEXCLASS.CLOSE;var l=this.create("token","mo",i,r);return this.create("node","mrow",[o,t,l],{open:n,close:r,texClass:a.TEXCLASS.INNER})},t}(o.BaseItem);t.BraketItem=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(961);new r.CommandMap("Braket-macros",{bra:["Macro","{\\langle {#1} \\vert}",1],ket:["Macro","{\\vert {#1} \\rangle}",1],braket:["Braket","⟨","⟩",!1,1/0],set:["Braket","{","}",!1,1],Bra:["Macro","{\\left\\langle {#1} \\right\\vert}",1],Ket:["Macro","{\\left\\vert {#1} \\right\\rangle}",1],Braket:["Braket","⟨","⟩",!0,1/0],Set:["Braket","{","}",!0,1],ketbra:["Macro","{\\vert {#1} \\rangle\\langle {#2} \\vert}",2],Ketbra:["Macro","{\\left\\vert {#1} \\right\\rangle\\left\\langle {#2} \\right\\vert}",2],"|":"Bar"},i.default),new r.MacroMap("Braket-characters",{"|":"Bar"},i.default)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(57),i=n(23),o=n(31),a={};a.Macro=r.default.Macro,a.Braket=function(e,t,n,r,i,a){var s=e.GetNext();if(""===s)throw new o.default("MissingArgFor","Missing argument for %1",e.currentCS);var l=!0;"{"===s&&(e.i++,l=!1),e.Push(e.itemFactory.create("braket").setProperties({barmax:a,barcount:0,open:n,close:r,stretchy:i,single:l}))},a.Bar=function(e,t){var n="|"===t?"|":"∥",r=e.stack.Top();if("braket"!==r.kind||r.getProperty("barcount")>=r.getProperty("barmax")){var o=e.create("token","mo",{texClass:i.TEXCLASS.ORD,stretchy:!1},n);e.Push(o)}else{if("|"===n&&"|"===e.GetNext()&&(e.i++,n="∥"),r.getProperty("stretchy")){var a=e.create("node","TeXAtom",[],{texClass:i.TEXCLASS.CLOSE});e.Push(a),r.setProperty("barcount",r.getProperty("barcount")+1),a=e.create("token","mo",{stretchy:!0,braketbar:!0},n),e.Push(a),a=e.create("node","TeXAtom",[],{texClass:i.TEXCLASS.OPEN}),e.Push(a)}else{var s=e.create("token","mo",{stretchy:!1,braketbar:!0},n);e.Push(s)}}},t.default=a},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.BussproofsConfiguration=void 0;var i=n(29),o=n(963),a=n(189);n(964),t.BussproofsConfiguration=i.Configuration.create("bussproofs",{handler:{macro:["Bussproofs-macros"],environment:["Bussproofs-environments"]},items:(r={},r[o.ProofTreeItem.prototype.kind]=o.ProofTreeItem,r),preprocessors:[[a.saveDocument,1]],postprocessors:[[a.clearDocument,3],[a.makeBsprAttributes,2],[a.balanceRules,1]]})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.ProofTreeItem=void 0;var o=n(31),a=n(95),s=n(418),l=n(189),c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.leftLabel=null,t.rigthLabel=null,t.innerStack=new s.default(t.factory,{},!0),t}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"proofTree"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(e){if(e.isKind("end")&&"prooftree"===e.getName()){var t=this.toMml();return l.setProperty(t,"proof",!0),[[this.factory.create("mml",t),e],!0]}if(e.isKind("stop"))throw new o.default("EnvMissingEnd","Missing \\end{%1}",this.getName());return this.innerStack.Push(e),a.BaseItem.fail},t.prototype.toMml=function(){var t=e.prototype.toMml.call(this),n=this.innerStack.Top();if(n.isKind("start")&&!n.Size())return t;this.innerStack.Push(this.factory.create("stop"));var r=this.innerStack.Top().toMml();return this.create("node","mrow",[r,t],{})},t}(a.BaseItem);t.ProofTreeItem=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(965),i=n(73),o=n(28);new o.CommandMap("Bussproofs-macros",{AxiomC:"Axiom",UnaryInfC:["Inference",1],BinaryInfC:["Inference",2],TrinaryInfC:["Inference",3],QuaternaryInfC:["Inference",4],QuinaryInfC:["Inference",5],RightLabel:["Label","right"],LeftLabel:["Label","left"],AXC:"Axiom",UIC:["Inference",1],BIC:["Inference",2],TIC:["Inference",3],RL:["Label","right"],LL:["Label","left"],noLine:["SetLine","none",!1],singleLine:["SetLine","solid",!1],solidLine:["SetLine","solid",!1],dashedLine:["SetLine","dashed",!1],alwaysNoLine:["SetLine","none",!0],alwaysSingleLine:["SetLine","solid",!0],alwaysSolidLine:["SetLine","solid",!0],alwaysDashedLine:["SetLine","dashed",!0],rootAtTop:["RootAtTop",!0],alwaysRootAtTop:["RootAtTop",!0],rootAtBottom:["RootAtTop",!1],alwaysRootAtBottom:["RootAtTop",!1],fCenter:"FCenter",Axiom:"AxiomF",UnaryInf:["InferenceF",1],BinaryInf:["InferenceF",2],TrinaryInf:["InferenceF",3],QuaternaryInf:["InferenceF",4],QuinaryInf:["InferenceF",5]},r.default),new o.EnvironmentMap("Bussproofs-environments",i.default.environment,{prooftree:["Prooftree",null,!1]},r.default)},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a},i=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e};Object.defineProperty(t,"__esModule",{value:!0});var o=n(31),a=n(49),s=n(37),l=n(189),c={Prooftree:function(e,t){return e.Push(t),e.itemFactory.create("proofTree").setProperties({name:t.getName(),line:"solid",currentLine:"solid",rootAtTop:!1})},Axiom:function(e,t){var n=e.stack.Top();if("proofTree"!==n.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");var r=u(e,e.GetArgument(t));l.setProperty(r,"axiom",!0),n.Push(r)}},u=function(e,t){var n=s.default.internalMath(e,s.default.trimSpaces(t),0);if(!n[0].childNodes[0].childNodes.length)return e.create("node","mrow",[]);var o=e.create("node","mspace",[],{width:".5ex"}),a=e.create("node","mspace",[],{width:".5ex"});return e.create("node","mrow",i(i([o],r(n)),[a]))};function d(e,t,n,r,i,o,a){var s,c,u,d,h=e.create("node","mtr",[e.create("node","mtd",[t],{})],{}),p=e.create("node","mtr",[e.create("node","mtd",n,{})],{}),f=e.create("node","mtable",a?[p,h]:[h,p],{align:"top 2",rowlines:o,framespacing:"0 0"});if(l.setProperty(f,"inferenceRule",a?"up":"down"),r&&(s=e.create("node","mpadded",[r],{height:"+.5em",width:"+.5em",voffset:"-.15em"}),l.setProperty(s,"prooflabel","left")),i&&(c=e.create("node","mpadded",[i],{height:"+.5em",width:"+.5em",voffset:"-.15em"}),l.setProperty(c,"prooflabel","right")),r&&i)u=[s,f,c],d="both";else if(r)u=[s,f],d="left";else{if(!i)return f;u=[f,c],d="right"}return f=e.create("node","mrow",u),l.setProperty(f,"labelledRule",d),f}function h(e,t){if("$"!==e.GetNext())throw new o.default("IllegalUseOfCommand","Use of %1 does not match it's definition.",t);e.i++;var n=e.GetUpTo(t,"$");if(-1===n.indexOf("\\fCenter"))throw new o.default("IllegalUseOfCommand","Missing \\fCenter in %1.",t);var i=r(n.split("\\fCenter"),2),s=i[0],c=i[1],u=new a.default(s,e.stack.env,e.configuration).mml(),d=new a.default(c,e.stack.env,e.configuration).mml(),h=new a.default("\\fCenter",e.stack.env,e.configuration).mml(),p=e.create("node","mtd",[u],{}),f=e.create("node","mtd",[h],{}),m=e.create("node","mtd",[d],{}),g=e.create("node","mtr",[p,f,m],{}),v=e.create("node","mtable",[g],{columnspacing:".5ex",columnalign:"center 2"});return l.setProperty(v,"sequent",!0),e.configuration.addNode("sequent",g),v}c.Inference=function(e,t,n){var r=e.stack.Top();if("proofTree"!==r.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");if(r.Size()<n)throw new o.default("BadProofTree","Proof tree badly specified.");var i=r.getProperty("rootAtTop"),a=1!==n||r.Peek()[0].childNodes.length?n:0,s=[];do{s.length&&s.unshift(e.create("node","mtd",[],{})),s.unshift(e.create("node","mtd",[r.Pop()],{rowalign:i?"top":"bottom"})),n--}while(n>0);var c=e.create("node","mtr",s,{}),h=e.create("node","mtable",[c],{framespacing:"0 0"}),p=u(e,e.GetArgument(t)),f=r.getProperty("currentLine");f!==r.getProperty("line")&&r.setProperty("currentLine",r.getProperty("line"));var m=d(e,h,[p],r.getProperty("left"),r.getProperty("right"),f,i);r.setProperty("left",null),r.setProperty("right",null),l.setProperty(m,"inference",a),e.configuration.addNode("inference",m),r.Push(m)},c.Label=function(e,t,n){var r=e.stack.Top();if("proofTree"!==r.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");var i=s.default.internalMath(e,e.GetArgument(t),0),a=i.length>1?e.create("node","mrow",i,{}):i[0];r.setProperty(n,a)},c.SetLine=function(e,t,n,r){var i=e.stack.Top();if("proofTree"!==i.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");i.setProperty("currentLine",n),r&&i.setProperty("line",n)},c.RootAtTop=function(e,t,n){var r=e.stack.Top();if("proofTree"!==r.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");r.setProperty("rootAtTop",n)},c.AxiomF=function(e,t){var n=e.stack.Top();if("proofTree"!==n.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");var r=h(e,t);l.setProperty(r,"axiom",!0),n.Push(r)},c.FCenter=function(e,t){},c.InferenceF=function(e,t,n){var r=e.stack.Top();if("proofTree"!==r.kind)throw new o.default("IllegalProofCommand","Proof commands only allowed in prooftree environment.");if(r.Size()<n)throw new o.default("BadProofTree","Proof tree badly specified.");var i=r.getProperty("rootAtTop"),a=1!==n||r.Peek()[0].childNodes.length?n:0,s=[];do{s.length&&s.unshift(e.create("node","mtd",[],{})),s.unshift(e.create("node","mtd",[r.Pop()],{rowalign:i?"top":"bottom"})),n--}while(n>0);var c=e.create("node","mtr",s,{}),u=e.create("node","mtable",[c],{framespacing:"0 0"}),p=h(e,t),f=r.getProperty("currentLine");f!==r.getProperty("line")&&r.setProperty("currentLine",r.getProperty("line"));var m=d(e,u,[p],r.getProperty("left"),r.getProperty("right"),f,i);r.setProperty("left",null),r.setProperty("right",null),l.setProperty(m,"inference",a),e.configuration.addNode("inference",m),r.Push(m)},t.default=c},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.CancelConfiguration=t.CancelMethods=void 0;var r=n(29),i=n(50),o=n(28),a=n(37),s=n(454);t.CancelMethods={},t.CancelMethods.Cancel=function(e,t,n){var r=e.GetBrackets(t,""),i=e.ParseArg(t),o=a.default.keyvalOptions(r,s.ENCLOSE_OPTIONS);o.notation=n,e.Push(e.create("node","menclose",[i],o))},t.CancelMethods.CancelTo=function(e,t){var n=e.GetBrackets(t,""),r=e.ParseArg(t),o=e.ParseArg(t),l=a.default.keyvalOptions(n,s.ENCLOSE_OPTIONS);l.notation=[i.TexConstant.Notation.UPDIAGONALSTRIKE,i.TexConstant.Notation.UPDIAGONALARROW,i.TexConstant.Notation.NORTHEASTARROW].join(" "),r=e.create("node","mpadded",[r],{depth:"-.1em",height:"+.1em",voffset:".1em"}),e.Push(e.create("node","msup",[e.create("node","menclose",[o],l),r]))},new o.CommandMap("cancel",{cancel:["Cancel",i.TexConstant.Notation.UPDIAGONALSTRIKE],bcancel:["Cancel",i.TexConstant.Notation.DOWNDIAGONALSTRIKE],xcancel:["Cancel",i.TexConstant.Notation.UPDIAGONALSTRIKE+" "+i.TexConstant.Notation.DOWNDIAGONALSTRIKE],cancelto:"CancelTo"},t.CancelMethods),t.CancelConfiguration=r.Configuration.create("cancel",{handler:{macro:["cancel"]}})},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.CasesConfiguration=t.CasesMethods=t.CasesTags=t.CasesBeginItem=void 0;var a=n(29),s=n(28),l=n(37),c=n(57),u=n(31),d=n(68),h=n(452),p=n(455),f=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"cases-begin"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){return t.isKind("end")&&t.getName()===this.getName()&&this.getProperty("end")?(this.setProperty("end",!1),[[],!0]):e.prototype.checkItem.call(this,t)},t}(d.BeginItem);t.CasesBeginItem=f;var m=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.subcounter=0,t}return o(t,e),t.prototype.start=function(t,n,r){this.subcounter=0,e.prototype.start.call(this,t,n,r)},t.prototype.autoTag=function(){null==this.currentTag.tag&&("subnumcases"===this.currentTag.env?(0===this.subcounter&&this.counter++,this.subcounter++,this.tag(this.formatNumber(this.counter,this.subcounter),!1)):(0!==this.subcounter&&"numcases-left"===this.currentTag.env||this.counter++,this.tag(this.formatNumber(this.counter),!1)))},t.prototype.formatNumber=function(e,t){return void 0===t&&(t=null),e.toString()+(null===t?"":String.fromCharCode(96+t))},t}(h.AmsTags);t.CasesTags=m,t.CasesMethods={NumCases:function(e,t){if(e.stack.env.closing===t.getName()){delete e.stack.env.closing,e.Push(e.itemFactory.create("end").setProperty("name",t.getName()));var n=e.stack.Top(),r=n.Last,i=l.default.copyNode(r,e),o=n.getProperty("left");return p.EmpheqUtil.left(r,i,o+"\\empheqlbrace\\,",e,"numcases-left"),e.Push(e.itemFactory.create("end").setProperty("name",t.getName())),null}o=e.GetArgument("\\begin{"+t.getName()+"}");t.setProperty("left",o);var a=c.default.EqnArray(e,t,!0,!0,"ll");return a.arraydef.displaystyle=!1,a.arraydef.rowspacing=".2em",a.setProperty("numCases",!0),e.Push(t),a},Entry:function(e,t){if(!e.stack.Top().getProperty("numCases"))return c.default.Entry(e,t);e.Push(e.itemFactory.create("cell").setProperties({isEntry:!0,name:t}));for(var n=e.string,r=0,i=e.i,o=n.length;i<o;){var a=n.charAt(i);if("{"===a)r++,i++;else if("}"===a){if(0===r)break;r--,i++}else{if("&"===a&&0===r)throw new u.default("ExtraCasesAlignTab","Extra alignment tab in text for numcase environment");if("\\"===a&&0===r){var s=(n.slice(i+1).match(/^[a-z]+|./i)||[])[0];if("\\"===s||"cr"===s||"end"===s||"label"===s)break;i+=s.length}else i++}}var d=n.substr(e.i,i-e.i).replace(/^\s*/,"");e.PushAll(l.default.internalMath(e,d,0)),e.i=i}},new s.EnvironmentMap("cases-env",p.EmpheqUtil.environment,{numcases:["NumCases","cases"],subnumcases:["NumCases","cases"]},t.CasesMethods),new s.MacroMap("cases-macros",{"&":"Entry"},t.CasesMethods),t.CasesConfiguration=a.Configuration.create("cases",{handler:{environment:["cases-env"],character:["cases-macros"]},items:(i={},i[f.prototype.kind]=f,i),tags:{cases:m}})},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.CenternotConfiguration=t.filterCenterOver=void 0;var i=n(29),o=n(49),a=n(39),s=n(28),l=n(57);function c(e){var t,n,i=e.data;try{for(var o=r(i.getList("centerOver")),s=o.next();!s.done;s=o.next()){var l=s.value,c=a.default.getTexClass(l.childNodes[0].childNodes[0]);null!==c&&a.default.setProperties(l.parent.parent.parent.parent.parent.parent,{texClass:c})}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=o.return)&&n.call(o)}finally{if(t)throw t.error}}}new s.CommandMap("centernot",{centerOver:"CenterOver",centernot:["Macro","\\centerOver{#1}{{⧸}}",1]},{CenterOver:function(e,t){var n="{"+e.GetArgument(t)+"}",r=e.ParseArg(t),i=new o.default(n,e.stack.env,e.configuration).mml(),a=e.create("node","TeXAtom",[new o.default(n,e.stack.env,e.configuration).mml(),e.create("node","mpadded",[e.create("node","mpadded",[r],{width:0,lspace:"-.5width"}),e.create("node","mphantom",[i])],{width:0,lspace:"-.5width"})]);e.configuration.addNode("centerOver",i),e.Push(a)},Macro:l.default.Macro}),t.filterCenterOver=c,t.CenternotConfiguration=i.Configuration.create("centernot",{handler:{macro:["centernot"]},postprocessors:[c]})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ColorConfiguration=void 0;var r=n(28),i=n(29),o=n(970),a=n(971);new r.CommandMap("color",{color:"Color",textcolor:"TextColor",definecolor:"DefineColor",colorbox:"ColorBox",fcolorbox:"FColorBox"},o.ColorMethods);t.ColorConfiguration=i.Configuration.create("color",{handler:{macro:["color"]},options:{color:{padding:"5px",borderWidth:"2px"}},config:function(e,t){t.parseOptions.packageData.set("color",{model:new a.ColorModel})}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ColorMethods=void 0;var r=n(39),i=n(37);function o(e){var t="+"+e,n=e.replace(/^.*?([a-z]*)$/,"$1");return{width:"+"+2*parseFloat(t)+n,height:t,depth:t,lspace:e}}t.ColorMethods={},t.ColorMethods.Color=function(e,t){var n=e.GetBrackets(t,""),r=e.GetArgument(t),i=e.configuration.packageData.get("color").model.getColor(n,r),o=e.itemFactory.create("style").setProperties({styles:{mathcolor:i}});e.stack.env.color=i,e.Push(o)},t.ColorMethods.TextColor=function(e,t){var n=e.GetBrackets(t,""),r=e.GetArgument(t),i=e.configuration.packageData.get("color").model.getColor(n,r),o=e.stack.env.color;e.stack.env.color=i;var a=e.ParseArg(t);o?e.stack.env.color=o:delete e.stack.env.color;var s=e.create("node","mstyle",[a],{mathcolor:i});e.Push(s)},t.ColorMethods.DefineColor=function(e,t){var n=e.GetArgument(t),r=e.GetArgument(t),i=e.GetArgument(t);e.configuration.packageData.get("color").model.defineColor(r,n,i)},t.ColorMethods.ColorBox=function(e,t){var n=e.GetArgument(t),a=i.default.internalMath(e,e.GetArgument(t)),s=e.configuration.packageData.get("color").model,l=e.create("node","mpadded",a,{mathbackground:s.getColor("named",n)});r.default.setProperties(l,o(e.options.color.padding)),e.Push(l)},t.ColorMethods.FColorBox=function(e,t){var n=e.GetArgument(t),a=e.GetArgument(t),s=i.default.internalMath(e,e.GetArgument(t)),l=e.options.color,c=e.configuration.packageData.get("color").model,u=e.create("node","mpadded",s,{mathbackground:c.getColor("named",a),style:"border: "+l.borderWidth+" solid "+c.getColor("named",n)});r.default.setProperties(u,o(l.padding)),e.Push(u)}},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.ColorModel=void 0;var i=n(31),o=n(972),a=new Map,s=function(){function e(){this.userColors=new Map}return e.prototype.normalizeColor=function(e,t){if(!e||"named"===e)return t;if(a.has(e))return a.get(e)(t);throw new i.default("UndefinedColorModel","Color model '%1' not defined",e)},e.prototype.getColor=function(e,t){return e&&"named"!==e?this.normalizeColor(e,t):this.getColorByName(t)},e.prototype.getColorByName=function(e){return this.userColors.has(e)?this.userColors.get(e):o.COLORS.has(e)?o.COLORS.get(e):e},e.prototype.defineColor=function(e,t,n){var r=this.normalizeColor(e,n);this.userColors.set(t,r)},e}();t.ColorModel=s,a.set("rgb",(function(e){var t,n,o=e.trim().split(/\s*,\s*/),a="#";if(3!==o.length)throw new i.default("ModelArg1","Color values for the %1 model require 3 numbers","rgb");try{for(var s=r(o),l=s.next();!l.done;l=s.next()){var c=l.value;if(!c.match(/^(\d+(\.\d*)?|\.\d+)$/))throw new i.default("InvalidDecimalNumber","Invalid decimal number");var u=parseFloat(c);if(u<0||u>1)throw new i.default("ModelArg2","Color values for the %1 model must be between %2 and %3","rgb","0","1");var d=Math.floor(255*u).toString(16);d.length<2&&(d="0"+d),a+=d}}catch(e){t={error:e}}finally{try{l&&!l.done&&(n=s.return)&&n.call(s)}finally{if(t)throw t.error}}return a})),a.set("RGB",(function(e){var t,n,o=e.trim().split(/\s*,\s*/),a="#";if(3!==o.length)throw new i.default("ModelArg1","Color values for the %1 model require 3 numbers","RGB");try{for(var s=r(o),l=s.next();!l.done;l=s.next()){var c=l.value;if(!c.match(/^\d+$/))throw new i.default("InvalidNumber","Invalid number");var u=parseInt(c);if(u>255)throw new i.default("ModelArg2","Color values for the %1 model must be between %2 and %3","RGB","0","255");var d=u.toString(16);d.length<2&&(d="0"+d),a+=d}}catch(e){t={error:e}}finally{try{l&&!l.done&&(n=s.return)&&n.call(s)}finally{if(t)throw t.error}}return a})),a.set("gray",(function(e){if(!e.match(/^\s*(\d+(\.\d*)?|\.\d+)\s*$/))throw new i.default("InvalidDecimalNumber","Invalid decimal number");var t=parseFloat(e);if(t<0||t>1)throw new i.default("ModelArg2","Color values for the %1 model must be between %2 and %3","gray","0","1");var n=Math.floor(255*t).toString(16);return n.length<2&&(n="0"+n),"#"+n+n+n}))},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.COLORS=void 0,t.COLORS=new Map([["Apricot","#FBB982"],["Aquamarine","#00B5BE"],["Bittersweet","#C04F17"],["Black","#221E1F"],["Blue","#2D2F92"],["BlueGreen","#00B3B8"],["BlueViolet","#473992"],["BrickRed","#B6321C"],["Brown","#792500"],["BurntOrange","#F7921D"],["CadetBlue","#74729A"],["CarnationPink","#F282B4"],["Cerulean","#00A2E3"],["CornflowerBlue","#41B0E4"],["Cyan","#00AEEF"],["Dandelion","#FDBC42"],["DarkOrchid","#A4538A"],["Emerald","#00A99D"],["ForestGreen","#009B55"],["Fuchsia","#8C368C"],["Goldenrod","#FFDF42"],["Gray","#949698"],["Green","#00A64F"],["GreenYellow","#DFE674"],["JungleGreen","#00A99A"],["Lavender","#F49EC4"],["LimeGreen","#8DC73E"],["Magenta","#EC008C"],["Mahogany","#A9341F"],["Maroon","#AF3235"],["Melon","#F89E7B"],["MidnightBlue","#006795"],["Mulberry","#A93C93"],["NavyBlue","#006EB8"],["OliveGreen","#3C8031"],["Orange","#F58137"],["OrangeRed","#ED135A"],["Orchid","#AF72B0"],["Peach","#F7965A"],["Periwinkle","#7977B8"],["PineGreen","#008B72"],["Plum","#92268F"],["ProcessBlue","#00B0F0"],["Purple","#99479B"],["RawSienna","#974006"],["Red","#ED1B23"],["RedOrange","#F26035"],["RedViolet","#A1246B"],["Rhodamine","#EF559F"],["RoyalBlue","#0071BC"],["RoyalPurple","#613F99"],["RubineRed","#ED017D"],["Salmon","#F69289"],["SeaGreen","#3FBC9D"],["Sepia","#671800"],["SkyBlue","#46C5DD"],["SpringGreen","#C6DC67"],["Tan","#DA9D76"],["TealBlue","#00AEB3"],["Thistle","#D883B7"],["Turquoise","#00B4CE"],["Violet","#58429B"],["VioletRed","#EF58A0"],["White","#FFFFFF"],["WildStrawberry","#EE2967"],["Yellow","#FFF200"],["YellowGreen","#98CC70"],["YellowOrange","#FAA21A"]])},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ColorConfiguration=t.ColorV2Methods=void 0;var r=n(28),i=n(29);t.ColorV2Methods={Color:function(e,t){var n=e.GetArgument(t),r=e.stack.env.color;e.stack.env.color=n;var i=e.ParseArg(t);r?e.stack.env.color=r:delete e.stack.env.color;var o=e.create("node","mstyle",[i],{mathcolor:n});e.Push(o)}},new r.CommandMap("colorv2",{color:"Color"},t.ColorV2Methods),t.ColorConfiguration=i.Configuration.create("colorv2",{handler:{macro:["colorv2"]}})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.ColortblConfiguration=t.ColorArrayItem=void 0;var o=n(68),a=n(29),s=n(28),l=n(31),c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.color={cell:"",row:"",col:[]},t.hasColor=!1,t}return i(t,e),t.prototype.EndEntry=function(){e.prototype.EndEntry.call(this);var t=this.row[this.row.length-1],n=this.color.cell||this.color.row||this.color.col[this.row.length-1];n&&(t.attributes.set("mathbackground",n),this.color.cell="",this.hasColor=!0)},t.prototype.EndRow=function(){e.prototype.EndRow.call(this),this.color.row=""},t.prototype.createMml=function(){var t=e.prototype.createMml.call(this),n=t.isKind("mrow")?t.childNodes[1]:t;return n.isKind("menclose")&&(n=n.childNodes[0].childNodes[0]),this.hasColor&&"none"===n.attributes.get("frame")&&n.attributes.set("frame",""),t},t}(o.ArrayItem);t.ColorArrayItem=c,new s.CommandMap("colortbl",{cellcolor:["TableColor","cell"],rowcolor:["TableColor","row"],columncolor:["TableColor","col"]},{TableColor:function(e,t,n){var r=e.configuration.packageData.get("color").model,i=e.GetBrackets(t,""),o=r.getColor(i,e.GetArgument(t)),a=e.stack.Top();if(!(a instanceof c))throw new l.default("UnsupportedTableColor","Unsupported use of %1",e.currentCS);if("col"===n){if(a.table.length)throw new l.default("ColumnColorNotTop","%1 must be in the top row",t);a.color.col[a.row.length]=o,e.GetBrackets(t,"")&&e.GetBrackets(t,"")}else if(a.color[n]=o,"row"===n&&(a.Size()||a.row.length))throw new l.default("RowColorNotFirst","%1 must be at the beginning of a row",t)}});t.ColortblConfiguration=a.Configuration.create("colortbl",{handler:{macro:["colortbl"]},items:{array:c},priority:10,config:[function(e,t){t.parseOptions.packageData.has("color")||a.ConfigurationHandler.get("color").config(e,t)},10]})},function(e,t,n){"use strict";var r,i=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.ConfigMacrosConfiguration=void 0;var o=n(29),a=n(47),s=n(28),l=n(73),c=n(96),u=n(190),d=n(456);t.ConfigMacrosConfiguration=o.Configuration.create("configmacros",{init:function(e){new s.CommandMap("configmacros-map",{},{}),new s.EnvironmentMap("configmacros-env-map",l.default.environment,{},{}),e.append(o.Configuration.local({handler:{macro:["configmacros-map"],environment:["configmacros-env-map"]},priority:3}))},config:function(e,t){!function(e){var t,n,r=e.parseOptions.handlers.retrieve("configmacros-map"),o=e.parseOptions.options.macros;try{for(var a=i(Object.keys(o)),s=a.next();!s.done;s=a.next()){var l=s.value,d="string"==typeof o[l]?[o[l]]:o[l],h=Array.isArray(d[2])?new c.Macro(l,u.default.MacroWithTemplate,d.slice(0,2).concat(d[2])):new c.Macro(l,u.default.Macro,d);r.add(l,h)}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}}(t),function(e){var t,n,r=e.parseOptions.handlers.retrieve("configmacros-env-map"),o=e.parseOptions.options.environments;try{for(var a=i(Object.keys(o)),s=a.next();!s.done;s=a.next()){var l=s.value;r.add(l,new c.Macro(l,u.default.BeginEnv,[!0].concat(o[l])))}}catch(e){t={error:e}}finally{try{s&&!s.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}}(t)},items:(r={},r[d.BeginEnvItem.prototype.kind]=d.BeginEnvItem,r),options:{macros:a.expandable({}),environments:a.expandable({})}})},function(e,t,n){"use strict";var r,i,o=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.EmpheqConfiguration=t.EmpheqMethods=t.EmpheqBeginItem=void 0;var s=n(29),l=n(28),c=n(37),u=n(31),d=n(68),h=n(455),p=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"empheq-begin"},enumerable:!1,configurable:!0}),t.prototype.checkItem=function(t){return t.isKind("end")&&t.getName()===this.getName()&&this.setProperty("end",!1),e.prototype.checkItem.call(this,t)},t}(d.BeginItem);t.EmpheqBeginItem=p,t.EmpheqMethods={Empheq:function(e,t){if(e.stack.env.closing===t.getName()){delete e.stack.env.closing,e.Push(e.itemFactory.create("end").setProperty("name",e.stack.global.empheq)),e.stack.global.empheq="";var n=e.stack.Top();h.EmpheqUtil.adjustTable(n,e),e.Push(e.itemFactory.create("end").setProperty("name","empheq"))}else{c.default.checkEqnEnv(e),delete e.stack.global.eqnenv;var r=e.GetBrackets("\\begin{"+t.getName()+"}")||"",i=a((e.GetArgument("\\begin{"+t.getName()+"}")||"").split(/=/),2),o=i[0],s=i[1];if(!h.EmpheqUtil.checkEnv(o))throw new u.default("UnknownEnv",'Unknown environment "%1"',o);r&&t.setProperties(h.EmpheqUtil.splitOptions(r,{left:1,right:1})),e.stack.global.empheq=o,e.string="\\begin{"+o+"}"+(s?"{"+s+"}":"")+e.string.slice(e.i),e.i=0,e.Push(t)}},EmpheqMO:function(e,t,n){e.Push(e.create("token","mo",{},n))},EmpheqDelim:function(e,t){var n=e.GetDelimiter(t);e.Push(e.create("token","mo",{stretchy:!0,symmetric:!0},n))}},new l.EnvironmentMap("empheq-env",h.EmpheqUtil.environment,{empheq:["Empheq","empheq"]},t.EmpheqMethods),new l.CommandMap("empheq-macros",{empheqlbrace:["EmpheqMO","{"],empheqrbrace:["EmpheqMO","}"],empheqlbrack:["EmpheqMO","["],empheqrbrack:["EmpheqMO","]"],empheqlangle:["EmpheqMO","⟨"],empheqrangle:["EmpheqMO","⟩"],empheqlparen:["EmpheqMO","("],empheqrparen:["EmpheqMO",")"],empheqlvert:["EmpheqMO","|"],empheqrvert:["EmpheqMO","|"],empheqlVert:["EmpheqMO","‖"],empheqrVert:["EmpheqMO","‖"],empheqlfloor:["EmpheqMO","⌊"],empheqrfloor:["EmpheqMO","⌋"],empheqlceil:["EmpheqMO","⌈"],empheqrceil:["EmpheqMO","⌉"],empheqbiglbrace:["EmpheqMO","{"],empheqbigrbrace:["EmpheqMO","}"],empheqbiglbrack:["EmpheqMO","["],empheqbigrbrack:["EmpheqMO","]"],empheqbiglangle:["EmpheqMO","⟨"],empheqbigrangle:["EmpheqMO","⟩"],empheqbiglparen:["EmpheqMO","("],empheqbigrparen:["EmpheqMO",")"],empheqbiglvert:["EmpheqMO","|"],empheqbigrvert:["EmpheqMO","|"],empheqbiglVert:["EmpheqMO","‖"],empheqbigrVert:["EmpheqMO","‖"],empheqbiglfloor:["EmpheqMO","⌊"],empheqbigrfloor:["EmpheqMO","⌋"],empheqbiglceil:["EmpheqMO","⌈"],empheqbigrceil:["EmpheqMO","⌉"],empheql:"EmpheqDelim",empheqr:"EmpheqDelim",empheqbigl:"EmpheqDelim",empheqbigr:"EmpheqDelim"},t.EmpheqMethods),t.EmpheqConfiguration=s.Configuration.create("empheq",{handler:{macro:["empheq-macros"],environment:["empheq-env"]},items:(i={},i[p.prototype.kind]=p,i)})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.ExtpfeilConfiguration=t.ExtpfeilMethods=void 0;var r=n(29),i=n(28),o=n(112),a=n(137),s=n(457),l=n(31);t.ExtpfeilMethods={},t.ExtpfeilMethods.xArrow=o.AmsMethods.xArrow,t.ExtpfeilMethods.NewExtArrow=function(e,n){var r=e.GetArgument(n),i=e.GetArgument(n),o=e.GetArgument(n);if(!r.match(/^\\([a-z]+|.)$/i))throw new l.default("NewextarrowArg1","First argument to %1 must be a control sequence name",n);if(!i.match(/^(\d+),(\d+)$/))throw new l.default("NewextarrowArg2","Second argument to %1 must be two integers separated by a comma",n);if(!o.match(/^(\d+|0x[0-9A-F]+)$/i))throw new l.default("NewextarrowArg3","Third argument to %1 must be a unicode character number",n);r=r.substr(1);var s=i.split(",");a.default.addMacro(e,r,t.ExtpfeilMethods.xArrow,[parseInt(o),parseInt(s[0]),parseInt(s[1])])},new i.CommandMap("extpfeil",{xtwoheadrightarrow:["xArrow",8608,12,16],xtwoheadleftarrow:["xArrow",8606,17,13],xmapsto:["xArrow",8614,6,7],xlongequal:["xArrow",61,7,7],xtofrom:["xArrow",8644,12,12],Newextarrow:"NewExtArrow"},t.ExtpfeilMethods);t.ExtpfeilConfiguration=r.Configuration.create("extpfeil",{handler:{macro:["extpfeil"]},init:function(e){s.NewcommandConfiguration.init(e)}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(190);new(n(28).CommandMap)("Newcommand-macros",{newcommand:"NewCommand",renewcommand:"NewCommand",newenvironment:"NewEnvironment",renewenvironment:"NewEnvironment",def:"MacroDef",let:"Let"},r.default)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.GensymbConfiguration=void 0;var r=n(29),i=n(50);new(n(28).CharacterMap)("gensymb-symbols",(function(e,t){var n=t.attributes||{};n.mathvariant=i.TexConstant.Variant.NORMAL,n.class="MathML-Unit";var r=e.create("token","mi",n,t.char);e.Push(r)}),{ohm:"Ω",degree:"°",celsius:"℃",perthousand:"‰",micro:"µ"}),t.GensymbConfiguration=r.Configuration.create("gensymb",{handler:{macro:["gensymb-symbols"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.HtmlConfiguration=void 0;var r=n(29),i=n(28),o=n(981);new i.CommandMap("html_macros",{href:"Href",class:"Class",style:"Style",cssId:"Id"},o.default),t.HtmlConfiguration=r.Configuration.create("html",{handler:{macro:["html_macros"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(39),i={Href:function(e,t){var n=e.GetArgument(t),i=o(e,t);r.default.setAttribute(i,"href",n),e.Push(i)},Class:function(e,t){var n=e.GetArgument(t),i=o(e,t),a=r.default.getAttribute(i,"class");a&&(n=a+" "+n),r.default.setAttribute(i,"class",n),e.Push(i)},Style:function(e,t){var n=e.GetArgument(t),i=o(e,t),a=r.default.getAttribute(i,"style");a&&(";"!==n.charAt(n.length-1)&&(n+=";"),n=a+" "+n),r.default.setAttribute(i,"style",n),e.Push(i)},Id:function(e,t){var n=e.GetArgument(t),i=o(e,t);r.default.setAttribute(i,"id",n),e.Push(i)}},o=function(e,t){var n=e.ParseArg(t);if(!r.default.isInferred(n))return n;var i=r.default.getChildren(n);if(1===i.length)return i[0];var o=e.create("node","mrow");return r.default.copyChildren(n,o),r.default.copyAttributes(n,o),o};t.default=i},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(73),i=n(28),o=n(50),a=n(459);new i.CommandMap("mathtools-macros",{shoveleft:["HandleShove",o.TexConstant.Align.LEFT],shoveright:["HandleShove",o.TexConstant.Align.RIGHT],xleftrightarrow:["xArrow",8596,10,10],xLeftarrow:["xArrow",8656,12,7],xRightarrow:["xArrow",8658,7,12],xLeftrightarrow:["xArrow",8660,12,12],xhookleftarrow:["xArrow",8617,10,5],xhookrightarrow:["xArrow",8618,5,10],xmapsto:["xArrow",8614,10,10],xrightharpoondown:["xArrow",8641,5,10],xleftharpoondown:["xArrow",8637,10,5],xrightleftharpoons:["xArrow",8652,10,10],xrightharpoonup:["xArrow",8640,5,10],xleftharpoonup:["xArrow",8636,10,5],xleftrightharpoons:["xArrow",8651,10,10],mathllap:["MathLap","l",!1],mathrlap:["MathLap","r",!1],mathclap:["MathLap","c",!1],clap:["MtLap","c"],textllap:["MtLap","l"],textrlap:["MtLap","r"],textclap:["MtLap","c"],cramped:"Cramped",crampedllap:["MathLap","l",!0],crampedrlap:["MathLap","r",!0],crampedclap:["MathLap","c",!0],crampedsubstack:["Macro","\\begin{crampedsubarray}{c}#1\\end{crampedsubarray}",1],mathmbox:"MathMBox",mathmakebox:"MathMakeBox",overbracket:"UnderOverBracket",underbracket:"UnderOverBracket",refeq:"HandleRef",MoveEqLeft:["Macro","\\hspace{#1em}&\\hspace{-#1em}",1,"2"],Aboxed:"Aboxed",ArrowBetweenLines:"ArrowBetweenLines",vdotswithin:"VDotsWithin",shortvdotswithin:"ShortVDotsWithin",MTFlushSpaceAbove:"FlushSpaceAbove",MTFlushSpaceBelow:"FlushSpaceBelow",DeclarePairedDelimiters:"DeclarePairedDelimiters",DeclarePairedDelimitersX:"DeclarePairedDelimitersX",DeclarePairedDelimitersXPP:"DeclarePairedDelimitersXPP",centercolon:["CenterColon",!0,!0],ordinarycolon:["CenterColon",!1],MTThinColon:["CenterColon",!0,!0,!0],coloneqq:["Relation",":=","≔"],Coloneqq:["Relation","::=","⩴"],coloneq:["Relation",":-"],Coloneq:["Relation","::-"],eqqcolon:["Relation","=:","≕"],Eqqcolon:["Relation","=::"],eqcolon:["Relation","-:","∹"],Eqcolon:["Relation","-::"],colonapprox:["Relation",":\\approx"],Colonapprox:["Relation","::\\approx"],colonsim:["Relation",":\\sim"],Colonsim:["Relation","::\\sim"],dblcolon:["Relation","::","∷"],nuparrow:["NArrow","↑",".06em"],ndownarrow:["NArrow","↓",".25em"],bigtimes:["Macro","\\mathop{\\Large\\kern-.1em\\boldsymbol{\\times}\\kern-.1em}"],splitfrac:["SplitFrac",!1],splitdfrac:["SplitFrac",!0],xmathstrut:"XMathStrut",prescript:"Prescript",newtagform:["NewTagForm",!1],renewtagform:["NewTagForm",!0],usetagform:"UseTagForm",adjustlimits:["MacroWithTemplate","\\mathop{{#1}\\vphantom{{#3}}}_{{#2}\\vphantom{{#4}}}\\mathop{{#3}\\vphantom{{#1}}}_{{#4}\\vphantom{{#2}}}",4,,"_",,"_"],mathtoolsset:"SetOptions"},a.MathtoolsMethods),new i.EnvironmentMap("mathtools-environments",r.default.environment,{dcases:["Array",null,"\\{","","ll",null,".2em","D"],rcases:["Array",null,"","\\}","ll",null,".2em"],drcases:["Array",null,"","\\}","ll",null,".2em","D"],"dcases*":["Cases",null,"{","","D"],"rcases*":["Cases",null,"","}"],"drcases*":["Cases",null,"","}","D"],"cases*":["Cases",null,"{",""],"matrix*":["MtMatrix",null,null,null],"pmatrix*":["MtMatrix",null,"(",")"],"bmatrix*":["MtMatrix",null,"[","]"],"Bmatrix*":["MtMatrix",null,"\\{","\\}"],"vmatrix*":["MtMatrix",null,"\\vert","\\vert"],"Vmatrix*":["MtMatrix",null,"\\Vert","\\Vert"],"smallmatrix*":["MtSmallMatrix",null,null,null],psmallmatrix:["MtSmallMatrix",null,"(",")","c"],"psmallmatrix*":["MtSmallMatrix",null,"(",")"],bsmallmatrix:["MtSmallMatrix",null,"[","]","c"],"bsmallmatrix*":["MtSmallMatrix",null,"[","]"],Bsmallmatrix:["MtSmallMatrix",null,"\\{","\\}","c"],"Bsmallmatrix*":["MtSmallMatrix",null,"\\{","\\}"],vsmallmatrix:["MtSmallMatrix",null,"\\vert","\\vert","c"],"vsmallmatrix*":["MtSmallMatrix",null,"\\vert","\\vert"],Vsmallmatrix:["MtSmallMatrix",null,"\\Vert","\\Vert","c"],"Vsmallmatrix*":["MtSmallMatrix",null,"\\Vert","\\Vert"],crampedsubarray:["Array",null,null,null,null,"0em","0.1em","S'",1],multlined:"MtMultlined",spreadlines:["SpreadLines",!0],lgathered:["AmsEqnArray",null,null,null,"l",null,".5em","D"],rgathered:["AmsEqnArray",null,null,null,"r",null,".5em","D"]},a.MathtoolsMethods),new i.DelimiterMap("mathtools-delimiters",r.default.delimiter,{"\\lparen":"(","\\rparen":")"}),new i.CommandMap("mathtools-characters",{":":["CenterColon",!0]},a.MathtoolsMethods)},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")},a=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0}),t.MathtoolsTagFormat=void 0;var s=n(31),l=n(72),c=0;t.MathtoolsTagFormat=function(e,t){var n=t.parseOptions.options.tags;"base"!==n&&e.tags.hasOwnProperty(n)&&l.TagsFactory.add(n,e.tags[n]);var r=function(e){function n(){var n,r,i=e.call(this)||this;i.mtFormats=new Map,i.mtCurrent=null;var a=t.parseOptions.options.mathtools.tagforms;try{for(var l=o(Object.keys(a)),c=l.next();!c.done;c=l.next()){var u=c.value;if(!Array.isArray(a[u])||3!==a[u].length)throw new s.default("InvalidTagFormDef",'The tag form definition for "%1" should be an array fo three strings',u);i.mtFormats.set(u,a[u])}}catch(e){n={error:e}}finally{try{c&&!c.done&&(r=l.return)&&r.call(l)}finally{if(n)throw n.error}}return i}return i(n,e),n.prototype.formatTag=function(t){if(this.mtCurrent){var n=a(this.mtCurrent,3),r=n[0],i=n[1],o=n[2];return o?""+r+o+"{"+t+"}"+i:""+r+t+i}return e.prototype.formatTag.call(this,t)},n}(l.TagsFactory.create(t.parseOptions.options.tags).constructor),u="MathtoolsTags-"+ ++c;l.TagsFactory.add(u,r),t.parseOptions.options.tags=u}},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.MultlinedItem=void 0;var o=n(453),a=n(39),s=n(50),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"multlined"},enumerable:!1,configurable:!0}),t.prototype.EndTable=function(){if((this.Size()||this.row.length)&&(this.EndEntry(),this.EndRow()),this.table.length>1){var t=this.factory.configuration.options.mathtools,n=t.multlinegap,r=t["firstline-afterskip"]||n,i=t["lastline-preskip"]||n,o=a.default.getChildren(this.table[0])[0];a.default.getAttribute(o,"columnalign")!==s.TexConstant.Align.RIGHT&&o.appendChild(this.create("node","mspace",[],{width:r}));var l=a.default.getChildren(this.table[this.table.length-1])[0];if(a.default.getAttribute(l,"columnalign")!==s.TexConstant.Align.LEFT){var c=a.default.getChildren(l)[0];c.childNodes.unshift(null);var u=this.create("node","mspace",[],{width:i});a.default.setChild(c,0,u)}}e.prototype.EndTable.call(this)},t}(o.MultlineItem);t.MultlinedItem=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.MhchemConfiguration=void 0;var r=n(29),i=n(28),o=n(31),a=n(57),s=n(112),l=n(986),c={};c.Macro=a.default.Macro,c.xArrow=s.AmsMethods.xArrow,c.Machine=function(e,t,n){try{var r=e.GetArgument(t),i=l.mhchemParser.toTex(r,n);e.string=i+e.string.substr(e.i),e.i=0}catch(e){throw new o.default(e[0],e[1],e.slice(2))}},new i.CommandMap("mhchem",{ce:["Machine","ce"],pu:["Machine","pu"],longrightleftharpoons:["Macro","\\stackrel{\\textstyle{-}\\!\\!{\\rightharpoonup}}{\\smash{{\\leftharpoondown}\\!\\!{-}}}"],longRightleftharpoons:["Macro","\\stackrel{\\textstyle{-}\\!\\!{\\rightharpoonup}}{\\smash{\\leftharpoondown}}"],longLeftrightharpoons:["Macro","\\stackrel{\\textstyle\\vphantom{{-}}{\\rightharpoonup}}{\\smash{{\\leftharpoondown}\\!\\!{-}}}"],longleftrightarrows:["Macro","\\stackrel{\\longrightarrow}{\\smash{\\longleftarrow}\\Rule{0px}{.25em}{0px}}"],tripledash:["Macro","\\vphantom{-}\\raise2mu{\\kern2mu\\tiny\\text{-}\\kern1mu\\text{-}\\kern1mu\\text{-}\\kern2mu}"],xleftrightarrow:["xArrow",8596,6,6],xrightleftharpoons:["xArrow",8652,5,7],xRightleftharpoons:["xArrow",8652,5,7],xLeftrightharpoons:["xArrow",8652,5,7]},c),t.MhchemConfiguration=r.Configuration.create("mhchem",{handler:{macro:["mhchem"]}})},function(e,t,n){"use strict";
/*!
 *************************************************************************
 *
 *  mhchemParser.ts
 *  4.1.1
 *
 *  Parser for the \ce command and \pu command for MathJax and Co.
 *
 *  mhchem's \ce is a tool for writing beautiful chemical equations easily.
 *  mhchem's \pu is a tool for writing physical units easily.
 *
 *  ----------------------------------------------------------------------
 *
 *  Copyright (c) 2015-2021 Martin Hensel
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  ----------------------------------------------------------------------
 *
 *  https://github.com/mhchem/mhchemParser
 *
 */Object.defineProperty(t,"__esModule",{value:!0}),t.mhchemParser=void 0;var r=function(){function e(){}return e.toTex=function(e,t){return a.go(o.go(e,t),"tex"!==t)},e}();function i(e){var t,n,r={};for(t in e)for(n in e[t]){var i=n.split("|");e[t][n].stateArray=i;for(var o=0;o<i.length;o++)r[i[o]]=[]}for(t in e)for(n in e[t])for(i=e[t][n].stateArray||[],o=0;o<i.length;o++){var a=e[t][n];a.action_=[].concat(a.action_);for(var s=0;s<a.action_.length;s++)"string"==typeof a.action_[s]&&(a.action_[s]={type_:a.action_[s]});for(var l=t.split("|"),c=0;c<l.length;c++)if("*"===i[o]){var u=void 0;for(u in r)r[u].push({pattern:l[c],task:a})}else r[i[o]].push({pattern:l[c],task:a})}return r}t.mhchemParser=r;var o={go:function(e,t){if(!e)return[];void 0===t&&(t="ce");var n,r="0",i={};i.parenthesisLevel=0,e=(e=(e=e.replace(/\n/g," ")).replace(/[\u2212\u2013\u2014\u2010]/g,"-")).replace(/[\u2026]/g,"...");for(var a=10,s=[];;){n!==e?(a=10,n=e):a--;var l=o.stateMachines[t],c=l.transitions[r]||l.transitions["*"];e:for(var u=0;u<c.length;u++){var d=o.patterns.match_(c[u].pattern,e);if(d){for(var h=c[u].task,p=0;p<h.action_.length;p++){var f=void 0;if(l.actions[h.action_[p].type_])f=l.actions[h.action_[p].type_](i,d.match_,h.action_[p].option);else{if(!o.actions[h.action_[p].type_])throw["MhchemBugA","mhchem bug A. Please report. ("+h.action_[p].type_+")"];f=o.actions[h.action_[p].type_](i,d.match_,h.action_[p].option)}o.concatArray(s,f)}if(r=h.nextState||r,!(e.length>0))return s;if(h.revisit||(e=d.remainder),!h.toContinue)break e}}if(a<=0)throw["MhchemBugU","mhchem bug U. Please report."]}},concatArray:function(e,t){if(t)if(Array.isArray(t))for(var n=0;n<t.length;n++)e.push(t[n]);else e.push(t)},patterns:{patterns:{empty:/^$/,else:/^./,else2:/^./,space:/^\s/,"space A":/^\s(?=[A-Z\\$])/,space$:/^\s$/,"a-z":/^[a-z]/,x:/^x/,x$:/^x$/,i$:/^i$/,letters:/^(?:[a-zA-Z\u03B1-\u03C9\u0391-\u03A9?@]|(?:\\(?:alpha|beta|gamma|delta|epsilon|zeta|eta|theta|iota|kappa|lambda|mu|nu|xi|omicron|pi|rho|sigma|tau|upsilon|phi|chi|psi|omega|Gamma|Delta|Theta|Lambda|Xi|Pi|Sigma|Upsilon|Phi|Psi|Omega)(?:\s+|\{\}|(?![a-zA-Z]))))+/,"\\greek":/^\\(?:alpha|beta|gamma|delta|epsilon|zeta|eta|theta|iota|kappa|lambda|mu|nu|xi|omicron|pi|rho|sigma|tau|upsilon|phi|chi|psi|omega|Gamma|Delta|Theta|Lambda|Xi|Pi|Sigma|Upsilon|Phi|Psi|Omega)(?:\s+|\{\}|(?![a-zA-Z]))/,"one lowercase latin letter $":/^(?:([a-z])(?:$|[^a-zA-Z]))$/,"$one lowercase latin letter$ $":/^\$(?:([a-z])(?:$|[^a-zA-Z]))\$$/,"one lowercase greek letter $":/^(?:\$?[\u03B1-\u03C9]\$?|\$?\\(?:alpha|beta|gamma|delta|epsilon|zeta|eta|theta|iota|kappa|lambda|mu|nu|xi|omicron|pi|rho|sigma|tau|upsilon|phi|chi|psi|omega)\s*\$?)(?:\s+|\{\}|(?![a-zA-Z]))$/,digits:/^[0-9]+/,"-9.,9":/^[+\-]?(?:[0-9]+(?:[,.][0-9]+)?|[0-9]*(?:\.[0-9]+))/,"-9.,9 no missing 0":/^[+\-]?[0-9]+(?:[.,][0-9]+)?/,"(-)(9.,9)(e)(99)":function(e){var t=e.match(/^(\+\-|\+\/\-|\+|\-|\\pm\s?)?([0-9]+(?:[,.][0-9]+)?|[0-9]*(?:\.[0-9]+))?(\((?:[0-9]+(?:[,.][0-9]+)?|[0-9]*(?:\.[0-9]+))\))?(?:(?:([eE])|\s*(\*|x|\\times|\u00D7)\s*10\^)([+\-]?[0-9]+|\{[+\-]?[0-9]+\}))?/);return t&&t[0]?{match_:t.slice(1),remainder:e.substr(t[0].length)}:null},"(-)(9)^(-9)":/^(\+\-|\+\/\-|\+|\-|\\pm\s?)?([0-9]+(?:[,.][0-9]+)?|[0-9]*(?:\.[0-9]+)?)\^([+\-]?[0-9]+|\{[+\-]?[0-9]+\})/,"state of aggregation $":function(e){var t=o.patterns.findObserveGroups(e,"",/^\([a-z]{1,3}(?=[\),])/,")","");if(t&&t.remainder.match(/^($|[\s,;\)\]\}])/))return t;var n=e.match(/^(?:\((?:\\ca\s?)?\$[amothc]\$\))/);return n?{match_:n[0],remainder:e.substr(n[0].length)}:null},"_{(state of aggregation)}$":/^_\{(\([a-z]{1,3}\))\}/,"{[(":/^(?:\\\{|\[|\()/,")]}":/^(?:\)|\]|\\\})/,", ":/^[,;]\s*/,",":/^[,;]/,".":/^[.]/,". __* ":/^([.\u22C5\u00B7\u2022]|[*])\s*/,"...":/^\.\.\.(?=$|[^.])/,"^{(...)}":function(e){return o.patterns.findObserveGroups(e,"^{","","","}")},"^($...$)":function(e){return o.patterns.findObserveGroups(e,"^","$","$","")},"^a":/^\^([0-9]+|[^\\_])/,"^\\x{}{}":function(e){return o.patterns.findObserveGroups(e,"^",/^\\[a-zA-Z]+\{/,"}","","","{","}","",!0)},"^\\x{}":function(e){return o.patterns.findObserveGroups(e,"^",/^\\[a-zA-Z]+\{/,"}","")},"^\\x":/^\^(\\[a-zA-Z]+)\s*/,"^(-1)":/^\^(-?\d+)/,"'":/^'/,"_{(...)}":function(e){return o.patterns.findObserveGroups(e,"_{","","","}")},"_($...$)":function(e){return o.patterns.findObserveGroups(e,"_","$","$","")},_9:/^_([+\-]?[0-9]+|[^\\])/,"_\\x{}{}":function(e){return o.patterns.findObserveGroups(e,"_",/^\\[a-zA-Z]+\{/,"}","","","{","}","",!0)},"_\\x{}":function(e){return o.patterns.findObserveGroups(e,"_",/^\\[a-zA-Z]+\{/,"}","")},"_\\x":/^_(\\[a-zA-Z]+)\s*/,"^_":/^(?:\^(?=_)|\_(?=\^)|[\^_]$)/,"{}^":/^\{\}(?=\^)/,"{}":/^\{\}/,"{...}":function(e){return o.patterns.findObserveGroups(e,"","{","}","")},"{(...)}":function(e){return o.patterns.findObserveGroups(e,"{","","","}")},"$...$":function(e){return o.patterns.findObserveGroups(e,"","$","$","")},"${(...)}$__$(...)$":function(e){return o.patterns.findObserveGroups(e,"${","","","}$")||o.patterns.findObserveGroups(e,"$","","","$")},"=<>":/^[=<>]/,"#":/^[#\u2261]/,"+":/^\+/,"-$":/^-(?=[\s_},;\]/]|$|\([a-z]+\))/,"-9":/^-(?=[0-9])/,"- orbital overlap":/^-(?=(?:[spd]|sp)(?:$|[\s,;\)\]\}]))/,"-":/^-/,"pm-operator":/^(?:\\pm|\$\\pm\$|\+-|\+\/-)/,operator:/^(?:\+|(?:[\-=<>]|<<|>>|\\approx|\$\\approx\$)(?=\s|$|-?[0-9]))/,arrowUpDown:/^(?:v|\(v\)|\^|\(\^\))(?=$|[\s,;\)\]\}])/,"\\bond{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\bond{","","","}")},"->":/^(?:<->|<-->|->|<-|<=>>|<<=>|<=>|[\u2192\u27F6\u21CC])/,CMT:/^[CMT](?=\[)/,"[(...)]":function(e){return o.patterns.findObserveGroups(e,"[","","","]")},"1st-level escape":/^(&|\\\\|\\hline)\s*/,"\\,":/^(?:\\[,\ ;:])/,"\\x{}{}":function(e){return o.patterns.findObserveGroups(e,"",/^\\[a-zA-Z]+\{/,"}","","","{","}","",!0)},"\\x{}":function(e){return o.patterns.findObserveGroups(e,"",/^\\[a-zA-Z]+\{/,"}","")},"\\ca":/^\\ca(?:\s+|(?![a-zA-Z]))/,"\\x":/^(?:\\[a-zA-Z]+\s*|\\[_&{}%])/,orbital:/^(?:[0-9]{1,2}[spdfgh]|[0-9]{0,2}sp)(?=$|[^a-zA-Z])/,others:/^[\/~|]/,"\\frac{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\frac{","","","}","{","","","}")},"\\overset{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\overset{","","","}","{","","","}")},"\\underset{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\underset{","","","}","{","","","}")},"\\underbrace{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\underbrace{","","","}_","{","","","}")},"\\color{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\color{","","","}")},"\\color{(...)}{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\color{","","","}","{","","","}")||o.patterns.findObserveGroups(e,"\\color","\\","",/^(?=\{)/,"{","","","}")},"\\ce{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\ce{","","","}")},"\\pu{(...)}":function(e){return o.patterns.findObserveGroups(e,"\\pu{","","","}")},oxidation$:/^(?:[+-][IVX]+|\\pm\s*0|\$\\pm\$\s*0)$/,"d-oxidation$":/^(?:[+-]?\s?[IVX]+|\\pm\s*0|\$\\pm\$\s*0)$/,"roman numeral":/^[IVX]+/,"1/2$":/^[+\-]?(?:[0-9]+|\$[a-z]\$|[a-z])\/[0-9]+(?:\$[a-z]\$|[a-z])?$/,amount:function(e){var t;if(t=e.match(/^(?:(?:(?:\([+\-]?[0-9]+\/[0-9]+\)|[+\-]?(?:[0-9]+|\$[a-z]\$|[a-z])\/[0-9]+|[+\-]?[0-9]+[.,][0-9]+|[+\-]?\.[0-9]+|[+\-]?[0-9]+)(?:[a-z](?=\s*[A-Z]))?)|[+\-]?[a-z](?=\s*[A-Z])|\+(?!\s))/))return{match_:t[0],remainder:e.substr(t[0].length)};var n=o.patterns.findObserveGroups(e,"","$","$","");return n&&(t=n.match_.match(/^\$(?:\(?[+\-]?(?:[0-9]*[a-z]?[+\-])?[0-9]*[a-z](?:[+\-][0-9]*[a-z]?)?\)?|\+|-)\$$/))?{match_:t[0],remainder:e.substr(t[0].length)}:null},amount2:function(e){return this.amount(e)},"(KV letters),":/^(?:[A-Z][a-z]{0,2}|i)(?=,)/,formula$:function(e){if(e.match(/^\([a-z]+\)$/))return null;var t=e.match(/^(?:[a-z]|(?:[0-9\ \+\-\,\.\(\)]+[a-z])+[0-9\ \+\-\,\.\(\)]*|(?:[a-z][0-9\ \+\-\,\.\(\)]+)+[a-z]?)$/);return t?{match_:t[0],remainder:e.substr(t[0].length)}:null},uprightEntities:/^(?:pH|pOH|pC|pK|iPr|iBu)(?=$|[^a-zA-Z])/,"/":/^\s*(\/)\s*/,"//":/^\s*(\/\/)\s*/,"*":/^\s*[*.]\s*/},findObserveGroups:function(e,t,n,r,i,o,a,s,l,c){var u=function(e,t){if("string"==typeof t)return 0!==e.indexOf(t)?null:t;var n=e.match(t);return n?n[0]:null},d=u(e,t);if(null===d)return null;if(e=e.substr(d.length),null===(d=u(e,n)))return null;var h=function(e,t,n){for(var r=0;t<e.length;){var i=e.charAt(t),o=u(e.substr(t),n);if(null!==o&&0===r)return{endMatchBegin:t,endMatchEnd:t+o.length};if("{"===i)r++;else if("}"===i){if(0===r)throw["ExtraCloseMissingOpen","Extra close brace or missing open brace"];r--}t++}return null}(e,d.length,r||i);if(null===h)return null;var p=e.substring(0,r?h.endMatchEnd:h.endMatchBegin);if(o||a){var f=this.findObserveGroups(e.substr(h.endMatchEnd),o,a,s,l);if(null===f)return null;var m=[p,f.match_];return{match_:c?m.join(""):m,remainder:f.remainder}}return{match_:p,remainder:e.substr(h.endMatchEnd)}},match_:function(e,t){var n=o.patterns.patterns[e];if(void 0===n)throw["MhchemBugP","mhchem bug P. Please report. ("+e+")"];if("function"==typeof n)return o.patterns.patterns[e](t);var r=t.match(n);return r?r.length>2?{match_:r.slice(1),remainder:t.substr(r[0].length)}:{match_:r[1]||r[0],remainder:t.substr(r[0].length)}:null}},actions:{"a=":function(e,t){e.a=(e.a||"")+t},"b=":function(e,t){e.b=(e.b||"")+t},"p=":function(e,t){e.p=(e.p||"")+t},"o=":function(e,t){e.o=(e.o||"")+t},"q=":function(e,t){e.q=(e.q||"")+t},"d=":function(e,t){e.d=(e.d||"")+t},"rm=":function(e,t){e.rm=(e.rm||"")+t},"text=":function(e,t){e.text_=(e.text_||"")+t},insert:function(e,t,n){return{type_:n}},"insert+p1":function(e,t,n){return{type_:n,p1:t}},"insert+p1+p2":function(e,t,n){return{type_:n,p1:t[0],p2:t[1]}},copy:function(e,t){return t},write:function(e,t,n){return n},rm:function(e,t){return{type_:"rm",p1:t}},text:function(e,t){return o.go(t,"text")},"tex-math":function(e,t){return o.go(t,"tex-math")},"tex-math tight":function(e,t){return o.go(t,"tex-math tight")},bond:function(e,t,n){return{type_:"bond",kind_:n||t}},"color0-output":function(e,t){return{type_:"color0",color:t}},ce:function(e,t){return o.go(t,"ce")},pu:function(e,t){return o.go(t,"pu")},"1/2":function(e,t){var n=[];t.match(/^[+\-]/)&&(n.push(t.substr(0,1)),t=t.substr(1));var r=t.match(/^([0-9]+|\$[a-z]\$|[a-z])\/([0-9]+)(\$[a-z]\$|[a-z])?$/);return r[1]=r[1].replace(/\$/g,""),n.push({type_:"frac",p1:r[1],p2:r[2]}),r[3]&&(r[3]=r[3].replace(/\$/g,""),n.push({type_:"tex-math",p1:r[3]})),n},"9,9":function(e,t){return o.go(t,"9,9")}},stateMachines:{tex:{transitions:i({empty:{0:{action_:"copy"}},"\\ce{(...)}":{0:{action_:[{type_:"write",option:"{"},"ce",{type_:"write",option:"}"}]}},"\\pu{(...)}":{0:{action_:[{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},else:{0:{action_:"copy"}}}),actions:{}},ce:{transitions:i({empty:{"*":{action_:"output"}},else:{"0|1|2":{action_:"beginsWithBond=false",revisit:!0,toContinue:!0}},oxidation$:{0:{action_:"oxidation-output"}},CMT:{r:{action_:"rdt=",nextState:"rt"},rd:{action_:"rqt=",nextState:"rdt"}},arrowUpDown:{"0|1|2|as":{action_:["sb=false","output","operator"],nextState:"1"}},uprightEntities:{"0|1|2":{action_:["o=","output"],nextState:"1"}},orbital:{"0|1|2|3":{action_:"o=",nextState:"o"}},"->":{"0|1|2|3":{action_:"r=",nextState:"r"},"a|as":{action_:["output","r="],nextState:"r"},"*":{action_:["output","r="],nextState:"r"}},"+":{o:{action_:"d= kv",nextState:"d"},"d|D":{action_:"d=",nextState:"d"},q:{action_:"d=",nextState:"qd"},"qd|qD":{action_:"d=",nextState:"qd"},dq:{action_:["output","d="],nextState:"d"},3:{action_:["sb=false","output","operator"],nextState:"0"}},amount:{"0|2":{action_:"a=",nextState:"a"}},"pm-operator":{"0|1|2|a|as":{action_:["sb=false","output",{type_:"operator",option:"\\pm"}],nextState:"0"}},operator:{"0|1|2|a|as":{action_:["sb=false","output","operator"],nextState:"0"}},"-$":{"o|q":{action_:["charge or bond","output"],nextState:"qd"},d:{action_:"d=",nextState:"d"},D:{action_:["output",{type_:"bond",option:"-"}],nextState:"3"},q:{action_:"d=",nextState:"qd"},qd:{action_:"d=",nextState:"qd"},"qD|dq":{action_:["output",{type_:"bond",option:"-"}],nextState:"3"}},"-9":{"3|o":{action_:["output",{type_:"insert",option:"hyphen"}],nextState:"3"}},"- orbital overlap":{o:{action_:["output",{type_:"insert",option:"hyphen"}],nextState:"2"},d:{action_:["output",{type_:"insert",option:"hyphen"}],nextState:"2"}},"-":{"0|1|2":{action_:[{type_:"output",option:1},"beginsWithBond=true",{type_:"bond",option:"-"}],nextState:"3"},3:{action_:{type_:"bond",option:"-"}},a:{action_:["output",{type_:"insert",option:"hyphen"}],nextState:"2"},as:{action_:[{type_:"output",option:2},{type_:"bond",option:"-"}],nextState:"3"},b:{action_:"b="},o:{action_:{type_:"- after o/d",option:!1},nextState:"2"},q:{action_:{type_:"- after o/d",option:!1},nextState:"2"},"d|qd|dq":{action_:{type_:"- after o/d",option:!0},nextState:"2"},"D|qD|p":{action_:["output",{type_:"bond",option:"-"}],nextState:"3"}},amount2:{"1|3":{action_:"a=",nextState:"a"}},letters:{"0|1|2|3|a|as|b|p|bp|o":{action_:"o=",nextState:"o"},"q|dq":{action_:["output","o="],nextState:"o"},"d|D|qd|qD":{action_:"o after d",nextState:"o"}},digits:{o:{action_:"q=",nextState:"q"},"d|D":{action_:"q=",nextState:"dq"},q:{action_:["output","o="],nextState:"o"},a:{action_:"o=",nextState:"o"}},"space A":{"b|p|bp":{action_:[]}},space:{a:{action_:[],nextState:"as"},0:{action_:"sb=false"},"1|2":{action_:"sb=true"},"r|rt|rd|rdt|rdq":{action_:"output",nextState:"0"},"*":{action_:["output","sb=true"],nextState:"1"}},"1st-level escape":{"1|2":{action_:["output",{type_:"insert+p1",option:"1st-level escape"}]},"*":{action_:["output",{type_:"insert+p1",option:"1st-level escape"}],nextState:"0"}},"[(...)]":{"r|rt":{action_:"rd=",nextState:"rd"},"rd|rdt":{action_:"rq=",nextState:"rdq"}},"...":{"o|d|D|dq|qd|qD":{action_:["output",{type_:"bond",option:"..."}],nextState:"3"},"*":{action_:[{type_:"output",option:1},{type_:"insert",option:"ellipsis"}],nextState:"1"}},". __* ":{"*":{action_:["output",{type_:"insert",option:"addition compound"}],nextState:"1"}},"state of aggregation $":{"*":{action_:["output","state of aggregation"],nextState:"1"}},"{[(":{"a|as|o":{action_:["o=","output","parenthesisLevel++"],nextState:"2"},"0|1|2|3":{action_:["o=","output","parenthesisLevel++"],nextState:"2"},"*":{action_:["output","o=","output","parenthesisLevel++"],nextState:"2"}},")]}":{"0|1|2|3|b|p|bp|o":{action_:["o=","parenthesisLevel--"],nextState:"o"},"a|as|d|D|q|qd|qD|dq":{action_:["output","o=","parenthesisLevel--"],nextState:"o"}},", ":{"*":{action_:["output","comma"],nextState:"0"}},"^_":{"*":{action_:[]}},"^{(...)}|^($...$)":{"0|1|2|as":{action_:"b=",nextState:"b"},p:{action_:"b=",nextState:"bp"},"3|o":{action_:"d= kv",nextState:"D"},q:{action_:"d=",nextState:"qD"},"d|D|qd|qD|dq":{action_:["output","d="],nextState:"D"}},"^a|^\\x{}{}|^\\x{}|^\\x|'":{"0|1|2|as":{action_:"b=",nextState:"b"},p:{action_:"b=",nextState:"bp"},"3|o":{action_:"d= kv",nextState:"d"},q:{action_:"d=",nextState:"qd"},"d|qd|D|qD":{action_:"d="},dq:{action_:["output","d="],nextState:"d"}},"_{(state of aggregation)}$":{"d|D|q|qd|qD|dq":{action_:["output","q="],nextState:"q"}},"_{(...)}|_($...$)|_9|_\\x{}{}|_\\x{}|_\\x":{"0|1|2|as":{action_:"p=",nextState:"p"},b:{action_:"p=",nextState:"bp"},"3|o":{action_:"q=",nextState:"q"},"d|D":{action_:"q=",nextState:"dq"},"q|qd|qD|dq":{action_:["output","q="],nextState:"q"}},"=<>":{"0|1|2|3|a|as|o|q|d|D|qd|qD|dq":{action_:[{type_:"output",option:2},"bond"],nextState:"3"}},"#":{"0|1|2|3|a|as|o":{action_:[{type_:"output",option:2},{type_:"bond",option:"#"}],nextState:"3"}},"{}^":{"*":{action_:[{type_:"output",option:1},{type_:"insert",option:"tinySkip"}],nextState:"1"}},"{}":{"*":{action_:{type_:"output",option:1},nextState:"1"}},"{...}":{"0|1|2|3|a|as|b|p|bp":{action_:"o=",nextState:"o"},"o|d|D|q|qd|qD|dq":{action_:["output","o="],nextState:"o"}},"$...$":{a:{action_:"a="},"0|1|2|3|as|b|p|bp|o":{action_:"o=",nextState:"o"},"as|o":{action_:"o="},"q|d|D|qd|qD|dq":{action_:["output","o="],nextState:"o"}},"\\bond{(...)}":{"*":{action_:[{type_:"output",option:2},"bond"],nextState:"3"}},"\\frac{(...)}":{"*":{action_:[{type_:"output",option:1},"frac-output"],nextState:"3"}},"\\overset{(...)}":{"*":{action_:[{type_:"output",option:2},"overset-output"],nextState:"3"}},"\\underset{(...)}":{"*":{action_:[{type_:"output",option:2},"underset-output"],nextState:"3"}},"\\underbrace{(...)}":{"*":{action_:[{type_:"output",option:2},"underbrace-output"],nextState:"3"}},"\\color{(...)}{(...)}":{"*":{action_:[{type_:"output",option:2},"color-output"],nextState:"3"}},"\\color{(...)}":{"*":{action_:[{type_:"output",option:2},"color0-output"]}},"\\ce{(...)}":{"*":{action_:[{type_:"output",option:2},"ce"],nextState:"3"}},"\\,":{"*":{action_:[{type_:"output",option:1},"copy"],nextState:"1"}},"\\pu{(...)}":{"*":{action_:["output",{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}],nextState:"3"}},"\\x{}{}|\\x{}|\\x":{"0|1|2|3|a|as|b|p|bp|o|c0":{action_:["o=","output"],nextState:"3"},"*":{action_:["output","o=","output"],nextState:"3"}},others:{"*":{action_:[{type_:"output",option:1},"copy"],nextState:"3"}},else2:{a:{action_:"a to o",nextState:"o",revisit:!0},as:{action_:["output","sb=true"],nextState:"1",revisit:!0},"r|rt|rd|rdt|rdq":{action_:["output"],nextState:"0",revisit:!0},"*":{action_:["output","copy"],nextState:"3"}}}),actions:{"o after d":function(e,t){var n;if((e.d||"").match(/^[1-9][0-9]*$/)){var r=e.d;e.d=void 0,(n=this.output(e)).push({type_:"tinySkip"}),e.b=r}else n=this.output(e);return o.actions["o="](e,t),n},"d= kv":function(e,t){e.d=t,e.dType="kv"},"charge or bond":function(e,t){if(e.beginsWithBond){var n=[];return o.concatArray(n,this.output(e)),o.concatArray(n,o.actions.bond(e,t,"-")),n}e.d=t},"- after o/d":function(e,t,n){var r=o.patterns.match_("orbital",e.o||""),i=o.patterns.match_("one lowercase greek letter $",e.o||""),a=o.patterns.match_("one lowercase latin letter $",e.o||""),s=o.patterns.match_("$one lowercase latin letter$ $",e.o||""),l="-"===t&&(r&&""===r.remainder||i||a||s);!l||e.a||e.b||e.p||e.d||e.q||r||!a||(e.o="$"+e.o+"$");var c=[];return l?(o.concatArray(c,this.output(e)),c.push({type_:"hyphen"})):(r=o.patterns.match_("digits",e.d||""),n&&r&&""===r.remainder?(o.concatArray(c,o.actions["d="](e,t)),o.concatArray(c,this.output(e))):(o.concatArray(c,this.output(e)),o.concatArray(c,o.actions.bond(e,t,"-")))),c},"a to o":function(e){e.o=e.a,e.a=void 0},"sb=true":function(e){e.sb=!0},"sb=false":function(e){e.sb=!1},"beginsWithBond=true":function(e){e.beginsWithBond=!0},"beginsWithBond=false":function(e){e.beginsWithBond=!1},"parenthesisLevel++":function(e){e.parenthesisLevel++},"parenthesisLevel--":function(e){e.parenthesisLevel--},"state of aggregation":function(e,t){return{type_:"state of aggregation",p1:o.go(t,"o")}},comma:function(e,t){var n=t.replace(/\s*$/,"");return n!==t&&0===e.parenthesisLevel?{type_:"comma enumeration L",p1:n}:{type_:"comma enumeration M",p1:n}},output:function(e,t,n){var r;if(e.r){var i=void 0;i="M"===e.rdt?o.go(e.rd,"tex-math"):"T"===e.rdt?[{type_:"text",p1:e.rd||""}]:o.go(e.rd,"ce");var a=void 0;a="M"===e.rqt?o.go(e.rq,"tex-math"):"T"===e.rqt?[{type_:"text",p1:e.rq||""}]:o.go(e.rq,"ce"),r={type_:"arrow",r:e.r,rd:i,rq:a}}else r=[],(e.a||e.b||e.p||e.o||e.q||e.d||n)&&(e.sb&&r.push({type_:"entitySkip"}),e.o||e.q||e.d||e.b||e.p||2===n?e.o||e.q||e.d||!e.b&&!e.p?e.o&&"kv"===e.dType&&o.patterns.match_("d-oxidation$",e.d||"")?e.dType="oxidation":e.o&&"kv"===e.dType&&!e.q&&(e.dType=void 0):(e.o=e.a,e.d=e.b,e.q=e.p,e.a=e.b=e.p=void 0):(e.o=e.a,e.a=void 0),r.push({type_:"chemfive",a:o.go(e.a,"a"),b:o.go(e.b,"bd"),p:o.go(e.p,"pq"),o:o.go(e.o,"o"),q:o.go(e.q,"pq"),d:o.go(e.d,"oxidation"===e.dType?"oxidation":"bd"),dType:e.dType}));for(var s in e)"parenthesisLevel"!==s&&"beginsWithBond"!==s&&delete e[s];return r},"oxidation-output":function(e,t){var n=["{"];return o.concatArray(n,o.go(t,"oxidation")),n.push("}"),n},"frac-output":function(e,t){return{type_:"frac-ce",p1:o.go(t[0],"ce"),p2:o.go(t[1],"ce")}},"overset-output":function(e,t){return{type_:"overset",p1:o.go(t[0],"ce"),p2:o.go(t[1],"ce")}},"underset-output":function(e,t){return{type_:"underset",p1:o.go(t[0],"ce"),p2:o.go(t[1],"ce")}},"underbrace-output":function(e,t){return{type_:"underbrace",p1:o.go(t[0],"ce"),p2:o.go(t[1],"ce")}},"color-output":function(e,t){return{type_:"color",color1:t[0],color2:o.go(t[1],"ce")}},"r=":function(e,t){e.r=t},"rdt=":function(e,t){e.rdt=t},"rd=":function(e,t){e.rd=t},"rqt=":function(e,t){e.rqt=t},"rq=":function(e,t){e.rq=t},operator:function(e,t,n){return{type_:"operator",kind_:n||t}}}},a:{transitions:i({empty:{"*":{action_:[]}},"1/2$":{0:{action_:"1/2"}},else:{0:{action_:[],nextState:"1",revisit:!0}},"${(...)}$__$(...)$":{"*":{action_:"tex-math tight",nextState:"1"}},",":{"*":{action_:{type_:"insert",option:"commaDecimal"}}},else2:{"*":{action_:"copy"}}}),actions:{}},o:{transitions:i({empty:{"*":{action_:[]}},"1/2$":{0:{action_:"1/2"}},else:{0:{action_:[],nextState:"1",revisit:!0}},letters:{"*":{action_:"rm"}},"\\ca":{"*":{action_:{type_:"insert",option:"circa"}}},"\\pu{(...)}":{"*":{action_:[{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"\\x{}{}|\\x{}|\\x":{"*":{action_:"copy"}},"${(...)}$__$(...)$":{"*":{action_:"tex-math"}},"{(...)}":{"*":{action_:[{type_:"write",option:"{"},"text",{type_:"write",option:"}"}]}},else2:{"*":{action_:"copy"}}}),actions:{}},text:{transitions:i({empty:{"*":{action_:"output"}},"{...}":{"*":{action_:"text="}},"${(...)}$__$(...)$":{"*":{action_:"tex-math"}},"\\greek":{"*":{action_:["output","rm"]}},"\\pu{(...)}":{"*":{action_:["output",{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"\\,|\\x{}{}|\\x{}|\\x":{"*":{action_:["output","copy"]}},else:{"*":{action_:"text="}}}),actions:{output:function(e){if(e.text_){var t={type_:"text",p1:e.text_};for(var n in e)delete e[n];return t}}}},pq:{transitions:i({empty:{"*":{action_:[]}},"state of aggregation $":{"*":{action_:"state of aggregation"}},i$:{0:{action_:[],nextState:"!f",revisit:!0}},"(KV letters),":{0:{action_:"rm",nextState:"0"}},formula$:{0:{action_:[],nextState:"f",revisit:!0}},"1/2$":{0:{action_:"1/2"}},else:{0:{action_:[],nextState:"!f",revisit:!0}},"${(...)}$__$(...)$":{"*":{action_:"tex-math"}},"{(...)}":{"*":{action_:"text"}},"a-z":{f:{action_:"tex-math"}},letters:{"*":{action_:"rm"}},"-9.,9":{"*":{action_:"9,9"}},",":{"*":{action_:{type_:"insert+p1",option:"comma enumeration S"}}},"\\color{(...)}{(...)}":{"*":{action_:"color-output"}},"\\color{(...)}":{"*":{action_:"color0-output"}},"\\ce{(...)}":{"*":{action_:"ce"}},"\\pu{(...)}":{"*":{action_:[{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"\\,|\\x{}{}|\\x{}|\\x":{"*":{action_:"copy"}},else2:{"*":{action_:"copy"}}}),actions:{"state of aggregation":function(e,t){return{type_:"state of aggregation subscript",p1:o.go(t,"o")}},"color-output":function(e,t){return{type_:"color",color1:t[0],color2:o.go(t[1],"pq")}}}},bd:{transitions:i({empty:{"*":{action_:[]}},x$:{0:{action_:[],nextState:"!f",revisit:!0}},formula$:{0:{action_:[],nextState:"f",revisit:!0}},else:{0:{action_:[],nextState:"!f",revisit:!0}},"-9.,9 no missing 0":{"*":{action_:"9,9"}},".":{"*":{action_:{type_:"insert",option:"electron dot"}}},"a-z":{f:{action_:"tex-math"}},x:{"*":{action_:{type_:"insert",option:"KV x"}}},letters:{"*":{action_:"rm"}},"'":{"*":{action_:{type_:"insert",option:"prime"}}},"${(...)}$__$(...)$":{"*":{action_:"tex-math"}},"{(...)}":{"*":{action_:"text"}},"\\color{(...)}{(...)}":{"*":{action_:"color-output"}},"\\color{(...)}":{"*":{action_:"color0-output"}},"\\ce{(...)}":{"*":{action_:"ce"}},"\\pu{(...)}":{"*":{action_:[{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"\\,|\\x{}{}|\\x{}|\\x":{"*":{action_:"copy"}},else2:{"*":{action_:"copy"}}}),actions:{"color-output":function(e,t){return{type_:"color",color1:t[0],color2:o.go(t[1],"bd")}}}},oxidation:{transitions:i({empty:{"*":{action_:[]}},"roman numeral":{"*":{action_:"roman-numeral"}},"${(...)}$__$(...)$":{"*":{action_:"tex-math"}},else:{"*":{action_:"copy"}}}),actions:{"roman-numeral":function(e,t){return{type_:"roman numeral",p1:t}}}},"tex-math":{transitions:i({empty:{"*":{action_:"output"}},"\\ce{(...)}":{"*":{action_:["output","ce"]}},"\\pu{(...)}":{"*":{action_:["output",{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"{...}|\\,|\\x{}{}|\\x{}|\\x":{"*":{action_:"o="}},else:{"*":{action_:"o="}}}),actions:{output:function(e){if(e.o){var t={type_:"tex-math",p1:e.o};for(var n in e)delete e[n];return t}}}},"tex-math tight":{transitions:i({empty:{"*":{action_:"output"}},"\\ce{(...)}":{"*":{action_:["output","ce"]}},"\\pu{(...)}":{"*":{action_:["output",{type_:"write",option:"{"},"pu",{type_:"write",option:"}"}]}},"{...}|\\,|\\x{}{}|\\x{}|\\x":{"*":{action_:"o="}},"-|+":{"*":{action_:"tight operator"}},else:{"*":{action_:"o="}}}),actions:{"tight operator":function(e,t){e.o=(e.o||"")+"{"+t+"}"},output:function(e){if(e.o){var t={type_:"tex-math",p1:e.o};for(var n in e)delete e[n];return t}}}},"9,9":{transitions:i({empty:{"*":{action_:[]}},",":{"*":{action_:"comma"}},else:{"*":{action_:"copy"}}}),actions:{comma:function(){return{type_:"commaDecimal"}}}},pu:{transitions:i({empty:{"*":{action_:"output"}},space$:{"*":{action_:["output","space"]}},"{[(|)]}":{"0|a":{action_:"copy"}},"(-)(9)^(-9)":{0:{action_:"number^",nextState:"a"}},"(-)(9.,9)(e)(99)":{0:{action_:"enumber",nextState:"a"}},space:{"0|a":{action_:[]}},"pm-operator":{"0|a":{action_:{type_:"operator",option:"\\pm"},nextState:"0"}},operator:{"0|a":{action_:"copy",nextState:"0"}},"//":{d:{action_:"o=",nextState:"/"}},"/":{d:{action_:"o=",nextState:"/"}},"{...}|else":{"0|d":{action_:"d=",nextState:"d"},a:{action_:["space","d="],nextState:"d"},"/|q":{action_:"q=",nextState:"q"}}}),actions:{enumber:function(e,t){var n=[];return"+-"===t[0]||"+/-"===t[0]?n.push("\\pm "):t[0]&&n.push(t[0]),t[1]&&(o.concatArray(n,o.go(t[1],"pu-9,9")),t[2]&&(t[2].match(/[,.]/)?o.concatArray(n,o.go(t[2],"pu-9,9")):n.push(t[2])),(t[3]||t[4])&&("e"===t[3]||"*"===t[4]?n.push({type_:"cdot"}):n.push({type_:"times"}))),t[5]&&n.push("10^{"+t[5]+"}"),n},"number^":function(e,t){var n=[];return"+-"===t[0]||"+/-"===t[0]?n.push("\\pm "):t[0]&&n.push(t[0]),o.concatArray(n,o.go(t[1],"pu-9,9")),n.push("^{"+t[2]+"}"),n},operator:function(e,t,n){return{type_:"operator",kind_:n||t}},space:function(){return{type_:"pu-space-1"}},output:function(e){var t,n=o.patterns.match_("{(...)}",e.d||"");n&&""===n.remainder&&(e.d=n.match_);var r=o.patterns.match_("{(...)}",e.q||"");if(r&&""===r.remainder&&(e.q=r.match_),e.d&&(e.d=e.d.replace(/\u00B0C|\^oC|\^{o}C/g,"{}^{\\circ}C"),e.d=e.d.replace(/\u00B0F|\^oF|\^{o}F/g,"{}^{\\circ}F")),e.q){e.q=e.q.replace(/\u00B0C|\^oC|\^{o}C/g,"{}^{\\circ}C"),e.q=e.q.replace(/\u00B0F|\^oF|\^{o}F/g,"{}^{\\circ}F");var i={d:o.go(e.d,"pu"),q:o.go(e.q,"pu")};"//"===e.o?t={type_:"pu-frac",p1:i.d,p2:i.q}:(t=i.d,i.d.length>1||i.q.length>1?t.push({type_:" / "}):t.push({type_:"/"}),o.concatArray(t,i.q))}else t=o.go(e.d,"pu-2");for(var a in e)delete e[a];return t}}},"pu-2":{transitions:i({empty:{"*":{action_:"output"}},"*":{"*":{action_:["output","cdot"],nextState:"0"}},"\\x":{"*":{action_:"rm="}},space:{"*":{action_:["output","space"],nextState:"0"}},"^{(...)}|^(-1)":{1:{action_:"^(-1)"}},"-9.,9":{0:{action_:"rm=",nextState:"0"},1:{action_:"^(-1)",nextState:"0"}},"{...}|else":{"*":{action_:"rm=",nextState:"1"}}}),actions:{cdot:function(){return{type_:"tight cdot"}},"^(-1)":function(e,t){e.rm+="^{"+t+"}"},space:function(){return{type_:"pu-space-2"}},output:function(e){var t=[];if(e.rm){var n=o.patterns.match_("{(...)}",e.rm||"");t=n&&""===n.remainder?o.go(n.match_,"pu"):{type_:"rm",p1:e.rm}}for(var r in e)delete e[r];return t}}},"pu-9,9":{transitions:i({empty:{0:{action_:"output-0"},o:{action_:"output-o"}},",":{0:{action_:["output-0","comma"],nextState:"o"}},".":{0:{action_:["output-0","copy"],nextState:"o"}},else:{"*":{action_:"text="}}}),actions:{comma:function(){return{type_:"commaDecimal"}},"output-0":function(e){var t=[];if(e.text_=e.text_||"",e.text_.length>4){var n=e.text_.length%3;0===n&&(n=3);for(var r=e.text_.length-3;r>0;r-=3)t.push(e.text_.substr(r,3)),t.push({type_:"1000 separator"});t.push(e.text_.substr(0,n)),t.reverse()}else t.push(e.text_);for(var i in e)delete e[i];return t},"output-o":function(e){var t=[];if(e.text_=e.text_||"",e.text_.length>4){var n=e.text_.length-3,r=void 0;for(r=0;r<n;r+=3)t.push(e.text_.substr(r,3)),t.push({type_:"1000 separator"});t.push(e.text_.substr(r))}else t.push(e.text_);for(var i in e)delete e[i];return t}}}}},a={go:function(e,t){if(!e)return"";for(var n="",r=!1,i=0;i<e.length;i++){var o=e[i];"string"==typeof o?n+=o:(n+=a._go2(o),"1st-level escape"===o.type_&&(r=!0))}return t&&!r&&n&&(n="{"+n+"}"),n},_goInner:function(e){return a.go(e,!1)},_go2:function(e){var t;switch(e.type_){case"chemfive":t="";var n={a:a._goInner(e.a),b:a._goInner(e.b),p:a._goInner(e.p),o:a._goInner(e.o),q:a._goInner(e.q),d:a._goInner(e.d)};n.a&&(n.a.match(/^[+\-]/)&&(n.a="{"+n.a+"}"),t+=n.a+"\\,"),(n.b||n.p)&&(t+="{\\vphantom{A}}",t+="^{\\hphantom{"+(n.b||"")+"}}_{\\hphantom{"+(n.p||"")+"}}",t+="\\mkern-1.5mu",t+="{\\vphantom{A}}",t+="^{\\smash[t]{\\vphantom{2}}\\llap{"+(n.b||"")+"}}",t+="_{\\vphantom{2}\\llap{\\smash[t]{"+(n.p||"")+"}}}"),n.o&&(n.o.match(/^[+\-]/)&&(n.o="{"+n.o+"}"),t+=n.o),"kv"===e.dType?((n.d||n.q)&&(t+="{\\vphantom{A}}"),n.d&&(t+="^{"+n.d+"}"),n.q&&(t+="_{\\smash[t]{"+n.q+"}}")):"oxidation"===e.dType?(n.d&&(t+="{\\vphantom{A}}",t+="^{"+n.d+"}"),n.q&&(t+="{\\vphantom{A}}",t+="_{\\smash[t]{"+n.q+"}}")):(n.q&&(t+="{\\vphantom{A}}",t+="_{\\smash[t]{"+n.q+"}}"),n.d&&(t+="{\\vphantom{A}}",t+="^{"+n.d+"}"));break;case"rm":t="\\mathrm{"+e.p1+"}";break;case"text":e.p1.match(/[\^_]/)?(e.p1=e.p1.replace(" ","~").replace("-","\\text{-}"),t="\\mathrm{"+e.p1+"}"):t="\\text{"+e.p1+"}";break;case"roman numeral":t="\\mathrm{"+e.p1+"}";break;case"state of aggregation":t="\\mskip2mu "+a._goInner(e.p1);break;case"state of aggregation subscript":t="\\mskip1mu "+a._goInner(e.p1);break;case"bond":if(!(t=a._getBond(e.kind_)))throw["MhchemErrorBond","mhchem Error. Unknown bond type ("+e.kind_+")"];break;case"frac":var r="\\frac{"+e.p1+"}{"+e.p2+"}";t="\\mathchoice{\\textstyle"+r+"}{"+r+"}{"+r+"}{"+r+"}";break;case"pu-frac":var i="\\frac{"+a._goInner(e.p1)+"}{"+a._goInner(e.p2)+"}";t="\\mathchoice{\\textstyle"+i+"}{"+i+"}{"+i+"}{"+i+"}";break;case"tex-math":t=e.p1+" ";break;case"frac-ce":t="\\frac{"+a._goInner(e.p1)+"}{"+a._goInner(e.p2)+"}";break;case"overset":t="\\overset{"+a._goInner(e.p1)+"}{"+a._goInner(e.p2)+"}";break;case"underset":t="\\underset{"+a._goInner(e.p1)+"}{"+a._goInner(e.p2)+"}";break;case"underbrace":t="\\underbrace{"+a._goInner(e.p1)+"}_{"+a._goInner(e.p2)+"}";break;case"color":t="{\\color{"+e.color1+"}{"+a._goInner(e.color2)+"}}";break;case"color0":t="\\color{"+e.color+"}";break;case"arrow":var o={rd:a._goInner(e.rd),rq:a._goInner(e.rq)},s=a._getArrow(e.r);o.rd||o.rq?"<=>"===e.r||"<=>>"===e.r||"<<=>"===e.r||"<--\x3e"===e.r?(s="\\long"+s,o.rd&&(s="\\overset{"+o.rd+"}{"+s+"}"),o.rq&&(s="<--\x3e"===e.r?"\\underset{\\lower2mu{"+o.rq+"}}{"+s+"}":"\\underset{\\lower6mu{"+o.rq+"}}{"+s+"}"),s=" {}\\mathrel{"+s+"}{} "):(o.rq&&(s+="[{"+o.rq+"}]"),s=" {}\\mathrel{\\x"+(s+="{"+o.rd+"}")+"}{} "):s=" {}\\mathrel{\\long"+s+"}{} ",t=s;break;case"operator":t=a._getOperator(e.kind_);break;case"1st-level escape":t=e.p1+" ";break;case"space":t=" ";break;case"tinySkip":t="\\mkern2mu";break;case"entitySkip":case"pu-space-1":t="~";break;case"pu-space-2":t="\\mkern3mu ";break;case"1000 separator":t="\\mkern2mu ";break;case"commaDecimal":t="{,}";break;case"comma enumeration L":t="{"+e.p1+"}\\mkern6mu ";break;case"comma enumeration M":t="{"+e.p1+"}\\mkern3mu ";break;case"comma enumeration S":t="{"+e.p1+"}\\mkern1mu ";break;case"hyphen":t="\\text{-}";break;case"addition compound":t="\\,{\\cdot}\\,";break;case"electron dot":t="\\mkern1mu \\bullet\\mkern1mu ";break;case"KV x":t="{\\times}";break;case"prime":t="\\prime ";break;case"cdot":t="\\cdot ";break;case"tight cdot":t="\\mkern1mu{\\cdot}\\mkern1mu ";break;case"times":t="\\times ";break;case"circa":t="{\\sim}";break;case"^":t="uparrow";break;case"v":t="downarrow";break;case"ellipsis":t="\\ldots ";break;case"/":t="/";break;case" / ":t="\\,/\\,";break;default:throw["MhchemBugT","mhchem bug T. Please report."]}return t},_getArrow:function(e){switch(e){case"->":case"→":case"⟶":return"rightarrow";case"<-":return"leftarrow";case"<->":return"leftrightarrow";case"<--\x3e":return"leftrightarrows";case"<=>":case"⇌":return"rightleftharpoons";case"<=>>":return"Rightleftharpoons";case"<<=>":return"Leftrightharpoons";default:throw["MhchemBugT","mhchem bug T. Please report."]}},_getBond:function(e){switch(e){case"-":case"1":return"{-}";case"=":case"2":return"{=}";case"#":case"3":return"{\\equiv}";case"~":return"{\\tripledash}";case"~-":return"{\\rlap{\\lower.1em{-}}\\raise.1em{\\tripledash}}";case"~=":case"~--":return"{\\rlap{\\lower.2em{-}}\\rlap{\\raise.2em{\\tripledash}}-}";case"-~-":return"{\\rlap{\\lower.2em{-}}\\rlap{\\raise.2em{-}}\\tripledash}";case"...":return"{{\\cdot}{\\cdot}{\\cdot}}";case"....":return"{{\\cdot}{\\cdot}{\\cdot}{\\cdot}}";case"->":return"{\\rightarrow}";case"<-":return"{\\leftarrow}";case"<":return"{<}";case">":return"{>}";default:throw["MhchemBugT","mhchem bug T. Please report."]}},_getOperator:function(e){switch(e){case"+":return" {}+{} ";case"-":return" {}-{} ";case"=":return" {}={} ";case"<":return" {}<{} ";case">":return" {}>{} ";case"<<":return" {}\\ll{} ";case">>":return" {}\\gg{} ";case"\\pm":return" {}\\pm{} ";case"\\approx":case"$\\approx$":return" {}\\approx{} ";case"v":case"(v)":return" \\downarrow{} ";case"^":case"(^)":return" \\uparrow{} ";default:throw["MhchemBugT","mhchem bug T. Please report."]}}}},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.NoErrorsConfiguration=void 0;var r=n(29);t.NoErrorsConfiguration=r.Configuration.create("noerrors",{nodes:{error:function(e,t,n,r){var i=e.create("token","mtext",{},r.replace(/\n/g," "));return e.create("node","merror",[i],{"data-mjx-error":t,title:t})}}})},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.NoUndefinedConfiguration=void 0;var i=n(29);t.NoUndefinedConfiguration=i.Configuration.create("noundefined",{fallback:{macro:function(e,t){var n,i,o=e.create("text","\\"+t),a=e.options.noundefined||{},s={};try{for(var l=r(["color","background","size"]),c=l.next();!c.done;c=l.next()){var u=c.value;a[u]&&(s["math"+u]=a[u])}}catch(e){n={error:e}}finally{try{c&&!c.done&&(i=l.return)&&i.call(l)}finally{if(n)throw n.error}}e.Push(e.create("node","mtext",[],s,o))}},options:{noundefined:{color:"red",background:"",size:""}},priority:3})},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.PhysicsConfiguration=void 0;var i=n(29),o=n(990);n(991),t.PhysicsConfiguration=i.Configuration.create("physics",{handler:{macro:["Physics-automatic-bracing-macros","Physics-vector-macros","Physics-vector-chars","Physics-derivative-macros","Physics-expressions-macros","Physics-quick-quad-macros","Physics-bra-ket-macros","Physics-matrix-macros"],character:["Physics-characters"],environment:["Physics-aux-envs"]},items:(r={},r[o.AutoOpen.prototype.kind]=o.AutoOpen,r),options:{physics:{italicdiff:!1,arrowdel:!1}}})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.AutoOpen=void 0;var o=n(95),a=n(37),s=n(49),l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return i(t,e),Object.defineProperty(t.prototype,"kind",{get:function(){return"auto open"},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isOpen",{get:function(){return!0},enumerable:!1,configurable:!0}),t.prototype.toMml=function(){var t=this.factory.configuration.parser,n=this.getProperty("right");if(this.getProperty("smash")){var r=e.prototype.toMml.call(this),i=t.create("node","mpadded",[r],{height:0,depth:0});this.Clear(),this.Push(t.create("node","TeXAtom",[i]))}n&&this.Push(new s.default(n,t.stack.env,t.configuration).mml());var o=e.prototype.toMml.call(this);return a.default.fenced(this.factory.configuration,this.getProperty("open"),o,this.getProperty("close"),this.getProperty("big"))},t.prototype.checkItem=function(t){var n=t.getProperty("autoclose");return n&&n===this.getProperty("close")?this.getProperty("ignore")?(this.Clear(),[[],!0]):[[this.toMml()],!0]:e.prototype.checkItem.call(this,t)},t}(o.BaseItem);t.AutoOpen=l},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(992),o=n(50),a=n(73),s=n(23);new r.CommandMap("Physics-automatic-bracing-macros",{quantity:"Quantity",qty:"Quantity",pqty:["Quantity","(",")",!0],bqty:["Quantity","[","]",!0],vqty:["Quantity","|","|",!0],Bqty:["Quantity","\\{","\\}",!0],absolutevalue:["Quantity","|","|",!0],abs:["Quantity","|","|",!0],norm:["Quantity","\\|","\\|",!0],evaluated:"Eval",eval:"Eval",order:["Quantity","(",")",!0,"O",o.TexConstant.Variant.CALLIGRAPHIC],commutator:"Commutator",comm:"Commutator",anticommutator:["Commutator","\\{","\\}"],acomm:["Commutator","\\{","\\}"],poissonbracket:["Commutator","\\{","\\}"],pb:["Commutator","\\{","\\}"]},i.default),new r.CharacterMap("Physics-vector-chars",a.default.mathchar0mi,{dotproduct:["⋅",{mathvariant:o.TexConstant.Variant.BOLD}],vdot:["⋅",{mathvariant:o.TexConstant.Variant.BOLD}],crossproduct:"×",cross:"×",cp:"×",gradientnabla:["∇",{mathvariant:o.TexConstant.Variant.BOLD}],real:["ℜ",{mathvariant:o.TexConstant.Variant.NORMAL}],imaginary:["ℑ",{mathvariant:o.TexConstant.Variant.NORMAL}]}),new r.CommandMap("Physics-vector-macros",{vnabla:"Vnabla",vectorbold:"VectorBold",vb:"VectorBold",vectorarrow:["StarMacro",1,"\\vec{\\vb","{#1}}"],va:["StarMacro",1,"\\vec{\\vb","{#1}}"],vectorunit:["StarMacro",1,"\\hat{\\vb","{#1}}"],vu:["StarMacro",1,"\\hat{\\vb","{#1}}"],gradient:["OperatorApplication","\\vnabla","(","["],grad:["OperatorApplication","\\vnabla","(","["],divergence:["VectorOperator","\\vnabla\\vdot","(","["],div:["VectorOperator","\\vnabla\\vdot","(","["],curl:["VectorOperator","\\vnabla\\crossproduct","(","["],laplacian:["OperatorApplication","\\nabla^2","(","["]},i.default),new r.CommandMap("Physics-expressions-macros",{sin:"Expression",sinh:"Expression",arcsin:"Expression",asin:"Expression",cos:"Expression",cosh:"Expression",arccos:"Expression",acos:"Expression",tan:"Expression",tanh:"Expression",arctan:"Expression",atan:"Expression",csc:"Expression",csch:"Expression",arccsc:"Expression",acsc:"Expression",sec:"Expression",sech:"Expression",arcsec:"Expression",asec:"Expression",cot:"Expression",coth:"Expression",arccot:"Expression",acot:"Expression",exp:["Expression",!1],log:"Expression",ln:"Expression",det:["Expression",!1],Pr:["Expression",!1],tr:["Expression",!1],trace:["Expression",!1,"tr"],Tr:["Expression",!1],Trace:["Expression",!1,"Tr"],rank:"NamedFn",erf:["Expression",!1],Residue:["Macro","\\mathrm{Res}"],Res:["OperatorApplication","\\Residue","(","[","{"],principalvalue:["OperatorApplication","{\\cal P}"],pv:["OperatorApplication","{\\cal P}"],PV:["OperatorApplication","{\\rm P.V.}"],Re:["OperatorApplication","\\mathrm{Re}","{"],Im:["OperatorApplication","\\mathrm{Im}","{"],sine:["NamedFn","sin"],hypsine:["NamedFn","sinh"],arcsine:["NamedFn","arcsin"],asine:["NamedFn","asin"],cosine:["NamedFn","cos"],hypcosine:["NamedFn","cosh"],arccosine:["NamedFn","arccos"],acosine:["NamedFn","acos"],tangent:["NamedFn","tan"],hyptangent:["NamedFn","tanh"],arctangent:["NamedFn","arctan"],atangent:["NamedFn","atan"],cosecant:["NamedFn","csc"],hypcosecant:["NamedFn","csch"],arccosecant:["NamedFn","arccsc"],acosecant:["NamedFn","acsc"],secant:["NamedFn","sec"],hypsecant:["NamedFn","sech"],arcsecant:["NamedFn","arcsec"],asecant:["NamedFn","asec"],cotangent:["NamedFn","cot"],hypcotangent:["NamedFn","coth"],arccotangent:["NamedFn","arccot"],acotangent:["NamedFn","acot"],exponential:["NamedFn","exp"],logarithm:["NamedFn","log"],naturallogarithm:["NamedFn","ln"],determinant:["NamedFn","det"],Probability:["NamedFn","Pr"]},i.default),new r.CommandMap("Physics-quick-quad-macros",{qqtext:"Qqtext",qq:"Qqtext",qcomma:["Macro","\\qqtext*{,}"],qc:["Macro","\\qqtext*{,}"],qcc:["Qqtext","c.c."],qif:["Qqtext","if"],qthen:["Qqtext","then"],qelse:["Qqtext","else"],qotherwise:["Qqtext","otherwise"],qunless:["Qqtext","unless"],qgiven:["Qqtext","given"],qusing:["Qqtext","using"],qassume:["Qqtext","assume"],qsince:["Qqtext","since"],qlet:["Qqtext","let"],qfor:["Qqtext","for"],qall:["Qqtext","all"],qeven:["Qqtext","even"],qodd:["Qqtext","odd"],qinteger:["Qqtext","integer"],qand:["Qqtext","and"],qor:["Qqtext","or"],qas:["Qqtext","as"],qin:["Qqtext","in"]},i.default),new r.CommandMap("Physics-derivative-macros",{diffd:"DiffD",flatfrac:["Macro","\\left.#1\\middle/#2\\right.",2],differential:["Differential","\\diffd"],dd:["Differential","\\diffd"],variation:["Differential","\\delta"],var:["Differential","\\delta"],derivative:["Derivative",2,"\\diffd"],dv:["Derivative",2,"\\diffd"],partialderivative:["Derivative",3,"\\partial"],pderivative:["Derivative",3,"\\partial"],pdv:["Derivative",3,"\\partial"],functionalderivative:["Derivative",2,"\\delta"],fderivative:["Derivative",2,"\\delta"],fdv:["Derivative",2,"\\delta"]},i.default),new r.CommandMap("Physics-bra-ket-macros",{bra:"Bra",ket:"Ket",innerproduct:"BraKet",ip:"BraKet",braket:"BraKet",outerproduct:"KetBra",dyad:"KetBra",ketbra:"KetBra",op:"KetBra",expectationvalue:"Expectation",expval:"Expectation",ev:"Expectation",matrixelement:"MatrixElement",matrixel:"MatrixElement",mel:"MatrixElement"},i.default),new r.CommandMap("Physics-matrix-macros",{matrixquantity:"MatrixQuantity",mqty:"MatrixQuantity",pmqty:["Macro","\\mqty(#1)",1],Pmqty:["Macro","\\mqty*(#1)",1],bmqty:["Macro","\\mqty[#1]",1],vmqty:["Macro","\\mqty|#1|",1],smallmatrixquantity:["MatrixQuantity",!0],smqty:["MatrixQuantity",!0],spmqty:["Macro","\\smqty(#1)",1],sPmqty:["Macro","\\smqty*(#1)",1],sbmqty:["Macro","\\smqty[#1]",1],svmqty:["Macro","\\smqty|#1|",1],matrixdeterminant:["Macro","\\vmqty{#1}",1],mdet:["Macro","\\vmqty{#1}",1],smdet:["Macro","\\svmqty{#1}",1],identitymatrix:"IdentityMatrix",imat:"IdentityMatrix",xmatrix:"XMatrix",xmat:"XMatrix",zeromatrix:["Macro","\\xmat{0}{#1}{#2}",2],zmat:["Macro","\\xmat{0}{#1}{#2}",2],paulimatrix:"PauliMatrix",pmat:"PauliMatrix",diagonalmatrix:"DiagonalMatrix",dmat:"DiagonalMatrix",antidiagonalmatrix:["DiagonalMatrix",!0],admat:["DiagonalMatrix",!0]},i.default),new r.EnvironmentMap("Physics-aux-envs",a.default.environment,{smallmatrix:["Array",null,null,null,"c","0.333em",".2em","S",1]},i.default),new r.MacroMap("Physics-characters",{"|":["AutoClose",s.TEXCLASS.ORD],")":"AutoClose","]":"AutoClose"},i.default)},function(e,t,n){"use strict";var r=this&&this.__read||function(e,t){var n="function"==typeof Symbol&&e[Symbol.iterator];if(!n)return e;var r,i,o=n.call(e),a=[];try{for(;(void 0===t||t-- >0)&&!(r=o.next()).done;)a.push(r.value)}catch(e){i={error:e}}finally{try{r&&!r.done&&(n=o.return)&&n.call(o)}finally{if(i)throw i.error}}return a};Object.defineProperty(t,"__esModule",{value:!0});var i=n(57),o=n(49),a=n(31),s=n(23),l=n(37),c=n(39),u=n(182),d={},h={"(":")","[":"]","{":"}","|":"|"},p=/^(b|B)i(g{1,2})$/;d.Quantity=function(e,t,n,r,i,u,d){void 0===n&&(n="("),void 0===r&&(r=")"),void 0===i&&(i=!1),void 0===u&&(u=""),void 0===d&&(d="");var f=!!i&&e.GetStar(),m=e.GetNext(),g=e.i,v=null;if("\\"===m){if(e.i++,!(v=e.GetCS()).match(p)){var y=e.create("node","mrow");return e.Push(l.default.fenced(e.configuration,n,y,r)),void(e.i=g)}m=e.GetNext()}var _=h[m];if(i&&"{"!==m)throw new a.default("MissingArgFor","Missing argument for %1",e.currentCS);if(!_){y=e.create("node","mrow");return e.Push(l.default.fenced(e.configuration,n,y,r)),void(e.i=g)}if(u){var b=e.create("token","mi",{texClass:s.TEXCLASS.OP},u);d&&c.default.setAttribute(b,"mathvariant",d),e.Push(e.itemFactory.create("fn",b))}if("{"===m){var M=e.GetArgument(t);return m=i?n:"\\{",_=i?r:"\\}",M=f?m+" "+M+" "+_:v?"\\"+v+"l"+m+" "+M+" \\"+v+"r"+_:"\\left"+m+" "+M+" \\right"+_,void e.Push(new o.default(M,e.stack.env,e.configuration).mml())}i&&(m=n,_=r),e.i++,e.Push(e.itemFactory.create("auto open").setProperties({open:m,close:_,big:v}))},d.Eval=function(e,t){var n=e.GetStar(),r=e.GetNext();if("{"!==r){if("("===r||"["===r)return e.i++,void e.Push(e.itemFactory.create("auto open").setProperties({open:r,close:"|",smash:n,right:"\\vphantom{\\int}"}));throw new a.default("MissingArgFor","Missing argument for %1",e.currentCS)}var i=e.GetArgument(t),o="\\left. "+(n?"\\smash{"+i+"}":i)+" \\vphantom{\\int}\\right|";e.string=e.string.slice(0,e.i)+o+e.string.slice(e.i)},d.Commutator=function(e,t,n,r){void 0===n&&(n="["),void 0===r&&(r="]");var i=e.GetStar(),s=e.GetNext(),l=null;if("\\"===s){if(e.i++,!(l=e.GetCS()).match(p))throw new a.default("MissingArgFor","Missing argument for %1",e.currentCS);s=e.GetNext()}if("{"!==s)throw new a.default("MissingArgFor","Missing argument for %1",e.currentCS);var c=e.GetArgument(t)+","+e.GetArgument(t);c=i?n+" "+c+" "+r:l?"\\"+l+"l"+n+" "+c+" \\"+l+"r"+r:"\\left"+n+" "+c+" \\right"+r,e.Push(new o.default(c,e.stack.env,e.configuration).mml())};var f=[65,90],m=[97,122],g=[913,937],v=[945,969],y=[48,57];function _(e,t){return e>=t[0]&&e<=t[1]}function b(e,t,n,r){var i=e.configuration.parser,o=u.NodeFactory.createToken(e,t,n,r),a=r.codePointAt(0);return 1===r.length&&!i.stack.env.font&&i.stack.env.vectorFont&&(_(a,f)||_(a,m)||_(a,g)||_(a,y)||_(a,v)&&i.stack.env.vectorStar||c.default.getAttribute(o,"accent"))&&c.default.setAttribute(o,"mathvariant",i.stack.env.vectorFont),o}d.VectorBold=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i=e.configuration.nodeFactory.get("token"),a=e.stack.env.font;delete e.stack.env.font,e.configuration.nodeFactory.set("token",b),e.stack.env.vectorFont=n?"bold-italic":"bold",e.stack.env.vectorStar=n;var s=new o.default(r,e.stack.env,e.configuration).mml();a&&(e.stack.env.font=a),delete e.stack.env.vectorFont,delete e.stack.env.vectorStar,e.configuration.nodeFactory.set("token",i),e.Push(s)},d.StarMacro=function(e,t,n){for(var r=[],i=3;i<arguments.length;i++)r[i-3]=arguments[i];var o=e.GetStar(),a=[];if(n)for(var s=a.length;s<n;s++)a.push(e.GetArgument(t));var c=r.join(o?"*":"");c=l.default.substituteArgs(e,a,c),e.string=l.default.addArgs(e,c,e.string.slice(e.i)),e.i=0,l.default.checkMaxMacros(e)};var M=function(e,t,n,r,i){var a=new o.default(r,e.stack.env,e.configuration).mml();e.Push(e.itemFactory.create(t,a));var s=e.GetNext(),l=h[s];if(l){var c=-1!==i.indexOf(s);if("{"===s){var u=(c?"\\left\\{":"")+" "+e.GetArgument(n)+" "+(c?"\\right\\}":"");return e.string=u+e.string.slice(e.i),void(e.i=0)}c&&(e.i++,e.Push(e.itemFactory.create("auto open").setProperties({open:s,close:l})))}};function w(e,t,n){var i=r(e,3),o=i[0],a=i[1],s=i[2];return t&&n?"\\left\\langle{"+o+"}\\middle\\vert{"+a+"}\\middle\\vert{"+s+"}\\right\\rangle":t?"\\langle{"+o+"}\\vert{"+a+"}\\vert{"+s+"}\\rangle":"\\left\\langle{"+o+"}\\right\\vert{"+a+"}\\left\\vert{"+s+"}\\right\\rangle"}d.OperatorApplication=function(e,t,n){for(var r=[],i=3;i<arguments.length;i++)r[i-3]=arguments[i];M(e,"fn",t,n,r)},d.VectorOperator=function(e,t,n){for(var r=[],i=3;i<arguments.length;i++)r[i-3]=arguments[i];M(e,"mml",t,n,r)},d.Expression=function(e,t,n,r){void 0===n&&(n=!0),void 0===r&&(r=""),r=r||t.slice(1);var i=n?e.GetBrackets(t):null,a=e.create("token","mi",{texClass:s.TEXCLASS.OP},r);if(i){var l=new o.default(i,e.stack.env,e.configuration).mml();a=e.create("node","msup",[a,l])}e.Push(e.itemFactory.create("fn",a)),"("===e.GetNext()&&(e.i++,e.Push(e.itemFactory.create("auto open").setProperties({open:"(",close:")"})))},d.Qqtext=function(e,t,n){var r=(e.GetStar()?"":"\\quad")+"\\text{"+(n||e.GetArgument(t))+"}\\quad ";e.string=e.string.slice(0,e.i)+r+e.string.slice(e.i)},d.Differential=function(e,t,n){var r=e.GetBrackets(t),i=null!=r?"^{"+r+"}":" ",a="("===e.GetNext(),l="{"===e.GetNext(),c=n+i;if(a||l)if(l){c+=e.GetArgument(t);u=new o.default(c,e.stack.env,e.configuration).mml();e.Push(e.create("node","TeXAtom",[u],{texClass:s.TEXCLASS.OP}))}else e.Push(new o.default(c,e.stack.env,e.configuration).mml()),e.i++,e.Push(e.itemFactory.create("auto open").setProperties({open:"(",close:")"}));else{c+=e.GetArgument(t,!0)||"";var u=new o.default(c,e.stack.env,e.configuration).mml();e.Push(u)}},d.Derivative=function(e,t,n,r){var i=e.GetStar(),a=e.GetBrackets(t),s=1,l=[];for(l.push(e.GetArgument(t));"{"===e.GetNext()&&s<n;)l.push(e.GetArgument(t)),s++;var c=!1,u=" ",d=" ";n>2&&l.length>2?(u="^{"+(l.length-1)+"}",c=!0):null!=a&&(n>2&&l.length>1&&(c=!0),d=u="^{"+a+"}");for(var h=i?"\\flatfrac":"\\frac",p=l.length>1?l[0]:"",f=l.length>1?l[1]:l[0],m="",g=2,v=void 0;v=l[g];g++)m+=r+" "+v;var y=h+"{"+r+u+p+"}{"+r+" "+f+d+" "+m+"}";e.Push(new o.default(y,e.stack.env,e.configuration).mml()),"("===e.GetNext()&&(e.i++,e.Push(e.itemFactory.create("auto open").setProperties({open:"(",close:")",ignore:c})))},d.Bra=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i="",a=!1,s=!1;if("\\"===e.GetNext()){var l=e.i;e.i++;var c=e.GetCS(),u=e.lookup("macro",c);u&&"ket"===u.symbol?(a=!0,l=e.i,s=e.GetStar(),"{"===e.GetNext()?i=e.GetArgument(c,!0):(e.i=l,s=!1)):e.i=l}var d="";d=a?n||s?"\\langle{"+r+"}\\vert{"+i+"}\\rangle":"\\left\\langle{"+r+"}\\middle\\vert{"+i+"}\\right\\rangle":n||s?"\\langle{"+r+"}\\vert":"\\left\\langle{"+r+"}\\right\\vert{"+i+"}",e.Push(new o.default(d,e.stack.env,e.configuration).mml())},d.Ket=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i=n?"\\vert{"+r+"}\\rangle":"\\left\\vert{"+r+"}\\right\\rangle";e.Push(new o.default(i,e.stack.env,e.configuration).mml())},d.BraKet=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i=null;"{"===e.GetNext()&&(i=e.GetArgument(t,!0));var a="";a=null==i?n?"\\langle{"+r+"}\\vert{"+r+"}\\rangle":"\\left\\langle{"+r+"}\\middle\\vert{"+r+"}\\right\\rangle":n?"\\langle{"+r+"}\\vert{"+i+"}\\rangle":"\\left\\langle{"+r+"}\\middle\\vert{"+i+"}\\right\\rangle",e.Push(new o.default(a,e.stack.env,e.configuration).mml())},d.KetBra=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i=null;"{"===e.GetNext()&&(i=e.GetArgument(t,!0));var a="";a=null==i?n?"\\vert{"+r+"}\\rangle\\!\\langle{"+r+"}\\vert":"\\left\\vert{"+r+"}\\middle\\rangle\\!\\middle\\langle{"+r+"}\\right\\vert":n?"\\vert{"+r+"}\\rangle\\!\\langle{"+i+"}\\vert":"\\left\\vert{"+r+"}\\middle\\rangle\\!\\middle\\langle{"+i+"}\\right\\vert",e.Push(new o.default(a,e.stack.env,e.configuration).mml())},d.Expectation=function(e,t){var n=e.GetStar(),r=n&&e.GetStar(),i=e.GetArgument(t),a=null;"{"===e.GetNext()&&(a=e.GetArgument(t,!0));var s=i&&a?w([a,i,a],n,r):n?"\\langle {"+i+"} \\rangle":"\\left\\langle {"+i+"} \\right\\rangle";e.Push(new o.default(s,e.stack.env,e.configuration).mml())},d.MatrixElement=function(e,t){var n=e.GetStar(),r=n&&e.GetStar(),i=w([e.GetArgument(t),e.GetArgument(t),e.GetArgument(t)],n,r);e.Push(new o.default(i,e.stack.env,e.configuration).mml())},d.MatrixQuantity=function(e,t,n){var r=e.GetStar(),i=n?"smallmatrix":"array",a="",s="",l="";switch(e.GetNext()){case"{":a=e.GetArgument(t);break;case"(":e.i++,s=r?"\\lgroup":"(",l=r?"\\rgroup":")",a=e.GetUpTo(t,")");break;case"[":e.i++,s="[",l="]",a=e.GetUpTo(t,"]");break;case"|":e.i++,s="|",l="|",a=e.GetUpTo(t,"|");break;default:s="(",l=")"}var c=(s?"\\left":"")+s+"\\begin{"+i+"}{} "+a+"\\end{"+i+"}"+(s?"\\right":"")+l;e.Push(new o.default(c,e.stack.env,e.configuration).mml())},d.IdentityMatrix=function(e,t){var n=e.GetArgument(t),r=parseInt(n,10);if(isNaN(r))throw new a.default("InvalidNumber","Invalid number");if(r<=1)return e.string="1"+e.string.slice(e.i),void(e.i=0);for(var i=Array(r).fill("0"),o=[],s=0;s<r;s++){var l=i.slice();l[s]="1",o.push(l.join(" & "))}e.string=o.join("\\\\ ")+e.string.slice(e.i),e.i=0},d.XMatrix=function(e,t){var n=e.GetStar(),r=e.GetArgument(t),i=e.GetArgument(t),o=e.GetArgument(t),s=parseInt(i,10),l=parseInt(o,10);if(isNaN(s)||isNaN(l)||l.toString()!==o||s.toString()!==i)throw new a.default("InvalidNumber","Invalid number");if(s=s<1?1:s,l=l<1?1:l,!n){var c=Array(l).fill(r).join(" & "),u=Array(s).fill(c).join("\\\\ ");return e.string=u+e.string.slice(e.i),void(e.i=0)}var d="";if(1===s&&1===l)d=r;else if(1===s){c=[];for(var h=1;h<=l;h++)c.push(r+"_{"+h+"}");d=c.join(" & ")}else if(1===l){for(c=[],h=1;h<=s;h++)c.push(r+"_{"+h+"}");d=c.join("\\\\ ")}else{var p=[];for(h=1;h<=s;h++){c=[];for(var f=1;f<=l;f++)c.push(r+"_{{"+h+"}{"+f+"}}");p.push(c.join(" & "))}d=p.join("\\\\ ")}e.string=d+e.string.slice(e.i),e.i=0},d.PauliMatrix=function(e,t){var n=e.GetArgument(t),r=n.slice(1);switch(n[0]){case"0":r+=" 1 & 0\\\\ 0 & 1";break;case"1":case"x":r+=" 0 & 1\\\\ 1 & 0";break;case"2":case"y":r+=" 0 & -i\\\\ i & 0";break;case"3":case"z":r+=" 1 & 0\\\\ 0 & -1"}e.string=r+e.string.slice(e.i),e.i=0},d.DiagonalMatrix=function(e,t,n){if("{"===e.GetNext()){var r=e.i;e.GetArgument(t);var i=e.i;e.i=r+1;for(var o=[],a="",s=e.i;s<i;){try{a=e.GetUpTo(t,",")}catch(t){e.i=i,o.push(e.string.slice(s,i-1));break}if(e.i>=i){o.push(e.string.slice(s,i));break}s=e.i,o.push(a)}e.string=function(e,t){for(var n=e.length,r=[],i=0;i<n;i++)r.push(Array(t?n-i:i+1).join("&")+"\\mqty{"+e[i]+"}");return r.join("\\\\ ")}(o,n)+e.string.slice(i),e.i=0}},d.AutoClose=function(e,t,n){var r=e.create("token","mo",{stretchy:!1},t),i=e.itemFactory.create("mml",r).setProperties({autoclose:t});e.Push(i)},d.Vnabla=function(e,t){var n=e.options.physics.arrowdel?"\\vec{\\gradientnabla}":"{\\gradientnabla}";return e.Push(new o.default(n,e.stack.env,e.configuration).mml())},d.DiffD=function(e,t){var n=e.options.physics.italicdiff?"d":"{\\rm d}";return e.Push(new o.default(n,e.stack.env,e.configuration).mml())},d.Macro=i.default.Macro,d.NamedFn=i.default.NamedFn,d.Array=i.default.Array,t.default=d},function(e,t,n){"use strict";var r=this&&this.__values||function(e){var t="function"==typeof Symbol&&Symbol.iterator,n=t&&e[t],r=0;if(n)return n.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")};Object.defineProperty(t,"__esModule",{value:!0}),t.SetOptionsConfiguration=t.SetOptionsUtil=void 0;var i=n(29),o=n(28),a=n(31),s=n(37),l=n(96),c=n(57),u=n(47);t.SetOptionsUtil={filterPackage:function(e,t){if("tex"!==t&&!i.ConfigurationHandler.get(t))throw new a.default("NotAPackage","Not a defined package: %1",t);var n=e.options.setoptions,r=n.allowOptions[t];if(void 0===r&&!n.allowPackageDefault||!1===r)throw new a.default("PackageNotSettable",'Options can\'t be set for package "%1"',t);return!0},filterOption:function(e,t,n){var r,i=e.options.setoptions,o=i.allowOptions[t]||{},s=o.hasOwnProperty(n)&&!u.isObject(o[n])?o[n]:null;if(!1===s||null===s&&!i.allowOptionsDefault)throw new a.default("OptionNotSettable",'Option "%1" is not allowed to be set',n);if(!(null===(r="tex"===t?e.options:e.options[t])||void 0===r?void 0:r.hasOwnProperty(n)))throw"tex"===t?new a.default("InvalidTexOption",'Invalid TeX option "%1"',n):new a.default("InvalidOptionKey",'Invalid option "%1" for package "%2"',n,t);return!0},filterValue:function(e,t,n,r){return r}};var d=new o.CommandMap("setoptions",{setOptions:"SetOptions"},{SetOptions:function(e,t){var n,i,o=e.GetBrackets(t)||"tex",a=s.default.keyvalOptions(e.GetArgument(t)),l=e.options.setoptions;if(l.filterPackage(e,o))try{for(var c=r(Object.keys(a)),u=c.next();!u.done;u=c.next()){var d=u.value;l.filterOption(e,o,d)&&(("tex"===o?e.options:e.options[o])[d]=l.filterValue(e,o,d,a[d]))}}catch(e){n={error:e}}finally{try{u&&!u.done&&(i=c.return)&&i.call(c)}finally{if(n)throw n.error}}}});t.SetOptionsConfiguration=i.Configuration.create("setoptions",{handler:{macro:["setoptions"]},config:function(e,t){var n=t.parseOptions.handlers.get("macro").lookup("require");n&&(d.add("Require",new l.Macro("Require",n._func)),d.add("require",new l.Macro("require",c.default.Macro,["\\Require{#2}\\setOptions[#2]{#1}",2,""])))},priority:3,options:{setoptions:{filterPackage:t.SetOptionsUtil.filterPackage,filterOption:t.SetOptionsUtil.filterOption,filterValue:t.SetOptionsUtil.filterValue,allowPackageDefault:!0,allowOptionsDefault:!0,allowOptions:u.expandable({tex:{FindTeX:!1,formatError:!1,package:!1,baseURL:!1,tags:!1,maxBuffer:!1,maxMaxros:!1,macros:!1,environments:!1},setoptions:!1,autoload:!1,require:!1,configmacros:!1,tagformat:!1})}}})},function(e,t,n){"use strict";var r,i=this&&this.__extends||(r=function(e,t){return(r=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}r(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)});Object.defineProperty(t,"__esModule",{value:!0}),t.TagFormatConfiguration=t.tagformatConfig=void 0;var o=n(29),a=n(72),s=0;function l(e,t){var n=t.parseOptions.options.tags;"base"!==n&&e.tags.hasOwnProperty(n)&&a.TagsFactory.add(n,e.tags[n]);var r=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return i(n,e),n.prototype.formatNumber=function(e){return t.parseOptions.options.tagformat.number(e)},n.prototype.formatTag=function(e){return t.parseOptions.options.tagformat.tag(e)},n.prototype.formatId=function(e){return t.parseOptions.options.tagformat.id(e)},n.prototype.formatUrl=function(e,n){return t.parseOptions.options.tagformat.url(e,n)},n}(a.TagsFactory.create(t.parseOptions.options.tags).constructor),o="configTags-"+ ++s;a.TagsFactory.add(o,r),t.parseOptions.options.tags=o}t.tagformatConfig=l,t.TagFormatConfiguration=o.Configuration.create("tagformat",{config:[l,10],options:{tagformat:{number:function(e){return e.toString()},tag:function(e){return"("+e+")"},id:function(e){return"mjx-eqn:"+e.replace(/\s/g,"_")},url:function(e,t){return t+"#"+encodeURIComponent(e)}}}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.TextcompConfiguration=void 0;var r=n(29);n(996),t.TextcompConfiguration=r.Configuration.create("textcomp",{handler:{macro:["textcomp-macros"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(50),o=n(191),a=n(37),s=n(461);new r.CommandMap("textcomp-macros",{textasciicircum:["Insert","^"],textasciitilde:["Insert","~"],textasteriskcentered:["Insert","*"],textbackslash:["Insert","\\"],textbar:["Insert","|"],textbraceleft:["Insert","{"],textbraceright:["Insert","}"],textbullet:["Insert","•"],textdagger:["Insert","†"],textdaggerdbl:["Insert","‡"],textellipsis:["Insert","…"],textemdash:["Insert","—"],textendash:["Insert","–"],textexclamdown:["Insert","¡"],textgreater:["Insert",">"],textless:["Insert","<"],textordfeminine:["Insert","ª"],textordmasculine:["Insert","º"],textparagraph:["Insert","¶"],textperiodcentered:["Insert","·"],textquestiondown:["Insert","¿"],textquotedblleft:["Insert","“"],textquotedblright:["Insert","”"],textquoteleft:["Insert","‘"],textquoteright:["Insert","’"],textsection:["Insert","§"],textunderscore:["Insert","_"],textvisiblespace:["Insert","␣"],textacutedbl:["Insert","˝"],textasciiacute:["Insert","´"],textasciibreve:["Insert","˘"],textasciicaron:["Insert","ˇ"],textasciidieresis:["Insert","¨"],textasciimacron:["Insert","¯"],textgravedbl:["Insert","˵"],texttildelow:["Insert","˷"],textbaht:["Insert","฿"],textcent:["Insert","¢"],textcolonmonetary:["Insert","₡"],textcurrency:["Insert","¤"],textdollar:["Insert","$"],textdong:["Insert","₫"],texteuro:["Insert","€"],textflorin:["Insert","ƒ"],textguarani:["Insert","₲"],textlira:["Insert","₤"],textnaira:["Insert","₦"],textpeso:["Insert","₱"],textsterling:["Insert","£"],textwon:["Insert","₩"],textyen:["Insert","¥"],textcircledP:["Insert","℗"],textcompwordmark:["Insert","‌"],textcopyleft:["Insert","🄯"],textcopyright:["Insert","©"],textregistered:["Insert","®"],textservicemark:["Insert","℠"],texttrademark:["Insert","™"],textbardbl:["Insert","‖"],textbigcircle:["Insert","◯"],textblank:["Insert","␢"],textbrokenbar:["Insert","¦"],textdiscount:["Insert","⁒"],textestimated:["Insert","℮"],textinterrobang:["Insert","‽"],textinterrobangdown:["Insert","⸘"],textmusicalnote:["Insert","♪"],textnumero:["Insert","№"],textopenbullet:["Insert","◦"],textpertenthousand:["Insert","‱"],textperthousand:["Insert","‰"],textrecipe:["Insert","℞"],textreferencemark:["Insert","※"],textlangle:["Insert","〈"],textrangle:["Insert","〉"],textlbrackdbl:["Insert","⟦"],textrbrackdbl:["Insert","⟧"],textlquill:["Insert","⁅"],textrquill:["Insert","⁆"],textcelsius:["Insert","℃"],textdegree:["Insert","°"],textdiv:["Insert","÷"],textdownarrow:["Insert","↓"],textfractionsolidus:["Insert","⁄"],textleftarrow:["Insert","←"],textlnot:["Insert","¬"],textmho:["Insert","℧"],textminus:["Insert","−"],textmu:["Insert","µ"],textohm:["Insert","Ω"],textonehalf:["Insert","½"],textonequarter:["Insert","¼"],textonesuperior:["Insert","¹"],textpm:["Insert","±"],textrightarrow:["Insert","→"],textsurd:["Insert","√"],textthreequarters:["Insert","¾"],textthreesuperior:["Insert","³"],texttimes:["Insert","×"],texttwosuperior:["Insert","²"],textuparrow:["Insert","↑"],textborn:["Insert","*"],textdied:["Insert","†"],textdivorced:["Insert","⚮"],textmarried:["Insert","⚭"],textcentoldstyle:["Insert","¢",i.TexConstant.Variant.OLDSTYLE],textdollaroldstyle:["Insert","$",i.TexConstant.Variant.OLDSTYLE],textzerooldstyle:["Insert","0",i.TexConstant.Variant.OLDSTYLE],textoneoldstyle:["Insert","1",i.TexConstant.Variant.OLDSTYLE],texttwooldstyle:["Insert","2",i.TexConstant.Variant.OLDSTYLE],textthreeoldstyle:["Insert","3",i.TexConstant.Variant.OLDSTYLE],textfouroldstyle:["Insert","4",i.TexConstant.Variant.OLDSTYLE],textfiveoldstyle:["Insert","5",i.TexConstant.Variant.OLDSTYLE],textsixoldstyle:["Insert","6",i.TexConstant.Variant.OLDSTYLE],textsevenoldstyle:["Insert","7",i.TexConstant.Variant.OLDSTYLE],texteightoldstyle:["Insert","8",i.TexConstant.Variant.OLDSTYLE],textnineoldstyle:["Insert","9",i.TexConstant.Variant.OLDSTYLE]},{Insert:function(e,t,n,r){if(e instanceof s.TextParser){if(!r)return void o.TextMacrosMethods.Insert(e,t,n);e.saveText()}e.Push(a.default.internalText(e,n,r?{mathvariant:r}:{}))}})},function(e,t,n){"use strict";var r;Object.defineProperty(t,"__esModule",{value:!0}),t.TextMacrosConfiguration=t.TextBaseConfiguration=void 0;var i=n(29),o=n(419),a=n(72),s=n(68),l=n(461),c=n(191);function u(e,t,n,r){var i=e.configuration.packageData.get("textmacros");return e instanceof l.TextParser||(i.texParser=e),[new l.TextParser(t,r?{mathvariant:r}:{},i.parseOptions,n).mml()]}n(998),t.TextBaseConfiguration=i.Configuration.create("text-base",{parser:"text",handler:{character:["command","text-special"],macro:["text-macros"]},fallback:{character:function(e,t){e.text+=t},macro:function(e,t){var n=e.texParser,r=n.lookup("macro",t);r&&r._func!==c.TextMacrosMethods.Macro&&e.Error("MathMacro","%1 is only supported in math mode","\\"+t),n.parse("macro",[e,t])}},items:(r={},r[s.StartItem.prototype.kind]=s.StartItem,r[s.StopItem.prototype.kind]=s.StopItem,r[s.MmlItem.prototype.kind]=s.MmlItem,r[s.StyleItem.prototype.kind]=s.StyleItem,r)}),t.TextMacrosConfiguration=i.Configuration.create("textmacros",{config:function(e,t){var n=new i.ParserConfiguration(t.parseOptions.options.textmacros.packages,["tex","text"]);n.init();var r=new o.default(n,[]);r.options=t.parseOptions.options,n.config(t),a.TagsFactory.addTags(n.tags),r.tags=a.TagsFactory.getDefault(),r.tags.configuration=r,r.packageData=t.parseOptions.packageData,r.packageData.set("textmacros",{parseOptions:r,jax:t,texParser:null}),r.options.internalMath=u},preprocessors:[function(e){var t=e.data.packageData.get("textmacros");t.parseOptions.nodeFactory.setMmlFactory(t.jax.mmlFactory)}],options:{textmacros:{packages:["text-base"]}}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r=n(28),i=n(50),o=n(191),a=n(58);new r.MacroMap("text-special",{$:"Math","%":"Comment","^":"MathModeOnly",_:"MathModeOnly","&":"Misplaced","#":"Misplaced","~":"Tilde"," ":"Space","\t":"Space","\r":"Space","\n":"Space"," ":"Tilde","{":"OpenBrace","}":"CloseBrace","`":"OpenQuote","'":"CloseQuote"},o.TextMacrosMethods),new r.CommandMap("text-macros",{"(":"Math",$:"SelfQuote",_:"SelfQuote","%":"SelfQuote","{":"SelfQuote","}":"SelfQuote"," ":"SelfQuote","&":"SelfQuote","#":"SelfQuote","\\":"SelfQuote","'":["Accent","´"],"’":["Accent","´"],"`":["Accent","`"],"‘":["Accent","`"],"^":["Accent","^"],'"':["Accent","¨"],"~":["Accent","~"],"=":["Accent","¯"],".":["Accent","˙"],u:["Accent","˘"],v:["Accent","ˇ"],emph:"Emph",rm:["SetFont",i.TexConstant.Variant.NORMAL],mit:["SetFont",i.TexConstant.Variant.ITALIC],oldstyle:["SetFont",i.TexConstant.Variant.OLDSTYLE],cal:["SetFont",i.TexConstant.Variant.CALLIGRAPHIC],it:["SetFont","-tex-mathit"],bf:["SetFont",i.TexConstant.Variant.BOLD],bbFont:["SetFont",i.TexConstant.Variant.DOUBLESTRUCK],scr:["SetFont",i.TexConstant.Variant.SCRIPT],frak:["SetFont",i.TexConstant.Variant.FRAKTUR],sf:["SetFont",i.TexConstant.Variant.SANSSERIF],tt:["SetFont",i.TexConstant.Variant.MONOSPACE],tiny:["SetSize",.5],Tiny:["SetSize",.6],scriptsize:["SetSize",.7],small:["SetSize",.85],normalsize:["SetSize",1],large:["SetSize",1.2],Large:["SetSize",1.44],LARGE:["SetSize",1.73],huge:["SetSize",2.07],Huge:["SetSize",2.49],Bbb:["Macro","{\\bbFont #1}",1],textrm:["Macro","{\\rm #1}",1],textit:["Macro","{\\it #1}",1],textbf:["Macro","{\\bf #1}",1],textsf:["Macro","{\\sf #1}",1],texttt:["Macro","{\\tt #1}",1],dagger:["Insert","†"],ddagger:["Insert","‡"],S:["Insert","§"],",":["Spacer",a.MATHSPACE.thinmathspace],":":["Spacer",a.MATHSPACE.mediummathspace],">":["Spacer",a.MATHSPACE.mediummathspace],";":["Spacer",a.MATHSPACE.thickmathspace],"!":["Spacer",a.MATHSPACE.negativethinmathspace],enspace:["Spacer",.5],quad:["Spacer",1],qquad:["Spacer",2],thinspace:["Spacer",a.MATHSPACE.thinmathspace],negthinspace:["Spacer",a.MATHSPACE.negativethinmathspace],hskip:"Hskip",hspace:"Hskip",kern:"Hskip",mskip:"Hskip",mspace:"Hskip",mkern:"Hskip",rule:"rule",Rule:["Rule"],Space:["Rule","blank"],color:"CheckAutoload",textcolor:"CheckAutoload",colorbox:"CheckAutoload",fcolorbox:"CheckAutoload",href:"CheckAutoload",style:"CheckAutoload",class:"CheckAutoload",cssId:"CheckAutoload",unicode:"CheckAutoload",ref:["HandleRef",!1],eqref:["HandleRef",!0]},o.TextMacrosMethods)},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.UpgreekConfiguration=void 0;var r=n(29),i=n(28),o=n(50);new i.CharacterMap("upgreek",(function(e,t){var n=t.attributes||{};n.mathvariant=o.TexConstant.Variant.NORMAL;var r=e.create("token","mi",n,t.char);e.Push(r)}),{upalpha:"α",upbeta:"β",upgamma:"γ",updelta:"δ",upepsilon:"ϵ",upzeta:"ζ",upeta:"η",uptheta:"θ",upiota:"ι",upkappa:"κ",uplambda:"λ",upmu:"μ",upnu:"ν",upxi:"ξ",upomicron:"ο",uppi:"π",uprho:"ρ",upsigma:"σ",uptau:"τ",upupsilon:"υ",upphi:"ϕ",upchi:"χ",uppsi:"ψ",upomega:"ω",upvarepsilon:"ε",upvartheta:"ϑ",upvarpi:"ϖ",upvarrho:"ϱ",upvarsigma:"ς",upvarphi:"φ",Upgamma:"Γ",Updelta:"Δ",Uptheta:"Θ",Uplambda:"Λ",Upxi:"Ξ",Uppi:"Π",Upsigma:"Σ",Upupsilon:"Υ",Upphi:"Φ",Uppsi:"Ψ",Upomega:"Ω"}),t.UpgreekConfiguration=r.Configuration.create("upgreek",{handler:{macro:["upgreek"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.UnicodeConfiguration=t.UnicodeMethods=void 0;var r=n(29),i=n(31),o=n(28),a=n(37),s=n(39),l=n(135);t.UnicodeMethods={};var c={};t.UnicodeMethods.Unicode=function(e,t){var n=e.GetBrackets(t),r=null,o=null;n&&(n.replace(/ /g,"").match(/^(\d+(\.\d*)?|\.\d+),(\d+(\.\d*)?|\.\d+)$/)?(r=n.replace(/ /g,"").split(/,/),o=e.GetBrackets(t)):o=n);var u=a.default.trimSpaces(e.GetArgument(t)).replace(/^0x/,"x");if(!u.match(/^(x[0-9A-Fa-f]+|[0-9]+)$/))throw new i.default("BadUnicode","Argument to \\unicode must be a number");var d=parseInt(u.match(/^x/)?"0"+u:u);c[d]?o||(o=c[d][2]):c[d]=[800,200,o,d],r&&(c[d][0]=Math.floor(1e3*parseFloat(r[0])),c[d][1]=Math.floor(1e3*parseFloat(r[1])));var h=e.stack.env.font,p={};o?(c[d][2]=p.fontfamily=o.replace(/'/g,"'"),h&&(h.match(/bold/)&&(p.fontweight="bold"),h.match(/italic|-mathit/)&&(p.fontstyle="italic"))):h&&(p.mathvariant=h);var f=e.create("token","mtext",p,l.numeric(u));s.default.setProperty(f,"unicode",!0),e.Push(f)},new o.CommandMap("unicode",{unicode:"Unicode"},t.UnicodeMethods),t.UnicodeConfiguration=r.Configuration.create("unicode",{handler:{macro:["unicode"]}})},function(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.VerbConfiguration=t.VerbMethods=void 0;var r=n(29),i=n(50),o=n(28),a=n(31);t.VerbMethods={},t.VerbMethods.Verb=function(e,t){var n=e.GetNext(),r=++e.i;if(""===n)throw new a.default("MissingArgFor","Missing argument for %1",t);for(;e.i<e.string.length&&e.string.charAt(e.i)!==n;)e.i++;if(e.i===e.string.length)throw new a.default("NoClosingDelim","Can't find closing delimiter for %1",e.currentCS);var o=e.string.slice(r,e.i).replace(/ /g," ");e.i++,e.Push(e.create("token","mtext",{mathvariant:i.TexConstant.Variant.MONOSPACE},o))},new o.CommandMap("verb",{verb:"Verb"},t.VerbMethods),t.VerbConfiguration=r.Configuration.create("verb",{handler:{macro:["verb"]}})},function(e,t,n){"use strict";n.r(t),n.d(t,"RenderMimeRegistry",(function(){return v})),n.d(t,"standardRendererFactories",(function(){return x})),n.d(t,"extendedRendererFactories",(function(){return E})),n.d(t,"WidgetManager",(function(){return Qt})),n.d(t,"connectKernel",(function(){return $t})),n.d(t,"renderMathJax",(function(){return hn}));var r={};n.r(r),n.d(r,"OUTPUT_WIDGET_VERSION",(function(){return ge})),n.d(r,"OutputModel",(function(){return ve})),n.d(r,"JupyterPhosphorPanelWidget",(function(){return ye})),n.d(r,"OutputView",(function(){return _e}));var i={};n.r(i),n.d(i,"ConnectionLost",(function(){return Pe})),n.d(i,"JupyterFrontEnd",(function(){return lt})),n.d(i,"JupyterFrontEndContextMenu",(function(){return at})),n.d(i,"JupyterLab",(function(){return Dt})),n.d(i,"ILayoutRestorer",(function(){return gt})),n.d(i,"LayoutRestorer",(function(){return yt})),n.d(i,"createRendermimePlugin",(function(){return wt})),n.d(i,"createRendermimePlugins",(function(){return Mt})),n.d(i,"IMimeDocumentTracker",(function(){return bt})),n.d(i,"Router",(function(){return jt})),n.d(i,"ILabShell",(function(){return St})),n.d(i,"LabShell",(function(){return Tt})),n.d(i,"ILabStatus",(function(){return It})),n.d(i,"IConnectionLost",(function(){return Pt})),n.d(i,"IRouter",(function(){return zt})),n.d(i,"ITreePathUpdater",(function(){return Rt}));var o={};n.r(o),n.d(o,"Context",(function(){return Vt})),n.d(o,"DocumentModel",(function(){return Ve})),n.d(o,"TextModelFactory",(function(){return Ue})),n.d(o,"Base64ModelFactory",(function(){return We})),n.d(o,"ABCWidgetFactory",(function(){return Ge})),n.d(o,"DocumentWidget",(function(){return qe})),n.d(o,"MimeContent",(function(){return ht})),n.d(o,"MimeDocument",(function(){return pt})),n.d(o,"MimeDocumentFactory",(function(){return ft})),n.d(o,"DocumentRegistry",(function(){return Ke}));var a={};n.r(a),n.d(a,"OutputAreaModel",(function(){return oe})),n.d(a,"OutputArea",(function(){return ce})),n.d(a,"SimplifiedOutputArea",(function(){return ue})),n.d(a,"OutputPrompt",(function(){return de})),n.d(a,"Stdin",(function(){return he}));var s,l,c=n(98),u=n.n(c),d=n(195),h={insert:"head",singleton:!1},p=(u()(d.a,h),d.a.locals,n(354)),f=n(12),m=n(22);class g{constructor(e={}){this.trusted=!!e.trusted,this._data=e.data||{},this._metadata=e.metadata||{},this._callback=e.callback||s.noOp}get data(){return this._data}get metadata(){return this._metadata}setData(e){this._data=e.data||this._data,this._metadata=e.metadata||this._metadata,this._callback(e)}}(s||(s={})).noOp=function(){};class v{constructor(e={}){if(this._id=0,this._ranks={},this._types=null,this._factories={},this.translator=e.translator||m.b,this.resolver=e.resolver||null,this.linkHandler=e.linkHandler||null,this.latexTypesetter=e.latexTypesetter||null,this.sanitizer=e.sanitizer||p.b,e.initialFactories)for(const t of e.initialFactories)this.addFactory(t)}get mimeTypes(){return this._types||(this._types=l.sortedTypes(this._ranks))}preferredMimeType(e,t="ensure"){if("ensure"===t||"prefer"===t)for(const t of this.mimeTypes)if(t in e&&this._factories[t].safe)return t;if("ensure"!==t)for(const t of this.mimeTypes)if(t in e)return t}createRenderer(e){if(!(e in this._factories))throw new Error(`No factory for mime type: '${e}'`);return this._factories[e].createRenderer({mimeType:e,resolver:this.resolver,sanitizer:this.sanitizer,linkHandler:this.linkHandler,latexTypesetter:this.latexTypesetter,translator:this.translator})}createModel(e={}){return new g(e)}clone(e={}){const t=new v({resolver:e.resolver||this.resolver||void 0,sanitizer:e.sanitizer||this.sanitizer||void 0,linkHandler:e.linkHandler||this.linkHandler||void 0,latexTypesetter:e.latexTypesetter||this.latexTypesetter||void 0,translator:this.translator});return t._factories=Object.assign({},this._factories),t._ranks=Object.assign({},this._ranks),t._id=this._id,t}getFactory(e){return this._factories[e]}addFactory(e,t){void 0===t&&void 0===(t=e.defaultRank)&&(t=100);for(const n of e.mimeTypes)this._factories[n]=e,this._ranks[n]={rank:t,id:this._id++};this._types=null}removeMimeType(e){delete this._factories[e],delete this._ranks[e],this._types=null}getRank(e){const t=this._ranks[e];return t&&t.rank}setRank(e,t){if(!this._ranks[e])return;const n=this._id++;this._ranks[e]={rank:t,id:n},this._types=null}}(v||(v={})).UrlResolver=class{constructor(e){if(e.path)this._path=e.path;else{if(!e.session)throw new Error("Either 'path' or 'session' must be given as a constructor option");this._session=e.session}this._contents=e.contents}get path(){var e;return null!==(e=this._path)&&void 0!==e?e:this._session.path}set path(e){this._path=e}async resolveUrl(e){if(this.isLocal(e)){const t=encodeURI(f.PathExt.dirname(this.path));e=f.PathExt.resolve(t,e)}return e}async getDownloadUrl(e){return this.isLocal(e)?this._contents.getDownloadUrl(decodeURIComponent(e)):e}isLocal(e){return!this.isMalformed(e)&&(f.URLExt.isLocal(e)||!!this._contents.driveName(decodeURI(e)))}isMalformed(e){try{return decodeURI(e),!1}catch(e){if(e instanceof URIError)return!0;throw e}}},function(e){e.sortedTypes=function(e){return Object.keys(e).sort((t,n)=>{const r=e[t],i=e[n];return r.rank!==i.rank?r.rank-i.rank:r.id-i.id})},e.sessionConnection=function(e){return e.sessionChanged?e.session:e}}(l||(l={}));var y=n(70);const _={safe:!0,mimeTypes:["text/html"],defaultRank:50,createRenderer:e=>new y.a(e)},b={safe:!0,mimeTypes:["image/bmp","image/png","image/jpeg","image/gif"],defaultRank:90,createRenderer:e=>new y.b(e)},M={safe:!0,mimeTypes:["text/latex"],defaultRank:70,createRenderer:e=>new y.d(e)},w={safe:!0,mimeTypes:["text/markdown"],defaultRank:60,createRenderer:e=>new y.e(e)},A={safe:!1,mimeTypes:["image/svg+xml"],defaultRank:80,createRenderer:e=>new y.f(e)},C={safe:!0,mimeTypes:["text/plain","application/vnd.jupyter.stdout","application/vnd.jupyter.stderr"],defaultRank:120,createRenderer:e=>new y.g(e)},x=[_,w,M,A,b,{safe:!1,mimeTypes:["text/javascript","application/javascript"],defaultRank:110,createRenderer:e=>new y.c(e)},C];const E=[_,w,M,A,b,n(576).a,C];var L=n(15),S=n(6),T=n(3),O=n(4),I=n(148);class k{constructor(){this._cache=Object.create(null)}set(e,t,n){if(e in this._cache||(this._cache[e]=Object.create(null)),t in this._cache[e])throw`Version ${t} of key ${e} already registered.`;this._cache[e][t]=n}get(e,t){if(e in this._cache){let n=this._cache[e];return n[Object(I.maxSatisfying)(Object.keys(n),t)]}}}const D="application/vnd.jupyter.widget-view+json";class N extends T.Widget{constructor(e){super(),this._view=null,this._view=e,e.on("remove",()=>{this.dispose()}),this.addClass("jp-BackboneViewWrapper"),this.node.appendChild(e.el)}onAfterAttach(e){this._view.trigger("displayed")}dispose(){this._view=null,super.dispose()}}class j extends L.ManagerBase{constructor(e,t,n){var r,i;super(),this._registry=new k,this._restored=new O.Signal(this),this._restoredStatus=!1,this._initialRestoredStatus=!1,this._modelsSync=new Map,this._onUnhandledIOPubMessage=new O.Signal(this),this._context=e,this._rendermime=t,this._handleCommOpen=async(e,t)=>{let n=new L.shims.services.Comm(e);await this.handle_comm_open(n,t)},e.sessionContext.kernelChanged.connect((e,t)=>{this._handleKernelChanged(t)}),e.sessionContext.statusChanged.connect((e,t)=>{this._handleKernelStatusChange(t)}),e.sessionContext.connectionStatusChanged.connect((e,t)=>{this._handleKernelConnectionStatusChange(t)}),(null===(r=e.sessionContext.session)||void 0===r?void 0:r.kernel)&&this._handleKernelChanged({name:"kernel",oldValue:null,newValue:null===(i=e.sessionContext.session)||void 0===i?void 0:i.kernel}),this.restoreWidgets(this._context.model),this._settings=n,e.saveState.connect((e,t)=>{"started"===t&&n.saveState&&this._saveState()})}_saveState(){const e=this.get_state_sync({drop_defaults:!0});this._context.model.metadata.set("widgets",{"application/vnd.jupyter.widget-state+json":e})}callbacks(e){return{iopub:{output:e=>{this._onUnhandledIOPubMessage.emit(e)}}}}_handleKernelChanged({oldValue:e,newValue:t}){e&&e.removeCommTarget(this.comm_target_name,this._handleCommOpen),t&&t.registerCommTarget(this.comm_target_name,this._handleCommOpen)}_handleKernelConnectionStatusChange(e){"connected"===e&&this._initialRestoredStatus&&this.restoreWidgets(this._context.model,{loadKernel:!0,loadNotebook:!1})}_handleKernelStatusChange(e){"restarting"===e&&this.disconnect()}async restoreWidgets(e,{loadKernel:t,loadNotebook:n}={loadKernel:!0,loadNotebook:!0}){t&&await this._loadFromKernel(),n&&await this._loadFromNotebook(e),this._restoredStatus=!0,this._initialRestoredStatus=!0,this._restored.emit()}disconnect(){super.disconnect(),this._restoredStatus=!1}async _loadFromKernel(){var e;if(!this.context.sessionContext)return;if(await this.context.sessionContext.ready,!1===(null===(e=this.context.sessionContext.session)||void 0===e?void 0:e.kernel.handleComms))return;const t=await this._get_comm_info(),n=await Promise.all(Object.keys(t).map(async e=>{try{return void await this.get_model(e)}catch(t){if("widget model not found"!==t.message)throw t;const n=await this._create_comm(this.comm_target_name,e);let r;const i=new S.PromiseDelegate;return n.on_msg(e=>{if(e.parent_header.msg_id===r&&"comm_msg"===e.header.msg_type&&"update"===e.content.data.method){let t=e.content.data,r=t.buffer_paths||[],o=(e.buffers||[]).map(e=>e instanceof DataView?e:new DataView(e instanceof ArrayBuffer?e:e.buffer));Object(L.put_buffers)(t.state,r,o),i.resolve({comm:n,msg:e})}}),r=n.send({method:"request_state"},this.callbacks(void 0)),i.promise}}));await Promise.all(n.map(async e=>{if(!e)return;const t=e.msg.content;await this.new_model({model_name:t.data.state._model_name,model_module:t.data.state._model_module,model_module_version:t.data.state._model_module_version,comm:e.comm},t.data.state)}))}async _loadFromNotebook(e){const t=e.metadata.get("widgets");if(t&&t["application/vnd.jupyter.widget-state+json"]){let e=t["application/vnd.jupyter.widget-state+json"];e=this.filterExistingModelState(e),await this.set_state(e)}}async display_view(e,t,n){return t.pWidget||new N(t)}async _create_comm(e,t,n,r,i){var o;let a=null===(o=this._context.sessionContext.session)||void 0===o?void 0:o.kernel;if(!a)throw new Error("No current kernel");let s=a.createComm(e,t);return(n||r)&&s.open(n,r,i),new L.shims.services.Comm(s)}async _get_comm_info(){var e;let t=null===(e=this._context.sessionContext.session)||void 0===e?void 0:e.kernel;if(!t)throw new Error("No current kernel");const n=await t.requestCommInfo({target_name:this.comm_target_name});return"ok"===n.content.status?n.content.comms:{}}get isDisposed(){return null===this._context}dispose(){this.isDisposed||(this._commRegistration&&this._commRegistration.dispose(),this._context=null)}async resolveUrl(e){const t=await this.context.urlResolver.resolveUrl(e);return this.context.urlResolver.getDownloadUrl(t)}async loadClass(e,t,n){"@jupyter-widgets/base"!==t&&"@jupyter-widgets/controls"!==t||!Object(I.valid)(n)||(n="^"+n);const r=this._registry.get(t,n);if(!r)throw new Error(`Module ${t}, semver range ${n} is not registered as a widget module`);let i;i="function"==typeof r?await r():await r;const o=i[e];if(!o)throw new Error(`Class ${e} not found in module ${t}`);return o}get context(){return this._context}get rendermime(){return this._rendermime}get restored(){return this._restored}get restoredStatus(){return this._restoredStatus}get onUnhandledIOPubMessage(){return this._onUnhandledIOPubMessage}register(e){this._registry.set(e.name,e.version,e.exports)}async get_model(e){const t=super.get_model(e);if(void 0===t)throw new Error("widget model not found");return t}register_model(e,t){super.register_model(e,t),t.then(t=>{this._modelsSync.set(e,t),t.once("comm:close",()=>{this._modelsSync.delete(e)})}),this.setDirty()}async clear_state(){await super.clear_state(),this._modelsSync=new Map,this.setDirty()}get_state_sync(e={}){const t=[];for(let e of this._modelsSync.values())e.comm_live&&t.push(e);return Object(L.serialize_state)(t,e)}setDirty(){this._settings.saveState&&(this._context.model.dirty=!0)}}class P extends T.Panel{constructor(e,t){super(),this._manager=new S.PromiseDelegate,this._rerenderMimeModel=null,this.mimeType=e.mimeType,t&&(this.manager=t)}set manager(e){e.restored.connect(this._rerender,this),this._manager.resolve(e)}async renderModel(e){const t=e.data[this.mimeType];this.node.textContent="Loading widget...",this.addClass("jupyter-widgets");const n=await this._manager.promise;if(""===t.model_id)return this.hide(),Promise.resolve();let r,i;try{r=await n.get_model(t.model_id)}catch(t){return n.restoredStatus?(this.node.textContent="Error displaying widget: model not found",this.addClass("jupyter-widgets"),void console.error(t)):void(this._rerenderMimeModel=e)}this._rerenderMimeModel=null;try{i=await n.display_model(void 0,r,void 0)}catch(e){return this.node.textContent="Error displaying widget",this.addClass("jupyter-widgets"),void console.error(e)}this.node.textContent="",this.addWidget(i),i.disposed.connect(()=>{this.hide(),t.model_id=""})}get isDisposed(){return null===this._manager}dispose(){this.isDisposed||(super.dispose(),this._manager=null)}_rerender(){this._rerenderMimeModel&&(this.node.textContent="",this.removeClass("jupyter-widgets"),this.renderModel(this._rerenderMimeModel))}}const z=new S.Token("@jupyterlab/coreutils:ISettingRegistry"),R=(new S.Token("@jupyterlab/notebook:INotebookWidgetFactory"),new S.Token("@jupyterlab/notebook:INotebookTools"),new S.Token("@jupyterlab/notebook:INotebookTracker")),B=new S.Token("@jupyterlab/mainmenu:IMainMenu"),H=new S.Token("@jupyterlab/rendermime:IRenderMimeRegistry"),F=(new S.Token("@jupyterlab/rendermime:ILatexTypesetter"),new S.Token("@jupyterlab/logconsole:ILoggerRegistry"));var Y,V=n(2),U=n(27),W=n(43),G=(Y=function(e,t){return(Y=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}Y(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),q=function(){return(q=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},K=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return G(t,e),t.prototype.defaults=function(){return q(q({},e.prototype.defaults.call(this)),{_model_name:"OutputModel",_view_name:"OutputView",_model_module:"@jupyter-widgets/output",_view_module:"@jupyter-widgets/output",_model_module_version:"1.0.0",_view_module_version:"1.0.0"})},t}(L.DOMWidgetModel),X=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return G(t,e),t}(L.DOMWidgetView);function J(e){return"execute_result"===e.output_type}function Q(e){return"display_data"===e.output_type}function Z(e){return"stream"===e.output_type}var $,ee,te,ne=n(486),re=n(487);class ie{constructor(e){this._changed=new O.Signal(this),this._raw={};const{data:t,metadata:n,trusted:r}=ee.getBundleOptions(e);this._data=new re.a({values:t}),this._rawData=t,this._metadata=new re.a({values:n}),this._rawMetadata=n,this.trusted=r;const i=e.value;for(const e in i)switch(e){case"data":case"metadata":break;default:this._raw[e]=ee.extract(i,e)}this.type=i.output_type,J(i)?this.executionCount=i.execution_count:this.executionCount=null}get changed(){return this._changed}dispose(){this._data.dispose(),this._metadata.dispose(),O.Signal.clearData(this)}get data(){return this._rawData}get metadata(){return this._rawMetadata}setData(e){e.data&&(this._updateObservable(this._data,e.data),this._rawData=e.data),e.metadata&&(this._updateObservable(this._metadata,e.metadata),this._rawMetadata=e.metadata),this._changed.emit(void 0)}toJSON(){const e={};for(const t in this._raw)e[t]=ee.extract(this._raw,t);switch(this.type){case"display_data":case"execute_result":case"update_display_data":e.data=this.data,e.metadata=this.metadata}return delete e.transient,e}_updateObservable(e,t){const n=e.keys(),r=Object.keys(t);for(const t of n)-1===r.indexOf(t)&&e.delete(t);for(const n of r){const r=e.get(n),i=t[n];r!==i&&e.set(n,i)}}}($=ie||(ie={})).getData=function(e){return ee.getData(e)},$.getMetadata=function(e){return ee.getMetadata(e)},function(e){function t(e){let t={};if(J(e)||Q(e)||function(e){return"update_display_data"===e.output_type}(e))t=e.data;else if(Z(e))"stderr"===e.name?t["application/vnd.jupyter.stderr"]=e.text:t["application/vnd.jupyter.stdout"]=e.text;else if(function(e){return"error"===e.output_type}(e)){t["application/vnd.jupyter.error"]=e;const n=e.traceback.join("\n");t["application/vnd.jupyter.stderr"]=n||`${e.ename}: ${e.evalue}`}return function(e){const t=Object.create(null);for(const n in e)t[n]=r(e,n);return t}(t)}function n(e){const t=Object.create(null);if(J(e)||Q(e))for(const n in e.metadata)t[n]=r(e.metadata,n);return t}function r(e,t){const n=e[t];return void 0===n||S.JSONExt.isPrimitive(n)?n:JSON.parse(JSON.stringify(n))}e.getData=t,e.getMetadata=n,e.getBundleOptions=function(e){return{data:t(e.value),metadata:n(e.value),trusted:!!e.trusted}},e.extract=r}(ee||(ee={}));class oe{constructor(e={}){this.clearNext=!1,this._trusted=!1,this._isDisposed=!1,this._stateChanged=new O.Signal(this),this._changed=new O.Signal(this),this._trusted=!!e.trusted,this.contentFactory=e.contentFactory||oe.defaultContentFactory,this.list=new ne.a,e.values&&Object(V.each)(e.values,e=>{this._add(e)}),this.list.changed.connect(this._onListChanged,this)}get stateChanged(){return this._stateChanged}get changed(){return this._changed}get length(){return this.list?this.list.length:0}get trusted(){return this._trusted}set trusted(e){if(e===this._trusted)return;const t=this._trusted=e;for(let e=0;e<this.list.length;e++){let n=this.list.get(e);const r=n.toJSON();n.dispose(),n=this._createItem({value:r,trusted:t}),this.list.set(e,n)}}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,this.list.dispose(),O.Signal.clearData(this))}get(e){return this.list.get(e)}set(e,t){t=S.JSONExt.deepCopy(t),te.normalize(t);const n=this._createItem({value:t,trusted:this._trusted});this.list.set(e,n)}add(e){return this.clearNext&&(this.clear(),this.clearNext=!1),this._add(e)}clear(e=!1){this._lastStream="",e?this.clearNext=!0:(Object(V.each)(this.list,e=>{e.dispose()}),this.list.clear())}fromJSON(e){this.clear(),Object(V.each)(e,e=>{this._add(e)})}toJSON(){return Object(V.toArray)(Object(V.map)(this.list,e=>e.toJSON()))}_add(e){const t=this._trusted;if(e=S.JSONExt.deepCopy(e),te.normalize(e),Z(e)&&this._lastStream&&e.name===this._lastName&&this.shouldCombine({value:e,lastModel:this.list.get(this.length-1)})){this._lastStream+=e.text,this._lastStream=te.removeOverwrittenChars(this._lastStream),e.text=this._lastStream;const n=this._createItem({value:e,trusted:t}),r=this.length-1;return this.list.get(r).dispose(),this.list.set(r,n),r}Z(e)&&(e.text=te.removeOverwrittenChars(e.text));const n=this._createItem({value:e,trusted:t});return Z(e)?(this._lastStream=e.text,this._lastName=e.name):this._lastStream="",this.list.push(n)}shouldCombine(e){return!0}_createItem(e){const t=this.contentFactory.createOutputModel(e);return t.changed.connect(this._onGenericChange,this),t}_onListChanged(e,t){this._changed.emit(t)}_onGenericChange(){this._stateChanged.emit(void 0)}}!function(e){class t{createOutputModel(e){return new ie(e)}}e.ContentFactory=t,e.defaultContentFactory=new t}(oe||(oe={})),function(e){e.normalize=function(e){Z(e)&&Array.isArray(e.text)&&(e.text=e.text.join("\n"))},e.removeOverwrittenChars=function(e){return function(e){for(e=e.replace(/\r+\n/gm,"\n");e.search(/\r[^$]/g)>-1;){const t=e.match(/^(.*)\r+/m)[1];let n=e.match(/\r+(.*)$/m)[1];n+=t.slice(n.length,t.length),e=e.replace(/\r+.*$/m,"\r").replace(/^.*\r/m,n)}return e}(function(e){let t=e;do{t=(e=t).replace(/[^\n]\x08/gm,"")}while(t.length<e.length);return e}(e))}}(te||(te={}));var ae=n(139),se=n(38),le=n(146);class ce extends T.Widget{constructor(e){super(),this.outputLengthChanged=new O.Signal(this),this._onIOPub=e=>{const t=this.model,n=e.header.msg_type;let r;const i=(e.content.transient||{}).display_id;let o;switch(n){case"execute_result":case"display_data":case"stream":case"error":r=Object.assign(Object.assign({},e.content),{output_type:n}),t.add(r);break;case"clear_output":{const n=e.content.wait;t.clear(n);break}case"update_display_data":if(r=Object.assign(Object.assign({},e.content),{output_type:"display_data"}),o=this._displayIdMap.get(i),o)for(const e of o)t.set(e,r)}i&&"display_data"===n&&(o=this._displayIdMap.get(i)||[],o.push(t.length-1),this._displayIdMap.set(i,o))},this._onExecuteReply=e=>{const t=this.model,n=e.content;if("ok"!==n.status)return;const r=n&&n.payload;if(!r||!r.length)return;const i=r.filter(e=>"page"===e.source);if(!i.length)return;const o={output_type:"display_data",data:JSON.parse(JSON.stringify(i[0])).data,metadata:{}};t.add(o)},this._minHeightTimeout=null,this._displayIdMap=new Map,this._outputTracker=new ae.a({namespace:S.UUID.uuid4()});const t=this.model=e.model;this.addClass("jp-OutputArea"),this.rendermime=e.rendermime,this.contentFactory=e.contentFactory||ce.defaultContentFactory,this.layout=new T.PanelLayout,this.trimmedOutputModels=new Array,this.maxNumberOutputs=e.maxNumberOutputs||0,this.headEndIndex=this.maxNumberOutputs;for(let e=0;e<t.length;e++){const n=t.get(e);this._insertOutput(e,n)}t.changed.connect(this.onModelChanged,this),t.stateChanged.connect(this.onStateChanged,this)}get widgets(){return this.layout.widgets}get future(){return this._future}set future(e){if(this.model.isDisposed)throw Error("Model is disposed");this._future!==e&&(this._future&&this._future.dispose(),this._future=e,this.model.clear(),this.widgets.length&&(this._clear(),this.outputLengthChanged.emit(this.model.length)),e.onIOPub=this._onIOPub,e.onReply=this._onExecuteReply,e.onStdin=t=>{se.KernelMessage.isInputRequestMsg(t)&&this.onInputRequest(t,e)})}dispose(){this._future&&(this._future.dispose(),this._future=null),this._displayIdMap.clear(),this._outputTracker.dispose(),super.dispose()}onModelChanged(e,t){switch(t.type){case"add":this._insertOutput(t.newIndex,t.newValues[0]),this.outputLengthChanged.emit(this.model.length);break;case"remove":if(this.widgets.length){if(0===this.model.length)this._clear();else{const e=t.oldIndex;for(let n=0;n<t.oldValues.length&&e<this.widgets.length;++n){const t=this.widgets[e];t.parent=null,t.dispose()}this._moveDisplayIdIndices(e,t.oldValues.length),this._preventHeightChangeJitter()}this.outputLengthChanged.emit(this.model.length)}break;case"set":this._setOutput(t.newIndex,t.newValues[0]),this.outputLengthChanged.emit(this.model.length)}}_moveDisplayIdIndices(e,t){this._displayIdMap.forEach(n=>{const r=e+t;for(let i=n.length-1;i>=0;--i){const o=n[i];o>=e&&o<r?n.splice(i,1):o>=r&&(n[i]-=t)}})}onStateChanged(e){this.trimmedOutputModels=new Array;for(let e=0;e<this.model.length;e++)this._setOutput(e,this.model.get(e));this.outputLengthChanged.emit(this.model.length)}_clear(){if(!this.widgets.length)return;const e=this.widgets.length;for(let t=0;t<e;t++){const e=this.widgets[0];e.parent=null,e.dispose()}this._displayIdMap.clear(),this._preventHeightChangeJitter()}_preventHeightChangeJitter(){const e=this.node.getBoundingClientRect();this.node.style.minHeight=e.height+"px",this._minHeightTimeout&&window.clearTimeout(this._minHeightTimeout),this._minHeightTimeout=window.setTimeout(()=>{this.isDisposed||(this.node.style.minHeight="")},50)}onInputRequest(e,t){const n=this.contentFactory,r=e.content.prompt,i=e.content.password,o=new T.Panel;o.addClass("jp-OutputArea-child"),o.addClass("jp-OutputArea-stdin-item");const a=n.createOutputPrompt();a.addClass("jp-OutputArea-prompt"),o.addWidget(a);const s=n.createStdin({prompt:r,password:i,future:t});s.addClass("jp-OutputArea-output"),o.addWidget(s);this.layout.addWidget(o),s.value.then(e=>{this.model.add({output_type:"stream",name:"stdin",text:e+"\n"}),o.dispose()})}_setOutput(e,t){if(e>=this.headEndIndex&&0!==this.maxNumberOutputs)return void(this.trimmedOutputModels[e-this.headEndIndex]=t);const n=this.layout,r=n.widgets[e],i=r.widgets?r.widgets[1]:r,o=this.rendermime.preferredMimeType(t.data,t.trusted?"any":"ensure");i.renderModel&&pe.currentPreferredMimetype.get(i)===o&&ce.isIsolated(o,t.metadata)===i instanceof pe.IsolatedRenderer?i.renderModel(t):(n.widgets[e].dispose(),this._insertOutput(e,t))}_insertOutput(e,t){if(0===e&&(this.trimmedOutputModels=new Array),e===this.maxNumberOutputs&&0!==this.maxNumberOutputs){const e=this.model.contentFactory.createOutputModel({value:{output_type:"display_data",data:{"text/html":`\n              <a style="margin: 10px; text-decoration: none; cursor: pointer;">\n                <pre>Output of this cell has been trimmed on the initial display.</pre>\n                <pre>Displaying the first ${this.maxNumberOutputs} top outputs.</pre>\n                <pre>Click on this message to get the complete output.</pre>\n              </a>\n              `}}}),t=()=>this._showTrimmedOutputs(),n=this.createOutputItem(e);n.node.addEventListener("click",t);this.layout.insertWidget(this.headEndIndex,n)}const n=this._createOutput(t),r=this.layout;(e<this.maxNumberOutputs||0===this.maxNumberOutputs)&&r.insertWidget(e,n),e>=this.maxNumberOutputs&&0!==this.maxNumberOutputs&&this.trimmedOutputModels.push(t),this._outputTracker.has(n)||this._outputTracker.add(n)}_createOutput(e){let t=this.createOutputItem(e);return t?t.toggleClass("jp-OutputArea-executeResult",null!==e.executionCount):t=new T.Widget,t}get outputTracker(){return this._outputTracker}_showTrimmedOutputs(){const e=this.layout;e.removeWidgetAt(this.headEndIndex);for(let t=0;t<this.trimmedOutputModels.length;t++){const n=this._createOutput(this.trimmedOutputModels[t]);e.insertWidget(this.headEndIndex+t,n)}}createOutputItem(e){const t=this.createRenderedMimetype(e);if(!t)return null;const n=new pe.OutputPanel;n.addClass("jp-OutputArea-child");const r=this.contentFactory.createOutputPrompt();return r.executionCount=e.executionCount,r.addClass("jp-OutputArea-prompt"),n.addWidget(r),t.addClass("jp-OutputArea-output"),n.addWidget(t),n}createRenderedMimetype(e){const t=this.rendermime.preferredMimeType(e.data,e.trusted?"any":"ensure");if(!t)return null;let n=this.rendermime.createRenderer(t);return!0===ce.isIsolated(t,e.metadata)&&(n=new pe.IsolatedRenderer(n)),pe.currentPreferredMimetype.set(n,t),n.renderModel(e).catch(e=>{const t=document.createElement("pre");t.textContent="Javascript Error: "+e.message,n.node.appendChild(t),n.node.className="lm-Widget jp-RenderedText",n.node.setAttribute("data-mime-type","application/vnd.jupyter.stderr")}),n}}class ue extends ce{onInputRequest(e,t){}createOutputItem(e){const t=this.createRenderedMimetype(e);return t&&t.addClass("jp-OutputArea-output"),t}}!function(e){e.execute=async function(e,t,n,r){var i;let o=!0;r&&Array.isArray(r.tags)&&-1!==r.tags.indexOf("raises-exception")&&(o=!1);const a={code:e,stop_on_error:o},s=null===(i=n.session)||void 0===i?void 0:i.kernel;if(!s)throw new Error("Session has no kernel.");const l=s.requestExecute(a,!1,r);return t.future=l,l.done},e.isIsolated=function(e,t){const n=t[e];return n&&void 0!==n.isolated?!!n.isolated:!!t.isolated};class t{createOutputPrompt(){return new de}createStdin(e){return new he(e)}}e.ContentFactory=t,e.defaultContentFactory=new t}(ce||(ce={}));class de extends T.Widget{constructor(){super(),this._executionCount=null,this.addClass("jp-OutputPrompt")}get executionCount(){return this._executionCount}set executionCount(e){this._executionCount=e,this.node.textContent=null===e?"":`[${e}]:`}}class he extends T.Widget{constructor(e){super({node:pe.createInputWidgetNode(e.prompt,e.password)}),this._promise=new S.PromiseDelegate,this.addClass("jp-Stdin"),this._input=this.node.getElementsByTagName("input")[0],this._input.focus(),this._future=e.future,this._value=e.prompt+" "}get value(){return this._promise.promise.then(()=>this._value)}handleEvent(e){const t=this._input;"keydown"===e.type&&13===e.keyCode&&(this._future.sendInputReply({status:"ok",value:t.value}),"password"===t.type?this._value+=Array(t.value.length+1).join("·"):this._value+=t.value,this._promise.resolve(void 0))}onAfterAttach(e){this._input.addEventListener("keydown",this),this.update()}onUpdateRequest(e){this._input.focus()}onBeforeDetach(e){this._input.removeEventListener("keydown",this)}}var pe;!function(e){e.createInputWidgetNode=function(e,t){const n=document.createElement("div"),r=document.createElement("pre");r.className="jp-Stdin-prompt",r.textContent=e;const i=document.createElement("input");return i.className="jp-Stdin-input",t&&(i.type="password"),n.appendChild(r),r.appendChild(i),n};class t extends T.Widget{constructor(e){super({node:document.createElement("iframe")}),this.addClass("jp-mod-isolated"),this._wrapped=e;const t=this.node;t.frameBorder="0",t.scrolling="auto",t.addEventListener("load",()=>{t.contentDocument.open(),t.contentDocument.write(this._wrapped.node.innerHTML),t.contentDocument.close();const e=t.contentDocument.body;t.style.height=e.scrollHeight+"px",t.heightChangeObserver=new le.a(()=>{t.style.height=e.scrollHeight+"px"}),t.heightChangeObserver.observe(e)})}renderModel(e){return this._wrapped.renderModel(e)}}e.IsolatedRenderer=t,e.currentPreferredMimetype=new W.AttachedProperty({name:"preferredMimetype",create:e=>""});class n extends T.Panel{constructor(e){super(e)}_onContext(e){this.node.focus()}onAfterAttach(e){super.onAfterAttach(e),this.node.addEventListener("contextmenu",this._onContext.bind(this))}onBeforeDetach(e){super.onAfterDetach(e),this.node.removeEventListener("contextmenu",this._onContext.bind(this))}}e.OutputPanel=n}(pe||(pe={}));var fe=n(41),me=n.n(fe);const ge="1.0.0";class ve extends K{defaults(){return Object.assign(Object.assign({},super.defaults()),{msg_id:"",outputs:[]})}initialize(e,t){super.initialize(e,t),this._outputs=new oe({trusted:!0}),this._msgHook=e=>(this.add(e),!1),this.widget_manager.context.sessionContext.kernelChanged.connect((e,t)=>{this._handleKernelChanged(t)}),this.listenTo(this,"change:msg_id",this.reset_msg_id),this.listenTo(this,"change:outputs",this.setOutputs),this.setOutputs()}_handleKernelChanged({oldValue:e}){const t=this.get("msg_id");t&&e&&(e.removeMessageHook(t,this._msgHook),this.set("msg_id",null))}reset_msg_id(){const e=this.widget_manager.context.sessionContext.session.kernel,t=this.get("msg_id"),n=this.previous("msg_id");n&&e&&e.removeMessageHook(n,this._msgHook),t&&e&&e.registerMessageHook(t,this._msgHook)}add(e){let t=e.header.msg_type;switch(t){case"execute_result":case"display_data":case"stream":case"error":let n=e.content;n.output_type=t,this._outputs.add(n);break;case"clear_output":this.clear_output(e.content.wait)}this.set("outputs",this._outputs.toJSON(),{newMessage:!0}),this.save_changes()}clear_output(e=!1){this._outputs.clear(e)}get outputs(){return this._outputs}setOutputs(e,t,n){n&&n.newMessage||(this.clear_output(),this._outputs.fromJSON(JSON.parse(JSON.stringify(this.get("outputs")))))}}class ye extends T.Panel{constructor(e){let t=e.view;delete e.view,super(e),this._view=t}processMessage(e){super.processMessage(e),this._view.processPhosphorMessage(e)}dispose(){this.isDisposed||(super.dispose(),this._view&&this._view.remove(),this._view=null)}}class _e extends X{_createElement(e){return this.pWidget=new ye({view:this}),this.pWidget.node}_setElement(e){if(this.el||e!==this.pWidget.node)throw new Error("Cannot reset the DOM element.");this.el=this.pWidget.node,this.$el=me()(this.pWidget.node)}render(){super.render(),this._outputView=new ce({rendermime:this.model.widget_manager.rendermime,contentFactory:ce.defaultContentFactory,model:this.model.outputs}),this.pWidget.insertWidget(0,this._outputView),this.pWidget.addClass("jupyter-widgets"),this.pWidget.addClass("widget-output"),this.update()}remove(){return this._outputView.dispose(),super.remove()}}var be=n(48),Me=n(201),we={insert:"head",singleton:!1},Ae=(u()(Me.a,we),Me.a.locals,n(202)),Ce={insert:"head",singleton:!1};u()(Ae.a,Ce),Ae.a.locals;const xe=[],Ee={saveState:!1};function*Le(e){for(let t of e.widgets)if("code"===t.model.type)for(let e of t.outputArea.widgets)for(let t of Object(V.toArray)(e.children()))t instanceof P&&(yield t)}function*Se(e,t){let n=Object(V.filter)(e.shell.widgets(),e=>e.id.startsWith("LinkedOutputView-")&&e.path===t);for(let e of Object(V.toArray)(n))for(let t of Object(V.toArray)(e.children()))for(let e of Object(V.toArray)(t.children()))e instanceof P&&(yield e)}function*Te(...e){for(let t of e)yield*t}function Oe(e,t,n){let r=ke.widgetManagerProperty.get(e);r||(r=new j(e,t,Ee),xe.forEach(e=>r.register(e)),ke.widgetManagerProperty.set(e,r));for(let e of n)e.manager=r;return t.removeMimeType(D),t.addFactory({safe:!1,mimeTypes:[D],createRenderer:e=>new P(e,r)},0),new U.DisposableDelegate(()=>{t&&t.removeMimeType(D),r.dispose()})}const Ie={id:"@jupyter-widgets/jupyterlab-manager:plugin",requires:[H,z],optional:[R,B,F],provides:L.IJupyterWidgetRegistry,activate:function(e,t,r,i,o,a){const{commands:s}=e,l=e=>{if(!a)return;const t=ke.widgetManagerProperty.get(e.context);t&&t.onUnhandledIOPubMessage.connect((t,n)=>{const r=a.getLogger(e.context.path);let i="warning";(se.KernelMessage.isErrorMsg(n)||se.KernelMessage.isStreamMsg(n)&&"stderr"===n.content.name)&&(i="error");const o=Object.assign(Object.assign({},n.content),{output_type:n.header.msg_type});r.rendermime=e.content.rendermime,r.log({type:"output",data:o,level:i})})};r.load(Ie.id).then(e=>{e.changed.connect(De),De(e)}).catch(e=>{console.error(e.message)}),t.addFactory({safe:!1,mimeTypes:[D],createRenderer:e=>new P(e)},0),i&&(i.forEach(t=>{Oe(t.context,t.content.rendermime,Te(Le(t.content),Se(e,t.context.path))),l(t)}),i.widgetAdded.connect((t,n)=>{Oe(n.context,n.content.rendermime,Te(Le(n.content),Se(e,n.context.path))),l(n)}));s.addCommand("@jupyter-widgets/jupyterlab-manager:saveWidgetState",{label:"Save Widget State Automatically",execute:e=>r.set(Ie.id,"saveState",!Ee.saveState).catch(e=>{console.error(`Failed to set ${Ie.id}: ${e.message}`)}),isToggled:()=>Ee.saveState}),o&&o.settingsMenu.addGroup([{command:"@jupyter-widgets/jupyterlab-manager:saveWidgetState"}]);return xe.push({name:"@jupyter-widgets/base",version:L.JUPYTER_WIDGETS_VERSION,exports:{WidgetModel:L.WidgetModel,WidgetView:L.WidgetView,DOMWidgetView:L.DOMWidgetView,DOMWidgetModel:L.DOMWidgetModel,LayoutModel:L.LayoutModel,LayoutView:L.LayoutView,StyleModel:L.StyleModel,StyleView:L.StyleView}}),xe.push({name:"@jupyter-widgets/controls",version:be.a,exports:()=>new Promise((e,t)=>{Promise.resolve().then((t=>{e(n(149))}).bind(null,n)).catch(e=>{t(e)})})}),xe.push({name:"@jupyter-widgets/output",version:ge,exports:{OutputModel:ve,OutputView:_e}}),{registerWidget(e){xe.push(e)}}},autoStart:!0};var ke;function De(e){Ee.saveState=e.get("saveState").composite}!function(e){e.widgetManagerProperty=new W.AttachedProperty({name:"widgetManager",create:()=>{}})}(ke||(ke={}));var Ne=n(149),je=n(32);const Pe=async function(e,t,n){const r=(n=n||m.b).load("jupyterlab"),i=r.__("Server Connection Error"),o=r.__("A connection to the Jupyter server could not be established.\nJupyterLab will continue trying to reconnect.\nCheck your network connection or Jupyter server configuration.\n");return Object(je.c)(i,{message:o})};var ze=n(414),Re=n(54),Be=n(415),He=n(1012),Fe=n(101),Ye=n(1013);class Ve extends He.a.Model{constructor(e,t){super({modelDB:t}),this._defaultLang="",this._readOnly=!1,this._contentChanged=new O.Signal(this),this._stateChanged=new O.Signal(this),this._defaultLang=e||"";const n=new Ye.a;this.switchSharedModel(n,!0),this.value.changed.connect(this.triggerContentChange,this),this.sharedModel.dirty=!1,this.sharedModel.changed.connect(this._onStateChanged,this)}get contentChanged(){return this._contentChanged}get stateChanged(){return this._stateChanged}get dirty(){return this.sharedModel.dirty}set dirty(e){e!==this.dirty&&(this.sharedModel.dirty=e)}get readOnly(){return this._readOnly}set readOnly(e){if(e===this._readOnly)return;const t=this._readOnly;this._readOnly=e,this.triggerStateChange({name:"readOnly",oldValue:t,newValue:e})}get defaultKernelName(){return""}get defaultKernelLanguage(){return this._defaultLang}toString(){return this.value.text}fromString(e){this.value.text=e}toJSON(){return JSON.parse(this.value.text||"null")}fromJSON(e){this.fromString(JSON.stringify(e))}initialize(){}triggerStateChange(e){this._stateChanged.emit(e)}triggerContentChange(){this._contentChanged.emit(void 0),this.dirty=!0}_onStateChanged(e,t){t.stateChange&&t.stateChange.forEach(e=>{"dirty"===e.name&&e.oldValue===e.newValue||this.triggerStateChange(e)})}}class Ue{constructor(){this._isDisposed=!1}get name(){return"text"}get contentType(){return"file"}get fileFormat(){return"text"}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed=!0}createNew(e,t,n){return new Ve(e,t)}preferredLanguage(e){const t=Fe.b.findByFileName(e);return t&&t.mode}}class We extends Ue{get name(){return"base64"}get contentType(){return"file"}get fileFormat(){return"base64"}}class Ge{constructor(e){this._isDisposed=!1,this._widgetCreated=new O.Signal(this),this._translator=e.translator||m.b,this._name=e.name,this._readOnly=void 0!==e.readOnly&&e.readOnly,this._defaultFor=e.defaultFor?e.defaultFor.slice():[],this._defaultRendered=(e.defaultRendered||[]).slice(),this._fileTypes=e.fileTypes.slice(),this._modelName=e.modelName||"text",this._preferKernel=!!e.preferKernel,this._canStartKernel=!!e.canStartKernel,this._shutdownOnClose=!!e.shutdownOnClose,this._toolbarFactory=e.toolbarFactory}get widgetCreated(){return this._widgetCreated}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,O.Signal.clearData(this))}get readOnly(){return this._readOnly}get name(){return this._name}get fileTypes(){return this._fileTypes.slice()}get modelName(){return this._modelName}get defaultFor(){return this._defaultFor.slice()}get defaultRendered(){return this._defaultRendered.slice()}get preferKernel(){return this._preferKernel}get canStartKernel(){return this._canStartKernel}get translator(){return this._translator}get shutdownOnClose(){return this._shutdownOnClose}set shutdownOnClose(e){this._shutdownOnClose=e}createNew(e,t){const n=this.createNewWidget(e,t);let r;return r=this._toolbarFactory?this._toolbarFactory(n):this.defaultToolbarFactory(n),r.forEach(({name:e,widget:t})=>{n.toolbar.addItem(e,t)}),this._widgetCreated.emit(n),n}defaultToolbarFactory(e){return[]}}class qe extends Be.a{constructor(e){e.reveal=Promise.all([e.reveal,e.context.ready]),super(e),this.context=e.context,this.context.pathChanged.connect(this._onPathChanged,this),this._onPathChanged(this.context,this.context.path),this.context.model.stateChanged.connect(this._onModelStateChanged,this),this.context.ready.then(()=>{this._handleDirtyState()}),this.title.changed.connect(this._onTitleChanged,this)}setFragment(e){}async _onTitleChanged(e){const t=this.title.label,n=this.context.path.split("/").pop();if(t!==n){if(t.length>0&&!/[\/\\:]/.test(t)){const e=this.context.path;if(await this.context.rename(t),this.context.path!==e)return}this.title.label=n}}_onPathChanged(e,t){this.title.label=f.PathExt.basename(e.localPath)}_onModelStateChanged(e,t){"dirty"===t.name&&this._handleDirtyState()}_handleDirtyState(){this.context.model.dirty&&!this.title.className.includes("jp-mod-dirty")?this.title.className+=" jp-mod-dirty":this.title.className=this.title.className.replace("jp-mod-dirty","")}}class Ke{constructor(e={}){this._modelFactories=Object.create(null),this._widgetFactories=Object.create(null),this._defaultWidgetFactory="",this._defaultWidgetFactoryOverrides=Object.create(null),this._defaultWidgetFactories=Object.create(null),this._defaultRenderedWidgetFactories=Object.create(null),this._widgetFactoriesForFileType=Object.create(null),this._fileTypes=[],this._extenders=Object.create(null),this._changed=new O.Signal(this),this._isDisposed=!1;const t=e.textModelFactory;if(this.translator=e.translator||m.b,t&&"text"!==t.name)throw new Error("Text model factory must have the name `text`");this._modelFactories.text=t||new Ue;(e.initialFileTypes||Ke.getDefaultFileTypes(this.translator)).forEach(e=>{const t=Object.assign(Object.assign({},Ke.getFileTypeDefaults(this.translator)),e);this._fileTypes.push(t)})}get changed(){return this._changed}get isDisposed(){return this._isDisposed}dispose(){if(!this.isDisposed){this._isDisposed=!0;for(const e in this._modelFactories)this._modelFactories[e].dispose();for(const e in this._widgetFactories)this._widgetFactories[e].dispose();for(const e in this._extenders)this._extenders[e].length=0;this._fileTypes.length=0,O.Signal.clearData(this)}}addWidgetFactory(e){const t=e.name.toLowerCase();if(!t||"default"===t)throw Error("Invalid factory name");if(this._widgetFactories[t])return console.warn("Duplicate registered factory "+t),new U.DisposableDelegate(Xe.noOp);this._widgetFactories[t]=e;for(const n of e.defaultFor||[])-1!==e.fileTypes.indexOf(n)&&("*"===n?this._defaultWidgetFactory=t:this._defaultWidgetFactories[n]=t);for(const n of e.defaultRendered||[])-1!==e.fileTypes.indexOf(n)&&(this._defaultRenderedWidgetFactories[n]=t);for(const n of e.fileTypes)this._widgetFactoriesForFileType[n]||(this._widgetFactoriesForFileType[n]=[]),this._widgetFactoriesForFileType[n].push(t);return this._changed.emit({type:"widgetFactory",name:t,change:"added"}),new U.DisposableDelegate(()=>{delete this._widgetFactories[t],this._defaultWidgetFactory===t&&(this._defaultWidgetFactory="");for(const e of Object.keys(this._defaultWidgetFactories))this._defaultWidgetFactories[e]===t&&delete this._defaultWidgetFactories[e];for(const e of Object.keys(this._defaultRenderedWidgetFactories))this._defaultRenderedWidgetFactories[e]===t&&delete this._defaultRenderedWidgetFactories[e];for(const e of Object.keys(this._widgetFactoriesForFileType))V.ArrayExt.removeFirstOf(this._widgetFactoriesForFileType[e],t),0===this._widgetFactoriesForFileType[e].length&&delete this._widgetFactoriesForFileType[e];for(const e of Object.keys(this._defaultWidgetFactoryOverrides))this._defaultWidgetFactoryOverrides[e]===t&&delete this._defaultWidgetFactoryOverrides[e];this._changed.emit({type:"widgetFactory",name:t,change:"removed"})})}addModelFactory(e){const t=e.name.toLowerCase();return this._modelFactories[t]?(console.warn("Duplicate registered factory "+t),new U.DisposableDelegate(Xe.noOp)):(this._modelFactories[t]=e,this._changed.emit({type:"modelFactory",name:t,change:"added"}),new U.DisposableDelegate(()=>{delete this._modelFactories[t],this._changed.emit({type:"modelFactory",name:t,change:"removed"})}))}addWidgetExtension(e,t){(e=e.toLowerCase())in this._extenders||(this._extenders[e]=[]);const n=this._extenders[e];return-1!==V.ArrayExt.firstIndexOf(n,t)?(console.warn("Duplicate registered extension for "+e),new U.DisposableDelegate(Xe.noOp)):(this._extenders[e].push(t),this._changed.emit({type:"widgetExtension",name:e,change:"added"}),new U.DisposableDelegate(()=>{V.ArrayExt.removeFirstOf(this._extenders[e],t),this._changed.emit({type:"widgetExtension",name:e,change:"removed"})}))}addFileType(e){const t=Object.assign(Object.assign(Object.assign({},Ke.getFileTypeDefaults(this.translator)),e),!(e.icon||e.iconClass)&&{icon:Re.j});return this._fileTypes.push(t),this._changed.emit({type:"fileType",name:t.name,change:"added"}),new U.DisposableDelegate(()=>{V.ArrayExt.removeFirstOf(this._fileTypes,t),this._changed.emit({type:"fileType",name:e.name,change:"removed"})})}preferredWidgetFactories(e){const t=new Set,n=this.getFileTypesForPath(f.PathExt.basename(e));n.forEach(e=>{e.name in this._defaultWidgetFactoryOverrides&&t.add(this._defaultWidgetFactoryOverrides[e.name])}),n.forEach(e=>{e.name in this._defaultWidgetFactories&&t.add(this._defaultWidgetFactories[e.name])}),n.forEach(e=>{e.name in this._defaultRenderedWidgetFactories&&t.add(this._defaultRenderedWidgetFactories[e.name])}),this._defaultWidgetFactory&&t.add(this._defaultWidgetFactory),n.forEach(e=>{e.name in this._widgetFactoriesForFileType&&Object(V.each)(this._widgetFactoriesForFileType[e.name],e=>{t.add(e)})}),"*"in this._widgetFactoriesForFileType&&Object(V.each)(this._widgetFactoriesForFileType["*"],e=>{t.add(e)});const r=[];return t.forEach(e=>{const t=this._widgetFactories[e];if(!t)return;(t.modelName||"text")in this._modelFactories&&r.push(t)}),r}defaultRenderedWidgetFactory(e){const t=this.getFileTypesForPath(f.PathExt.basename(e));let n=void 0;for(const e of t)if(e.name in this._defaultRenderedWidgetFactories){n=this._widgetFactories[this._defaultRenderedWidgetFactories[e.name]];break}return n||this.defaultWidgetFactory(e)}defaultWidgetFactory(e){return e?this.preferredWidgetFactories(e)[0]:this._widgetFactories[this._defaultWidgetFactory]}setDefaultWidgetFactory(e,t){if(e=e.toLowerCase(),!this.getFileType(e))throw Error("Cannot find file type "+e);if(!t)return void(this._defaultWidgetFactoryOverrides[e]&&delete this._defaultWidgetFactoryOverrides[e]);if(!this.getWidgetFactory(t))throw Error("Cannot find widget factory "+t);t=t.toLowerCase();const n=this._widgetFactoriesForFileType[e];if(!(t===this._defaultWidgetFactory||n&&n.includes(t)))throw Error(`Factory ${t} cannot view file type ${e}`);this._defaultWidgetFactoryOverrides[e]=t}widgetFactories(){return Object(V.map)(Object.keys(this._widgetFactories),e=>this._widgetFactories[e])}modelFactories(){return Object(V.map)(Object.keys(this._modelFactories),e=>this._modelFactories[e])}widgetExtensions(e){return(e=e.toLowerCase())in this._extenders?new V.ArrayIterator(this._extenders[e]):Object(V.empty)()}fileTypes(){return new V.ArrayIterator(this._fileTypes)}getWidgetFactory(e){return this._widgetFactories[e.toLowerCase()]}getModelFactory(e){return this._modelFactories[e.toLowerCase()]}getFileType(e){return e=e.toLowerCase(),Object(V.find)(this._fileTypes,t=>t.name.toLowerCase()===e)}getKernelPreference(e,t,n){t=t.toLowerCase();const r=this._widgetFactories[t];if(!r)return;const i=this.getModelFactory(r.modelName||"text");if(!i)return;const o=i.preferredLanguage(f.PathExt.basename(e)),a=n&&n.name;return{id:n&&n.id,name:a,language:o,shouldStart:r.preferKernel,canStart:r.canStartKernel,shutdownOnDispose:r.shutdownOnClose}}getFileTypeForModel(e){switch(e.type){case"directory":return Object(V.find)(this._fileTypes,e=>"directory"===e.contentType)||Ke.getDefaultDirectoryFileType(this.translator);case"notebook":return Object(V.find)(this._fileTypes,e=>"notebook"===e.contentType)||Ke.getDefaultNotebookFileType(this.translator);default:if(e.name||e.path){const t=e.name||f.PathExt.basename(e.path),n=this.getFileTypesForPath(t);if(n.length>0)return n[0]}return this.getFileType("text")||Ke.getDefaultTextFileType(this.translator)}}getFileTypesForPath(e){const t=[],n=f.PathExt.basename(e);let r=Object(V.find)(this._fileTypes,e=>!(!e.pattern||null===n.match(e.pattern)));r&&t.push(r);let i=Xe.extname(n);for(;i.length>1;)r=Object(V.find)(this._fileTypes,e=>-1!==e.extensions.map(e=>e.toLowerCase()).indexOf(i)),r&&t.push(r),i="."+i.split(".").slice(2).join(".");return t}}var Xe;!function(e){function t(e){return{name:"default",displayName:(null==(e=e||m.b)?void 0:e.load("jupyterlab")).__("default"),extensions:[],mimeTypes:[],contentType:"file",fileFormat:"text"}}function n(e){const n=null==(e=e||m.b)?void 0:e.load("jupyterlab"),r=t(e);return Object.assign(Object.assign({},r),{name:"text",displayName:n.__("Text"),mimeTypes:["text/plain"],extensions:[".txt"],icon:Re.j})}function r(e){const n=null==(e=e||m.b)?void 0:e.load("jupyterlab");return Object.assign(Object.assign({},t(e)),{name:"notebook",displayName:n.__("Notebook"),mimeTypes:["application/x-ipynb+json"],extensions:[".ipynb"],contentType:"notebook",fileFormat:"json",icon:Re.r})}function i(e){const n=null==(e=e||m.b)?void 0:e.load("jupyterlab");return Object.assign(Object.assign({},t(e)),{name:"directory",displayName:n.__("Directory"),extensions:[],mimeTypes:["text/directory"],contentType:"directory",icon:Re.k})}e.getFileTypeDefaults=t,e.getDefaultTextFileType=n,e.getDefaultNotebookFileType=r,e.getDefaultDirectoryFileType=i,e.getDefaultFileTypes=function(e){const t=null==(e=e||m.b)?void 0:e.load("jupyterlab");return[n(e),r(e),i(e),{name:"markdown",displayName:t.__("Markdown File"),extensions:[".md"],mimeTypes:["text/markdown"],icon:Re.q},{name:"PDF",displayName:t.__("PDF File"),extensions:[".pdf"],mimeTypes:["application/pdf"],icon:Re.t},{name:"python",displayName:t.__("Python File"),extensions:[".py"],mimeTypes:["text/x-python"],icon:Re.u},{name:"json",displayName:t.__("JSON File"),extensions:[".json"],mimeTypes:["application/json"],icon:Re.m},{name:"julia",displayName:t.__("Julia File"),extensions:[".jl"],mimeTypes:["text/x-julia"],icon:Re.n},{name:"csv",displayName:t.__("CSV File"),extensions:[".csv"],mimeTypes:["text/csv"],icon:Re.y},{name:"tsv",displayName:t.__("TSV File"),extensions:[".tsv"],mimeTypes:["text/csv"],icon:Re.y},{name:"r",displayName:t.__("R File"),mimeTypes:["text/x-rsrc"],extensions:[".R"],icon:Re.v},{name:"yaml",displayName:t.__("YAML File"),mimeTypes:["text/x-yaml","text/yaml"],extensions:[".yaml",".yml"],icon:Re.B},{name:"svg",displayName:t.__("Image"),mimeTypes:["image/svg+xml"],extensions:[".svg"],icon:Re.l,fileFormat:"base64"},{name:"tiff",displayName:t.__("Image"),mimeTypes:["image/tiff"],extensions:[".tif",".tiff"],icon:Re.l,fileFormat:"base64"},{name:"jpeg",displayName:t.__("Image"),mimeTypes:["image/jpeg"],extensions:[".jpg",".jpeg"],icon:Re.l,fileFormat:"base64"},{name:"gif",displayName:t.__("Image"),mimeTypes:["image/gif"],extensions:[".gif"],icon:Re.l,fileFormat:"base64"},{name:"png",displayName:t.__("Image"),mimeTypes:["image/png"],extensions:[".png"],icon:Re.l,fileFormat:"base64"},{name:"bmp",displayName:t.__("Image"),mimeTypes:["image/bmp"],extensions:[".bmp"],icon:Re.l,fileFormat:"base64"}]}}(Ke||(Ke={})),function(e){e.extname=function(e){const t=f.PathExt.basename(e).split(".");return t.shift(),("."+t.join(".")).toLowerCase()},e.noOp=function(){}}(Xe||(Xe={}));var Je=n(24),Qe=n(203),Ze=n(45);const $e=Re.c.bindprops({stylesheet:"menuItem"});class et extends T.ContextMenu{constructor(e){super(e),this._isDisposed=!1,this._opened=new O.Signal(this),this.menu=new tt(e)}get isDisposed(){return this._isDisposed}get opened(){return this._opened}dispose(){this._isDisposed||(this._isDisposed=!0,this.menu.dispose(),O.Signal.disconnectSender(this))}open(e){if(this._isDisposed)return!1;const t=super.open(e);return t&&this._opened.emit(),t}}class tt extends T.Menu{constructor(e){e.renderer=e.renderer||tt.defaultRenderer,super(e)}insertItem(e,t){return t.submenu&&tt.overrideDefaultRenderer(t.submenu),super.insertItem(e,t)}}!function(e){e.overrideDefaultRenderer=function t(n){n.renderer===T.Menu.defaultRenderer&&(n.renderer=e.defaultRenderer);const r=n.insertItem.bind(n);n.insertItem=(t,n)=>(n.submenu&&e.overrideDefaultRenderer(n.submenu),r(t,n));for(const e of n._items)e.submenu&&t(e.submenu)};class t extends T.Menu.Renderer{renderIcon(e){const t=this.createIconClass(e);return e.item.isToggled?Je.h.div({className:t},Re.e,e.item.iconLabel):"string"==typeof e.item.icon?Je.h.div({className:Object(Ze.a)(t,"jp-Icon")},e.item.iconLabel):Je.h.div({className:t},e.item.icon,e.item.iconLabel)}createIconClass(e){let t="lm-Menu-itemIcon";return t+=" p-Menu-itemIcon","separator"===e.item.type?Object(Ze.a)(e.item.iconClass,t):Object(Ze.a)(Qe.a.styleClass({stylesheet:"menuItem"}),e.item.iconClass,t)}renderSubmenu(e){const t="lm-Menu-itemSubmenuIcon p-Menu-itemSubmenuIcon";return"submenu"===e.item.type?Je.h.div({className:t},$e):Je.h.div({className:t})}}e.Renderer=t,e.defaultRenderer=new t}(tt||(tt={}));var nt=n(65);
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var rt,it,ot,at,st=function(){function e(e){this._started=!1,this._pluginMap=rt.createPluginMap(),this._serviceMap=rt.createServiceMap(),this._delegate=new S.PromiseDelegate;var t=new nt.CommandRegistry,n=e.contextMenuRenderer,r=new T.ContextMenu({commands:t,renderer:n});this.commands=t,this.contextMenu=r,this.shell=e.shell}return Object.defineProperty(e.prototype,"started",{get:function(){return this._delegate.promise},enumerable:!0,configurable:!0}),e.prototype.hasPlugin=function(e){return e in this._pluginMap},e.prototype.listPlugins=function(){return Object.keys(this._pluginMap)},e.prototype.registerPlugin=function(e){if(e.id in this._pluginMap)throw new Error("Plugin '"+e.id+"' is already registered.");var t=rt.createPluginData(e);rt.ensureNoCycle(t,this._pluginMap,this._serviceMap),t.provides&&this._serviceMap.set(t.provides,t.id),this._pluginMap[t.id]=t},e.prototype.registerPlugins=function(e){for(var t=0,n=e;t<n.length;t++){var r=n[t];this.registerPlugin(r)}},e.prototype.activatePlugin=function(e){var t=this,n=this._pluginMap[e];if(!n)return Promise.reject(new Error("Plugin '"+e+"' is not registered."));if(n.activated)return Promise.resolve(void 0);if(n.promise)return n.promise;var r=n.requires.map((function(e){return t.resolveRequiredService(e)})),i=n.optional.map((function(e){return t.resolveOptionalService(e)})),o=r.concat(i);return n.promise=Promise.all(o).then((function(e){return n.activate.apply(void 0,function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}([t],e))})).then((function(e){n.service=e,n.activated=!0,n.promise=null})).catch((function(e){throw n.promise=null,e})),n.promise},e.prototype.resolveRequiredService=function(e){var t=this._serviceMap.get(e);if(!t)return Promise.reject(new Error("No provider for: "+e.name+"."));var n=this._pluginMap[t];return n.activated?Promise.resolve(n.service):this.activatePlugin(t).then((function(){return n.service}))},e.prototype.resolveOptionalService=function(e){var t=this._serviceMap.get(e);if(!t)return Promise.resolve(null);var n=this._pluginMap[t];return n.activated?Promise.resolve(n.service):this.activatePlugin(t).then((function(){return n.service})).catch((function(e){return console.error(e),null}))},e.prototype.start=function(e){var t=this;if(void 0===e&&(e={}),this._started)return this._delegate.promise;this._started=!0;var n=e.hostID||"",r=rt.collectStartupPlugins(this._pluginMap,e).map((function(e){return t.activatePlugin(e).catch((function(t){console.error("Plugin '"+e+"' failed to activate."),console.error(t)}))}));return Promise.all(r).then((function(){t.attachShell(n),t.addEventListeners(),t._delegate.resolve(void 0)})),this._delegate.promise},e.prototype.handleEvent=function(e){switch(e.type){case"resize":this.evtResize(e);break;case"keydown":this.evtKeydown(e);break;case"contextmenu":this.evtContextMenu(e)}},e.prototype.attachShell=function(e){T.Widget.attach(this.shell,e&&document.getElementById(e)||document.body)},e.prototype.addEventListeners=function(){document.addEventListener("contextmenu",this),document.addEventListener("keydown",this,!0),window.addEventListener("resize",this)},e.prototype.evtKeydown=function(e){this.commands.processKeydownEvent(e)},e.prototype.evtContextMenu=function(e){e.shiftKey||this.contextMenu.open(e)&&(e.preventDefault(),e.stopPropagation())},e.prototype.evtResize=function(e){this.shell.update()},e}();!function(e){e.createPluginMap=function(){return Object.create(null)},e.createServiceMap=function(){return new Map},e.createPluginData=function(e){return{id:e.id,service:null,promise:null,activated:!1,activate:e.activate,provides:e.provides||null,autoStart:e.autoStart||!1,requires:e.requires?e.requires.slice():[],optional:e.optional?e.optional.slice():[]}},e.ensureNoCycle=function(e,t,n){var r=e.requires.concat(e.optional);if(e.provides&&0!==r.length){var i=[e.id];if(r.some((function r(o){if(o===e.provides)return!0;var a=n.get(o);if(!a)return!1;var s=t[a],l=s.requires.concat(s.optional);if(0===l.length)return!1;if(i.push(a),l.some(r))return!0;return i.pop(),!1})))throw new Error("Cycle detected: "+i.join(" -> ")+".")}},e.collectStartupPlugins=function(e,t){var n=Object.create(null);for(var r in e)e[r].autoStart&&(n[r]=!0);if(t.startPlugins)for(var i=0,o=t.startPlugins;i<o.length;i++){n[r=o[i]]=!0}if(t.ignorePlugins)for(var a=0,s=t.ignorePlugins;a<s.length;a++){delete n[r=s[a]]}return Object.keys(n)}}(rt||(rt={}));class lt extends st{constructor(e){super(e),this._formatChanged=new O.Signal(this),this.contextMenu=new et({commands:this.commands,renderer:e.contextMenuRenderer});const t=new Promise(e=>{requestAnimationFrame(()=>{e()})});this.commandLinker=e.commandLinker||new ze.a({commands:this.commands}),this.docRegistry=e.docRegistry||new Ke,this.restored=e.restored||this.started.then(()=>t).catch(()=>t),this.serviceManager=e.serviceManager||new se.ServiceManager}get format(){return this._format}set format(e){this._format!==e&&(this._format=e,document.body.dataset.format=e,this._formatChanged.emit(e))}get formatChanged(){return this._formatChanged}contextMenuHitTest(e){if(!(this._contextMenuEvent&&this._contextMenuEvent.target instanceof Node))return;let t=this._contextMenuEvent.target;do{if(t instanceof HTMLElement&&e(t))return t;t=t.parentNode}while(t&&t.parentNode&&t!==t.parentNode)}evtContextMenu(e){if(this._contextMenuEvent=e,e.shiftKey||ot.suppressContextMenu(e.target))return;if(this.contextMenu.open(e)){const t=this.contextMenu.menu.items;if(1===t.length&&t[0].command===at.contextMenu)return void this.contextMenu.menu.close();e.preventDefault(),e.stopPropagation()}}}(it=lt||(lt={})).inDocMode=function(e,t){const n=new RegExp("^"+t.urls.doc);return!!e.match(n)},it.IPaths=new S.Token("@jupyterlab/application:IPaths"),it.ITreeResolver=new S.Token("@jupyterlab/application:ITreeResolver"),function(e){e.suppressContextMenu=function(e){return null!==e.closest("[data-jp-suppress-context-menu]")}}(ot||(ot={})),function(e){e.contextMenu="__internal:context-menu-info"}(at||(at={}));var ct,ut=n(116),dt=n(8);class ht extends T.Widget{constructor(e){super(),this._changeCallback=e=>{if(!e.data||!e.data[this.mimeType])return;const t=e.data[this.mimeType];"string"==typeof t?t!==this._context.model.toString()&&this._context.model.fromString(t):null==t||S.JSONExt.deepEqual(t,this._context.model.toJSON())||this._context.model.fromJSON(t)},this._fragment="",this._ready=new S.PromiseDelegate,this._isRendering=!1,this._renderRequested=!1,this.addClass("jp-MimeDocument"),this.translator=e.translator||m.b,this._trans=this.translator.load("jupyterlab"),this.mimeType=e.mimeType,this._dataType=e.dataType||"string",this._context=e.context,this.renderer=e.renderer;(this.layout=new T.StackedLayout).addWidget(this.renderer),this._context.ready.then(()=>this._render()).then(()=>{this.node===document.activeElement&&dt.c.sendMessage(this.renderer,T.Widget.Msg.ActivateRequest),this._monitor=new f.ActivityMonitor({signal:this._context.model.contentChanged,timeout:e.renderTimeout}),this._monitor.activityStopped.connect(this.update,this),this._ready.resolve(void 0)}).catch(e=>{requestAnimationFrame(()=>{this.dispose()}),Object(je.c)(this._trans.__("Renderer Failure: %1",this._context.path),e)})}[ut.a.symbol](){return ut.a.getPrintFunction(this.renderer)}get ready(){return this._ready.promise}setFragment(e){this._fragment=e,this.update()}dispose(){this.isDisposed||(this._monitor&&this._monitor.dispose(),this._monitor=null,super.dispose())}onUpdateRequest(e){this._context.isReady&&(this._render(),this._fragment="")}async _render(){if(this.isDisposed)return;if(this._isRendering)return void(this._renderRequested=!0);this._renderRequested=!1;const e=this._context,t=e.model,n={};"string"===this._dataType?n[this.mimeType]=t.toString():n[this.mimeType]=t.toJSON();const r=new g({data:n,callback:this._changeCallback,metadata:{fragment:this._fragment}});try{if(this._isRendering=!0,await this.renderer.renderModel(r),this._isRendering=!1,this._renderRequested)return this._render()}catch(t){requestAnimationFrame(()=>{this.dispose()}),Object(je.c)(this._trans.__("Renderer Failure: %1",e.path),t)}}}class pt extends qe{setFragment(e){this.content.setFragment(e)}}class ft extends Ge{constructor(e){super(ct.createRegistryOptions(e)),this._rendermime=e.rendermime,this._renderTimeout=e.renderTimeout||1e3,this._dataType=e.dataType||"string",this._fileType=e.primaryFileType,this._factory=e.factory}createNewWidget(e){var t,n;const r=this._fileType,i=(null==r?void 0:r.mimeTypes.length)?r.mimeTypes[0]:"text/plain",o=this._rendermime.clone({resolver:e.urlResolver});let a;a=this._factory&&this._factory.mimeTypes.includes(i)?this._factory.createRenderer({mimeType:i,resolver:o.resolver,sanitizer:o.sanitizer,linkHandler:o.linkHandler,latexTypesetter:o.latexTypesetter}):o.createRenderer(i);const s=new ht({context:e,renderer:a,mimeType:i,renderTimeout:this._renderTimeout,dataType:this._dataType});s.title.icon=null==r?void 0:r.icon,s.title.iconClass=null!==(t=null==r?void 0:r.iconClass)&&void 0!==t?t:"",s.title.iconLabel=null!==(n=null==r?void 0:r.iconLabel)&&void 0!==n?n:"";return new pt({content:s,context:e})}}!function(e){e.createRegistryOptions=function(e){return Object.assign(Object.assign({},e),{readOnly:!0})}}(ct||(ct={}));var mt=n(13);const gt=new S.Token("@jupyterlab/application:ILayoutRestorer"),vt="layout-restorer:data";class yt{constructor(e){this._firstDone=!1,this._promisesDone=!1,this._promises=[],this._restored=new S.PromiseDelegate,this._trackers=new Set,this._widgets=new Map,this._connector=e.connector,this._first=e.first,this._registry=e.registry,this._first.then(()=>{this._firstDone=!0}).then(()=>Promise.all(this._promises)).then(()=>{this._promisesDone=!0,this._trackers.clear()}).then(()=>{this._restored.resolve(void 0)})}get restored(){return this._restored.promise}add(e,t){_t.nameProperty.set(e,t),this._widgets.set(t,e),e.disposed.connect(this._onWidgetDisposed,this)}async fetch(){const e={fresh:!0,mainArea:null,downArea:null,leftArea:null,rightArea:null,relativeSizes:null},t=this._connector.fetch(vt);try{const[n]=await Promise.all([t,this.restored]);if(!n)return e;const{main:r,down:i,left:o,right:a,relativeSizes:s}=n,l=!1,c=this._rehydrateMainArea(r),u=this._rehydrateDownArea(i),d=this._rehydrateSideArea(o);return{fresh:l,mainArea:c,downArea:u,leftArea:d,rightArea:this._rehydrateSideArea(a),relativeSizes:s||null}}catch(t){return e}}restore(e,t){const n="restore() can only be called before `first` has resolved.";if(this._firstDone)return console.warn(n),Promise.reject(n);const{namespace:r}=e;if(this._trackers.has(r)){const e=`A tracker namespaced ${r} was already restored.`;return console.warn(e),Promise.reject(e)}const{args:i,command:o,name:a,when:s}=t;this._trackers.add(r),e.widgetAdded.connect((e,t)=>{const n=a(t);n&&this.add(t,`${r}:${n}`)},this),e.widgetUpdated.connect((e,t)=>{const n=a(t);if(n){const e=`${r}:${n}`;_t.nameProperty.set(t,e),this._widgets.set(e,t)}});const l=this._first,c=e.restore({args:i||(()=>S.JSONExt.emptyObject),command:o,connector:this._connector,name:a,registry:this._registry,when:s?[l].concat(s):l}).catch(e=>{console.error(e)});return this._promises.push(c),c}save(e){if(!this._promisesDone){const e="save() was called prematurely.";return console.warn(e),Promise.reject(e)}const t={};return t.main=this._dehydrateMainArea(e.mainArea),t.down=this._dehydrateDownArea(e.downArea),t.left=this._dehydrateSideArea(e.leftArea),t.right=this._dehydrateSideArea(e.rightArea),t.relativeSizes=e.relativeSizes,this._connector.save(vt,t)}_dehydrateMainArea(e){return e?_t.serializeMain(e):null}_rehydrateMainArea(e){return e?_t.deserializeMain(e,this._widgets):null}_dehydrateDownArea(e){if(!e)return null;const t={size:e.size};if(e.currentWidget){const n=_t.nameProperty.get(e.currentWidget);n&&(t.current=n)}return e.widgets&&(t.widgets=e.widgets.map(e=>_t.nameProperty.get(e)).filter(e=>!!e)),t}_rehydrateDownArea(e){var t;if(!e)return{currentWidget:null,size:0,widgets:null};const n=this._widgets,r=e.current&&n.has(""+e.current)?n.get(""+e.current):null,i=Array.isArray(e.widgets)?e.widgets.map(e=>n.has(""+e)?n.get(""+e):null).filter(e=>!!e):null;return{currentWidget:r,size:null!==(t=e.size)&&void 0!==t?t:0,widgets:i}}_dehydrateSideArea(e){if(!e)return null;const t={collapsed:e.collapsed};if(e.currentWidget){const n=_t.nameProperty.get(e.currentWidget);n&&(t.current=n)}return e.widgets&&(t.widgets=e.widgets.map(e=>_t.nameProperty.get(e)).filter(e=>!!e)),t}_rehydrateSideArea(e){var t;if(!e)return{collapsed:!0,currentWidget:null,widgets:null};const n=this._widgets;return{collapsed:null!==(t=e.collapsed)&&void 0!==t&&t,currentWidget:e.current&&n.has(""+e.current)?n.get(""+e.current):null,widgets:Array.isArray(e.widgets)?e.widgets.map(e=>n.has(""+e)?n.get(""+e):null).filter(e=>!!e):null}}_onWidgetDisposed(e){const t=_t.nameProperty.get(e);this._widgets.delete(t)}}var _t;!function(e){function t(n){return n&&n.type?"tab-area"===n.type?{type:"tab-area",currentIndex:n.currentIndex,widgets:n.widgets.map(t=>e.nameProperty.get(t)).filter(e=>!!e)}:{type:"split-area",orientation:n.orientation,sizes:n.sizes,children:n.children.map(t).filter(e=>!!e)}:null}function n(e,t){if(!e)return null;const r=e.type||"unknown";if("unknown"===r||"tab-area"!==r&&"split-area"!==r)return console.warn("Attempted to deserialize unknown type: "+r),null;if("tab-area"===r){const{currentIndex:n,widgets:r}=e,i={type:"tab-area",currentIndex:n||0,widgets:r&&r.map(e=>t.get(e)).filter(e=>!!e)||[]};return i.currentIndex>i.widgets.length-1&&(i.currentIndex=0),i}const{orientation:i,sizes:o,children:a}=e;return{type:"split-area",orientation:i,sizes:o||[],children:a&&a.map(e=>n(e,t)).filter(e=>!!e)||[]}}e.nameProperty=new W.AttachedProperty({name:"name",create:e=>""}),e.serializeMain=function(n){const r={dock:n&&n.dock&&t(n.dock.main)||null};if(n&&n.currentWidget){const t=e.nameProperty.get(n.currentWidget);t&&(r.current=t)}return r},e.deserializeMain=function(e,t){if(!e)return null;const r=e.current||null,i=e.dock||null;return{currentWidget:r&&t.has(r)&&t.get(r)||null,dock:i?{main:n(i,t)}:null}}}(_t||(_t={}));const bt=new S.Token("@jupyterlab/application:IMimeDocumentTracker");function Mt(e){const t=[],n=new ae.a({namespace:"application-mimedocuments"});return e.forEach(e=>{let r=e.default;e.hasOwnProperty("__esModule")||(r=e),Array.isArray(r)||(r=[r]),r.forEach(e=>{t.push(wt(n,e))})}),t.push({id:"@jupyterlab/application:mimedocument",optional:[gt],provides:bt,autoStart:!0,activate:(e,t)=>(t&&t.restore(n,{command:"docmanager:open",args:e=>({path:e.context.path,factory:At.factoryNameProperty.get(e)}),name:e=>`${e.context.path}:${At.factoryNameProperty.get(e)}`}),n)}),t}function wt(e,t){return{id:t.id,requires:[H,m.a],autoStart:!0,activate:(n,r,i)=>{if(void 0!==t.rank?r.addFactory(t.rendererFactory,t.rank):r.addFactory(t.rendererFactory),!t.documentWidgetFactoryOptions)return;const o=n.docRegistry;let a=[];a=Array.isArray(t.documentWidgetFactoryOptions)?t.documentWidgetFactoryOptions:[t.documentWidgetFactoryOptions],t.fileTypes&&t.fileTypes.forEach(e=>{e.icon&&(e=Object.assign(Object.assign({},e),{icon:mt.a.resolve({icon:e.icon})})),n.docRegistry.addFileType(e)}),a.forEach(n=>{const a=n.toolbarFactory?e=>n.toolbarFactory(e.content.renderer):void 0,s=new ft({renderTimeout:t.renderTimeout,dataType:t.dataType,rendermime:r,modelName:n.modelName,name:n.name,primaryFileType:o.getFileType(n.primaryFileType),fileTypes:n.fileTypes,defaultFor:n.defaultFor,defaultRendered:n.defaultRendered,toolbarFactory:a,translator:i,factory:t.rendererFactory});o.addWidgetFactory(s),s.widgetCreated.connect((t,n)=>{At.factoryNameProperty.set(n,s.name),n.context.pathChanged.connect(()=>{e.save(n)}),e.add(n)})})}}}var At;!function(e){e.factoryNameProperty=new W.AttachedProperty({name:"factoryName",create:()=>{}})}(At||(At={}));class Ct extends T.TabBar{constructor(e={}){e.renderer=e.renderer||Ct.defaultRenderer,super(e)}}!function(e){class t extends T.TabBar.Renderer{renderCloseIcon(e){const t=Object(Ze.a)("jp-icon-hover lm-TabBar-tabCloseIcon",Qe.a.styleClass({elementPosition:"center",height:"16px",width:"16px"}));return Object(Je.hpass)("div",{className:t},Re.h)}}e.Renderer=t,e.defaultRenderer=new t}(Ct||(Ct={}));class xt extends T.DockPanel{constructor(e={}){e.renderer=e.renderer||xt.defaultRenderer,super(e)}}!function(e){class t extends T.DockPanel.Renderer{createTabBar(){const e=new Ct;return e.addClass("lm-DockPanel-tabBar"),e}}e.Renderer=t,e.defaultRenderer=new t}(xt||(xt={}));class Et extends T.TabPanel{constructor(e={}){e.renderer=e.renderer||Ct.defaultRenderer,super(e)}}var Lt=n(64);const St=new S.Token("@jupyterlab/application:ILabShell");class Tt extends T.Widget{constructor(e){super(),this._dockChildHook=(e,t)=>{switch(t.type){case"child-added":t.child.addClass("jp-Activity"),this._tracker.add(t.child);break;case"child-removed":t.child.removeClass("jp-Activity"),this._tracker.remove(t.child)}return!0},this._activeChanged=new O.Signal(this),this._cachedLayout=null,this._currentChanged=new O.Signal(this),this._currentPath="",this._currentPathChanged=new O.Signal(this),this._modeChanged=new O.Signal(this),this._isRestored=!1,this._layoutModified=new O.Signal(this),this._layoutDebouncer=new Lt.Debouncer(()=>{this._layoutModified.emit(void 0)},0),this._restored=new S.PromiseDelegate,this._tracker=new T.FocusTracker,this._mainOptionsCache=new Map,this._sideOptionsCache=new Map,this.addClass("jp-LabShell"),this.id="main";const t=(e&&e.translator||m.b).load("jupyterlab"),n=this._headerPanel=new T.BoxPanel,r=this._menuHandler=new Ot.PanelHandler;r.panel.node.setAttribute("role","navigation"),r.panel.node.setAttribute("aria-label",t.__("main"));const i=this._topHandler=new Ot.PanelHandler;i.panel.node.setAttribute("role","banner");const o=this._bottomPanel=new T.BoxPanel;o.node.setAttribute("role","contentinfo");const a=new T.BoxPanel,s=this._vsplitPanel=new Ot.RestorableSplitPanel,l=this._dockPanel=new xt;dt.c.installMessageHook(l,this._dockChildHook);const c=this._hsplitPanel=new Ot.RestorableSplitPanel,u=this._downPanel=new Et({tabsMovable:!0}),d=this._leftHandler=new Ot.SideBarHandler,h=this._rightHandler=new Ot.SideBarHandler,p=new T.BoxLayout;n.id="jp-header-panel",r.panel.id="jp-menu-panel",i.panel.id="jp-top-panel",o.id="jp-bottom-panel",a.id="jp-main-content-panel",s.id="jp-main-vsplit-panel",l.id="jp-main-dock-panel",c.id="jp-main-split-panel",u.id="jp-down-stack",d.sideBar.addClass("jp-SideBar"),d.sideBar.addClass("jp-mod-left"),d.sideBar.node.setAttribute("aria-label",t.__("main sidebar")),d.sideBar.contentNode.setAttribute("aria-label",t.__("main sidebar")),d.sideBar.node.setAttribute("role","complementary"),d.stackedPanel.id="jp-left-stack",h.sideBar.addClass("jp-SideBar"),h.sideBar.addClass("jp-mod-right"),h.sideBar.node.setAttribute("aria-label",t.__("alternate sidebar")),h.sideBar.contentNode.setAttribute("aria-label",t.__("alternate sidebar")),h.sideBar.node.setAttribute("role","complementary"),h.stackedPanel.id="jp-right-stack",l.node.setAttribute("role","main"),a.spacing=0,s.spacing=1,l.spacing=5,c.spacing=1,n.direction="top-to-bottom",s.orientation="vertical",a.direction="left-to-right",c.orientation="horizontal",o.direction="bottom-to-top",T.SplitPanel.setStretch(d.stackedPanel,0),T.SplitPanel.setStretch(u,0),T.SplitPanel.setStretch(l,1),T.SplitPanel.setStretch(h.stackedPanel,0),T.BoxPanel.setStretch(d.sideBar,0),T.BoxPanel.setStretch(c,1),T.BoxPanel.setStretch(h.sideBar,0),T.SplitPanel.setStretch(s,1),c.addWidget(d.stackedPanel),c.addWidget(l),c.addWidget(h.stackedPanel),s.addWidget(c),s.addWidget(u),a.addWidget(d.sideBar),a.addWidget(s),a.addWidget(h.sideBar),p.direction="top-to-bottom",p.spacing=0,s.setRelativeSizes([3,1]),c.setRelativeSizes([1,2.5,1]),T.BoxLayout.setStretch(n,0),T.BoxLayout.setStretch(r.panel,0),T.BoxLayout.setStretch(i.panel,0),T.BoxLayout.setStretch(a,1),T.BoxLayout.setStretch(o,0),p.addWidget(n),p.addWidget(i.panel),p.addWidget(a),p.addWidget(o),this._headerPanel.hide(),this._bottomPanel.hide(),this._downPanel.hide(),this.layout=p,this._tracker.currentChanged.connect(this._onCurrentChanged,this),this._tracker.activeChanged.connect(this._onActiveChanged,this),this._dockPanel.layoutModified.connect(this._onLayoutModified,this),this._vsplitPanel.updated.connect(this._onLayoutModified,this),this._downPanel.currentChanged.connect(this._onLayoutModified,this),this._downPanel.tabBar.tabMoved.connect(this._onTabPanelChanged,this),this._downPanel.stackedPanel.widgetRemoved.connect(this._onTabPanelChanged,this),this._leftHandler.sideBar.currentChanged.connect(this._onLayoutModified,this),this._rightHandler.sideBar.currentChanged.connect(this._onLayoutModified,this),this._hsplitPanel.updated.connect(this._onLayoutModified,this);const f=this._titleHandler=new Ot.TitleHandler(this);this.add(f,"top",{rank:100}),"multiple-document"===this._dockPanel.mode?(this._topHandler.addWidget(this._menuHandler.panel,100),f.hide()):p.insertWidget(2,this._menuHandler.panel);const g=this._skipLinkWidget=new Ot.SkipLinkWidget(this);this.add(g,"top",{rank:0}),this._skipLinkWidget.show(),this.currentChanged.connect((e,t)=>{let n=t.newValue,r=t.oldValue;r&&r.title.changed.disconnect(this._updateTitlePanelTitle,this),n&&(n.title.changed.connect(this._updateTitlePanelTitle,this),this._updateTitlePanelTitle()),n&&n instanceof qe&&n.context.pathChanged.connect(this._updateCurrentPath,this),this._updateCurrentPath()})}get activeChanged(){return this._activeChanged}get activeWidget(){return this._tracker.activeWidget}get currentChanged(){return this._currentChanged}get modeChanged(){return this._modeChanged}get currentPathChanged(){return this._currentPathChanged}get currentWidget(){return this._tracker.currentWidget}get layoutModified(){return this._layoutModified}get leftCollapsed(){return!this._leftHandler.sideBar.currentTitle}get rightCollapsed(){return!this._rightHandler.sideBar.currentTitle}get presentationMode(){return this.hasClass("jp-mod-presentationMode")}set presentationMode(e){this.toggleClass("jp-mod-presentationMode",e)}get mode(){return this._dockPanel.mode}set mode(e){const t=this._dockPanel;if(e===t.mode)return;const n=this.currentWidget;if("single-document"===e)this._cachedLayout=t.saveLayout(),t.mode=e,this.currentWidget&&t.activateWidget(this.currentWidget),this.layout.insertWidget(2,this._menuHandler.panel),this._titleHandler.show(),this._updateTitlePanelTitle();else{const r=Object(V.toArray)(t.widgets());t.mode=e,this._cachedLayout&&(Ot.normalizeAreaConfig(t,this._cachedLayout.main),t.restoreLayout(this._cachedLayout),this._cachedLayout=null),r.forEach(e=>{e.parent||this._addToMainArea(e,Object.assign(Object.assign({},this._mainOptionsCache.get(e)),{activate:!1}))}),this._mainOptionsCache.clear(),n&&t.activateWidget(n),this.add(this._menuHandler.panel,"top",{rank:100}),this._titleHandler.hide()}this.node.dataset.shellMode=e,this._downPanel.fit(),this._modeChanged.emit(e)}get restored(){return this._restored.promise}activateById(e){if(this._leftHandler.has(e))return void this._leftHandler.activate(e);if(this._rightHandler.has(e))return void this._rightHandler.activate(e);const t=this._downPanel.tabBar.titles.findIndex(t=>t.owner.id===e);if(t>=0)return void(this._downPanel.currentIndex=t);const n=this._dockPanel,r=Object(V.find)(n.widgets(),t=>t.id===e);r&&n.activateWidget(r)}activateNextTab(){const e=this._currentTabBar();if(!e)return;const t=e.currentIndex;if(-1!==t){if(t<e.titles.length-1)return e.currentIndex+=1,void(e.currentTitle&&e.currentTitle.owner.activate());if(t===e.titles.length-1){const e=this._adjacentBar("next");e&&(e.currentIndex=0,e.currentTitle&&e.currentTitle.owner.activate())}}}activatePreviousTab(){const e=this._currentTabBar();if(!e)return;const t=e.currentIndex;if(-1!==t){if(t>0)return e.currentIndex-=1,void(e.currentTitle&&e.currentTitle.owner.activate());if(0===t){const e=this._adjacentBar("previous");if(e){const t=e.titles.length;e.currentIndex=t-1,e.currentTitle&&e.currentTitle.owner.activate()}}}}activateNextTabBar(){const e=this._adjacentBar("next");e&&e.currentTitle&&e.currentTitle.owner.activate()}activatePreviousTabBar(){const e=this._adjacentBar("previous");e&&e.currentTitle&&e.currentTitle.owner.activate()}add(e,t="main",n){switch(t||"main"){case"bottom":return this._addToBottomArea(e,n);case"down":return this._addToDownArea(e,n);case"header":return this._addToHeaderArea(e,n);case"left":return this._addToLeftArea(e,n);case"main":return this._addToMainArea(e,n);case"menu":return this._addToMenuArea(e,n);case"right":return this._addToRightArea(e,n);case"top":return this._addToTopArea(e,n);default:throw new Error("Invalid area: "+t)}}collapseLeft(){this._leftHandler.collapse(),this._onLayoutModified()}collapseRight(){this._rightHandler.collapse(),this._onLayoutModified()}dispose(){this.isDisposed||(this._layoutDebouncer.dispose(),super.dispose())}expandLeft(){this._leftHandler.expand(),this._onLayoutModified()}expandRight(){this._rightHandler.expand(),this._onLayoutModified()}closeAll(){Object(V.toArray)(this._dockPanel.widgets()).forEach(e=>e.close()),this._downPanel.stackedPanel.widgets.forEach(e=>e.close())}isEmpty(e){switch(e){case"bottom":return 0===this._bottomPanel.widgets.length;case"down":return 0===this._downPanel.stackedPanel.widgets.length;case"header":return 0===this._headerPanel.widgets.length;case"left":return 0===this._leftHandler.stackedPanel.widgets.length;case"main":return this._dockPanel.isEmpty;case"menu":return 0===this._menuHandler.panel.widgets.length;case"right":return 0===this._rightHandler.stackedPanel.widgets.length;case"top":return 0===this._topHandler.panel.widgets.length;default:return!0}}restoreLayout(e,t){var n,r;const{mainArea:i,downArea:o,leftArea:a,rightArea:s,relativeSizes:l}=t;if(i){const{currentWidget:t,dock:n}=i;n&&this._dockPanel.restoreLayout(n),e&&(this.mode=e),t&&this.activateById(t.id)}else e&&(this.mode=e);if(o){const{currentWidget:e,widgets:t,size:i}=o,a=null!==(n=null==t?void 0:t.map(e=>e.id))&&void 0!==n?n:[];this._downPanel.tabBar.titles.filter(e=>!a.includes(e.owner.id)).map(e=>e.owner.close());const s=this._downPanel.tabBar.titles.map(e=>e.owner.id);for(null==t||t.filter(e=>!s.includes(e.id)).map(e=>this._downPanel.addWidget(e));!V.ArrayExt.shallowEqual(a,this._downPanel.tabBar.titles.map(e=>e.owner.id));)this._downPanel.tabBar.titles.forEach((e,t)=>{const n=a.findIndex(t=>e.owner.id==t);n>=0&&n!=t&&this._downPanel.tabBar.insertTab(n,e)});if(e){const t=this._downPanel.stackedPanel.widgets.findIndex(t=>t.id===e.id);t&&(this._downPanel.currentIndex=t,null===(r=this._downPanel.currentWidget)||void 0===r||r.activate())}i&&i>0?this._vsplitPanel.setRelativeSizes([1-i,i]):(this._downPanel.stackedPanel.widgets.forEach(e=>e.close()),this._downPanel.hide())}a?this._leftHandler.rehydrate(a):"single-document"===e&&this.collapseLeft(),s?this._rightHandler.rehydrate(s):"single-document"===e&&this.collapseRight(),l&&this._hsplitPanel.setRelativeSizes(l),this._isRestored||(dt.c.flush(),this._restored.resolve(t))}saveLayout(){return{mainArea:{currentWidget:this._tracker.currentWidget,dock:"single-document"===this.mode&&this._cachedLayout||this._dockPanel.saveLayout()},downArea:{currentWidget:this._downPanel.currentWidget,widgets:Object(V.toArray)(this._downPanel.stackedPanel.widgets),size:this._vsplitPanel.relativeSizes()[1]},leftArea:this._leftHandler.dehydrate(),rightArea:this._rightHandler.dehydrate(),relativeSizes:this._hsplitPanel.relativeSizes()}}widgets(e){switch(null!=e?e:"main"){case"main":return this._dockPanel.widgets();case"left":return Object(V.iter)(this._leftHandler.sideBar.titles.map(e=>e.owner));case"right":return Object(V.iter)(this._rightHandler.sideBar.titles.map(e=>e.owner));case"header":return this._headerPanel.children();case"top":return this._topHandler.panel.children();case"menu":return this._menuHandler.panel.children();case"bottom":return this._bottomPanel.children();default:throw new Error("Invalid area: "+e)}}onAfterAttach(e){this.node.dataset.shellMode=this.mode}_updateTitlePanelTitle(){let e=this.currentWidget;const t=this._titleHandler.inputElement;t.value=e?e.title.label:"",t.title=e?e.title.caption:""}_updateCurrentPath(){let e=this.currentWidget,t="";e&&e instanceof qe&&(t=e.context.path),this._currentPathChanged.emit({newValue:t,oldValue:this._currentPath}),this._currentPath=t}_addToLeftArea(e,t){if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");t=t||this._sideOptionsCache.get(e)||{},this._sideOptionsCache.set(e,t);const n="rank"in t?t.rank:900;this._leftHandler.addWidget(e,n),this._onLayoutModified()}_addToMainArea(e,t){if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");t=t||{};const n=this._dockPanel,r=t.mode||"tab-after";let i=this.currentWidget;t.ref&&(i=Object(V.find)(n.widgets(),e=>e.id===t.ref)||null);const{title:o}=e;o.dataset=Object.assign(Object.assign({},o.dataset),{id:e.id}),o.icon instanceof mt.a?o.icon=o.icon.bindprops({stylesheet:"mainAreaTab"}):"string"!=typeof o.icon&&o.icon||(o.iconClass=Object(Ze.a)(o.iconClass,"jp-Icon")),n.addWidget(e,{mode:r,ref:i}),"single-document"===n.mode&&this._mainOptionsCache.set(e,t),!1!==t.activate&&n.activateWidget(e)}_addToRightArea(e,t){if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");const n="rank"in(t=t||this._sideOptionsCache.get(e)||{})?t.rank:900;this._sideOptionsCache.set(e,t),this._rightHandler.addWidget(e,n),this._onLayoutModified()}_addToTopArea(e,t){var n;if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");const r=null!==(n=(t=t||{}).rank)&&void 0!==n?n:900;this._topHandler.addWidget(e,r),this._onLayoutModified(),this._topHandler.panel.isHidden&&this._topHandler.panel.show()}_addToMenuArea(e,t){var n;if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");const r=null!==(n=(t=t||{}).rank)&&void 0!==n?n:900;this._menuHandler.addWidget(e,r),this._onLayoutModified(),this._menuHandler.panel.isHidden&&this._menuHandler.panel.show()}_addToHeaderArea(e,t){e.id?(this._headerPanel.addWidget(e),this._onLayoutModified(),this._headerPanel.isHidden&&this._headerPanel.show()):console.error("Widgets added to app shell must have unique id property.")}_addToBottomArea(e,t){e.id?(this._bottomPanel.addWidget(e),this._onLayoutModified(),this._bottomPanel.isHidden&&this._bottomPanel.show()):console.error("Widgets added to app shell must have unique id property.")}_addToDownArea(e,t){if(!e.id)return void console.error("Widgets added to app shell must have unique id property.");t=t||{};const{title:n}=e;n.dataset=Object.assign(Object.assign({},n.dataset),{id:e.id}),n.icon instanceof mt.a?n.icon=n.icon.bindprops({stylesheet:"mainAreaTab"}):"string"!=typeof n.icon&&n.icon||(n.iconClass=Object(Ze.a)(n.iconClass,"jp-Icon")),this._downPanel.addWidget(e),this._onLayoutModified(),this._downPanel.isHidden&&this._downPanel.show()}_adjacentBar(e){const t=this._currentTabBar();if(!t)return null;const n=Object(V.toArray)(this._dockPanel.tabBars()),r=n.length,i=n.indexOf(t);return"previous"===e?i>0?n[i-1]:0===i?n[r-1]:null:i<r-1?n[i+1]:i===r-1?n[0]:null}_currentTabBar(){const e=this._tracker.currentWidget;if(!e)return null;const t=e.title,n=this._dockPanel.tabBars();return Object(V.find)(n,e=>e.titles.indexOf(t)>-1)||null}_onActiveChanged(e,t){t.newValue&&(t.newValue.title.className+=" jp-mod-active"),t.oldValue&&(t.oldValue.title.className=t.oldValue.title.className.replace("jp-mod-active","")),this._activeChanged.emit(t)}_onCurrentChanged(e,t){t.newValue&&(t.newValue.title.className+=" jp-mod-current"),t.oldValue&&(t.oldValue.title.className=t.oldValue.title.className.replace("jp-mod-current","")),this._currentChanged.emit(t),this._onLayoutModified()}_onTabPanelChanged(){0===this._downPanel.stackedPanel.widgets.length&&this._downPanel.hide(),this._onLayoutModified()}_onLayoutModified(){this._layoutDebouncer.invoke()}}var Ot;!function(e){e.itemCmp=function(e,t){return e.rank-t.rank},e.normalizeAreaConfig=function e(t,n){n&&("tab-area"!==n.type?n.children.forEach(n=>{e(t,n)}):n.widgets=n.widgets.filter(e=>!e.isDisposed&&e.parent===t))};e.PanelHandler=class{constructor(){this._panelChildHook=(e,t)=>{switch(t.type){case"child-added":{const e=t.child;if(this._items.find(t=>t.widget===e))break;const n=this._items[this._items.length-1].rank;this._items.push({widget:e,rank:n})}break;case"child-removed":{const e=t.child;V.ArrayExt.removeFirstWhere(this._items,t=>t.widget===e)}}return!0},this._items=new Array,this._panel=new T.Panel,dt.c.installMessageHook(this._panel,this._panelChildHook)}get panel(){return this._panel}addWidget(t,n){t.parent=null;const r={widget:t,rank:n},i=V.ArrayExt.upperBound(this._items,r,e.itemCmp);V.ArrayExt.insert(this._items,i,r),this._panel.insertWidget(i,t)}};e.SideBarHandler=class{constructor(){this._items=new Array,this._sideBar=new T.TabBar({insertBehavior:"none",removeBehavior:"none",allowDeselect:!0,orientation:"vertical"}),this._stackedPanel=new T.StackedPanel,this._sideBar.hide(),this._stackedPanel.hide(),this._lastCurrent=null,this._sideBar.currentChanged.connect(this._onCurrentChanged,this),this._sideBar.tabActivateRequested.connect(this._onTabActivateRequested,this),this._stackedPanel.widgetRemoved.connect(this._onWidgetRemoved,this)}get sideBar(){return this._sideBar}get stackedPanel(){return this._stackedPanel}expand(){const e=this._lastCurrent||this._items.length>0&&this._items[0].widget;e&&this.activate(e.id)}activate(e){const t=this._findWidgetByID(e);t&&(this._sideBar.currentTitle=t.title,t.activate())}has(e){return null!==this._findWidgetByID(e)}collapse(){this._sideBar.currentTitle=null}addWidget(e,t){e.parent=null,e.hide();const n={widget:e,rank:t},r=this._findInsertIndex(n);V.ArrayExt.insert(this._items,r,n),this._stackedPanel.insertWidget(r,e);const i=this._sideBar.insertTab(r,e.title);i.dataset={id:e.id},i.icon instanceof mt.a?i.icon=i.icon.bindprops({stylesheet:"sideBar"}):"string"!=typeof i.icon&&i.icon||(i.iconClass=Object(Ze.a)(i.iconClass,"jp-Icon","jp-Icon-20")),this._refreshVisibility()}dehydrate(){const e=null===this._sideBar.currentTitle,t=Object(V.toArray)(this._stackedPanel.widgets);return{collapsed:e,currentWidget:t[this._sideBar.currentIndex],widgets:t}}rehydrate(e){e.currentWidget&&this.activate(e.currentWidget.id),e.collapsed&&this.collapse()}_findInsertIndex(t){return V.ArrayExt.upperBound(this._items,t,e.itemCmp)}_findWidgetIndex(e){return V.ArrayExt.findFirstIndex(this._items,t=>t.widget===e)}_findWidgetByTitle(e){const t=Object(V.find)(this._items,t=>t.widget.title===e);return t?t.widget:null}_findWidgetByID(e){const t=Object(V.find)(this._items,t=>t.widget.id===e);return t?t.widget:null}_refreshVisibility(){this._sideBar.setHidden(0===this._sideBar.titles.length),this._stackedPanel.setHidden(null===this._sideBar.currentTitle)}_onCurrentChanged(e,t){const n=t.previousTitle?this._findWidgetByTitle(t.previousTitle):null,r=t.currentTitle?this._findWidgetByTitle(t.currentTitle):null;n&&n.hide(),r&&r.show(),this._lastCurrent=r||n,this._refreshVisibility()}_onTabActivateRequested(e,t){t.title.owner.activate()}_onWidgetRemoved(e,t){t===this._lastCurrent&&(this._lastCurrent=null),V.ArrayExt.removeAt(this._items,this._findWidgetIndex(t)),this._sideBar.removeTab(t.title),this._refreshVisibility()}};class t extends T.Widget{constructor(e){super(),this.addClass("jp-skiplink"),this.id="jp-skiplink",this._shell=e,this._createSkipLink("Skip to left side bar")}handleEvent(e){switch(e.type){case"click":this._focusLeftSideBar()}}onAfterAttach(e){super.onAfterAttach(e),this.node.addEventListener("click",this)}onBeforeDetach(e){this.node.removeEventListener("click",this),super.onBeforeDetach(e)}_focusLeftSideBar(){this._shell.expandLeft()}_createSkipLink(e){const t=document.createElement("a");t.href="#",t.tabIndex=1,t.text=e,t.className="skip-link",this.node.appendChild(t)}}e.SkipLinkWidget=t;class n extends T.Widget{constructor(e){super(),this._selected=!1;const t=document.createElement("input");t.type="text",this.node.appendChild(t),this._shell=e,this.id="jp-title-panel-title"}onAfterAttach(e){super.onAfterAttach(e),this.inputElement.addEventListener("keyup",this),this.inputElement.addEventListener("click",this),this.inputElement.addEventListener("blur",this)}onBeforeDetach(e){super.onBeforeDetach(e),this.inputElement.removeEventListener("keyup",this),this.inputElement.removeEventListener("click",this),this.inputElement.removeEventListener("blur",this)}handleEvent(e){switch(e.type){case"keyup":this._evtKeyUp(e);break;case"click":this._evtClick(e);break;case"blur":this._selected=!1}}async _evtKeyUp(e){if("Enter"==e.key){const e=this._shell.currentWidget;if(null==e)return;const t=e.title.label,n=this.inputElement,r=n.value;n.blur(),r!==t?e.title.label=r:n.value=t}}_evtClick(e){if(0!==e.button||this._selected)return;const t=this.inputElement;e.preventDefault(),e.stopPropagation(),this._selected=!0;const n=t.value.indexOf(".");-1===n?t.select():t.setSelectionRange(0,n)}get inputElement(){return this.node.children[0]}}e.TitleHandler=n;class r extends T.SplitPanel{constructor(e={}){super(e),this.updated=new O.Signal(this)}onUpdateRequest(e){super.onUpdateRequest(e),this.updated.emit()}}e.RestorableSplitPanel=r}(Ot||(Ot={}));const It=new S.Token("@jupyterlab/application:ILabStatus");class kt{constructor(e){this._busyCount=0,this._dirtyCount=0,this._busySignal=new O.Signal(e),this._dirtySignal=new O.Signal(e)}get busySignal(){return this._busySignal}get dirtySignal(){return this._dirtySignal}get isBusy(){return this._busyCount>0}get isDirty(){return this._dirtyCount>0}setDirty(){const e=this.isDirty;return this._dirtyCount++,this.isDirty!==e&&this._dirtySignal.emit(this.isDirty),new U.DisposableDelegate(()=>{const e=this.isDirty;this._dirtyCount=Math.max(0,this._dirtyCount-1),this.isDirty!==e&&this._dirtySignal.emit(this.isDirty)})}setBusy(){const e=this.isBusy;return this._busyCount++,this.isBusy!==e&&this._busySignal.emit(this.isBusy),new U.DisposableDelegate(()=>{const e=this.isBusy;this._busyCount--,this.isBusy!==e&&this._busySignal.emit(this.isBusy)})}}class Dt extends lt{constructor(e={shell:new Tt}){super(Object.assign(Object.assign({},e),{shell:e.shell||new Tt})),this.name=f.PageConfig.getOption("appName")||"JupyterLab",this.namespace=f.PageConfig.getOption("appNamespace")||this.name,this.registerPluginErrors=[],this.status=new kt(this),this.version=f.PageConfig.getOption("appVersion")||"unknown",this.restored=this.shell.restored.then(()=>{}).catch(()=>{});const t=Object.keys(Dt.defaultInfo).reduce((t,n)=>(n in e&&(t[n]=JSON.parse(JSON.stringify(e[n]))),t),{});this._info=Object.assign(Object.assign({},Dt.defaultInfo),t);const n=Dt.defaultPaths.urls,r=Dt.defaultPaths.directories,i=e.paths&&e.paths.urls||{},o=e.paths&&e.paths.directories||{};if(this._paths={urls:Object.keys(n).reduce((e,t)=>{if(t in i){const n=i[t];e[t]=n}else e[t]=n[t];return e},{}),directories:Object.keys(Dt.defaultPaths.directories).reduce((e,t)=>{if(t in o){const n=o[t];e[t]=n}else e[t]=r[t];return e},{})},this._info.devMode&&this.shell.addClass("jp-mod-devMode"),this.docRegistry.addModelFactory(new We),e.mimeExtensions)for(const t of Mt(e.mimeExtensions))this.registerPlugin(t)}get info(){return this._info}get paths(){return this._paths}registerPluginModule(e){let t=e.default;e.hasOwnProperty("__esModule")||(t=e),Array.isArray(t)||(t=[t]),t.forEach(e=>{try{this.registerPlugin(e)}catch(e){this.registerPluginErrors.push(e)}})}registerPluginModules(e){e.forEach(e=>{this.registerPluginModule(e)})}}var Nt;(Nt=Dt||(Dt={})).IInfo=new S.Token("@jupyterlab/application:IInfo"),Nt.defaultInfo={devMode:"true"===f.PageConfig.getOption("devMode").toLowerCase(),deferred:{patterns:[],matches:[]},disabled:{patterns:[],matches:[]},mimeExtensions:[],filesCached:"true"===f.PageConfig.getOption("cacheFiles").toLowerCase()},Nt.defaultPaths={urls:{base:f.PageConfig.getOption("baseUrl"),notFound:f.PageConfig.getOption("notFoundUrl"),app:f.PageConfig.getOption("appUrl"),doc:f.PageConfig.getOption("docUrl"),static:f.PageConfig.getOption("staticUrl"),settings:f.PageConfig.getOption("settingsUrl"),themes:f.PageConfig.getOption("themesUrl"),translations:f.PageConfig.getOption("translationsApiUrl"),hubHost:f.PageConfig.getOption("hubHost")||void 0,hubPrefix:f.PageConfig.getOption("hubPrefix")||void 0,hubUser:f.PageConfig.getOption("hubUser")||void 0,hubServerName:f.PageConfig.getOption("hubServerName")||void 0},directories:{appSettings:f.PageConfig.getOption("appSettingsDir"),schemas:f.PageConfig.getOption("schemasDir"),static:f.PageConfig.getOption("staticDir"),templates:f.PageConfig.getOption("templatesDir"),themes:f.PageConfig.getOption("themesDir"),userSettings:f.PageConfig.getOption("userSettingsDir"),serverRoot:f.PageConfig.getOption("serverRoot"),workspaces:f.PageConfig.getOption("workspacesDir")}};class jt{constructor(e){this.stop=new S.Token("@jupyterlab/application:Router#stop"),this._routed=new O.Signal(this),this._rules=new Map,this.base=e.base,this.commands=e.commands}get current(){var e,t;const{base:n}=this,r=f.URLExt.parse(window.location.href),{search:i,hash:o}=r,a=null!==(t=null===(e=r.pathname)||void 0===e?void 0:e.replace(n,"/"))&&void 0!==t?t:"";return{hash:o,path:a,request:a+i+o,search:i}}get routed(){return this._routed}navigate(e,t={}){const{base:n}=this,{history:r}=window,{hard:i}=t,o=document.location.href,a=e&&0===e.indexOf(n)?e:f.URLExt.join(n,e);return a===o?i?this.reload():void 0:(r.pushState({},"",a),i?this.reload():void(t.skipRouting||requestAnimationFrame(()=>{this.route()})))}register(e){var t;const{command:n,pattern:r}=e,i=null!==(t=e.rank)&&void 0!==t?t:100,o=this._rules;return o.set(r,{command:n,rank:i}),new U.DisposableDelegate(()=>{o.delete(r)})}reload(){window.location.reload()}route(){const{commands:e,current:t,stop:n}=this,{request:r}=t,i=this._routed,o=this._rules,a=[];o.forEach((e,t)=>{(null==r?void 0:r.match(t))&&a.push(e)});const s=a.sort((e,t)=>t.rank-e.rank),l=new S.PromiseDelegate,c=async()=>{if(!s.length)return i.emit(t),void l.resolve(void 0);const{command:o}=s.pop();try{const r=this.current.request;await e.execute(o,t)===n&&(s.length=0,console.debug(`Routing ${r} was short-circuited by ${o}`))}catch(e){console.warn(`Routing ${r} to ${o} failed`,e)}c()};return c(),l.promise}}const Pt=new S.Token("@jupyterlab/apputils:IConnectionLost"),zt=new S.Token("@jupyterlab/application:IRouter"),Rt=new S.Token("@jupyterlab/application:ITreePathUpdater");var Bt,Ht=n(51),Ft=n(115);class Yt{requestInitialContent(){return Promise.resolve(!1)}putInitializedState(){}acquireLock(){return Promise.resolve(0)}releaseLock(e){}destroy(){}setPath(e){}}class Vt{constructor(e){this._path="",this._lineEnding=null,this._contentsModel=null,this._populatedPromise=new S.PromiseDelegate,this._isPopulated=!1,this._isReady=!1,this._isDisposed=!1,this._pathChanged=new O.Signal(this),this._fileChanged=new O.Signal(this),this._saveState=new O.Signal(this),this._disposed=new O.Signal(this),this._lastModifiedCheckMargin=500;const t=this._manager=e.manager;this.translator=e.translator||m.b,this._trans=this.translator.load("jupyterlab"),this._factory=e.factory,this._dialogs=e.sessionDialogs||Ft.b,this._opener=e.opener||Bt.noOp,this._path=this._manager.contents.normalize(e.path),this._lastModifiedCheckMargin=e.lastModifiedCheckMargin||500;const n=this._manager.contents.localPath(this._path),r=this._factory.preferredLanguage(f.PathExt.basename(n)),i=e.modelDBFactory;if(i){const e=t.contents.localPath(this._path);this._modelDB=i.createNew(e),this._model=this._factory.createNew(r,this._modelDB,!1)}else this._model=this._factory.createNew(r,void 0,!1);const o=this._model.sharedModel,a=o.ydoc;this._ydoc=a,this._ycontext=a.getMap("context");const s=e.docProviderFactory;this._provider=s?s({path:this._path,contentType:this._factory.contentType,ymodel:o}):new Yt,this._readyPromise=t.ready.then(()=>this._populatedPromise.promise);const l=f.PathExt.extname(this._path);this.sessionContext=new Ft.a({sessionManager:t.sessions,specsManager:t.kernelspecs,path:this._path,type:".ipynb"===l?"notebook":"file",name:f.PathExt.basename(n),kernelPreference:e.kernelPreference||{shouldStart:!1},setBusy:e.setBusy}),this.sessionContext.propertyChanged.connect(this._onSessionChanged,this),t.contents.fileChanged.connect(this._onFileChanged,this);const c=this.urlResolver=new v.UrlResolver({path:this._path,contents:t.contents});this._ycontext.set("path",this._path),this._ycontext.observe(e=>{var t;const n=e.changes.keys.get("path");if(n){const e=this._ycontext.get("path");e&&e!==n.oldValue&&(c.path=e,this._path=e,this._provider.setPath(e),this._pathChanged.emit(this.path),null===(t=this.sessionContext.session)||void 0===t||t.setPath(e))}})}get pathChanged(){return this._pathChanged}get fileChanged(){return this._fileChanged}get saveState(){return this._saveState}get disposed(){return this._disposed}get lastModifiedCheckMargin(){return this._lastModifiedCheckMargin}set lastModifiedCheckMargin(e){this._lastModifiedCheckMargin=e}get model(){return this._model}get path(){return this._path}get localPath(){return this._manager.contents.localPath(this._path)}get contentsModel(){return this._contentsModel}get factoryName(){return this.isDisposed?"":this._factory.name}get isDisposed(){return this._isDisposed}dispose(){this.isDisposed||(this._isDisposed=!0,this.sessionContext.dispose(),this._modelDB&&this._modelDB.dispose(),this._model.dispose(),this._provider.destroy(),this._model.sharedModel.dispose(),this._ydoc.destroy(),this._disposed.emit(void 0),O.Signal.clearData(this))}get isReady(){return this._isReady}get ready(){return this._readyPromise}async initialize(e){const t=await this._provider.acquireLock(),n=await this._provider.requestInitialContent();let r;r=e||n?this._save():this._revert();const i=()=>{this._provider.releaseLock(t)};return r.then(()=>{this._provider.putInitializedState(),this._model.initialize()}).then(i,i),r}rename(e){return this.ready.then(()=>this._manager.ready.then(()=>this._rename(e)))}async save(){const[e]=await Promise.all([this._provider.acquireLock(),this.ready]);let t;t=this._save(),t=t.then(()=>{this._provider.putInitializedState()});const n=()=>{this._provider.releaseLock(e)};return t.then(n,n),await t}saveAs(){return this.ready.then(()=>Bt.getSavePath(this._path)).then(e=>{if(!this.isDisposed&&e)return e===this._path?this.save():this._manager.ready.then(()=>this._manager.contents.get(e)).then(()=>this._maybeOverWrite(e)).catch(t=>{if(!t.response||404!==t.response.status)throw t;return this._finishSaveAs(e)})})}async download(){const e=await this._manager.contents.getDownloadUrl(this._path),t=document.createElement("a");t.href=e,t.download="",document.body.appendChild(t),t.click(),document.body.removeChild(t)}async revert(){const[e]=await Promise.all([this._provider.acquireLock(),this.ready]),t=this._revert(),n=()=>{this._provider.releaseLock(e)};return t.then(n,n),await t}createCheckpoint(){const e=this._manager.contents;return this._manager.ready.then(()=>e.createCheckpoint(this._path))}deleteCheckpoint(e){const t=this._manager.contents;return this._manager.ready.then(()=>t.deleteCheckpoint(this._path,e))}restoreCheckpoint(e){const t=this._manager.contents,n=this._path;return this._manager.ready.then(()=>e?t.restoreCheckpoint(n,e):this.listCheckpoints().then(r=>{if(!this.isDisposed&&r.length)return e=r[r.length-1].id,t.restoreCheckpoint(n,e)}))}listCheckpoints(){const e=this._manager.contents;return this._manager.ready.then(()=>e.listCheckpoints(this._path))}addSibling(e,t={}){const n=this._opener;return n&&n(e,t),new U.DisposableDelegate(()=>{e.close()})}_onFileChanged(e,t){var n,r,i;if("rename"!==t.type)return;let o=t.oldValue&&t.oldValue.path,a=t.newValue&&t.newValue.path;if(a&&0===this._path.indexOf(o||"")){let e=t.newValue;o!==this._path&&(a=this._path.replace(new RegExp(`^${o}/`),a+"/"),o=this._path,e={last_modified:null===(n=t.newValue)||void 0===n?void 0:n.created,path:a}),this._path=a,null===(r=this.sessionContext.session)||void 0===r||r.setPath(a);const s=Object.assign(Object.assign({},this._contentsModel),e),l=this._manager.contents.localPath(a);null===(i=this.sessionContext.session)||void 0===i||i.setName(f.PathExt.basename(l)),this._updateContentsModel(s),this._ycontext.set("path",this._path)}}_onSessionChanged(e,t){if("path"!==t)return;const n=this.sessionContext.session.path;n!==this._path&&(this._path=n,this._ycontext.set("path",this._path))}_updateContentsModel(e){const t={path:e.path,name:e.name,type:e.type,content:void 0,writable:e.writable,created:e.created,last_modified:e.last_modified,mimetype:e.mimetype,format:e.format},n=this._contentsModel?this._contentsModel.last_modified:null;this._contentsModel=t,this._ycontext.set("last_modified",t.last_modified),n&&t.last_modified===n||this._fileChanged.emit(t)}_populate(){return this._isPopulated=!0,this._isReady=!0,this._populatedPromise.resolve(void 0),this._maybeCheckpoint(!1).then(()=>{if(this.isDisposed)return;const e=this._model.defaultKernelName||this.sessionContext.kernelPreference.name;this.sessionContext.kernelPreference=Object.assign(Object.assign({},this.sessionContext.kernelPreference),{name:e,language:this._model.defaultKernelLanguage}),this.sessionContext.initialize().then(e=>{e&&this._dialogs.selectKernel(this.sessionContext)})})}async _rename(e){var t,n;const r=this.path.split("/");r[r.length-1]=e;const i=r.join("/");await this._manager.contents.rename(this.path,i),await(null===(t=this.sessionContext.session)||void 0===t?void 0:t.setPath(i)),await(null===(n=this.sessionContext.session)||void 0===n?void 0:n.setName(e)),this._path=i,this._ycontext.set("path",this._path)}async _save(){this._saveState.emit("started");const e=this._model;let t;"json"===this._factory.fileFormat?t=e.toJSON():(t=e.toString(),this._lineEnding&&(t=t.replace(/\n/g,this._lineEnding)));const n={type:this._factory.contentType,format:this._factory.fileFormat,content:t};try{let t;if(await this._manager.ready,t=e.modelDB.isCollaborative?await this._manager.contents.save(this._path,n):await this._maybeSave(n),this.isDisposed)return;e.dirty=!1,this._updateContentsModel(t),this._isPopulated||await this._populate(),this._saveState.emit("completed")}catch(e){if("Cancel"===e.message)throw e;const t=this._manager.contents.localPath(this._path),n=f.PathExt.basename(t);throw this._handleError(e,this._trans.__("File Save Error for %1",n)),this._saveState.emit("failed"),e}}_revert(e=!1){const t=Object.assign({type:this._factory.contentType,content:null!==this._factory.fileFormat},null!==this._factory.fileFormat?{format:this._factory.fileFormat}:{}),n=this._path,r=this._model;return this._manager.ready.then(()=>this._manager.contents.get(n,t)).then(t=>{if(!this.isDisposed){if("json"===t.format)r.fromJSON(t.content),e&&r.initialize();else{let n=t.content;-1!==n.indexOf("\r\n")?(this._lineEnding="\r\n",n=n.replace(/\r\n/g,"\n")):-1!==n.indexOf("\r")?(this._lineEnding="\r",n=n.replace(/\r/g,"\n")):this._lineEnding=null,r.fromString(n),e&&r.initialize()}return this._updateContentsModel(t),r.dirty=!1,this._isPopulated?void 0:this._populate()}}).catch(async e=>{const t=this._manager.contents.localPath(this._path),n=f.PathExt.basename(t);throw this._handleError(e,this._trans.__("File Load Error for %1",n)),e})}_maybeSave(e){const t=this._path;return this._manager.contents.get(t,{content:!1}).then(n=>{var r;if(this.isDisposed)return Promise.reject(new Error("Disposed"));const i=this._lastModifiedCheckMargin,o=this._ycontext.get("last_modified")||(null===(r=this.contentsModel)||void 0===r?void 0:r.last_modified),a=o?new Date(o):new Date,s=new Date(n.last_modified);return o&&s.getTime()-a.getTime()>i?this._timeConflict(a,n,e):this._manager.contents.save(t,e)},n=>{if(n.response&&404===n.response.status)return this._manager.contents.save(t,e);throw n})}async _handleError(e,t){await Object(je.c)(t,e)}_maybeCheckpoint(e){let t=this._contentsModel&&this._contentsModel.writable,n=Promise.resolve(void 0);return t?(n=e?this.createCheckpoint().then():this.listCheckpoints().then(e=>{if(t=this._contentsModel&&this._contentsModel.writable,!this.isDisposed&&!e.length&&t)return this.createCheckpoint().then()}),n.catch(e=>{if(!e.response||403!==e.response.status)throw e})):n}_timeConflict(e,t,n){const r=new Date(t.last_modified);console.warn(`Last saving performed ${e} while the current file seems to have been saved `+r);const i=this._trans.__('"%1" has changed on disk since the last time it was opened or saved.\nDo you want to overwrite the file on disk with the version open here,\nor load the version on disk (revert)?',this.path),o=je.a.okButton({label:this._trans.__("Revert")}),a=je.a.warnButton({label:this._trans.__("Overwrite")});return Object(je.b)({title:this._trans.__("File Changed"),body:i,buttons:[je.a.cancelButton(),o,a]}).then(e=>this.isDisposed?Promise.reject(new Error("Disposed")):e.button.label===this._trans.__("Overwrite")?this._manager.contents.save(this._path,n):e.button.label===this._trans.__("Revert")?this.revert().then(()=>t):Promise.reject(new Error("Cancel")))}_maybeOverWrite(e){const t=this._trans.__('"%1" already exists. Do you want to replace it?',e),n=je.a.warnButton({label:this._trans.__("Overwrite")});return Object(je.b)({title:this._trans.__("File Overwrite?"),body:t,buttons:[je.a.cancelButton(),n]}).then(t=>this.isDisposed?Promise.reject(new Error("Disposed")):t.button.label===this._trans.__("Overwrite")?this._manager.contents.delete(e).then(()=>this._finishSaveAs(e)):void 0)}async _finishSaveAs(e){var t,n;this._path=e,await(null===(t=this.sessionContext.session)||void 0===t?void 0:t.setPath(e)),await(null===(n=this.sessionContext.session)||void 0===n?void 0:n.setName(e.split("/").pop())),await this.save(),this._ycontext.set("path",this._path),await this._maybeCheckpoint(!0)}}!function(e){e.getSavePath=function(e,n){const r=(n=n||m.b).load("jupyterlab"),i=je.a.okButton({label:r.__("Save")});return Object(je.b)({title:r.__("Save File As.."),body:new t(e),buttons:[je.a.cancelButton(),i]}).then(e=>{var t;if(e.button.label===r.__("Save"))return null!==(t=e.value)&&void 0!==t?t:void 0})},e.noOp=function(){};class t extends T.Widget{constructor(e){super({node:n(e)})}getValue(){return this.node.value}}function n(e){const t=document.createElement("input");return t.value=e,t}}(Bt||(Bt={}));var Ut=n(21);const Wt="https://cdn.jsdelivr.net/npm/";function Gt(e){return new Promise((t,n)=>{const r=window.requirejs;void 0===r?n("Requirejs is needed, please ensure it is loaded on the page."):r(e,t,n)})}function qt(e,t){return Gt([""+e]).catch(n=>{const r=n.requireModules&&n.requireModules[0];if(r){console.log(`Falling back to ${Wt} for ${e}@${t}`);const n=window.requirejs;if(void 0===n)throw new Error("Requirejs is needed, please ensure it is loaded on the page.");const i={paths:{}};return i.paths[e]=function(e,t){let n=e,r="index",i=e.indexOf("/");return-1!==i&&"@"===e[0]&&(i=e.indexOf("/",i+1)),-1!==i&&(r=e.substr(i+1),n=e.substr(0,i)),`${Wt}${n}@${t}/dist/${r}`}(e,t),n.undef(r),n.config(i),Gt([""+e])}})}var Kt=n(579),Xt=n.n(Kt);const Jt=(e,t,{room:n,rate:r})=>{const i=Xt()(n);return e.map(async e=>new Promise((o,a)=>{i(()=>{const i=(a=n/r,new Promise(e=>setTimeout(e,1e3*a)));var a;const s=t(e).then(o);return Promise.all([s,i])})}))};"undefined"!=typeof window&&void 0!==window.define&&(window.define("@jupyter-widgets/base",L),window.define("@jupyter-widgets/controls",Ne),window.define("@jupyter-widgets/output",r),window.define("@jupyterlab/application",i),window.define("@jupyterlab/apputils",Ht),window.define("@jupyterlab/coreutils",f),window.define("@jupyterlab/docregistry",o),window.define("@jupyterlab/outputarea",a),window.define("@phosphor/widgets",T),window.define("@phosphor/signaling",O),window.define("@phosphor/virtualdom",Je),window.define("@phosphor/algorithm",V),window.define("@phosphor/commands",nt),window.define("@phosphor/domutils",Ut),window.define("@lumino/widgets",T),window.define("@lumino/signaling",O),window.define("@lumino/virtualdom",Je),window.define("@lumino/algorithm",V),window.define("@lumino/commands",nt),window.define("@lumino/domutils",Ut));class Qt extends j{constructor(e,t,n){super(e,t,n),t.addFactory({safe:!1,mimeTypes:["application/vnd.jupyter.widget-view+json"],createRenderer:e=>new P(e,this)},1),this._registerWidgets(),this._loader=qt}async build_widgets(){const e=await this._build_models();document.body.querySelectorAll('script[type="application/vnd.jupyter.widget-view+json"]').forEach(async t=>{if(null==t?void 0:t.parentElement)try{const n=JSON.parse(t.innerHTML),{model_id:r}=n,i=e[r],o=document.createElement("div");t.parentElement.insertBefore(o,t),await this.display_model(void 0,i,{el:o})}catch(e){}})}async display_view(e,t,n){return n.el&&T.Widget.attach(t.pWidget,n.el),t.el&&(t.el.setAttribute("data-voila-jupyter-widget",""),t.el.addEventListener("jupyterWidgetResize",e=>{dt.c.postMessage(t.pWidget,T.Widget.ResizeMessage.UnknownSize)})),t.pWidget}async loadClass(e,t,n){return"@jupyter-widgets/base"===t||"@jupyter-widgets/controls"===t||"@jupyter-widgets/output"===t?super.loadClass(e,t,n):this._loader(t,n).then(r=>r[e]?r[e]:Promise.reject("Class "+e+" not found in module "+t+"@"+n))}restoreWidgets(e){return Promise.resolve()}_registerWidgets(){this.register({name:"@jupyter-widgets/base",version:L.JUPYTER_WIDGETS_VERSION,exports:L}),this.register({name:"@jupyter-widgets/controls",version:Ne.JUPYTER_CONTROLS_VERSION,exports:Ne}),this.register({name:"@jupyter-widgets/output",version:r.OUTPUT_WIDGET_VERSION,exports:r})}async _build_models(){const e={},t=L.uuid(),n=await this._create_comm("jupyter.widget.control",t,{widgets:null},{version:"1.0.0"});let r,i;try{await new Promise((e,t)=>{n.on_msg(t=>{r=t.content.data,"update_states"===r.method?(i=(t.buffers||[]).map(e=>e instanceof DataView?e:new DataView(e instanceof ArrayBuffer?e:e.buffer)),e(null)):console.warn(`\n              Unknown ${r.method} message on the Control channel\n            `)}),n.on_close(t),n.send({method:"request_states"},{})})}catch(e){return console.warn('Failed to open "jupyter.widget.control" comm channel, fallback to slow fetching of widgets.',e),this._build_models_slow()}n.close();const o=r.states,a={};for(const e of r.buffer_paths)a[e[0]]||(a[e[0]]=[]),a[e[0]].push(e.slice(1));const s=[];for(const[e,t]of Object.entries(o))try{const n=await this._create_comm("jupyter.widget",e);if(e in a){const n=a[e].length;L.put_buffers(t,a[e],i.splice(0,n))}const r=this.new_model({model_name:t.model_name,model_module:t.model_module,model_module_version:t.model_module_version,model_id:e,comm:n},t.state);s.push(r)}catch(e){console.error(e)}const l=await Promise.all(s);for(const t of l)e[t.model_id]=t;return e}async _build_models_slow(){const e=await this._get_comm_info(),t={},n=await Promise.all(Jt(Object.keys(e),async e=>{const t=await this._create_comm(this.comm_target_name,e);return this._update_comm(t)},{room:100,rate:500}));return await Promise.all(n.map(async e=>{const n=e.msg.content.data.state;try{const r=this.new_model({model_name:n._model_name,model_module:n._model_module,model_module_version:n._model_module_version,comm:e.comm},n),i=await r;t[i.model_id]=i}catch(e){console.error(e)}})),t}async _update_comm(e){return new Promise((t,n)=>{e.on_msg(async n=>{n.content.data.buffer_paths&&L.put_buffers(n.content.data.state,n.content.data.buffer_paths,n.buffers),"update"===n.content.data.method&&t({comm:e,msg:n})}),e.send({method:"request_state"},{})})}}var Zt=n(192);async function $t(e,t){e=null!=e?e:f.PageConfig.getBaseUrl(),t=null!=t?t:f.PageConfig.getOption("kernelId");const n=se.ServerConnection.makeSettings({baseUrl:e}),r=await se.KernelAPI.getKernelModel(t,n);if(!r)return;return new Zt.KernelConnection({model:r,serverSettings:n})}var en=n(142),tn=n(581),nn=n(582),rn=n(583),on=n(194),an=n(584),sn=n(585);Object(an.RegisterHTMLHandler)(Object(rn.browserAdaptor)());class ln extends on.TeXFont{constructor(){super(...arguments),this.defaultFonts={}}}const cn=new nn.CHTML({font:new ln}),un=new tn.TeX({packages:sn.AllPackages,inlineMath:[["$","$"],["\\(","\\)"]],displayMath:[["$$","$$"],["\\[","\\]"]],processEscapes:!0,processEnvironments:!0}),dn=en.mathjax.document(document,{InputJax:un,OutputJax:cn});function hn(){dn.findMath().compile().getMetrics().typeset().updateDocument().reset()}},,,,,,,,,,function(e,t,n){"use strict";n.d(t,"a",(function(){return g}));var r=n(6),i=n(27),o=n(4),a=n(487),s=n(144);class l{constructor(e=""){this._text="",this._isDisposed=!1,this._changed=new o.Signal(this),this._text=e}get type(){return"String"}get changed(){return this._changed}set text(e){e.length===this._text.length&&e===this._text||(this._text=e,this._changed.emit({type:"set",start:0,end:e.length,value:e}))}get text(){return this._text}insert(e,t){this._text=this._text.slice(0,e)+t+this._text.slice(e),this._changed.emit({type:"insert",start:e,end:e+t.length,value:t})}remove(e,t){const n=this._text.slice(e,t);this._text=this._text.slice(0,e)+this._text.slice(t),this._changed.emit({type:"remove",start:e,end:t,value:n})}clear(){this.text=""}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed||(this._isDisposed=!0,o.Signal.clearData(this),this.clear())}}var c=n(2),u=n(486);class d extends u.a{constructor(e){super(),this._inCompound=!1,this._isUndoable=!0,this._madeCompoundChange=!1,this._index=-1,this._stack=[],this._serializer=e,this.changed.connect(this._onListChanged,this)}get canRedo(){return this._index<this._stack.length-1}get canUndo(){return this._index>=0}beginCompoundOperation(e){this._inCompound=!0,this._isUndoable=!1!==e,this._madeCompoundChange=!1}endCompoundOperation(){this._inCompound=!1,this._isUndoable=!0,this._madeCompoundChange&&this._index++}undo(){if(!this.canUndo)return;const e=this._stack[this._index];this._isUndoable=!1;for(const t of e.reverse())this._undoChange(t);this._isUndoable=!0,this._index--}redo(){if(!this.canRedo)return;this._index++;const e=this._stack[this._index];this._isUndoable=!1;for(const t of e)this._redoChange(t);this._isUndoable=!0}clearUndo(){this._index=-1,this._stack=[]}_onListChanged(e,t){if(this.isDisposed||!this._isUndoable)return;this._inCompound&&this._madeCompoundChange||(this._stack=this._stack.slice(0,this._index+1));const n=this._copyChange(t);this._stack[this._index+1]?this._stack[this._index+1].push(n):this._stack.push([n]),this._inCompound?this._madeCompoundChange=!0:this._index++}_undoChange(e){let t=0;const n=this._serializer;switch(e.type){case"add":Object(c.each)(e.newValues,()=>{this.remove(e.newIndex)});break;case"set":t=e.oldIndex,Object(c.each)(e.oldValues,e=>{this.set(t++,n.fromJSON(e))});break;case"remove":t=e.oldIndex,Object(c.each)(e.oldValues,e=>{this.insert(t++,n.fromJSON(e))});break;case"move":this.move(e.newIndex,e.oldIndex);break;default:return}}_redoChange(e){let t=0;const n=this._serializer;switch(e.type){case"add":t=e.newIndex,Object(c.each)(e.newValues,e=>{this.insert(t++,n.fromJSON(e))});break;case"set":t=e.newIndex,Object(c.each)(e.newValues,t=>{this.set(e.newIndex++,n.fromJSON(t))});break;case"remove":Object(c.each)(e.oldValues,()=>{this.remove(e.oldIndex)});break;case"move":this.move(e.oldIndex,e.newIndex);break;default:return}}_copyChange(e){const t=[];Object(c.each)(e.oldValues,e=>{t.push(this._serializer.toJSON(e))});const n=[];return Object(c.each)(e.newValues,e=>{n.push(this._serializer.toJSON(e))}),{type:e.type,oldIndex:e.oldIndex,newIndex:e.newIndex,oldValues:t,newValues:n}}}(d||(d={})).IdentitySerializer=class{toJSON(e){return e}fromJSON(e){return e}};class h{constructor(e=null){this._value=null,this._changed=new o.Signal(this),this._isDisposed=!1,this._value=e}get type(){return"Value"}get isDisposed(){return this._isDisposed}get changed(){return this._changed}get(){return this._value}set(e){const t=this._value;r.JSONExt.deepEqual(t,e)||(this._value=e,this._changed.emit({oldValue:t,newValue:e}))}dispose(){this._isDisposed||(this._isDisposed=!0,o.Signal.clearData(this),this._value=null)}}(h||(h={})).IChangedArgs=class{};class p{constructor(e={}){this.isPrepopulated=!1,this.isCollaborative=!1,this.connected=Promise.resolve(void 0),this._toDispose=!1,this._isDisposed=!1,this._disposables=new i.DisposableSet,this._basePath=e.basePath||"",e.baseDB?this._db=e.baseDB:(this._db=new s.a,this._toDispose=!0)}get basePath(){return this._basePath}get isDisposed(){return this._isDisposed}get(e){return this._db.get(this._resolvePath(e))}has(e){return this._db.has(this._resolvePath(e))}createString(e){const t=new l;return this._disposables.add(t),this.set(e,t),t}createList(e){const t=new d(new d.IdentitySerializer);return this._disposables.add(t),this.set(e,t),t}createMap(e){const t=new a.a;return this._disposables.add(t),this.set(e,t),t}createValue(e){const t=new h;return this._disposables.add(t),this.set(e,t),t}getValue(e){const t=this.get(e);if(!t||"Value"!==t.type)throw Error("Can only call getValue for an ObservableValue");return t.get()}setValue(e,t){const n=this.get(e);if(!n||"Value"!==n.type)throw Error("Can only call setValue on an ObservableValue");n.set(t)}view(e){const t=new p({basePath:e,baseDB:this});return this._disposables.add(t),t}set(e,t){this._db.set(this._resolvePath(e),t)}dispose(){this.isDisposed||(this._isDisposed=!0,this._toDispose&&this._db.dispose(),this._disposables.dispose())}_resolvePath(e){return this._basePath&&(e=this._basePath+"."+e),e}}var f=n(1013);const m=(()=>{let e=!0;return t=>{if(e){e=!1;try{t()}finally{e=!0}}}})();var g;!function(e){e.defaultSelectionStyle={className:"",displayName:"",color:"black"};e.Model=class{constructor(e){this._isDisposed=!1,this._mimeTypeChanged=new o.Signal(this),this._sharedModelSwitched=new o.Signal(this),(e=e||{}).modelDB?this.modelDB=e.modelDB:this.modelDB=new p,this.sharedModel=f.b(this.type,e.id),this.sharedModel.changed.connect(this._onSharedModelChanged,this);const t=this.modelDB.createString("value");t.changed.connect(this._onModelDBValueChanged,this),t.text=t.text||e.value||"";const n=this.modelDB.createValue("mimeType");n.changed.connect(this._onModelDBMimeTypeChanged,this),n.set(e.mimeType||"text/plain"),this.modelDB.createMap("selections")}switchSharedModel(e,t){t&&(this.value.text=e.getSource()),this.sharedModel.changed.disconnect(this._onSharedModelChanged,this),this.sharedModel=e,this.sharedModel.changed.connect(this._onSharedModelChanged,this),this._sharedModelSwitched.emit(!0)}_onSharedModelChanged(e,t){m(()=>{if(t.sourceChange){const e=this.modelDB.get("value");let n=0;t.sourceChange.forEach(t=>{null!=t.insert?(e.insert(n,t.insert),n+=t.insert.length):null!=t.delete?e.remove(n,n+t.delete):null!=t.retain&&(n+=t.retain)})}})}_onModelDBValueChanged(e,t){m(()=>{this.sharedModel.transact(()=>{switch(t.type){case"insert":this.sharedModel.updateSource(t.start,t.start,t.value);break;case"remove":this.sharedModel.updateSource(t.start,t.end);break;default:this.sharedModel.setSource(e.text)}})})}get type(){return"code"}get mimeTypeChanged(){return this._mimeTypeChanged}get sharedModelSwitched(){return this._sharedModelSwitched}get value(){return this.modelDB.get("value")}get selections(){return this.modelDB.get("selections")}get mimeType(){return this.modelDB.getValue("mimeType")}set mimeType(e){this.mimeType!==e&&this.modelDB.setValue("mimeType",e)}get isDisposed(){return this._isDisposed}dispose(){this._isDisposed||(this._isDisposed=!0,o.Signal.clearData(this))}_onModelDBMimeTypeChanged(e,t){this._mimeTypeChanged.emit({name:"mimeType",oldValue:t.oldValue,newValue:t.newValue})}},e.defaultConfig={cursorBlinkRate:530,fontFamily:null,fontSize:null,lineHeight:null,lineNumbers:!1,lineWrap:"on",wordWrapColumn:80,readOnly:!1,tabSize:4,insertSpaces:!0,matchBrackets:!0,autoClosingBrackets:!1,handlePaste:!0,rulers:[],codeFolding:!1,showTrailingSpace:!1}}(g||(g={}))},function(e,t,n){"use strict";n.d(t,"a",(function(){return f})),n.d(t,"b",(function(){return m}));var r=n(6),i=n(4),o=(n(10),n(11),n(53)),a=n(25),s=n(78),l=n(52);class c extends s.a{constructor(e){super(),this.doc=e,this.clientID=e.clientID,this.states=new Map,this.meta=new Map,this._checkInterval=setInterval(()=>{const e=o.a();null!==this.getLocalState()&&15e3<=e-this.meta.get(this.clientID).lastUpdated&&this.setLocalState(this.getLocalState());const t=[];this.meta.forEach((n,r)=>{r!==this.clientID&&3e4<=e-n.lastUpdated&&this.states.has(r)&&t.push(r)}),t.length>0&&u(this,t,"timeout")},a.d(3e3)),e.on("destroy",()=>{this.destroy()}),this.setLocalState({})}destroy(){this.emit("destroy",[this]),this.setLocalState(null),super.destroy(),clearInterval(this._checkInterval)}getLocalState(){return this.states.get(this.clientID)||null}setLocalState(e){const t=this.clientID,n=this.meta.get(t),r=void 0===n?0:n.clock+1,i=this.states.get(t);null===e?this.states.delete(t):this.states.set(t,e),this.meta.set(t,{clock:r,lastUpdated:o.a()});const a=[],s=[],c=[],u=[];null===e?u.push(t):null==i?null!=e&&a.push(t):(s.push(t),l.b(i,e)||c.push(t)),(a.length>0||c.length>0||u.length>0)&&this.emit("change",[{added:a,updated:c,removed:u},"local"]),this.emit("update",[{added:a,updated:s,removed:u},"local"])}setLocalStateField(e,t){const n=this.getLocalState();null!==n&&this.setLocalState({...n,[e]:t})}getStates(){return this.states}}const u=(e,t,n)=>{const r=[];for(let n=0;n<t.length;n++){const i=t[n];if(e.states.has(i)){if(e.states.delete(i),i===e.clientID){const t=e.meta.get(i);e.meta.set(i,{clock:t.clock+1,lastUpdated:o.a()})}r.push(i)}}r.length>0&&(e.emit("change",[{added:[],updated:[],removed:r},n]),e.emit("update",[{added:[],updated:[],removed:r},n]))};var d=n(36);const h=e=>JSON.parse(JSON.stringify(e));class p{constructor(){this.isDisposed=!1,this.ydoc=new d.b,this.source=this.ydoc.getText("source"),this.ystate=this.ydoc.getMap("state"),this.undoManager=new d.e([this.source],{trackedOrigins:new Set([this])}),this.awareness=new c(this.ydoc),this._changed=new i.Signal(this)}get dirty(){return this.ystate.get("dirty")}set dirty(e){this.transact(()=>{this.ystate.set("dirty",e)},!1)}transact(e,t=!0){this.ydoc.transact(e,t?this:null)}dispose(){this.isDisposed=!0,this.ydoc.destroy()}canUndo(){return this.undoManager.undoStack.length>0}canRedo(){return this.undoManager.redoStack.length>0}undo(){this.undoManager.undo()}redo(){this.undoManager.redo()}clearUndoHistory(){this.undoManager.clear()}get changed(){return this._changed}}class f extends p{constructor(){super(),this._modelObserver=e=>{const t={};t.sourceChange=e.changes.delta,this._changed.emit(t)},this._onStateChanged=e=>{const t=[];e.keysChanged.forEach(n=>{const r=e.changes.keys.get(n);r&&t.push({name:n,oldValue:r.oldValue,newValue:this.ystate.get(n)})}),this._changed.emit({stateChange:t})},this.ysource=this.ydoc.getText("source"),this.ysource.observe(this._modelObserver),this.ystate.observe(this._onStateChanged)}dispose(){this.ysource.unobserve(this._modelObserver),this.ystate.unobserve(this._onStateChanged)}static create(){return new f}getSource(){return this.ysource.toString()}setSource(e){this.transact(()=>{const t=this.ysource;t.delete(0,t.length),t.insert(0,e)})}updateSource(e,t,n=""){this.transact(()=>{const r=this.ysource;r.insert(e,n),r.delete(e+n.length,t-e)})}}const m=(e,t)=>{switch(e){case"markdown":return _.createStandalone(t);case"code":return v.createStandalone(t);default:return y.createStandalone(t)}};class g{constructor(e){this._notebook=null,this.isStandalone=!1,this._modelObserver=e=>{const t={},n=e.find(e=>e.target===this.ymodel.get("source"));n&&(t.sourceChange=n.changes.delta);const r=e.find(e=>e.target===this.ymodel.get("outputs"));r&&(t.outputsChange=r.changes.delta);const i=e.find(e=>e.target===this.ymodel);if(i&&i.keysChanged.has("metadata")){const e=i.changes.keys.get("metadata");t.metadataChange={oldValue:(null==e?void 0:e.oldValue)?e.oldValue:void 0,newValue:this.getMetadata()}}if(i&&i.keysChanged.has("execution_count")){const e=i.changes.keys.get("execution_count");t.executionCountChange={oldValue:e.oldValue,newValue:this.ymodel.get("execution_count")}}const o=this.ymodel.get("source");i&&i.keysChanged.has("source")&&(t.sourceChange=[{delete:this._prevSourceLength},{insert:o.toString()}]),this._prevSourceLength=o.length,this._changed.emit(t)},this.isDisposed=!1,this._undoManager=null,this._changed=new i.Signal(this),this.ymodel=e;const t=e.get("source");this._prevSourceLength=t?t.length:0,this.ymodel.observeDeep(this._modelObserver),this._awareness=null}get ysource(){return this.ymodel.get("source")}get awareness(){var e,t,n;return null!==(n=null!==(e=this._awareness)&&void 0!==e?e:null===(t=this.notebook)||void 0===t?void 0:t.awareness)&&void 0!==n?n:null}transact(e,t=!0){this.notebook&&t?this.notebook.transact(e):this.ymodel.doc.transact(e,this)}get undoManager(){var e;return this.notebook?(null===(e=this.notebook)||void 0===e?void 0:e.disableDocumentWideUndoRedo)?this._undoManager:this.notebook.undoManager:this._undoManager}set undoManager(e){this._undoManager=e}undo(){var e;null===(e=this.undoManager)||void 0===e||e.undo()}redo(){var e;null===(e=this.undoManager)||void 0===e||e.redo()}canUndo(){return!!this.undoManager&&this.undoManager.undoStack.length>0}canRedo(){return!!this.undoManager&&this.undoManager.redoStack.length>0}clearUndoHistory(){var e;null===(e=this.undoManager)||void 0===e||e.clear()}get notebook(){return this._notebook}static create(e=r.UUID.uuid4()){const t=new d.c,n=new d.d;return t.set("source",n),t.set("metadata",{}),t.set("cell_type",this.prototype.cell_type),t.set("id",e),new this(t)}static createStandalone(e){const t=this.create(e);t.isStandalone=!0;const n=new d.b;return n.getArray().insert(0,[t.ymodel]),t._awareness=new c(n),t._undoManager=new d.e([t.ymodel],{trackedOrigins:new Set([t])}),t}clone(){const e=new d.c,t=new d.d(this.getSource());e.set("source",t),e.set("metadata",this.getMetadata()),e.set("cell_type",this.cell_type),e.set("id",this.getId());const n=new(0,this.constructor)(e);return n._undoManager=this.undoManager,n}get changed(){return this._changed}dispose(){this.ymodel.unobserveDeep(this._modelObserver)}getAttachments(){return this.ymodel.get("attachments")}setAttachments(e){this.transact(()=>{null==e?this.ymodel.delete("attachments"):this.ymodel.set("attachments",e)})}getId(){return this.ymodel.get("id")}getSource(){return this.ymodel.get("source").toString()}setSource(e){const t=this.ymodel.get("source");this.transact(()=>{t.delete(0,t.length),t.insert(0,e)})}updateSource(e,t,n=""){this.transact(()=>{const r=this.ysource;r.insert(e,n),r.delete(e+n.length,t-e)})}get cell_type(){throw new Error("A YBaseCell must not be constructed")}getMetadata(){return h(this.ymodel.get("metadata"))}setMetadata(e){this.transact(()=>{this.ymodel.set("metadata",h(e))})}toJSON(){return{id:this.getId(),cell_type:this.cell_type,source:this.getSource(),metadata:this.getMetadata()}}}class v extends g{get cell_type(){return"code"}get execution_count(){return this.ymodel.get("execution_count")}set execution_count(e){this.transact(()=>{this.ymodel.set("execution_count",e)})}getOutputs(){return h(this.ymodel.get("outputs").toArray())}setOutputs(e){const t=this.ymodel.get("outputs");this.transact(()=>{t.delete(0,t.length),t.insert(0,e)},!1)}updateOutputs(e,t,n=[]){const r=this.ymodel.get("outputs"),i=t<r.length?t-e:r.length-e;this.transact(()=>{r.delete(e,i),r.insert(e,n)},!1)}static create(e){const t=super.create(e);return t.ymodel.set("execution_count",0),t.ymodel.set("outputs",new d.a),t}static createStandalone(e){const t=super.createStandalone(e);return t.ymodel.set("execution_count",null),t.ymodel.set("outputs",new d.a),t}clone(){const e=super.clone(),t=new d.a;return t.insert(0,this.getOutputs()),e.ymodel.set("execution_count",this.execution_count),e.ymodel.set("outputs",t),e}toJSON(){return{id:this.getId(),cell_type:"code",source:this.getSource(),metadata:this.getMetadata(),outputs:this.getOutputs(),execution_count:this.execution_count}}}class y extends g{static create(e){return super.create(e)}static createStandalone(e){return super.createStandalone(e)}get cell_type(){return"raw"}toJSON(){return{id:this.getId(),cell_type:"raw",source:this.getSource(),metadata:this.getMetadata(),attachments:this.getAttachments()}}}class _ extends g{static create(e){return super.create(e)}static createStandalone(e){return super.createStandalone(e)}get cell_type(){return"markdown"}toJSON(){return{id:this.getId(),cell_type:"markdown",source:this.getSource(),metadata:this.getMetadata(),attachments:this.getAttachments()}}}}])}));
//# sourceMappingURL=voila.js.map